/**
 * This file is part of JS8Call.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * (C) 2018 Jordan Sherer <kn4crd@gmail.com> - All Rights Reserved
 *
 **/
#include "jsc.h"

const Tuple JSC::map[262144] = {
    // str, len, index
	{"E", 1, 0},
	{"T", 1, 1},
	{"A", 1, 2},
	{"O", 1, 3},
	{"I", 1, 4},
	{"N", 1, 5},
	{"S", 1, 6},
	{"H", 1, 7},
	{"R", 1, 8},
	{"D", 1, 9},
	{"L", 1, 10},
	{"C", 1, 11},
	{"U", 1, 12},
	{"M", 1, 13},
	{"W", 1, 14},
	{"F", 1, 15},
	{"G", 1, 16},
	{"Y", 1, 17},
	{"P", 1, 18},
	{"B", 1, 19},
	{",", 1, 20},
	{".", 1, 21},
	{"V", 1, 22},
	{"K", 1, 23},
	{"-", 1, 24},
	{"+", 1, 25},
	{"\"", 1, 26},
	{"?", 1, 27},
	{"!", 1, 28},
	{"'", 1, 29},
	{"X", 1, 30},
	{")", 1, 31},
	{"(", 1, 32},
	{"0", 1, 33},
	{"J", 1, 34},
	{"1", 1, 35},
	{"Q", 1, 36},
	{"=", 1, 37},
	{"2", 1, 38},
	{":", 1, 39},
	{"Z", 1, 40},
	{"3", 1, 41},
	{"5", 1, 42},
	{"4", 1, 43},
	{"9", 1, 44},
	{"8", 1, 45},
	{"6", 1, 46},
	{"7", 1, 47},
	{"_", 1, 48},
	{"/", 1, 49},
	{"&", 1, 50},
	{"$", 1, 51},
	{"%", 1, 52},
	{"#", 1, 53},
	{"@", 1, 54},
	{"*", 1, 55},
	{">", 1, 56},
	{"<", 1, 57},
	{"[", 1, 58},
	{"]", 1, 59},
	{"{", 1, 60},
	{"}", 1, 61},
	{"|", 1, 62},
	{";", 1, 63},
	{"^", 1, 64},
	{"`", 1, 65},
	{"~", 1, 66},
    {" ", 1, 67},
    {"\\", 1, 68}, // FYI: this used to be FT8 in JS8 1.0
    {"\n", 1, 69}, // FYI: this used to be "\" in JS8 1.0
	{"JS8", 3, 70},
	{"JS8CALL", 7, 71},
    {"\x1A", 1, 72}, // FYI: this used to be JSQSO in JS8 1.0, it is now a substitute flag
    {"JSQCALL", 7, 73},
	{"JORDAN", 6, 74},
	{"KN4CRD", 6, 75},
	{"599", 3, 76},
	{"559", 3, 77},
	{"589", 3, 78},
	{"579", 3, 79},
	{"569", 3, 80},
    {"@ALLCALL", 7, 81},
	{"BEACON", 6, 82},
	{"CQCQCQ", 6, 83},
	{"CPY?", 4, 84},
	{"QSL?", 4, 85},
	{"AGN?", 4, 86},
	{"AGN", 3, 87},
	{"ACK", 3, 88},
	{"ABT", 3, 89},
	{"ARES", 4, 90},
	{"APRS", 4, 91},
	{"ARL", 3, 92},
	{"ARRL", 4, 93},
	{"ANS", 3, 94},
	{"ANT", 3, 95},
	{"B4", 2, 96},
	{"BC", 2, 97},
	{"BCN", 3, 98},
	{"BCNU", 4, 99},
	{"BD", 2, 100},
	{"BK", 2, 101},
	{"BN", 2, 102},
	{"BEAM", 4, 103},
	{"BEN", 3, 104},
	{"BTU", 3, 105},
	{"BURO", 4, 106},
	{"CALLSIGN", 8, 107},
	{"CB", 2, 108},
	{"CBA", 3, 109},
	{"CFM", 3, 110},
	{"CL", 2, 111},
	{"CLDY", 4, 112},
	{"CLG", 3, 113},
	{"CLR", 3, 114},
	{"CONDX", 5, 115},
	{"CONGRATS", 8, 116},
	{"CONTEST", 7, 117},
	{"CPI", 3, 118},
	{"CPY", 3, 119},
	{"CP?", 3, 120},
	{"CQ", 2, 121},
	{"CQCQ", 4, 122},
	{"CUAGN", 5, 123},
	{"CUD", 3, 124},
	{"DE", 2, 125},
	{"DB", 2, 126},
	{"DOUBLET", 7, 127},
	{"DUBLET", 6, 128},
	{"DIPOLE", 6, 129},
	{"DIT", 3, 130},
	{"DITDIT", 6, 131},
	{"DR", 2, 132},
	{"DSW", 3, 133},
	{"DWN", 3, 134},
	{"DX", 2, 135},
	{"EFHW", 4, 136},
	{"ENDFED", 6, 137},
	{"EL", 2, 138},
	{"ENUF", 4, 139},
	{"FB", 2, 140},
	{"FD", 2, 141},
	{"FER", 3, 142},
	{"FEET", 4, 143},
	{"FIELDDAY", 8, 144},
	{"FIN", 3, 145},
	{"FIST", 4, 146},
	{"FONE", 4, 147},
	{"FM", 2, 148},
	{"FQ", 2, 149},
	{"FREQ", 4, 150},
	{"GA", 2, 151},
	{"GB", 2, 152},
	{"GD", 2, 153},
	{"GE", 2, 154},
	{"GL", 2, 155},
	{"GG", 2, 156},
	{"GM", 2, 157},
	{"GMT", 3, 158},
	{"GN", 2, 159},
	{"GND", 3, 160},
	{"GP", 2, 161},
	{"GRATS", 5, 162},
	{"GRID", 4, 163},
	{"GUD", 3, 164},
	{"HAM", 3, 165},
	{"HC", 2, 166},
	{"HIHI", 4, 167},
	{"HNY", 3, 168},
	{"HPE", 3, 169},
	{"HR", 2, 170},
	{"HV", 2, 171},
	{"HVNT", 4, 172},
	{"HVY", 3, 173},
	{"HW?", 3, 174},
	{"HWCPY?", 6, 175},
	{"HXA", 3, 176},
	{"HXB", 3, 177},
	{"HXC", 3, 178},
	{"HXD", 3, 179},
	{"HXE", 3, 180},
	{"HXF", 3, 181},
	{"HXG", 3, 182},
	{"INV", 3, 183},
	{"JA", 2, 184},
	{"JMP", 3, 185},
	{"KN", 2, 186},
	{"KW", 2, 187},
	{"KNW", 3, 188},
	{"LID", 3, 189},
	{"LOOP", 4, 190},
	{"LP", 2, 191},
	{"LSB", 3, 192},
	{"LW", 2, 193},
	{"MIL", 3, 194},
	{"METER", 5, 195},
	{"MODE", 4, 196},
	{"MHZ", 3, 197},
	{"MGR", 3, 198},
	{"MNI", 3, 199},
	{"MSG", 3, 200},
	{"MW", 2, 201},
	{"MULT", 4, 202},
	{"NIL", 3, 203},
	{"NR", 2, 204},
	{"NW", 2, 205},
	{"OB", 2, 206},
	{"OC", 2, 207},
	{"OM", 2, 208},
	{"OP", 2, 209},
	{"OPR", 3, 210},
	{"PSE", 3, 211},
	{"PWR", 3, 212},
	{"PO", 2, 213},
	{"PFX", 3, 214},
	{"QSLL", 4, 215},
	{"RR", 2, 216},
	{"RR73", 4, 217},
	{"RRR", 3, 218},
	{"RACES", 5, 219},
	{"RECV", 4, 220},
	{"RCV", 3, 221},
	{"RCVD", 4, 222},
	{"RCVR", 4, 223},
	{"RIG", 3, 224},
	{"RX", 2, 225},
	{"SDR", 3, 226},
	{"SHUD", 4, 227},
	{"SIG", 3, 228},
	{"SK", 2, 229},
	{"SKED", 4, 230},
	{"SNR", 3, 231},
	{"SNW", 3, 232},
	{"SP", 2, 233},
	{"SPCL", 4, 234},
	{"SRI", 3, 235},
	{"STD", 3, 236},
	{"STN", 3, 237},
	{"SWL", 3, 238},
	{"TEMP", 4, 239},
	{"TEST", 4, 240},
	{"TFC", 3, 241},
	{"TIL", 3, 242},
	{"TCVR", 4, 243},
	{"TRANSCEIVER", 11, 244},
	{"TU", 2, 245},
	{"TX", 2, 246},
	{"TKS", 3, 247},
	{"THX", 3, 248},
	{"TNX", 3, 249},
	{"UFB", 3, 250},
	{"UR", 2, 251},
	{"URS", 3, 252},
	{"USB", 3, 253},
	{"UTC", 3, 254},
	{"VEE", 3, 255},
	{"VERT", 4, 256},
	{"VERTICAL", 8, 257},
	{"VFO", 3, 258},
	{"VY", 2, 259},
	{"VVV", 3, 260},
	{"W1AW", 4, 261},
	{"WATTS", 5, 262},
	{"WTTS", 4, 263},
	{"WID", 3, 264},
	{"WIRE", 4, 265},
	{"WK", 2, 266},
	{"WKD", 3, 267},
	{"WKG", 3, 268},
	{"WL", 2, 269},
	{"WPM", 3, 270},
	{"WRK", 3, 271},
	{"WUD", 3, 272},
	{"WX", 2, 273},
	{"XCVR", 4, 274},
	{"XMTR", 4, 275},
	{"XTAL", 4, 276},
	{"XYL", 3, 277},
	{"YF", 2, 278},
	{"YL", 2, 279},
	{"YR", 2, 280},
	{"YRS", 3, 281},
	{"ZZ", 2, 282},
	{"TGZ", 3, 283},
	{"ZIP", 3, 284},
	{"DOC", 3, 285},
	{"TXT", 3, 286},
	{"ALINCO", 6, 287},
	{"ICOM", 4, 288},
	{"KENWOOD", 7, 289},
	{"YAESU", 5, 290},
	{"ELECRAFT", 8, 291},
	{"FLEX", 4, 292},
	{"QSO", 3, 293},
	{"QSL", 3, 294},
	{"QRM", 3, 295},
	{"QRN", 3, 296},
	{"QTH", 3, 297},
	{"QRP", 3, 298},
	{"QRPP", 4, 299},
	{"QRO", 3, 300},
	{"QSB", 3, 301},
	{"QRZ", 3, 302},
	{"QRL", 3, 303},
	{"QRQ", 3, 304},
	{"QRV", 3, 305},
	{"..", 2, 306},
	{"...", 3, 307},
	{"'T", 2, 308},
	{"'D", 2, 309},
	{"'RE", 3, 310},
	{"'VE", 3, 311},
	{"'LL", 3, 312},
	{"'M", 2, 313},
	{"'S", 2, 314},
	{"-10", 3, 315},
	{"-11", 3, 316},
	{"-12", 3, 317},
	{"-13", 3, 318},
	{"-14", 3, 319},
	{"-15", 3, 320},
	{"-16", 3, 321},
	{"-17", 3, 322},
	{"-18", 3, 323},
	{"-19", 3, 324},
	{"-20", 3, 325},
	{"-21", 3, 326},
	{"-22", 3, 327},
	{"-23", 3, 328},
	{"-24", 3, 329},
	{"10", 2, 330},
	{"20", 2, 331},
	{"30", 2, 332},
	{"32", 2, 333},
	{"40", 2, 334},
	{"50", 2, 335},
	{"60", 2, 336},
	{"64", 2, 337},
	{"70", 2, 338},
	{"80", 2, 339},
	{"90", 2, 340},
	{"100", 3, 341},
	{"128", 3, 342},
	{"500", 3, 343},
	{"817", 3, 344},
	{"1000", 4, 345},
	{"232", 3, 346},
	{"33", 2, 347},
	{"42", 2, 348},
	{"55", 2, 349},
	{"72", 2, 350},
	{"73", 2, 351},
	{"88", 2, 352},
	{"59", 2, 353},
	{"100MW", 5, 354},
	{"500MW", 5, 355},
	{"5W", 2, 356},
	{"10W", 3, 357},
	{"30W", 3, 358},
	{"50W", 3, 359},
	{"100W", 4, 360},
	{"ONE", 3, 361},
	{"TWO", 3, 362},
	{"THREE", 5, 363},
	{"FOUR", 4, 364},
	{"FIVE", 4, 365},
	{"SIX", 3, 366},
	{"SEVEN", 5, 367},
	{"EIGHT", 5, 368},
	{"NINE", 4, 369},
	{"TEN", 3, 370},
	{"QRS", 3, 371},
	{"QRT", 3, 372},
	{"QRU", 3, 373},
	{"QRX", 3, 374},
	{"QSK", 3, 375},
	{"QST", 3, 376},
	{"QSX", 3, 377},
	{"QSY", 3, 378},
	{"QRA", 3, 379},
	{"QRB", 3, 380},
	{"QRG", 3, 381},
	{"QRH", 3, 382},
	{"QRI", 3, 383},
	{"QRK", 3, 384},
	{"QRW", 3, 385},
	{"QSA", 3, 386},
	{"QSD", 3, 387},
	{"QSG", 3, 388},
	{"QSM", 3, 389},
	{"QSN", 3, 390},
	{"QSP", 3, 391},
	{"QSU", 3, 392},
	{"QSV", 3, 393},
	{"QSW", 3, 394},
	{"QSZ", 3, 395},
	{"QTA", 3, 396},
	{"QTB", 3, 397},
	{"QTC", 3, 398},
	{"QTR", 3, 399},
	{"VERED", 5, 400},
	{"ABOUT", 5, 401},
	{"ACCESSIBILITY", 13, 402},
	{"ACCURATE", 8, 403},
	{"ACHIEVEMENT", 11, 404},
	{"ADDITIONAL", 10, 405},
	{"ADDRESS", 7, 406},
	{"ADDRESSED", 9, 407},
	{"ADVISE", 6, 408},
	{"AGAIN", 5, 409},
	{"ALSO", 4, 410},
	{"ALWAYS", 6, 411},
	{"AM", 2, 412},
	{"AND", 3, 413},
	{"ANXIOUS", 7, 414},
	{"APPRECIATED", 11, 415},
	{"ARE", 3, 416},
	{"AREA", 4, 417},
	{"ARRANGE", 7, 418},
	{"ARRIVAL", 7, 419},
	{"ARRIVED", 7, 420},
	{"ARRIVING", 8, 421},
	{"ASSIST", 6, 422},
	{"ASSISTANCE", 10, 423},
	{"AUTHORITIES", 11, 424},
	{"AVAILABILITY", 12, 425},
	{"AVAILABLE", 9, 426},
	{"BE", 2, 427},
	{"BECAUSE", 7, 428},
	{"BECOMING", 8, 429},
	{"BEING", 5, 430},
	{"BEST", 4, 431},
	{"BIRTHDAY", 8, 432},
	{"BUREAU", 6, 433},
	{"BY", 2, 434},
	{"CARE", 4, 435},
	{"CHANNEL", 7, 436},
	{"CHILD", 5, 437},
	{"CHRISTMAS", 9, 438},
	{"COME", 4, 439},
	{"COMING", 6, 440},
	{"COMMUNICATION", 13, 441},
	{"COMMUNICATIONS", 14, 442},
	{"CONCERNED", 9, 443},
	{"CONDITION", 9, 444},
	{"CONDITIONS", 10, 445},
	{"CONGRATULATIONS", 15, 446},
	{"CONTACT", 7, 447},
	{"COULD", 5, 448},
	{"CRITICAL", 8, 449},
	{"DAMAGE", 6, 450},
	{"DEFEAT", 6, 451},
	{"DELAY", 5, 452},
	{"DELIGHTED", 9, 453},
	{"DELIVERED", 9, 454},
	{"DELIVERING", 10, 455},
	{"DESERVED", 8, 456},
	{"DISASTER", 8, 457},
	{"DO", 2, 458},
	{"DON'T", 5, 459},
	{"EIGHTEEN", 8, 460},
	{"ELEVEN", 6, 461},
	{"EMERGENCY", 9, 462},
	{"ENJOY", 5, 463},
	{"ENJOYED", 7, 464},
	{"ENVELOPES", 9, 465},
	{"EQUIPMENT", 9, 466},
	{"ESTABLISH", 9, 467},
	{"EVACUATION", 10, 468},
	{"EVERYONE", 8, 469},
	{"EVERYTHING", 10, 470},
	{"EXCELLENT", 9, 471},
	{"EXISTING", 8, 472},
	{"EXITS", 5, 473},
	{"EXTENT", 6, 474},
	{"FELLOWSHIP", 10, 475},
	{"FIFTEEN", 7, 476},
	{"FIFTY", 5, 477},
	{"FINE", 4, 478},
	{"FOR", 3, 479},
	{"FORTY", 5, 480},
	{"FORWARD", 7, 481},
	{"FOURTEEN", 8, 482},
	{"FREE", 4, 483},
	{"FROM", 4, 484},
	{"FUN", 3, 485},
	{"FURNISH", 7, 486},
	{"FURTHER", 7, 487},
	{"GETTING", 7, 488},
	{"GLAD", 4, 489},
	{"GOOD", 4, 490},
	{"GREETINGS", 9, 491},
	{"HAND", 4, 492},
	{"HAPPY", 5, 493},
	{"HAVE", 4, 494},
	{"HAVING", 6, 495},
	{"HEALTH", 6, 496},
	{"HEAR", 4, 497},
	{"HELP", 4, 498},
	{"HERE", 4, 499},
	{"HOLIDAY", 7, 500},
	{"HOME", 4, 501},
	{"HOPE", 4, 502},
	{"HOSPITAL", 8, 503},
	{"ILL", 3, 504},
	{"IMMEDIATE", 9, 505},
	{"INCREASING", 10, 506},
	{"INFORM", 6, 507},
	{"INFORMATION", 11, 508},
	{"INJURED", 7, 509},
	{"INSTRUCTIONS", 12, 510},
	{"IT'S", 4, 511},
	{"KNOW", 4, 512},
	{"LET", 3, 513},
	{"LOCAL", 5, 514},
	{"LOCATION", 8, 515},
	{"LOOKING", 7, 516},
	{"LOSSES", 6, 517},
	{"MAIL", 4, 518},
	{"MANY", 4, 519},
	{"ME", 2, 520},
	{"MEDICAL", 7, 521},
	{"MEET", 4, 522},
	{"MERRY", 5, 523},
	{"MESSAGE", 7, 524},
	{"MOBILE", 6, 525},
	{"MORE", 4, 526},
	{"MOST", 4, 527},
	{"MOTHER", 6, 528},
	{"MOVING", 6, 529},
	{"NAME", 4, 530},
	{"NEED", 4, 531},
	{"NEEDED", 6, 532},
	{"NEW", 3, 533},
	{"NEWS", 4, 534},
	{"NINETEEN", 8, 535},
	{"NOT", 3, 536},
	{"NOW", 3, 537},
	{"NUMBER", 6, 538},
	{"OF", 2, 539},
	{"ONCE", 4, 540},
	{"ONLY", 4, 541},
	{"OPERATORS", 9, 542},
	{"OR", 2, 543},
	{"ORGANIZATION", 12, 544},
	{"OUR", 3, 545},
	{"PLANS", 5, 546},
	{"PLEASANT", 8, 547},
	{"PLEASE", 6, 548},
	{"PORTABLE", 8, 549},
	{"POSSIBLE", 8, 550},
	{"PROPERTY", 8, 551},
	{"PROVIDE", 7, 552},
	{"PUBLIC", 6, 553},
	{"QSLS", 4, 554},
	{"RADIO", 5, 555},
	{"REACH", 5, 556},
	{"REACT", 5, 557},
	{"REALLY", 6, 558},
	{"RECEIVED", 8, 559},
	{"RECEIVING", 9, 560},
	{"RECOVERING", 10, 561},
	{"RECOVERY", 8, 562},
	{"REFERENCE", 9, 563},
	{"RELOCATED", 9, 564},
	{"REPLY", 5, 565},
	{"REPORT", 6, 566},
	{"REPORTS", 7, 567},
	{"REQUEST", 7, 568},
	{"RESCUE", 6, 569},
	{"RESIDENTS", 9, 570},
	{"RETURN", 6, 571},
	{"SAFE", 4, 572},
	{"SAFELY", 6, 573},
	{"SEARCH", 6, 574},
	{"SEASON", 6, 575},
	{"SELF", 4, 576},
	{"SEND", 4, 577},
	{"SENT", 4, 578},
	{"SERVICE", 7, 579},
	{"SERVICES", 8, 580},
	{"SEVENTEEN", 9, 581},
	{"SEVERE", 6, 582},
	{"SICK", 4, 583},
	{"SITUATION", 9, 584},
	{"SIXTEEN", 7, 585},
	{"SIXTY", 5, 586},
	{"SLIGHT", 6, 587},
	{"SOME", 4, 588},
	{"SOON", 4, 589},
	{"SORRY", 5, 590},
	{"SPEEDY", 6, 591},
	{"STANDBY", 7, 592},
	{"STATE", 5, 593},
	{"STRANDED", 8, 594},
	{"TELEPHONE", 9, 595},
	{"TEMPORARILY", 11, 596},
	{"THANKS", 6, 597},
	{"THERE", 5, 598},
	{"THIRTEEN", 8, 599},
	{"THIS", 4, 600},
	{"THROUGH", 7, 601},
	{"TIME", 4, 602},
	{"TOGETHER", 8, 603},
	{"TWELVE", 6, 604},
	{"TWENTY", 6, 605},
	{"TYPE", 4, 606},
	{"UNDELIVERABLE", 13, 607},
	{"URGENTLY", 8, 608},
	{"USE", 3, 609},
	{"VERY", 4, 610},
	{"VICTORY", 7, 611},
	{"WAY", 3, 612},
	{"WEATHER", 7, 613},
	{"WELCOME", 7, 614},
	{"WELFARE", 7, 615},
	{"WELL", 4, 616},
	{"WHAT", 4, 617},
	{"WHEN", 4, 618},
	{"WILL", 4, 619},
	{"WIN", 3, 620},
	{"WISH", 4, 621},
	{"WISHES", 6, 622},
	{"WISHING", 7, 623},
	{"WITH", 4, 624},
	{"WITHOUT", 7, 625},
	{"WONDERFUL", 9, 626},
	{"WORD", 4, 627},
	{"WORRY", 5, 628},
	{"WORTHY", 6, 629},
	{"YEAR", 4, 630},
	{"YOU", 3, 631},
	{"YOUR", 4, 632},
	{"YOURS", 5, 633},
	{":)", 2, 634},
	{":P", 2, 635},
	{":-)", 3, 636},
	{":-P", 3, 637},
	{":D", 2, 638},
	{":(", 2, 639},
	{":-(", 3, 640},
	{"=)", 2, 641},
	{"=D", 2, 642},
	{"<3", 2, 643},
	{"YCO", 3, 644},
	{"AREN'T", 6, 645},
	{"CAN'T", 5, 646},
	{"COULDN'T", 8, 647},
	{"DIDN'T", 6, 648},
	{"DOESN'T", 7, 649},
	{"HADN'T", 6, 650},
	{"HASN'T", 6, 651},
	{"HAVEN'T", 7, 652},
	{"HE'D", 4, 653},
	{"HE'LL", 5, 654},
	{"HE'S", 4, 655},
	{"I'D", 3, 656},
	{"I'LL", 4, 657},
	{"I'M", 3, 658},
	{"I'VE", 4, 659},
	{"ISN'T", 5, 660},
	{"LET'S", 5, 661},
	{"MIGHTN'T", 8, 662},
	{"MUSTN'T", 7, 663},
	{"SHAN'T", 6, 664},
	{"SHE'D", 5, 665},
	{"SHE'LL", 6, 666},
	{"SHE'S", 5, 667},
	{"SHOULDN'T", 9, 668},
	{"THAT'S", 6, 669},
	{"THERE'S", 7, 670},
	{"THEY'D", 6, 671},
	{"THEY'LL", 7, 672},
	{"THEY'RE", 7, 673},
	{"THEY'VE", 7, 674},
	{"WE'D", 4, 675},
	{"WE'RE", 5, 676},
	{"WE'VE", 5, 677},
	{"WEREN'T", 7, 678},
	{"WHAT'LL", 7, 679},
	{"WHAT'RE", 7, 680},
	{"WHAT'S", 6, 681},
	{"WHAT'VE", 7, 682},
	{"WHERE'S", 7, 683},
	{"WHO'S", 5, 684},
	{"WHO'LL", 6, 685},
	{"WHO'RE", 6, 686},
	{"WHO'VE", 6, 687},
	{"WON'T", 5, 688},
	{"WOULDN'T", 8, 689},
	{"Y'ALL", 5, 690},
	{"YOU'D", 5, 691},
	{"YOU'LL", 6, 692},
	{"YOU'RE", 6, 693},
	{"YOU'VE", 6, 694},
	{"THAT", 4, 695},
	{"LYI", 3, 696},
	{"YFO", 3, 697},
	{"YWI", 3, 698},
	{"YWA", 3, 699},
	{"RYI", 3, 700},
	{"LYW", 3, 701},
	{"LYB", 3, 702},
	{"YWE", 3, 703},
	{"YWH", 3, 704},
	{"SAY", 3, 705},
	{"ONV", 3, 706},
	{"THEY", 4, 707},
	{"NJU", 3, 708},
	{"YSH", 3, 709},
	{"BUT", 3, 710},
	{"N'T", 3, 711},
	{"LBU", 3, 712},
	{"TYI", 3, 713},
	{"YWO", 3, 714},
	{"YFR", 3, 715},
	{"FYO", 3, 716},
	{"OUB", 3, 717},
	{"WAS", 3, 718},
	{"WNE", 3, 719},
	{"RBU", 3, 720},
	{"YLO", 3, 721},
	{"YDO", 3, 722},
	{"AYW", 3, 723},
	{"YBU", 3, 724},
	{"OJE", 3, 725},
	{"YBO", 3, 726},
	{"THEIR", 5, 727},
	{"LYL", 3, 728},
	{"EYR", 3, 729},
	{"YLA", 3, 730},
	{"RYB", 3, 731},
	{"TBY", 3, 732},
	{"YHI", 3, 733},
	{"CAN", 3, 734},
	{"TYW", 3, 735},
	{"WHO", 3, 736},
	{"GET", 3, 737},
	{"EYD", 3, 738},
	{"EYT", 3, 739},
	{"HER", 3, 740},
	{"YFI", 3, 741},
	{"RYF", 3, 742},
	{"RYP", 3, 743},
	{"EOV", 3, 744},
	{"DJU", 3, 745},
	{"AYH", 3, 746},
	{"WOULD", 5, 747},
	{"YHO", 3, 748},
	{"MY", 2, 749},
	{"ALL", 3, 750},
	{"IQU", 3, 751},
	{"DQU", 3, 752},
	{"YFA", 3, 753},
	{"MAKE", 4, 754},
	{"LYG", 3, 755},
	{"OUW", 3, 756},
	{"LKI", 3, 757},
	{"UP", 2, 758},
	{"NGY", 3, 759},
	{"OFTH", 4, 760},
	{"THINK", 5, 761},
	{"BYH", 3, 762},
	{"NYW", 3, 763},
	{"TJU", 3, 764},
	{"RYH", 3, 765},
	{"YEX", 3, 766},
	{"OUH", 3, 767},
	{"HEQ", 3, 768},
	{"INTH", 4, 769},
	{"PEOPLE", 6, 770},
	{"WHICH", 5, 771},
	{"AYL", 3, 772},
	{"YBR", 3, 773},
	{"OUT", 3, 774},
	{"THEM", 4, 775},
	{"JUST", 4, 776},
	{"HIM", 3, 777},
	{"TAKE", 4, 778},
	{"INTO", 4, 779},
	{"YPI", 3, 780},
	{"EYM", 3, 781},
	{"NQU", 3, 782},
	{"YRI", 3, 783},
	{"EYF", 3, 784},
	{"OMW", 3, 785},
	{"INGT", 4, 786},
	{"YGR", 3, 787},
	{"YGE", 3, 788},
	{"YSW", 3, 789},
	{"TYB", 3, 790},
	{"YBY", 3, 791},
	{"TYH", 3, 792},
	{"EYI", 3, 793},
	{"YDR", 3, 794},
	{"THAN", 4, 795},
	{"FHO", 3, 796},
	{"FNE", 3, 797},
	{"LIKE", 4, 798},
	{"EYL", 3, 799},
	{"IXT", 3, 800},
	{"YNI", 3, 801},
	{"OTHER", 5, 802},
	{"YFE", 3, 803},
	{"THEN", 4, 804},
	{"HOW", 3, 805},
	{"BEEN", 4, 806},
	{"WERE", 4, 807},
	{"NMY", 3, 808},
	{"TJO", 3, 809},
	{"WANT", 4, 810},
	{"THESE", 5, 811},
	{"YMU", 3, 812},
	{"YCR", 3, 813},
	{"YYE", 3, 814},
	{"LOOK", 4, 815},
	{"BYF", 3, 816},
	{"TQU", 3, 817},
	{"ISJ", 3, 818},
	{"NIQ", 3, 819},
	{"BYI", 3, 820},
	{"UEO", 3, 821},
	{"DYT", 3, 822},
	{"RQU", 3, 823},
	{"URH", 3, 824},
	{"FIRST", 5, 825},
	{"FGO", 3, 826},
	{"EEY", 3, 827},
	{"HAD", 3, 828},
	{"YGA", 3, 829},
	{"ORJ", 3, 830},
	{"VEU", 3, 831},
	{"YYO", 3, 832},
	{"DAY", 3, 833},
	{"IXE", 3, 834},
	{"RYG", 3, 835},
	{"AYD", 3, 836},
	{"OGU", 3, 837},
	{"YJU", 3, 838},
	{"EMAIL", 5, 839},
	{"MAN", 3, 840},
	{"WNB", 3, 841},
	{"UBJ", 3, 842},
	{"OEV", 3, 843},
	{"EYG", 3, 844},
	{"THING", 5, 845},
	{"NGTH", 4, 846},
	{"FIND", 4, 847},
	{"YVI", 3, 848},
	{"YCE", 3, 849},
	{"YSF", 3, 850},
	{"OOU", 3, 851},
	{"TELL", 4, 852},
	{"YKN", 3, 853},
	{"GIVE", 4, 854},
	{"PRODUCTS", 8, 855},
	{"THOSE", 5, 856},
	{"IZI", 3, 857},
	{"DGU", 3, 858},
	{"OQU", 3, 859},
	{"EDTO", 4, 860},
	{"RJU", 3, 861},
	{"BACK", 4, 862},
	{"EYN", 3, 863},
	{"YJO", 3, 864},
	{"YDU", 3, 865},
	{"LLK", 3, 866},
	{"EVEN", 4, 867},
	{"YOV", 3, 868},
	{"TGU", 3, 869},
	{"EDTH", 4, 870},
	{"ANY", 3, 871},
	{"NDTH", 4, 872},
	{"COPYRIGHT", 9, 873},
	{"DYW", 3, 874},
	{"BYN", 3, 875},
	{"NYF", 3, 876},
	{"OUV", 3, 877},
	{"WOMAN", 5, 878},
	{"JAN", 3, 879},
	{"LIFE", 4, 880},
	{"ATTH", 4, 881},
	{"WNH", 3, 882},
	{"DOWN", 4, 883},
	{"YTW", 3, 884},
	{"YBI", 3, 885},
	{"INFO", 4, 886},
	{"RIGHTS", 6, 887},
	{"KEU", 3, 888},
	{"MAY", 3, 889},
	{"FVI", 3, 890},
	{"YKI", 3, 891},
	{"OZE", 3, 892},
	{"OYM", 3, 893},
	{"UEW", 3, 894},
	{"BOOKS", 5, 895},
	{"EXU", 3, 896},
	{"WORK", 4, 897},
	{"THJ", 3, 898},
	{"YRU", 3, 899},
	{"LINKS", 5, 900},
	{"YEARS", 5, 901},
	{"AFTER", 5, 902},
	{"SHOULD", 6, 903},
	{"CALL", 4, 904},
	{"ITEMS", 5, 905},
	{"SCHOOL", 6, 906},
	{"WORLD", 5, 907},
	{"OVER", 4, 908},
	{"UNW", 3, 909},
	{"YGI", 3, 910},
	{"HQU", 3, 911},
	{"STILL", 5, 912},
	{"OJU", 3, 913},
	{"TRY", 3, 914},
	{"SAID", 4, 915},
	{"DOES", 4, 916},
	{"LAST", 4, 917},
	{"OLW", 3, 918},
	{"JANUARY", 7, 919},
	{"IJU", 3, 920},
	{"ASK", 3, 921},
	{"REVIEWS", 7, 922},
	{"LSY", 3, 923},
	{"MYH", 3, 924},
	{"GAMES", 5, 925},
	{"DAYS", 4, 926},
	{"NKW", 3, 927},
	{"MYW", 3, 928},
	{"YBL", 3, 929},
	{"NTJ", 3, 930},
	{"FEEL", 4, 931},
	{"EBAY", 4, 932},
	{"LYV", 3, 933},
	{"YQU", 3, 934},
	{"DYB", 3, 935},
	{"COMMENTS", 8, 936},
	{"MADE", 4, 937},
	{"YCU", 3, 938},
	{"FJU", 3, 939},
	{"XHI", 3, 940},
	{"BETWEEN", 7, 941},
	{"NEVER", 5, 942},
	{"DETAILS", 7, 943},
	{"BECOME", 6, 944},
	{"AJU", 3, 945},
	{"OYI", 3, 946},
	{"HIGH", 4, 947},
	{"STUDENT", 7, 948},
	{"SOMETHING", 9, 949},
	{"HOTELS", 6, 950},
	{"DID", 3, 951},
	{"YSD", 3, 952},
	{"USING", 5, 953},
	{"UYI", 3, 954},
	{"RESULTS", 7, 955},
	{"YJA", 3, 956},
	{"AYG", 3, 957},
	{"MUCH", 4, 958},
	{"POSTED", 6, 959},
	{"DYH", 3, 960},
	{"FAMILY", 6, 961},
	{"OKP", 3, 962},
	{"MEAN", 4, 963},
	{"IDY", 3, 964},
	{"STATES", 6, 965},
	{"ANOTHER", 7, 966},
	{"LEAVE", 5, 967},
	{"OWN", 3, 968},
	{"XTY", 3, 969},
	{"DNU", 3, 970},
	{"PUT", 3, 971},
	{"DVD", 3, 972},
	{"SHIPPING", 8, 973},
	{"RESERVED", 8, 974},
	{"OLD", 3, 975},
	{"RNU", 3, 976},
	{"NKH", 3, 977},
	{"WHY", 3, 978},
	{"OWY", 3, 979},
	{"WHILE", 5, 980},
	{"NZA", 3, 981},
	{"BASED", 5, 982},
	{"CYI", 3, 983},
	{"KEEP", 4, 984},
	{"WNM", 3, 985},
	{"GROUP", 5, 986},
	{"TALK", 4, 987},
	{"BIG", 3, 988},
	{"PRICES", 6, 989},
	{"GREAT", 5, 990},
	{"NGTO", 4, 991},
	{"WEBSITE", 7, 992},
	{"WOMEN", 5, 993},
	{"UOU", 3, 994},
	{"COUNTRY", 7, 995},
	{"SAME", 4, 996},
	{"YAV", 3, 997},
	{"OTJ", 3, 998},
	{"TURN", 4, 999},
	{"TNU", 3, 1000},
	{"YVA", 3, 1001},
	{"SEEM", 4, 1002},
	{"EIW", 3, 1003},
	{"YPH", 3, 1004},
	{"BEGIN", 5, 1005},
	{"DKN", 3, 1006},
	{"PROBLEM", 7, 1007},
	{"PAGES", 5, 1008},
	{"UK", 2, 1009},
	{"AMERICAN", 8, 1010},
	{"SPORTS", 6, 1011},
	{"START", 5, 1012},
	{"WHERE", 5, 1013},
	{"YGU", 3, 1014},
	{"EWAS", 4, 1015},
	{"EVERY", 5, 1016},
	{"MEMBERS", 7, 1017},
	{"MIGHT", 5, 1018},
	{"SHOW", 4, 1019},
	{"YMB", 3, 1020},
	{"PART", 4, 1021},
	{"YTU", 3, 1022},
	{"HFU", 3, 1023},
	{"SUCH", 4, 1024},
	{"SYSTEMS", 7, 1025},
	{"STHA", 4, 1026},
	{"EOFT", 4, 1027},
	{"FJO", 3, 1028},
	{"RIGHT", 5, 1029},
	{"AGAINST", 7, 1030},
	{"DOWNLOAD", 8, 1031},
	{"COMPANY", 7, 1032},
	{"PLACE", 5, 1033},
	{"RESOURCES", 9, 1034},
	{"CASE", 4, 1035},
	{"POSTS", 5, 1036},
	{"LYY", 3, 1037},
	{"EDBY", 4, 1038},
	{"SYSTEM", 6, 1039},
	{"WEEK", 4, 1040},
	{"PICTURES", 8, 1041},
	{"FEW", 3, 1042},
	{"YCI", 3, 1043},
	{"DIRECTORY", 9, 1044},
	{"EACH", 4, 1045},
	{"PROGRAM", 7, 1046},
	{"UEH", 3, 1047},
	{"YWR", 3, 1048},
	{"YSY", 3, 1049},
	{"QUESTION", 8, 1050},
	{"OYT", 3, 1051},
	{"GOVERNMENT", 10, 1052},
	{"CHILDREN", 8, 1053},
	{"OHU", 3, 1054},
	{"LYJ", 3, 1055},
	{"USA", 3, 1056},
	{"DURING", 6, 1057},
	{"RYV", 3, 1058},
	{"LJO", 3, 1059},
	{"STUDENTS", 8, 1060},
	{"MR", 2, 1061},
	{"PLAY", 4, 1062},
	{"OKH", 3, 1063},
	{"INGI", 4, 1064},
	{"IRY", 3, 1065},
	{"MBY", 3, 1066},
	{"TIMES", 5, 1067},
	{"LKO", 3, 1068},
	{"SITES", 5, 1069},
	{"RUN", 3, 1070},
	{"UZZ", 3, 1071},
	{"UYA", 3, 1072},
	{"EVENTS", 6, 1073},
	{"YLV", 3, 1074},
	{"SMALL", 5, 1075},
	{"GJU", 3, 1076},
	{"JOHN", 4, 1077},
	{"NIGHT", 5, 1078},
	{"OFF", 3, 1079},
	{"XFO", 3, 1080},
	{"TODAY", 5, 1081},
	{"ERQ", 3, 1082},
	{"HOURS", 5, 1083},
	{"HEWA", 4, 1084},
	{"ASTH", 4, 1085},
	{"HYW", 3, 1086},
	{"HBY", 3, 1087},
	{"HAPPEN", 6, 1088},
	{"RCY", 3, 1089},
	{"IXM", 3, 1090},
	{"MOVE", 4, 1091},
	{"LQU", 3, 1092},
	{"BELIEVE", 7, 1093},
	{"POINT", 5, 1094},
	{"HOLD", 4, 1095},
	{"MILLION", 7, 1096},
	{"CD", 2, 1097},
	{"RYY", 3, 1098},
	{"NEXT", 4, 1099},
	{"LIVE", 4, 1100},
	{"LARGE", 5, 1101},
	{"NDIN", 4, 1102},
	{"LISTING", 7, 1103},
	{"ETHA", 4, 1104},
	{"OMJ", 3, 1105},
	{"BRING", 5, 1106},
	{"STUDY", 5, 1107},
	{"GJO", 3, 1108},
	{"OYD", 3, 1109},
	{"BEFORE", 6, 1110},
	{"ITHT", 4, 1111},
	{"ROOM", 4, 1112},
	{"EYU", 3, 1113},
	{"NGQ", 3, 1114},
	{"ESTH", 4, 1115},
	{"TOOLS", 5, 1116},
	{"MUST", 4, 1117},
	{"GQU", 3, 1118},
	{"LOT", 3, 1119},
	{"DECEMBER", 8, 1120},
	{"HJO", 3, 1121},
	{"EYE", 3, 1122},
	{"MOVIES", 6, 1123},
	{"HJU", 3, 1124},
	{"YORK", 4, 1125},
	{"WATER", 5, 1126},
	{"JOBS", 4, 1127},
	{"ONOF", 4, 1128},
	{"NATIONAL", 8, 1129},
	{"XHA", 3, 1130},
	{"OXE", 3, 1131},
	{"MONEY", 5, 1132},
	{"UNDER", 5, 1133},
	{"FACT", 4, 1134},
	{"AYY", 3, 1135},
	{"CANADA", 6, 1136},
	{"STORY", 5, 1137},
	{"MONTH", 5, 1138},
	{"DIFFERENT", 9, 1139},
	{"WRITE", 5, 1140},
	{"XCO", 3, 1141},
	{"KBY", 3, 1142},
	{"MEN", 3, 1143},
	{"ITHA", 4, 1144},
	{"CATEGORIES", 10, 1145},
	{"TEDT", 4, 1146},
	{"HEAD", 4, 1147},
	{"YOUNG", 5, 1148},
	{"HEFI", 4, 1149},
	{"AYJ", 3, 1150},
	{"EKW", 3, 1151},
	{"XTU", 3, 1152},
	{"YES", 3, 1153},
	{"UYE", 3, 1154},
	{"EINT", 4, 1155},
	{"ISSUE", 5, 1156},
	{"NGIN", 4, 1157},
	{"WINDOWS", 7, 1158},
	{"UTTH", 4, 1159},
	{"PHOTOS", 6, 1160},
	{"KIND", 4, 1161},
	{"JOB", 3, 1162},
	{"ROMT", 4, 1163},
	{"BUSINESS", 8, 1164},
	{"LJA", 3, 1165},
	{"BOOK", 4, 1166},
	{"UTJ", 3, 1167},
	{"BYV", 3, 1168},
	{"GMY", 3, 1169},
	{"UGHT", 4, 1170},
	{"YSK", 3, 1171},
	{"SIDE", 4, 1172},
	{"WZE", 3, 1173},
	{"THOUGH", 6, 1174},
	{"CYW", 3, 1175},
	{"JUNE", 4, 1176},
	{"FYT", 3, 1177},
	{"OCTOBER", 7, 1178},
	{"NOVEMBER", 8, 1179},
	{"BLACK", 5, 1180},
	{"ZZL", 3, 1181},
	{"XMO", 3, 1182},
	{"ULW", 3, 1183},
	{"LITTLE", 6, 1184},
	{"HOUSE", 5, 1185},
	{"LONG", 4, 1186},
	{"FEATURES", 8, 1187},
	{"FAR", 3, 1188},
	{"ACCESSORIES", 11, 1189},
	{"NTIN", 4, 1190},
	{"FORUMS", 6, 1191},
	{"BOTH", 4, 1192},
	{"GAME", 4, 1193},
	{"EHY", 3, 1194},
	{"YND", 3, 1195},
	{"SEPTEMBER", 9, 1196},
	{"FATHER", 6, 1197},
	{"WJE", 3, 1198},
	{"QUESTIONS", 9, 1199},
	{"JULY", 4, 1200},
	{"AWAY", 4, 1201},
	{"POLITICAL", 9, 1202},
	{"GEU", 3, 1203},
	{"IMPORTANT", 9, 1204},
	{"YAHOO", 5, 1205},
	{"EREA", 4, 1206},
	{"AROUND", 6, 1207},
	{"GOING", 5, 1208},
	{"ERSI", 4, 1209},
	{"DEC", 3, 1210},
	{"FRIEND", 6, 1211},
	{"NDZ", 3, 1212},
	{"HOWEVER", 7, 1213},
	{"SERVER", 6, 1214},
	{"POWER", 5, 1215},
	{"SINCE", 5, 1216},
	{"CIZ", 3, 1217},
	{"STAND", 5, 1218},
	{"UNTIL", 5, 1219},
	{"OFTEN", 5, 1220},
	{"AZY", 3, 1221},
	{"ERSO", 4, 1222},
	{"ARTICLES", 8, 1223},
	{"HOUR", 4, 1224},
	{"ISSUES", 6, 1225},
	{"APRIL", 5, 1226},
	{"AMONG", 5, 1227},
	{"USERS", 5, 1228},
	{"THINGS", 6, 1229},
	{"LINE", 4, 1230},
	{"EVER", 4, 1231},
	{"YET", 3, 1232},
	{"EYJ", 3, 1233},
	{"BAD", 3, 1234},
	{"MEMBER", 6, 1235},
	{"PRESIDENT", 9, 1236},
	{"GOT", 3, 1237},
	{"BLOG", 4, 1238},
	{"END", 3, 1239},
	{"LOSE", 4, 1240},
	{"YNT", 3, 1241},
	{"UEZ", 3, 1242},
	{"OMTH", 4, 1243},
	{"LAW", 3, 1244},
	{"CAR", 3, 1245},
	{"INCLUDE", 7, 1246},
	{"LOGIN", 5, 1247},
	{"PAY", 3, 1248},
	{"COMMUNITY", 9, 1249},
	{"FJE", 3, 1250},
	{"EDQ", 3, 1251},
	{"ITJ", 3, 1252},
	{"SOCIAL", 6, 1253},
	{"RYJ", 3, 1254},
	{"FQU", 3, 1255},
	{"CITY", 4, 1256},
	{"HEPR", 4, 1257},
	{"PROGRAMS", 8, 1258},
	{"TEAM", 4, 1259},
	{"OFFERS", 6, 1260},
	{"FGU", 3, 1261},
	{"UIV", 3, 1262},
	{"XRE", 3, 1263},
	{"DTHA", 4, 1264},
	{"STORES", 6, 1265},
	{"NZI", 3, 1266},
	{"FKE", 3, 1267},
	{"OMK", 3, 1268},
	{"OUO", 3, 1269},
	{"AUGUST", 6, 1270},
	{"TYU", 3, 1271},
	{"XTW", 3, 1272},
	{"ALMOST", 6, 1273},
	{"NKM", 3, 1274},
	{"OPTIONS", 7, 1275},
	{"FACE", 4, 1276},
	{"RATES", 5, 1277},
	{"WHITE", 5, 1278},
	{"NOTHING", 7, 1279},
	{"MINUTE", 6, 1280},
	{"LATER", 5, 1281},
	{"KID", 3, 1282},
	{"EROF", 4, 1283},
	{"TIQ", 3, 1284},
	{"OYC", 3, 1285},
	{"CONTINUE", 8, 1286},
	{"AMERICA", 7, 1287},
	{"AGO", 3, 1288},
	{"BODY", 4, 1289},
	{"DOOR", 4, 1290},
	{"WATCH", 5, 1291},
	{"LEARN", 5, 1292},
	{"REAL", 4, 1293},
	{"SEVERAL", 7, 1294},
	{"INGF", 4, 1295},
	{"LEAST", 5, 1296},
	{"EOPL", 4, 1297},
	{"HYH", 3, 1298},
	{"DWIT", 4, 1299},
	{"CHANGE", 6, 1300},
	{"EMBE", 4, 1301},
	{"ACTIVITIES", 10, 1302},
	{"LEAD", 4, 1303},
	{"GIRLS", 5, 1304},
	{"PASSWORD", 8, 1305},
	{"IDEA", 4, 1306},
	{"LATEST", 6, 1307},
	{"WHETHER", 7, 1308},
	{"EIZ", 3, 1309},
	{"LEVEL", 5, 1310},
	{"STOP", 4, 1311},
	{"UNDERSTAND", 10, 1312},
	{"ORQ", 3, 1313},
	{"CHANGES", 7, 1314},
	{"YEF", 3, 1315},
	{"ANYTHING", 8, 1316},
	{"UAK", 3, 1317},
	{"ESOF", 4, 1318},
	{"TEXAS", 5, 1319},
	{"PARENT", 6, 1320},
	{"OCT", 3, 1321},
	{"FOLLOW", 6, 1322},
	{"CREATE", 6, 1323},
	{"INGH", 4, 1324},
	{"POKER", 5, 1325},
	{"BROWSE", 6, 1326},
	{"ROUG", 4, 1327},
	{"EASO", 4, 1328},
	{"FEBRUARY", 8, 1329},
	{"ART", 3, 1330},
	{"ADD", 3, 1331},
	{"WAR", 3, 1332},
	{"IONT", 4, 1333},
	{"DYG", 3, 1334},
	{"AUDIO", 5, 1335},
	{"SPEAK", 5, 1336},
	{"UYT", 3, 1337},
	{"NOV", 3, 1338},
	{"GROUPS", 6, 1339},
	{"RESULT", 6, 1340},
	{"SURE", 4, 1341},
	{"FILES", 5, 1342},
	{"TEACHER", 7, 1343},
	{"OSQ", 3, 1344},
	{"OTHERS", 6, 1345},
	{"ALREADY", 7, 1346},
	{"FAX", 3, 1347},
	{"CHINA", 5, 1348},
	{"HISTORY", 7, 1349},
	{"ALLOW", 5, 1350},
	{"MAKING", 6, 1351},
	{"RESEARCH", 8, 1352},
	{"OFFICE", 6, 1353},
	{"WITHIN", 6, 1354},
	{"SPEND", 5, 1355},
	{"NEEDS", 5, 1356},
	{"READ", 4, 1357},
	{"MORNING", 7, 1358},
	{"WALK", 4, 1359},
	{"EDUCATION", 9, 1360},
	{"PERSON", 6, 1361},
	{"PARTY", 5, 1362},
	{"IRJ", 3, 1363},
	{"AREAS", 5, 1364},
	{"AXC", 3, 1365},
	{"OKY", 3, 1366},
	{"CARDS", 5, 1367},
	{"PROBLEMS", 8, 1368},
	{"LONDON", 6, 1369},
	{"WASHINGTON", 10, 1370},
	{"OPEN", 4, 1371},
	{"RSS", 3, 1372},
	{"IONI", 4, 1373},
	{"RKU", 3, 1374},
	{"CALIFORNIA", 10, 1375},
	{"GIRL", 4, 1376},
	{"GUY", 3, 1377},
	{"SCHOOLS", 7, 1378},
	{"GROW", 4, 1379},
	{"HKE", 3, 1380},
	{"MOMENT", 6, 1381},
	{"HIMSELF", 7, 1382},
	{"COMPANIES", 9, 1383},
	{"LISTED", 6, 1384},
	{"LOW", 3, 1385},
	{"KIW", 3, 1386},
	{"MAYBE", 5, 1387},
	{"YKA", 3, 1388},
	{"UEV", 3, 1389},
	{"EPLA", 4, 1390},
	{"EARLY", 5, 1391},
	{"FORCE", 5, 1392},
	{"ALTHOUGH", 8, 1393},
	{"FOOD", 4, 1394},
	{"UWH", 3, 1395},
	{"POLICY", 6, 1396},
	{"BOY", 3, 1397},
	{"PROCESS", 7, 1398},
	{"FOOT", 4, 1399},
	{"REMEMBER", 8, 1400},
	{"REASON", 6, 1401},
	{"STORIES", 7, 1402},
	{"INGW", 4, 1403},
	{"COMPUTERS", 9, 1404},
	{"NZO", 3, 1405},
	{"OFFER", 5, 1406},
	{"ONSI", 4, 1407},
	{"TOWARD", 6, 1408},
	{"AIR", 3, 1409},
	{"ENOUGH", 6, 1410},
	{"ACROSS", 6, 1411},
	{"YJE", 3, 1412},
	{"IMAGES", 6, 1413},
	{"ACTUALLY", 8, 1414},
	{"TYV", 3, 1415},
	{"HHU", 3, 1416},
	{"YMY", 3, 1417},
	{"INCLUDES", 8, 1418},
	{"ITWA", 4, 1419},
	{"YNU", 3, 1420},
	{"INGC", 4, 1421},
	{"AUSTRALIA", 9, 1422},
	{"LOVE", 4, 1423},
	{"INCLUDING", 9, 1424},
	{"SSIO", 4, 1425},
	{"SECOND", 6, 1426},
	{"ARCHIVE", 7, 1427},
	{"AGE", 3, 1428},
	{"YEAH", 4, 1429},
	{"OYF", 3, 1430},
	{"ABLE", 4, 1431},
	{"XWI", 3, 1432},
	{"VOK", 3, 1433},
	{"FSY", 3, 1434},
	{"ANQ", 3, 1435},
	{"MONTHS", 6, 1436},
	{"EDWI", 4, 1437},
	{"NSJ", 3, 1438},
	{"MUSIC", 5, 1439},
	{"NTOF", 4, 1440},
	{"WAIT", 4, 1441},
	{"FRIENDS", 7, 1442},
	{"OUTT", 4, 1443},
	{"FAQ", 3, 1444},
	{"CONSIDER", 8, 1445},
	{"EFIR", 4, 1446},
	{"GVO", 3, 1447},
	{"CARS", 4, 1448},
	{"MESSAGES", 8, 1449},
	{"EWIT", 4, 1450},
	{"UPDATED", 7, 1451},
	{"HUMAN", 5, 1452},
	{"EPRE", 4, 1453},
	{"BUY", 3, 1454},
	{"PROVIDES", 8, 1455},
	{"DAVID", 5, 1456},
	{"OYW", 3, 1457},
	{"NSQ", 3, 1458},
	{"APPEAR", 6, 1459},
	{"MARKET", 6, 1460},
	{"STUDIES", 7, 1461},
	{"ECAU", 4, 1462},
	{"PROBABLY", 8, 1463},
	{"SERVE", 5, 1464},
	{"FEB", 3, 1465},
	{"ATUR", 4, 1466},
	{"SEP", 3, 1467},
	{"CALLED", 6, 1468},
	{"NTHA", 4, 1469},
	{"GYW", 3, 1470},
	{"RTHA", 4, 1471},
	{"ARTS", 4, 1472},
	{"DIE", 3, 1473},
	{"CKJ", 3, 1474},
	{"POWERED", 7, 1475},
	{"GJA", 3, 1476},
	{"SOLUTIONS", 9, 1477},
	{"EXPERIENCE", 10, 1478},
	{"MEANS", 5, 1479},
	{"IXW", 3, 1480},
	{"EWOR", 4, 1481},
	{"ORET", 4, 1482},
	{"NATION", 6, 1483},
	{"NCLU", 4, 1484},
	{"COLLEGE", 7, 1485},
	{"STAY", 4, 1486},
	{"FALL", 4, 1487},
	{"UBLI", 4, 1488},
	{"LMY", 3, 1489},
	{"BUILD", 5, 1490},
	{"INTEREST", 8, 1491},
	{"ERTO", 4, 1492},
	{"ONTR", 4, 1493},
	{"COURSE", 6, 1494},
	{"KFU", 3, 1495},
	{"RKY", 3, 1496},
	{"CUT", 3, 1497},
	{"RDQ", 3, 1498},
	{"SAYS", 4, 1499},
	{"SENSE", 5, 1500},
	{"PLAN", 4, 1501},
	{"OMET", 4, 1502},
	{"SOMEONE", 7, 1503},
	{"EXPECT", 6, 1504},
	{"MAR", 3, 1505},
	{"HEHA", 4, 1506},
	{"EFFECT", 6, 1507},
	{"DONE", 4, 1508},
	{"BEHIND", 6, 1509},
	{"FRANCE", 6, 1510},
	{"HOUG", 4, 1511},
	{"MICROSOFT", 9, 1512},
	{"HEWO", 4, 1513},
	{"EDFO", 4, 1514},
	{"RECORDS", 7, 1515},
	{"ECOU", 4, 1516},
	{"INGP", 4, 1517},
	{"COSTS", 5, 1518},
	{"ESTR", 4, 1519},
	{"URL", 3, 1520},
	{"DEATH", 5, 1521},
	{"PARTS", 5, 1522},
	{"AUG", 3, 1523},
	{"HGU", 3, 1524},
	{"LYZ", 3, 1525},
	{"XYE", 3, 1526},
	{"DOWNLOADS", 9, 1527},
	{"KILL", 4, 1528},
	{"SUGGEST", 7, 1529},
	{"MILES", 5, 1530},
	{"DEVELOPMENT", 11, 1531},
	{"APPLICATIONS", 12, 1532},
	{"UPY", 3, 1533},
	{"CLASS", 5, 1534},
	{"REMAIN", 6, 1535},
	{"ONIN", 4, 1536},
	{"YZE", 3, 1537},
	{"OUJ", 3, 1538},
	{"ONEO", 4, 1539},
	{"APR", 3, 1540},
	{"HROU", 4, 1541},
	{"HOSTING", 7, 1542},
	{"ECONOMIC", 8, 1543},
	{"RULES", 5, 1544},
	{"CONTROL", 7, 1545},
	{"TICKETS", 7, 1546},
	{"AYV", 3, 1547},
	{"CENTRE", 6, 1548},
	{"REQUIREMENTS", 12, 1549},
	{"ESID", 4, 1550},
	{"NUDE", 4, 1551},
	{"VOICE", 5, 1552},
	{"WKI", 3, 1553},
	{"KIDS", 4, 1554},
	{"REQUIRE", 7, 1555},
	{"PYW", 3, 1556},
	{"EWV", 3, 1557},
	{"OWIN", 4, 1558},
	{"MINUTES", 7, 1559},
	{"FORMER", 6, 1560},
	{"OBW", 3, 1561},
	{"OWJ", 3, 1562},
	{"ZZI", 3, 1563},
	{"ROLE", 4, 1564},
	{"HATW", 4, 1565},
	{"UXU", 3, 1566},
	{"THANK", 5, 1567},
	{"TTHA", 4, 1568},
	{"KYT", 3, 1569},
	{"ISHE", 4, 1570},
	{"FBY", 3, 1571},
	{"GIFTS", 5, 1572},
	{"EUROPE", 6, 1573},
	{"DITI", 4, 1574},
	{"OEU", 3, 1575},
	{"IAK", 3, 1576},
	{"TOPICS", 6, 1577},
	{"ELSE", 4, 1578},
	{"SELL", 4, 1579},
	{"UYO", 3, 1580},
	{"TIPS", 4, 1581},
	{"MAJOR", 5, 1582},
	{"LIGHT", 5, 1583},
	{"SFRO", 4, 1584},
	{"FIELD", 5, 1585},
	{"PULL", 4, 1586},
	{"RODU", 4, 1587},
	{"RATE", 4, 1588},
	{"UJU", 3, 1589},
	{"UYW", 3, 1590},
	{"PERHAPS", 7, 1591},
	{"RAISE", 5, 1592},
	{"VIDEOS", 6, 1593},
	{"PERCENT", 7, 1594},
	{"HARD", 4, 1595},
	{"ENTT", 4, 1596},
	{"ERVI", 4, 1597},
	{"NEOF", 4, 1598},
	{"EFFORT", 6, 1599},
	{"LATE", 4, 1600},
	{"TECH", 4, 1601},
	{"DRUG", 4, 1602},
	{"PASS", 4, 1603},
	{"OKR", 3, 1604},
	{"POLICE", 6, 1605},
	{"PROJECTS", 8, 1606},
	{"LYRICS", 6, 1607},
	{"SUBSCRIBE", 9, 1608},
	{"LEADER", 6, 1609},
	{"NMEN", 4, 1610},
	{"THEMSELVES", 10, 1611},
	{"GERMANY", 7, 1612},
	{"MILITARY", 8, 1613},
	{"NDRE", 4, 1614},
	{"INCLUDED", 8, 1615},
	{"NYV", 3, 1616},
	{"INGB", 4, 1617},
	{"ALONG", 5, 1618},
	{"ARM", 3, 1619},
	{"ANIN", 4, 1620},
	{"SOMETIMES", 9, 1621},
	{"DEVELOP", 7, 1622},
	{"XUR", 3, 1623},
	{"RELATIONSHIP", 12, 1624},
	{"HEART", 5, 1625},
	{"ERFO", 4, 1626},
	{"PRICE", 5, 1627},
	{"WEJ", 3, 1628},
	{"DEALS", 5, 1629},
	{"RZE", 3, 1630},
	{"WORDS", 5, 1631},
	{"LINUX", 5, 1632},
	{"DECIDE", 6, 1633},
	{"JUL", 3, 1634},
	{"BETTER", 6, 1635},
	{"ACCORDING", 9, 1636},
	{"WHOLE", 5, 1637},
	{"JAMES", 5, 1638},
	{"DKO", 3, 1639},
	{"STRONG", 6, 1640},
	{"WIFE", 4, 1641},
	{"NEWSLETTER", 10, 1642},
	{"ARCHIVES", 8, 1643},
	{"POINTS", 6, 1644},
	{"YYA", 3, 1645},
	{"MODEL", 5, 1646},
	{"VALUE", 5, 1647},
	{"XWE", 3, 1648},
	{"LESS", 4, 1649},
	{"DIFFERENCE", 10, 1650},
	{"MIND", 4, 1651},
	{"NTQ", 3, 1652},
	{"JUN", 3, 1653},
	{"DECISION", 8, 1654},
	{"TOYS", 4, 1655},
	{"FINALLY", 7, 1656},
	{"REGISTERED", 10, 1657},
	{"FEDERAL", 7, 1658},
	{"INTERNATIONAL", 13, 1659},
	{"ENIN", 4, 1660},
	{"PLAYER", 6, 1661},
	{"VIEW", 4, 1662},
	{"METHODS", 7, 1663},
	{"KEJ", 3, 1664},
	{"MAKES", 5, 1665},
	{"POLICIES", 8, 1666},
	{"SOCIETY", 7, 1667},
	{"RKG", 3, 1668},
	{"ROAD", 4, 1669},
	{"INDIA", 5, 1670},
	{"LLBE", 4, 1671},
	{"EXPLAIN", 7, 1672},
	{"TAX", 3, 1673},
	{"JOIN", 4, 1674},
	{"TAKEN", 5, 1675},
	{"DRIVE", 5, 1676},
	{"LISTINGS", 8, 1677},
	{"NNIN", 4, 1678},
	{"RECEIVE", 7, 1679},
	{"ULDB", 4, 1680},
	{"MODELS", 6, 1681},
	{"MICHAEL", 7, 1682},
	{"ACTION", 6, 1683},
	{"LLTH", 4, 1684},
	{"LYQ", 3, 1685},
	{"RDIN", 4, 1686},
	{"CTIV", 4, 1687},
	{"TOWN", 4, 1688},
	{"DIRECTOR", 8, 1689},
	{"CASES", 5, 1690},
	{"YIW", 3, 1691},
	{"CARRY", 5, 1692},
	{"FLORIDA", 7, 1693},
	{"BREAK", 5, 1694},
	{"TRUE", 4, 1695},
	{"AHY", 3, 1696},
	{"LDBE", 4, 1697},
	{"HYF", 3, 1698},
	{"OFFICIAL", 8, 1699},
	{"XTB", 3, 1700},
	{"EZW", 3, 1701},
	{"INAT", 4, 1702},
	{"WIRELESS", 8, 1703},
	{"NTTO", 4, 1704},
	{"PAUL", 4, 1705},
	{"FRIDAY", 6, 1706},
	{"ITHI", 4, 1707},
	{"ENTL", 4, 1708},
	{"PUBLISHED", 9, 1709},
	{"TYJ", 3, 1710},
	{"FORM", 4, 1711},
	{"BUILDING", 8, 1712},
	{"SONY", 4, 1713},
	{"SHOWS", 5, 1714},
	{"AINT", 4, 1715},
	{"GOOGLE", 6, 1716},
	{"WJO", 3, 1717},
	{"XWA", 3, 1718},
	{"CUSTOMERS", 9, 1719},
	{"ACTIVITY", 8, 1720},
	{"IONW", 4, 1721},
	{"OMIN", 4, 1722},
	{"WEAR", 4, 1723},
	{"INGM", 4, 1724},
	{"ETIM", 4, 1725},
	{"MATERIALS", 9, 1726},
	{"ERET", 4, 1727},
	{"FULL", 4, 1728},
	{"RECORD", 6, 1729},
	{"SHAV", 4, 1730},
	{"CHAT", 4, 1731},
	{"YMN", 3, 1732},
	{"DESIGNED", 8, 1733},
	{"HJE", 3, 1734},
	{"PICK", 4, 1735},
	{"NDAN", 4, 1736},
	{"POSITION", 8, 1737},
	{"SYI", 3, 1738},
	{"VETH", 4, 1739},
	{"VYW", 3, 1740},
	{"HTML", 4, 1741},
	{"HNU", 3, 1742},
	{"COUNTRIES", 9, 1743},
	{"EEJ", 3, 1744},
	{"AGREE", 5, 1745},
	{"DATA", 4, 1746},
	{"SUPPORT", 7, 1747},
	{"AVET", 4, 1748},
	{"HIGHER", 6, 1749},
	{"ESPECIALLY", 10, 1750},
	{"EFFECTS", 7, 1751},
	{"CREATED", 7, 1752},
	{"OGRA", 4, 1753},
	{"STANDARDS", 9, 1754},
	{"SITE", 4, 1755},
	{"UKO", 3, 1756},
	{"RSAN", 4, 1757},
	{"BASE", 4, 1758},
	{"EREI", 4, 1759},
	{"ADVERTISE", 9, 1760},
	{"ILLB", 4, 1761},
	{"EVENT", 5, 1762},
	{"HEPO", 4, 1763},
	{"PROJECT", 7, 1764},
	{"SPACE", 5, 1765},
	{"PAPER", 5, 1766},
	{"CKV", 3, 1767},
	{"SPECIAL", 7, 1768},
	{"TABLE", 5, 1769},
	{"ILJ", 3, 1770},
	{"JAPAN", 5, 1771},
	{"WHOSE", 5, 1772},
	{"COUPLE", 6, 1773},
	{"FIGURE", 6, 1774},
	{"DTOT", 4, 1775},
	{"OWEV", 4, 1776},
	{"DOING", 5, 1777},
	{"LOANS", 5, 1778},
	{"GROUND", 6, 1779},
	{"SHOES", 5, 1780},
	{"CENTER", 6, 1781},
	{"ORDERS", 6, 1782},
	{"ZWA", 3, 1783},
	{"AFRICA", 6, 1784},
	{"ODJ", 3, 1785},
	{"OIL", 3, 1786},
	{"PRODUCE", 7, 1787},
	{"ECTE", 4, 1788},
	{"COURT", 5, 1789},
	{"NTLY", 4, 1790},
	{"NOTES", 5, 1791},
	{"MPAN", 4, 1792},
	{"MATTER", 6, 1793},
	{"PRACTICE", 8, 1794},
	{"MONDAY", 6, 1795},
	{"STAR", 4, 1796},
	{"SEOF", 4, 1797},
	{"COST", 4, 1798},
	{"PICS", 4, 1799},
	{"ECHA", 4, 1800},
	{"VYA", 3, 1801},
	{"ASBE", 4, 1802},
	{"INDUSTRY", 8, 1803},
	{"AKY", 3, 1804},
	{"NGZ", 3, 1805},
	{"TYOF", 4, 1806},
	{"ONSO", 4, 1807},
	{"ITIE", 4, 1808},
	{"TEACH", 5, 1809},
	{"NOFT", 4, 1810},
	{"UALL", 4, 1811},
	{"CONTENTS", 8, 1812},
	{"SEEN", 4, 1813},
	{"PLAYERS", 7, 1814},
	{"PATIENT", 7, 1815},
	{"IMAGE", 5, 1816},
	{"YGL", 3, 1817},
	{"NDOF", 4, 1818},
	{"EOK", 3, 1819},
	{"REDT", 4, 1820},
	{"AYK", 3, 1821},
	{"SUPPLIES", 8, 1822},
	{"STARTED", 7, 1823},
	{"STREET", 6, 1824},
	{"UEU", 3, 1825},
	{"REPUBLICAN", 10, 1826},
	{"EASY", 4, 1827},
	{"PHONE", 5, 1828},
	{"WKE", 3, 1829},
	{"INSTITUTE", 9, 1830},
	{"VIEWS", 5, 1831},
	{"GYB", 3, 1832},
	{"PECI", 4, 1833},
	{"WALL", 4, 1834},
	{"DESCRIBE", 8, 1835},
	{"TYPES", 5, 1836},
	{"ITSELF", 6, 1837},
	{"SPONSORED", 9, 1838},
	{"LINES", 5, 1839},
	{"SEDT", 4, 1840},
	{"XWH", 3, 1841},
	{"HALF", 4, 1842},
	{"PRODUCT", 7, 1843},
	{"MHU", 3, 1844},
	{"BENEFITS", 8, 1845},
	{"ERSH", 4, 1846},
	{"EHAS", 4, 1847},
	{"RECENT", 6, 1848},
	{"HELD", 4, 1849},
	{"PRINTER", 7, 1850},
	{"NEDT", 4, 1851},
	{"LLIO", 4, 1852},
	{"HECH", 4, 1853},
	{"QUITE", 5, 1854},
	{"WORKER", 6, 1855},
	{"ASKED", 5, 1856},
	{"EDAT", 4, 1857},
	{"EUR", 3, 1858},
	{"LAND", 4, 1859},
	{"GHTH", 4, 1860},
	{"HYR", 3, 1861},
	{"SUNDAY", 6, 1862},
	{"TECHNOLOGY", 10, 1863},
	{"HAIR", 4, 1864},
	{"EITHER", 6, 1865},
	{"DOCTOR", 6, 1866},
	{"COVER", 5, 1867},
	{"MOVIE", 5, 1868},
	{"PICTURE", 7, 1869},
	{"PDF", 3, 1870},
	{"RANC", 4, 1871},
	{"OXW", 3, 1872},
	{"PIECE", 5, 1873},
	{"YSV", 3, 1874},
	{"DHY", 3, 1875},
	{"ERCE", 4, 1876},
	{"CLEAR", 5, 1877},
	{"HEFO", 4, 1878},
	{"ZAA", 3, 1879},
	{"MATURE", 6, 1880},
	{"WINDOW", 6, 1881},
	{"OGH", 3, 1882},
	{"NTZ", 3, 1883},
	{"CATCH", 5, 1884},
	{"RJI", 3, 1885},
	{"TSOF", 4, 1886},
	{"WEEKS", 5, 1887},
	{"NORTH", 5, 1888},
	{"PERSONAL", 8, 1889},
	{"BABY", 4, 1890},
	{"NCET", 4, 1891},
	{"CAME", 4, 1892},
	{"RENC", 4, 1893},
	{"USR", 3, 1894},
	{"OYH", 3, 1895},
	{"COMPUTER", 8, 1896},
	{"TSTH", 4, 1897},
	{"OUTO", 4, 1898},
	{"RSTO", 4, 1899},
	{"ERVE", 4, 1900},
	{"NDCO", 4, 1901},
	{"CERTAIN", 7, 1902},
	{"EFRO", 4, 1903},
	{"CULTURE", 7, 1904},
	{"DC", 2, 1905},
	{"TTIN", 4, 1906},
	{"THIRD", 5, 1907},
	{"ESHO", 4, 1908},
	{"MON", 3, 1909},
	{"IXF", 3, 1910},
	{"TSTO", 4, 1911},
	{"SOURCE", 6, 1912},
	{"COM", 3, 1913},
	{"EENT", 4, 1914},
	{"FILM", 4, 1915},
	{"SIMPLY", 6, 1916},
	{"DBYT", 4, 1917},
	{"HOUL", 4, 1918},
	{"TREE", 4, 1919},
	{"NGOF", 4, 1920},
	{"OMPL", 4, 1921},
	{"UOI", 3, 1922},
	{"NAMES", 5, 1923},
	{"ROBERT", 6, 1924},
	{"HOMEPAGE", 8, 1925},
	{"STEP", 4, 1926},
	{"RED", 3, 1927},
	{"INGD", 4, 1928},
	{"OWV", 3, 1929},
	{"SKILLS", 6, 1930},
	{"YSTE", 4, 1931},
	{"OIW", 3, 1932},
	{"HETO", 4, 1933},
	{"ISLANDS", 7, 1934},
	{"ISIO", 4, 1935},
	{"OWTH", 4, 1936},
	{"CETH", 4, 1937},
	{"UNJ", 3, 1938},
	{"NTRO", 4, 1939},
	{"TEDB", 4, 1940},
	{"EDHI", 4, 1941},
	{"CENTURY", 7, 1942},
	{"TEENS", 5, 1943},
	{"EFIN", 4, 1944},
	{"PRE", 3, 1945},
	{"EVIDENCE", 8, 1946},
	{"FACILITIES", 10, 1947},
	{"ATTENTION", 9, 1948},
	{"BILLION", 7, 1949},
	{"DRAW", 4, 1950},
	{"RTOF", 4, 1951},
	{"SELLERS", 7, 1952},
	{"LISTEN", 6, 1953},
	{"ITHO", 4, 1954},
	{"ENTU", 4, 1955},
	{"XME", 3, 1956},
	{"HASB", 4, 1957},
	{"DYU", 3, 1958},
	{"NEARLY", 6, 1959},
	{"NDIT", 4, 1960},
	{"OPPORTUNITIES", 13, 1961},
	{"TAKING", 6, 1962},
	{"DNOT", 4, 1963},
	{"OGET", 4, 1964},
	{"VALUES", 6, 1965},
	{"HISF", 4, 1966},
	{"NDSO", 4, 1967},
	{"TUESDAY", 7, 1968},
	{"OKD", 3, 1969},
	{"OYB", 3, 1970},
	{"FIW", 3, 1971},
	{"PERIOD", 6, 1972},
	{"CAUSE", 5, 1973},
	{"EUNI", 4, 1974},
	{"IESA", 4, 1975},
	{"NTTH", 4, 1976},
	{"CHOOSE", 6, 1977},
	{"RSIN", 4, 1978},
	{"LOGO", 4, 1979},
	{"SBEE", 4, 1980},
	{"CAMPAIGN", 8, 1981},
	{"ENERGY", 6, 1982},
	{"PPOR", 4, 1983},
	{"DIFFICULT", 9, 1984},
	{"RETURNS", 7, 1985},
	{"NWAS", 4, 1986},
	{"ROFT", 4, 1987},
	{"SHOWN", 5, 1988},
	{"OLIC", 4, 1989},
	{"TMEN", 4, 1990},
	{"SATURDAY", 8, 1991},
	{"ECAM", 4, 1992},
	{"PLANT", 5, 1993},
	{"ROVI", 4, 1994},
	{"ENGLAND", 7, 1995},
	{"ETWE", 4, 1996},
	{"HESO", 4, 1997},
	{"BROTHER", 7, 1998},
	{"AXW", 3, 1999},
	{"NGFO", 4, 2000},
	{"KFE", 3, 2001},
	{"GEORGE", 6, 2002},
	{"GKE", 3, 2003},
	{"WENT", 4, 2004},
	{"LIKELY", 6, 2005},
	{"POPULATION", 10, 2006},
	{"TERM", 4, 2007},
	{"REGISTRATION", 12, 2008},
	{"EYOU", 4, 2009},
	{"ASTO", 4, 2010},
	{"LDIN", 4, 2011},
	{"CONGRESS", 8, 2012},
	{"FRI", 3, 2013},
	{"ERSW", 4, 2014},
	{"UAY", 3, 2015},
	{"HISW", 4, 2016},
	{"CHANCE", 6, 2017},
	{"THURSDAY", 8, 2018},
	{"COURSES", 7, 2019},
	{"BEHAVIOR", 8, 2020},
	{"SUMMER", 6, 2021},
	{"YSJ", 3, 2022},
	{"NTHI", 4, 2023},
	{"IXD", 3, 2024},
	{"FLOOR", 5, 2025},
	{"MATERIAL", 8, 2026},
	{"OPPORTUNITY", 11, 2027},
	{"EVU", 3, 2028},
	{"ONTI", 4, 2029},
	{"ITYO", 4, 2030},
	{"LJE", 3, 2031},
	{"LEVELS", 6, 2032},
	{"PHONES", 6, 2033},
	{"IDEAS", 5, 2034},
	{"WEDNESDAY", 9, 2035},
	{"ARKE", 4, 2036},
	{"OEY", 3, 2037},
	{"ADMINISTRATION", 14, 2038},
	{"EATT", 4, 2039},
	{"IEJ", 3, 2040},
	{"NSAN", 4, 2041},
	{"DEDT", 4, 2042},
	{"RELEASES", 8, 2043},
	{"WED", 3, 2044},
	{"HOMES", 5, 2045},
	{"XTG", 3, 2046},
	{"REALIZE", 7, 2047},
	{"VIRGINIA", 8, 2048},
	{"EAQ", 3, 2049},
	{"SUBJECT", 7, 2050},
	{"IXH", 3, 2051},
	{"TOOK", 4, 2052},
	{"LOCATED", 7, 2053},
	{"HUNDRED", 7, 2054},
	{"CURRENT", 7, 2055},
	{"IVED", 4, 2056},
	{"VEBE", 4, 2057},
	{"ULAT", 4, 2058},
	{"RULE", 4, 2059},
	{"ENAT", 4, 2060},
	{"ECONOMY", 7, 2061},
	{"CLOSE", 5, 2062},
	{"CNET", 4, 2063},
	{"LTD", 3, 2064},
	{"LOS", 3, 2065},
	{"UMBE", 4, 2066},
	{"RNIN", 4, 2067},
	{"SOUTH", 5, 2068},
	{"FEATURED", 8, 2069},
	{"YZA", 3, 2070},
	{"ROOMS", 5, 2071},
	{"NDON", 4, 2072},
	{"STOT", 4, 2073},
	{"CHOICE", 6, 2074},
	{"OUU", 3, 2075},
	{"SHORT", 5, 2076},
	{"INCREASE", 8, 2077},
	{"RISK", 4, 2078},
	{"DAUGHTER", 8, 2079},
	{"INC", 3, 2080},
	{"LETTER", 6, 2081},
	{"ERNM", 4, 2082},
	{"RNED", 4, 2083},
	{"BED", 3, 2084},
	{"THOMAS", 6, 2085},
	{"NUMBERS", 7, 2086},
	{"NDST", 4, 2087},
	{"HUSBAND", 7, 2088},
	{"OSIT", 4, 2089},
	{"OLLO", 4, 2090},
	{"SINGLE", 6, 2091},
	{"UCHA", 4, 2092},
	{"EALS", 4, 2093},
	{"BROWSER", 7, 2094},
	{"PERFORMANCE", 11, 2095},
	{"ALRE", 4, 2096},
	{"TTHI", 4, 2097},
	{"RSOF", 4, 2098},
	{"ROGR", 4, 2099},
	{"CERTAINLY", 9, 2100},
	{"MYSELF", 6, 2101},
	{"OFHI", 4, 2102},
	{"DEFENSE", 7, 2103},
	{"INVOLVE", 7, 2104},
	{"NTAN", 4, 2105},
	{"CHURCH", 6, 2106},
	{"COMES", 5, 2107},
	{"PER", 3, 2108},
	{"FIRE", 4, 2109},
	{"YKO", 3, 2110},
	{"CAMERAS", 7, 2111},
	{"HEFA", 4, 2112},
	{"OGW", 3, 2113},
	{"MAPS", 4, 2114},
	{"NGWI", 4, 2115},
	{"SPORT", 5, 2116},
	{"UXI", 3, 2117},
	{"BANK", 4, 2118},
	{"RATINGS", 7, 2119},
	{"WRONG", 5, 2120},
	{"CHICAGO", 7, 2121},
	{"SIGNIFICANT", 11, 2122},
	{"SECURITY", 8, 2123},
	{"FORMS", 5, 2124},
	{"REPRESENT", 9, 2125},
	{"GOAL", 4, 2126},
	{"EWHO", 4, 2127},
	{"TUE", 3, 2128},
	{"SMITH", 5, 2129},
	{"WANTED", 6, 2130},
	{"DEVELOPED", 9, 2131},
	{"SEEK", 4, 2132},
	{"DFRO", 4, 2133},
	{"ZHO", 3, 2134},
	{"BOARD", 5, 2135},
	{"THOUSAND", 8, 2136},
	{"QAN", 3, 2137},
	{"AUTHOR", 6, 2138},
	{"ANYONE", 6, 2139},
	{"URRE", 4, 2140},
	{"YEQ", 3, 2141},
	{"WEST", 4, 2142},
	{"UQU", 3, 2143},
	{"NWIT", 4, 2144},
	{"FUTURE", 6, 2145},
	{"NATURE", 6, 2146},
	{"ZZO", 3, 2147},
	{"EBEE", 4, 2148},
	{"SOURCES", 7, 2149},
	{"MEXICO", 6, 2150},
	{"EALT", 4, 2151},
	{"THROW", 5, 2152},
	{"TOP", 3, 2153},
	{"UEJ", 3, 2154},
	{"ETUR", 4, 2155},
	{"OFFICER", 7, 2156},
	{"FACTOR", 6, 2157},
	{"SWHO", 4, 2158},
	{"FOREIGN", 7, 2159},
	{"NAVIGATION", 10, 2160},
	{"RNME", 4, 2161},
	{"UPPO", 4, 2162},
	{"OPERATIONS", 10, 2163},
	{"DEAL", 4, 2164},
	{"NTEN", 4, 2165},
	{"UCTI", 4, 2166},
	{"AVEB", 4, 2167},
	{"YMR", 3, 2168},
	{"PRIVATE", 7, 2169},
	{"MQU", 3, 2170},
	{"PAYPAL", 6, 2171},
	{"FOCUS", 5, 2172},
	{"HESU", 4, 2173},
	{"THUS", 4, 2174},
	{"UPON", 4, 2175},
	{"REDUCE", 6, 2176},
	{"NOTE", 4, 2177},
	{"UTIO", 4, 2178},
	{"THU", 3, 2179},
	{"HETR", 4, 2180},
	{"YIC", 3, 2181},
	{"COLOR", 5, 2182},
	{"AGENCY", 6, 2183},
	{"UHO", 3, 2184},
	{"RENTALS", 7, 2185},
	{"FILL", 4, 2186},
	{"BUILT", 5, 2187},
	{"PUBLICATIONS", 12, 2188},
	{"FIGHT", 5, 2189},
	{"SOUND", 5, 2190},
	{"PPEA", 4, 2191},
	{"ORAT", 4, 2192},
	{"REST", 4, 2193},
	{"LARGER", 6, 2194},
	{"NDAR", 4, 2195},
	{"ANTI", 4, 2196},
	{"PAST", 4, 2197},
	{"HEGR", 4, 2198},
	{"NETWORKS", 8, 2199},
	{"ORDER", 5, 2200},
	{"PARENTS", 7, 2201},
	{"NOKIA", 5, 2202},
	{"QUICKLY", 7, 2203},
	{"DROP", 4, 2204},
	{"EYEA", 4, 2205},
	{"OEW", 3, 2206},
	{"PLET", 4, 2207},
	{"RTIC", 4, 2208},
	{"BLOOD", 5, 2209},
	{"ENOT", 4, 2210},
	{"LEDT", 4, 2211},
	{"RESPONSE", 8, 2212},
	{"YINT", 4, 2213},
	{"TETH", 4, 2214},
	{"TEL", 3, 2215},
	{"IENC", 4, 2216},
	{"CAROLINA", 8, 2217},
	{"MOVEMENT", 8, 2218},
	{"PROPERTIES", 10, 2219},
	{"STORE", 5, 2220},
	{"OVERVIEW", 8, 2221},
	{"KETH", 4, 2222},
	{"PUSH", 4, 2223},
	{"FKO", 3, 2224},
	{"ACCOMMODATION", 13, 2225},
	{"OWNERS", 6, 2226},
	{"RECENTLY", 8, 2227},
	{"RNJ", 3, 2228},
	{"RVIC", 4, 2229},
	{"COMMON", 6, 2230},
	{"PAGE", 4, 2231},
	{"SIMILAR", 7, 2232},
	{"OTHI", 4, 2233},
	{"LANGUAGE", 8, 2234},
	{"PAID", 4, 2235},
	{"ITALY", 5, 2236},
	{"UNTR", 4, 2237},
	{"MMUN", 4, 2238},
	{"OFCO", 4, 2239},
	{"GJE", 3, 2240},
	{"NATURAL", 7, 2241},
	{"CITIES", 6, 2242},
	{"WILLIAM", 7, 2243},
	{"ANAL", 4, 2244},
	{"OLOG", 4, 2245},
	{"CONCERN", 7, 2246},
	{"DEAD", 4, 2247},
	{"PETER", 5, 2248},
	{"HESI", 4, 2249},
	{"HLU", 3, 2250},
	{"OACH", 4, 2251},
	{"NSIN", 4, 2252},
	{"UTOF", 4, 2253},
	{"ARTICLE", 7, 2254},
	{"NEAR", 4, 2255},
	{"INTERFACE", 9, 2256},
	{"RACE", 4, 2257},
	{"ECAN", 4, 2258},
	{"OMMU", 4, 2259},
	{"IFFE", 4, 2260},
	{"PM", 2, 2261},
	{"ESON", 4, 2262},
	{"INDIVIDUAL", 10, 2263},
	{"NGRE", 4, 2264},
	{"PARTNERS", 8, 2265},
	{"YSQ", 3, 2266},
	{"EREW", 4, 2267},
	{"RATED", 5, 2268},
	{"GUIDES", 6, 2269},
	{"NSID", 4, 2270},
	{"SERIES", 6, 2271},
	{"EENA", 4, 2272},
	{"ENTER", 5, 2273},
	{"FICI", 4, 2274},
	{"NTST", 4, 2275},
	{"ARTIST", 6, 2276},
	{"IEVE", 4, 2277},
	{"STOCK", 5, 2278},
	{"TTEN", 4, 2279},
	{"AMAZON", 6, 2280},
	{"PATIENTS", 8, 2281},
	{"RESTAURANTS", 11, 2282},
	{"LOCATIONS", 9, 2283},
	{"HEHO", 4, 2284},
	{"NSOF", 4, 2285},
	{"SHARE", 5, 2286},
	{"ETWO", 4, 2287},
	{"FLOWERS", 7, 2288},
	{"APPROACH", 8, 2289},
	{"STARS", 5, 2290},
	{"IFTH", 4, 2291},
	{"LISTS", 5, 2292},
	{"FUND", 4, 2293},
	{"TECHNOLOGIES", 12, 2294},
	{"ANALYSIS", 8, 2295},
	{"POOR", 4, 2296},
	{"ANIMALS", 7, 2297},
	{"WAYS", 4, 2298},
	{"DECADE", 6, 2299},
	{"YOFT", 4, 2300},
	{"CUP", 3, 2301},
	{"PROVIDING", 9, 2302},
	{"ANAG", 4, 2303},
	{"YTHI", 4, 2304},
	{"ESIG", 4, 2305},
	{"RISE", 4, 2306},
	{"MAC", 3, 2307},
	{"IDENTIFY", 8, 2308},
	{"USUALLY", 7, 2309},
	{"TAKES", 5, 2310},
	{"RZO", 3, 2311},
	{"RESOURCE", 8, 2312},
	{"NDHE", 4, 2313},
	{"TREATMENT", 9, 2314},
	{"HEDA", 4, 2315},
	{"ONSH", 4, 2316},
	{"RCEN", 4, 2317},
	{"INDICATE", 8, 2318},
	{"XBU", 3, 2319},
	{"SEARCHES", 8, 2320},
	{"MAX", 3, 2321},
	{"TRYING", 6, 2322},
	{"KSY", 3, 2323},
	{"ANIMAL", 6, 2324},
	{"CONSIDERED", 10, 2325},
	{"SHOOT", 5, 2326},
	{"EAST", 4, 2327},
	{"RSIT", 4, 2328},
	{"TOLD", 4, 2329},
	{"XML", 3, 2330},
	{"PROGRAMME", 9, 2331},
	{"HERSELF", 7, 2332},
	{"JOINED", 6, 2333},
	{"EWIL", 4, 2334},
	{"OHY", 3, 2335},
	{"LDRE", 4, 2336},
	{"BIN", 3, 2337},
	{"DOFT", 4, 2338},
	{"OCCUR", 5, 2339},
	{"ESHE", 4, 2340},
	{"EXACTLY", 7, 2341},
	{"ETIN", 4, 2342},
	{"IRELAND", 7, 2343},
	{"FHIS", 4, 2344},
	{"CENTRAL", 7, 2345},
	{"DOG", 3, 2346},
	{"UNITS", 5, 2347},
	{"QUALITY", 7, 2348},
	{"WROTE", 5, 2349},
	{"IDTH", 4, 2350},
	{"SHIPS", 5, 2351},
	{"DETERMINE", 9, 2352},
	{"NSTO", 4, 2353},
	{"CAREER", 6, 2354},
	{"RSTH", 4, 2355},
	{"SAVE", 4, 2356},
	{"MD", 2, 2357},
	{"SWHI", 4, 2358},
	{"FL", 2, 2359},
	{"DERT", 4, 2360},
	{"SIZE", 4, 2361},
	{"ERIO", 4, 2362},
	{"MB", 2, 2363},
	{"LPY", 3, 2364},
	{"MEDIA", 5, 2365},
	{"ASIA", 4, 2366},
	{"HEYW", 4, 2367},
	{"NGLE", 4, 2368},
	{"GWIT", 4, 2369},
	{"OXB", 3, 2370},
	{"LIE", 3, 2371},
	{"USES", 4, 2372},
	{"ERTA", 4, 2373},
	{"YMM", 3, 2374},
	{"FUNDS", 5, 2375},
	{"DESPITE", 7, 2376},
	{"THOUGHT", 7, 2377},
	{"IONF", 4, 2378},
	{"GREATER", 7, 2379},
	{"OYN", 3, 2380},
	{"ABILITY", 7, 2381},
	{"PHYSICAL", 8, 2382},
	{"NDTO", 4, 2383},
	{"EMPLOYEES", 9, 2384},
	{"ARTISTS", 7, 2385},
	{"ELECTION", 8, 2386},
	{"XNE", 3, 2387},
	{"RREN", 4, 2388},
	{"SCENE", 5, 2389},
	{"DISEASE", 7, 2390},
	{"JAVA", 4, 2391},
	{"ENVIRONMENTAL", 13, 2392},
	{"EVERYBODY", 9, 2393},
	{"SEEMS", 5, 2394},
	{"EMAR", 4, 2395},
	{"RELATIONS", 9, 2396},
	{"ZLI", 3, 2397},
	{"ARGUE", 5, 2398},
	{"IVIN", 4, 2399},
	{"CONTAINS", 8, 2400},
	{"XYG", 3, 2401},
	{"DTOB", 4, 2402},
	{"MULTI", 5, 2403},
	{"DWAS", 4, 2404},
	{"REGION", 6, 2405},
	{"GROWTH", 6, 2406},
	{"ATTACK", 6, 2407},
	{"WONDER", 6, 2408},
	{"NCON", 4, 2409},
	{"FEES", 4, 2410},
	{"COMPONENTS", 10, 2411},
	{"READY", 5, 2412},
	{"AIDT", 4, 2413},
	{"PRESSURE", 8, 2414},
	{"OFIN", 4, 2415},
	{"BEYOND", 6, 2416},
	{"COMPLETED", 9, 2417},
	{"LIST", 4, 2418},
	{"RCHA", 4, 2419},
	{"GRAPHICS", 8, 2420},
	{"PROTECT", 7, 2421},
	{"EONE", 4, 2422},
	{"DEGREE", 6, 2423},
	{"SIMPLE", 6, 2424},
	{"SUCCESS", 7, 2425},
	{"EQUE", 4, 2426},
	{"PREV", 4, 2427},
	{"LEFT", 4, 2428},
	{"EDFR", 4, 2429},
	{"SKILL", 5, 2430},
	{"ADS", 3, 2431},
	{"PRETTY", 6, 2432},
	{"IBY", 3, 2433},
	{"KNOWLEDGE", 9, 2434},
	{"MARY", 4, 2435},
	{"PARTICULARLY", 12, 2436},
	{"FYF", 3, 2437},
	{"SERIOUS", 7, 2438},
	{"RYIN", 4, 2439},
	{"EBUT", 4, 2440},
	{"DATING", 6, 2441},
	{"WHATEVER", 8, 2442},
	{"HEGA", 4, 2443},
	{"PACIFIC", 7, 2444},
	{"ONTA", 4, 2445},
	{"UIZ", 3, 2446},
	{"STAFF", 5, 2447},
	{"NDHA", 4, 2448},
	{"ORGANIZATIONS", 13, 2449},
	{"PQU", 3, 2450},
	{"SIGN", 4, 2451},
	{"RECOGNIZE", 9, 2452},
	{"MAILING", 7, 2453},
	{"LONGER", 6, 2454},
	{"TRAINING", 8, 2455},
	{"ANSWER", 6, 2456},
	{"OURC", 4, 2457},
	{"ACCEPT", 6, 2458},
	{"AMOUNT", 6, 2459},
	{"INGU", 4, 2460},
	{"MEETING", 7, 2461},
	{"QWH", 3, 2462},
	{"ONTE", 4, 2463},
	{"STANDARD", 8, 2464},
	{"EOX", 3, 2465},
	{"MEOF", 4, 2466},
	{"OTQ", 3, 2467},
	{"HENO", 4, 2468},
	{"HETI", 4, 2469},
	{"SECTION", 7, 2470},
	{"LOSS", 4, 2471},
	{"TRADE", 5, 2472},
	{"GLASS", 5, 2473},
	{"TELEVISION", 10, 2474},
	{"NSTH", 4, 2475},
	{"BOX", 3, 2476},
	{"PRESENT", 7, 2477},
	{"GENERAL", 7, 2478},
	{"LEOF", 4, 2479},
	{"CHARACTER", 9, 2480},
	{"NHY", 3, 2481},
	{"BUYING", 6, 2482},
	{"DEFAULT", 7, 2483},
	{"IRAQ", 4, 2484},
	{"RKIN", 4, 2485},
	{"ICUL", 4, 2486},
	{"BOYS", 4, 2487},
	{"URNE", 4, 2488},
	{"ESWI", 4, 2489},
	{"IXB", 3, 2490},
	{"LAY", 3, 2491},
	{"ALLOWS", 6, 2492},
	{"TWOR", 4, 2493},
	{"VEQ", 3, 2494},
	{"GYH", 3, 2495},
	{"PREPARE", 7, 2496},
	{"REPORTED", 8, 2497},
	{"SBUT", 4, 2498},
	{"MYJ", 3, 2499},
	{"CTUR", 4, 2500},
	{"STRATEGY", 8, 2501},
	{"THAV", 4, 2502},
	{"MM", 2, 2503},
	{"XHO", 3, 2504},
	{"MINI", 4, 2505},
	{"EEND", 4, 2506},
	{"BILL", 4, 2507},
	{"EREP", 4, 2508},
	{"DISCLAIMER", 10, 2509},
	{"AUTHORS", 7, 2510},
	{"BOARDS", 6, 2511},
	{"REOF", 4, 2512},
	{"RIY", 3, 2513},
	{"PARTIES", 7, 2514},
	{"EGAM", 4, 2515},
	{"OPUL", 4, 2516},
	{"RTAN", 4, 2517},
	{"MODIFIED", 8, 2518},
	{"DESIGN", 6, 2519},
	{"RELEASED", 8, 2520},
	{"RUCT", 4, 2521},
	{"BENEFIT", 7, 2522},
	{"KVE", 3, 2523},
	{"ERMI", 4, 2524},
	{"GOODS", 5, 2525},
	{"LAUGH", 5, 2526},
	{"RECOMMENDED", 11, 2527},
	{"HISM", 4, 2528},
	{"ANBE", 4, 2529},
	{"HEPL", 4, 2530},
	{"RICHARD", 7, 2531},
	{"NCRE", 4, 2532},
	{"ASRE", 4, 2533},
	{"RYQ", 3, 2534},
	{"APPROVED", 8, 2535},
	{"ITHH", 4, 2536},
	{"HATC", 4, 2537},
	{"DCY", 3, 2538},
	{"SISTER", 6, 2539},
	{"NTIL", 4, 2540},
	{"RMAT", 4, 2541},
	{"COMPARE", 7, 2542},
	{"GUESS", 5, 2543},
	{"CRIME", 5, 2544},
	{"FUNCTIONS", 9, 2545},
	{"NTON", 4, 2546},
	{"IALL", 4, 2547},
	{"LAWYER", 6, 2548},
	{"PTIO", 4, 2549},
	{"BRANDS", 6, 2550},
	{"PLACES", 6, 2551},
	{"ENVIRONMENT", 11, 2552},
	{"FINANCIAL", 9, 2553},
	{"KMY", 3, 2554},
	{"PHP", 3, 2555},
	{"NDWA", 4, 2556},
	{"EWHE", 4, 2557},
	{"ERWA", 4, 2558},
	{"TRADEMARKS", 10, 2559},
	{"ZZE", 3, 2560},
	{"PHENTERMINE", 11, 2561},
	{"SPAIN", 5, 2562},
	{"ASWE", 4, 2563},
	{"BLUE", 4, 2564},
	{"EARC", 4, 2565},
	{"DARK", 4, 2566},
	{"HTJ", 3, 2567},
	{"TONIGHT", 7, 2568},
	{"SUBMITTED", 9, 2569},
	{"BOSTON", 6, 2570},
	{"FAIL", 4, 2571},
	{"TYEA", 4, 2572},
	{"KEYWORDS", 8, 2573},
	{"LEG", 3, 2574},
	{"YEB", 3, 2575},
	{"ARRIVE", 6, 2576},
	{"ONOM", 4, 2577},
	{"ATET", 4, 2578},
	{"PURPOSES", 8, 2579},
	{"FEELING", 7, 2580},
	{"EXECUTIVE", 9, 2581},
	{"SETS", 4, 2582},
	{"AUTHORITY", 9, 2583},
	{"GUN", 3, 2584},
	{"DEMOCRATIC", 10, 2585},
	{"EGRE", 4, 2586},
	{"OPERATION", 9, 2587},
	{"MSN", 3, 2588},
	{"ERWH", 4, 2589},
	{"TOFI", 4, 2590},
	{"DEFINED", 7, 2591},
	{"STHI", 4, 2592},
	{"PAPERS", 6, 2593},
	{"PLAYING", 7, 2594},
	{"AWARDS", 6, 2595},
	{"INHI", 4, 2596},
	{"EXAMPLE", 7, 2597},
	{"SORT", 4, 2598},
	{"KYH", 3, 2599},
	{"ESTABLISHED", 11, 2600},
	{"ANSWERS", 7, 2601},
	{"NDEN", 4, 2602},
	{"ONFO", 4, 2603},
	{"DEMOCRAT", 8, 2604},
	{"LAS", 3, 2605},
	{"NDSA", 4, 2606},
	{"DISCUSS", 7, 2607},
	{"ICHA", 4, 2608},
	{"OHAV", 4, 2609},
	{"GTHA", 4, 2610},
	{"VARIOUS", 7, 2611},
	{"SIBL", 4, 2612},
	{"AXY", 3, 2613},
	{"HANG", 4, 2614},
	{"ESFO", 4, 2615},
	{"OUTSIDE", 7, 2616},
	{"YUT", 3, 2617},
	{"MIN", 3, 2618},
	{"EHAV", 4, 2619},
	{"NSHI", 4, 2620},
	{"PROFESSOR", 9, 2621},
	{"OFFERED", 7, 2622},
	{"MISS", 4, 2623},
	{"YTHA", 4, 2624},
	{"SWEL", 4, 2625},
	{"RELIGIOUS", 9, 2626},
	{"OUNC", 4, 2627},
	{"GHTE", 4, 2628},
	{"STAGE", 5, 2629},
	{"STATION", 7, 2630},
	{"ANCI", 4, 2631},
	{"UDIN", 4, 2632},
	{"WQU", 3, 2633},
	{"MANAGER", 7, 2634},
	{"INDEED", 6, 2635},
	{"ESOU", 4, 2636},
	{"TEACHERS", 8, 2637},
	{"ENTW", 4, 2638},
	{"ISBN", 4, 2639},
	{"MARTIN", 6, 2640},
	{"TOHA", 4, 2641},
	{"NGCO", 4, 2642},
	{"CLEARLY", 7, 2643},
	{"EREM", 4, 2644},
	{"DCON", 4, 2645},
	{"SUBJECTS", 8, 2646},
	{"AGENTS", 6, 2647},
	{"HEGO", 4, 2648},
	{"CHECK", 5, 2649},
	{"SCIENCE", 7, 2650},
	{"ZUE", 3, 2651},
	{"URQ", 3, 2652},
	{"ISAL", 4, 2653},
	{"CULTURAL", 8, 2654},
	{"ACT", 3, 2655},
	{"ISRE", 4, 2656},
	{"RNAT", 4, 2657},
	{"SONGS", 5, 2658},
	{"FORGET", 6, 2659},
	{"THEORY", 6, 2660},
	{"IAZ", 3, 2661},
	{"TOPR", 4, 2662},
	{"HANDS", 5, 2663},
	{"VYI", 3, 2664},
	{"SONG", 4, 2665},
	{"ASSOCIATES", 10, 2666},
	{"TOFA", 4, 2667},
	{"REFO", 4, 2668},
	{"OMMI", 4, 2669},
	{"URSE", 4, 2670},
	{"CANB", 4, 2671},
	{"ROCK", 4, 2672},
	{"UPDATES", 7, 2673},
	{"DESKTOP", 7, 2674},
	{"CLASSES", 7, 2675},
	{"PARIS", 5, 2676},
	{"SHAKE", 5, 2677},
	{"TRUTH", 5, 2678},
	{"OHIO", 4, 2679},
	{"GETS", 4, 2680},
	{"NETWORK", 7, 2681},
	{"MANAGEMENT", 10, 2682},
	{"TYOU", 4, 2683},
	{"REQUIRES", 8, 2684},
	{"EALI", 4, 2685},
	{"JERSEY", 6, 2686},
	{"AYED", 4, 2687},
	{"RATHER", 6, 2688},
	{"SWOR", 4, 2689},
	{"SAW", 3, 2690},
	{"INSTRUMENTS", 11, 2691},
	{"QUOTES", 6, 2692},
	{"CELL", 4, 2693},
	{"LEGAL", 5, 2694},
	{"ULDN", 4, 2695},
	{"SSTH", 4, 2696},
	{"OMME", 4, 2697},
	{"NTRE", 4, 2698},
	{"NICE", 4, 2699},
	{"BUSINESSES", 10, 2700},
	{"FIRM", 4, 2701},
	{"NDHI", 4, 2702},
	{"RNV", 3, 2703},
	{"REMOVE", 6, 2704},
	{"GREEN", 5, 2705},
	{"SPECIFIED", 9, 2706},
	{"SDAY", 4, 2707},
	{"COLD", 4, 2708},
	{"MIKE", 4, 2709},
	{"EARA", 4, 2710},
	{"OWNA", 4, 2711},
	{"PST", 3, 2712},
	{"TRIAL", 5, 2713},
	{"EKY", 3, 2714},
	{"PROCEDURES", 10, 2715},
	{"SEAT", 4, 2716},
	{"EYES", 4, 2717},
	{"WORKERS", 7, 2718},
	{"GEORGIA", 7, 2719},
	{"PROVE", 5, 2720},
	{"UOV", 3, 2721},
	{"CLAIM", 5, 2722},
	{"TOM", 3, 2723},
	{"EHIS", 4, 2724},
	{"RMER", 4, 2725},
	{"SHOWING", 7, 2726},
	{"ABOVE", 5, 2727},
	{"SPRING", 6, 2728},
	{"DEVICES", 7, 2729},
	{"LORD", 4, 2730},
	{"ITHS", 4, 2731},
	{"SUB", 3, 2732},
	{"ENTIRE", 6, 2733},
	{"RGAN", 4, 2734},
	{"CEIV", 4, 2735},
	{"MEASURE", 7, 2736},
	{"EWHI", 4, 2737},
	{"EXPERT", 6, 2738},
	{"NFRO", 4, 2739},
	{"WATCHES", 7, 2740},
	{"CAREERS", 7, 2741},
	{"MPOR", 4, 2742},
	{"IMPACT", 6, 2743},
	{"DHAV", 4, 2744},
	{"GOES", 4, 2745},
	{"MAIN", 4, 2746},
	{"FAMILIES", 8, 2747},
	{"EFEN", 4, 2748},
	{"TRADITIONAL", 11, 2749},
	{"EADI", 4, 2750},
	{"LED", 3, 2751},
	{"STRUCTURE", 9, 2752},
	{"HEPE", 4, 2753},
	{"CARD", 4, 2754},
	{"FINAL", 5, 2755},
	{"GYL", 3, 2756},
	{"OWNT", 4, 2757},
	{"ONTO", 4, 2758},
	{"MEMORY", 6, 2759},
	{"BALL", 4, 2760},
	{"MAINTAIN", 8, 2761},
	{"IMAGINE", 7, 2762},
	{"ZCO", 3, 2763},
	{"ASNO", 4, 2764},
	{"BLOGS", 5, 2765},
	{"ACCEPTED", 8, 2766},
	{"YOURSELF", 8, 2767},
	{"MMER", 4, 2768},
	{"HITS", 4, 2769},
	{"SUDDENLY", 8, 2770},
	{"ECUR", 4, 2771},
	{"GALLERIES", 9, 2772},
	{"NTAI", 4, 2773},
	{"OCAT", 4, 2774},
	{"NTIO", 4, 2775},
	{"CHAIR", 5, 2776},
	{"CANDIDATE", 9, 2777},
	{"REFERENCES", 10, 2778},
	{"PRESENTED", 9, 2779},
	{"JACK", 4, 2780},
	{"NDAL", 4, 2781},
	{"WEAPON", 6, 2782},
	{"CEIN", 4, 2783},
	{"FINISH", 6, 2784},
	{"AGENCIES", 8, 2785},
	{"EHEA", 4, 2786},
	{"KGE", 3, 2787},
	{"RESPECTIVE", 10, 2788},
	{"SWHE", 4, 2789},
	{"VYT", 3, 2790},
	{"OCY", 3, 2791},
	{"MICHIGAN", 8, 2792},
	{"TLEA", 4, 2793},
	{"VISIT", 5, 2794},
	{"STATEMENT", 9, 2795},
	{"HEUS", 4, 2796},
	{"AVOID", 5, 2797},
	{"COLUMBIA", 8, 2798},
	{"SHOULDER", 8, 2799},
	{"HEWE", 4, 2800},
	{"EMPLOYEE", 8, 2801},
	{"HEWI", 4, 2802},
	{"HIGHEST", 7, 2803},
	{"FYOU", 4, 2804},
	{"METHOD", 6, 2805},
	{"HATM", 4, 2806},
	{"REVEAL", 6, 2807},
	{"HUGE", 4, 2808},
	{"NDSE", 4, 2809},
	{"AMEA", 4, 2810},
	{"CONTAIN", 7, 2811},
	{"ANGELES", 7, 2812},
	{"NETWORKING", 10, 2813},
	{"ECEI", 4, 2814},
	{"POPULAR", 7, 2815},
	{"OOZ", 3, 2816},
	{"SPECIFIC", 8, 2817},
	{"APPLY", 5, 2818},
	{"NTUR", 4, 2819},
	{"EINC", 4, 2820},
	{"ONGT", 4, 2821},
	{"CHARGE", 6, 2822},
	{"STIT", 4, 2823},
	{"AUSTRALIAN", 10, 2824},
	{"PARTICULAR", 10, 2825},
	{"ERWI", 4, 2826},
	{"NTRI", 4, 2827},
	{"PEACE", 5, 2828},
	{"GIVES", 5, 2829},
	{"LTHO", 4, 2830},
	{"KB", 2, 2831},
	{"NTOA", 4, 2832},
	{"MAGAZINES", 9, 2833},
	{"INSTITUTION", 11, 2834},
	{"RESPOND", 7, 2835},
	{"PACKAGES", 8, 2836},
	{"ZBE", 3, 2837},
	{"IONC", 4, 2838},
	{"FRANCISCO", 9, 2839},
	{"EEVE", 4, 2840},
	{"PRODUCTION", 10, 2841},
	{"LAWS", 4, 2842},
	{"CHANGED", 7, 2843},
	{"HEARD", 5, 2844},
	{"INDIVIDUALS", 11, 2845},
	{"EYAR", 4, 2846},
	{"COLORADO", 8, 2847},
	{"WEIGHT", 6, 2848},
	{"BIT", 3, 2849},
	{"LARGEST", 7, 2850},
	{"OESN", 4, 2851},
	{"EATI", 4, 2852},
	{"PJO", 3, 2853},
	{"TITLES", 6, 2854},
	{"DHER", 4, 2855},
	{"GUIDELINES", 10, 2856},
	{"UXE", 3, 2857},
	{"SCOU", 4, 2858},
	{"POLITICS", 8, 2859},
	{"GHTT", 4, 2860},
	{"DEV", 3, 2861},
	{"PERFORM", 7, 2862},
	{"ITTL", 4, 2863},
	{"SOMEBODY", 8, 2864},
	{"INTERVIEW", 9, 2865},
	{"APPLIED", 7, 2866},
	{"VOL", 3, 2867},
	{"DESCRIBED", 9, 2868},
	{"NSTE", 4, 2869},
	{"AFFECT", 6, 2870},
	{"PP", 2, 2871},
	{"FISH", 4, 2872},
	{"SMILE", 5, 2873},
	{"PARTICIPANT", 11, 2874},
	{"HECI", 4, 2875},
	{"VEGAS", 5, 2876},
	{"EOFA", 4, 2877},
	{"CHRIS", 5, 2878},
	{"FLY", 3, 2879},
	{"UCY", 3, 2880},
	{"PAIN", 4, 2881},
	{"RANGE", 5, 2882},
	{"EOTH", 4, 2883},
	{"DIRECTION", 9, 2884},
	{"DPRO", 4, 2885},
	{"OXH", 3, 2886},
	{"OREC", 4, 2887},
	{"WIDE", 4, 2888},
	{"CAMERA", 6, 2889},
	{"LEE", 3, 2890},
	{"ALLOWED", 7, 2891},
	{"EOUT", 4, 2892},
	{"CHARLES", 7, 2893},
	{"TZW", 3, 2894},
	{"UNIT", 4, 2895},
	{"SELLING", 7, 2896},
	{"XPER", 4, 2897},
	{"ECIT", 4, 2898},
	{"EDGE", 4, 2899},
	{"ORKI", 4, 2900},
	{"OLDER", 5, 2901},
	{"ILLINOIS", 8, 2902},
	{"STYLE", 5, 2903},
	{"REGULATIONS", 11, 2904},
	{"EVENING", 7, 2905},
	{"ELEMENTS", 8, 2906},
	{"INSIDE", 6, 2907},
	{"FINGER", 6, 2908},
	{"UTIN", 4, 2909},
	{"CELLS", 5, 2910},
	{"MODULE", 6, 2911},
	{"TICI", 4, 2912},
	{"NECESSARY", 9, 2913},
	{"EKK", 3, 2914},
	{"PRICING", 7, 2915},
	{"COACH", 5, 2916},
	{"ADULT", 5, 2917},
	{"DVDS", 4, 2918},
	{"REFLECT", 7, 2919},
	{"CERTIFICATE", 11, 2920},
	{"CONFERENCE", 10, 2921},
	{"ERTI", 4, 2922},
	{"COMMERCIAL", 10, 2923},
	{"LOOKS", 5, 2924},
	{"DIRECTIONS", 10, 2925},
	{"VISITORS", 8, 2926},
	{"MRS", 3, 2927},
	{"MANAGE", 6, 2928},
	{"OURN", 4, 2929},
	{"DISCOVER", 8, 2930},
	{"TZG", 3, 2931},
	{"TRIP", 4, 2932},
	{"ONWI", 4, 2933},
	{"NZY", 3, 2934},
	{"MIDDLE", 6, 2935},
	{"PATTERN", 7, 2936},
	{"CALLS", 5, 2937},
	{"CHALLENGE", 9, 2938},
	{"HEAT", 4, 2939},
	{"ITEM", 4, 2940},
	{"ITYA", 4, 2941},
	{"EIVE", 4, 2942},
	{"HERW", 4, 2943},
	{"NGAS", 4, 2944},
	{"TREAT", 5, 2945},
	{"GIVING", 6, 2946},
	{"IMPROVE", 7, 2947},
	{"ORRE", 4, 2948},
	{"MOUTH", 5, 2949},
	{"STUFF", 5, 2950},
	{"THROUGHOUT", 10, 2951},
	{"PPED", 4, 2952},
	{"TERW", 4, 2953},
	{"RTHI", 4, 2954},
	{"DEEP", 4, 2955},
	{"OREI", 4, 2956},
	{"PURPOSE", 7, 2957},
	{"ENDING", 6, 2958},
	{"ETIT", 4, 2959},
	{"BEAUTIFUL", 9, 2960},
	{"CLIENTS", 7, 2961},
	{"ACTIONS", 7, 2962},
	{"BAG", 3, 2963},
	{"YWIT", 4, 2964},
	{"SKIN", 4, 2965},
	{"AUTOMOTIVE", 10, 2966},
	{"NAKED", 5, 2967},
	{"ECZ", 3, 2968},
	{"BAR", 3, 2969},
	{"KKN", 3, 2970},
	{"MENTION", 7, 2971},
	{"WYA", 3, 2972},
	{"HEOR", 4, 2973},
	{"SOLD", 4, 2974},
	{"COMMUNITIES", 11, 2975},
	{"TTOT", 4, 2976},
	{"FEQ", 3, 2977},
	{"YWAS", 4, 2978},
	{"RYTH", 4, 2979},
	{"AHEAD", 5, 2980},
	{"WKW", 3, 2981},
	{"ETTI", 4, 2982},
	{"WRITER", 6, 2983},
	{"TROUBLE", 7, 2984},
	{"SCIENCES", 8, 2985},
	{"MARKETS", 7, 2986},
	{"LOWEST", 6, 2987},
	{"HOTEL", 5, 2988},
	{"SHIS", 4, 2989},
	{"DISCUSSION", 10, 2990},
	{"DREAM", 5, 2991},
	{"TOUGH", 5, 2992},
	{"PUBLISHING", 10, 2993},
	{"ORKE", 4, 2994},
	{"OMPE", 4, 2995},
	{"IONB", 4, 2996},
	{"SOLDIER", 7, 2997},
	{"LIVES", 5, 2998},
	{"RWAS", 4, 2999},
	{"XWO", 3, 3000},
	{"QUIR", 4, 3001},
	{"ITYT", 4, 3002},
	{"ESWE", 4, 3003},
	{"OWNER", 5, 3004},
	{"ERAG", 4, 3005},
	{"TFRO", 4, 3006},
	{"VOTE", 4, 3007},
	{"MILF", 4, 3008},
	{"CANCER", 6, 3009},
	{"LWAY", 4, 3010},
	{"ANNOUNCEMENTS", 13, 3011},
	{"SURFACE", 7, 3012},
	{"EXIST", 5, 3013},
	{"ETEA", 4, 3014},
	{"KITCHEN", 7, 3015},
	{"NCEI", 4, 3016},
	{"POSITIVE", 8, 3017},
	{"ORNI", 4, 3018},
	{"BOB", 3, 3019},
	{"SCORE", 5, 3020},
	{"COMMERCE", 8, 3021},
	{"RINGTONES", 9, 3022},
	{"STARE", 5, 3023},
	{"PAINTING", 8, 3024},
	{"WASR", 4, 3025},
	{"YARD", 4, 3026},
	{"PERSONS", 7, 3027},
	{"TASK", 4, 3028},
	{"KQU", 3, 3029},
	{"MAGAZINE", 8, 3030},
	{"BUDGET", 6, 3031},
	{"ONWA", 4, 3032},
	{"ERHE", 4, 3033},
	{"HEAVY", 5, 3034},
	{"TESTS", 5, 3035},
	{"ACCOUNTS", 8, 3036},
	{"UTHO", 4, 3037},
	{"RELATE", 6, 3038},
	{"TWIL", 4, 3039},
	{"XSO", 3, 3040},
	{"MET", 3, 3041},
	{"INSTEAD", 7, 3042},
	{"NVES", 4, 3043},
	{"XBOX", 4, 3044},
	{"ETTH", 4, 3045},
	{"FACTORS", 7, 3046},
	{"ONAT", 4, 3047},
	{"WWW", 3, 3048},
	{"NOTICE", 6, 3049},
	{"SETTINGS", 8, 3050},
	{"KCU", 3, 3051},
	{"FEAR", 4, 3052},
	{"EREF", 4, 3053},
	{"IVEA", 4, 3054},
	{"STEVE", 5, 3055},
	{"OXN", 3, 3056},
	{"SSHO", 4, 3057},
	{"INVESTMENT", 10, 3058},
	{"NDFO", 4, 3059},
	{"GARDEN", 6, 3060},
	{"TOTAL", 5, 3061},
	{"FORD", 4, 3062},
	{"DETAIL", 6, 3063},
	{"TOHI", 4, 3064},
	{"ILDR", 4, 3065},
	{"ORMO", 4, 3066},
	{"NSON", 4, 3067},
	{"TEDF", 4, 3068},
	{"WNJ", 3, 3069},
	{"INHE", 4, 3070},
	{"RCHI", 4, 3071},
	{"HOLIDAYS", 8, 3072},
	{"UNDT", 4, 3073},
	{"IKET", 4, 3074},
	{"SING", 4, 3075},
	{"ZEALAND", 7, 3076},
	{"IAJ", 3, 3077},
	{"MONITORING", 10, 3078},
	{"MARRIAGE", 8, 3079},
	{"REPLIES", 7, 3080},
	{"TONT", 4, 3081},
	{"VIOLENCE", 8, 3082},
	{"NDAT", 4, 3083},
	{"CETO", 4, 3084},
	{"LLAS", 4, 3085},
	{"COLLECTION", 10, 3086},
	{"LKF", 3, 3087},
	{"MACHINE", 7, 3088},
	{"INEA", 4, 3089},
	{"REALITY", 7, 3090},
	{"MODERN", 6, 3091},
	{"DTOA", 4, 3092},
	{"HADT", 4, 3093},
	{"GENERATION", 10, 3094},
	{"ESIT", 4, 3095},
	{"UNTY", 4, 3096},
	{"TEND", 4, 3097},
	{"FFEC", 4, 3098},
	{"SFIR", 4, 3099},
	{"INUE", 4, 3100},
	{"ORTI", 4, 3101},
	{"BEAT", 4, 3102},
	{"AGENT", 5, 3103},
	{"SCOTT", 5, 3104},
	{"ESUL", 4, 3105},
	{"GAS", 3, 3106},
	{"UTQ", 3, 3107},
	{"LLC", 3, 3108},
	{"TEDO", 4, 3109},
	{"NTSO", 4, 3110},
	{"REHE", 4, 3111},
	{"RKJ", 3, 3112},
	{"AGREEMENT", 9, 3113},
	{"SEC", 3, 3114},
	{"RRIE", 4, 3115},
	{"LLOF", 4, 3116},
	{"CONSUMER", 8, 3117},
	{"ONWH", 4, 3118},
	{"CANON", 5, 3119},
	{"RKV", 3, 3120},
	{"DSAN", 4, 3121},
	{"ZGE", 3, 3122},
	{"FTEN", 4, 3123},
	{"OPRO", 4, 3124},
	{"SSUC", 4, 3125},
	{"RWIT", 4, 3126},
	{"ATIT", 4, 3127},
	{"OAY", 3, 3128},
	{"FHY", 3, 3129},
	{"ATTORNEY", 8, 3130},
	{"WHOM", 4, 3131},
	{"NCOU", 4, 3132},
	{"TANC", 4, 3133},
	{"AGEO", 4, 3134},
	{"LZA", 3, 3135},
	{"NPRO", 4, 3136},
	{"KYF", 3, 3137},
	{"OPTIONAL", 8, 3138},
	{"DICTIONARY", 10, 3139},
	{"EONT", 4, 3140},
	{"ETHR", 4, 3141},
	{"CIVIL", 5, 3142},
	{"ESWH", 4, 3143},
	{"SECTIONS", 8, 3144},
	{"SCIENTIST", 9, 3145},
	{"ULDH", 4, 3146},
	{"FIELDS", 6, 3147},
	{"ERPR", 4, 3148},
	{"ESNO", 4, 3149},
	{"LETTERS", 7, 3150},
	{"NGAT", 4, 3151},
	{"DSOF", 4, 3152},
	{"PARTNER", 7, 3153},
	{"NEWSPAPER", 9, 3154},
	{"SHOT", 4, 3155},
	{"RICT", 4, 3156},
	{"INTERESTING", 11, 3157},
	{"AYBE", 4, 3158},
	{"LKY", 3, 3159},
	{"APPAREL", 7, 3160},
	{"CAPITAL", 7, 3161},
	{"WESTERN", 7, 3162},
	{"WMY", 3, 3163},
	{"FRONT", 5, 3164},
	{"YHAV", 4, 3165},
	{"TECHNIQUES", 10, 3166},
	{"IBM", 3, 3167},
	{"NOR", 3, 3168},
	{"DEBATE", 6, 3169},
	{"RD", 2, 3170},
	{"EFER", 4, 3171},
	{"EARO", 4, 3172},
	{"JOHNSON", 7, 3173},
	{"DINNER", 6, 3174},
	{"DOLLARS", 7, 3175},
	{"WEBSITES", 8, 3176},
	{"EARI", 4, 3177},
	{"RESPONSIBILITY", 14, 3178},
	{"HISB", 4, 3179},
	{"EONL", 4, 3180},
	{"THREAT", 6, 3181},
	{"IATI", 4, 3182},
	{"ONSU", 4, 3183},
	{"NOQ", 3, 3184},
	{"RELATION", 8, 3185},
	{"MEASURES", 8, 3186},
	{"KANSAS", 6, 3187},
	{"EFOU", 4, 3188},
	{"SZO", 3, 3189},
	{"UZE", 3, 3190},
	{"HEBU", 4, 3191},
	{"VICTIM", 6, 3192},
	{"RSHI", 4, 3193},
	{"SENATE", 6, 3194},
	{"BROUGHT", 7, 3195},
	{"NDPR", 4, 3196},
	{"DTHI", 4, 3197},
	{"ACCOUNT", 7, 3198},
	{"ZCA", 3, 3199},
	{"MAJORITY", 8, 3200},
	{"ABSOLUTELY", 10, 3201},
	{"NDLE", 4, 3202},
	{"SANTA", 5, 3203},
	{"ILDI", 4, 3204},
	{"EUSE", 4, 3205},
	{"MID", 3, 3206},
	{"ROBL", 4, 3207},
	{"SENIOR", 6, 3208},
	{"GHTO", 4, 3209},
	{"RSAR", 4, 3210},
	{"TSHE", 4, 3211},
	{"OCOM", 4, 3212},
	{"ISRAEL", 6, 3213},
	{"NGIT", 4, 3214},
	{"RSHA", 4, 3215},
	{"PROCESSES", 9, 3216},
	{"IVET", 4, 3217},
	{"WIND", 4, 3218},
	{"PREVENT", 7, 3219},
	{"OSTE", 4, 3220},
	{"CITIZEN", 7, 3221},
	{"HISO", 4, 3222},
	{"NDAY", 4, 3223},
	{"VYR", 3, 3224},
	{"GLOBAL", 6, 3225},
	{"SERVERS", 7, 3226},
	{"EWOU", 4, 3227},
	{"MEETINGS", 8, 3228},
	{"EDOU", 4, 3229},
	{"SECONDS", 7, 3230},
	{"JONES", 5, 3231},
	{"ARIZONA", 7, 3232},
	{"PROFESSIONAL", 12, 3233},
	{"KEYWORD", 7, 3234},
	{"TOHE", 4, 3235},
	{"INTERESTS", 9, 3236},
	{"AUDIENCE", 8, 3237},
	{"CHTH", 4, 3238},
	{"ATHI", 4, 3239},
	{"OOKI", 4, 3240},
	{"EGRO", 4, 3241},
	{"USERNAME", 8, 3242},
	{"SOVIET", 6, 3243},
	{"UMV", 3, 3244},
	{"EDAL", 4, 3245},
	{"REFORM", 6, 3246},
	{"PRODUCED", 8, 3247},
	{"HENH", 4, 3248},
	{"PAPERBACK", 9, 3249},
	{"CLASSIFIEDS", 11, 3250},
	{"XDO", 3, 3251},
	{"SUPPORTED", 9, 3252},
	{"DENC", 4, 3253},
	{"KEY", 3, 3254},
	{"LDHA", 4, 3255},
	{"SAINT", 5, 3256},
	{"TROOP", 5, 3257},
	{"CUSTOMER", 8, 3258},
	{"UNTE", 4, 3259},
	{"FRESH", 5, 3260},
	{"ASSUME", 6, 3261},
	{"CREATING", 8, 3262},
	{"CONCEPT", 7, 3263},
	{"RICH", 4, 3264},
	{"JIM", 3, 3265},
	{"DRUGS", 5, 3266},
	{"RESTAURANT", 10, 3267},
	{"SSIB", 4, 3268},
	{"PROVIDERS", 9, 3269},
	{"CHARACTERS", 10, 3270},
	{"UPGRADE", 7, 3271},
	{"HJI", 3, 3272},
	{"EFFECTIVE", 9, 3273},
	{"THEREFORE", 9, 3274},
	{"EXAMINE", 7, 3275},
	{"SPECIES", 7, 3276},
	{"TRAVEL", 6, 3277},
	{"THOUSANDS", 9, 3278},
	{"KM", 2, 3279},
	{"UTIT", 4, 3280},
	{"APARTMENTS", 10, 3281},
	{"IGNE", 4, 3282},
	{"AUCTIONS", 8, 3283},
	{"ETOW", 4, 3284},
	{"LYTO", 4, 3285},
	{"TWOU", 4, 3286},
	{"SYOU", 4, 3287},
	{"ENTRIES", 7, 3288},
	{"DATES", 5, 3289},
	{"GENERATED", 9, 3290},
	{"CCOR", 4, 3291},
	{"ENHE", 4, 3292},
	{"UETO", 4, 3293},
	{"EINA", 4, 3294},
	{"YCON", 4, 3295},
	{"SPEECH", 6, 3296},
	{"CORNER", 6, 3297},
	{"SIGNED", 6, 3298},
	{"YAJ", 3, 3299},
	{"NDWH", 4, 3300},
	{"FAST", 4, 3301},
	{"OVEM", 4, 3302},
	{"JUDGE", 5, 3303},
	{"SUCCESSFUL", 10, 3304},
	{"NDWI", 4, 3305},
	{"ONAS", 4, 3306},
	{"TERF", 4, 3307},
	{"ATTITUDE", 8, 3308},
	{"OPTION", 6, 3309},
	{"FOREST", 6, 3310},
	{"SAMSUNG", 7, 3311},
	{"TEDW", 4, 3312},
	{"BEGAN", 5, 3313},
	{"SSAI", 4, 3314},
	{"LOUIS", 5, 3315},
	{"ONDI", 4, 3316},
	{"STEPS", 5, 3317},
	{"ERRORS", 6, 3318},
	{"SHOPS", 5, 3319},
	{"NONE", 4, 3320},
	{"DEL", 3, 3321},
	{"EFFORTS", 7, 3322},
	{"BORN", 4, 3323},
	{"INFORMED", 8, 3324},
	{"SOUTHERN", 8, 3325},
	{"ACCESS", 6, 3326},
	{"RHIS", 4, 3327},
	{"THOUGHTS", 8, 3328},
	{"LLYA", 4, 3329},
	{"PYF", 3, 3330},
	{"IOX", 3, 3331},
	{"CREEK", 5, 3332},
	{"WORKED", 6, 3333},
	{"VIDEO", 5, 3334},
	{"MISSION", 7, 3335},
	{"ACHIEVE", 7, 3336},
	{"PRACTICES", 9, 3337},
	{"SORTED", 6, 3338},
	{"ADMIT", 5, 3339},
	{"SKY", 3, 3340},
	{"ORTU", 4, 3341},
	{"NGLI", 4, 3342},
	{"TOURS", 5, 3343},
	{"EAMS", 4, 3344},
	{"NTAT", 4, 3345},
	{"PUBLISH", 7, 3346},
	{"GHTI", 4, 3347},
	{"UYB", 3, 3348},
	{"OBJECT", 6, 3349},
	{"AFFILIATE", 9, 3350},
	{"ADMIN", 5, 3351},
	{"NGSA", 4, 3352},
	{"NURSING", 7, 3353},
	{"ALONE", 5, 3354},
	{"MACHINES", 8, 3355},
	{"DESIGNATED", 10, 3356},
	{"INCOME", 6, 3357},
	{"CONDUCT", 7, 3358},
	{"TAGS", 4, 3359},
	{"IGIN", 4, 3360},
	{"COVERED", 7, 3361},
	{"BIRD", 4, 3362},
	{"TBAL", 4, 3363},
	{"JOE", 3, 3364},
	{"MIY", 3, 3365},
	{"SLEEP", 5, 3366},
	{"BASIC", 5, 3367},
	{"GUYS", 4, 3368},
	{"CONFIGURATION", 13, 3369},
	{"COCK", 4, 3370},
	{"RESEARCHER", 10, 3371},
	{"TOUCH", 5, 3372},
	{"OYP", 3, 3373},
	{"ENOU", 4, 3374},
	{"CONFLICT", 8, 3375},
	{"NEIGHBORHOOD", 12, 3376},
	{"TERB", 4, 3377},
	{"AIZ", 3, 3378},
	{"SUFFER", 6, 3379},
	{"ACKT", 4, 3380},
	{"EATU", 4, 3381},
	{"CDS", 3, 3382},
	{"CREDIT", 6, 3383},
	{"LANGUAGES", 9, 3384},
	{"AFRICAN", 7, 3385},
	{"GHTA", 4, 3386},
	{"EVENTUALLY", 10, 3387},
	{"BECAME", 6, 3388},
	{"OPINION", 7, 3389},
	{"ONEA", 4, 3390},
	{"JEO", 3, 3391},
	{"VEHICLES", 8, 3392},
	{"VERSION", 7, 3393},
	{"HURT", 4, 3394},
	{"RECALL", 6, 3395},
	{"EUF", 3, 3396},
	{"LABOR", 5, 3397},
	{"VYD", 3, 3398},
	{"XRO", 3, 3399},
	{"SCALE", 5, 3400},
	{"ORIGINAL", 8, 3401},
	{"REFER", 5, 3402},
	{"AREP", 4, 3403},
	{"ESOM", 4, 3404},
	{"RELEASE", 7, 3405},
	{"EZZ", 3, 3406},
	{"EAGU", 4, 3407},
	{"NOBODY", 6, 3408},
	{"HISR", 4, 3409},
	{"NUCLEAR", 7, 3410},
	{"PENNSYLVANIA", 12, 3411},
	{"GHER", 4, 3412},
	{"EXAMPLES", 8, 3413},
	{"VARIETY", 7, 3414},
	{"OMMO", 4, 3415},
	{"EDOF", 4, 3416},
	{"UIRE", 4, 3417},
	{"YIV", 3, 3418},
	{"ZYA", 3, 3419},
	{"IPOD", 4, 3420},
	{"SAYING", 6, 3421},
	{"SAFETY", 6, 3422},
	{"FREEDOM", 7, 3423},
	{"CLAIMS", 6, 3424},
	{"INGG", 4, 3425},
	{"MOTOROLA", 8, 3426},
	{"VEDT", 4, 3427},
	{"UOD", 3, 3428},
	{"STRATEGIES", 10, 3429},
	{"DIRECTLY", 8, 3430},
	{"KKO", 3, 3431},
	{"EMOV", 4, 3432},
	{"TTIM", 4, 3433},
	{"ETHO", 4, 3434},
	{"ZRE", 3, 3435},
	{"AFFAIRS", 7, 3436},
	{"INTENDED", 8, 3437},
	{"OROF", 4, 3438},
	{"YOUC", 4, 3439},
	{"CLIENT", 6, 3440},
	{"EXG", 3, 3441},
	{"NDDE", 4, 3442},
	{"GOALS", 5, 3443},
	{"ANYT", 4, 3444},
	{"ICTI", 4, 3445},
	{"DEFINE", 6, 3446},
	{"CHARGES", 7, 3447},
	{"AFFILIATES", 10, 3448},
	{"REASONS", 7, 3449},
	{"EREH", 4, 3450},
	{"UYH", 3, 3451},
	{"PLANE", 5, 3452},
	{"INAR", 4, 3453},
	{"TALKING", 7, 3454},
	{"INVESTIGATION", 13, 3455},
	{"GAVE", 4, 3456},
	{"OBEA", 4, 3457},
	{"RINC", 4, 3458},
	{"ONES", 4, 3459},
	{"ZYM", 3, 3460},
	{"UXA", 3, 3461},
	{"TRACK", 5, 3462},
	{"HEEX", 4, 3463},
	{"MULTIMEDIA", 10, 3464},
	{"XP", 2, 3465},
	{"TITS", 4, 3466},
	{"NDSH", 4, 3467},
	{"CERTIFIED", 9, 3468},
	{"ECUT", 4, 3469},
	{"NDMO", 4, 3470},
	{"ERYO", 4, 3471},
	{"ENTC", 4, 3472},
	{"COMPUTING", 9, 3473},
	{"ERGE", 4, 3474},
	{"OREGON", 6, 3475},
	{"UZU", 3, 3476},
	{"FTHI", 4, 3477},
	{"EEXP", 4, 3478},
	{"EADO", 4, 3479},
	{"INTERACTIVE", 11, 3480},
	{"REQUESTS", 8, 3481},
	{"HEEA", 4, 3482},
	{"STATUS", 6, 3483},
	{"PERFECT", 7, 3484},
	{"INVOLVED", 8, 3485},
	{"PRESS", 5, 3486},
	{"SLOWLY", 6, 3487},
	{"VYM", 3, 3488},
	{"ARGUMENT", 8, 3489},
	{"UGW", 3, 3490},
	{"TABLES", 6, 3491},
	{"ATTEND", 6, 3492},
	{"RACING", 6, 3493},
	{"ENCOURAGE", 9, 3494},
	{"FEATURE", 7, 3495},
	{"OFRE", 4, 3496},
	{"FACTS", 5, 3497},
	{"HEBI", 4, 3498},
	{"ANNOUNCE", 8, 3499},
	{"KONG", 4, 3500},
	{"ATHO", 4, 3501},
	{"PLANTS", 6, 3502},
	{"WEEKEND", 7, 3503},
	{"STRIKE", 6, 3504},
	{"ITST", 4, 3505},
	{"STIO", 4, 3506},
	{"AFTERNOON", 9, 3507},
	{"DHIM", 4, 3508},
	{"TERH", 4, 3509},
	{"GENERALLY", 9, 3510},
	{"HECL", 4, 3511},
	{"AVENUE", 6, 3512},
	{"OTIN", 4, 3513},
	{"POWERFUL", 8, 3514},
	{"GHIS", 4, 3515},
	{"DIED", 4, 3516},
	{"HISL", 4, 3517},
	{"YLY", 3, 3518},
	{"WASB", 4, 3519},
	{"LYBE", 4, 3520},
	{"IMMEDIATELY", 11, 3521},
	{"ELEMENT", 7, 3522},
	{"CONVERSATION", 12, 3523},
	{"SITEMAP", 7, 3524},
	{"RECOMMENDATIONS", 15, 3525},
	{"ECHN", 4, 3526},
	{"MOVED", 5, 3527},
	{"HOUSTON", 7, 3528},
	{"PMEN", 4, 3529},
	{"IONP", 4, 3530},
	{"UNIVERSITY", 10, 3531},
	{"VIEWED", 6, 3532},
	{"THOF", 4, 3533},
	{"NDBE", 4, 3534},
	{"INCH", 4, 3535},
	{"OUX", 3, 3536},
	{"SPIRIT", 6, 3537},
	{"BRITISH", 7, 3538},
	{"INSURANCE", 9, 3539},
	{"RRES", 4, 3540},
	{"CRISIS", 6, 3541},
	{"CENTERS", 7, 3542},
	{"FAN", 3, 3543},
	{"INWH", 4, 3544},
	{"BRAIN", 5, 3545},
	{"OEQ", 3, 3546},
	{"COMPLETE", 8, 3547},
	{"RECIPES", 7, 3548},
	{"VYL", 3, 3549},
	{"SURVEY", 6, 3550},
	{"CVS", 3, 3551},
	{"GAMMA", 5, 3552},
	{"RIBU", 4, 3553},
	{"PLACED", 6, 3554},
	{"XPEC", 4, 3555},
	{"REPLACE", 7, 3556},
	{"FOLLOWS", 7, 3557},
	{"ORHI", 4, 3558},
	{"CAMP", 4, 3559},
	{"ZBO", 3, 3560},
	{"SUN", 3, 3561},
	{"DOLLAR", 6, 3562},
	{"ERAC", 4, 3563},
	{"ARAT", 4, 3564},
	{"ONTARIO", 7, 3565},
	{"SHIP", 4, 3566},
	{"DES", 3, 3567},
	{"NDWE", 4, 3568},
	{"MINNESOTA", 9, 3569},
	{"FILMS", 5, 3570},
	{"COMPLETELY", 10, 3571},
	{"STONE", 5, 3572},
	{"EWAR", 4, 3573},
	{"TZH", 3, 3574},
	{"RYOF", 4, 3575},
	{"OCKE", 4, 3576},
	{"NHER", 4, 3577},
	{"WILLIAMS", 8, 3578},
	{"IDNT", 4, 3579},
	{"ORST", 4, 3580},
	{"POSSIBILITY", 11, 3581},
	{"GTOT", 4, 3582},
	{"PRINTING", 8, 3583},
	{"SAMPLE", 6, 3584},
	{"DOZEN", 5, 3585},
	{"OWNED", 5, 3586},
	{"LYAN", 4, 3587},
	{"VISION", 6, 3588},
	{"OUSL", 4, 3589},
	{"PLAYED", 6, 3590},
	{"CONTACTS", 8, 3591},
	{"CHINESE", 7, 3592},
	{"CC", 2, 3593},
	{"PARK", 4, 3594},
	{"EEDT", 4, 3595},
	{"TEXT", 4, 3596},
	{"JESUS", 5, 3597},
	{"HOLE", 4, 3598},
	{"NZH", 3, 3599},
	{"YZI", 3, 3600},
	{"READERS", 7, 3601},
	{"HECR", 4, 3602},
	{"CLUBS", 5, 3603},
	{"LCD", 3, 3604},
	{"STICK", 5, 3605},
	{"DEPARTMENT", 10, 3606},
	{"JACKSON", 7, 3607},
	{"CTER", 4, 3608},
	{"ICTO", 4, 3609},
	{"MATCHING", 8, 3610},
	{"INGN", 4, 3611},
	{"LACK", 4, 3612},
	{"SHIRTS", 6, 3613},
	{"SALES", 5, 3614},
	{"LEADERS", 7, 3615},
	{"MMON", 4, 3616},
	{"HATP", 4, 3617},
	{"POSTERS", 7, 3618},
	{"INSTITUTIONS", 12, 3619},
	{"TRADITION", 9, 3620},
	{"AVE", 3, 3621},
	{"YRN", 3, 3622},
	{"DJ", 2, 3623},
	{"BOAT", 4, 3624},
	{"DRINK", 5, 3625},
	{"ITHM", 4, 3626},
	{"EDSO", 4, 3627},
	{"WASF", 4, 3628},
	{"SOLUTION", 8, 3629},
	{"HEADLINES", 9, 3630},
	{"COMPARED", 8, 3631},
	{"ACKE", 4, 3632},
	{"AROL", 4, 3633},
	{"ESHI", 4, 3634},
	{"DETERMINED", 10, 3635},
	{"WHOLESALE", 9, 3636},
	{"BATTLE", 6, 3637},
	{"CTTH", 4, 3638},
	{"UALI", 4, 3639},
	{"ATTEMPT", 7, 3640},
	{"RUSSIA", 6, 3641},
	{"VATI", 4, 3642},
	{"ITAN", 4, 3643},
	{"GONE", 4, 3644},
	{"CODES", 5, 3645},
	{"KINDS", 5, 3646},
	{"BEGINNING", 9, 3647},
	{"SEATTLE", 7, 3648},
	{"ARDT", 4, 3649},
	{"LCON", 4, 3650},
	{"RESIDENT", 8, 3651},
	{"STATEMENTS", 10, 3652},
	{"OXL", 3, 3653},
	{"TEAMS", 5, 3654},
	{"WOOD", 4, 3655},
	{"RPRO", 4, 3656},
	{"FORT", 4, 3657},
	{"EASILY", 6, 3658},
	{"INRE", 4, 3659},
	{"CM", 2, 3660},
	{"FORCES", 6, 3661},
	{"LLYT", 4, 3662},
	{"DYJ", 3, 3663},
	{"ICE", 3, 3664},
	{"TURNED", 6, 3665},
	{"EORG", 4, 3666},
	{"TRIED", 5, 3667},
	{"DRIVER", 6, 3668},
	{"SPOT", 4, 3669},
	{"APPLICABLE", 10, 3670},
	{"ROLL", 4, 3671},
	{"OLDI", 4, 3672},
	{"RETURNED", 8, 3673},
	{"VWH", 3, 3674},
	{"EDUP", 4, 3675},
	{"NEAN", 4, 3676},
	{"YJI", 3, 3677},
	{"NAMED", 5, 3678},
	{"THEATRE", 7, 3679},
	{"TRUCK", 5, 3680},
	{"EARLIER", 7, 3681},
	{"MANUFACTURERS", 13, 3682},
	{"NSIV", 4, 3683},
	{"ONMA", 4, 3684},
	{"DATE", 4, 3685},
	{"EUROPEAN", 8, 3686},
	{"READER", 6, 3687},
	{"ONFI", 4, 3688},
	{"LAYI", 4, 3689},
	{"DDIT", 4, 3690},
	{"DISTANCE", 8, 3691},
	{"GJI", 3, 3692},
	{"WARRANTY", 8, 3693},
	{"DEDICATED", 9, 3694},
	{"INDIANA", 7, 3695},
	{"EBAL", 4, 3696},
	{"EYHA", 4, 3697},
	{"INTRODUCE", 9, 3698},
	{"NTHO", 4, 3699},
	{"HEHI", 4, 3700},
	{"DISTRICT", 8, 3701},
	{"HARRY", 5, 3702},
	{"MOUNTAIN", 8, 3703},
	{"UNDERSTANDING", 13, 3704},
	{"ARTM", 4, 3705},
	{"OBJECTS", 7, 3706},
	{"OBVIOUSLY", 9, 3707},
	{"POTENTIAL", 9, 3708},
	{"ATTL", 4, 3709},
	{"NORMAL", 6, 3710},
	{"ENDS", 4, 3711},
	{"VEME", 4, 3712},
	{"OXP", 3, 3713},
	{"NGES", 4, 3714},
	{"DELETE", 6, 3715},
	{"WINTER", 6, 3716},
	{"LREA", 4, 3717},
	{"EHOU", 4, 3718},
	{"ERIA", 4, 3719},
	{"OYR", 3, 3720},
	{"IDENTITY", 8, 3721},
	{"HERH", 4, 3722},
	{"TAXES", 5, 3723},
	{"RDAY", 4, 3724},
	{"HYY", 3, 3725},
	{"ISSUED", 6, 3726},
	{"YWER", 4, 3727},
	{"VYB", 3, 3728},
	{"HIDE", 4, 3729},
	{"TSHO", 4, 3730},
	{"WISCONSIN", 9, 3731},
	{"NYQ", 3, 3732},
	{"INDEPENDENT", 11, 3733},
	{"ERCA", 4, 3734},
	{"LLAR", 4, 3735},
	{"APARTMENT", 9, 3736},
	{"SUPPOSED", 8, 3737},
	{"TERMS", 5, 3738},
	{"HORSE", 5, 3739},
	{"WHOH", 4, 3740},
	{"OBTAINED", 8, 3741},
	{"EXPRESS", 7, 3742},
	{"CKET", 4, 3743},
	{"CONTRACT", 8, 3744},
	{"TOIN", 4, 3745},
	{"ATWA", 4, 3746},
	{"FELT", 4, 3747},
	{"IFYO", 4, 3748},
	{"CLUB", 4, 3749},
	{"RIQ", 3, 3750},
	{"WAYT", 4, 3751},
	{"SCREEN", 6, 3752},
	{"PASSED", 6, 3753},
	{"DYOU", 4, 3754},
	{"SUPPLIED", 8, 3755},
	{"ROJE", 4, 3756},
	{"VILLAGE", 7, 3757},
	{"TZK", 3, 3758},
	{"OBSERVE", 7, 3759},
	{"GOLD", 4, 3760},
	{"IDENTIFIED", 10, 3761},
	{"CHRISTIAN", 9, 3762},
	{"FALLS", 5, 3763},
	{"EAPP", 4, 3764},
	{"PIC", 3, 3765},
	{"GAIN", 4, 3766},
	{"VIOU", 4, 3767},
	{"OSEE", 4, 3768},
	{"OPINIONS", 8, 3769},
	{"YCOM", 4, 3770},
	{"HANDLE", 6, 3771},
	{"PRESENCE", 8, 3772},
	{"STATED", 6, 3773},
	{"STATS", 5, 3774},
	{"HAWAII", 6, 3775},
	{"NSWE", 4, 3776},
	{"PROFESSIONALS", 13, 3777},
	{"ENEX", 4, 3778},
	{"APPEARS", 7, 3779},
	{"EGRA", 4, 3780},
	{"NEDI", 4, 3781},
	{"DECIDED", 7, 3782},
	{"CROWD", 5, 3783},
	{"DEMAND", 6, 3784},
	{"CTUA", 4, 3785},
	{"UJO", 3, 3786},
	{"COVERS", 6, 3787},
	{"EYY", 3, 3788},
	{"ONVE", 4, 3789},
	{"PREVIOUS", 8, 3790},
	{"DESIGNS", 7, 3791},
	{"RIDE", 4, 3792},
	{"CHOF", 4, 3793},
	{"ENTB", 4, 3794},
	{"ORYO", 4, 3795},
	{"REPORTER", 8, 3796},
	{"HTER", 4, 3797},
	{"ASSOCIATE", 9, 3798},
	{"NKIN", 4, 3799},
	{"NEWSLETTERS", 11, 3800},
	{"SHAPE", 5, 3801},
	{"ONOR", 4, 3802},
	{"HISH", 4, 3803},
	{"ADULTS", 6, 3804},
	{"CLIPS", 5, 3805},
	{"BASIS", 5, 3806},
	{"OFMA", 4, 3807},
	{"BUTW", 4, 3808},
	{"REWE", 4, 3809},
	{"SAVINGS", 7, 3810},
	{"ALOF", 4, 3811},
	{"IESI", 4, 3812},
	{"GRAPHIC", 7, 3813},
	{"ATOM", 4, 3814},
	{"SSOC", 4, 3815},
	{"LLST", 4, 3816},
	{"PAYMENTS", 8, 3817},
	{"PYL", 3, 3818},
	{"FARM", 4, 3819},
	{"TOOL", 4, 3820},
	{"RW", 2, 3821},
	{"OAQ", 3, 3822},
	{"PRISON", 6, 3823},
	{"ECHI", 4, 3824},
	{"HEYH", 4, 3825},
	{"NGAR", 4, 3826},
	{"ISFA", 4, 3827},
	{"CKTO", 4, 3828},
	{"LKU", 3, 3829},
	{"EBEC", 4, 3830},
	{"EPEO", 4, 3831},
	{"REFUSE", 6, 3832},
	{"EINF", 4, 3833},
	{"HEOT", 4, 3834},
	{"AKEA", 4, 3835},
	{"GUARD", 5, 3836},
	{"BINDING", 7, 3837},
	{"ENDED", 5, 3838},
	{"MPLO", 4, 3839},
	{"ISHO", 4, 3840},
	{"WINNING", 7, 3841},
	{"FACILITY", 8, 3842},
	{"SERVED", 6, 3843},
	{"TOMORROW", 8, 3844},
	{"WANTS", 5, 3845},
	{"CONTRIBUTE", 10, 3846},
	{"MISCELLANEOUS", 13, 3847},
	{"PREPARED", 8, 3848},
	{"VOID", 4, 3849},
	{"IFIE", 4, 3850},
	{"LEADERSHIP", 10, 3851},
	{"ALERT", 5, 3852},
	{"NOTB", 4, 3853},
	{"PRINCIPLE", 9, 3854},
	{"ATLANTA", 7, 3855},
	{"DAKOTA", 6, 3856},
	{"ESSU", 4, 3857},
	{"ERMO", 4, 3858},
	{"OWAS", 4, 3859},
	{"POUND", 5, 3860},
	{"INSTALLED", 9, 3861},
	{"VHS", 3, 3862},
	{"CREDITS", 7, 3863},
	{"ONON", 4, 3864},
	{"OUY", 3, 3865},
	{"IUL", 3, 3866},
	{"PUBMED", 6, 3867},
	{"TARGET", 6, 3868},
	{"DAVE", 4, 3869},
	{"NWHO", 4, 3870},
	{"ITUT", 4, 3871},
	{"MASSACHUSETTS", 13, 3872},
	{"DBEE", 4, 3873},
	{"NTSI", 4, 3874},
	{"TECHNIQUE", 9, 3875},
	{"DIEGO", 5, 3876},
	{"ADTO", 4, 3877},
	{"HONG", 4, 3878},
	{"THHI", 4, 3879},
	{"UBG", 3, 3880},
	{"VICE", 4, 3881},
	{"BRIGHT", 6, 3882},
	{"AMOU", 4, 3883},
	{"STRENGTH", 8, 3884},
	{"BAND", 4, 3885},
	{"AYST", 4, 3886},
	{"ERUN", 4, 3887},
	{"TINY", 4, 3888},
	{"YFRO", 4, 3889},
	{"UEY", 3, 3890},
	{"ESTU", 4, 3891},
	{"AVERAGE", 7, 3892},
	{"ENLARGE", 7, 3893},
	{"NGAL", 4, 3894},
	{"RAY", 3, 3895},
	{"CRY", 3, 3896},
	{"ADTH", 4, 3897},
	{"PROMOTE", 7, 3898},
	{"KGU", 3, 3899},
	{"VOTES", 5, 3900},
	{"OPLA", 4, 3901},
	{"WILLING", 7, 3902},
	{"ACKA", 4, 3903},
	{"DU", 2, 3904},
	{"AXH", 3, 3905},
	{"NDNO", 4, 3906},
	{"OVIN", 4, 3907},
	{"ATWE", 4, 3908},
	{"EAR", 3, 3909},
	{"FEJ", 3, 3910},
	{"LOOKED", 6, 3911},
	{"DISCUSSIONS", 11, 3912},
	{"ERSF", 4, 3913},
	{"EDED", 4, 3914},
	{"UYL", 3, 3915},
	{"EROU", 4, 3916},
	{"EARN", 4, 3917},
	{"ONSW", 4, 3918},
	{"HIGHLY", 6, 3919},
	{"ITYI", 4, 3920},
	{"FLIGHT", 6, 3921},
	{"FLIGHTS", 7, 3922},
	{"EXPERTS", 7, 3923},
	{"SSOM", 4, 3924},
	{"SIGNS", 5, 3925},
	{"REDB", 4, 3926},
	{"EMERGE", 6, 3927},
	{"IOWA", 4, 3928},
	{"LOGGED", 6, 3929},
	{"WILD", 4, 3930},
	{"HATD", 4, 3931},
	{"LAPTOP", 6, 3932},
	{"ASPECT", 6, 3933},
	{"VINTAGE", 7, 3934},
	{"EGUL", 4, 3935},
	{"VEHICLE", 7, 3936},
	{"ONFE", 4, 3937},
	{"EFAC", 4, 3938},
	{"LIFT", 4, 3939},
	{"OPERATE", 7, 3940},
	{"ADVANTAGE", 9, 3941},
	{"PROTECTION", 10, 3942},
	{"DBYA", 4, 3943},
	{"MARYLAND", 8, 3944},
	{"SPA", 3, 3945},
	{"GUEST", 5, 3946},
	{"DWHE", 4, 3947},
	{"CHECKOUT", 8, 3948},
	{"PYB", 3, 3949},
	{"TEOF", 4, 3950},
	{"FORGOT", 6, 3951},
	{"LSAN", 4, 3952},
	{"HANDLING", 8, 3953},
	{"PPEN", 4, 3954},
	{"KNEW", 4, 3955},
	{"VYF", 3, 3956},
	{"GAMING", 6, 3957},
	{"FEEDS", 5, 3958},
	{"TITLE", 5, 3959},
	{"RMOR", 4, 3960},
	{"SCOTLAND", 8, 3961},
	{"DEMONSTRATE", 11, 3962},
	{"DELIVER", 7, 3963},
	{"DALLAS", 6, 3964},
	{"RSQU", 4, 3965},
	{"INTERESTED", 10, 3966},
	{"STHR", 4, 3967},
	{"BOUGHT", 6, 3968},
	{"CONTEXT", 7, 3969},
	{"LPRO", 4, 3970},
	{"QUICK", 5, 3971},
	{"AKET", 4, 3972},
	{"TEAD", 4, 3973},
	{"CON", 3, 3974},
	{"UPS", 3, 3975},
	{"NATIONS", 7, 3976},
	{"FOLLOWED", 8, 3977},
	{"SPECIFICATIONS", 14, 3978},
	{"OREP", 4, 3979},
	{"PROCEDURE", 9, 3980},
	{"TRIPADVISOR", 11, 3981},
	{"FRANK", 5, 3982},
	{"RTME", 4, 3983},
	{"ALASKA", 6, 3984},
	{"ZOOM", 4, 3985},
	{"EETI", 4, 3986},
	{"ANIME", 5, 3987},
	{"DECISIONS", 9, 3988},
	{"INDUSTRIES", 10, 3989},
	{"ALFO", 4, 3990},
	{"NGAB", 4, 3991},
	{"COLLECT", 7, 3992},
	{"QUERY", 5, 3993},
	{"OCES", 4, 3994},
	{"ORX", 3, 3995},
	{"LIMIT", 5, 3996},
	{"STCO", 4, 3997},
	{"EDITORIAL", 9, 3998},
	{"ONAR", 4, 3999},
	{"LEARNING", 8, 4000},
	{"RIVER", 5, 4001},
	{"BELIEF", 6, 4002},
	{"IESW", 4, 4003},
	{"COUNT", 5, 4004},
	{"SETTLE", 6, 4005},
	{"BLOCK", 5, 4006},
	{"TCAN", 4, 4007},
	{"VOLV", 4, 4008},
	{"EETH", 4, 4009},
	{"PROVISIONS", 10, 4010},
	{"HURC", 4, 4011},
	{"COMPETITION", 11, 4012},
	{"ONGR", 4, 4013},
	{"TCHA", 4, 4014},
	{"PYH", 3, 4015},
	{"LIVING", 6, 4016},
	{"MMIT", 4, 4017},
	{"MARRY", 5, 4018},
	{"PRINCIPLES", 10, 4019},
	{"OTOF", 4, 4020},
	{"FAITH", 5, 4021},
	{"ANYBODY", 7, 4022},
	{"SUGGESTIONS", 11, 4023},
	{"FOLK", 4, 4024},
	{"EDAR", 4, 4025},
	{"SOUNDS", 6, 4026},
	{"SONW", 4, 4027},
	{"LAIM", 4, 4028},
	{"TCHI", 4, 4029},
	{"BORDER", 6, 4030},
	{"GNED", 4, 4031},
	{"LESSON", 6, 4032},
	{"IGNI", 4, 4033},
	{"TWHE", 4, 4034},
	{"WARM", 4, 4035},
	{"SHOP", 4, 4036},
	{"YKR", 3, 4037},
	{"TPLA", 4, 4038},
	{"SPAM", 4, 4039},
	{"ATEO", 4, 4040},
	{"CHAIRMAN", 8, 4041},
	{"BASEBALL", 8, 4042},
	{"ONGS", 4, 4043},
	{"IZAT", 4, 4044},
	{"UMEN", 4, 4045},
	{"BYTES", 5, 4046},
	{"ASTY", 4, 4047},
	{"CENT", 4, 4048},
	{"FORCED", 6, 4049},
	{"WNK", 3, 4050},
	{"JUMP", 4, 4051},
	{"COMPATIBLE", 10, 4052},
	{"FEED", 4, 4053},
	{"INKI", 4, 4054},
	{"ZATI", 4, 4055},
	{"ANNUAL", 6, 4056},
	{"RYEA", 4, 4057},
	{"NULL", 4, 4058},
	{"EANI", 4, 4059},
	{"ZERO", 4, 4060},
	{"FILED", 5, 4061},
	{"ARSO", 4, 4062},
	{"EEAR", 4, 4063},
	{"INFLUENCE", 9, 4064},
	{"NETHERLANDS", 11, 4065},
	{"CONSULTING", 10, 4066},
	{"RECREATION", 10, 4067},
	{"OFFICES", 7, 4068},
	{"PATH", 4, 4069},
	{"MURDER", 6, 4070},
	{"COFFEE", 6, 4071},
	{"PERSPECTIVE", 11, 4072},
	{"SQUO", 4, 4073},
	{"HEYC", 4, 4074},
	{"MANAGED", 7, 4075},
	{"PR", 2, 4076},
	{"EEDE", 4, 4077},
	{"FAILED", 6, 4078},
	{"GYG", 3, 4079},
	{"RTUN", 4, 4080},
	{"KOREA", 5, 4081},
	{"BANKS", 5, 4082},
	{"NGPR", 4, 4083},
	{"FR", 2, 4084},
	{"HARG", 4, 4085},
	{"PARTICIPANTS", 12, 4086},
	{"YSTA", 4, 4087},
	{"FINDING", 7, 4088},
	{"CRITIC", 6, 4089},
	{"FAILURE", 7, 4090},
	{"KELLY", 5, 4091},
	{"RELIGION", 8, 4092},
	{"LEADS", 5, 4093},
	{"ACADEMIC", 8, 4094},
	{"RKED", 4, 4095},
	{"ENGAGE", 6, 4096},
	{"UTTO", 4, 4097},
	{"AUSTIN", 6, 4098},
	{"DTHR", 4, 4099},
	{"ILLH", 4, 4100},
	{"FAVORITES", 9, 4101},
	{"MOSTLY", 6, 4102},
	{"TORONTO", 7, 4103},
	{"ANYWAY", 6, 4104},
	{"SPRINGS", 7, 4105},
	{"REVIEW", 6, 4106},
	{"MISSOURI", 8, 4107},
	{"ACKI", 4, 4108},
	{"YPRO", 4, 4109},
	{"ANDREW", 6, 4110},
	{"TZT", 3, 4111},
	{"NGFR", 4, 4112},
	{"VAR", 3, 4113},
	{"HEFR", 4, 4114},
	{"SYU", 3, 4115},
	{"USLY", 4, 4116},
	{"DSOM", 4, 4117},
	{"SSOF", 4, 4118},
	{"ESTIMATES", 9, 4119},
	{"FONT", 4, 4120},
	{"ASSETS", 6, 4121},
	{"NATIVE", 6, 4122},
	{"DGY", 3, 4123},
	{"JOSEPH", 6, 4124},
	{"FUNCTION", 8, 4125},
	{"RSTT", 4, 4126},
	{"DRIVERS", 7, 4127},
	{"EOFH", 4, 4128},
	{"SOFT", 4, 4129},
	{"FIGURES", 7, 4130},
	{"FEMALE", 6, 4131},
	{"MMEN", 4, 4132},
	{"PROTECTED", 9, 4133},
	{"EGG", 3, 4134},
	{"SHARING", 7, 4135},
	{"PHILADELPHIA", 12, 4136},
	{"UNLESS", 6, 4137},
	{"PORTAL", 6, 4138},
	{"WAITING", 7, 4139},
	{"BETA", 4, 4140},
	{"TCOU", 4, 4141},
	{"GRATIS", 6, 4142},
	{"FIT", 3, 4143},
	{"UDGE", 4, 4144},
	{"ULJ", 3, 4145},
	{"RGES", 4, 4146},
	{"HOWT", 4, 4147},
	{"OWAR", 4, 4148},
	{"OFFICIALS", 9, 4149},
	{"BRIAN", 5, 4150},
	{"EVIS", 4, 4151},
	{"YCY", 3, 4152},
	{"DPLA", 4, 4153},
	{"VOTER", 5, 4154},
	{"UILT", 4, 4155},
	{"EGIO", 4, 4156},
	{"YOUTH", 5, 4157},
	{"WON", 3, 4158},
	{"SPEED", 5, 4159},
	{"EDITOR", 6, 4160},
	{"AFRAID", 6, 4161},
	{"COOK", 4, 4162},
	{"ETOA", 4, 4163},
	{"EDRE", 4, 4164},
	{"COMMENT", 7, 4165},
	{"CONTAINED", 9, 4166},
	{"LINGERIE", 8, 4167},
	{"WORTH", 5, 4168},
	{"SURVIVE", 7, 4169},
	{"CALLING", 7, 4170},
	{"PARAMETERS", 10, 4171},
	{"BAGS", 4, 4172},
	{"PROFILES", 8, 4173},
	{"MIAMI", 5, 4174},
	{"GATHER", 6, 4175},
	{"HEY", 3, 4176},
	{"COMICS", 6, 4177},
	{"MATTERS", 7, 4178},
	{"HOUSES", 6, 4179},
	{"USSI", 4, 4180},
	{"OLJ", 3, 4181},
	{"DTOH", 4, 4182},
	{"POSTAL", 6, 4183},
	{"TSON", 4, 4184},
	{"OTBE", 4, 4185},
	{"RELATIONSHIPS", 13, 4186},
	{"TENNESSEE", 9, 4187},
	{"CONTROLS", 8, 4188},
	{"BREAKING", 8, 4189},
	{"SOFS", 4, 4190},
	{"OUBL", 4, 4191},
	{"FRENCH", 6, 4192},
	{"WALES", 5, 4193},
	{"NTHS", 4, 4194},
	{"OLUT", 4, 4195},
	{"NMAR", 4, 4196},
	{"RESPONSIBLE", 11, 4197},
	{"INTELLIGENCE", 12, 4198},
	{"INTRODUCED", 10, 4199},
	{"EREB", 4, 4200},
	{"DEPARTMENTS", 11, 4201},
	{"CLASSROOM", 9, 4202},
	{"DTOP", 4, 4203},
	{"CROSS", 5, 4204},
	{"DSTH", 4, 4205},
	{"NOTED", 5, 4206},
	{"DISPLAYED", 9, 4207},
	{"HOHA", 4, 4208},
	{"LLIA", 4, 4209},
	{"REDUCED", 7, 4210},
	{"SOVE", 4, 4211},
	{"SPENT", 5, 4212},
	{"PERFORMED", 9, 4213},
	{"RPRI", 4, 4214},
	{"DYV", 3, 4215},
	{"ATEI", 4, 4216},
	{"SAMPLES", 7, 4217},
	{"DAVIS", 5, 4218},
	{"DANIEL", 6, 4219},
	{"ZSC", 3, 4220},
	{"BARS", 4, 4221},
	{"NGED", 4, 4222},
	{"REVIEWED", 8, 4223},
	{"AFFAIR", 6, 4224},
	{"ESFR", 4, 4225},
	{"IGHE", 4, 4226},
	{"XAMP", 4, 4227},
	{"IEDT", 4, 4228},
	{"SYEA", 4, 4229},
	{"FORECAST", 8, 4230},
	{"ISFI", 4, 4231},
	{"NGLA", 4, 4232},
	{"REMOVED", 7, 4233},
	{"HELPS", 5, 4234},
	{"SINGLES", 7, 4235},
	{"EYWE", 4, 4236},
	{"AMOUNTS", 7, 4237},
	{"UBLE", 4, 4238},
	{"HEAS", 4, 4239},
	{"DUAL", 4, 4240},
	{"USD", 3, 4241},
	{"ESUP", 4, 4242},
	{"ALIZ", 4, 4243},
	{"NOD", 3, 4244},
	{"HELL", 4, 4245},
	{"ORWA", 4, 4246},
	{"IDIN", 4, 4247},
	{"EVW", 3, 4248},
	{"SONL", 4, 4249},
	{"NALT", 4, 4250},
	{"SPREAD", 6, 4251},
	{"HISTORICAL", 10, 4252},
	{"ETOF", 4, 4253},
	{"BLOW", 4, 4254},
	{"NOUG", 4, 4255},
	{"MG", 2, 4256},
	{"REGULAR", 7, 4257},
	{"XHE", 3, 4258},
	{"CATEGORY", 8, 4259},
	{"ONEI", 4, 4260},
	{"RPOR", 4, 4261},
	{"INSIST", 6, 4262},
	{"BROAD", 5, 4263},
	{"PHARMACY", 8, 4264},
	{"BRAZIL", 6, 4265},
	{"STATIC", 6, 4266},
	{"GRADE", 5, 4267},
	{"ADDRESSES", 9, 4268},
	{"ASHO", 4, 4269},
	{"QUARTER", 7, 4270},
	{"CONSTRUCTION", 12, 4271},
	{"INDIAN", 6, 4272},
	{"ITTH", 4, 4273},
	{"FANS", 4, 4274},
	{"OLZ", 3, 4275},
	{"OKLAHOMA", 8, 4276},
	{"SPEAKERS", 8, 4277},
	{"SUIT", 4, 4278},
	{"ACADEMY", 7, 4279},
	{"WEHA", 4, 4280},
	{"GIFT", 4, 4281},
	{"UATI", 4, 4282},
	{"XSU", 3, 4283},
	{"CLOTHES", 7, 4284},
	{"DELL", 4, 4285},
	{"IGNORE", 6, 4286},
	{"CLEANING", 8, 4287},
	{"INTERNET", 8, 4288},
	{"MORAL", 5, 4289},
	{"EDEV", 4, 4290},
	{"CONSTITUTES", 11, 4291},
	{"DTOC", 4, 4292},
	{"ZBU", 3, 4293},
	{"GRAB", 4, 4294},
	{"SHOE", 4, 4295},
	{"COMMIT", 6, 4296},
	{"COLLECTIBLES", 12, 4297},
	{"UYC", 3, 4298},
	{"ICHW", 4, 4299},
	{"TIFI", 4, 4300},
	{"IVAT", 4, 4301},
	{"EABO", 4, 4302},
	{"BACKGROUND", 10, 4303},
	{"LEAN", 4, 4304},
	{"ANIZ", 4, 4305},
	{"SLIGHTLY", 8, 4306},
	{"CONCERNS", 8, 4307},
	{"GGES", 4, 4308},
	{"COLOUR", 6, 4309},
	{"IONH", 4, 4310},
	{"PPIN", 4, 4311},
	{"GROWING", 7, 4312},
	{"ASTT", 4, 4313},
	{"NEGATIVE", 8, 4314},
	{"WAVE", 4, 4315},
	{"LEDI", 4, 4316},
	{"NGMA", 4, 4317},
	{"OPJ", 3, 4318},
	{"EOVE", 4, 4319},
	{"EMEM", 4, 4320},
	{"INTEL", 5, 4321},
	{"LVES", 4, 4322},
	{"PPLI", 4, 4323},
	{"ASFO", 4, 4324},
	{"UTILITIES", 9, 4325},
	{"OFFICERS", 8, 4326},
	{"NTCO", 4, 4327},
	{"LDTH", 4, 4328},
	{"TSWH", 4, 4329},
	{"REACTION", 8, 4330},
	{"BELOW", 5, 4331},
	{"BIDS", 4, 4332},
	{"OURI", 4, 4333},
	{"DSHE", 4, 4334},
	{"REFERRED", 8, 4335},
	{"SUPPORTS", 8, 4336},
	{"ESBE", 4, 4337},
	{"ONHI", 4, 4338},
	{"QUIET", 5, 4339},
	{"NUTRITION", 9, 4340},
	{"NTAR", 4, 4341},
	{"NTFO", 4, 4342},
	{"NWHE", 4, 4343},
	{"REGIONS", 7, 4344},
	{"COMMITTEE", 9, 4345},
	{"LES", 3, 4346},
	{"WINE", 4, 4347},
	{"CAPE", 4, 4348},
	{"INUT", 4, 4349},
	{"DENY", 4, 4350},
	{"TSHA", 4, 4351},
	{"TOFO", 4, 4352},
	{"DRESS", 5, 4353},
	{"RINGS", 5, 4354},
	{"BURN", 4, 4355},
	{"FOLLOWING", 9, 4356},
	{"IGHS", 4, 4357},
	{"LADIES", 6, 4358},
	{"NVOL", 4, 4359},
	{"ONHA", 4, 4360},
	{"HENRY", 5, 4361},
	{"EELE", 4, 4362},
	{"FKU", 3, 4363},
	{"HEAC", 4, 4364},
	{"EBRA", 4, 4365},
	{"ANNOUNCED", 9, 4366},
	{"THREATEN", 8, 4367},
	{"COMBINE", 7, 4368},
	{"AGREED", 6, 4369},
	{"CONNECTION", 10, 4370},
	{"STTO", 4, 4371},
	{"ZYS", 3, 4372},
	{"ERVA", 4, 4373},
	{"EPOL", 4, 4374},
	{"APPARENTLY", 10, 4375},
	{"ONGA", 4, 4376},
	{"ACTIVE", 6, 4377},
	{"AYOF", 4, 4378},
	{"PARTICIPATE", 11, 4379},
	{"EWYO", 4, 4380},
	{"UXT", 3, 4381},
	{"LTUR", 4, 4382},
	{"PLEW", 4, 4383},
	{"ILLT", 4, 4384},
	{"RELATIVELY", 10, 4385},
	{"LLYI", 4, 4386},
	{"POSTING", 7, 4387},
	{"ETOR", 4, 4388},
	{"RSWH", 4, 4389},
	{"CHIEF", 5, 4390},
	{"TRYI", 4, 4391},
	{"TWICE", 5, 4392},
	{"LEFO", 4, 4393},
	{"NSHE", 4, 4394},
	{"MENTIONED", 9, 4395},
	{"TYIN", 4, 4396},
	{"UNITED", 6, 4397},
	{"HEALTHCARE", 10, 4398},
	{"IVID", 4, 4399},
	{"VIEWING", 7, 4400},
	{"MAINTAINED", 10, 4401},
	{"HOFT", 4, 4402},
	{"SSUR", 4, 4403},
	{"ASSESSMENT", 10, 4404},
	{"NGIS", 4, 4405},
	{"CONNECTED", 9, 4406},
	{"ATSH", 4, 4407},
	{"BONE", 4, 4408},
	{"COOL", 4, 4409},
	{"CHRIST", 6, 4410},
	{"DAN", 3, 4411},
	{"DOGS", 4, 4412},
	{"YHY", 3, 4413},
	{"MPER", 4, 4414},
	{"DIRECTORS", 9, 4415},
	{"LITERATURE", 10, 4416},
	{"ASPECTS", 7, 4417},
	{"AUSTRIA", 7, 4418},
	{"APPROPRIATE", 11, 4419},
	{"UNCE", 4, 4420},
	{"YESTERDAY", 9, 4421},
	{"YDB", 3, 4422},
	{"RVED", 4, 4423},
	{"ERSU", 4, 4424},
	{"DESTROY", 7, 4425},
	{"PREVIEW", 7, 4426},
	{"NGOU", 4, 4427},
	{"SYH", 3, 4428},
	{"STSE", 4, 4429},
	{"MATRIX", 6, 4430},
	{"LZE", 3, 4431},
	{"NDCH", 4, 4432},
	{"CONTAINING", 10, 4433},
	{"NSFO", 4, 4434},
	{"ACKO", 4, 4435},
	{"MISTAKE", 7, 4436},
	{"OTTH", 4, 4437},
	{"PRIMARY", 7, 4438},
	{"DEVEL", 5, 4439},
	{"DEMOCRACY", 9, 4440},
	{"UREO", 4, 4441},
	{"ONRE", 4, 4442},
	{"GUARANTEED", 10, 4443},
	{"HEALTHY", 7, 4444},
	{"DIRECT", 6, 4445},
	{"LIBRARIES", 9, 4446},
	{"DISTRIBUTED", 11, 4447},
	{"DEGREES", 7, 4448},
	{"SINGAPORE", 9, 4449},
	{"ECTR", 4, 4450},
	{"ENTERPRISES", 11, 4451},
	{"EXTEND", 6, 4452},
	{"OSIN", 4, 4453},
	{"DELTA", 5, 4454},
	{"EHIG", 4, 4455},
	{"EXERCISE", 8, 4456},
	{"NPLA", 4, 4457},
	{"SEEKING", 7, 4458},
	{"INCHES", 6, 4459},
	{"PHOENIX", 7, 4460},
	{"KNEE", 4, 4461},
	{"OUCA", 4, 4462},
	{"SHARES", 6, 4463},
	{"STSA", 4, 4464},
	{"WYOR", 4, 4465},
	{"NTSW", 4, 4466},
	{"BUS", 3, 4467},
	{"ALPR", 4, 4468},
	{"COLORS", 6, 4469},
	{"FYH", 3, 4470},
	{"WARS", 4, 4471},
	{"CISCO", 5, 4472},
	{"LLHA", 4, 4473},
	{"YAQ", 3, 4474},
	{"TOUR", 4, 4475},
	{"LTIM", 4, 4476},
	{"ORDERING", 8, 4477},
	{"KEPT", 4, 4478},
	{"OBAM", 4, 4479},
	{"ALPHA", 5, 4480},
	{"NGSI", 4, 4481},
	{"APPLICATION", 11, 4482},
	{"TAPE", 4, 4483},
	{"PROMISE", 7, 4484},
	{"NECK", 4, 4485},
	{"ZRA", 3, 4486},
	{"EZF", 3, 4487},
	{"ONFR", 4, 4488},
	{"EBES", 4, 4489},
	{"EITS", 4, 4490},
	{"OYOU", 4, 4491},
	{"YKU", 3, 4492},
	{"FLOWER", 6, 4493},
	{"OWQ", 3, 4494},
	{"CERTIFICATION", 13, 4495},
	{"ESUR", 4, 4496},
	{"NVER", 4, 4497},
	{"HEPU", 4, 4498},
	{"HETW", 4, 4499},
	{"BOOKMARK", 8, 4500},
	{"ETOO", 4, 4501},
	{"ROPO", 4, 4502},
	{"AREI", 4, 4503},
	{"LLEC", 4, 4504},
	{"ELIV", 4, 4505},
	{"RTHO", 4, 4506},
	{"BUILDINGS", 9, 4507},
	{"LTHA", 4, 4508},
	{"SPECIALS", 8, 4509},
	{"ESSF", 4, 4510},
	{"OLON", 4, 4511},
	{"YWHE", 4, 4512},
	{"REMIND", 6, 4513},
	{"ATWO", 4, 4514},
	{"MEDICINE", 8, 4515},
	{"AWARE", 5, 4516},
	{"NEIGHBOR", 8, 4517},
	{"OXV", 3, 4518},
	{"PHOTO", 5, 4519},
	{"DISNEY", 6, 4520},
	{"RDAN", 4, 4521},
	{"TSCO", 4, 4522},
	{"DVAN", 4, 4523},
	{"AREM", 4, 4524},
	{"BATTERIES", 9, 4525},
	{"ADOBE", 5, 4526},
	{"USEI", 4, 4527},
	{"SMOKING", 7, 4528},
	{"TBUT", 4, 4529},
	{"ERYT", 4, 4530},
	{"IRAQI", 5, 4531},
	{"LADY", 4, 4532},
	{"IGNA", 4, 4533},
	{"BBC", 3, 4534},
	{"DEPEND", 6, 4535},
	{"TSFO", 4, 4536},
	{"BECOMES", 7, 4537},
	{"OFHE", 4, 4538},
	{"HEYR", 4, 4539},
	{"DRIVES", 6, 4540},
	{"RPLA", 4, 4541},
	{"JUSTICE", 7, 4542},
	{"ARMS", 4, 4543},
	{"ALABAMA", 7, 4544},
	{"HHIS", 4, 4545},
	{"UYM", 3, 4546},
	{"YNB", 3, 4547},
	{"TREES", 5, 4548},
	{"AVG", 3, 4549},
	{"TALL", 4, 4550},
	{"NSUR", 4, 4551},
	{"PAIR", 4, 4552},
	{"EDUCATIONAL", 11, 4553},
	{"POSITIONS", 9, 4554},
	{"FOOTBALL", 8, 4555},
	{"SUBSCRIPTION", 12, 4556},
	{"OFST", 4, 4557},
	{"LIP", 3, 4558},
	{"PGU", 3, 4559},
	{"UTAH", 4, 4560},
	{"HWAS", 4, 4561},
	{"GZH", 3, 4562},
	{"EUW", 3, 4563},
	{"ONSC", 4, 4564},
	{"RUW", 3, 4565},
	{"EPTI", 4, 4566},
	{"ROM", 3, 4567},
	{"INSTRUCTION", 11, 4568},
	{"ORPO", 4, 4569},
	{"EFUL", 4, 4570},
	{"CARRIED", 7, 4571},
	{"DAILY", 5, 4572},
	{"TICU", 4, 4573},
	{"DANGEROUS", 9, 4574},
	{"EDAB", 4, 4575},
	{"ERCH", 4, 4576},
	{"PANASONIC", 9, 4577},
	{"IALI", 4, 4578},
	{"WASE", 4, 4579},
	{"PERMALINK", 9, 4580},
	{"EASTERN", 7, 4581},
	{"GAMBLING", 8, 4582},
	{"EFRE", 4, 4583},
	{"HIRE", 4, 4584},
	{"FAIR", 4, 4585},
	{"MILLER", 6, 4586},
	{"RYTO", 4, 4587},
	{"OFWH", 4, 4588},
	{"OUTDOORS", 8, 4589},
	{"AYSA", 4, 4590},
	{"CAUSED", 6, 4591},
	{"DMOR", 4, 4592},
	{"WRITING", 7, 4593},
	{"LUXURY", 6, 4594},
	{"BABES", 5, 4595},
	{"FRAMES", 6, 4596},
	{"VIAGRA", 6, 4597},
	{"YOUA", 4, 4598},
	{"UPQ", 3, 4599},
	{"USTH", 4, 4600},
	{"IMPORTANCE", 10, 4601},
	{"ONGW", 4, 4602},
	{"SUPPLY", 6, 4603},
	{"DEVICE", 6, 4604},
	{"PLIC", 4, 4605},
	{"RGER", 4, 4606},
	{"TZP", 3, 4607},
	{"MALE", 4, 4608},
	{"ETOU", 4, 4609},
	{"PRINTED", 7, 4610},
	{"SEDB", 4, 4611},
	{"HIMT", 4, 4612},
	{"ECID", 4, 4613},
	{"ACTOR", 5, 4614},
	{"EASU", 4, 4615},
	{"ULTU", 4, 4616},
	{"EASIER", 6, 4617},
	{"FULLY", 5, 4618},
	{"SRC", 3, 4619},
	{"OFAR", 4, 4620},
	{"EXCHANGE", 8, 4621},
	{"TRADEMARK", 9, 4622},
	{"PRINTERS", 8, 4623},
	{"FAQS", 4, 4624},
	{"SWOU", 4, 4625},
	{"ADDING", 6, 4626},
	{"KENTUCKY", 8, 4627},
	{"SHUT", 4, 4628},
	{"STUDIO", 6, 4629},
	{"ERIC", 4, 4630},
	{"EXPRESSION", 10, 4631},
	{"CIRCLE", 6, 4632},
	{"TAYLOR", 6, 4633},
	{"TRACKBACK", 9, 4634},
	{"NDSI", 4, 4635},
	{"PRINTS", 6, 4636},
	{"SALT", 4, 4637},
	{"ADOF", 4, 4638},
	{"REVISED", 7, 4639},
	{"NTOR", 4, 4640},
	{"EDBE", 4, 4641},
	{"BREATH", 6, 4642},
	{"AMERICANS", 9, 4643},
	{"OPTICAL", 7, 4644},
	{"TSOM", 4, 4645},
	{"BOTTOM", 6, 4646},
	{"OWOR", 4, 4647},
	{"PROGRESS", 8, 4648},
	{"FAMOUS", 6, 4649},
	{"RSIO", 4, 4650},
	{"ZFO", 3, 4651},
	{"NYTH", 4, 4652},
	{"TWHI", 4, 4653},
	{"OPME", 4, 4654},
	{"PLATE", 5, 4655},
	{"SUITES", 6, 4656},
	{"NGHA", 4, 4657},
	{"PLASTIC", 7, 4658},
	{"TOAC", 4, 4659},
	{"OBTAIN", 6, 4660},
	{"ABUSE", 5, 4661},
	{"VICTORIA", 8, 4662},
	{"ONME", 4, 4663},
	{"FAMILIAR", 8, 4664},
	{"BIRTH", 5, 4665},
	{"HECE", 4, 4666},
	{"OFES", 4, 4667},
	{"SERIAL", 6, 4668},
	{"REVISION", 8, 4669},
	{"BROADBAND", 9, 4670},
	{"PDA", 3, 4671},
	{"CHICKEN", 7, 4672},
	{"SJUS", 4, 4673},
	{"THEATER", 7, 4674},
	{"DDLE", 4, 4675},
	{"DSL", 3, 4676},
	{"ILET", 4, 4677},
	{"HATR", 4, 4678},
	{"WEBMASTER", 9, 4679},
	{"UTHI", 4, 4680},
	{"COPIES", 6, 4681},
	{"TEACHING", 8, 4682},
	{"TUNI", 4, 4683},
	{"ZUM", 3, 4684},
	{"NCHI", 4, 4685},
	{"ZWE", 3, 4686},
	{"COLLEAGUE", 9, 4687},
	{"CLIMB", 5, 4688},
	{"SEEING", 6, 4689},
	{"ITHC", 4, 4690},
	{"CLEAN", 5, 4691},
	{"DOMESTIC", 8, 4692},
	{"DIFF", 4, 4693},
	{"ISLAND", 6, 4694},
	{"SUGAR", 5, 4695},
	{"LOPM", 4, 4696},
	{"BASS", 4, 4697},
	{"RWAR", 4, 4698},
	{"OKAY", 4, 4699},
	{"LIY", 3, 4700},
	{"STBE", 4, 4701},
	{"DKY", 3, 4702},
	{"ASDE", 4, 4703},
	{"ZPA", 3, 4704},
	{"OWIT", 4, 4705},
	{"PETS", 4, 4706},
	{"LICENSED", 8, 4707},
	{"ALIVE", 5, 4708},
	{"VWI", 3, 4709},
	{"ICHH", 4, 4710},
	{"TPER", 4, 4711},
	{"ORLANDO", 7, 4712},
	{"BEHI", 4, 4713},
	{"IDON", 4, 4714},
	{"RAIN", 4, 4715},
	{"ERPA", 4, 4716},
	{"ESRE", 4, 4717},
	{"LLCO", 4, 4718},
	{"DTOD", 4, 4719},
	{"MAINE", 5, 4720},
	{"SQL", 3, 4721},
	{"SPECS", 5, 4722},
	{"JURY", 4, 4723},
	{"RECORDED", 8, 4724},
	{"MEANING", 7, 4725},
	{"PRESIDENTIAL", 12, 4726},
	{"PIECES", 6, 4727},
	{"FINISHED", 8, 4728},
	{"LEAF", 4, 4729},
	{"PAINT", 5, 4730},
	{"TTRA", 4, 4731},
	{"PARKS", 5, 4732},
	{"LAWYERS", 7, 4733},
	{"SESSION", 7, 4734},
	{"POLL", 4, 4735},
	{"EXTRA", 5, 4736},
	{"SYDNEY", 6, 4737},
	{"DESIRE", 6, 4738},
	{"TRAIN", 5, 4739},
	{"UNCI", 4, 4740},
	{"NBUT", 4, 4741},
	{"DBEC", 4, 4742},
	{"SOFTWARE", 8, 4743},
	{"NGSE", 4, 4744},
	{"RUNS", 4, 4745},
	{"TRENDS", 6, 4746},
	{"YOUW", 4, 4747},
	{"INJURY", 6, 4748},
	{"UARE", 4, 4749},
	{"ONBE", 4, 4750},
	{"FUEL", 4, 4751},
	{"EEME", 4, 4752},
	{"ARMY", 4, 4753},
	{"NGUP", 4, 4754},
	{"TTEM", 4, 4755},
	{"READING", 7, 4756},
	{"NTAG", 4, 4757},
	{"TERD", 4, 4758},
	{"UZH", 3, 4759},
	{"SUPREME", 7, 4760},
	{"TICKET", 6, 4761},
	{"URBAN", 5, 4762},
	{"YNM", 3, 4763},
	{"PATTERNS", 8, 4764},
	{"NDID", 4, 4765},
	{"ATHLETE", 7, 4766},
	{"TTOB", 4, 4767},
	{"OOKA", 4, 4768},
	{"IETY", 4, 4769},
	{"BOXES", 5, 4770},
	{"ORMI", 4, 4771},
	{"LOUISIANA", 9, 4772},
	{"HEDU", 4, 4773},
	{"SWEET", 5, 4774},
	{"SREP", 4, 4775},
	{"HILLS", 5, 4776},
	{"ENRE", 4, 4777},
	{"JAVASCRIPT", 10, 4778},
	{"INSTRUMENT", 10, 4779},
	{"DRY", 3, 4780},
	{"OTHERWISE", 9, 4781},
	{"ADVISOR", 7, 4782},
	{"NORTHERN", 8, 4783},
	{"NDDI", 4, 4784},
	{"LESO", 4, 4785},
	{"UTHA", 4, 4786},
	{"HEDT", 4, 4787},
	{"WILSON", 6, 4788},
	{"COMPLEX", 7, 4789},
	{"LOTS", 4, 4790},
	{"STRANGE", 7, 4791},
	{"EXPLORE", 7, 4792},
	{"RUSSIAN", 7, 4793},
	{"KIY", 3, 4794},
	{"EIMP", 4, 4795},
	{"OPPE", 4, 4796},
	{"EFEA", 4, 4797},
	{"OMMA", 4, 4798},
	{"ANSF", 4, 4799},
	{"CERTIFICATES", 12, 4800},
	{"OBJECTIVES", 10, 4801},
	{"NTWA", 4, 4802},
	{"SCIENTIFIC", 10, 4803},
	{"STATIONS", 8, 4804},
	{"EOPE", 4, 4805},
	{"EMOC", 4, 4806},
	{"MAP", 3, 4807},
	{"ERIG", 4, 4808},
	{"SUGGESTED", 9, 4809},
	{"GPS", 3, 4810},
	{"OKV", 3, 4811},
	{"MENTAL", 6, 4812},
	{"REMAINS", 7, 4813},
	{"UENC", 4, 4814},
	{"ACC", 3, 4815},
	{"TBEC", 4, 4816},
	{"CORPORATE", 9, 4817},
	{"TZC", 3, 4818},
	{"OTED", 4, 4819},
	{"ENGINE", 6, 4820},
	{"TZM", 3, 4821},
	{"BJEC", 4, 4822},
	{"FIRMS", 5, 4823},
	{"POCKET", 6, 4824},
	{"IGAT", 4, 4825},
	{"IVEI", 4, 4826},
	{"PLANET", 6, 4827},
	{"EURO", 4, 4828},
	{"ISWA", 4, 4829},
	{"ONCA", 4, 4830},
	{"STRUCTURES", 10, 4831},
	{"INTEND", 6, 4832},
	{"GENERIC", 7, 4833},
	{"ENCYCLOPEDIA", 12, 4834},
	{"HISY", 4, 4835},
	{"IKW", 3, 4836},
	{"USAGE", 5, 4837},
	{"INCREASINGLY", 12, 4838},
	{"SOMEWHERE", 9, 4839},
	{"CHARTS", 6, 4840},
	{"ITYS", 4, 4841},
	{"NDFI", 4, 4842},
	{"CENSUS", 6, 4843},
	{"EVIC", 4, 4844},
	{"NTBE", 4, 4845},
	{"INTERRACIAL", 11, 4846},
	{"EGOT", 4, 4847},
	{"ATEG", 4, 4848},
	{"DESK", 4, 4849},
	{"DEOF", 4, 4850},
	{"MOM", 3, 4851},
	{"ITHP", 4, 4852},
	{"TEDH", 4, 4853},
	{"YNW", 3, 4854},
	{"DICK", 4, 4855},
	{"SUPPLIERS", 9, 4856},
	{"NNEC", 4, 4857},
	{"COMPACT", 7, 4858},
	{"EXPAND", 6, 4859},
	{"LIGHTS", 6, 4860},
	{"RCHE", 4, 4861},
	{"TRACKING", 8, 4862},
	{"DISAPPEAR", 9, 4863},
	{"OYG", 3, 4864},
	{"KEEPING", 7, 4865},
	{"PTED", 4, 4866},
	{"GFRO", 4, 4867},
	{"EMPTY", 5, 4868},
	{"DINC", 4, 4869},
	{"ISCU", 4, 4870},
	{"POOL", 4, 4871},
	{"ERAR", 4, 4872},
	{"SEQU", 4, 4873},
	{"METAL", 5, 4874},
	{"CONSEQUENCE", 11, 4875},
	{"MATCHES", 7, 4876},
	{"ACCORDANCE", 10, 4877},
	{"IOND", 4, 4878},
	{"UPTH", 4, 4879},
	{"EPTE", 4, 4880},
	{"WIDTH", 5, 4881},
	{"ENGINES", 7, 4882},
	{"TTOM", 4, 4883},
	{"RESPECT", 7, 4884},
	{"AIDH", 4, 4885},
	{"BASICALLY", 9, 4886},
	{"DISCUSSED", 9, 4887},
	{"STEPHEN", 7, 4888},
	{"DANGER", 6, 4889},
	{"ELIZABETH", 9, 4890},
	{"IANC", 4, 4891},
	{"NCEW", 4, 4892},
	{"FOURTH", 6, 4893},
	{"LUNCH", 5, 4894},
	{"RESERVATIONS", 12, 4895},
	{"BYQ", 3, 4896},
	{"YZO", 3, 4897},
	{"PLAYSTATION", 11, 4898},
	{"REGIONAL", 8, 4899},
	{"ANNOTATION", 10, 4900},
	{"MINORITY", 8, 4901},
	{"FAVORITE", 8, 4902},
	{"COMMITMENT", 10, 4903},
	{"TSWI", 4, 4904},
	{"MOCR", 4, 4905},
	{"DIFFERENCES", 11, 4906},
	{"PITE", 4, 4907},
	{"TEMPERATURE", 11, 4908},
	{"SMALLER", 7, 4909},
	{"HEDR", 4, 4910},
	{"NEWEST", 6, 4911},
	{"NGMO", 4, 4912},
	{"VYP", 3, 4913},
	{"EDWH", 4, 4914},
	{"GNU", 3, 4915},
	{"HAPPENED", 8, 4916},
	{"RSWI", 4, 4917},
	{"EXPRESSED", 9, 4918},
	{"OVET", 4, 4919},
	{"NGWH", 4, 4920},
	{"EDNE", 4, 4921},
	{"ERCI", 4, 4922},
	{"JEFF", 4, 4923},
	{"SSER", 4, 4924},
	{"UMME", 4, 4925},
	{"ITUA", 4, 4926},
	{"CONCLUSION", 10, 4927},
	{"TRAIL", 5, 4928},
	{"UENT", 4, 4929},
	{"NGCA", 4, 4930},
	{"FARMER", 6, 4931},
	{"CISI", 4, 4932},
	{"PARAGRAPH", 9, 4933},
	{"ONPR", 4, 4934},
	{"VYH", 3, 4935},
	{"EZP", 3, 4936},
	{"ANWH", 4, 4937},
	{"PREDICT", 7, 4938},
	{"STRAIGHT", 8, 4939},
	{"HSCH", 4, 4940},
	{"DBUT", 4, 4941},
	{"SREL", 4, 4942},
	{"MANAGERS", 8, 4943},
	{"MODULES", 7, 4944},
	{"ADOPT", 5, 4945},
	{"SIGHT", 5, 4946},
	{"ERHI", 4, 4947},
	{"VARIABLE", 8, 4948},
	{"SWEDEN", 6, 4949},
	{"CONDUCTED", 9, 4950},
	{"VERSIONS", 8, 4951},
	{"CAREFULLY", 9, 4952},
	{"PROPOSAL", 8, 4953},
	{"HECU", 4, 4954},
	{"NDPA", 4, 4955},
	{"OFFT", 4, 4956},
	{"YHAS", 4, 4957},
	{"SHADOW", 6, 4958},
	{"KNOWS", 5, 4959},
	{"GOFT", 4, 4960},
	{"MISSISSIPPI", 11, 4961},
	{"EMOTIONAL", 9, 4962},
	{"YCOU", 4, 4963},
	{"IKEL", 4, 4964},
	{"BACKUP", 6, 4965},
	{"REQUESTED", 9, 4966},
	{"CITIZENS", 8, 4967},
	{"WORKS", 5, 4968},
	{"OUTCOME", 7, 4969},
	{"CONNECTICUT", 11, 4970},
	{"DPER", 4, 4971},
	{"SOUL", 4, 4972},
	{"PERSONALS", 9, 4973},
	{"EKJ", 3, 4974},
	{"HOLDING", 7, 4975},
	{"HEMU", 4, 4976},
	{"COUNTY", 6, 4977},
	{"GREATEST", 8, 4978},
	{"KEVIN", 5, 4979},
	{"ANALYST", 7, 4980},
	{"ULLY", 4, 4981},
	{"YUC", 3, 4982},
	{"OMQ", 3, 4983},
	{"SUPPORTING", 10, 4984},
	{"UTUR", 4, 4985},
	{"ETHNIC", 6, 4986},
	{"DAYT", 4, 4987},
	{"LSOA", 4, 4988},
	{"REPEAT", 6, 4989},
	{"ENEMY", 5, 4990},
	{"TYQ", 3, 4991},
	{"HATB", 4, 4992},
	{"ASSIGNED", 8, 4993},
	{"COLLECTIONS", 11, 4994},
	{"YRH", 3, 4995},
	{"AGES", 4, 4996},
	{"ROMH", 4, 4997},
	{"PLUG", 4, 4998},
	{"VVY", 3, 4999},
	{"VIRGIN", 6, 5000},
	{"THCA", 4, 5001},
	{"RAISED", 6, 5002},
	{"STORM", 5, 5003},
	{"ANGU", 4, 5004},
	{"PANEL", 5, 5005},
	{"DIRECTED", 8, 5006},
	{"URIT", 4, 5007},
	{"DEALERS", 7, 5008},
	{"CHEST", 5, 5009},
	{"SEARCHING", 9, 5010},
	{"SPORTING", 8, 5011},
	{"HELPING", 7, 5012},
	{"THEME", 5, 5013},
	{"DHAS", 4, 5014},
	{"EJR", 3, 5015},
	{"PERL", 4, 5016},
	{"REGULATION", 10, 5017},
	{"ELOC", 4, 5018},
	{"AFFECTED", 8, 5019},
	{"RFRO", 4, 5020},
	{"OFPR", 4, 5021},
	{"LIB", 3, 5022},
	{"SSOR", 4, 5023},
	{"E-MAIL", 6, 5024},
	{"ISPL", 4, 5025},
	{"ESOR", 4, 5026},
	{"YELLOW", 6, 5027},
	{"REVENUE", 7, 5028},
	{"RSHE", 4, 5029},
	{"IYU", 3, 5030},
	{"YWIL", 4, 5031},
	{"EXPENSES", 8, 5032},
	{"TOPL", 4, 5033},
	{"BLEF", 4, 5034},
	{"ERLA", 4, 5035},
	{"BLONDE", 6, 5036},
	{"INVESTOR", 8, 5037},
	{"RTOT", 4, 5038},
	{"FRUIT", 5, 5039},
	{"KEDT", 4, 5040},
	{"PROCEEDINGS", 11, 5041},
	{"NOVEL", 5, 5042},
	{"ENDT", 4, 5043},
	{"SURROUND", 8, 5044},
	{"FAVOURITE", 9, 5045},
	{"ORGANIZE", 8, 5046},
	{"RTRA", 4, 5047},
	{"UNION", 5, 5048},
	{"ANDERSON", 8, 5049},
	{"BREAST", 6, 5050},
	{"CHARACTERISTICS", 15, 5051},
	{"MARRIED", 7, 5052},
	{"DER", 3, 5053},
	{"NDTR", 4, 5054},
	{"LOAN", 4, 5055},
	{"NTWO", 4, 5056},
	{"EXPERIENCES", 11, 5057},
	{"ALBUMS", 6, 5058},
	{"CHEATS", 6, 5059},
	{"VERZEICHNIS", 11, 5060},
	{"DIFFICULTY", 10, 5061},
	{"CONTRACTS", 9, 5062},
	{"REWI", 4, 5063},
	{"GUESTS", 6, 5064},
	{"NGBE", 4, 5065},
	{"SURPRISE", 8, 5066},
	{"LSON", 4, 5067},
	{"OBEC", 4, 5068},
	{"HOSTED", 6, 5069},
	{"SOMEHOW", 7, 5070},
	{"LSIN", 4, 5071},
	{"AYEA", 4, 5072},
	{"DISEASES", 8, 5073},
	{"DEVELOPERS", 10, 5074},
	{"CONCLUDE", 8, 5075},
	{"TONY", 4, 5076},
	{"BALANCE", 7, 5077},
	{"NEVADA", 6, 5078},
	{"IMPOSSIBLE", 10, 5079},
	{"AMEO", 4, 5080},
	{"KITS", 4, 5081},
	{"THAILAND", 8, 5082},
	{"FYU", 3, 5083},
	{"DTOM", 4, 5084},
	{"VARIABLES", 9, 5085},
	{"GENERATE", 8, 5086},
	{"FTHA", 4, 5087},
	{"CONTINUES", 9, 5088},
	{"TRACKS", 6, 5089},
	{"ERSB", 4, 5090},
	{"ADVISORY", 8, 5091},
	{"CAM", 3, 5092},
	{"BEAR", 4, 5093},
	{"GENDER", 6, 5094},
	{"UNTA", 4, 5095},
	{"ECTT", 4, 5096},
	{"TEMPLATE", 8, 5097},
	{"PRINCE", 6, 5098},
	{"INVITE", 6, 5099},
	{"GRANTS", 6, 5100},
	{"ELYT", 4, 5101},
	{"EIRC", 4, 5102},
	{"ABLI", 4, 5103},
	{"SEWH", 4, 5104},
	{"RESPONSES", 9, 5105},
	{"ATLANTIC", 8, 5106},
	{"IMEN", 4, 5107},
	{"ASTW", 4, 5108},
	{"EDWARD", 6, 5109},
	{"CONNECT", 7, 5110},
	{"LARGELY", 7, 5111},
	{"EAMO", 4, 5112},
	{"COMPONENT", 9, 5113},
	{"ROFI", 4, 5114},
	{"PRIME", 5, 5115},
	{"RAM", 3, 5116},
	{"LEAVING", 7, 5117},
	{"APPLIANCES", 10, 5118},
	{"MATT", 4, 5119},
	{"IONM", 4, 5120},
	{"DWOR", 4, 5121},
	{"SIGNIFICANTLY", 13, 5122},
	{"SPEAKING", 8, 5123},
	{"INTERNAL", 8, 5124},
	{"PHOTOGRAPH", 10, 5125},
	{"CODE", 4, 5126},
	{"SPONSORS", 8, 5127},
	{"FOX", 3, 5128},
	{"UNLIMITED", 9, 5129},
	{"NLYT", 4, 5130},
	{"SETTING", 7, 5131},
	{"NGDO", 4, 5132},
	{"OTBA", 4, 5133},
	{"NDLA", 4, 5134},
	{"NINC", 4, 5135},
	{"ACKNOWLEDGE", 11, 5136},
	{"ADVICE", 6, 5137},
	{"SIZES", 5, 5138},
	{"HATY", 4, 5139},
	{"ENTERED", 7, 5140},
	{"IRAN", 4, 5141},
	{"AMEI", 4, 5142},
	{"KEYS", 4, 5143},
	{"THICK", 5, 5144},
	{"MUSCLE", 6, 5145},
	{"CHECKING", 8, 5146},
	{"COSTA", 5, 5147},
	{"NCTI", 4, 5148},
	{"ERLI", 4, 5149},
	{"EHEL", 4, 5150},
	{"BELGIUM", 7, 5151},
	{"PRINTABLE", 9, 5152},
	{"ACTS", 4, 5153},
	{"SFUL", 4, 5154},
	{"AREG", 4, 5155},
	{"TREND", 5, 5156},
	{"NIND", 4, 5157},
	{"MESH", 4, 5158},
	{"YCAN", 4, 5159},
	{"RING", 4, 5160},
	{"RREC", 4, 5161},
	{"NOWI", 4, 5162},
	{"ERWO", 4, 5163},
	{"BELONG", 6, 5164},
	{"CRAFTS", 6, 5165},
	{"CKAN", 4, 5166},
	{"ASAB", 4, 5167},
	{"LOCATE", 6, 5168},
	{"LLYW", 4, 5169},
	{"NGAG", 4, 5170},
	{"HARDCOVER", 9, 5171},
	{"OBSERVED", 8, 5172},
	{"CONTENT", 7, 5173},
	{"DEAN", 4, 5174},
	{"STRESS", 6, 5175},
	{"RSWE", 4, 5176},
	{"NOTION", 6, 5177},
	{"JAPANESE", 8, 5178},
	{"DANCE", 5, 5179},
	{"RIDG", 4, 5180},
	{"ANYMORE", 7, 5181},
	{"SETUP", 5, 5182},
	{"BOOKING", 7, 5183},
	{"PROFIT", 6, 5184},
	{"EAUT", 4, 5185},
	{"GLOSSARY", 8, 5186},
	{"TTHR", 4, 5187},
	{"XYA", 3, 5188},
	{"STYLES", 6, 5189},
	{"HEAM", 4, 5190},
	{"MUSEUM", 6, 5191},
	{"PWIT", 4, 5192},
	{"RECOMMEND", 9, 5193},
	{"EXPENSIVE", 9, 5194},
	{"DENVER", 6, 5195},
	{"UNIX", 4, 5196},
	{"NDOW", 4, 5197},
	{"PROPOSE", 7, 5198},
	{"FILLED", 6, 5199},
	{"ETOC", 4, 5200},
	{"ANOF", 4, 5201},
	{"CHANNELS", 8, 5202},
	{"PACKAGE", 7, 5203},
	{"THINKING", 8, 5204},
	{"ERICSSON", 8, 5205},
	{"TLAN", 4, 5206},
	{"NDOU", 4, 5207},
	{"APPENDIX", 8, 5208},
	{"CURRENTLY", 9, 5209},
	{"NEDB", 4, 5210},
	{"NOTIFY", 6, 5211},
	{"BLUES", 5, 5212},
	{"PUB", 3, 5213},
	{"SELECT", 6, 5214},
	{"EOFC", 4, 5215},
	{"GEME", 4, 5216},
	{"HAMPSHIRE", 9, 5217},
	{"CONTRAST", 8, 5218},
	{"BOTTLE", 6, 5219},
	{"CABLES", 6, 5220},
	{"HEARING", 7, 5221},
	{"MEAL", 4, 5222},
	{"OUGHT", 5, 5223},
	{"ASOF", 4, 5224},
	{"BLUETOOTH", 9, 5225},
	{"OFCA", 4, 5226},
	{"CONTROLLED", 10, 5227},
	{"ESAY", 4, 5228},
	{"SOFP", 4, 5229},
	{"HEKI", 4, 5230},
	{"BRIDGE", 6, 5231},
	{"DENTAL", 6, 5232},
	{"KILLED", 6, 5233},
	{"VISITOR", 7, 5234},
	{"SHIRT", 5, 5235},
	{"ERFI", 4, 5236},
	{"ANGRY", 5, 5237},
	{"PLEO", 4, 5238},
	{"EVIO", 4, 5239},
	{"NTOW", 4, 5240},
	{"APIT", 4, 5241},
	{"NYOF", 4, 5242},
	{"UYN", 3, 5243},
	{"REPRESENTATIVES", 15, 5244},
	{"RWHE", 4, 5245},
	{"YSHO", 4, 5246},
	{"UNIQUE", 6, 5247},
	{"RDSA", 4, 5248},
	{"EDPR", 4, 5249},
	{"STARTS", 6, 5250},
	{"CAUSES", 6, 5251},
	{"RKER", 4, 5252},
	{"ARKANSAS", 8, 5253},
	{"NGBA", 4, 5254},
	{"YHAD", 4, 5255},
	{"ZMO", 3, 5256},
	{"LEISURE", 7, 5257},
	{"ATTRACTIONS", 11, 5258},
	{"EALO", 4, 5259},
	{"LEARNED", 7, 5260},
	{"TRANSACTIONS", 12, 5261},
	{"STRUGGLE", 8, 5262},
	{"XGO", 3, 5263},
	{"EXPLORER", 8, 5264},
	{"DSON", 4, 5265},
	{"RSEA", 4, 5266},
	{"EARTH", 5, 5267},
	{"ATTACHED", 8, 5268},
	{"GHTB", 4, 5269},
	{"OPENED", 6, 5270},
	{"CASH", 4, 5271},
	{"ENSURE", 6, 5272},
	{"OFPE", 4, 5273},
	{"LINK", 4, 5274},
	{"WAKE", 4, 5275},
	{"SHIFT", 5, 5276},
	{"ACTUAL", 6, 5277},
	{"AUTHORIZED", 10, 5278},
	{"EINV", 4, 5279},
	{"NIFI", 4, 5280},
	{"UPCOMING", 8, 5281},
	{"BRITAIN", 7, 5282},
	{"TRAFFIC", 7, 5283},
	{"SCORES", 6, 5284},
	{"CKOF", 4, 5285},
	{"FINANCING", 9, 5286},
	{"EHOL", 4, 5287},
	{"HEFU", 4, 5288},
	{"OMAT", 4, 5289},
	{"GTHI", 4, 5290},
	{"ADOPTED", 7, 5291},
	{"WEBLOG", 6, 5292},
	{"CREW", 4, 5293},
	{"MARK", 4, 5294},
	{"SLIP", 4, 5295},
	{"UZO", 3, 5296},
	{"LINEAR", 6, 5297},
	{"AGOO", 4, 5298},
	{"BEARS", 5, 5299},
	{"JEAN", 4, 5300},
	{"EDITED", 6, 5301},
	{"CHWA", 4, 5302},
	{"VISA", 4, 5303},
	{"NCEN", 4, 5304},
	{"BROWN", 5, 5305},
	{"SILENCE", 7, 5306},
	{"LYFO", 4, 5307},
	{"LINKED", 6, 5308},
	{"ERER", 4, 5309},
	{"MPAI", 4, 5310},
	{"APPEARANCE", 10, 5311},
	{"DUE", 3, 5312},
	{"ITWI", 4, 5313},
	{"ESTM", 4, 5314},
	{"EBET", 4, 5315},
	{"PORTLAND", 8, 5316},
	{"INTERVIEWS", 10, 5317},
	{"NDIV", 4, 5318},
	{"CONCEPTS", 8, 5319},
	{"LDNO", 4, 5320},
	{"MPAR", 4, 5321},
	{"CAPACITY", 8, 5322},
	{"COMFORTABLE", 11, 5323},
	{"REGIME", 6, 5324},
	{"ONSF", 4, 5325},
	{"OMPO", 4, 5326},
	{"ERFR", 4, 5327},
	{"TICL", 4, 5328},
	{"PERCEPTION", 10, 5329},
	{"AZD", 3, 5330},
	{"IVIT", 4, 5331},
	{"FZA", 3, 5332},
	{"LESSONS", 7, 5333},
	{"MTHA", 4, 5334},
	{"BEAUTY", 6, 5335},
	{"DWHI", 4, 5336},
	{"ITIV", 4, 5337},
	{"OBVIOUS", 7, 5338},
	{"BEGINS", 6, 5339},
	{"QUALIFIED", 9, 5340},
	{"ZPR", 3, 5341},
	{"INTERVENTION", 12, 5342},
	{"CAPTURE", 7, 5343},
	{"ALERTS", 6, 5344},
	{"NSWI", 4, 5345},
	{"TREATED", 7, 5346},
	{"SNOW", 4, 5347},
	{"MYSQL", 5, 5348},
	{"SFOU", 4, 5349},
	{"CLASSIFIED", 10, 5350},
	{"ICEO", 4, 5351},
	{"RELATING", 8, 5352},
	{"VERW", 4, 5353},
	{"OUZ", 3, 5354},
	{"HEVE", 4, 5355},
	{"GOLF", 4, 5356},
	{"OFCH", 4, 5357},
	{"NDHO", 4, 5358},
	{"ACCIDENT", 8, 5359},
	{"UDIE", 4, 5360},
	{"BASKETBALL", 10, 5361},
	{"POSSIBLY", 8, 5362},
	{"PREFER", 6, 5363},
	{"LEWIS", 5, 5364},
	{"EEPI", 4, 5365},
	{"HOWARD", 6, 5366},
	{"GHSC", 4, 5367},
	{"OFFLINE", 7, 5368},
	{"SOIL", 4, 5369},
	{"LEAVES", 6, 5370},
	{"CONTRIBUTION", 12, 5371},
	{"OMTO", 4, 5372},
	{"AIRPORT", 7, 5373},
	{"CLEARANCE", 9, 5374},
	{"ENTD", 4, 5375},
	{"EORI", 4, 5376},
	{"DPRE", 4, 5377},
	{"CONNECTIONS", 11, 5378},
	{"CATHOLIC", 8, 5379},
	{"YOUH", 4, 5380},
	{"CONVERTER", 9, 5381},
	{"EENC", 4, 5382},
	{"LONG-TERM", 9, 5383},
	{"FILE", 4, 5384},
	{"NDWO", 4, 5385},
	{"NDPO", 4, 5386},
	{"SSIV", 4, 5387},
	{"ORGANISATION", 12, 5388},
	{"NDLI", 4, 5389},
	{"TENC", 4, 5390},
	{"APPRECIATE", 10, 5391},
	{"OREX", 4, 5392},
	{"BABE", 4, 5393},
	{"GOVERNOR", 8, 5394},
	{"CHECKS", 6, 5395},
	{"REACHED", 7, 5396},
	{"SAFARI", 6, 5397},
	{"SHEET", 5, 5398},
	{"INDICATED", 9, 5399},
	{"RGIN", 4, 5400},
	{"LYHA", 4, 5401},
	{"WNTO", 4, 5402},
	{"ROOT", 4, 5403},
	{"PERCENTAGE", 10, 5404},
	{"TONL", 4, 5405},
	{"LAUNCH", 6, 5406},
	{"CIFI", 4, 5407},
	{"HARDLY", 6, 5408},
	{"LEDB", 4, 5409},
	{"OMBI", 4, 5410},
	{"LEGS", 4, 5411},
	{"RWOR", 4, 5412},
	{"ACOU", 4, 5413},
	{"CHNO", 4, 5414},
	{"OFSE", 4, 5415},
	{"SECURITIES", 10, 5416},
	{"INGY", 4, 5417},
	{"LDNT", 4, 5418},
	{"ALLEN", 5, 5419},
	{"PDT", 3, 5420},
	{"USER", 4, 5421},
	{"ESTATE", 6, 5422},
	{"ENABLED", 7, 5423},
	{"MONTANA", 7, 5424},
	{"BOWL", 4, 5425},
	{"USZ", 3, 5426},
	{"ARER", 4, 5427},
	{"TESTED", 6, 5428},
	{"IDDL", 4, 5429},
	{"GUIDE", 5, 5430},
	{"MIX", 3, 5431},
	{"TOPIC", 5, 5432},
	{"IHAV", 4, 5433},
	{"SWITZERLAND", 11, 5434},
	{"BOUND", 5, 5435},
	{"PARAMETER", 9, 5436},
	{"UEK", 3, 5437},
	{"ADAPTER", 7, 5438},
	{"NODE", 4, 5439},
	{"CORRECT", 7, 5440},
	{"LVED", 4, 5441},
	{"NTWI", 4, 5442},
	{"DIMENSIONS", 10, 5443},
	{"RPER", 4, 5444},
	{"UBN", 3, 5445},
	{"TRULY", 5, 5446},
	{"WNAS", 4, 5447},
	{"LWIT", 4, 5448},
	{"MICRO", 5, 5449},
	{"EOFM", 4, 5450},
	{"DECLARE", 7, 5451},
	{"COLLEGES", 8, 5452},
	{"LAPTOPS", 7, 5453},
	{"ISLI", 4, 5454},
	{"TOOTH", 5, 5455},
	{"MILE", 4, 5456},
	{"DEFEND", 6, 5457},
	{"EBIG", 4, 5458},
	{"FREQUENTLY", 10, 5459},
	{"SHOWED", 6, 5460},
	{"CHALLENGES", 10, 5461},
	{"ILIN", 4, 5462},
	{"FTHO", 4, 5463},
	{"TTOR", 4, 5464},
	{"ADET", 4, 5465},
	{"EPOI", 4, 5466},
	{"EDITORS", 7, 5467},
	{"MENS", 4, 5468},
	{"ESTIMATE", 8, 5469},
	{"ZONE", 4, 5470},
	{"UXS", 3, 5471},
	{"LLSA", 4, 5472},
	{"THREADS", 7, 5473},
	{"OMEW", 4, 5474},
	{"TERV", 4, 5475},
	{"BROTHERS", 8, 5476},
	{"GCY", 3, 5477},
	{"PRESENTS", 8, 5478},
	{"TSWE", 4, 5479},
	{"SGOI", 4, 5480},
	{"REF", 3, 5481},
	{"CTLY", 4, 5482},
	{"RATING", 6, 5483},
	{"SUBMISSION", 10, 5484},
	{"DOLLS", 5, 5485},
	{"SLOW", 4, 5486},
	{"FUNNY", 5, 5487},
	{"ERFE", 4, 5488},
	{"ULTIMATELY", 10, 5489},
	{"BEDROOM", 7, 5490},
	{"NTIM", 4, 5491},
	{"NAVY", 4, 5492},
	{"AREB", 4, 5493},
	{"DEDB", 4, 5494},
	{"EBUI", 4, 5495},
	{"POLITICIAN", 10, 5496},
	{"REQUIREMENT", 11, 5497},
	{"HEBL", 4, 5498},
	{"LEWH", 4, 5499},
	{"HISG", 4, 5500},
	{"CRAZY", 5, 5501},
	{"CONSUMERS", 9, 5502},
	{"FFEN", 4, 5503},
	{"LIMITS", 6, 5504},
	{"EXTREMELY", 9, 5505},
	{"NKV", 3, 5506},
	{"PAIG", 4, 5507},
	{"MANCHESTER", 10, 5508},
	{"STEAL", 5, 5509},
	{"DTOG", 4, 5510},
	{"WEAPONS", 7, 5511},
	{"STLE", 4, 5512},
	{"NNEL", 4, 5513},
	{"EMTO", 4, 5514},
	{"AIGN", 4, 5515},
	{"MEAT", 4, 5516},
	{"UGGE", 4, 5517},
	{"IDHE", 4, 5518},
	{"NDLO", 4, 5519},
	{"ETAR", 4, 5520},
	{"WNER", 4, 5521},
	{"IGUR", 4, 5522},
	{"CONTRIBUTIONS", 13, 5523},
	{"HALL", 4, 5524},
	{"ENGLISH", 7, 5525},
	{"STME", 4, 5526},
	{"EDEP", 4, 5527},
	{"ECLI", 4, 5528},
	{"NERG", 4, 5529},
	{"PEPPER", 6, 5530},
	{"NDRO", 4, 5531},
	{"CZECH", 5, 5532},
	{"ITCO", 4, 5533},
	{"SOFM", 4, 5534},
	{"RESULTING", 9, 5535},
	{"DUTY", 4, 5536},
	{"EEDI", 4, 5537},
	{"CAMBRIDGE", 9, 5538},
	{"JEWISH", 6, 5539},
	{"PILOT", 5, 5540},
	{"EADT", 4, 5541},
	{"OXD", 3, 5542},
	{"ERFA", 4, 5543},
	{"OREV", 4, 5544},
	{"STIR", 4, 5545},
	{"LANDSCAPE", 9, 5546},
	{"UGHO", 4, 5547},
	{"DAD", 3, 5548},
	{"INCREASES", 9, 5549},
	{"ULTRA", 5, 5550},
	{"IDAHO", 5, 5551},
	{"OWAN", 4, 5552},
	{"RLIE", 4, 5553},
	{"RHER", 4, 5554},
	{"PURSUE", 6, 5555},
	{"POTTER", 6, 5556},
	{"TOSU", 4, 5557},
	{"ILTH", 4, 5558},
	{"PLAYS", 5, 5559},
	{"ATYO", 4, 5560},
	{"SURGERY", 7, 5561},
	{"INVESTIGATE", 11, 5562},
	{"BULLETIN", 8, 5563},
	{"GEDT", 4, 5564},
	{"FACULTY", 7, 5565},
	{"NEITHER", 7, 5566},
	{"GERMAN", 6, 5567},
	{"SLEA", 4, 5568},
	{"EYQ", 3, 5569},
	{"KICK", 4, 5570},
	{"INDICATES", 9, 5571},
	{"ULDS", 4, 5572},
	{"MIRROR", 6, 5573},
	{"ZYN", 3, 5574},
	{"ZYT", 3, 5575},
	{"YJR", 3, 5576},
	{"OXFORD", 6, 5577},
	{"ADAM", 4, 5578},
	{"STFO", 4, 5579},
	{"ARIT", 4, 5580},
	{"AINL", 4, 5581},
	{"USTT", 4, 5582},
	{"EPINIONS", 8, 5583},
	{"COMMITTED", 9, 5584},
	{"ITWO", 4, 5585},
	{"COMBINATION", 11, 5586},
	{"AFFORDABLE", 10, 5587},
	{"FRAME", 5, 5588},
	{"TPAR", 4, 5589},
	{"MANNER", 6, 5590},
	{"MPLI", 4, 5591},
	{"WARN", 4, 5592},
	{"DATABASES", 9, 5593},
	{"IFFI", 4, 5594},
	{"OFDE", 4, 5595},
	{"YRY", 3, 5596},
	{"UVO", 3, 5597},
	{"OBAB", 4, 5598},
	{"RALA", 4, 5599},
	{"RSEL", 4, 5600},
	{"PSP", 3, 5601},
	{"EQUAL", 5, 5602},
	{"BESIDE", 6, 5603},
	{"ISFO", 4, 5604},
	{"PLANNED", 7, 5605},
	{"WATCHING", 8, 5606},
	{"OURSELVES", 9, 5607},
	{"LODGE", 5, 5608},
	{"MESSENGER", 9, 5609},
	{"HOWI", 4, 5610},
	{"SVER", 4, 5611},
	{"YBUT", 4, 5612},
	{"DISCOUNTS", 9, 5613},
	{"ITYC", 4, 5614},
	{"OVB", 3, 5615},
	{"STERLING", 8, 5616},
	{"SESSIONS", 8, 5617},
	{"RPRE", 4, 5618},
	{"NDME", 4, 5619},
	{"STWO", 4, 5620},
	{"KERNEL", 6, 5621},
	{"OMOT", 4, 5622},
	{"BOND", 4, 5623},
	{"GOLDEN", 6, 5624},
	{"BOOBS", 5, 5625},
	{"IONR", 4, 5626},
	{"OPPOSITION", 10, 5627},
	{"STOCKS", 6, 5628},
	{"BUYERS", 6, 5629},
	{"DMAR", 4, 5630},
	{"ETED", 4, 5631},
	{"JOURNALS", 8, 5632},
	{"TEAR", 4, 5633},
	{"ANCIENT", 7, 5634},
	{"CATALOGUE", 9, 5635},
	{"ANUA", 4, 5636},
	{"NGSH", 4, 5637},
	{"ICHT", 4, 5638},
	{"BLAME", 5, 5639},
	{"JENNIFER", 8, 5640},
	{"OFMO", 4, 5641},
	{"ORAR", 4, 5642},
	{"ERAB", 4, 5643},
	{"ANTONIO", 7, 5644},
	{"CONSERVATIVE", 12, 5645},
	{"CHARGED", 7, 5646},
	{"ELIMINATE", 9, 5647},
	{"DIVISION", 8, 5648},
	{"UGHA", 4, 5649},
	{"LEAGUE", 6, 5650},
	{"LWAS", 4, 5651},
	{"TEDP", 4, 5652},
	{"TAIWAN", 6, 5653},
	{"ORTT", 4, 5654},
	{"INPR", 4, 5655},
	{"UND", 3, 5656},
	{"NTEL", 4, 5657},
	{"CHOSEN", 6, 5658},
	{"ILLN", 4, 5659},
	{"DEMO", 4, 5660},
	{"TKNO", 4, 5661},
	{"GREECE", 6, 5662},
	{"SWISS", 5, 5663},
	{"TYPICAL", 7, 5664},
	{"SARAH", 5, 5665},
	{"ENFO", 4, 5666},
	{"EIRF", 4, 5667},
	{"HEQU", 4, 5668},
	{"CLARK", 5, 5669},
	{"IVEP", 4, 5670},
	{"LABOUR", 6, 5671},
	{"CHAIN", 5, 5672},
	{"URNI", 4, 5673},
	{"PRODUCER", 8, 5674},
	{"TERMINAL", 8, 5675},
	{"ANRE", 4, 5676},
	{"LLYC", 4, 5677},
	{"RZY", 3, 5678},
	{"YNY", 3, 5679},
	{"PUBLISHERS", 10, 5680},
	{"ORYA", 4, 5681},
	{"NIGHTS", 6, 5682},
	{"RDIS", 4, 5683},
	{"EFIL", 4, 5684},
	{"CARIBBEAN", 9, 5685},
	{"MBIN", 4, 5686},
	{"RSCO", 4, 5687},
	{"MOTION", 6, 5688},
	{"BRANCH", 6, 5689},
	{"AMEW", 4, 5690},
	{"EDAF", 4, 5691},
	{"USTB", 4, 5692},
	{"LENGTH", 6, 5693},
	{"CHARACTERISTIC", 14, 5694},
	{"RELY", 4, 5695},
	{"TOFH", 4, 5696},
	{"EXPECTATION", 11, 5697},
	{"TSEL", 4, 5698},
	{"EXCEPT", 6, 5699},
	{"EUND", 4, 5700},
	{"TUAT", 4, 5701},
	{"NEBRASKA", 8, 5702},
	{"FOODS", 5, 5703},
	{"GOURMET", 7, 5704},
	{"APPEAL", 6, 5705},
	{"ERBU", 4, 5706},
	{"LLRE", 4, 5707},
	{"RABL", 4, 5708},
	{"NGUA", 4, 5709},
	{"ORLEANS", 7, 5710},
	{"NTHR", 4, 5711},
	{"NFL", 3, 5712},
	{"FORTH", 5, 5713},
	{"ERHO", 4, 5714},
	{"COVERAGE", 8, 5715},
	{"ITHD", 4, 5716},
	{"ROW", 3, 5717},
	{"YIB", 3, 5718},
	{"MULTIPLE", 8, 5719},
	{"DEBT", 4, 5720},
	{"EMID", 4, 5721},
	{"MEANWHILE", 9, 5722},
	{"SOLVE", 5, 5723},
	{"DNY", 3, 5724},
	{"RELIEF", 6, 5725},
	{"AVATAR", 6, 5726},
	{"GARY", 4, 5727},
	{"HEPI", 4, 5728},
	{"TRUST", 5, 5729},
	{"IVEO", 4, 5730},
	{"AGEM", 4, 5731},
	{"RSAI", 4, 5732},
	{"OMOR", 4, 5733},
	{"LSTO", 4, 5734},
	{"NZU", 3, 5735},
	{"HUNDREDS", 8, 5736},
	{"ROME", 4, 5737},
	{"ZUC", 3, 5738},
	{"LLAG", 4, 5739},
	{"LINCOLN", 7, 5740},
	{"ZLO", 3, 5741},
	{"HELPED", 6, 5742},
	{"OCEAN", 5, 5743},
	{"PREMIER", 7, 5744},
	{"INDUSTRIAL", 10, 5745},
	{"GRAY", 4, 5746},
	{"DBEA", 4, 5747},
	{"NEXP", 4, 5748},
	{"EFFO", 4, 5749},
	{"RLEA", 4, 5750},
	{"OUSI", 4, 5751},
	{"PURCHASED", 9, 5752},
	{"AMEM", 4, 5753},
	{"NURSE", 5, 5754},
	{"AIDS", 4, 5755},
	{"NGRA", 4, 5756},
	{"SMART", 5, 5757},
	{"VEGETABLE", 9, 5758},
	{"ESLI", 4, 5759},
	{"FIX", 3, 5760},
	{"BEER", 4, 5761},
	{"VISITING", 8, 5762},
	{"YATT", 4, 5763},
	{"OUPL", 4, 5764},
	{"PERFORMING", 10, 5765},
	{"XHU", 3, 5766},
	{"CONFIRM", 7, 5767},
	{"ODZ", 3, 5768},
	{"KEYBOARD", 8, 5769},
	{"HEWH", 4, 5770},
	{"JUDGMENT", 8, 5771},
	{"UMY", 3, 5772},
	{"POUR", 4, 5773},
	{"CONTEMPORARY", 12, 5774},
	{"LSTH", 4, 5775},
	{"COLLECTED", 9, 5776},
	{"BANDS", 5, 5777},
	{"NSCO", 4, 5778},
	{"FFTH", 4, 5779},
	{"UTWH", 4, 5780},
	{"LKIN", 4, 5781},
	{"EBOO", 4, 5782},
	{"MILLIONS", 8, 5783},
	{"UYG", 3, 5784},
	{"NDNE", 4, 5785},
	{"ATEW", 4, 5786},
	{"AUDIT", 5, 5787},
	{"ASSESS", 6, 5788},
	{"WINNER", 6, 5789},
	{"CEFO", 4, 5790},
	{"IGGE", 4, 5791},
	{"CLOUD", 5, 5792},
	{"GUINEA", 6, 5793},
	{"FINDINGS", 8, 5794},
	{"ATTRACT", 7, 5795},
	{"KEQ", 3, 5796},
	{"ITHF", 4, 5797},
	{"CURRICULUM", 10, 5798},
	{"ICET", 4, 5799},
	{"ELOS", 4, 5800},
	{"FEATURING", 9, 5801},
	{"YSTH", 4, 5802},
	{"RRIV", 4, 5803},
	{"TZB", 3, 5804},
	{"CLICKING", 8, 5805},
	{"TANK", 4, 5806},
	{"LLIS", 4, 5807},
	{"MINISTER", 8, 5808},
	{"NWIL", 4, 5809},
	{"OMPU", 4, 5810},
	{"SCHEDULED", 9, 5811},
	{"INTERACTION", 11, 5812},
	{"ERSM", 4, 5813},
	{"POLLS", 5, 5814},
	{"USED", 4, 5815},
	{"SECRET", 6, 5816},
	{"MISC", 4, 5817},
	{"CALCULATOR", 10, 5818},
	{"NTOB", 4, 5819},
	{"SECTOR", 6, 5820},
	{"COMPLAIN", 8, 5821},
	{"PLEASURE", 8, 5822},
	{"OFFO", 4, 5823},
	{"NGLY", 4, 5824},
	{"ALAN", 4, 5825},
	{"SEED", 4, 5826},
	{"HATF", 4, 5827},
	{"SENDING", 7, 5828},
	{"ENTIRELY", 8, 5829},
	{"NGAC", 4, 5830},
	{"JASON", 5, 5831},
	{"WASTE", 5, 5832},
	{"TOPU", 4, 5833},
	{"SEPARATE", 8, 5834},
	{"ADUA", 4, 5835},
	{"GICA", 4, 5836},
	{"HOLDEM", 6, 5837},
	{"ASIDE", 5, 5838},
	{"HATL", 4, 5839},
	{"SCOV", 4, 5840},
	{"BENEATH", 7, 5841},
	{"STWE", 4, 5842},
	{"AFFORD", 6, 5843},
	{"OVERALL", 7, 5844},
	{"ETOG", 4, 5845},
	{"ESSENTIAL", 9, 5846},
	{"WING", 4, 5847},
	{"XSY", 3, 5848},
	{"INITIAL", 7, 5849},
	{"SACT", 4, 5850},
	{"STRETCH", 7, 5851},
	{"NDPE", 4, 5852},
	{"CITE", 4, 5853},
	{"ORSH", 4, 5854},
	{"KYG", 3, 5855},
	{"GONT", 4, 5856},
	{"VOLUME", 6, 5857},
	{"NSPO", 4, 5858},
	{"INCREASED", 9, 5859},
	{"NDOR", 4, 5860},
	{"RARE", 4, 5861},
	{"IMPROVEMENT", 11, 5862},
	{"OWNI", 4, 5863},
	{"ANYWHERE", 8, 5864},
	{"VANCOUVER", 9, 5865},
	{"CONFIDENCE", 10, 5866},
	{"NVEN", 4, 5867},
	{"EFAM", 4, 5868},
	{"SEEMED", 6, 5869},
	{"TZL", 3, 5870},
	{"EMPHASIZE", 9, 5871},
	{"ZVO", 3, 5872},
	{"ABORTION", 8, 5873},
	{"RESOLUTION", 10, 5874},
	{"WITNESS", 7, 5875},
	{"EREO", 4, 5876},
	{"TOWI", 4, 5877},
	{"GNY", 3, 5878},
	{"EMPLOY", 6, 5879},
	{"SPYWARE", 7, 5880},
	{"PACKAGING", 9, 5881},
	{"INDT", 4, 5882},
	{"JOSE", 4, 5883},
	{"DISH", 4, 5884},
	{"EKNO", 4, 5885},
	{"MASTER", 6, 5886},
	{"AZL", 3, 5887},
	{"SPECIFICALLY", 12, 5888},
	{"JANE", 4, 5889},
	{"HEFL", 4, 5890},
	{"TSAL", 4, 5891},
	{"SOFH", 4, 5892},
	{"PAKISTAN", 8, 5893},
	{"SURPRISED", 9, 5894},
	{"NKTH", 4, 5895},
	{"CONSULTATION", 12, 5896},
	{"NGPO", 4, 5897},
	{"ANUN", 4, 5898},
	{"ARYS", 4, 5899},
	{"DSHO", 4, 5900},
	{"SOMEWHAT", 8, 5901},
	{"LEDG", 4, 5902},
	{"FINDER", 6, 5903},
	{"YMOR", 4, 5904},
	{"LBUM", 4, 5905},
	{"PERIODS", 7, 5906},
	{"NJUR", 4, 5907},
	{"NDEC", 4, 5908},
	{"TASKS", 5, 5909},
	{"RDTO", 4, 5910},
	{"XBI", 3, 5911},
	{"YTOT", 4, 5912},
	{"ATTACKS", 7, 5913},
	{"KIM", 3, 5914},
	{"WALLPAPER", 9, 5915},
	{"MERCHANDISE", 11, 5916},
	{"ERBO", 4, 5917},
	{"TOTALLY", 7, 5918},
	{"CONST", 5, 5919},
	{"ANYW", 4, 5920},
	{"ESEV", 4, 5921},
	{"NDBA", 4, 5922},
	{"DOORS", 5, 5923},
	{"IEDA", 4, 5924},
	{"SYMPTOMS", 8, 5925},
	{"EHIM", 4, 5926},
	{"RESORTS", 7, 5927},
	{"TOTR", 4, 5928},
	{"LLYO", 4, 5929},
	{"BIGGEST", 7, 5930},
	{"TEMB", 4, 5931},
	{"CCUR", 4, 5932},
	{"SBAN", 4, 5933},
	{"RURAL", 5, 5934},
	{"THCE", 4, 5935},
	{"TERRIBLE", 8, 5936},
	{"ENAL", 4, 5937},
	{"MEMORIAL", 8, 5938},
	{"EABL", 4, 5939},
	{"DTWO", 4, 5940},
	{"BALTIMORE", 9, 5941},
	{"NCAN", 4, 5942},
	{"GATEWAY", 7, 5943},
	{"SFIN", 4, 5944},
	{"TERL", 4, 5945},
	{"GRANT", 5, 5946},
	{"TIRED", 5, 5947},
	{"CORE", 4, 5948},
	{"DONT", 4, 5949},
	{"ALUMNI", 6, 5950},
	{"OURP", 4, 5951},
	{"RUSH", 4, 5952},
	{"AYZ", 3, 5953},
	{"CANDIDATES", 10, 5954},
	{"CHARLOTTE", 9, 5955},
	{"ORDERED", 7, 5956},
	{"DOUBT", 5, 5957},
	{"BABL", 4, 5958},
	{"BARELY", 6, 5959},
	{"LIMITED", 7, 5960},
	{"HAPPENS", 7, 5961},
	{"ITYW", 4, 5962},
	{"PREFERENCES", 11, 5963},
	{"OFAS", 4, 5964},
	{"HCEN", 4, 5965},
	{"ONWE", 4, 5966},
	{"TOFS", 4, 5967},
	{"BUSY", 4, 5968},
	{"BRUCE", 5, 5969},
	{"TMOR", 4, 5970},
	{"OPPOSE", 6, 5971},
	{"FASHION", 7, 5972},
	{"OFOU", 4, 5973},
	{"OLDT", 4, 5974},
	{"UPLE", 4, 5975},
	{"THEMES", 6, 5976},
	{"POWERS", 6, 5977},
	{"GPRO", 4, 5978},
	{"WNTH", 4, 5979},
	{"STOG", 4, 5980},
	{"FLOW", 4, 5981},
	{"WTHA", 4, 5982},
	{"BEACH", 5, 5983},
	{"BITS", 4, 5984},
	{"HOUSEHOLD", 9, 5985},
	{"NDMI", 4, 5986},
	{"ATWI", 4, 5987},
	{"CREAM", 5, 5988},
	{"EXPERIMENT", 10, 5989},
	{"OUHA", 4, 5990},
	{"CLASSIFICATION", 14, 5991},
	{"FOCUSED", 7, 5992},
	{"EGYPT", 5, 5993},
	{"HOLLYWOOD", 9, 5994},
	{"CRIMINAL", 8, 5995},
	{"PITC", 4, 5996},
	{"SONC", 4, 5997},
	{"LICI", 4, 5998},
	{"BARGAIN", 7, 5999},
	{"WIKIPEDIA", 9, 6000},
	{"EARM", 4, 6001},
	{"OPEA", 4, 6002},
	{"OBET", 4, 6003},
	{"CELLULAR", 8, 6004},
	{"NORWAY", 6, 6005},
	{"CCOU", 4, 6006},
	{"OFSO", 4, 6007},
	{"VERMONT", 7, 6008},
	{"NDSP", 4, 6009},
	{"ROWI", 4, 6010},
	{"GHOU", 4, 6011},
	{"ANTR", 4, 6012},
	{"ASKING", 6, 6013},
	{"BLOCKS", 6, 6014},
	{"NEFI", 4, 6015},
	{"HEAU", 4, 6016},
	{"EANY", 4, 6017},
	{"ICKS", 4, 6018},
	{"CHEAP", 5, 6019},
	{"YPLA", 4, 6020},
	{"VESO", 4, 6021},
	{"SDON", 4, 6022},
	{"HERO", 4, 6023},
	{"DIVIDE", 6, 6024},
	{"NECESSARILY", 11, 6025},
	{"ONVI", 4, 6026},
	{"ORHE", 4, 6027},
	{"SERIOUSLY", 9, 6028},
	{"ENGT", 4, 6029},
	{"ROUTE", 5, 6030},
	{"BODIES", 6, 6031},
	{"TOWARDS", 7, 6032},
	{"PHOTOGRAPHS", 11, 6033},
	{"CUTTING", 7, 6034},
	{"WHEEL", 5, 6035},
	{"ERYS", 4, 6036},
	{"HNOL", 4, 6037},
	{"BOMB", 4, 6038},
	{"ARLE", 4, 6039},
	{"RWHI", 4, 6040},
	{"CABLE", 5, 6041},
	{"UTON", 4, 6042},
	{"SIMON", 5, 6043},
	{"RSHO", 4, 6044},
	{"WRITERS", 7, 6045},
	{"MARKS", 5, 6046},
	{"TYPICALLY", 9, 6047},
	{"YBEC", 4, 6048},
	{"TITW", 4, 6049},
	{"COPY", 4, 6050},
	{"LOVED", 5, 6051},
	{"ALLB", 4, 6052},
	{"NGRO", 4, 6053},
	{"FAVOURITES", 10, 6054},
	{"ERPO", 4, 6055},
	{"MAPPING", 7, 6056},
	{"LIBERAL", 7, 6057},
	{"FEWER", 5, 6058},
	{"OWHE", 4, 6059},
	{"BIRDS", 5, 6060},
	{"DEFINITELY", 10, 6061},
	{"REPRESENTS", 10, 6062},
	{"USEFUL", 6, 6063},
	{"CHAR", 4, 6064},
	{"USTE", 4, 6065},
	{"INDEXED", 7, 6066},
	{"UPPER", 5, 6067},
	{"REPRESENTATIVE", 14, 6068},
	{"ALLP", 4, 6069},
	{"TEDM", 4, 6070},
	{"PITTSBURGH", 10, 6071},
	{"PREFERRED", 9, 6072},
	{"ERPE", 4, 6073},
	{"SAVED", 5, 6074},
	{"NTIR", 4, 6075},
	{"THOL", 4, 6076},
	{"NTIF", 4, 6077},
	{"DVER", 4, 6078},
	{"PAYING", 6, 6079},
	{"LYAS", 4, 6080},
	{"SHOTS", 5, 6081},
	{"GRASS", 5, 6082},
	{"HILL", 4, 6083},
	{"EAMA", 4, 6084},
	{"EVERYWHERE", 10, 6085},
	{"TLIK", 4, 6086},
	{"MOORE", 5, 6087},
	{"NGDE", 4, 6088},
	{"LARL", 4, 6089},
	{"GAQ", 3, 6090},
	{"GRANTED", 7, 6091},
	{"MASS", 4, 6092},
	{"IMTO", 4, 6093},
	{"FISHING", 7, 6094},
	{"MERELY", 6, 6095},
	{"EDBA", 4, 6096},
	{"CHOICES", 7, 6097},
	{"INVEST", 6, 6098},
	{"OPENING", 7, 6099},
	{"DECLINE", 7, 6100},
	{"ACIN", 4, 6101},
	{"EVED", 4, 6102},
	{"LISTENING", 9, 6103},
	{"REGISTRY", 8, 6104},
	{"LSOS", 4, 6105},
	{"GTOB", 4, 6106},
	{"NOISE", 5, 6107},
	{"HENC", 4, 6108},
	{"ODQ", 3, 6109},
	{"GZO", 3, 6110},
	{"GATE", 4, 6111},
	{"OUTLOOK", 7, 6112},
	{"DENMARK", 7, 6113},
	{"ITSF", 4, 6114},
	{"ENGINEER", 8, 6115},
	{"EMPLOYED", 8, 6116},
	{"HEADER", 6, 6117},
	{"RTST", 4, 6118},
	{"LLEA", 4, 6119},
	{"YMEN", 4, 6120},
	{"LLEY", 4, 6121},
	{"FORMED", 6, 6122},
	{"OUQ", 3, 6123},
	{"ISRAELI", 7, 6124},
	{"RVAT", 4, 6125},
	{"NNED", 4, 6126},
	{"DTOW", 4, 6127},
	{"NDFR", 4, 6128},
	{"OMEI", 4, 6129},
	{"XGR", 3, 6130},
	{"APPO", 4, 6131},
	{"ZKI", 3, 6132},
	{"LEGISLATION", 11, 6133},
	{"EAVI", 4, 6134},
	{"QUE", 3, 6135},
	{"IPLE", 4, 6136},
	{"SHEETS", 6, 6137},
	{"PATRICK", 7, 6138},
	{"SECRETARY", 9, 6139},
	{"YDH", 3, 6140},
	{"AVEH", 4, 6141},
	{"AVOR", 4, 6142},
	{"PUERTO", 6, 6143},
	{"OREF", 4, 6144},
	{"JEW", 3, 6145},
	{"TYTH", 4, 6146},
	{"CONSOLIDATION", 13, 6147},
	{"CAREFUL", 7, 6148},
	{"ELAR", 4, 6149},
	{"DISPLAYS", 8, 6150},
	{"PLASMA", 6, 6151},
	{"INCIDENT", 8, 6152},
	{"APART", 5, 6153},
	{"DPAR", 4, 6154},
	{"ALLOWING", 8, 6155},
	{"EOFP", 4, 6156},
	{"USEH", 4, 6157},
	{"PROUD", 5, 6158},
	{"NARROW", 6, 6159},
	{"SSFU", 4, 6160},
	{"VOIP", 4, 6161},
	{"VAST", 4, 6162},
	{"AVED", 4, 6163},
	{"ECLO", 4, 6164},
	{"IXU", 3, 6165},
	{"OFMI", 4, 6166},
	{"MILK", 4, 6167},
	{"UGUS", 4, 6168},
	{"UARD", 4, 6169},
	{"MATCH", 5, 6170},
	{"ESBU", 4, 6171},
	{"DELAWARE", 8, 6172},
	{"BIDDING", 7, 6173},
	{"ACCUSE", 6, 6174},
	{"CONSULTANTS", 11, 6175},
	{"NPRE", 4, 6176},
	{"DWIL", 4, 6177},
	{"RISKS", 5, 6178},
	{"SBUR", 4, 6179},
	{"OWLE", 4, 6180},
	{"BANNER", 6, 6181},
	{"ASSOCIATION", 11, 6182},
	{"APPLICANT", 9, 6183},
	{"RCOU", 4, 6184},
	{"FIG", 3, 6185},
	{"BARBARA", 7, 6186},
	{"ZQU", 3, 6187},
	{"COUNTIES", 8, 6188},
	{"ORTR", 4, 6189},
	{"PORTS", 5, 6190},
	{"RIPT", 4, 6191},
	{"RTHR", 4, 6192},
	{"IMPLEMENTED", 11, 6193},
	{"ITHB", 4, 6194},
	{"LLYB", 4, 6195},
	{"DIRECTORIES", 11, 6196},
	{"EAFT", 4, 6197},
	{"EENG", 4, 6198},
	{"EXPLANATION", 11, 6199},
	{"PHYSICIAN", 9, 6200},
	{"RECOGNIZED", 10, 6201},
	{"RREL", 4, 6202},
	{"DREAMS", 6, 6203},
	{"BLOGGER", 7, 6204},
	{"CYU", 3, 6205},
	{"XECU", 4, 6206},
	{"LSOC", 4, 6207},
	{"IDUA", 4, 6208},
	{"NOTIFICATION", 12, 6209},
	{"AYQ", 3, 6210},
	{"LDIS", 4, 6211},
	{"SOLID", 5, 6212},
	{"LICENSING", 9, 6213},
	{"MEWH", 4, 6214},
	{"STANDS", 6, 6215},
	{"REJECT", 6, 6216},
	{"OOKE", 4, 6217},
	{"LLYD", 4, 6218},
	{"CHHA", 4, 6219},
	{"EPUT", 4, 6220},
	{"TLIN", 4, 6221},
	{"OCCURRED", 8, 6222},
	{"ADDITION", 8, 6223},
	{"TEXTBOOKS", 9, 6224},
	{"HAIRY", 5, 6225},
	{"TOFC", 4, 6226},
	{"IMMIGRANT", 9, 6227},
	{"CLEVELAND", 9, 6228},
	{"TOGR", 4, 6229},
	{"RTSA", 4, 6230},
	{"EPIN", 4, 6231},
	{"RRAN", 4, 6232},
	{"UCTU", 4, 6233},
	{"YWHI", 4, 6234},
	{"CREATIVE", 8, 6235},
	{"GUILTY", 6, 6236},
	{"TOWO", 4, 6237},
	{"TECHNICAL", 9, 6238},
	{"RONM", 4, 6239},
	{"PPOI", 4, 6240},
	{"RGED", 4, 6241},
	{"INVESTMENTS", 11, 6242},
	{"EAPO", 4, 6243},
	{"LATINA", 6, 6244},
	{"LEBR", 4, 6245},
	{"EXPOSE", 6, 6246},
	{"WHEELS", 6, 6247},
	{"HEEV", 4, 6248},
	{"ITHR", 4, 6249},
	{"NOMY", 4, 6250},
	{"UKK", 3, 6251},
	{"GHTW", 4, 6252},
	{"INWA", 4, 6253},
	{"DERW", 4, 6254},
	{"EELI", 4, 6255},
	{"TEMPLATES", 9, 6256},
	{"HEOF", 4, 6257},
	{"FORMATS", 7, 6258},
	{"NDAM", 4, 6259},
	{"MASSIVE", 7, 6260},
	{"ATFO", 4, 6261},
	{"DEPENDS", 7, 6262},
	{"BOOTS", 5, 6263},
	{"CAMPUS", 6, 6264},
	{"HOLDS", 5, 6265},
	{"ROUTER", 6, 6266},
	{"RDEN", 4, 6267},
	{"NDFA", 4, 6268},
	{"TSRE", 4, 6269},
	{"RBUT", 4, 6270},
	{"IREA", 4, 6271},
	{"ERSD", 4, 6272},
	{"EDITING", 7, 6273},
	{"POLAND", 6, 6274},
	{"SCUS", 4, 6275},
	{"FOLDER", 6, 6276},
	{"ISWE", 4, 6277},
	{"EARD", 4, 6278},
	{"WOMENS", 6, 6279},
	{"MEFO", 4, 6280},
	{"OBSERVATION", 11, 6281},
	{"DEFINITION", 10, 6282},
	{"ERWE", 4, 6283},
	{"NGBU", 4, 6284},
	{"COMPLETION", 10, 6285},
	{"UPLOAD", 6, 6286},
	{"ENORMOUS", 8, 6287},
	{"UNFORTUNATELY", 13, 6288},
	{"SCHOLAR", 7, 6289},
	{"TALENT", 6, 6290},
	{"UNIVERSITIES", 12, 6291},
	{"RZH", 3, 6292},
	{"HICA", 4, 6293},
	{"TSTR", 4, 6294},
	{"PLENTY", 6, 6295},
	{"ICHE", 4, 6296},
	{"NEIG", 4, 6297},
	{"VIDU", 4, 6298},
	{"ACQUIRE", 7, 6299},
	{"CKSO", 4, 6300},
	{"OTRE", 4, 6301},
	{"GAY", 3, 6302},
	{"REDW", 4, 6303},
	{"VIRTUALLY", 9, 6304},
	{"SUCCEED", 7, 6305},
	{"CELEBRATE", 9, 6306},
	{"SBEI", 4, 6307},
	{"CONTRACTORS", 11, 6308},
	{"CHEESE", 6, 6309},
	{"DBET", 4, 6310},
	{"TASTE", 5, 6311},
	{"MANW", 4, 6312},
	{"MILFHUNTER", 10, 6313},
	{"HEIGHT", 6, 6314},
	{"SHARP", 5, 6315},
	{"LDAN", 4, 6316},
	{"COURTS", 6, 6317},
	{"UNDR", 4, 6318},
	{"NWOR", 4, 6319},
	{"ARDW", 4, 6320},
	{"EDBU", 4, 6321},
	{"RDST", 4, 6322},
	{"NOTICES", 7, 6323},
	{"SUBSCRIPTIONS", 13, 6324},
	{"RTWO", 4, 6325},
	{"EPOP", 4, 6326},
	{"OFPO", 4, 6327},
	{"ANTL", 4, 6328},
	{"LLTO", 4, 6329},
	{"DETROIT", 7, 6330},
	{"ALEXANDER", 9, 6331},
	{"SCREAM", 6, 6332},
	{"CONVERTED", 9, 6333},
	{"METRO", 5, 6334},
	{"TOSHIBA", 7, 6335},
	{"ONDU", 4, 6336},
	{"ECOV", 4, 6337},
	{"APPROVE", 7, 6338},
	{"OSEW", 4, 6339},
	{"TEDC", 4, 6340},
	{"IMPROVEMENTS", 12, 6341},
	{"VISUAL", 6, 6342},
	{"URPR", 4, 6343},
	{"BIKE", 4, 6344},
	{"SPECIFICATION", 13, 6345},
	{"PEARL", 5, 6346},
	{"DIND", 4, 6347},
	{"NICK", 4, 6348},
	{"ACCESSORY", 9, 6349},
	{"DLEA", 4, 6350},
	{"ZDI", 3, 6351},
	{"QTY", 3, 6352},
	{"COMPETE", 7, 6353},
	{"EWAL", 4, 6354},
	{"HROW", 4, 6355},
	{"PROSECUTOR", 10, 6356},
	{"ILLEGAL", 7, 6357},
	{"ICIE", 4, 6358},
	{"IBIL", 4, 6359},
	{"ISOF", 4, 6360},
	{"MMED", 4, 6361},
	{"TSBE", 4, 6362},
	{"EXISTS", 6, 6363},
	{"SHOUT", 5, 6364},
	{"ORFO", 4, 6365},
	{"ARRANGEMENTS", 12, 6366},
	{"EZL", 3, 6367},
	{"CONFERENCES", 11, 6368},
	{"UNIPROTKB", 9, 6369},
	{"OFAM", 4, 6370},
	{"CLOSELY", 7, 6371},
	{"REGARDING", 9, 6372},
	{"INAM", 4, 6373},
	{"BIRMINGHAM", 10, 6374},
	{"RTTH", 4, 6375},
	{"DJUS", 4, 6376},
	{"NUAR", 4, 6377},
	{"ORRI", 4, 6378},
	{"LOWER", 5, 6379},
	{"PLUS", 4, 6380},
	{"FLASHING", 8, 6381},
	{"ALTERNATIVE", 11, 6382},
	{"ESCAPE", 6, 6383},
	{"CLIMATE", 7, 6384},
	{"TLET", 4, 6385},
	{"PARTICIPATION", 13, 6386},
	{"NSUM", 4, 6387},
	{"THCO", 4, 6388},
	{"HENU", 4, 6389},
	{"NNOU", 4, 6390},
	{"PERCEIVE", 8, 6391},
	{"ONSP", 4, 6392},
	{"SBET", 4, 6393},
	{"AIRLINE", 7, 6394},
	{"CAST", 4, 6395},
	{"RROW", 4, 6396},
	{"SENTENCE", 8, 6397},
	{"CIGARETTE", 9, 6398},
	{"SBEF", 4, 6399},
	{"TOEX", 4, 6400},
	{"KNOCK", 5, 6401},
	{"NGHO", 4, 6402},
	{"LYDI", 4, 6403},
	{"FHER", 4, 6404},
	{"SBRO", 4, 6405},
	{"SURVEYS", 7, 6406},
	{"SITTING", 7, 6407},
	{"RMAR", 4, 6408},
	{"PUTTING", 7, 6409},
	{"NDTE", 4, 6410},
	{"CONTROLLER", 10, 6411},
	{"NOTR", 4, 6412},
	{"COMMITTEES", 10, 6413},
	{"XBY", 3, 6414},
	{"REXA", 4, 6415},
	{"SNAM", 4, 6416},
	{"NGTE", 4, 6417},
	{"RESEARCHERS", 11, 6418},
	{"VIETNAM", 7, 6419},
	{"ECEM", 4, 6420},
	{"EWAT", 4, 6421},
	{"SPIRITUAL", 9, 6422},
	{"WRAP", 4, 6423},
	{"CASTLE", 6, 6424},
	{"GARDENS", 7, 6425},
	{"TIVA", 4, 6426},
	{"DREC", 4, 6427},
	{"MISSED", 6, 6428},
	{"OKJ", 3, 6429},
	{"MALAYSIA", 8, 6430},
	{"UNSUBSCRIBE", 11, 6431},
	{"HYSI", 4, 6432},
	{"CRITICISM", 9, 6433},
	{"ANTIQUE", 7, 6434},
	{"LABELS", 6, 6435},
	{"NGAP", 4, 6436},
	{"MOLECULAR", 9, 6437},
	{"ACTING", 6, 6438},
	{"PROPER", 6, 6439},
	{"OYED", 4, 6440},
	{"HEADS", 5, 6441},
	{"DLIN", 4, 6442},
	{"UTIV", 4, 6443},
	{"PRIMARILY", 9, 6444},
	{"STORED", 6, 6445},
	{"UNUSUAL", 7, 6446},
	{"OFLA", 4, 6447},
	{"VERC", 4, 6448},
	{"EAKI", 4, 6449},
	{"OMEB", 4, 6450},
	{"LOGOS", 5, 6451},
	{"TSPE", 4, 6452},
	{"ATTORNEYS", 9, 6453},
	{"YWOU", 4, 6454},
	{"MILFS", 5, 6455},
	{"ASSET", 5, 6456},
	{"DEPRESSION", 10, 6457},
	{"LHAV", 4, 6458},
	{"ANTIQUES", 8, 6459},
	{"CREATION", 8, 6460},
	{"RYAN", 4, 6461},
	{"RFAC", 4, 6462},
	{"NCEF", 4, 6463},
	{"CONVINCE", 8, 6464},
	{"NLYA", 4, 6465},
	{"EYCA", 4, 6466},
	{"PHILIPPINES", 11, 6467},
	{"ICKL", 4, 6468},
	{"PERSONALITY", 11, 6469},
	{"PASSENGER", 9, 6470},
	{"DIET", 4, 6471},
	{"WDY", 3, 6472},
	{"MUSICAL", 7, 6473},
	{"BEDS", 4, 6474},
	{"BREASTS", 7, 6475},
	{"ZKO", 3, 6476},
	{"ENEF", 4, 6477},
	{"NOWW", 4, 6478},
	{"PCS", 3, 6479},
	{"EMPLOYERS", 9, 6480},
	{"GREY", 4, 6481},
	{"PARALLEL", 8, 6482},
	{"ORWH", 4, 6483},
	{"HONDA", 5, 6484},
	{"FOREVER", 7, 6485},
	{"REGARD", 6, 6486},
	{"SSAY", 4, 6487},
	{"AMENDED", 7, 6488},
	{"BILLS", 5, 6489},
	{"ELLT", 4, 6490},
	{"HEPH", 4, 6491},
	{"ERGR", 4, 6492},
	{"JOURNALIST", 10, 6493},
	{"EMSE", 4, 6494},
	{"ONAB", 4, 6495},
	{"DEFINITIONS", 11, 6496},
	{"DOCTORS", 7, 6497},
	{"EFOL", 4, 6498},
	{"SIGNAL", 6, 6499},
	{"GKU", 3, 6500},
	{"XRU", 3, 6501},
	{"ESCE", 4, 6502},
	{"CINEMA", 6, 6503},
	{"COLUMN", 6, 6504},
	{"COMPARISON", 10, 6505},
	{"DISPLAY", 7, 6506},
	{"SLIDE", 5, 6507},
	{"ELECTIONS", 9, 6508},
	{"GRADUATE", 8, 6509},
	{"SILENT", 6, 6510},
	{"DZH", 3, 6511},
	{"YSAI", 4, 6512},
	{"RLDW", 4, 6513},
	{"OWNO", 4, 6514},
	{"UDES", 4, 6515},
	{"FICU", 4, 6516},
	{"INMO", 4, 6517},
	{"ENHANCED", 8, 6518},
	{"ENTITLED", 8, 6519},
	{"OMEP", 4, 6520},
	{"DONL", 4, 6521},
	{"STAINLESS", 9, 6522},
	{"NCIN", 4, 6523},
	{"ATME", 4, 6524},
	{"PERMIT", 6, 6525},
	{"NEWSPAPERS", 10, 6526},
	{"HOSPITALS", 9, 6527},
	{"ANYP", 4, 6528},
	{"NCEB", 4, 6529},
	{"ENBE", 4, 6530},
	{"AREW", 4, 6531},
	{"NSOR", 4, 6532},
	{"NSIB", 4, 6533},
	{"ARAB", 4, 6534},
	{"ZZS", 3, 6535},
	{"NABO", 4, 6536},
	{"DELUXE", 6, 6537},
	{"RLAN", 4, 6538},
	{"AYSI", 4, 6539},
	{"NVIR", 4, 6540},
	{"LTIN", 4, 6541},
	{"SWHA", 4, 6542},
	{"SELECTION", 9, 6543},
	{"PAYMENT", 7, 6544},
	{"AGED", 4, 6545},
	{"MONITORS", 8, 6546},
	{"LIVED", 5, 6547},
	{"DURATION", 8, 6548},
	{"HONOR", 5, 6549},
	{"BREAD", 5, 6550},
	{"DDIS", 4, 6551},
	{"WOQ", 3, 6552},
	{"DRAG", 4, 6553},
	{"INWI", 4, 6554},
	{"SSCO", 4, 6555},
	{"IALC", 4, 6556},
	{"ALLW", 4, 6557},
	{"INDONESIA", 9, 6558},
	{"SSAG", 4, 6559},
	{"PURSUANT", 8, 6560},
	{"CONSIST", 7, 6561},
	{"VISITS", 6, 6562},
	{"SINV", 4, 6563},
	{"DOMAINS", 7, 6564},
	{"WEAK", 4, 6565},
	{"CAPABILITIES", 12, 6566},
	{"EOFI", 4, 6567},
	{"PMID", 4, 6568},
	{"NGPE", 4, 6569},
	{"OFLI", 4, 6570},
	{"HELLO", 5, 6571},
	{"UNIVERSE", 8, 6572},
	{"RECRUITMENT", 11, 6573},
	{"GUAG", 4, 6574},
	{"BERLIN", 6, 6575},
	{"PRIORITY", 8, 6576},
	{"ULDA", 4, 6577},
	{"SUPPOSE", 7, 6578},
	{"OOPE", 4, 6579},
	{"RSPE", 4, 6580},
	{"LSOH", 4, 6581},
	{"LUCKY", 5, 6582},
	{"KEIT", 4, 6583},
	{"OFTW", 4, 6584},
	{"PTEM", 4, 6585},
	{"PLIE", 4, 6586},
	{"EDDE", 4, 6587},
	{"PARA", 4, 6588},
	{"SIEMENS", 7, 6589},
	{"ROOF", 4, 6590},
	{"OMEC", 4, 6591},
	{"IMPROVING", 9, 6592},
	{"KKU", 3, 6593},
	{"RTON", 4, 6594},
	{"TMAK", 4, 6595},
	{"CTOB", 4, 6596},
	{"NDDO", 4, 6597},
	{"WASW", 4, 6598},
	{"LAB", 3, 6599},
	{"ORRO", 4, 6600},
	{"ERLO", 4, 6601},
	{"MEANT", 5, 6602},
	{"POUNDS", 6, 6603},
	{"INAB", 4, 6604},
	{"EALW", 4, 6605},
	{"EZV", 3, 6606},
	{"BUFFALO", 7, 6607},
	{"ORGANISATIONS", 13, 6608},
	{"EXPLAINED", 9, 6609},
	{"RCED", 4, 6610},
	{"PROGRAMMES", 10, 6611},
	{"AGENDA", 6, 6612},
	{"INITIATIVE", 10, 6613},
	{"ETIR", 4, 6614},
	{"UPAN", 4, 6615},
	{"ATEV", 4, 6616},
	{"CAMPING", 7, 6617},
	{"PLANNING", 8, 6618},
	{"TDOE", 4, 6619},
	{"JEWELLERY", 9, 6620},
	{"MEETS", 5, 6621},
	{"ESUN", 4, 6622},
	{"CAUGHT", 6, 6623},
	{"CYY", 3, 6624},
	{"DESCRIPTION", 11, 6625},
	{"HOUSING", 7, 6626},
	{"URDE", 4, 6627},
	{"MARKED", 6, 6628},
	{"DRIVEN", 6, 6629},
	{"MEASURED", 8, 6630},
	{"MEDLINE", 7, 6631},
	{"ISLO", 4, 6632},
	{"AGREEMENTS", 10, 6633},
	{"CONSIDERING", 11, 6634},
	{"BUQ", 3, 6635},
	{"UGHI", 4, 6636},
	{"MARSHALL", 8, 6637},
	{"MASSAGE", 7, 6638},
	{"JIW", 3, 6639},
	{"NCEM", 4, 6640},
	{"ALLF", 4, 6641},
	{"THERAPY", 7, 6642},
	{"VESI", 4, 6643},
	{"CONSISTENT", 10, 6644},
	{"CLOSING", 7, 6645},
	{"TAMPA", 5, 6646},
	{"SSAR", 4, 6647},
	{"NDEA", 4, 6648},
	{"SUSAN", 5, 6649},
	{"LIBRARY", 7, 6650},
	{"WASH", 4, 6651},
	{"AREH", 4, 6652},
	{"ISWO", 4, 6653},
	{"ICIT", 4, 6654},
	{"ADAMS", 5, 6655},
	{"PRAYER", 6, 6656},
	{"OVES", 4, 6657},
	{"ENABLE", 6, 6658},
	{"PYTHON", 6, 6659},
	{"BEND", 4, 6660},
	{"YDD", 3, 6661},
	{"ALEX", 4, 6662},
	{"RVIE", 4, 6663},
	{"FUNDING", 7, 6664},
	{"NPER", 4, 6665},
	{"BANG", 4, 6666},
	{"EXPENSE", 7, 6667},
	{"EMAY", 4, 6668},
	{"NMOR", 4, 6669},
	{"CHILDHOOD", 9, 6670},
	{"VILLA", 5, 6671},
	{"TMAR", 4, 6672},
	{"EPAI", 4, 6673},
	{"COLUMNS", 7, 6674},
	{"DISORDERS", 9, 6675},
	{"MSOF", 4, 6676},
	{"RSFO", 4, 6677},
	{"BUGS", 4, 6678},
	{"LAYER", 5, 6679},
	{"MSAN", 4, 6680},
	{"HAMILTON", 8, 6681},
	{"DETECTION", 9, 6682},
	{"FTP", 3, 6683},
	{"MBLE", 4, 6684},
	{"FACTORY", 7, 6685},
	{"COOKIES", 7, 6686},
	{"DRAMATIC", 8, 6687},
	{"YSIC", 4, 6688},
	{"COP", 3, 6689},
	{"ARYT", 4, 6690},
	{"GAP", 3, 6691},
	{"TUTORIAL", 8, 6692},
	{"MED", 3, 6693},
	{"TLYA", 4, 6694},
	{"IZW", 3, 6695},
	{"EVALUATION", 10, 6696},
	{"ENGINEERS", 9, 6697},
	{"WARNING", 7, 6698},
	{"ARREST", 6, 6699},
	{"ISWH", 4, 6700},
	{"CRUISES", 7, 6701},
	{"HMAN", 4, 6702},
	{"SUSPECT", 7, 6703},
	{"EDRO", 4, 6704},
	{"TEFO", 4, 6705},
	{"LSOT", 4, 6706},
	{"HOLDER", 6, 6707},
	{"PROPOSALS", 9, 6708},
	{"MODERATOR", 9, 6709},
	{"SETTLEMENT", 10, 6710},
	{"TUTORIALS", 9, 6711},
	{"UYD", 3, 6712},
	{"MOREOVER", 8, 6713},
	{"CHIP", 4, 6714},
	{"YAFT", 4, 6715},
	{"PORTUGAL", 8, 6716},
	{"YSHE", 4, 6717},
	{"NDYO", 4, 6718},
	{"LAWRENCE", 8, 6719},
	{"TOFR", 4, 6720},
	{"OSTL", 4, 6721},
	{"TWAR", 4, 6722},
	{"RSOM", 4, 6723},
	{"EBEA", 4, 6724},
	{"OWTO", 4, 6725},
	{"KISS", 4, 6726},
	{"IMPLEMENT", 9, 6727},
	{"DUTIES", 6, 6728},
	{"MWIT", 4, 6729},
	{"EROTIC", 6, 6730},
	{"UHAV", 4, 6731},
	{"HEVA", 4, 6732},
	{"EBEG", 4, 6733},
	{"OMEF", 4, 6734},
	{"TWER", 4, 6735},
	{"COLLECTABLES", 12, 6736},
	{"FORMAL", 6, 6737},
	{"DRAGON", 6, 6738},
	{"UPPL", 4, 6739},
	{"PURCHASE", 8, 6740},
	{"RALO", 4, 6741},
	{"EMOTION", 7, 6742},
	{"BRINGS", 6, 6743},
	{"HEATING", 7, 6744},
	{"MSTO", 4, 6745},
	{"TRANSITION", 10, 6746},
	{"EDLI", 4, 6747},
	{"YSTO", 4, 6748},
	{"GOVERNMENTS", 11, 6749},
	{"PHASE", 5, 6750},
	{"PURCHASING", 10, 6751},
	{"SCRIPTS", 7, 6752},
	{"ABC", 3, 6753},
	{"STEREO", 6, 6754},
	{"APPOINTED", 9, 6755},
	{"COAT", 4, 6756},
	{"CHAMPIONSHIP", 12, 6757},
	{"GLANCE", 6, 6758},
	{"DEALING", 7, 6759},
	{"EEMS", 4, 6760},
	{"WIDELY", 6, 6761},
	{"SHALL", 5, 6762},
	{"BUTN", 4, 6763},
	{"OPERATIONAL", 11, 6764},
	{"AIRLINES", 8, 6765},
	{"DINF", 4, 6766},
	{"LIVECAM", 7, 6767},
	{"REMAINING", 9, 6768},
	{"JAY", 3, 6769},
	{"EERS", 4, 6770},
	{"SCHEDULE", 8, 6771},
	{"TEDL", 4, 6772},
	{"STEEL", 5, 6773},
	{"CKTH", 4, 6774},
	{"ERROR", 5, 6775},
	{"EXPOSURE", 8, 6776},
	{"ANYC", 4, 6777},
	{"TRIPS", 5, 6778},
	{"SIDES", 5, 6779},
	{"EDPO", 4, 6780},
	{"EXISTENCE", 9, 6781},
	{"TURNS", 5, 6782},
	{"CORRESPONDING", 13, 6783},
	{"ICEI", 4, 6784},
	{"DESCRIPTIONS", 12, 6785},
	{"CACHE", 5, 6786},
	{"NGPA", 4, 6787},
	{"TRYT", 4, 6788},
	{"CTOF", 4, 6789},
	{"ITHL", 4, 6790},
	{"TPRE", 4, 6791},
	{"ZZB", 3, 6792},
	{"EADD", 4, 6793},
	{"ANIMATION", 9, 6794},
	{"IECE", 4, 6795},
	{"ORACLE", 6, 6796},
	{"SAVING", 6, 6797},
	{"XPLO", 4, 6798},
	{"EFUN", 4, 6799},
	{"SUBSTANCE", 9, 6800},
	{"SAUCE", 5, 6801},
	{"MATTHEW", 7, 6802},
	{"UNABLE", 6, 6803},
	{"ERFU", 4, 6804},
	{"ERAI", 4, 6805},
	{"LEASE", 5, 6806},
	{"IGHB", 4, 6807},
	{"PRODUCTIONS", 11, 6808},
	{"AVIATION", 8, 6809},
	{"SYMPTOM", 7, 6810},
	{"HOBBIES", 7, 6811},
	{"RTNE", 4, 6812},
	{"ALCOHOL", 7, 6813},
	{"XQU", 3, 6814},
	{"BOTHER", 6, 6815},
	{"ALBUM", 5, 6816},
	{"ANWA", 4, 6817},
	{"ESUM", 4, 6818},
	{"REBU", 4, 6819},
	{"EXCESS", 6, 6820},
	{"REDUCTION", 9, 6821},
	{"DEEPLY", 6, 6822},
	{"ONLINE", 6, 6823},
	{"AGEI", 4, 6824},
	{"ROWT", 4, 6825},
	{"CONSOLE", 7, 6826},
	{"LAKE", 4, 6827},
	{"COMMANDS", 8, 6828},
	{"ONBU", 4, 6829},
	{"TERRITORY", 9, 6830},
	{"WEDDING", 7, 6831},
	{"CEMB", 4, 6832},
	{"VEMB", 4, 6833},
	{"TELECOMMUNICATIONS", 18, 6834},
	{"LCHA", 4, 6835},
	{"RDTH", 4, 6836},
	{"REAB", 4, 6837},
	{"TRANSFORM", 9, 6838},
	{"EYAN", 4, 6839},
	{"BREATHE", 7, 6840},
	{"ORUN", 4, 6841},
	{"ACHIEVED", 8, 6842},
	{"TABLESPOON", 10, 6843},
	{"OPPONENT", 8, 6844},
	{"RNOR", 4, 6845},
	{"INJURIES", 8, 6846},
	{"SHIPPED", 7, 6847},
	{"XPLA", 4, 6848},
	{"MINE", 4, 6849},
	{"YCHA", 4, 6850},
	{"KNIFE", 5, 6851},
	{"USPE", 4, 6852},
	{"SEATS", 5, 6853},
	{"NAPR", 4, 6854},
	{"APPROACHES", 10, 6855},
	{"BIZ", 3, 6856},
	{"RECOVER", 7, 6857},
	{"SSUP", 4, 6858},
	{"EVALUATE", 8, 6859},
	{"VOLTAGE", 7, 6860},
	{"ANTHONY", 7, 6861},
	{"CYCLE", 5, 6862},
	{"NINTENDO", 8, 6863},
	{"BRIEF", 5, 6864},
	{"TEASPOON", 8, 6865},
	{"LYWI", 4, 6866},
	{"OREH", 4, 6867},
	{"VIOLENT", 7, 6868},
	{"LOADING", 7, 6869},
	{"ORLE", 4, 6870},
	{"STAMPS", 6, 6871},
	{"APPEARED", 8, 6872},
	{"FRANKLIN", 8, 6873},
	{"TJUS", 4, 6874},
	{"NTSF", 4, 6875},
	{"DCOU", 4, 6876},
	{"PHILOSOPHY", 10, 6877},
	{"DTOL", 4, 6878},
	{"MANUFACTURER", 12, 6879},
	{"EAWA", 4, 6880},
	{"ROB", 3, 6881},
	{"DSPE", 4, 6882},
	{"VINYL", 5, 6883},
	{"TOFP", 4, 6884},
	{"HIGHLIGHTS", 10, 6885},
	{"OROU", 4, 6886},
	{"MINING", 6, 6887},
	{"COALITION", 9, 6888},
	{"DESIGNERS", 9, 6889},
	{"MELBOURNE", 9, 6890},
	{"YKH", 3, 6891},
	{"PASSAGE", 7, 6892},
	{"WORST", 5, 6893},
	{"FAIRLY", 6, 6894},
	{"GSAN", 4, 6895},
	{"CEWI", 4, 6896},
	{"POST", 4, 6897},
	{"ESSW", 4, 6898},
	{"JACKET", 6, 6899},
	{"AWV", 3, 6900},
	{"IMAGING", 7, 6901},
	{"RACIAL", 6, 6902},
	{"BETTING", 7, 6903},
	{"RESISTANCE", 10, 6904},
	{"RYZ", 3, 6905},
	{"DISCIPLINE", 10, 6906},
	{"SCIENTISTS", 10, 6907},
	{"RTSO", 4, 6908},
	{"NEGOTIATION", 11, 6909},
	{"PORTION", 7, 6910},
	{"WYOMING", 7, 6911},
	{"BLACKJACK", 9, 6912},
	{"ARGENTINA", 9, 6913},
	{"RDOF", 4, 6914},
	{"LEADING", 7, 6915},
	{"NOTC", 4, 6916},
	{"GRAND", 5, 6917},
	{"SAND", 4, 6918},
	{"DESERT", 6, 6919},
	{"ITCA", 4, 6920},
	{"LOWT", 4, 6921},
	{"INVOLVEMENT", 11, 6922},
	{"PRINT", 5, 6923},
	{"AYFO", 4, 6924},
	{"IVEM", 4, 6925},
	{"NSOU", 4, 6926},
	{"LOCK", 4, 6927},
	{"EHOM", 4, 6928},
	{"TENSION", 7, 6929},
	{"ZYB", 3, 6930},
	{"INTERPRETATION", 14, 6931},
	{"THONGS", 6, 6932},
	{"MEWI", 4, 6933},
	{"GCC", 3, 6934},
	{"IVEB", 4, 6935},
	{"DTOO", 4, 6936},
	{"OLID", 4, 6937},
	{"SEDF", 4, 6938},
	{"EALA", 4, 6939},
	{"ANALYZE", 7, 6940},
	{"VOLUNTEERS", 10, 6941},
	{"LPLA", 4, 6942},
	{"ATTACHMENT", 10, 6943},
	{"POTATO", 6, 6944},
	{"RINGTONE", 8, 6945},
	{"HEAG", 4, 6946},
	{"UZM", 3, 6947},
	{"OPPOSITE", 8, 6948},
	{"DDIN", 4, 6949},
	{"RLES", 4, 6950},
	{"FINLAND", 7, 6951},
	{"MORGAN", 6, 6952},
	{"DERIVED", 7, 6953},
	{"ONEM", 4, 6954},
	{"EENP", 4, 6955},
	{"EFIE", 4, 6956},
	{"YGH", 3, 6957},
	{"NSWH", 4, 6958},
	{"PRESERVE", 8, 6959},
	{"ORIENTED", 8, 6960},
	{"EAGLE", 5, 6961},
	{"DESKTOPS", 8, 6962},
	{"IGHL", 4, 6963},
	{"LSOB", 4, 6964},
	{"PANTS", 5, 6965},
	{"UTAL", 4, 6966},
	{"MEXICAN", 7, 6967},
	{"COLUMBUS", 8, 6968},
	{"SPANISH", 7, 6969},
	{"EGOI", 4, 6970},
	{"NBEC", 4, 6971},
	{"KSTO", 4, 6972},
	{"WORKSHOPS", 9, 6973},
	{"DTOF", 4, 6974},
	{"YMAN", 4, 6975},
	{"NDBR", 4, 6976},
	{"POSTAGE", 7, 6977},
	{"DUST", 4, 6978},
	{"EHAR", 4, 6979},
	{"REPRESENTED", 11, 6980},
	{"MORTGAGES", 9, 6981},
	{"DIAL", 4, 6982},
	{"RESPONSIBILITIES", 16, 6983},
	{"OYAL", 4, 6984},
	{"EDUCATOR", 8, 6985},
	{"JOINT", 5, 6986},
	{"GHBO", 4, 6987},
	{"COMIC", 5, 6988},
	{"ERPL", 4, 6989},
	{"ZYI", 3, 6990},
	{"EDOW", 4, 6991},
	{"NGCH", 4, 6992},
	{"IPPE", 4, 6993},
	{"YRG", 3, 6994},
	{"EDOE", 4, 6995},
	{"INVESTORS", 9, 6996},
	{"QUOTE", 5, 6997},
	{"NDUC", 4, 6998},
	{"NTOC", 4, 6999},
	{"USSE", 4, 7000},
	{"CROWN", 5, 7001},
	{"STREAM", 6, 7002},
	{"PAR", 3, 7003},
	{"ILLR", 4, 7004},
	{"AZIN", 4, 7005},
	{"UNDERGROUND", 11, 7006},
	{"ENHANCE", 7, 7007},
	{"RSZ", 3, 7008},
	{"EVEA", 4, 7009},
	{"EARB", 4, 7010},
	{"NUMEROUS", 8, 7011},
	{"JUICE", 5, 7012},
	{"ERSL", 4, 7013},
	{"NNOV", 4, 7014},
	{"WHISPER", 7, 7015},
	{"PICKS", 5, 7016},
	{"DUAT", 4, 7017},
	{"GENE", 4, 7018},
	{"VACATIONS", 9, 7019},
	{"YSIN", 4, 7020},
	{"AVEM", 4, 7021},
	{"YDM", 3, 7022},
	{"OFME", 4, 7023},
	{"SEMESTER", 8, 7024},
	{"CALCULATED", 10, 7025},
	{"ECIF", 4, 7026},
	{"WAJ", 3, 7027},
	{"DISCOVERY", 9, 7028},
	{"OWNF", 4, 7029},
	{"URVI", 4, 7030},
	{"FETISH", 6, 7031},
	{"SALE", 4, 7032},
	{"ELECT", 5, 7033},
	{"ENYO", 4, 7034},
	{"ALKE", 4, 7035},
	{"AKEI", 4, 7036},
	{"APPLIES", 7, 7037},
	{"EMPHASIS", 8, 7038},
	{"CASINOS", 7, 7039},
	{"YPEO", 4, 7040},
	{"ABANDON", 7, 7041},
	{"APACHE", 6, 7042},
	{"ATMOSPHERE", 10, 7043},
	{"STOU", 4, 7044},
	{"ERTR", 4, 7045},
	{"ITOF", 4, 7046},
	{"PRACTICAL", 9, 7047},
	{"NMAY", 4, 7048},
	{"FILTERS", 7, 7049},
	{"HEGU", 4, 7050},
	{"EWEL", 4, 7051},
	{"KSQ", 3, 7052},
	{"INCORPORATED", 12, 7053},
	{"IGIO", 4, 7054},
	{"JOKE", 4, 7055},
	{"OWST", 4, 7056},
	{"NOTEBOOKS", 9, 7057},
	{"FOUNDATION", 10, 7058},
	{"RESOLVE", 7, 7059},
	{"INDEPENDENCE", 12, 7060},
	{"MARKETING", 9, 7061},
	{"INVESTIGATOR", 12, 7062},
	{"ATRO", 4, 7063},
	{"ANMA", 4, 7064},
	{"ITHW", 4, 7065},
	{"PSYCHOLOGICAL", 13, 7066},
	{"DISTRIBUTION", 12, 7067},
	{"TSMA", 4, 7068},
	{"HATG", 4, 7069},
	{"ZZF", 3, 7070},
	{"HENW", 4, 7071},
	{"LTHI", 4, 7072},
	{"LOUNGE", 6, 7073},
	{"MWAS", 4, 7074},
	{"DOUBLE", 6, 7075},
	{"POSE", 4, 7076},
	{"ALGORITHM", 9, 7077},
	{"SEMI", 4, 7078},
	{"COINS", 5, 7079},
	{"RFUL", 4, 7080},
	{"SMELL", 5, 7081},
	{"ANDY", 4, 7082},
	{"RYCO", 4, 7083},
	{"CAFE", 4, 7084},
	{"FUNDAMENTAL", 11, 7085},
	{"ILLP", 4, 7086},
	{"VALENTINE", 9, 7087},
	{"HILTON", 6, 7088},
	{"LLIE", 4, 7089},
	{"ESWA", 4, 7090},
	{"NALY", 4, 7091},
	{"PROTEINS", 8, 7092},
	{"APPROXIMATELY", 13, 7093},
	{"PACK", 4, 7094},
	{"REYO", 4, 7095},
	{"SAGR", 4, 7096},
	{"EXP", 3, 7097},
	{"REEA", 4, 7098},
	{"TWOO", 4, 7099},
	{"DOUGLAS", 7, 7100},
	{"DEBIAN", 6, 7101},
	{"INVOLVING", 9, 7102},
	{"MISSILE", 7, 7103},
	{"SUICIDE", 7, 7104},
	{"TTOP", 4, 7105},
	{"INVESTING", 9, 7106},
	{"GWAS", 4, 7107},
	{"DLIK", 4, 7108},
	{"TOBR", 4, 7109},
	{"CHRISTOPHER", 11, 7110},
	{"LMAN", 4, 7111},
	{"AMAZING", 7, 7112},
	{"EPSON", 5, 7113},
	{"ULDE", 4, 7114},
	{"OBJECTIVE", 9, 7115},
	{"ELECTED", 7, 7116},
	{"CARRYING", 8, 7117},
	{"MADISON", 7, 7118},
	{"ESTW", 4, 7119},
	{"EOLD", 4, 7120},
	{"PREVIOUSLY", 10, 7121},
	{"ILLUSTRATE", 10, 7122},
	{"EDITIONS", 8, 7123},
	{"CPU", 3, 7124},
	{"NYEA", 4, 7125},
	{"NOWL", 4, 7126},
	{"TMON", 4, 7127},
	{"PARLIAMENT", 10, 7128},
	{"CHNI", 4, 7129},
	{"FINDS", 5, 7130},
	{"RESPONDENT", 10, 7131},
	{"ESTL", 4, 7132},
	{"ENFORCEMENT", 11, 7133},
	{"HENY", 4, 7134},
	{"SITUATIONS", 10, 7135},
	{"DIGITAL", 7, 7136},
	{"IRON", 4, 7137},
	{"RSDA", 4, 7138},
	{"ISDI", 4, 7139},
	{"ORTW", 4, 7140},
	{"ASGO", 4, 7141},
	{"BOOT", 4, 7142},
	{"ALLOCATED", 9, 7143},
	{"YINC", 4, 7144},
	{"EAMI", 4, 7145},
	{"HICL", 4, 7146},
	{"YNF", 3, 7147},
	{"ESSENTIALLY", 11, 7148},
	{"ZYO", 3, 7149},
	{"YYI", 3, 7150},
	{"CORRECTIONS", 11, 7151},
	{"DEFICIT", 7, 7152},
	{"GHIM", 4, 7153},
	{"TALE", 4, 7154},
	{"BEAN", 4, 7155},
	{"USHE", 4, 7156},
	{"DESCRIBES", 9, 7157},
	{"ZRI", 3, 7158},
	{"OCCURS", 6, 7159},
	{"DISABILITIES", 12, 7160},
	{"CONSISTS", 8, 7161},
	{"LLON", 4, 7162},
	{"RETIRE", 6, 7163},
	{"FCOU", 4, 7164},
	{"ANYTIME", 7, 7165},
	{"EATR", 4, 7166},
	{"TGET", 4, 7167},
	{"PROHIBITED", 10, 7168},
	{"PARKING", 7, 7169},
	{"LIES", 4, 7170},
	{"SPENDING", 8, 7171},
	{"DIMENSION", 9, 7172},
	{"SOLDIERS", 8, 7173},
	{"VOLUNTEER", 9, 7174},
	{"GUARDIAN", 8, 7175},
	{"VARY", 4, 7176},
	{"SIMULATION", 10, 7177},
	{"LAYOUT", 6, 7178},
	{"DESERVE", 7, 7179},
	{"COMPETITIVE", 11, 7180},
	{"CONGRESSIONAL", 13, 7181},
	{"INITIATIVES", 11, 7182},
	{"ERYE", 4, 7183},
	{"CLASSICS", 8, 7184},
	{"LBS", 3, 7185},
	{"RARELY", 6, 7186},
	{"NAFT", 4, 7187},
	{"OFLO", 4, 7188},
	{"HURS", 4, 7189},
	{"AWHI", 4, 7190},
	{"HORSES", 6, 7191},
	{"LOL", 3, 7192},
	{"URGE", 4, 7193},
	{"POVERTY", 7, 7194},
	{"PRIEST", 6, 7195},
	{"EWON", 4, 7196},
	{"ELSEWHERE", 9, 7197},
	{"EPAT", 4, 7198},
	{"WAYNE", 5, 7199},
	{"IMPOSE", 6, 7200},
	{"TAUGHT", 6, 7201},
	{"ASIAN", 5, 7202},
	{"EDCA", 4, 7203},
	{"TOMATO", 6, 7204},
	{"NGSU", 4, 7205},
	{"NTLE", 4, 7206},
	{"OPTIMIZATION", 12, 7207},
	{"GSTO", 4, 7208},
	{"MIXTURE", 7, 7209},
	{"NFAC", 4, 7210},
	{"ENGINEERING", 11, 7211},
	{"CREATURE", 8, 7212},
	{"ICEN", 4, 7213},
	{"EMPLOYER", 8, 7214},
	{"SUBSTANCES", 10, 7215},
	{"STLI", 4, 7216},
	{"WNIN", 4, 7217},
	{"DISCOVERED", 10, 7218},
	{"WINGS", 5, 7219},
	{"BREAKS", 6, 7220},
	{"RESTRICTIONS", 12, 7221},
	{"NDUN", 4, 7222},
	{"ESEP", 4, 7223},
	{"TTOD", 4, 7224},
	{"WAYF", 4, 7225},
	{"OFHO", 4, 7226},
	{"PARTICIPATING", 13, 7227},
	{"WATERS", 6, 7228},
	{"OKNO", 4, 7229},
	{"NDPL", 4, 7230},
	{"ESWO", 4, 7231},
	{"LYMA", 4, 7232},
	{"EROA", 4, 7233},
	{"XFU", 3, 7234},
	{"OCCASION", 8, 7235},
	{"IMPLICATION", 11, 7236},
	{"NANY", 4, 7237},
	{"OUTM", 4, 7238},
	{"MODEM", 5, 7239},
	{"ETRU", 4, 7240},
	{"ENMA", 4, 7241},
	{"DISORDER", 8, 7242},
	{"BUTTER", 6, 7243},
	{"HARRIS", 6, 7244},
	{"MPH", 3, 7245},
	{"ORDINARY", 8, 7246},
	{"OFRO", 4, 7247},
	{"BRINGING", 8, 7248},
	{"INSPIRE", 7, 7249},
	{"NDBU", 4, 7250},
	{"SCHI", 4, 7251},
	{"DOMINATE", 8, 7252},
	{"IESF", 4, 7253},
	{"TLYT", 4, 7254},
	{"DFIN", 4, 7255},
	{"NGME", 4, 7256},
	{"TIFFANY", 7, 7257},
	{"YHIS", 4, 7258},
	{"CEDB", 4, 7259},
	{"OSEL", 4, 7260},
	{"EBOT", 4, 7261},
	{"TOYOTA", 6, 7262},
	{"STREETS", 7, 7263},
	{"UTNO", 4, 7264},
	{"PEER", 4, 7265},
	{"VECTOR", 6, 7266},
	{"ILLNESS", 7, 7267},
	{"BATHROOM", 8, 7268},
	{"SHAVED", 6, 7269},
	{"TURNING", 7, 7270},
	{"BUFFER", 6, 7271},
	{"COMMENTARY", 10, 7272},
	{"LARRY", 5, 7273},
	{"LIMOUSINES", 10, 7274},
	{"ELAW", 4, 7275},
	{"DEVELOPMENTS", 12, 7276},
	{"CHCO", 4, 7277},
	{"DEF", 3, 7278},
	{"VISIBLE", 7, 7279},
	{"ARTN", 4, 7280},
	{"FZO", 3, 7281},
	{"DESTINATIONS", 12, 7282},
	{"TRANSFER", 8, 7283},
	{"LETS", 4, 7284},
	{"THROAT", 6, 7285},
	{"ZZT", 3, 7286},
	{"YMT", 3, 7287},
	{"PIPELINE", 8, 7288},
	{"CAP", 3, 7289},
	{"SEMB", 4, 7290},
	{"NESD", 4, 7291},
	{"LDWA", 4, 7292},
	{"KWIT", 4, 7293},
	{"MKU", 3, 7294},
	{"SYNTAX", 6, 7295},
	{"GENTLEMAN", 9, 7296},
	{"ADVANCE", 7, 7297},
	{"CHAIRS", 6, 7298},
	{"ENTRY", 5, 7299},
	{"LLYH", 4, 7300},
	{"IONL", 4, 7301},
	{"PASSION", 7, 7302},
	{"OURF", 4, 7303},
	{"TNER", 4, 7304},
	{"CTRI", 4, 7305},
	{"SDEA", 4, 7306},
	{"ONMO", 4, 7307},
	{"ZYW", 3, 7308},
	{"EBOA", 4, 7309},
	{"ENTERTAINMENT", 13, 7310},
	{"TWIN", 4, 7311},
	{"TOFM", 4, 7312},
	{"ZFE", 3, 7313},
	{"MOUNTAINS", 9, 7314},
	{"MOVES", 5, 7315},
	{"ELEF", 4, 7316},
	{"ETHERNET", 8, 7317},
	{"SYMBOL", 6, 7318},
	{"ERIV", 4, 7319},
	{"BOSS", 4, 7320},
	{"ELPE", 4, 7321},
	{"MAKER", 5, 7322},
	{"CHECKED", 7, 7323},
	{"NTOM", 4, 7324},
	{"INGV", 4, 7325},
	{"ABOV", 4, 7326},
	{"AINC", 4, 7327},
	{"INLO", 4, 7328},
	{"YDIS", 4, 7329},
	{"EDIR", 4, 7330},
	{"ADJUST", 6, 7331},
	{"NFIR", 4, 7332},
	{"SIERRA", 6, 7333},
	{"CATS", 4, 7334},
	{"ATTACH", 6, 7335},
	{"SHOCK", 5, 7336},
	{"COMPLAINT", 9, 7337},
	{"POSTPOSTED", 10, 7338},
	{"ONSB", 4, 7339},
	{"ROUND", 5, 7340},
	{"OLDEST", 6, 7341},
	{"RHODE", 5, 7342},
	{"TSFR", 4, 7343},
	{"XYO", 3, 7344},
	{"LBEA", 4, 7345},
	{"DSER", 4, 7346},
	{"SHEC", 4, 7347},
	{"LOFF", 4, 7348},
	{"ERBR", 4, 7349},
	{"IMMIGRATION", 11, 7350},
	{"PROSPECT", 8, 7351},
	{"MERCURY", 7, 7352},
	{"STEVEN", 6, 7353},
	{"LSOR", 4, 7354},
	{"NGLO", 4, 7355},
	{"TRANSPORTATION", 14, 7356},
	{"HANDBOOK", 8, 7357},
	{"OXG", 3, 7358},
	{"OFTR", 4, 7359},
	{"ARYO", 4, 7360},
	{"GREG", 4, 7361},
	{"NAVIGATE", 8, 7362},
	{"WORSE", 5, 7363},
	{"HABIT", 5, 7364},
	{"EXPA", 4, 7365},
	{"MONITOR", 7, 7366},
	{"CONVENTION", 10, 7367},
	{"VICTIMS", 7, 7368},
	{"TWOM", 4, 7369},
	{"REWO", 4, 7370},
	{"ENWI", 4, 7371},
	{"EDOR", 4, 7372},
	{"SPACES", 6, 7373},
	{"WHENEVER", 8, 7374},
	{"ONEP", 4, 7375},
	{"PEAK", 4, 7376},
	{"AYSH", 4, 7377},
	{"QWE", 3, 7378},
	{"ORPR", 4, 7379},
	{"HEJO", 4, 7380},
	{"MPLY", 4, 7381},
	{"STRONGLY", 8, 7382},
	{"ENWE", 4, 7383},
	{"COUPONS", 7, 7384},
	{"YTHR", 4, 7385},
	{"TWHA", 4, 7386},
	{"INTENSE", 7, 7387},
	{"KING", 4, 7388},
	{"CIALIS", 6, 7389},
	{"NCZ", 3, 7390},
	{"VIW", 3, 7391},
	{"NGOV", 4, 7392},
	{"BOATS", 5, 7393},
	{"DZU", 3, 7394},
	{"RSAG", 4, 7395},
	{"COMMANDER", 9, 7396},
	{"SBOR", 4, 7397},
	{"IZB", 3, 7398},
	{"ECHE", 4, 7399},
	{"NEDF", 4, 7400},
	{"VESE", 4, 7401},
	{"ARRANGEMENT", 11, 7402},
	{"SCOTTISH", 8, 7403},
	{"BREAKFAST", 9, 7404},
	{"SOFO", 4, 7405},
	{"EARR", 4, 7406},
	{"OINC", 4, 7407},
	{"EQUALLY", 7, 7408},
	{"RRIS", 4, 7409},
	{"OFNE", 4, 7410},
	{"ARCADE", 6, 7411},
	{"RICHMOND", 8, 7412},
	{"SACRAMENTO", 10, 7413},
	{"EYCO", 4, 7414},
	{"ONAP", 4, 7415},
	{"TONC", 4, 7416},
	{"COMMISSION", 10, 7417},
	{"RUSSELL", 7, 7418},
	{"TELLS", 5, 7419},
	{"VETERAN", 7, 7420},
	{"OOKT", 4, 7421},
	{"GHTL", 4, 7422},
	{"NHAD", 4, 7423},
	{"DALO", 4, 7424},
	{"GRAPH", 5, 7425},
	{"COVERING", 8, 7426},
	{"OFBE", 4, 7427},
	{"DDEN", 4, 7428},
	{"SPOK", 4, 7429},
	{"ALME", 4, 7430},
	{"ZAV", 3, 7431},
	{"EMPE", 4, 7432},
	{"PLATINUM", 8, 7433},
	{"UYR", 3, 7434},
	{"BEDROOMS", 8, 7435},
	{"SMOKE", 5, 7436},
	{"ACCOMPLISH", 10, 7437},
	{"TALKS", 5, 7438},
	{"ELEB", 4, 7439},
	{"YLEA", 4, 7440},
	{"FILING", 6, 7441},
	{"EAKE", 4, 7442},
	{"SWING", 5, 7443},
	{"STWI", 4, 7444},
	{"MODELING", 8, 7445},
	{"TOFE", 4, 7446},
	{"PEDT", 4, 7447},
	{"USUAL", 5, 7448},
	{"AWARDED", 7, 7449},
	{"TESTIMONIALS", 12, 7450},
	{"SDEC", 4, 7451},
	{"SOFE", 4, 7452},
	{"TRIALS", 6, 7453},
	{"RFIR", 4, 7454},
	{"MEMORABILIA", 11, 7455},
	{"TOSP", 4, 7456},
	{"CLINTON", 7, 7457},
	{"MASTERS", 7, 7458},
	{"RENG", 4, 7459},
	{"BONDS", 5, 7460},
	{"INBE", 4, 7461},
	{"NCIE", 4, 7462},
	{"ZMU", 3, 7463},
	{"INLY", 4, 7464},
	{"VEOF", 4, 7465},
	{"EBEI", 4, 7466},
	{"TOAP", 4, 7467},
	{"CARTRIDGE", 9, 7468},
	{"ALBERTA", 7, 7469},
	{"RTIM", 4, 7470},
	{"RECOGNITION", 11, 7471},
	{"UGHS", 4, 7472},
	{"ANGER", 5, 7473},
	{"HAEL", 4, 7474},
	{"ORG", 3, 7475},
	{"ORHO", 4, 7476},
	{"CRUCIAL", 7, 7477},
	{"CONSTRUCT", 9, 7478},
	{"NIQU", 4, 7479},
	{"COMMONS", 7, 7480},
	{"CINCINNATI", 10, 7481},
	{"EENR", 4, 7482},
	{"SUBSECTION", 10, 7483},
	{"RSEC", 4, 7484},
	{"MOOD", 4, 7485},
	{"LYOU", 4, 7486},
	{"LLAT", 4, 7487},
	{"PERMITTED", 9, 7488},
	{"RAIG", 4, 7489},
	{"RNEY", 4, 7490},
	{"NOWH", 4, 7491},
	{"MYSTERY", 7, 7492},
	{"DESIGNER", 8, 7493},
	{"POTTERY", 7, 7494},
	{"CKSA", 4, 7495},
	{"UTAT", 4, 7496},
	{"ENCI", 4, 7497},
	{"ROGER", 5, 7498},
	{"AWESOME", 7, 7499},
	{"DISABILITY", 10, 7500},
	{"MSTH", 4, 7501},
	{"EFOO", 4, 7502},
	{"LUCK", 4, 7503},
	{"CONFIRMED", 9, 7504},
	{"SKNO", 4, 7505},
	{"COUNTS", 6, 7506},
	{"PRICED", 6, 7507},
	{"NTWH", 4, 7508},
	{"WALLPAPERS", 10, 7509},
	{"YYU", 3, 7510},
	{"CRITERIA", 8, 7511},
	{"CONCENTRATE", 11, 7512},
	{"TZF", 3, 7513},
	{"SMOOTH", 6, 7514},
	{"IVEW", 4, 7515},
	{"WASU", 4, 7516},
	{"SOFD", 4, 7517},
	{"TBAC", 4, 7518},
	{"ISGO", 4, 7519},
	{"DESIRED", 7, 7520},
	{"EXCEPTION", 9, 7521},
	{"DYY", 3, 7522},
	{"IMEO", 4, 7523},
	{"WHOC", 4, 7524},
	{"INTER", 5, 7525},
	{"QCO", 3, 7526},
	{"ETBA", 4, 7527},
	{"NERVOUS", 7, 7528},
	{"TDOW", 4, 7529},
	{"PERSONNEL", 9, 7530},
	{"NCEL", 4, 7531},
	{"ASSUMES", 7, 7532},
	{"HOLY", 4, 7533},
	{"ANXIETY", 7, 7534},
	{"PHENOMENON", 10, 7535},
	{"NDGR", 4, 7536},
	{"HEIGHTS", 7, 7537},
	{"DSHA", 4, 7538},
	{"EPTH", 4, 7539},
	{"RIDING", 6, 7540},
	{"CONSTANT", 8, 7541},
	{"EZG", 3, 7542},
	{"OFSU", 4, 7543},
	{"SO-CALLED", 9, 7544},
	{"FIREFOX", 7, 7545},
	{"SAYT", 4, 7546},
	{"LISA", 4, 7547},
	{"ENWH", 4, 7548},
	{"ADMINISTRATOR", 13, 7549},
	{"ELECTRONIC", 10, 7550},
	{"GROVE", 5, 7551},
	{"ELIGIBILITY", 11, 7552},
	{"CONSIDERATION", 13, 7553},
	{"YWOR", 4, 7554},
	{"PUBLICATION", 11, 7555},
	{"PROTEIN", 7, 7556},
	{"NDTA", 4, 7557},
	{"HEALING", 7, 7558},
	{"PRINCESS", 8, 7559},
	{"SILVER", 6, 7560},
	{"ISOR", 4, 7561},
	{"HEJU", 4, 7562},
	{"ICHC", 4, 7563},
	{"BURY", 4, 7564},
	{"ENTERING", 8, 7565},
	{"LYWO", 4, 7566},
	{"ALLY", 4, 7567},
	{"PACKET", 6, 7568},
	{"COMMAND", 7, 7569},
	{"NGFI", 4, 7570},
	{"ULDT", 4, 7571},
	{"CLINIC", 6, 7572},
	{"NSLA", 4, 7573},
	{"ANYM", 4, 7574},
	{"PALESTINIAN", 11, 7575},
	{"STUDIOS", 7, 7576},
	{"ERSR", 4, 7577},
	{"LTRA", 4, 7578},
	{"PRAY", 4, 7579},
	{"RNIA", 4, 7580},
	{"OSTC", 4, 7581},
	{"ELOO", 4, 7582},
	{"BUTTONS", 7, 7583},
	{"WEDT", 4, 7584},
	{"EDAG", 4, 7585},
	{"EXHIBITION", 10, 7586},
	{"OBSERVATIONS", 12, 7587},
	{"ITYF", 4, 7588},
	{"DITW", 4, 7589},
	{"OFWA", 4, 7590},
	{"ROFA", 4, 7591},
	{"VBULLETIN", 9, 7592},
	{"SUPPORTER", 9, 7593},
	{"FUNDED", 6, 7594},
	{"THOMPSON", 8, 7595},
	{"WINNERS", 7, 7596},
	{"HEAVILY", 7, 7597},
	{"RETIREMENT", 10, 7598},
	{"ROADS", 5, 7599},
	{"STPR", 4, 7600},
	{"MOON", 4, 7601},
	{"DUBLIN", 6, 7602},
	{"FELL", 4, 7603},
	{"MOTORCYCLE", 10, 7604},
	{"TOWER", 5, 7605},
	{"DISCLOSURE", 10, 7606},
	{"EDPE", 4, 7607},
	{"YPIC", 4, 7608},
	{"CAPABLE", 7, 7609},
	{"MEMORIES", 8, 7610},
	{"RTIE", 4, 7611},
	{"NELSON", 6, 7612},
	{"PRISONER", 8, 7613},
	{"IGNS", 4, 7614},
	{"RVIV", 4, 7615},
	{"CREATES", 7, 7616},
	{"FACES", 5, 7617},
	{"STPA", 4, 7618},
	{"YREA", 4, 7619},
	{"NIMP", 4, 7620},
	{"STLY", 4, 7621},
	{"STWA", 4, 7622},
	{"SURELY", 6, 7623},
	{"MAYOR", 5, 7624},
	{"OVY", 3, 7625},
	{"NGDI", 4, 7626},
	{"ONEL", 4, 7627},
	{"TOURIST", 7, 7628},
	{"EMST", 4, 7629},
	{"PRESENTATIONS", 13, 7630},
	{"GRADES", 6, 7631},
	{"SALARY", 6, 7632},
	{"TILI", 4, 7633},
	{"CARTOONS", 8, 7634},
	{"EATL", 4, 7635},
	{"LUSI", 4, 7636},
	{"DIVERSITY", 9, 7637},
	{"DIGEST", 6, 7638},
	{"REG", 3, 7639},
	{"LODGING", 7, 7640},
	{"REUN", 4, 7641},
	{"ATOU", 4, 7642},
	{"WIKI", 4, 7643},
	{"CHHE", 4, 7644},
	{"REPLACED", 8, 7645},
	{"THOD", 4, 7646},
	{"DDOW", 4, 7647},
	{"NFIN", 4, 7648},
	{"ONJU", 4, 7649},
	{"PINK", 4, 7650},
	{"OLDA", 4, 7651},
	{"STOMACH", 7, 7652},
	{"EDNO", 4, 7653},
	{"EDUR", 4, 7654},
	{"YONT", 4, 7655},
	{"REDUCING", 8, 7656},
	{"RECIPE", 6, 7657},
	{"KEND", 4, 7658},
	{"STOPPED", 7, 7659},
	{"DHAD", 4, 7660},
	{"ELEMENTARY", 10, 7661},
	{"NALM", 4, 7662},
	{"BELT", 4, 7663},
	{"LAKES", 5, 7664},
	{"NEARBY", 6, 7665},
	{"ALWI", 4, 7666},
	{"DONATIONS", 9, 7667},
	{"ASSOCIATIONS", 12, 7668},
	{"CITYSEARCH", 10, 7669},
	{"OBSERVER", 8, 7670},
	{"TERRORISM", 9, 7671},
	{"EFLE", 4, 7672},
	{"ESSAY", 5, 7673},
	{"JUNIOR", 6, 7674},
	{"LATIN", 5, 7675},
	{"KINGS", 5, 7676},
	{"OMUC", 4, 7677},
	{"DAYI", 4, 7678},
	{"NTOU", 4, 7679},
	{"GISL", 4, 7680},
	{"VENS", 4, 7681},
	{"RLYS", 4, 7682},
	{"KENT", 4, 7683},
	{"NGWO", 4, 7684},
	{"ONION", 5, 7685},
	{"EDSI", 4, 7686},
	{"TTOC", 4, 7687},
	{"ADDS", 4, 7688},
	{"ZME", 3, 7689},
	{"CONFRONT", 8, 7690},
	{"MM-HMM", 6, 7691},
	{"FLAGS", 5, 7692},
	{"LRES", 4, 7693},
	{"OUDO", 4, 7694},
	{"PCI", 3, 7695},
	{"BAKER", 5, 7696},
	{"LAUNCHED", 8, 7697},
	{"STMO", 4, 7698},
	{"TBET", 4, 7699},
	{"CORN", 4, 7700},
	{"SFAT", 4, 7701},
	{"GUESTBOOK", 9, 7702},
	{"OYEA", 4, 7703},
	{"LZI", 3, 7704},
	{"CROP", 4, 7705},
	{"SOFB", 4, 7706},
	{"CKLE", 4, 7707},
	{"TESTING", 7, 7708},
	{"WALLS", 5, 7709},
	{"EBONY", 5, 7710},
	{"RWIL", 4, 7711},
	{"WARD", 4, 7712},
	{"EPEA", 4, 7713},
	{"DRAWN", 5, 7714},
	{"ARTHUR", 6, 7715},
	{"UKY", 3, 7716},
	{"WLX", 3, 7717},
	{"POEM", 4, 7718},
	{"VISITED", 7, 7719},
	{"WALKER", 6, 7720},
	{"PTUR", 4, 7721},
	{"ITSB", 4, 7722},
	{"BUCK", 4, 7723},
	{"SUGGESTS", 8, 7724},
	{"INMI", 4, 7725},
	{"REPUTATION", 10, 7726},
	{"AMEF", 4, 7727},
	{"OURM", 4, 7728},
	{"VBU", 3, 7729},
	{"UNNE", 4, 7730},
	{"EMPLOYMENT", 10, 7731},
	{"OPERATED", 8, 7732},
	{"TROO", 4, 7733},
	{"PURE", 4, 7734},
	{"PERFECTLY", 9, 7735},
	{"EEFF", 4, 7736},
	{"GRANDMOTHER", 11, 7737},
	{"ACCOMPANY", 9, 7738},
	{"TARGETS", 7, 7739},
	{"RALC", 4, 7740},
	{"ESSM", 4, 7741},
	{"OVERSEAS", 8, 7742},
	{"INBO", 4, 7743},
	{"PURCHASES", 9, 7744},
	{"DODGE", 5, 7745},
	{"OWHA", 4, 7746},
	{"FEDERATION", 10, 7747},
	{"FLAG", 4, 7748},
	{"ORIGIN", 6, 7749},
	{"INVITED", 7, 7750},
	{"CONSULTANT", 10, 7751},
	{"KTHA", 4, 7752},
	{"INJA", 4, 7753},
	{"DIG", 3, 7754},
	{"EDLA", 4, 7755},
	{"IEDI", 4, 7756},
	{"ESDE", 4, 7757},
	{"YARDS", 5, 7758},
	{"KUY", 3, 7759},
	{"SDUR", 4, 7760},
	{"TEENAGER", 8, 7761},
	{"FIBER", 5, 7762},
	{"CHEMICALS", 9, 7763},
	{"GTOA", 4, 7764},
	{"ASTF", 4, 7765},
	{"JOURNEY", 7, 7766},
	{"ABSENCE", 7, 7767},
	{"GORDON", 6, 7768},
	{"MOD", 3, 7769},
	{"FARMERS", 7, 7770},
	{"HASM", 4, 7771},
	{"CLINICAL", 8, 7772},
	{"TBEA", 4, 7773},
	{"EOFW", 4, 7774},
	{"QUERIES", 7, 7775},
	{"LLYF", 4, 7776},
	{"BMW", 3, 7777},
	{"FELLOW", 6, 7778},
	{"ICRO", 4, 7779},
	{"INSTALL", 7, 7780},
	{"CKQ", 3, 7781},
	{"UKRAINE", 7, 7782},
	{"OBIL", 4, 7783},
	{"TYIS", 4, 7784},
	{"DCAN", 4, 7785},
	{"NEAREST", 7, 7786},
	{"VENDORS", 7, 7787},
	{"MPEG", 4, 7788},
	{"YOGA", 4, 7789},
	{"RNOT", 4, 7790},
	{"SERVES", 6, 7791},
	{"SMUC", 4, 7792},
	{"AKEO", 4, 7793},
	{"PREPARATION", 11, 7794},
	{"GYOU", 4, 7795},
	{"WOODS", 5, 7796},
	{"RSFR", 4, 7797},
	{"INNER", 5, 7798},
	{"RICO", 4, 7799},
	{"DBAC", 4, 7800},
	{"SHOPPERS", 8, 7801},
	{"ENTERPRISE", 10, 7802},
	{"RVES", 4, 7803},
	{"YOTH", 4, 7804},
	{"RELATIVE", 8, 7805},
	{"ULDC", 4, 7806},
	{"PHIL", 4, 7807},
	{"HESW", 4, 7808},
	{"TNOW", 4, 7809},
	{"HMEN", 4, 7810},
	{"COUPLES", 7, 7811},
	{"NASHVILLE", 9, 7812},
	{"EACO", 4, 7813},
	{"EPOW", 4, 7814},
	{"RANKING", 7, 7815},
	{"JOKES", 5, 7816},
	{"WOODEN", 6, 7817},
	{"TDIS", 4, 7818},
	{"COAST", 5, 7819},
	{"HTTP", 4, 7820},
	{"SIMPSON", 7, 7821},
	{"DDRE", 4, 7822},
	{"HISTORIC", 8, 7823},
	{"TOCR", 4, 7824},
	{"TWIKI", 5, 7825},
	{"OMPR", 4, 7826},
	{"HHER", 4, 7827},
	{"QUIETLY", 7, 7828},
	{"UXC", 3, 7829},
	{"JIV", 3, 7830},
	{"SUBLIME", 7, 7831},
	{"NDAB", 4, 7832},
	{"SATISFIED", 9, 7833},
	{"CANP", 4, 7834},
	{"ANKI", 4, 7835},
	{"WINS", 4, 7836},
	{"XYS", 3, 7837},
	{"EHEW", 4, 7838},
	{"UPWI", 4, 7839},
	{"LLSE", 4, 7840},
	{"ULLE", 4, 7841},
	{"NDGE", 4, 7842},
	{"ONEB", 4, 7843},
	{"BEAB", 4, 7844},
	{"HYJ", 3, 7845},
	{"EXV", 3, 7846},
	{"VIEWER", 6, 7847},
	{"MEASUREMENTS", 12, 7848},
	{"VERIFY", 6, 7849},
	{"FTJ", 3, 7850},
	{"AKV", 3, 7851},
	{"TRUSTED", 7, 7852},
	{"COPPER", 6, 7853},
	{"OMEM", 4, 7854},
	{"MILWAUKEE", 9, 7855},
	{"RYST", 4, 7856},
	{"EMAK", 4, 7857},
	{"MSIN", 4, 7858},
	{"HISTORIAN", 9, 7859},
	{"SHAREWARE", 9, 7860},
	{"APPARENT", 8, 7861},
	{"ASSUMPTION", 10, 7862},
	{"NGYO", 4, 7863},
	{"GHTN", 4, 7864},
	{"URSD", 4, 7865},
	{"NTPR", 4, 7866},
	{"REP", 3, 7867},
	{"DICKE", 5, 7868},
	{"KERRY", 5, 7869},
	{"LITERALLY", 9, 7870},
	{"RECEIPT", 7, 7871},
	{"URNT", 4, 7872},
	{"OHER", 4, 7873},
	{"STUR", 4, 7874},
	{"ESTF", 4, 7875},
	{"CHEEK", 5, 7876},
	{"RUAR", 4, 7877},
	{"GHES", 4, 7878},
	{"LYSI", 4, 7879},
	{"GZE", 3, 7880},
	{"PERMANENT", 9, 7881},
	{"NDAF", 4, 7882},
	{"IALT", 4, 7883},
	{"INGREDIENT", 10, 7884},
	{"OFAP", 4, 7885},
	{"NGNE", 4, 7886},
	{"YPRE", 4, 7887},
	{"YNR", 3, 7888},
	{"DRAWING", 7, 7889},
	{"CONFIGURE", 9, 7890},
	{"SUBSTANTIAL", 11, 7891},
	{"EFIG", 4, 7892},
	{"SMEN", 4, 7893},
	{"TUBE", 4, 7894},
	{"SNAP", 4, 7895},
	{"SDEF", 4, 7896},
	{"BUTO", 4, 7897},
	{"APPLYING", 8, 7898},
	{"OVG", 3, 7899},
	{"RALT", 4, 7900},
	{"ARISE", 5, 7901},
	{"YPAR", 4, 7902},
	{"SSIG", 4, 7903},
	{"EXPECTATIONS", 12, 7904},
	{"ARKI", 4, 7905},
	{"OWWH", 4, 7906},
	{"CAKE", 4, 7907},
	{"RESIST", 6, 7908},
	{"KNOWING", 7, 7909},
	{"ZIZ", 3, 7910},
	{"OVEL", 4, 7911},
	{"NGSW", 4, 7912},
	{"LICY", 4, 7913},
	{"JAIL", 4, 7914},
	{"ISLAMIC", 7, 7915},
	{"ZYG", 3, 7916},
	{"NDGO", 4, 7917},
	{"RKAN", 4, 7918},
	{"OCCASIONALLY", 12, 7919},
	{"BRUA", 4, 7920},
	{"ISUS", 4, 7921},
	{"REDH", 4, 7922},
	{"METABOLISM", 10, 7923},
	{"KEITH", 5, 7924},
	{"INCORPORATE", 11, 7925},
	{"OODT", 4, 7926},
	{"ECRO", 4, 7927},
	{"CLOUDY", 6, 7928},
	{"LINDA", 5, 7929},
	{"LLFO", 4, 7930},
	{"HCON", 4, 7931},
	{"OURB", 4, 7932},
	{"ROSS", 4, 7933},
	{"CHILE", 5, 7934},
	{"TTOG", 4, 7935},
	{"SOLO", 4, 7936},
	{"REWH", 4, 7937},
	{"CYV", 3, 7938},
	{"EFFECTIVELY", 11, 7939},
	{"DARKNESS", 8, 7940},
	{"LENC", 4, 7941},
	{"MARIA", 5, 7942},
	{"CONCERT", 7, 7943},
	{"ASDI", 4, 7944},
	{"IMEW", 4, 7945},
	{"LLMA", 4, 7946},
	{"EXCELLENCE", 10, 7947},
	{"PROVISION", 9, 7948},
	{"NALR", 4, 7949},
	{"ADEI", 4, 7950},
	{"UNLIKE", 6, 7951},
	{"TUW", 3, 7952},
	{"AYFR", 4, 7953},
	{"TIZE", 4, 7954},
	{"URPO", 4, 7955},
	{"OUAR", 4, 7956},
	{"FAVOR", 5, 7957},
	{"SAPR", 4, 7958},
	{"BIOLOGICAL", 10, 7959},
	{"ECTL", 4, 7960},
	{"ATTRIBUTES", 10, 7961},
	{"BRASS", 5, 7962},
	{"SASW", 4, 7963},
	{"NGTI", 4, 7964},
	{"EWEE", 4, 7965},
	{"HEHU", 4, 7966},
	{"STPO", 4, 7967},
	{"SENC", 4, 7968},
	{"CONVENTIONAL", 12, 7969},
	{"ULZ", 3, 7970},
	{"INTENTION", 9, 7971},
	{"WRITES", 6, 7972},
	{"PLAZA", 5, 7973},
	{"KSIN", 4, 7974},
	{"ZIW", 3, 7975},
	{"YVS", 3, 7976},
	{"DTOE", 4, 7977},
	{"PDAS", 4, 7978},
	{"EKEN", 4, 7979},
	{"OUTCOMES", 8, 7980},
	{"ESLA", 4, 7981},
	{"INGJ", 4, 7982},
	{"IALP", 4, 7983},
	{"AGGRESSIVE", 10, 7984},
	{"NEVERTHELESS", 12, 7985},
	{"EMBRACE", 7, 7986},
	{"SECURE", 6, 7987},
	{"LLNO", 4, 7988},
	{"THUMBNAIL", 9, 7989},
	{"TRANS", 5, 7990},
	{"EARW", 4, 7991},
	{"EGOO", 4, 7992},
	{"DEVELOPING", 10, 7993},
	{"JONATHAN", 8, 7994},
	{"NOVA", 4, 7995},
	{"NDSW", 4, 7996},
	{"SSOU", 4, 7997},
	{"SGRE", 4, 7998},
	{"RSEN", 4, 7999},
	{"BOOTY", 5, 8000},
	{"TREP", 4, 8001},
	{"NALB", 4, 8002},
	{"FIFTH", 5, 8003},
	{"UTILITY", 7, 8004},
	{"FORGOTTEN", 9, 8005},
	{"ACROBAT", 7, 8006},
	{"MUSLIM", 6, 8007},
	{"IXV", 3, 8008},
	{"SUGGESTION", 10, 8009},
	{"PLATES", 6, 8010},
	{"ACRES", 5, 8011},
	{"LESW", 4, 8012},
	{"VENUE", 5, 8013},
	{"DCHI", 4, 8014},
	{"NREA", 4, 8015},
	{"DOFA", 4, 8016},
	{"YELL", 4, 8017},
	{"REASONABLE", 10, 8018},
	{"EDHO", 4, 8019},
	{"PURC", 4, 8020},
	{"POP", 3, 8021},
	{"THERMAL", 7, 8022},
	{"ESSAYS", 6, 8023},
	{"IVEF", 4, 8024},
	{"NGTR", 4, 8025},
	{"SENSITIVE", 9, 8026},
	{"BEHAVIOUR", 9, 8027},
	{"YTOS", 4, 8028},
	{"BIND", 4, 8029},
	{"RSER", 4, 8030},
	{"LGY", 3, 8031},
	{"OUSS", 4, 8032},
	{"LBER", 4, 8033},
	{"BRAND", 5, 8034},
	{"LYPR", 4, 8035},
	{"DFOU", 4, 8036},
	{"RTTO", 4, 8037},
	{"HIEV", 4, 8038},
	{"TELLING", 7, 8039},
	{"VGU", 3, 8040},
	{"SOFW", 4, 8041},
	{"NDEM", 4, 8042},
	{"CONFIG", 6, 8043},
	{"SABL", 4, 8044},
	{"YYEA", 4, 8045},
	{"EDINBURGH", 9, 8046},
	{"NCHO", 4, 8047},
	{"EXCEL", 5, 8048},
	{"OLYMPIC", 7, 8049},
	{"MODES", 5, 8050},
	{"RAPIDLY", 7, 8051},
	{"LLIT", 4, 8052},
	{"EXTREME", 7, 8053},
	{"CAMPBELL", 8, 8054},
	{"HARBOR", 6, 8055},
	{"SSUM", 4, 8056},
	{"HUNGARY", 7, 8057},
	{"BLEO", 4, 8058},
	{"WEIGH", 5, 8059},
	{"URW", 3, 8060},
	{"ONAC", 4, 8061},
	{"QUIT", 4, 8062},
	{"ALLM", 4, 8063},
	{"NEGOTIATE", 9, 8064},
	{"SMUS", 4, 8065},
	{"SPECIALIST", 10, 8066},
	{"CONSTANTLY", 10, 8067},
	{"WAGE", 4, 8068},
	{"RALD", 4, 8069},
	{"EMOD", 4, 8070},
	{"OSUR", 4, 8071},
	{"RISING", 6, 8072},
	{"EIRL", 4, 8073},
	{"WELLS", 5, 8074},
	{"ASFI", 4, 8075},
	{"NALF", 4, 8076},
	{"WISHLIST", 8, 8077},
	{"OPENS", 5, 8078},
	{"REFUGEE", 7, 8079},
	{"LLAL", 4, 8080},
	{"EBOU", 4, 8081},
	{"VEFO", 4, 8082},
	{"GSTA", 4, 8083},
	{"RESTRICTED", 10, 8084},
	{"SECRETS", 7, 8085},
	{"DEALER", 6, 8086},
	{"EDSH", 4, 8087},
	{"ORID", 4, 8088},
	{"UMJ", 3, 8089},
	{"ENMO", 4, 8090},
	{"MERCHANTS", 9, 8091},
	{"UTTI", 4, 8092},
	{"OFTO", 4, 8093},
	{"YSAN", 4, 8094},
	{"DBYS", 4, 8095},
	{"TRAILERS", 8, 8096},
	{"ASEB", 4, 8097},
	{"HYK", 3, 8098},
	{"DEPUTY", 6, 8099},
	{"PHILIPS", 7, 8100},
	{"ZZC", 3, 8101},
	{"SCLO", 4, 8102},
	{"ARMED", 5, 8103},
	{"GIANT", 5, 8104},
	{"NSCH", 4, 8105},
	{"TEXP", 4, 8106},
	{"GLASSES", 7, 8107},
	{"SHELL", 5, 8108},
	{"ENABLES", 7, 8109},
	{"RREA", 4, 8110},
	{"NNUA", 4, 8111},
	{"GSIN", 4, 8112},
	{"IGJ", 3, 8113},
	{"TMAY", 4, 8114},
	{"MECHANISM", 9, 8115},
	{"NCOR", 4, 8116},
	{"NTOD", 4, 8117},
	{"LYWA", 4, 8118},
	{"XCEP", 4, 8119},
	{"VISTA", 5, 8120},
	{"ORPE", 4, 8121},
	{"KOUT", 4, 8122},
	{"JESSICA", 7, 8123},
	{"CHIPS", 5, 8124},
	{"TERRY", 5, 8125},
	{"FOTO", 4, 8126},
	{"DEPTH", 5, 8127},
	{"ARGUMENTS", 9, 8128},
	{"EWEA", 4, 8129},
	{"AMSTERDAM", 9, 8130},
	{"TYFO", 4, 8131},
	{"RSMA", 4, 8132},
	{"ADVENTURES", 10, 8133},
	{"HONEST", 6, 8134},
	{"REEX", 4, 8135},
	{"FPRO", 4, 8136},
	{"CRITICIZE", 9, 8137},
	{"YUW", 3, 8138},
	{"PUPILS", 6, 8139},
	{"STEWART", 7, 8140},
	{"TABS", 4, 8141},
	{"MAD", 3, 8142},
	{"NDBO", 4, 8143},
	{"EEDO", 4, 8144},
	{"FLAT", 4, 8145},
	{"DSAI", 4, 8146},
	{"OFDI", 4, 8147},
	{"PACE", 4, 8148},
	{"NTME", 4, 8149},
	{"SPEAKER", 7, 8150},
	{"EXPANDED", 8, 8151},
	{"GROWN", 5, 8152},
	{"WEALTH", 6, 8153},
	{"SCUR", 4, 8154},
	{"EBRE", 4, 8155},
	{"ESYS", 4, 8156},
	{"POLISH", 6, 8157},
	{"EXTRAS", 6, 8158},
	{"PRECISELY", 9, 8159},
	{"AWARD", 5, 8160},
	{"ENAB", 4, 8161},
	{"GEAR", 4, 8162},
	{"ONEF", 4, 8163},
	{"FALSE", 5, 8164},
	{"HTOF", 4, 8165},
	{"HBOR", 4, 8166},
	{"NDAP", 4, 8167},
	{"CENTRES", 7, 8168},
	{"URAG", 4, 8169},
	{"JERRY", 5, 8170},
	{"EPHO", 4, 8171},
	{"CLAUSE", 6, 8172},
	{"TWHO", 4, 8173},
	{"SHIG", 4, 8174},
	{"LANDS", 5, 8175},
	{"IGNO", 4, 8176},
	{"TROOPS", 6, 8177},
	{"ASSIGN", 6, 8178},
	{"TESW", 4, 8179},
	{"COOPERATION", 11, 8180},
	{"TEWI", 4, 8181},
	{"INDOOR", 6, 8182},
	{"BULGARIA", 8, 8183},
	{"THMA", 4, 8184},
	{"FIFT", 4, 8185},
	{"SHOM", 4, 8186},
	{"CHARGER", 7, 8187},
	{"AREU", 4, 8188},
	{"CANADIAN", 8, 8189},
	{"RESTORE", 7, 8190},
	{"BELIEVED", 8, 8191},
	{"RHAP", 4, 8192},
	{"XPRE", 4, 8193},
	{"ICHO", 4, 8194},
	{"COOLING", 7, 8195},
	{"LITERARY", 8, 8196},
	{"LYWH", 4, 8197},
	{"APPROVAL", 8, 8198},
	{"LDCO", 4, 8199},
	{"GULF", 4, 8200},
	{"TTAK", 4, 8201},
	{"RICK", 4, 8202},
	{"NJUN", 4, 8203},
	{"CKLY", 4, 8204},
	{"SWIF", 4, 8205},
	{"TRUCKS", 6, 8206},
	{"DETO", 4, 8207},
	{"BARRIER", 7, 8208},
	{"MECHANISMS", 10, 8209},
	{"YDT", 3, 8210},
	{"SGRA", 4, 8211},
	{"LAURA", 5, 8212},
	{"SHOPPER", 7, 8213},
	{"TOKYO", 5, 8214},
	{"ATSW", 4, 8215},
	{"NIKON", 5, 8216},
	{"TELESCOPE", 9, 8217},
	{"INDEX", 5, 8218},
	{"EEXT", 4, 8219},
	{"CUSTOMIZE", 9, 8220},
	{"IMPRESSION", 10, 8221},
	{"LFIN", 4, 8222},
	{"EFLO", 4, 8223},
	{"NTEX", 4, 8224},
	{"ACTIVIST", 8, 8225},
	{"AYOR", 4, 8226},
	{"SGIV", 4, 8227},
	{"ATAB", 4, 8228},
	{"PILLS", 5, 8229},
	{"TIGER", 5, 8230},
	{"YVU", 3, 8231},
	{"ORYE", 4, 8232},
	{"DONALD", 6, 8233},
	{"FOLKS", 5, 8234},
	{"YDON", 4, 8235},
	{"NGSC", 4, 8236},
	{"EXPOSED", 7, 8237},
	{"TELECOM", 7, 8238},
	{"KTY", 3, 8239},
	{"ANGELS", 6, 8240},
	{"NDEL", 4, 8241},
	{"SINM", 4, 8242},
	{"LPED", 4, 8243},
	{"ANOP", 4, 8244},
	{"TRET", 4, 8245},
	{"INDICATORS", 10, 8246},
	{"INEM", 4, 8247},
	{"SEALED", 6, 8248},
	{"DUND", 4, 8249},
	{"EVET", 4, 8250},
	{"ETYO", 4, 8251},
	{"OEXP", 4, 8252},
	{"NWER", 4, 8253},
	{"ILWA", 4, 8254},
	{"ICKI", 4, 8255},
	{"OGIV", 4, 8256},
	{"SPOKESMAN", 9, 8257},
	{"EMISSIONS", 9, 8258},
	{"PHYSICIANS", 10, 8259},
	{"ZCH", 3, 8260},
	{"RALM", 4, 8261},
	{"UCHO", 4, 8262},
	{"TIND", 4, 8263},
	{"LOADED", 6, 8264},
	{"CYJ", 3, 8265},
	{"DRAFT", 5, 8266},
	{"TOURNAMENT", 10, 8267},
	{"CHOCOLATE", 9, 8268},
	{"KEDI", 4, 8269},
	{"SYV", 3, 8270},
	{"EYON", 4, 8271},
	{"TESTIMONY", 9, 8272},
	{"INBU", 4, 8273},
	{"FRED", 4, 8274},
	{"CHEMICAL", 8, 8275},
	{"SPIN", 4, 8276},
	{"IMTH", 4, 8277},
	{"CEILING", 7, 8278},
	{"WHEREAS", 7, 8279},
	{"SCENES", 6, 8280},
	{"EXPERIMENTS", 11, 8281},
	{"ASAG", 4, 8282},
	{"SFAM", 4, 8283},
	{"GANG", 4, 8284},
	{"OMEE", 4, 8285},
	{"BALLS", 5, 8286},
	{"LAWSUIT", 7, 8287},
	{"WLED", 4, 8288},
	{"AFGHANISTAN", 11, 8289},
	{"RCAN", 4, 8290},
	{"HIGHWAY", 7, 8291},
	{"WAYA", 4, 8292},
	{"SPANKING", 8, 8293},
	{"EDPA", 4, 8294},
	{"IWOU", 4, 8295},
	{"DIQ", 3, 8296},
	{"GOVERNANCE", 10, 8297},
	{"YIELD", 5, 8298},
	{"FOUNDED", 7, 8299},
	{"SUPPLEMENTS", 11, 8300},
	{"KILLER", 6, 8301},
	{"VALUABLE", 8, 8302},
	{"ICONS", 5, 8303},
	{"IPZ", 3, 8304},
	{"CATERING", 8, 8305},
	{"SOFR", 4, 8306},
	{"GYZ", 3, 8307},
	{"AUD", 3, 8308},
	{"CORPORATION", 11, 8309},
	{"YYOU", 4, 8310},
	{"ONPA", 4, 8311},
	{"CLASSIC", 7, 8312},
	{"ICST", 4, 8313},
	{"MEFR", 4, 8314},
	{"HLET", 4, 8315},
	{"OXX", 3, 8316},
	{"OMFO", 4, 8317},
	{"STAKE", 5, 8318},
	{"ILLW", 4, 8319},
	{"KEEPS", 5, 8320},
	{"ADVERTISING", 11, 8321},
	{"ATPR", 4, 8322},
	{"UNIVERSAL", 9, 8323},
	{"CAMCORDER", 9, 8324},
	{"TRAINED", 7, 8325},
	{"OOLI", 4, 8326},
	{"SUPER", 5, 8327},
	{"NLYO", 4, 8328},
	{"NBET", 4, 8329},
	{"PAUSE", 5, 8330},
	{"YSTR", 4, 8331},
	{"HOWM", 4, 8332},
	{"NGEO", 4, 8333},
	{"ROUTINE", 7, 8334},
	{"RUJ", 3, 8335},
	{"TPEO", 4, 8336},
	{"TKY", 3, 8337},
	{"IMPLEMENTING", 12, 8338},
	{"CONSTITUTIONAL", 14, 8339},
	{"ROSES", 5, 8340},
	{"ADVOCATE", 8, 8341},
	{"KSTH", 4, 8342},
	{"LABS", 4, 8343},
	{"ABIG", 4, 8344},
	{"UGGL", 4, 8345},
	{"EITW", 4, 8346},
	{"PHRASE", 6, 8347},
	{"LEHA", 4, 8348},
	{"KUF", 3, 8349},
	{"ONDT", 4, 8350},
	{"ZFI", 3, 8351},
	{"BUTTON", 6, 8352},
	{"TDAY", 4, 8353},
	{"YABO", 4, 8354},
	{"MOTORS", 6, 8355},
	{"HEYO", 4, 8356},
	{"ASSURE", 6, 8357},
	{"ULTIMATE", 8, 8358},
	{"DISTANT", 7, 8359},
	{"DTHO", 4, 8360},
	{"HPRO", 4, 8361},
	{"OWNW", 4, 8362},
	{"ROBERTS", 7, 8363},
	{"YWHO", 4, 8364},
	{"RDON", 4, 8365},
	{"YOFA", 4, 8366},
	{"LATTER", 6, 8367},
	{"GONNA", 5, 8368},
	{"DSHI", 4, 8369},
	{"CRM", 3, 8370},
	{"LSOP", 4, 8371},
	{"ANSL", 4, 8372},
	{"SWITCH", 6, 8373},
	{"UXD", 3, 8374},
	{"RSTI", 4, 8375},
	{"TLER", 4, 8376},
	{"BILLY", 5, 8377},
	{"ATWH", 4, 8378},
	{"LABEL", 5, 8379},
	{"CTST", 4, 8380},
	{"REVENUES", 8, 8381},
	{"SSIC", 4, 8382},
	{"ERDO", 4, 8383},
	{"WORSHIP", 7, 8384},
	{"YTRA", 4, 8385},
	{"HEAB", 4, 8386},
	{"QYO", 3, 8387},
	{"TOFL", 4, 8388},
	{"DQUA", 4, 8389},
	{"CRAIG", 5, 8390},
	{"STUPID", 6, 8391},
	{"NGEA", 4, 8392},
	{"POUN", 4, 8393},
	{"PRODUCING", 9, 8394},
	{"RSRE", 4, 8395},
	{"HEAVEN", 6, 8396},
	{"FURNITURE", 9, 8397},
	{"ZZM", 3, 8398},
	{"NDDA", 4, 8399},
	{"PANT", 4, 8400},
	{"CHURCHES", 8, 8401},
	{"PRECISION", 9, 8402},
	{"DAMAGES", 7, 8403},
	{"EEKE", 4, 8404},
	{"RESERVES", 8, 8405},
	{"UXF", 3, 8406},
	{"CONTRIBUTED", 11, 8407},
	{"ILLF", 4, 8408},
	{"LSOI", 4, 8409},
	{"SATELLITE", 9, 8410},
	{"WIPE", 4, 8411},
	{"REPRODUCTION", 12, 8412},
	{"SWEEP", 5, 8413},
	{"SRAE", 4, 8414},
	{"VACATION", 8, 8415},
	{"BELL", 4, 8416},
	{"LLYP", 4, 8417},
	{"AMP", 3, 8418},
	{"UTST", 4, 8419},
	{"OYK", 3, 8420},
	{"INGREDIENTS", 11, 8421},
	{"RSBE", 4, 8422},
	{"YALS", 4, 8423},
	{"ULDR", 4, 8424},
	{"YREC", 4, 8425},
	{"NORMALLY", 8, 8426},
	{"INFECTION", 9, 8427},
	{"EOFB", 4, 8428},
	{"JOHNNY", 6, 8429},
	{"NAUG", 4, 8430},
	{"GETI", 4, 8431},
	{"CLOCK", 5, 8432},
	{"HASR", 4, 8433},
	{"DRAMA", 5, 8434},
	{"EADV", 4, 8435},
	{"FENCE", 5, 8436},
	{"ILTO", 4, 8437},
	{"RECORDER", 8, 8438},
	{"ORUS", 4, 8439},
	{"YEVE", 4, 8440},
	{"ITALIAN", 7, 8441},
	{"COMPLAINTS", 10, 8442},
	{"EBLO", 4, 8443},
	{"ZYC", 3, 8444},
	{"ITBE", 4, 8445},
	{"FACING", 6, 8446},
	{"RESORT", 6, 8447},
	{"NANCY", 5, 8448},
	{"URST", 4, 8449},
	{"FOUND", 5, 8450},
	{"AYOU", 4, 8451},
	{"PROMOTIONS", 10, 8452},
	{"TRYA", 4, 8453},
	{"TONES", 5, 8454},
	{"EDFI", 4, 8455},
	{"HOIC", 4, 8456},
	{"ROUGH", 5, 8457},
	{"MAINTAINING", 11, 8458},
	{"AYHA", 4, 8459},
	{"YINS", 4, 8460},
	{"ECTU", 4, 8461},
	{"LAID", 4, 8462},
	{"EXTRAORDINARY", 13, 8463},
	{"DESTRUCTION", 11, 8464},
	{"DEFENCE", 7, 8465},
	{"PATCHES", 7, 8466},
	{"SEFO", 4, 8467},
	{"STRATEGIC", 9, 8468},
	{"MINOR", 5, 8469},
	{"NSUL", 4, 8470},
	{"TISSUE", 6, 8471},
	{"TERROR", 6, 8472},
	{"PORTRAIT", 8, 8473},
	{"REFUND", 6, 8474},
	{"USC", 3, 8475},
	{"TOWNS", 5, 8476},
	{"WSTH", 4, 8477},
	{"SURVIVAL", 8, 8478},
	{"ZFR", 3, 8479},
	{"HDY", 3, 8480},
	{"ENVIRONMENTS", 12, 8481},
	{"PREGNANT", 8, 8482},
	{"ELITE", 5, 8483},
	{"YINA", 4, 8484},
	{"TREMBL", 6, 8485},
	{"DIVIDED", 7, 8486},
	{"ERYD", 4, 8487},
	{"INTERPRET", 9, 8488},
	{"BLVD", 4, 8489},
	{"PERSONALLY", 10, 8490},
	{"AMD", 3, 8491},
	{"JPU", 3, 8492},
	{"PENALTY", 7, 8493},
	{"NGAF", 4, 8494},
	{"WEDN", 4, 8495},
	{"TMEA", 4, 8496},
	{"XVE", 3, 8497},
	{"NMON", 4, 8498},
	{"EOPP", 4, 8499},
	{"EMAILS", 6, 8500},
	{"OSAY", 4, 8501},
	{"CYPRUS", 6, 8502},
	{"ASTL", 4, 8503},
	{"DISAGREE", 8, 8504},
	{"INSIDER", 7, 8505},
	{"NLIK", 4, 8506},
	{"DAYW", 4, 8507},
	{"SEMINARS", 8, 8508},
	{"CONSEQUENCES", 12, 8509},
	{"MAKERS", 6, 8510},
	{"OFSA", 4, 8511},
	{"HEARTS", 6, 8512},
	{"GEOGRAPHY", 9, 8513},
	{"EMAJ", 4, 8514},
	{"STRANGER", 8, 8515},
	{"EXTERNAL", 8, 8516},
	{"APPEARING", 9, 8517},
	{"INAU", 4, 8518},
	{"DGES", 4, 8519},
	{"VOIC", 4, 8520},
	{"HADO", 4, 8521},
	{"THAF", 4, 8522},
	{"BAKE", 4, 8523},
	{"CHAMPION", 8, 8524},
	{"CARTER", 6, 8525},
	{"SATISFACTION", 12, 8526},
	{"RANK", 4, 8527},
	{"LWOR", 4, 8528},
	{"INOF", 4, 8529},
	{"GENTLY", 6, 8530},
	{"LUJ", 3, 8531},
	{"ANGO", 4, 8532},
	{"EROO", 4, 8533},
	{"ESLO", 4, 8534},
	{"IPPI", 4, 8535},
	{"LLSH", 4, 8536},
	{"MARC", 4, 8537},
	{"BUNCH", 5, 8538},
	{"UPOF", 4, 8539},
	{"ARDL", 4, 8540},
	{"CEWA", 4, 8541},
	{"YDG", 3, 8542},
	{"UTWI", 4, 8543},
	{"YDID", 4, 8544},
	{"TOWH", 4, 8545},
	{"RELEVANT", 8, 8546},
	{"NOFS", 4, 8547},
	{"CKST", 4, 8548},
	{"ETWI", 4, 8549},
	{"CESW", 4, 8550},
	{"DISPUTE", 7, 8551},
	{"PROCESSED", 9, 8552},
	{"RAISING", 7, 8553},
	{"ROUGHLY", 7, 8554},
	{"IMPLICATIONS", 12, 8555},
	{"FUNCTIONALITY", 13, 8556},
	{"PARADISE", 8, 8557},
	{"RRIN", 4, 8558},
	{"DMAK", 4, 8559},
	{"LLSO", 4, 8560},
	{"IDIT", 4, 8561},
	{"LDST", 4, 8562},
	{"DTOI", 4, 8563},
	{"HYBRID", 6, 8564},
	{"READS", 5, 8565},
	{"ROLES", 5, 8566},
	{"SIMILARLY", 9, 8567},
	{"COMMUNICATE", 11, 8568},
	{"ODAN", 4, 8569},
	{"INTERMEDIATE", 12, 8570},
	{"IHAD", 4, 8571},
	{"APPLE", 5, 8572},
	{"STAIR", 5, 8573},
	{"PLATFORMS", 9, 8574},
	{"COUNSELOR", 9, 8575},
	{"TERRORIST", 9, 8576},
	{"BIGGER", 6, 8577},
	{"BILLING", 7, 8578},
	{"EDUL", 4, 8579},
	{"DIESEL", 6, 8580},
	{"NGSP", 4, 8581},
	{"CESH", 4, 8582},
	{"COUSIN", 6, 8583},
	{"XOU", 3, 8584},
	{"GEOGRAPHIC", 10, 8585},
	{"RDSO", 4, 8586},
	{"UIK", 3, 8587},
	{"CONCENTRATION", 13, 8588},
	{"DPRI", 4, 8589},
	{"SAUDI", 5, 8590},
	{"EENB", 4, 8591},
	{"EYWO", 4, 8592},
	{"EVOT", 4, 8593},
	{"ECUL", 4, 8594},
	{"CUBA", 4, 8595},
	{"ULDL", 4, 8596},
	{"DISTRICTS", 9, 8597},
	{"SOLAR", 5, 8598},
	{"TOGI", 4, 8599},
	{"XPEN", 4, 8600},
	{"ADVISER", 7, 8601},
	{"DHEL", 4, 8602},
	{"MHY", 3, 8603},
	{"OYEE", 4, 8604},
	{"APHI", 4, 8605},
	{"EBSI", 4, 8606},
	{"UTFO", 4, 8607},
	{"VIRUS", 5, 8608},
	{"AINW", 4, 8609},
	{"INCENTIVE", 9, 8610},
	{"SALAD", 5, 8611},
	{"PROMOTIONAL", 11, 8612},
	{"HUNTING", 7, 8613},
	{"ARYC", 4, 8614},
	{"BROKEN", 6, 8615},
	{"LLNE", 4, 8616},
	{"KATE", 4, 8617},
	{"CHEVROLET", 9, 8618},
	{"OREE", 4, 8619},
	{"SENATOR", 7, 8620},
	{"BABIES", 6, 8621},
	{"PROFILE", 7, 8622},
	{"KAREN", 5, 8623},
	{"COMPILED", 8, 8624},
	{"STATISTICS", 10, 8625},
	{"EENM", 4, 8626},
	{"TINF", 4, 8627},
	{"BOUNDARY", 8, 8628},
	{"RROU", 4, 8629},
	{"OFYO", 4, 8630},
	{"CLOTHING", 8, 8631},
	{"LNOT", 4, 8632},
	{"UITA", 4, 8633},
	{"GENETIC", 7, 8634},
	{"RVIN", 4, 8635},
	{"REVEALED", 8, 8636},
	{"SPECIALISTS", 11, 8637},
	{"DIRT", 4, 8638},
	{"REPRESENTATION", 14, 8639},
	{"GENERATOR", 9, 8640},
	{"ALBERT", 6, 8641},
	{"IMPLY", 5, 8642},
	{"NJAN", 4, 8643},
	{"OURH", 4, 8644},
	{"BURDEN", 6, 8645},
	{"EXPANSION", 9, 8646},
	{"DSEV", 4, 8647},
	{"JIMMY", 5, 8648},
	{"LLET", 4, 8649},
	{"SEDW", 4, 8650},
	{"YKL", 3, 8651},
	{"GRAHAM", 6, 8652},
	{"SUSPENSION", 10, 8653},
	{"BRISTOL", 7, 8654},
	{"ANYI", 4, 8655},
	{"MARGARET", 8, 8656},
	{"YXI", 3, 8657},
	{"RETAIN", 6, 8658},
	{"CEWH", 4, 8659},
	{"COMPAQ", 6, 8660},
	{"ISCL", 4, 8661},
	{"ILLM", 4, 8662},
	{"CHAMBER", 7, 8663},
	{"CORRECTION", 10, 8664},
	{"GHLY", 4, 8665},
	{"OFGO", 4, 8666},
	{"YLIN", 4, 8667},
	{"ORKT", 4, 8668},
	{"AUTHENTICATION", 14, 8669},
	{"INITIALLY", 9, 8670},
	{"DREP", 4, 8671},
	{"SSCH", 4, 8672},
	{"RUGBY", 5, 8673},
	{"UCHD", 4, 8674},
	{"DIVERSE", 7, 8675},
	{"SUPPLEMENT", 10, 8676},
	{"AWARENESS", 9, 8677},
	{"RTIO", 4, 8678},
	{"CORRESPONDENT", 13, 8679},
	{"ELECTRIC", 8, 8680},
	{"BLIND", 5, 8681},
	{"SHOWTIMES", 9, 8682},
	{"YCK", 3, 8683},
	{"TWOY", 4, 8684},
	{"RLJ", 3, 8685},
	{"CAL", 3, 8686},
	{"LLAB", 4, 8687},
	{"PORTIONS", 8, 8688},
	{"TLEM", 4, 8689},
	{"DVU", 3, 8690},
	{"PROMOTING", 9, 8691},
	{"EIRH", 4, 8692},
	{"OLDM", 4, 8693},
	{"DWHA", 4, 8694},
	{"SECTORS", 7, 8695},
	{"SAMUEL", 6, 8696},
	{"FWHI", 4, 8697},
	{"STRING", 6, 8698},
	{"ENCOUNTER", 9, 8699},
	{"GROUNDS", 7, 8700},
	{"FITS", 4, 8701},
	{"REGARDS", 7, 8702},
	{"EIRD", 4, 8703},
	{"MACHINERY", 9, 8704},
	{"OMBA", 4, 8705},
	{"BANDWIDTH", 9, 8706},
	{"BASKETS", 7, 8707},
	{"OVJ", 3, 8708},
	{"AVEI", 4, 8709},
	{"PROBABILITY", 11, 8710},
	{"SHOPPING", 8, 8711},
	{"WRIGHT", 6, 8712},
	{"DVIS", 4, 8713},
	{"ELECTRICITY", 11, 8714},
	{"IMG", 3, 8715},
	{"ISHM", 4, 8716},
	{"BARRY", 5, 8717},
	{"PROVEN", 6, 8718},
	{"ATHR", 4, 8719},
	{"SCHEDULES", 9, 8720},
	{"CONSTITUTE", 10, 8721},
	{"RICE", 4, 8722},
	{"ATDO", 4, 8723},
	{"ZOV", 3, 8724},
	{"ADMISSIONS", 10, 8725},
	{"NDIF", 4, 8726},
	{"ITHG", 4, 8727},
	{"GTOD", 4, 8728},
	{"CEREMONY", 8, 8729},
	{"ASAW", 4, 8730},
	{"CACHED", 6, 8731},
	{"WARREN", 6, 8732},
	{"STUDIED", 7, 8733},
	{"REVIEWER", 8, 8734},
	{"INVOLVES", 8, 8735},
	{"QUARTERLY", 9, 8736},
	{"AINF", 4, 8737},
	{"RPM", 3, 8738},
	{"PROFITS", 7, 8739},
	{"UREW", 4, 8740},
	{"ICHM", 4, 8741},
	{"ESIM", 4, 8742},
	{"MARIE", 5, 8743},
	{"ITIZ", 4, 8744},
	{"FLORIST", 7, 8745},
	{"EFRA", 4, 8746},
	{"IRLI", 4, 8747},
	{"ILLUSTRATED", 11, 8748},
	{"PORT", 4, 8749},
	{"CHERRY", 6, 8750},
	{"CONTINENTAL", 11, 8751},
	{"LOST", 4, 8752},
	{"RDZ", 3, 8753},
	{"ALTERNATE", 9, 8754},
	{"DEUTSCH", 7, 8755},
	{"REFLECTION", 10, 8756},
	{"AFET", 4, 8757},
	{"LIMITATIONS", 11, 8758},
	{"NOTP", 4, 8759},
	{"ULTO", 4, 8760},
	{"KENYA", 5, 8761},
	{"RNTO", 4, 8762},
	{"GTOG", 4, 8763},
	{"EIRT", 4, 8764},
	{"CUTS", 4, 8765},
	{"UNLIKELY", 8, 8766},
	{"ALSH", 4, 8767},
	{"NUTTEN", 6, 8768},
	{"SLAVE", 5, 8769},
	{"DSUP", 4, 8770},
	{"YOFS", 4, 8771},
	{"CHART", 5, 8772},
	{"EARRINGS", 8, 8773},
	{"AUTOMATED", 9, 8774},
	{"CHAPTERS", 8, 8775},
	{"CHARLIE", 7, 8776},
	{"ODD", 3, 8777},
	{"JOURNAL", 7, 8778},
	{"DSOU", 4, 8779},
	{"QUEBEC", 6, 8780},
	{"ATDE", 4, 8781},
	{"CABINET", 7, 8782},
	{"OREW", 4, 8783},
	{"VYN", 3, 8784},
	{"TESTIFY", 7, 8785},
	{"INTELLECTUAL", 12, 8786},
	{"DINB", 4, 8787},
	{"CONVENIENT", 10, 8788},
	{"DENNIS", 6, 8789},
	{"ASWI", 4, 8790},
	{"INBA", 4, 8791},
	{"UBJE", 4, 8792},
	{"RXA", 3, 8793},
	{"MARS", 4, 8794},
	{"FRANCIS", 7, 8795},
	{"NLAN", 4, 8796},
	{"DECK", 4, 8797},
	{"NTFR", 4, 8798},
	{"ASSISTANT", 9, 8799},
	{"RECOMMENDATION", 14, 8800},
	{"XVA", 3, 8801},
	{"SIZED", 5, 8802},
	{"MANGA", 5, 8803},
	{"FORTUNE", 7, 8804},
	{"NOTICED", 7, 8805},
	{"SOCKET", 6, 8806},
	{"EWED", 4, 8807},
	{"EXK", 3, 8808},
	{"PROCEED", 7, 8809},
	{"TERG", 4, 8810},
	{"EECH", 4, 8811},
	{"URER", 4, 8812},
	{"SIGNALS", 7, 8813},
	{"OVERCOME", 8, 8814},
	{"CAPS", 4, 8815},
	{"REVOLUTION", 10, 8816},
	{"CHARACTERIZE", 12, 8817},
	{"REHO", 4, 8818},
	{"SPOI", 4, 8819},
	{"ELSO", 4, 8820},
	{"STPE", 4, 8821},
	{"HEYM", 4, 8822},
	{"EDHA", 4, 8823},
	{"THEFT", 5, 8824},
	{"SOFL", 4, 8825},
	{"CHMO", 4, 8826},
	{"ZDO", 3, 8827},
	{"OFNO", 4, 8828},
	{"NINV", 4, 8829},
	{"SYMBOLS", 7, 8830},
	{"DETECT", 6, 8831},
	{"META", 4, 8832},
	{"HUMANS", 6, 8833},
	{"ANALOG", 6, 8834},
	{"FACIAL", 6, 8835},
	{"LFJ", 3, 8836},
	{"LYAF", 4, 8837},
	{"CHOOSING", 8, 8838},
	{"LYHE", 4, 8839},
	{"OCCUPY", 6, 8840},
	{"DATED", 5, 8841},
	{"LOBA", 4, 8842},
	{"SCENARIO", 8, 8843},
	{"PRIOR", 5, 8844},
	{"URAT", 4, 8845},
	{"SEEKER", 6, 8846},
	{"MINT", 4, 8847},
	{"PACKARD", 7, 8848},
	{"OFFSET", 6, 8849},
	{"PAYDAY", 6, 8850},
	{"PHILIP", 6, 8851},
	{"TRANSLATE", 9, 8852},
	{"TLOO", 4, 8853},
	{"ONCL", 4, 8854},
	{"ONGI", 4, 8855},
	{"HOLDERS", 7, 8856},
	{"ETAB", 4, 8857},
	{"BELIEVES", 8, 8858},
	{"SWEDISH", 7, 8859},
	{"POEMS", 5, 8860},
	{"FRAMEWORK", 9, 8861},
	{"DTIM", 4, 8862},
	{"BULLET", 6, 8863},
	{"DIALOGUE", 8, 8864},
	{"EVJ", 3, 8865},
	{"TDID", 4, 8866},
	{"DISPLAYING", 10, 8867},
	{"FICTION", 7, 8868},
	{"YTIM", 4, 8869},
	{"SSIM", 4, 8870},
	{"RUB", 3, 8871},
	{"OURD", 4, 8872},
	{"COLLINS", 7, 8873},
	{"TREATY", 6, 8874},
	{"LLYE", 4, 8875},
	{"ELTH", 4, 8876},
	{"EMISSION", 8, 8877},
	{"EQUIPPED", 8, 8878},
	{"DINM", 4, 8879},
	{"STAGES", 6, 8880},
	{"ENCOURAGED", 10, 8881},
	{"SUR", 3, 8882},
	{"YRR", 3, 8883},
	{"REMARKABLE", 10, 8884},
	{"EYTO", 4, 8885},
	{"WINDS", 5, 8886},
	{"OFFENSE", 7, 8887},
	{"TREMENDOUS", 10, 8888},
	{"COUNTER", 7, 8889},
	{"HEEC", 4, 8890},
	{"TONGUE", 6, 8891},
	{"BROADWAY", 8, 8892},
	{"ACQUIRED", 8, 8893},
	{"BENCH", 5, 8894},
	{"LBUT", 4, 8895},
	{"CARTRIDGES", 10, 8896},
	{"STONES", 6, 8897},
	{"DEER", 4, 8898},
	{"GNOME", 5, 8899},
	{"ROOTS", 5, 8900},
	{"DECLARATION", 11, 8901},
	{"LOSING", 6, 8902},
	{"ATTEMPTS", 8, 8903},
	{"GADGETS", 7, 8904},
	{"NOBLE", 5, 8905},
	{"TFIR", 4, 8906},
	{"TSBU", 4, 8907},
	{"GLASGOW", 7, 8908},
	{"ACKL", 4, 8909},
	{"HWIT", 4, 8910},
	{"AUTOMATION", 10, 8911},
	{"IMPACTS", 7, 8912},
	{"TIGHT", 5, 8913},
	{"EYWI", 4, 8914},
	{"THIRTY", 6, 8915},
	{"ICEW", 4, 8916},
	{"SHOOTING", 8, 8917},
	{"REV", 3, 8918},
	{"SQUARE", 6, 8919},
	{"GOSPEL", 6, 8920},
	{"EHAL", 4, 8921},
	{"ADVANTAGES", 10, 8922},
	{"ADVANCED", 8, 8923},
	{"ORSW", 4, 8924},
	{"LOVES", 5, 8925},
	{"INDUCED", 7, 8926},
	{"EMPO", 4, 8927},
	{"KNIGHT", 6, 8928},
	{"PREPARING", 9, 8929},
	{"AIMS", 4, 8930},
	{"LINKING", 7, 8931},
	{"EXTENSIONS", 10, 8932},
	{"IDEAL", 5, 8933},
	{"APPEALS", 7, 8934},
	{"AVEP", 4, 8935},
	{"NGBO", 4, 8936},
	{"COMPREHENSIVE", 13, 8937},
	{"NGUN", 4, 8938},
	{"URBA", 4, 8939},
	{"OPRI", 4, 8940},
	{"IFEA", 4, 8941},
	{"EARNED", 6, 8942},
	{"WRON", 4, 8943},
	{"PALE", 4, 8944},
	{"ONTW", 4, 8945},
	{"FREEZE", 6, 8946},
	{"NINF", 4, 8947},
	{"ATHLETICS", 9, 8948},
	{"SINK", 4, 8949},
	{"LLPR", 4, 8950},
	{"AIRCRAFT", 8, 8951},
	{"INSIGHT", 7, 8952},
	{"ILLG", 4, 8953},
	{"ITFO", 4, 8954},
	{"DTAK", 4, 8955},
	{"XKI", 3, 8956},
	{"ERYA", 4, 8957},
	{"EXTENSIVE", 9, 8958},
	{"ATBE", 4, 8959},
	{"ESTB", 4, 8960},
	{"OADS", 4, 8961},
	{"ALTERNATIVES", 12, 8962},
	{"EIRM", 4, 8963},
	{"PENDING", 7, 8964},
	{"PARKER", 6, 8965},
	{"FOUNDER", 7, 8966},
	{"DETERMINING", 11, 8967},
	{"INLI", 4, 8968},
	{"NOTG", 4, 8969},
	{"MUTUAL", 6, 8970},
	{"LEBANON", 7, 8971},
	{"CORP", 4, 8972},
	{"CRAFT", 5, 8973},
	{"OFBA", 4, 8974},
	{"PERSONALIZED", 12, 8975},
	{"UXH", 3, 8976},
	{"KENNEDY", 7, 8977},
	{"OFHA", 4, 8978},
	{"CONDITIONING", 12, 8979},
	{"OTAB", 4, 8980},
	{"RTEA", 4, 8981},
	{"OUTR", 4, 8982},
	{"RLYA", 4, 8983},
	{"CONSIDERABLE", 12, 8984},
	{"STRIP", 5, 8985},
	{"TRIPLE", 6, 8986},
	{"COOPER", 6, 8987},
	{"YBET", 4, 8988},
	{"NYC", 3, 8989},
	{"BIBLE", 5, 8990},
	{"VINCENT", 7, 8991},
	{"JAM", 3, 8992},
	{"INNOCENT", 8, 8993},
	{"SECURED", 7, 8994},
	{"RZU", 3, 8995},
	{"ANSWERED", 8, 8996},
	{"SIGNIFICANCE", 12, 8997},
	{"PARTNERSHIPS", 12, 8998},
	{"SLOTS", 5, 8999},
	{"TSPO", 4, 9000},
	{"TOOLBAR", 7, 9001},
	{"OMHI", 4, 9002},
	{"FINANCE", 7, 9003},
	{"LOVER", 5, 9004},
	{"CHMA", 4, 9005},
	{"DMIL", 4, 9006},
	{"YUSE", 4, 9007},
	{"ROCKS", 5, 9008},
	{"TIRE", 4, 9009},
	{"UTIF", 4, 9010},
	{"EENW", 4, 9011},
	{"LDWI", 4, 9012},
	{"INTRODUCTION", 12, 9013},
	{"SQUI", 4, 9014},
	{"LDEN", 4, 9015},
	{"DWHO", 4, 9016},
	{"LEDW", 4, 9017},
	{"EDOV", 4, 9018},
	{"TITANS", 6, 9019},
	{"KTOT", 4, 9020},
	{"APPLICANTS", 10, 9021},
	{"AHIG", 4, 9022},
	{"POSSESS", 7, 9023},
	{"WEARING", 7, 9024},
	{"LTAN", 4, 9025},
	{"AXIS", 4, 9026},
	{"PROFESSION", 10, 9027},
	{"DWER", 4, 9028},
	{"SOUGHT", 6, 9029},
	{"GENES", 5, 9030},
	{"ELYS", 4, 9031},
	{"SBEL", 4, 9032},
	{"ZKY", 3, 9033},
	{"MOUNTED", 7, 9034},
	{"AYWI", 4, 9035},
	{"IRPO", 4, 9036},
	{"FIREWALL", 8, 9037},
	{"MEDIAN", 6, 9038},
	{"GUNS", 4, 9039},
	{"OVEN", 4, 9040},
	{"GARLIC", 6, 9041},
	{"SCANNER", 7, 9042},
	{"POLE", 4, 9043},
	{"OURL", 4, 9044},
	{"HEREIN", 6, 9045},
	{"AIGH", 4, 9046},
	{"EVOLVE", 6, 9047},
	{"DEFENSIVE", 9, 9048},
	{"ENBY", 4, 9049},
	{"OCCUPATIONAL", 12, 9050},
	{"ANIMATED", 8, 9051},
	{"LYMO", 4, 9052},
	{"HORNY", 5, 9053},
	{"DSCO", 4, 9054},
	{"GUARANTEE", 9, 9055},
	{"OOKO", 4, 9056},
	{"DMON", 4, 9057},
	{"NHOU", 4, 9058},
	{"ENOV", 4, 9059},
	{"OODI", 4, 9060},
	{"INTEGER", 7, 9061},
	{"TREATMENTS", 10, 9062},
	{"BACHELOR", 8, 9063},
	{"JUSTIFY", 7, 9064},
	{"UEDT", 4, 9065},
	{"VARIATION", 9, 9066},
	{"CAMCORDERS", 10, 9067},
	{"ENGAGED", 7, 9068},
	{"FALLING", 7, 9069},
	{"XTRE", 4, 9070},
	{"POLLUTION", 9, 9071},
	{"BASICS", 6, 9072},
	{"NEWLY", 5, 9073},
	{"POTENTIALLY", 11, 9074},
	{"MONTREAL", 8, 9075},
	{"LICT", 4, 9076},
	{"DISTINCTION", 11, 9077},
	{"LEDF", 4, 9078},
	{"ONBO", 4, 9079},
	{"FADE", 4, 9080},
	{"YEDA", 4, 9081},
	{"PRESENTATION", 12, 9082},
	{"SUDDEN", 6, 9083},
	{"STRUCT", 6, 9084},
	{"TMOS", 4, 9085},
	{"ONBY", 4, 9086},
	{"MAINLY", 6, 9087},
	{"LENSES", 6, 9088},
	{"BINARY", 6, 9089},
	{"RTFO", 4, 9090},
	{"GENETICS", 8, 9091},
	{"ATTENDED", 8, 9092},
	{"CTSO", 4, 9093},
	{"PUNK", 4, 9094},
	{"FRIENDLY", 8, 9095},
	{"NTYO", 4, 9096},
	{"ESTABLISHMENT", 13, 9097},
	{"IESC", 4, 9098},
	{"WITHDRAW", 8, 9099},
	{"REMOTE", 6, 9100},
	{"DROPPED", 7, 9101},
	{"ONAF", 4, 9102},
	{"SWIM", 4, 9103},
	{"NDCR", 4, 9104},
	{"NGAD", 4, 9105},
	{"RYFO", 4, 9106},
	{"ENROLLMENT", 10, 9107},
	{"DUKE", 4, 9108},
	{"AMQ", 3, 9109},
	{"PRETEND", 7, 9110},
	{"WALTER", 6, 9111},
	{"REGULARLY", 9, 9112},
	{"SURPRISING", 10, 9113},
	{"ILLD", 4, 9114},
	{"POLITICALLY", 11, 9115},
	{"EARNINGS", 8, 9116},
	{"PRODUCERS", 9, 9117},
	{"DELIVERY", 8, 9118},
	{"EEMP", 4, 9119},
	{"DERC", 4, 9120},
	{"EYSA", 4, 9121},
	{"PSYCHOLOGY", 10, 9122},
	{"ARC", 3, 9123},
	{"HOSTS", 5, 9124},
	{"RAW", 3, 9125},
	{"INTERFACES", 10, 9126},
	{"EIRB", 4, 9127},
	{"ADVERTISERS", 11, 9128},
	{"COMPLICATED", 11, 9129},
	{"GHTC", 4, 9130},
	{"LEHE", 4, 9131},
	{"MOMENTS", 7, 9132},
	{"ATLAS", 5, 9133},
	{"NATURALLY", 9, 9134},
	{"STRINGS", 7, 9135},
	{"REPRESENTING", 12, 9136},
	{"LOOSE", 5, 9137},
	{"FEELS", 5, 9138},
	{"PSAN", 4, 9139},
	{"TORTURE", 7, 9140},
	{"LIFETIME", 8, 9141},
	{"CARL", 4, 9142},
	{"DELETED", 7, 9143},
	{"MITCHELL", 8, 9144},
	{"RICA", 4, 9145},
	{"NEDH", 4, 9146},
	{"RESTORATION", 11, 9147},
	{"ARWI", 4, 9148},
	{"FREQUENCY", 9, 9149},
	{"IVEH", 4, 9150},
	{"RETURNING", 9, 9151},
	{"SQUEEZE", 7, 9152},
	{"DRUN", 4, 9153},
	{"ITDO", 4, 9154},
	{"SINGER", 6, 9155},
	{"RALPH", 5, 9156},
	{"IZC", 3, 9157},
	{"OUIS", 4, 9158},
	{"REHI", 4, 9159},
	{"UTCO", 4, 9160},
	{"TTOW", 4, 9161},
	{"WNAN", 4, 9162},
	{"RNAN", 4, 9163},
	{"WARNER", 6, 9164},
	{"TOUG", 4, 9165},
	{"EOFO", 4, 9166},
	{"CRASH", 5, 9167},
	{"CONFIRMATION", 12, 9168},
	{"APP", 3, 9169},
	{"EMBEDDED", 8, 9170},
	{"INKJET", 6, 9171},
	{"WOYE", 4, 9172},
	{"EFK", 3, 9173},
	{"WIZARD", 6, 9174},
	{"CORPS", 5, 9175},
	{"ACTORS", 6, 9176},
	{"OMBE", 4, 9177},
	{"PERIPHERALS", 11, 9178},
	{"EENF", 4, 9179},
	{"EDCH", 4, 9180},
	{"DIFFER", 6, 9181},
	{"YTOB", 4, 9182},
	{"LIABLE", 6, 9183},
	{"IGAN", 4, 9184},
	{"EINP", 4, 9185},
	{"YISA", 4, 9186},
	{"BROCHURE", 8, 9187},
	{"LDIE", 4, 9188},
	{"ONWO", 4, 9189},
	{"MORRIS", 6, 9190},
	{"BESTSELLERS", 11, 9191},
	{"PETITION", 8, 9192},
	{"EMINEM", 6, 9193},
	{"NDPU", 4, 9194},
	{"PLATFORM", 8, 9195},
	{"ANTENNA", 7, 9196},
	{"PICKED", 6, 9197},
	{"ASSUMED", 7, 9198},
	{"MINNEAPOLIS", 11, 9199},
	{"RELAX", 5, 9200},
	{"WORKING", 7, 9201},
	{"BIKINI", 6, 9202},
	{"MASK", 4, 9203},
	{"MEMPHIS", 7, 9204},
	{"DSWI", 4, 9205},
	{"DECOR", 5, 9206},
	{"DBEF", 4, 9207},
	{"DOYO", 4, 9208},
	{"LOOKUP", 6, 9209},
	{"TEXTS", 5, 9210},
	{"REEC", 4, 9211},
	{"ENOF", 4, 9212},
	{"ASMU", 4, 9213},
	{"ONCH", 4, 9214},
	{"ATSU", 4, 9215},
	{"NPOL", 4, 9216},
	{"HARVARD", 7, 9217},
	{"ECLU", 4, 9218},
	{"PROTEST", 7, 9219},
	{"HTBE", 4, 9220},
	{"TWOT", 4, 9221},
	{"EMOU", 4, 9222},
	{"NTOL", 4, 9223},
	{"JOY", 3, 9224},
	{"BROKERS", 7, 9225},
	{"ROY", 3, 9226},
	{"ULDP", 4, 9227},
	{"AGEW", 4, 9228},
	{"INEV", 4, 9229},
	{"LYUN", 4, 9230},
	{"ILLL", 4, 9231},
	{"LYEA", 4, 9232},
	{"DISMISS", 7, 9233},
	{"GALAXY", 6, 9234},
	{"LEATHER", 7, 9235},
	{"DIAMETER", 8, 9236},
	{"VIOLATION", 9, 9237},
	{"TEDR", 4, 9238},
	{"EXQ", 3, 9239},
	{"OTTAWA", 6, 9240},
	{"LSAR", 4, 9241},
	{"ZYD", 3, 9242},
	{"PODCAST", 7, 9243},
	{"HEADQUARTERS", 12, 9244},
	{"OWNP", 4, 9245},
	{"IRAT", 4, 9246},
	{"SEASONS", 7, 9247},
	{"PARTLY", 6, 9248},
	{"PERU", 4, 9249},
	{"OUSC", 4, 9250},
	{"INTERACTIONS", 12, 9251},
	{"SLIF", 4, 9252},
	{"DTOU", 4, 9253},
	{"REFINE", 6, 9254},
	{"ORTL", 4, 9255},
	{"BIDDER", 6, 9256},
	{"ENTRANCE", 8, 9257},
	{"OWNB", 4, 9258},
	{"NOTW", 4, 9259},
	{"MMIN", 4, 9260},
	{"ATTRACTIVE", 10, 9261},
	{"RSTC", 4, 9262},
	{"EVANS", 5, 9263},
	{"AVOI", 4, 9264},
	{"HERALD", 6, 9265},
	{"FAULT", 5, 9266},
	{"GPLA", 4, 9267},
	{"PARTNERSHIP", 11, 9268},
	{"LITERACY", 8, 9269},
	{"FAILS", 5, 9270},
	{"DSAR", 4, 9271},
	{"AGING", 5, 9272},
	{"ORWI", 4, 9273},
	{"DIRTY", 5, 9274},
	{"EDMI", 4, 9275},
	{"HENB", 4, 9276},
	{"OSOM", 4, 9277},
	{"NIKE", 4, 9278},
	{"PRIDE", 5, 9279},
	{"ALTER", 5, 9280},
	{"EOFR", 4, 9281},
	{"FED", 3, 9282},
	{"ACKW", 4, 9283},
	{"PLUGIN", 6, 9284},
	{"ANLE", 4, 9285},
	{"DIVING", 6, 9286},
	{"UNKNOWN", 7, 9287},
	{"MODIFICATION", 12, 9288},
	{"ALICE", 5, 9289},
	{"NDUR", 4, 9290},
	{"LATINAS", 7, 9291},
	{"GBAC", 4, 9292},
	{"ICAG", 4, 9293},
	{"FUNERAL", 7, 9294},
	{"AIDO", 4, 9295},
	{"IAME", 4, 9296},
	{"RFIN", 4, 9297},
	{"CUSTOMIZED", 10, 9298},
	{"EFUS", 4, 9299},
	{"REED", 4, 9300},
	{"AILI", 4, 9301},
	{"YOUNGER", 7, 9302},
	{"ONOU", 4, 9303},
	{"EINM", 4, 9304},
	{"EPISODE", 7, 9305},
	{"MICE", 4, 9306},
	{"EVOLUTION", 9, 9307},
	{"UNDERSTOOD", 10, 9308},
	{"AWHO", 4, 9309},
	{"RUIT", 4, 9310},
	{"EGIV", 4, 9311},
	{"DEALTIME", 8, 9312},
	{"CONTROVERSY", 11, 9313},
	{"OBRI", 4, 9314},
	{"IALE", 4, 9315},
	{"LTEA", 4, 9316},
	{"OFUS", 4, 9317},
	{"INTRO", 5, 9318},
	{"REGARDLESS", 10, 9319},
	{"FSTA", 4, 9320},
	{"MERCEDES", 8, 9321},
	{"ZUS", 3, 9322},
	{"ASSAULT", 7, 9323},
	{"TRAGEDY", 7, 9324},
	{"LIMITATION", 10, 9325},
	{"ISGR", 4, 9326},
	{"ASSURANCE", 9, 9327},
	{"ADVENTURE", 9, 9328},
	{"HAPPENING", 9, 9329},
	{"WYL", 3, 9330},
	{"EFED", 4, 9331},
	{"ITSR", 4, 9332},
	{"DBYH", 4, 9333},
	{"EOFD", 4, 9334},
	{"MILLS", 5, 9335},
	{"IRCO", 4, 9336},
	{"PALM", 4, 9337},
	{"HONEY", 5, 9338},
	{"AMENDMENTS", 10, 9339},
	{"TRAMADOL", 8, 9340},
	{"HOLLAND", 7, 9341},
	{"RECEIVES", 8, 9342},
	{"OFWO", 4, 9343},
	{"LDMA", 4, 9344},
	{"GRANDFATHER", 11, 9345},
	{"COMPILATION", 11, 9346},
	{"EEXC", 4, 9347},
	{"VERIFICATION", 12, 9348},
	{"EYWA", 4, 9349},
	{"SDOW", 4, 9350},
	{"SITW", 4, 9351},
	{"ORIGINALLY", 10, 9352},
	{"ACEW", 4, 9353},
	{"OMEL", 4, 9354},
	{"NMIN", 4, 9355},
	{"FONTS", 5, 9356},
	{"OFIL", 4, 9357},
	{"LLHE", 4, 9358},
	{"CONVERT", 7, 9359},
	{"HESM", 4, 9360},
	{"ADAPT", 5, 9361},
	{"REFERS", 6, 9362},
	{"VETERANS", 8, 9363},
	{"QUIZ", 4, 9364},
	{"ELDERLY", 7, 9365},
	{"CKON", 4, 9366},
	{"SIGMA", 5, 9367},
	{"CIOU", 4, 9368},
	{"EYDO", 4, 9369},
	{"ERIF", 4, 9370},
	{"CHRE", 4, 9371},
	{"XHTML", 5, 9372},
	{"LLYM", 4, 9373},
	{"RECORDINGS", 10, 9374},
	{"CHZ", 3, 9375},
	{"STABLE", 6, 9376},
	{"JEFFERSON", 9, 9377},
	{"COMPOSITION", 11, 9378},
	{"LLSI", 4, 9379},
	{"EMTH", 4, 9380},
	{"DEMANDS", 7, 9381},
	{"GSTH", 4, 9382},
	{"NARRATIVE", 9, 9383},
	{"ATPE", 4, 9384},
	{"BUYER", 5, 9385},
	{"GBUT", 4, 9386},
	{"SLEEPING", 8, 9387},
	{"PROMINENT", 9, 9388},
	{"ESAG", 4, 9389},
	{"LICENSE", 7, 9390},
	{"GIFTED", 6, 9391},
	{"IVEE", 4, 9392},
	{"GARDENING", 9, 9393},
	{"TONW", 4, 9394},
	{"OBLIGATIONS", 11, 9395},
	{"TBEE", 4, 9396},
	{"EWSP", 4, 9397},
	{"RADICAL", 7, 9398},
	{"ITSL", 4, 9399},
	{"ORCHESTRA", 9, 9400},
	{"VESSEL", 6, 9401},
	{"OWHI", 4, 9402},
	{"SUNSET", 6, 9403},
	{"TRACKED", 7, 9404},
	{"NDCL", 4, 9405},
	{"GTIM", 4, 9406},
	{"OFAT", 4, 9407},
	{"IMAGINATION", 11, 9408},
	{"DERIVE", 6, 9409},
	{"IGK", 3, 9410},
	{"CAPABILITY", 10, 9411},
	{"STABILITY", 9, 9412},
	{"LYNO", 4, 9413},
	{"RQA", 3, 9414},
	{"STTW", 4, 9415},
	{"MHIS", 4, 9416},
	{"POLYPHONIC", 10, 9417},
	{"PORCH", 5, 9418},
	{"STORAGE", 7, 9419},
	{"LOTTERY", 7, 9420},
	{"SHELTER", 7, 9421},
	{"TOPS", 4, 9422},
	{"FRAMED", 6, 9423},
	{"AMAJ", 4, 9424},
	{"GTOH", 4, 9425},
	{"CHOT", 4, 9426},
	{"INSTANCE", 8, 9427},
	{"OUTSOURCING", 11, 9428},
	{"YNIG", 4, 9429},
	{"KETB", 4, 9430},
	{"LICENCE", 7, 9431},
	{"ADJUSTABLE", 10, 9432},
	{"ALLOCATION", 10, 9433},
	{"HWES", 4, 9434},
	{"VJO", 3, 9435},
	{"MICHELLE", 8, 9436},
	{"STDE", 4, 9437},
	{"URRO", 4, 9438},
	{"ERYW", 4, 9439},
	{"VITAL", 5, 9440},
	{"UCHT", 4, 9441},
	{"SHORTLY", 7, 9442},
	{"DSEE", 4, 9443},
	{"EDWE", 4, 9444},
	{"AVEF", 4, 9445},
	{"ALSW", 4, 9446},
	{"OFAB", 4, 9447},
	{"IDTO", 4, 9448},
	{"TRIBE", 5, 9449},
	{"AMY", 3, 9450},
	{"GMOR", 4, 9451},
	{"SONM", 4, 9452},
	{"RYIS", 4, 9453},
	{"SEGMENT", 7, 9454},
	{"DINING", 6, 9455},
	{"URRI", 4, 9456},
	{"DEMONSTRATED", 12, 9457},
	{"POET", 4, 9458},
	{"XUP", 3, 9459},
	{"HUNTER", 6, 9460},
	{"IDENTIFYING", 11, 9461},
	{"ALPHABETICAL", 12, 9462},
	{"HEVO", 4, 9463},
	{"HASD", 4, 9464},
	{"NSAL", 4, 9465},
	{"DEDW", 4, 9466},
	{"CAMPS", 5, 9467},
	{"IRISH", 5, 9468},
	{"PREFERENCE", 10, 9469},
	{"MEHE", 4, 9470},
	{"CONFIDENT", 9, 9471},
	{"ICRE", 4, 9472},
	{"DECLARED", 8, 9473},
	{"TLEO", 4, 9474},
	{"EAMT", 4, 9475},
	{"RCHO", 4, 9476},
	{"DISPATCHED", 10, 9477},
	{"VIOLATE", 7, 9478},
	{"AARON", 5, 9479},
	{"HANDHELD", 8, 9480},
	{"ROFS", 4, 9481},
	{"IFHE", 4, 9482},
	{"DISPOSAL", 8, 9483},
	{"OBEI", 4, 9484},
	{"LAWN", 4, 9485},
	{"NGPL", 4, 9486},
	{"RMEN", 4, 9487},
	{"FLORISTS", 8, 9488},
	{"HMOR", 4, 9489},
	{"PACKS", 5, 9490},
	{"DTJ", 3, 9491},
	{"ATHLETIC", 8, 9492},
	{"OHOL", 4, 9493},
	{"INSTALLING", 10, 9494},
	{"CARBON", 6, 9495},
	{"SWITCHES", 8, 9496},
	{"ROMANIA", 7, 9497},
	{"NCAA", 4, 9498},
	{"SGEN", 4, 9499},
	{"THOU", 4, 9500},
	{"OLUN", 4, 9501},
	{"PHD", 3, 9502},
	{"MOFT", 4, 9503},
	{"ITYH", 4, 9504},
	{"VESH", 4, 9505},
	{"BLOGGING", 8, 9506},
	{"RHIM", 4, 9507},
	{"PROPERLY", 8, 9508},
	{"ATFI", 4, 9509},
	{"CYCLING", 7, 9510},
	{"MERE", 4, 9511},
	{"OADC", 4, 9512},
	{"DDUR", 4, 9513},
	{"PROOF", 5, 9514},
	{"NHOW", 4, 9515},
	{"REEO", 4, 9516},
	{"NKNO", 4, 9517},
	{"ZAU", 3, 9518},
	{"ITYB", 4, 9519},
	{"SSTU", 4, 9520},
	{"BEYO", 4, 9521},
	{"OUSP", 4, 9522},
	{"ZYK", 3, 9523},
	{"ERBY", 4, 9524},
	{"EDLE", 4, 9525},
	{"QWI", 3, 9526},
	{"NEFO", 4, 9527},
	{"CELEBRITY", 9, 9528},
	{"TURKISH", 7, 9529},
	{"SCARED", 6, 9530},
	{"MESSAGING", 9, 9531},
	{"DISTRIBUTE", 10, 9532},
	{"PENTIUM", 7, 9533},
	{"AMTH", 4, 9534},
	{"ISFR", 4, 9535},
	{"SHELF", 5, 9536},
	{"QUANTUM", 7, 9537},
	{"GESTURE", 7, 9538},
	{"NUND", 4, 9539},
	{"MURRAY", 6, 9540},
	{"LOAD", 4, 9541},
	{"YMAR", 4, 9542},
	{"OPPI", 4, 9543},
	{"UTCH", 4, 9544},
	{"OAPP", 4, 9545},
	{"TBEF", 4, 9546},
	{"EXAMINATION", 11, 9547},
	{"HEDB", 4, 9548},
	{"ONGOING", 7, 9549},
	{"ANTC", 4, 9550},
	{"URVE", 4, 9551},
	{"LTHC", 4, 9552},
	{"INEB", 4, 9553},
	{"URCO", 4, 9554},
	{"STEADY", 6, 9555},
	{"CONSTRUCTED", 11, 9556},
	{"CHFO", 4, 9557},
	{"ADDITIONS", 9, 9558},
	{"REQUIRING", 9, 9559},
	{"SPOKE", 5, 9560},
	{"DEDF", 4, 9561},
	{"CQUI", 4, 9562},
	{"YTHO", 4, 9563},
	{"PSYCHOLOGIST", 12, 9564},
	{"COUNCIL", 7, 9565},
	{"SAMPLING", 8, 9566},
	{"SHRUG", 5, 9567},
	{"ENTG", 4, 9568},
	{"NHAV", 4, 9569},
	{"ASLEEP", 6, 9570},
	{"THWA", 4, 9571},
	{"GMEN", 4, 9572},
	{"SHADE", 5, 9573},
	{"UTTE", 4, 9574},
	{"COMFORT", 7, 9575},
	{"ERYB", 4, 9576},
	{"UBST", 4, 9577},
	{"REFINANCE", 9, 9578},
	{"POETRY", 6, 9579},
	{"OPOF", 4, 9580},
	{"ELDI", 4, 9581},
	{"NBOT", 4, 9582},
	{"INSPIRED", 8, 9583},
	{"SCLE", 4, 9584},
	{"HOLES", 5, 9585},
	{"WEDDINGS", 8, 9586},
	{"TAIL", 4, 9587},
	{"ICEF", 4, 9588},
	{"REEW", 4, 9589},
	{"DBYM", 4, 9590},
	{"RTOR", 4, 9591},
	{"NOWHERE", 7, 9592},
	{"MEALS", 5, 9593},
	{"CANYON", 6, 9594},
	{"OURG", 4, 9595},
	{"TENDENCY", 8, 9596},
	{"CHOLESTEROL", 11, 9597},
	{"GOTO", 4, 9598},
	{"UYY", 3, 9599},
	{"METERS", 6, 9600},
	{"ARYI", 4, 9601},
	{"RUNI", 4, 9602},
	{"ASTU", 4, 9603},
	{"LMAR", 4, 9604},
	{"OWHO", 4, 9605},
	{"LLWA", 4, 9606},
	{"RVY", 3, 9607},
	{"CALENDARS", 9, 9608},
	{"NGNO", 4, 9609},
	{"ECONOMIST", 9, 9610},
	{"SEWI", 4, 9611},
	{"RTAT", 4, 9612},
	{"CONCLUSIONS", 11, 9613},
	{"PASSES", 6, 9614},
	{"BIBLIOGRAPHY", 12, 9615},
	{"GIVEN", 5, 9616},
	{"RRIC", 4, 9617},
	{"POINTER", 7, 9618},
	{"ORIENTATION", 11, 9619},
	{"ISDO", 4, 9620},
	{"TOAR", 4, 9621},
	{"VKA", 3, 9622},
	{"RFEC", 4, 9623},
	{"COMPATIBILITY", 13, 9624},
	{"NDDR", 4, 9625},
	{"ONBA", 4, 9626},
	{"EWTH", 4, 9627},
	{"DURHAM", 6, 9628},
	{"RGAM", 4, 9629},
	{"TOBACCO", 7, 9630},
	{"EXCITING", 8, 9631},
	{"PILE", 4, 9632},
	{"PERMITS", 7, 9633},
	{"SPLIT", 5, 9634},
	{"NEIL", 4, 9635},
	{"ZBR", 3, 9636},
	{"NETSCAPE", 8, 9637},
	{"CLEANER", 7, 9638},
	{"CRICKET", 7, 9639},
	{"FEEDING", 7, 9640},
	{"EFEE", 4, 9641},
	{"MUSICIAN", 8, 9642},
	{"CHAPTER", 7, 9643},
	{"EFFICIENCY", 10, 9644},
	{"TOWNSHIP", 8, 9645},
	{"RANKINGS", 8, 9646},
	{"MEASURING", 9, 9647},
	{"CAD", 3, 9648},
	{"OFBO", 4, 9649},
	{"OCKI", 4, 9650},
	{"ORGANIC", 7, 9651},
	{"SOUP", 4, 9652},
	{"ISBO", 4, 9653},
	{"ADOLESCENT", 10, 9654},
	{"ROBIN", 5, 9655},
	{"MOTIVATION", 10, 9656},
	{"ROBINSON", 8, 9657},
	{"HCOM", 4, 9658},
	{"JACKSONVILLE", 12, 9659},
	{"WISDOM", 6, 9660},
	{"DISCOURSE", 9, 9661},
	{"MURD", 4, 9662},
	{"STRAP", 5, 9663},
	{"SHARON", 6, 9664},
	{"GKH", 3, 9665},
	{"FORMATION", 9, 9666},
	{"TCP", 3, 9667},
	{"SUSTAIN", 7, 9668},
	{"HYOU", 4, 9669},
	{"TRANSFERS", 9, 9670},
	{"SURF", 4, 9671},
	{"VEHA", 4, 9672},
	{"LLUS", 4, 9673},
	{"ORSC", 4, 9674},
	{"KWAS", 4, 9675},
	{"OPOL", 4, 9676},
	{"OBLIGATION", 10, 9677},
	{"REMAINED", 8, 9678},
	{"ATTACHMENTS", 11, 9679},
	{"GRADUALLY", 9, 9680},
	{"BESIDES", 7, 9681},
	{"RSTU", 4, 9682},
	{"AGRICULTURAL", 12, 9683},
	{"IBIT", 4, 9684},
	{"EXIC", 4, 9685},
	{"OCRE", 4, 9686},
	{"ITEL", 4, 9687},
	{"DIR", 3, 9688},
	{"OSTU", 4, 9689},
	{"NONL", 4, 9690},
	{"FMAN", 4, 9691},
	{"NUET", 4, 9692},
	{"ENDU", 4, 9693},
	{"FATE", 4, 9694},
	{"PROPORTION", 10, 9695},
	{"ENTITIES", 8, 9696},
	{"CUSTOMS", 7, 9697},
	{"NGFA", 4, 9698},
	{"SNOR", 4, 9699},
	{"ADMINISTRATORS", 14, 9700},
	{"HOWO", 4, 9701},
	{"NTBU", 4, 9702},
	{"ENWA", 4, 9703},
	{"RAINBOW", 7, 9704},
	{"FLEE", 4, 9705},
	{"ROULETTE", 8, 9706},
	{"NUNI", 4, 9707},
	{"ANFR", 4, 9708},
	{"ENPR", 4, 9709},
	{"AROF", 4, 9710},
	{"NDGA", 4, 9711},
	{"RNQ", 3, 9712},
	{"GLOVES", 6, 9713},
	{"USIO", 4, 9714},
	{"OFTI", 4, 9715},
	{"YOVE", 4, 9716},
	{"MEDICARE", 8, 9717},
	{"IEWE", 4, 9718},
	{"SKIING", 6, 9719},
	{"CALCULATE", 9, 9720},
	{"PLOT", 4, 9721},
	{"EOFL", 4, 9722},
	{"RSEV", 4, 9723},
	{"INEU", 4, 9724},
	{"SUBSCRIBER", 10, 9725},
	{"VALVE", 5, 9726},
	{"ADEF", 4, 9727},
	{"VAL", 3, 9728},
	{"HEWLETT", 7, 9729},
	{"AREV", 4, 9730},
	{"TSOR", 4, 9731},
	{"EBIL", 4, 9732},
	{"EXPLAINS", 8, 9733},
	{"ADNO", 4, 9734},
	{"ZGR", 3, 9735},
	{"LOJ", 3, 9736},
	{"BOMBING", 7, 9737},
	{"DEPENDING", 9, 9738},
	{"ITYP", 4, 9739},
	{"VEDF", 4, 9740},
	{"FLICKR", 6, 9741},
	{"RATIO", 5, 9742},
	{"OKTH", 4, 9743},
	{"ANGLE", 5, 9744},
	{"WNQ", 3, 9745},
	{"SSOL", 4, 9746},
	{"OMEH", 4, 9747},
	{"RGEO", 4, 9748},
	{"EFFICIENT", 9, 9749},
	{"FEELINGS", 8, 9750},
	{"DPOL", 4, 9751},
	{"FANTASY", 7, 9752},
	{"UTDO", 4, 9753},
	{"JAMAICA", 7, 9754},
	{"ORHA", 4, 9755},
	{"ZYP", 3, 9756},
	{"LWY", 3, 9757},
	{"PRIORITIES", 10, 9758},
	{"SGOO", 4, 9759},
	{"BOOKSTORE", 9, 9760},
	{"CYK", 3, 9761},
	{"ELAY", 4, 9762},
	{"LIKED", 5, 9763},
	{"PARENTING", 9, 9764},
	{"PIPE", 4, 9765},
	{"MATH", 4, 9766},
	{"ENEM", 4, 9767},
	{"SCHEME", 6, 9768},
	{"RAPID", 5, 9769},
	{"XSW", 3, 9770},
	{"DENIED", 6, 9771},
	{"GGLE", 4, 9772},
	{"ELYI", 4, 9773},
	{"DCOL", 4, 9774},
	{"FOTOS", 5, 9775},
	{"GTOC", 4, 9776},
	{"EOFE", 4, 9777},
	{"BRITNEY", 7, 9778},
	{"EXAC", 4, 9779},
	{"TSUP", 4, 9780},
	{"FREEWARE", 8, 9781},
	{"NOTF", 4, 9782},
	{"CUSTOM", 6, 9783},
	{"NTPA", 4, 9784},
	{"SCANDAL", 7, 9785},
	{"LSOW", 4, 9786},
	{"DEATHS", 6, 9787},
	{"VULNERABLE", 10, 9788},
	{"INSTITUTIONAL", 13, 9789},
	{"HEWR", 4, 9790},
	{"RIVERS", 6, 9791},
	{"BLADE", 5, 9792},
	{"RTUR", 4, 9793},
	{"TUSE", 4, 9794},
	{"COMMONWEALTH", 12, 9795},
	{"LCOU", 4, 9796},
	{"PHARMACEUTICAL", 14, 9797},
	{"INAW", 4, 9798},
	{"MANHATTAN", 9, 9799},
	{"LYAT", 4, 9800},
	{"TALES", 5, 9801},
	{"RGRO", 4, 9802},
	{"FTWA", 4, 9803},
	{"KATRINA", 7, 9804},
	{"WORKFORCE", 9, 9805},
	{"YCB", 3, 9806},
	{"AZP", 3, 9807},
	{"NDAG", 4, 9808},
	{"NODES", 5, 9809},
	{"EREX", 4, 9810},
	{"ETHC", 4, 9811},
	{"THUMBS", 6, 9812},
	{"SEEDS", 5, 9813},
	{"ADMISSION", 9, 9814},
	{"CITED", 5, 9815},
	{"LITE", 4, 9816},
	{"NTDE", 4, 9817},
	{"NWHA", 4, 9818},
	{"DREL", 4, 9819},
	{"OYY", 3, 9820},
	{"GHZ", 3, 9821},
	{"HUB", 3, 9822},
	{"TARGETED", 8, 9823},
	{"HENF", 4, 9824},
	{"FURTHERMORE", 11, 9825},
	{"SKYPE", 5, 9826},
	{"YEXP", 4, 9827},
	{"REALIZED", 8, 9828},
	{"IBED", 4, 9829},
	{"SRET", 4, 9830},
	{"INCREDIBLE", 10, 9831},
	{"GAMECUBE", 8, 9832},
	{"THAC", 4, 9833},
	{"AIDE", 4, 9834},
	{"SINW", 4, 9835},
	{"CRACK", 5, 9836},
	{"RTHW", 4, 9837},
	{"DRAF", 4, 9838},
	{"IAGE", 4, 9839},
	{"NFOU", 4, 9840},
	{"LOUD", 4, 9841},
	{"TISF", 4, 9842},
	{"PORTUGUESE", 10, 9843},
	{"DIVORCE", 7, 9844},
	{"ANWI", 4, 9845},
	{"TITTEN", 6, 9846},
	{"ADVERSE", 7, 9847},
	{"FABRIC", 6, 9848},
	{"ESCU", 4, 9849},
	{"SURVIVOR", 8, 9850},
	{"EFAL", 4, 9851},
	{"DGRA", 4, 9852},
	{"EXCERPT", 7, 9853},
	{"ADJUSTMENT", 10, 9854},
	{"CONSUME", 7, 9855},
	{"DHES", 4, 9856},
	{"FIGHTER", 7, 9857},
	{"APTU", 4, 9858},
	{"OUPO", 4, 9859},
	{"ASEV", 4, 9860},
	{"SCHOLARSHIP", 11, 9861},
	{"DISCHARGE", 9, 9862},
	{"SMOT", 4, 9863},
	{"AUZ", 3, 9864},
	{"MOUNT", 5, 9865},
	{"GUIDELINE", 9, 9866},
	{"DRINKS", 6, 9867},
	{"VOICES", 6, 9868},
	{"ACUTE", 5, 9869},
	{"OKAT", 4, 9870},
	{"YTOP", 4, 9871},
	{"IEDO", 4, 9872},
	{"HALLOWEEN", 9, 9873},
	{"ORSU", 4, 9874},
	{"ERCL", 4, 9875},
	{"HEEL", 4, 9876},
	{"PROPOSED", 8, 9877},
	{"NSOL", 4, 9878},
	{"NOCT", 4, 9879},
	{"VYG", 3, 9880},
	{"CLIMBING", 8, 9881},
	{"NBEA", 4, 9882},
	{"BLEC", 4, 9883},
	{"STOOD", 5, 9884},
	{"PUBLISHER", 9, 9885},
	{"CHWI", 4, 9886},
	{"YIST", 4, 9887},
	{"PERFUME", 7, 9888},
	{"RANY", 4, 9889},
	{"CAROL", 5, 9890},
	{"SUFFICIENT", 10, 9891},
	{"ALBANY", 6, 9892},
	{"KZA", 3, 9893},
	{"MEMBERSHIP", 10, 9894},
	{"BUTM", 4, 9895},
	{"BYHI", 4, 9896},
	{"ERYC", 4, 9897},
	{"HAZARDOUS", 9, 9898},
	{"YWAY", 4, 9899},
	{"EADM", 4, 9900},
	{"METHODOLOGY", 11, 9901},
	{"TSLI", 4, 9902},
	{"NYMO", 4, 9903},
	{"FTIM", 4, 9904},
	{"HOUSEWARES", 10, 9905},
	{"CTTO", 4, 9906},
	{"RESISTANT", 9, 9907},
	{"DEMOCRATS", 9, 9908},
	{"RECYCLING", 9, 9909},
	{"GBP", 3, 9910},
	{"OURW", 4, 9911},
	{"NSFE", 4, 9912},
	{"CREATOR", 7, 9913},
	{"MENU", 4, 9914},
	{"ONLA", 4, 9915},
	{"AMBER", 5, 9916},
	{"QUALIFICATIONS", 14, 9917},
	{"AWOR", 4, 9918},
	{"ONYO", 4, 9919},
	{"ORGO", 4, 9920},
	{"MUSEUMS", 7, 9921},
	{"OFGR", 4, 9922},
	{"CODING", 6, 9923},
	{"IGQ", 3, 9924},
	{"SLIDESHOW", 9, 9925},
	{"UTSO", 4, 9926},
	{"HEJA", 4, 9927},
	{"EFRI", 4, 9928},
	{"TRACKER", 7, 9929},
	{"LYSU", 4, 9930},
	{"TLYI", 4, 9931},
	{"OFLE", 4, 9932},
	{"SFRE", 4, 9933},
	{"GLOVE", 5, 9934},
	{"RLYI", 4, 9935},
	{"RESERVATION", 11, 9936},
	{"NSUN", 4, 9937},
	{"CELEBRATION", 11, 9938},
	{"INFANT", 6, 9939},
	{"RIFLE", 5, 9940},
	{"RCOL", 4, 9941},
	{"TRANSFERRED", 11, 9942},
	{"PROVIDER", 8, 9943},
	{"SATISFY", 7, 9944},
	{"HIKING", 6, 9945},
	{"UNIFORM", 7, 9946},
	{"OPTE", 4, 9947},
	{"WEWE", 4, 9948},
	{"TSMO", 4, 9949},
	{"HIMI", 4, 9950},
	{"MALL", 4, 9951},
	{"PIERRE", 6, 9952},
	{"JELSOFT", 7, 9953},
	{"HEADSET", 7, 9954},
	{"MEASUREMENT", 11, 9955},
	{"ANSM", 4, 9956},
	{"OAKLAND", 7, 9957},
	{"COLOMBIA", 8, 9958},
	{"BSER", 4, 9959},
	{"WAVES", 5, 9960},
	{"CAMEL", 5, 9961},
	{"LSHA", 4, 9962},
	{"ESBY", 4, 9963},
	{"DISTRIBUTOR", 11, 9964},
	{"LAMPS", 5, 9965},
	{"WSQ", 3, 9966},
	{"HOOD", 4, 9967},
	{"DOWNTOWN", 8, 9968},
	{"SSEM", 4, 9969},
	{"WRESTLING", 9, 9970},
	{"EDUCATE", 7, 9971},
	{"PUBLICLY", 8, 9972},
	{"PPRE", 4, 9973},
	{"ARCHIVED", 8, 9974},
	{"TFIN", 4, 9975},
	{"MAINTENANCE", 11, 9976},
	{"PHOTOSHOP", 9, 9977},
	{"COGNITIVE", 9, 9978},
	{"RMSO", 4, 9979},
	{"SANCTION", 8, 9980},
	{"ORPA", 4, 9981},
	{"CONSUMPTION", 11, 9982},
	{"MYTH", 4, 9983},
	{"STRENGTHEN", 10, 9984},
	{"ZGA", 3, 9985},
	{"ARABIA", 6, 9986},
	{"YNX", 3, 9987},
	{"NDFE", 4, 9988},
	{"MATHEMATICAL", 12, 9989},
	{"EXPLOSION", 9, 9990},
	{"FLAVOR", 6, 9991},
	{"DOMINANT", 8, 9992},
	{"EXTRACT", 7, 9993},
	{"SPECIALIZED", 11, 9994},
	{"DIAGNOSTIC", 10, 9995},
	{"SQUE", 4, 9996},
	{"OFEA", 4, 9997},
	{"PANAMA", 6, 9998},
	{"OWNC", 4, 9999},
	{"CHEF", 4, 10000},
	{"TMIL", 4, 10001},
	{"FRIENDSHIP", 10, 10002},
	{"INDIANAPOLIS", 12, 10003},
	{"ORYT", 4, 10004},
	{"PAYABLE", 7, 10005},
	{"BRIEFLY", 7, 10006},
	{"ASSERT", 6, 10007},
	{"CORPORATIONS", 12, 10008},
	{"COURTESY", 8, 10009},
	{"PSIN", 4, 10010},
	{"ECHU", 4, 10011},
	{"USEU", 4, 10012},
	{"HELPFUL", 7, 10013},
	{"CONFIDENTIAL", 12, 10014},
	{"RFC", 3, 10015},
	{"SCOPE", 5, 10016},
	{"EAOF", 4, 10017},
	{"STATUTORY", 9, 10018},
	{"TAXPAYER", 8, 10019},
	{"ACCOMMODATIONS", 14, 10020},
	{"ATHENS", 6, 10021},
	{"YHEA", 4, 10022},
	{"FPEO", 4, 10023},
	{"WAYI", 4, 10024},
	{"RID", 3, 10025},
	{"CTRO", 4, 10026},
	{"ENBA", 4, 10027},
	{"DOWNLOADED", 10, 10028},
	{"NJUL", 4, 10029},
	{"CRUI", 4, 10030},
	{"SIGH", 4, 10031},
	{"RYAR", 4, 10032},
	{"JUDGES", 6, 10033},
	{"LEMON", 5, 10034},
	{"YBEA", 4, 10035},
	{"REMARKS", 7, 10036},
	{"DETECTED", 8, 10037},
	{"DECADES", 7, 10038},
	{"QUALIFY", 7, 10039},
	{"XYC", 3, 10040},
	{"AZW", 3, 10041},
	{"PAINTINGS", 9, 10042},
	{"WALKED", 6, 10043},
	{"NOFC", 4, 10044},
	{"ARISING", 7, 10045},
	{"CTIM", 4, 10046},
	{"MAYH", 4, 10047},
	{"MPTI", 4, 10048},
	{"TUND", 4, 10049},
	{"NISSAN", 6, 10050},
	{"BRACELET", 8, 10051},
	{"EGGS", 4, 10052},
	{"JUVENILE", 8, 10053},
	{"TSFI", 4, 10054},
	{"OORS", 4, 10055},
	{"GSOM", 4, 10056},
	{"INJECTION", 9, 10057},
	{"TOFW", 4, 10058},
	{"XGE", 3, 10059},
	{"YORKSHIRE", 9, 10060},
	{"POPULATIONS", 11, 10061},
	{"WEALTHY", 7, 10062},
	{"IZIN", 4, 10063},
	{"FETY", 4, 10064},
	{"UFAC", 4, 10065},
	{"CANR", 4, 10066},
	{"RESEMBLE", 8, 10067},
	{"ACOUSTIC", 8, 10068},
	{"TRICK", 5, 10069},
	{"SEQUENCE", 8, 10070},
	{"RAILWAY", 7, 10071},
	{"CASSETTE", 8, 10072},
	{"EEPE", 4, 10073},
	{"YMW", 3, 10074},
	{"TEGR", 4, 10075},
	{"ZYH", 3, 10076},
	{"TRACE", 5, 10077},
	{"COW", 3, 10078},
	{"POINTED", 7, 10079},
	{"SZK", 3, 10080},
	{"JPG", 3, 10081},
	{"DEPENDENT", 9, 10082},
	{"YGOO", 4, 10083},
	{"CAUSING", 7, 10084},
	{"NORTON", 6, 10085},
	{"NTKN", 4, 10086},
	{"LOCKED", 6, 10087},
	{"NOTM", 4, 10088},
	{"CEHE", 4, 10089},
	{"MORTGAGE", 8, 10090},
	{"FUSION", 6, 10091},
	{"EEKI", 4, 10092},
	{"IPAN", 4, 10093},
	{"SUNGLASSES", 10, 10094},
	{"RUBY", 4, 10095},
	{"EDDU", 4, 10096},
	{"SHME", 4, 10097},
	{"GEFO", 4, 10098},
	{"STEERING", 8, 10099},
	{"QUARTERBACK", 11, 10100},
	{"BEADS", 5, 10101},
	{"INBR", 4, 10102},
	{"OVEA", 4, 10103},
	{"VERSUS", 6, 10104},
	{"DETAILED", 8, 10105},
	{"AUTO", 4, 10106},
	{"NSMA", 4, 10107},
	{"YOFC", 4, 10108},
	{"LHIS", 4, 10109},
	{"RDFO", 4, 10110},
	{"MNOT", 4, 10111},
	{"RLYT", 4, 10112},
	{"DEDU", 4, 10113},
	{"VEHE", 4, 10114},
	{"CLAIMED", 7, 10115},
	{"APPOINTMENT", 11, 10116},
	{"RBEC", 4, 10117},
	{"SCREENS", 7, 10118},
	{"CROATIA", 7, 10119},
	{"FLOWS", 5, 10120},
	{"VENEZUELA", 9, 10121},
	{"HELICOPTER", 10, 10122},
	{"PUNISHMENT", 10, 10123},
	{"TENNIS", 6, 10124},
	{"MINS", 4, 10125},
	{"UNFO", 4, 10126},
	{"FLOAT", 5, 10127},
	{"BITE", 4, 10128},
	{"SEQUENCES", 9, 10129},
	{"EFUT", 4, 10130},
	{"COUPON", 6, 10131},
	{"MOTOR", 5, 10132},
	{"CLOSER", 6, 10133},
	{"XYT", 3, 10134},
	{"NURSES", 6, 10135},
	{"LYWE", 4, 10136},
	{"LABORATORY", 10, 10137},
	{"RTOO", 4, 10138},
	{"OODF", 4, 10139},
	{"SGET", 4, 10140},
	{"PROXY", 5, 10141},
	{"INTW", 4, 10142},
	{"ULDG", 4, 10143},
	{"AO00", 4, 10144},
	{"AO01", 4, 10145},
	{"AO02", 4, 10146},
	{"AO03", 4, 10147},
	{"AO04", 4, 10148},
	{"AO05", 4, 10149},
	{"AO06", 4, 10150},
	{"AO07", 4, 10151},
	{"AO08", 4, 10152},
	{"AO09", 4, 10153},
	{"AO10", 4, 10154},
	{"AO11", 4, 10155},
	{"AO12", 4, 10156},
	{"AO13", 4, 10157},
	{"AO14", 4, 10158},
	{"AO15", 4, 10159},
	{"AO16", 4, 10160},
	{"AO17", 4, 10161},
	{"AO18", 4, 10162},
	{"AO19", 4, 10163},
	{"AO20", 4, 10164},
	{"AO21", 4, 10165},
	{"AO22", 4, 10166},
	{"AO23", 4, 10167},
	{"AO24", 4, 10168},
	{"AO25", 4, 10169},
	{"AO26", 4, 10170},
	{"AO27", 4, 10171},
	{"AO28", 4, 10172},
	{"AO29", 4, 10173},
	{"AO30", 4, 10174},
	{"AO31", 4, 10175},
	{"AO32", 4, 10176},
	{"AO33", 4, 10177},
	{"AO34", 4, 10178},
	{"AO35", 4, 10179},
	{"AO36", 4, 10180},
	{"AO37", 4, 10181},
	{"AO38", 4, 10182},
	{"AO39", 4, 10183},
	{"AO40", 4, 10184},
	{"AO41", 4, 10185},
	{"AO42", 4, 10186},
	{"AO43", 4, 10187},
	{"AO44", 4, 10188},
	{"AO45", 4, 10189},
	{"AO46", 4, 10190},
	{"AO47", 4, 10191},
	{"AO48", 4, 10192},
	{"AO49", 4, 10193},
	{"AO50", 4, 10194},
	{"AO51", 4, 10195},
	{"AO52", 4, 10196},
	{"AO53", 4, 10197},
	{"AO54", 4, 10198},
	{"AO55", 4, 10199},
	{"AO56", 4, 10200},
	{"AO57", 4, 10201},
	{"AO58", 4, 10202},
	{"AO59", 4, 10203},
	{"AO60", 4, 10204},
	{"AO61", 4, 10205},
	{"AO62", 4, 10206},
	{"AO63", 4, 10207},
	{"AO64", 4, 10208},
	{"AO65", 4, 10209},
	{"AO66", 4, 10210},
	{"AO67", 4, 10211},
	{"AO68", 4, 10212},
	{"AO69", 4, 10213},
	{"AO70", 4, 10214},
	{"AO71", 4, 10215},
	{"AO72", 4, 10216},
	{"AO73", 4, 10217},
	{"AO74", 4, 10218},
	{"AO75", 4, 10219},
	{"AO76", 4, 10220},
	{"AO77", 4, 10221},
	{"AO78", 4, 10222},
	{"AO79", 4, 10223},
	{"AO80", 4, 10224},
	{"AO81", 4, 10225},
	{"AO82", 4, 10226},
	{"AO83", 4, 10227},
	{"AO84", 4, 10228},
	{"AO85", 4, 10229},
	{"AO86", 4, 10230},
	{"AO87", 4, 10231},
	{"AO88", 4, 10232},
	{"AO89", 4, 10233},
	{"AO90", 4, 10234},
	{"AO91", 4, 10235},
	{"AO92", 4, 10236},
	{"AO93", 4, 10237},
	{"AO94", 4, 10238},
	{"AO95", 4, 10239},
	{"AO96", 4, 10240},
	{"AO97", 4, 10241},
	{"AO98", 4, 10242},
	{"AO99", 4, 10243},
	{"AP00", 4, 10244},
	{"AP01", 4, 10245},
	{"AP02", 4, 10246},
	{"AP03", 4, 10247},
	{"AP04", 4, 10248},
	{"AP05", 4, 10249},
	{"AP06", 4, 10250},
	{"AP07", 4, 10251},
	{"AP08", 4, 10252},
	{"AP09", 4, 10253},
	{"AP10", 4, 10254},
	{"AP11", 4, 10255},
	{"AP12", 4, 10256},
	{"AP13", 4, 10257},
	{"AP14", 4, 10258},
	{"AP15", 4, 10259},
	{"AP16", 4, 10260},
	{"AP17", 4, 10261},
	{"AP18", 4, 10262},
	{"AP19", 4, 10263},
	{"AP20", 4, 10264},
	{"AP21", 4, 10265},
	{"AP22", 4, 10266},
	{"AP23", 4, 10267},
	{"AP24", 4, 10268},
	{"AP25", 4, 10269},
	{"AP26", 4, 10270},
	{"AP27", 4, 10271},
	{"AP28", 4, 10272},
	{"AP29", 4, 10273},
	{"AP30", 4, 10274},
	{"AP31", 4, 10275},
	{"AP32", 4, 10276},
	{"AP33", 4, 10277},
	{"AP34", 4, 10278},
	{"AP35", 4, 10279},
	{"AP36", 4, 10280},
	{"AP37", 4, 10281},
	{"AP38", 4, 10282},
	{"AP39", 4, 10283},
	{"AP40", 4, 10284},
	{"AP41", 4, 10285},
	{"AP42", 4, 10286},
	{"AP43", 4, 10287},
	{"AP44", 4, 10288},
	{"AP45", 4, 10289},
	{"AP46", 4, 10290},
	{"AP47", 4, 10291},
	{"AP48", 4, 10292},
	{"AP49", 4, 10293},
	{"AP50", 4, 10294},
	{"AP51", 4, 10295},
	{"AP52", 4, 10296},
	{"AP53", 4, 10297},
	{"AP54", 4, 10298},
	{"AP55", 4, 10299},
	{"AP56", 4, 10300},
	{"AP57", 4, 10301},
	{"AP58", 4, 10302},
	{"AP59", 4, 10303},
	{"AP60", 4, 10304},
	{"AP61", 4, 10305},
	{"AP62", 4, 10306},
	{"AP63", 4, 10307},
	{"AP64", 4, 10308},
	{"AP65", 4, 10309},
	{"AP66", 4, 10310},
	{"AP67", 4, 10311},
	{"AP68", 4, 10312},
	{"AP69", 4, 10313},
	{"AP70", 4, 10314},
	{"AP71", 4, 10315},
	{"AP72", 4, 10316},
	{"AP73", 4, 10317},
	{"AP74", 4, 10318},
	{"AP75", 4, 10319},
	{"AP76", 4, 10320},
	{"AP77", 4, 10321},
	{"AP78", 4, 10322},
	{"AP79", 4, 10323},
	{"AP80", 4, 10324},
	{"AP81", 4, 10325},
	{"AP82", 4, 10326},
	{"AP83", 4, 10327},
	{"AP84", 4, 10328},
	{"AP85", 4, 10329},
	{"AP86", 4, 10330},
	{"AP87", 4, 10331},
	{"AP88", 4, 10332},
	{"AP89", 4, 10333},
	{"AP90", 4, 10334},
	{"AP91", 4, 10335},
	{"AP92", 4, 10336},
	{"AP93", 4, 10337},
	{"AP94", 4, 10338},
	{"AP95", 4, 10339},
	{"AP96", 4, 10340},
	{"AP97", 4, 10341},
	{"AP98", 4, 10342},
	{"AP99", 4, 10343},
	{"BB00", 4, 10344},
	{"BB01", 4, 10345},
	{"BB02", 4, 10346},
	{"BB03", 4, 10347},
	{"BB04", 4, 10348},
	{"BB05", 4, 10349},
	{"BB06", 4, 10350},
	{"BB07", 4, 10351},
	{"BB08", 4, 10352},
	{"BB09", 4, 10353},
	{"BB10", 4, 10354},
	{"BB11", 4, 10355},
	{"BB12", 4, 10356},
	{"BB13", 4, 10357},
	{"BB14", 4, 10358},
	{"BB15", 4, 10359},
	{"BB16", 4, 10360},
	{"BB17", 4, 10361},
	{"BB18", 4, 10362},
	{"BB19", 4, 10363},
	{"BB20", 4, 10364},
	{"BB21", 4, 10365},
	{"BB22", 4, 10366},
	{"BB23", 4, 10367},
	{"BB24", 4, 10368},
	{"BB25", 4, 10369},
	{"BB26", 4, 10370},
	{"BB27", 4, 10371},
	{"BB28", 4, 10372},
	{"BB29", 4, 10373},
	{"BB30", 4, 10374},
	{"BB31", 4, 10375},
	{"BB32", 4, 10376},
	{"BB33", 4, 10377},
	{"BB34", 4, 10378},
	{"BB35", 4, 10379},
	{"BB36", 4, 10380},
	{"BB37", 4, 10381},
	{"BB38", 4, 10382},
	{"BB39", 4, 10383},
	{"BB40", 4, 10384},
	{"BB41", 4, 10385},
	{"BB42", 4, 10386},
	{"BB43", 4, 10387},
	{"BB44", 4, 10388},
	{"BB45", 4, 10389},
	{"BB46", 4, 10390},
	{"BB47", 4, 10391},
	{"BB48", 4, 10392},
	{"BB49", 4, 10393},
	{"BB50", 4, 10394},
	{"BB51", 4, 10395},
	{"BB52", 4, 10396},
	{"BB53", 4, 10397},
	{"BB54", 4, 10398},
	{"BB55", 4, 10399},
	{"BB56", 4, 10400},
	{"BB57", 4, 10401},
	{"BB58", 4, 10402},
	{"BB59", 4, 10403},
	{"BB60", 4, 10404},
	{"BB61", 4, 10405},
	{"BB62", 4, 10406},
	{"BB63", 4, 10407},
	{"BB64", 4, 10408},
	{"BB65", 4, 10409},
	{"BB66", 4, 10410},
	{"BB67", 4, 10411},
	{"BB68", 4, 10412},
	{"BB69", 4, 10413},
	{"BB70", 4, 10414},
	{"BB71", 4, 10415},
	{"BB72", 4, 10416},
	{"BB73", 4, 10417},
	{"BB74", 4, 10418},
	{"BB75", 4, 10419},
	{"BB76", 4, 10420},
	{"BB77", 4, 10421},
	{"BB78", 4, 10422},
	{"BB79", 4, 10423},
	{"BB80", 4, 10424},
	{"BB81", 4, 10425},
	{"BB82", 4, 10426},
	{"BB83", 4, 10427},
	{"BB84", 4, 10428},
	{"BB85", 4, 10429},
	{"BB86", 4, 10430},
	{"BB87", 4, 10431},
	{"BB88", 4, 10432},
	{"BB89", 4, 10433},
	{"BB90", 4, 10434},
	{"BB91", 4, 10435},
	{"BB92", 4, 10436},
	{"BB93", 4, 10437},
	{"BB94", 4, 10438},
	{"BB95", 4, 10439},
	{"BB96", 4, 10440},
	{"BB97", 4, 10441},
	{"BB98", 4, 10442},
	{"BB99", 4, 10443},
	{"BK00", 4, 10444},
	{"BK01", 4, 10445},
	{"BK02", 4, 10446},
	{"BK03", 4, 10447},
	{"BK04", 4, 10448},
	{"BK05", 4, 10449},
	{"BK06", 4, 10450},
	{"BK07", 4, 10451},
	{"BK08", 4, 10452},
	{"BK09", 4, 10453},
	{"BK10", 4, 10454},
	{"BK11", 4, 10455},
	{"BK12", 4, 10456},
	{"BK13", 4, 10457},
	{"BK14", 4, 10458},
	{"BK15", 4, 10459},
	{"BK16", 4, 10460},
	{"BK17", 4, 10461},
	{"BK18", 4, 10462},
	{"BK19", 4, 10463},
	{"BK20", 4, 10464},
	{"BK21", 4, 10465},
	{"BK22", 4, 10466},
	{"BK23", 4, 10467},
	{"BK24", 4, 10468},
	{"BK25", 4, 10469},
	{"BK26", 4, 10470},
	{"BK27", 4, 10471},
	{"BK28", 4, 10472},
	{"BK29", 4, 10473},
	{"BK30", 4, 10474},
	{"BK31", 4, 10475},
	{"BK32", 4, 10476},
	{"BK33", 4, 10477},
	{"BK34", 4, 10478},
	{"BK35", 4, 10479},
	{"BK36", 4, 10480},
	{"BK37", 4, 10481},
	{"BK38", 4, 10482},
	{"BK39", 4, 10483},
	{"BK40", 4, 10484},
	{"BK41", 4, 10485},
	{"BK42", 4, 10486},
	{"BK43", 4, 10487},
	{"BK44", 4, 10488},
	{"BK45", 4, 10489},
	{"BK46", 4, 10490},
	{"BK47", 4, 10491},
	{"BK48", 4, 10492},
	{"BK49", 4, 10493},
	{"BK50", 4, 10494},
	{"BK51", 4, 10495},
	{"BK52", 4, 10496},
	{"BK53", 4, 10497},
	{"BK54", 4, 10498},
	{"BK55", 4, 10499},
	{"BK56", 4, 10500},
	{"BK57", 4, 10501},
	{"BK58", 4, 10502},
	{"BK59", 4, 10503},
	{"BK60", 4, 10504},
	{"BK61", 4, 10505},
	{"BK62", 4, 10506},
	{"BK63", 4, 10507},
	{"BK64", 4, 10508},
	{"BK65", 4, 10509},
	{"BK66", 4, 10510},
	{"BK67", 4, 10511},
	{"BK68", 4, 10512},
	{"BK69", 4, 10513},
	{"BK70", 4, 10514},
	{"BK71", 4, 10515},
	{"BK72", 4, 10516},
	{"BK73", 4, 10517},
	{"BK74", 4, 10518},
	{"BK75", 4, 10519},
	{"BK76", 4, 10520},
	{"BK77", 4, 10521},
	{"BK78", 4, 10522},
	{"BK79", 4, 10523},
	{"BK80", 4, 10524},
	{"BK81", 4, 10525},
	{"BK82", 4, 10526},
	{"BK83", 4, 10527},
	{"BK84", 4, 10528},
	{"BK85", 4, 10529},
	{"BK86", 4, 10530},
	{"BK87", 4, 10531},
	{"BK88", 4, 10532},
	{"BK89", 4, 10533},
	{"BK90", 4, 10534},
	{"BK91", 4, 10535},
	{"BK92", 4, 10536},
	{"BK93", 4, 10537},
	{"BK94", 4, 10538},
	{"BK95", 4, 10539},
	{"BK96", 4, 10540},
	{"BK97", 4, 10541},
	{"BK98", 4, 10542},
	{"BK99", 4, 10543},
	{"BL00", 4, 10544},
	{"BL01", 4, 10545},
	{"BL02", 4, 10546},
	{"BL03", 4, 10547},
	{"BL04", 4, 10548},
	{"BL05", 4, 10549},
	{"BL06", 4, 10550},
	{"BL07", 4, 10551},
	{"BL08", 4, 10552},
	{"BL09", 4, 10553},
	{"BL10", 4, 10554},
	{"BL11", 4, 10555},
	{"BL12", 4, 10556},
	{"BL13", 4, 10557},
	{"BL14", 4, 10558},
	{"BL15", 4, 10559},
	{"BL16", 4, 10560},
	{"BL17", 4, 10561},
	{"BL18", 4, 10562},
	{"BL19", 4, 10563},
	{"BL20", 4, 10564},
	{"BL21", 4, 10565},
	{"BL22", 4, 10566},
	{"BL23", 4, 10567},
	{"BL24", 4, 10568},
	{"BL25", 4, 10569},
	{"BL26", 4, 10570},
	{"BL27", 4, 10571},
	{"BL28", 4, 10572},
	{"BL29", 4, 10573},
	{"BL30", 4, 10574},
	{"BL31", 4, 10575},
	{"BL32", 4, 10576},
	{"BL33", 4, 10577},
	{"BL34", 4, 10578},
	{"BL35", 4, 10579},
	{"BL36", 4, 10580},
	{"BL37", 4, 10581},
	{"BL38", 4, 10582},
	{"BL39", 4, 10583},
	{"BL40", 4, 10584},
	{"BL41", 4, 10585},
	{"BL42", 4, 10586},
	{"BL43", 4, 10587},
	{"BL44", 4, 10588},
	{"BL45", 4, 10589},
	{"BL46", 4, 10590},
	{"BL47", 4, 10591},
	{"BL48", 4, 10592},
	{"BL49", 4, 10593},
	{"BL50", 4, 10594},
	{"BL51", 4, 10595},
	{"BL52", 4, 10596},
	{"BL53", 4, 10597},
	{"BL54", 4, 10598},
	{"BL55", 4, 10599},
	{"BL56", 4, 10600},
	{"BL57", 4, 10601},
	{"BL58", 4, 10602},
	{"BL59", 4, 10603},
	{"BL60", 4, 10604},
	{"BL61", 4, 10605},
	{"BL62", 4, 10606},
	{"BL63", 4, 10607},
	{"BL64", 4, 10608},
	{"BL65", 4, 10609},
	{"BL66", 4, 10610},
	{"BL67", 4, 10611},
	{"BL68", 4, 10612},
	{"BL69", 4, 10613},
	{"BL70", 4, 10614},
	{"BL71", 4, 10615},
	{"BL72", 4, 10616},
	{"BL73", 4, 10617},
	{"BL74", 4, 10618},
	{"BL75", 4, 10619},
	{"BL76", 4, 10620},
	{"BL77", 4, 10621},
	{"BL78", 4, 10622},
	{"BL79", 4, 10623},
	{"BL80", 4, 10624},
	{"BL81", 4, 10625},
	{"BL82", 4, 10626},
	{"BL83", 4, 10627},
	{"BL84", 4, 10628},
	{"BL85", 4, 10629},
	{"BL86", 4, 10630},
	{"BL87", 4, 10631},
	{"BL88", 4, 10632},
	{"BL89", 4, 10633},
	{"BL90", 4, 10634},
	{"BL91", 4, 10635},
	{"BL92", 4, 10636},
	{"BL93", 4, 10637},
	{"BL94", 4, 10638},
	{"BL95", 4, 10639},
	{"BL96", 4, 10640},
	{"BL97", 4, 10641},
	{"BL98", 4, 10642},
	{"BL99", 4, 10643},
	{"BO00", 4, 10644},
	{"BO01", 4, 10645},
	{"BO02", 4, 10646},
	{"BO03", 4, 10647},
	{"BO04", 4, 10648},
	{"BO05", 4, 10649},
	{"BO06", 4, 10650},
	{"BO07", 4, 10651},
	{"BO08", 4, 10652},
	{"BO09", 4, 10653},
	{"BO10", 4, 10654},
	{"BO11", 4, 10655},
	{"BO12", 4, 10656},
	{"BO13", 4, 10657},
	{"BO14", 4, 10658},
	{"BO15", 4, 10659},
	{"BO16", 4, 10660},
	{"BO17", 4, 10661},
	{"BO18", 4, 10662},
	{"BO19", 4, 10663},
	{"BO20", 4, 10664},
	{"BO21", 4, 10665},
	{"BO22", 4, 10666},
	{"BO23", 4, 10667},
	{"BO24", 4, 10668},
	{"BO25", 4, 10669},
	{"BO26", 4, 10670},
	{"BO27", 4, 10671},
	{"BO28", 4, 10672},
	{"BO29", 4, 10673},
	{"BO30", 4, 10674},
	{"BO31", 4, 10675},
	{"BO32", 4, 10676},
	{"BO33", 4, 10677},
	{"BO34", 4, 10678},
	{"BO35", 4, 10679},
	{"BO36", 4, 10680},
	{"BO37", 4, 10681},
	{"BO38", 4, 10682},
	{"BO39", 4, 10683},
	{"BO40", 4, 10684},
	{"BO41", 4, 10685},
	{"BO42", 4, 10686},
	{"BO43", 4, 10687},
	{"BO44", 4, 10688},
	{"BO45", 4, 10689},
	{"BO46", 4, 10690},
	{"BO47", 4, 10691},
	{"BO48", 4, 10692},
	{"BO49", 4, 10693},
	{"BO50", 4, 10694},
	{"BO51", 4, 10695},
	{"BO52", 4, 10696},
	{"BO53", 4, 10697},
	{"BO54", 4, 10698},
	{"BO55", 4, 10699},
	{"BO56", 4, 10700},
	{"BO57", 4, 10701},
	{"BO58", 4, 10702},
	{"BO59", 4, 10703},
	{"\xa1" /* ¡ - "BO60" */, 1, 10704},
	{"\xbf" /* ¿ - "BO61" */, 1, 10705},
	{"\xc0" /* À - "BO62" */, 1, 10706},
	{"\xc1" /* Á - "BO63" */, 1, 10707},
	{"\xc2" /* Â - "BO64" */, 1, 10708},
	{"\xc3" /* Ã - "BO65" */, 1, 10709},
	{"\xc4" /* Ä - "BO66" */, 1, 10710},
	{"\xc5" /* Å - "BO67" */, 1, 10711},
	{"\xc6" /* Æ - "BO68" */, 1, 10712},
	{"\xc7" /* Ç - "BO69" */, 1, 10713},
	{"\xc8" /* È - "BO70" */, 1, 10714},
	{"\xc9" /* É - "BO71" */, 1, 10715},
	{"\xca" /* Ê - "BO72" */, 1, 10716},
	{"\xcb" /* Ë - "BO73" */, 1, 10717},
	{"\xcc" /* Ì - "BO74" */, 1, 10718},
	{"\xcd" /* Í - "BO75" */, 1, 10719},
	{"\xce" /* Î - "BO76" */, 1, 10720},
	{"\xcf" /* Ï - "BO77" */, 1, 10721},
	{"\xd0" /* Ð - "BO78" */, 1, 10722},
	{"\xd1" /* Ñ - "BO79" */, 1, 10723},
	{"\xd2" /* Ò - "BO80" */, 1, 10724},
	{"\xd3" /* Ó - "BO81" */, 1, 10725},
	{"\xd4" /* Ô - "BO82" */, 1, 10726},
	{"\xd5" /* Õ - "BO83" */, 1, 10727},
	{"\xd6" /* Ö - "BO84" */, 1, 10728},
	{"\xd8" /* Ø - "BO85" */, 1, 10729},
	{"\xd9" /* Ù - "BO86" */, 1, 10730},
	{"\xda" /* Ú - "BO87" */, 1, 10731},
	{"\xdb" /* Û - "BO88" */, 1, 10732},
	{"\xdc" /* Ü - "BO89" */, 1, 10733},
	{"\xdd" /* Ý - "BO90" */, 1, 10734},
	{"\xde" /* Þ - "BO91" */, 1, 10735},
	{"BO92", 4, 10736},
	{"BO93", 4, 10737},
	{"BO94", 4, 10738},
	{"BO95", 4, 10739},
	{"BO96", 4, 10740},
	{"BO97", 4, 10741},
	{"BO98", 4, 10742},
	{"BO99", 4, 10743},
	{"BP00", 4, 10744},
	{"BP01", 4, 10745},
	{"BP02", 4, 10746},
	{"BP03", 4, 10747},
	{"BP04", 4, 10748},
	{"BP05", 4, 10749},
	{"BP06", 4, 10750},
	{"BP07", 4, 10751},
	{"BP08", 4, 10752},
	{"BP09", 4, 10753},
	{"BP10", 4, 10754},
	{"BP11", 4, 10755},
	{"BP12", 4, 10756},
	{"BP13", 4, 10757},
	{"BP14", 4, 10758},
	{"BP15", 4, 10759},
	{"BP16", 4, 10760},
	{"BP17", 4, 10761},
	{"BP18", 4, 10762},
	{"BP19", 4, 10763},
	{"BP20", 4, 10764},
	{"BP21", 4, 10765},
	{"BP22", 4, 10766},
	{"BP23", 4, 10767},
	{"BP24", 4, 10768},
	{"BP25", 4, 10769},
	{"BP26", 4, 10770},
	{"BP27", 4, 10771},
	{"BP28", 4, 10772},
	{"BP29", 4, 10773},
	{"BP30", 4, 10774},
	{"BP31", 4, 10775},
	{"BP32", 4, 10776},
	{"BP33", 4, 10777},
	{"BP34", 4, 10778},
	{"BP35", 4, 10779},
	{"BP36", 4, 10780},
	{"BP37", 4, 10781},
	{"BP38", 4, 10782},
	{"BP39", 4, 10783},
	{"BP40", 4, 10784},
	{"BP41", 4, 10785},
	{"BP42", 4, 10786},
	{"BP43", 4, 10787},
	{"BP44", 4, 10788},
	{"BP45", 4, 10789},
	{"BP46", 4, 10790},
	{"BP47", 4, 10791},
	{"BP48", 4, 10792},
	{"BP49", 4, 10793},
	{"BP50", 4, 10794},
	{"BP51", 4, 10795},
	{"BP52", 4, 10796},
	{"BP53", 4, 10797},
	{"BP54", 4, 10798},
	{"BP55", 4, 10799},
	{"BP56", 4, 10800},
	{"BP57", 4, 10801},
	{"BP58", 4, 10802},
	{"BP59", 4, 10803},
	{"BP60", 4, 10804},
	{"BP61", 4, 10805},
	{"BP62", 4, 10806},
	{"BP63", 4, 10807},
	{"BP64", 4, 10808},
	{"BP65", 4, 10809},
	{"BP66", 4, 10810},
	{"BP67", 4, 10811},
	{"BP68", 4, 10812},
	{"BP69", 4, 10813},
	{"BP70", 4, 10814},
	{"BP71", 4, 10815},
	{"BP72", 4, 10816},
	{"BP73", 4, 10817},
	{"BP74", 4, 10818},
	{"BP75", 4, 10819},
	{"BP76", 4, 10820},
	{"BP77", 4, 10821},
	{"BP78", 4, 10822},
	{"BP79", 4, 10823},
	{"BP80", 4, 10824},
	{"BP81", 4, 10825},
	{"BP82", 4, 10826},
	{"BP83", 4, 10827},
	{"BP84", 4, 10828},
	{"BP85", 4, 10829},
	{"BP86", 4, 10830},
	{"BP87", 4, 10831},
	{"BP88", 4, 10832},
	{"BP89", 4, 10833},
	{"BP90", 4, 10834},
	{"BP91", 4, 10835},
	{"BP92", 4, 10836},
	{"BP93", 4, 10837},
	{"BP94", 4, 10838},
	{"BP95", 4, 10839},
	{"BP96", 4, 10840},
	{"BP97", 4, 10841},
	{"BP98", 4, 10842},
	{"BP99", 4, 10843},
	{"BQ00", 4, 10844},
	{"BQ01", 4, 10845},
	{"BQ02", 4, 10846},
	{"BQ03", 4, 10847},
	{"BQ04", 4, 10848},
	{"BQ05", 4, 10849},
	{"BQ06", 4, 10850},
	{"BQ07", 4, 10851},
	{"BQ08", 4, 10852},
	{"BQ09", 4, 10853},
	{"BQ10", 4, 10854},
	{"BQ11", 4, 10855},
	{"BQ12", 4, 10856},
	{"BQ13", 4, 10857},
	{"BQ14", 4, 10858},
	{"BQ15", 4, 10859},
	{"BQ16", 4, 10860},
	{"BQ17", 4, 10861},
	{"BQ18", 4, 10862},
	{"BQ19", 4, 10863},
	{"BQ20", 4, 10864},
	{"BQ21", 4, 10865},
	{"BQ22", 4, 10866},
	{"BQ23", 4, 10867},
	{"BQ24", 4, 10868},
	{"BQ25", 4, 10869},
	{"BQ26", 4, 10870},
	{"BQ27", 4, 10871},
	{"BQ28", 4, 10872},
	{"BQ29", 4, 10873},
	{"BQ30", 4, 10874},
	{"BQ31", 4, 10875},
	{"BQ32", 4, 10876},
	{"BQ33", 4, 10877},
	{"BQ34", 4, 10878},
	{"BQ35", 4, 10879},
	{"BQ36", 4, 10880},
	{"BQ37", 4, 10881},
	{"BQ38", 4, 10882},
	{"BQ39", 4, 10883},
	{"BQ40", 4, 10884},
	{"BQ41", 4, 10885},
	{"BQ42", 4, 10886},
	{"BQ43", 4, 10887},
	{"BQ44", 4, 10888},
	{"BQ45", 4, 10889},
	{"BQ46", 4, 10890},
	{"BQ47", 4, 10891},
	{"BQ48", 4, 10892},
	{"BQ49", 4, 10893},
	{"BQ50", 4, 10894},
	{"BQ51", 4, 10895},
	{"BQ52", 4, 10896},
	{"BQ53", 4, 10897},
	{"BQ54", 4, 10898},
	{"BQ55", 4, 10899},
	{"BQ56", 4, 10900},
	{"BQ57", 4, 10901},
	{"BQ58", 4, 10902},
	{"BQ59", 4, 10903},
	{"BQ60", 4, 10904},
	{"BQ61", 4, 10905},
	{"BQ62", 4, 10906},
	{"BQ63", 4, 10907},
	{"BQ64", 4, 10908},
	{"BQ65", 4, 10909},
	{"BQ66", 4, 10910},
	{"BQ67", 4, 10911},
	{"BQ68", 4, 10912},
	{"BQ69", 4, 10913},
	{"BQ70", 4, 10914},
	{"BQ71", 4, 10915},
	{"BQ72", 4, 10916},
	{"BQ73", 4, 10917},
	{"BQ74", 4, 10918},
	{"BQ75", 4, 10919},
	{"BQ76", 4, 10920},
	{"BQ77", 4, 10921},
	{"BQ78", 4, 10922},
	{"BQ79", 4, 10923},
	{"BQ80", 4, 10924},
	{"BQ81", 4, 10925},
	{"BQ82", 4, 10926},
	{"BQ83", 4, 10927},
	{"BQ84", 4, 10928},
	{"BQ85", 4, 10929},
	{"BQ86", 4, 10930},
	{"BQ87", 4, 10931},
	{"BQ88", 4, 10932},
	{"BQ89", 4, 10933},
	{"BQ90", 4, 10934},
	{"BQ91", 4, 10935},
	{"BQ92", 4, 10936},
	{"BQ93", 4, 10937},
	{"BQ94", 4, 10938},
	{"BQ95", 4, 10939},
	{"BQ96", 4, 10940},
	{"BQ97", 4, 10941},
	{"BQ98", 4, 10942},
	{"BQ99", 4, 10943},
	{"CB00", 4, 10944},
	{"CB01", 4, 10945},
	{"CB02", 4, 10946},
	{"CB03", 4, 10947},
	{"CB04", 4, 10948},
	{"CB05", 4, 10949},
	{"CB06", 4, 10950},
	{"CB07", 4, 10951},
	{"CB08", 4, 10952},
	{"CB09", 4, 10953},
	{"CB10", 4, 10954},
	{"CB11", 4, 10955},
	{"CB12", 4, 10956},
	{"CB13", 4, 10957},
	{"CB14", 4, 10958},
	{"CB15", 4, 10959},
	{"CB16", 4, 10960},
	{"CB17", 4, 10961},
	{"CB18", 4, 10962},
	{"CB19", 4, 10963},
	{"CB20", 4, 10964},
	{"CB21", 4, 10965},
	{"CB22", 4, 10966},
	{"CB23", 4, 10967},
	{"CB24", 4, 10968},
	{"CB25", 4, 10969},
	{"CB26", 4, 10970},
	{"CB27", 4, 10971},
	{"CB28", 4, 10972},
	{"CB29", 4, 10973},
	{"CB30", 4, 10974},
	{"CB31", 4, 10975},
	{"CB32", 4, 10976},
	{"CB33", 4, 10977},
	{"CB34", 4, 10978},
	{"CB35", 4, 10979},
	{"CB36", 4, 10980},
	{"CB37", 4, 10981},
	{"CB38", 4, 10982},
	{"CB39", 4, 10983},
	{"CB40", 4, 10984},
	{"CB41", 4, 10985},
	{"CB42", 4, 10986},
	{"CB43", 4, 10987},
	{"CB44", 4, 10988},
	{"CB45", 4, 10989},
	{"CB46", 4, 10990},
	{"CB47", 4, 10991},
	{"CB48", 4, 10992},
	{"CB49", 4, 10993},
	{"CB50", 4, 10994},
	{"CB51", 4, 10995},
	{"CB52", 4, 10996},
	{"CB53", 4, 10997},
	{"CB54", 4, 10998},
	{"CB55", 4, 10999},
	{"CB56", 4, 11000},
	{"CB57", 4, 11001},
	{"CB58", 4, 11002},
	{"CB59", 4, 11003},
	{"CB60", 4, 11004},
	{"CB61", 4, 11005},
	{"CB62", 4, 11006},
	{"CB63", 4, 11007},
	{"CB64", 4, 11008},
	{"CB65", 4, 11009},
	{"CB66", 4, 11010},
	{"CB67", 4, 11011},
	{"CB68", 4, 11012},
	{"CB69", 4, 11013},
	{"CB70", 4, 11014},
	{"CB71", 4, 11015},
	{"CB72", 4, 11016},
	{"CB73", 4, 11017},
	{"CB74", 4, 11018},
	{"CB75", 4, 11019},
	{"CB76", 4, 11020},
	{"CB77", 4, 11021},
	{"CB78", 4, 11022},
	{"CB79", 4, 11023},
	{"CB80", 4, 11024},
	{"CB81", 4, 11025},
	{"CB82", 4, 11026},
	{"CB83", 4, 11027},
	{"CB84", 4, 11028},
	{"CB85", 4, 11029},
	{"CB86", 4, 11030},
	{"CB87", 4, 11031},
	{"CB88", 4, 11032},
	{"CB89", 4, 11033},
	{"CB90", 4, 11034},
	{"CB91", 4, 11035},
	{"CB92", 4, 11036},
	{"CB93", 4, 11037},
	{"CB94", 4, 11038},
	{"CB95", 4, 11039},
	{"CB96", 4, 11040},
	{"CB97", 4, 11041},
	{"CB98", 4, 11042},
	{"CB99", 4, 11043},
	{"CM00", 4, 11044},
	{"CM01", 4, 11045},
	{"CM02", 4, 11046},
	{"CM03", 4, 11047},
	{"CM04", 4, 11048},
	{"CM05", 4, 11049},
	{"CM06", 4, 11050},
	{"CM07", 4, 11051},
	{"CM08", 4, 11052},
	{"CM09", 4, 11053},
	{"CM10", 4, 11054},
	{"CM11", 4, 11055},
	{"CM12", 4, 11056},
	{"CM13", 4, 11057},
	{"CM14", 4, 11058},
	{"CM15", 4, 11059},
	{"CM16", 4, 11060},
	{"CM17", 4, 11061},
	{"CM18", 4, 11062},
	{"CM19", 4, 11063},
	{"CM20", 4, 11064},
	{"CM21", 4, 11065},
	{"CM22", 4, 11066},
	{"CM23", 4, 11067},
	{"CM24", 4, 11068},
	{"CM25", 4, 11069},
	{"CM26", 4, 11070},
	{"CM27", 4, 11071},
	{"CM28", 4, 11072},
	{"CM29", 4, 11073},
	{"CM30", 4, 11074},
	{"CM31", 4, 11075},
	{"CM32", 4, 11076},
	{"CM33", 4, 11077},
	{"CM34", 4, 11078},
	{"CM35", 4, 11079},
	{"CM36", 4, 11080},
	{"CM37", 4, 11081},
	{"CM38", 4, 11082},
	{"CM39", 4, 11083},
	{"CM40", 4, 11084},
	{"CM41", 4, 11085},
	{"CM42", 4, 11086},
	{"CM43", 4, 11087},
	{"CM44", 4, 11088},
	{"CM45", 4, 11089},
	{"CM46", 4, 11090},
	{"CM47", 4, 11091},
	{"CM48", 4, 11092},
	{"CM49", 4, 11093},
	{"CM50", 4, 11094},
	{"CM51", 4, 11095},
	{"CM52", 4, 11096},
	{"CM53", 4, 11097},
	{"CM54", 4, 11098},
	{"CM55", 4, 11099},
	{"CM56", 4, 11100},
	{"CM57", 4, 11101},
	{"CM58", 4, 11102},
	{"CM59", 4, 11103},
	{"CM60", 4, 11104},
	{"CM61", 4, 11105},
	{"CM62", 4, 11106},
	{"CM63", 4, 11107},
	{"CM64", 4, 11108},
	{"CM65", 4, 11109},
	{"CM66", 4, 11110},
	{"CM67", 4, 11111},
	{"CM68", 4, 11112},
	{"CM69", 4, 11113},
	{"CM70", 4, 11114},
	{"CM71", 4, 11115},
	{"CM72", 4, 11116},
	{"CM73", 4, 11117},
	{"CM74", 4, 11118},
	{"CM75", 4, 11119},
	{"CM76", 4, 11120},
	{"CM77", 4, 11121},
	{"CM78", 4, 11122},
	{"CM79", 4, 11123},
	{"CM80", 4, 11124},
	{"CM81", 4, 11125},
	{"CM82", 4, 11126},
	{"CM83", 4, 11127},
	{"CM84", 4, 11128},
	{"CM85", 4, 11129},
	{"CM86", 4, 11130},
	{"CM87", 4, 11131},
	{"CM88", 4, 11132},
	{"CM89", 4, 11133},
	{"CM90", 4, 11134},
	{"CM91", 4, 11135},
	{"CM92", 4, 11136},
	{"CM93", 4, 11137},
	{"CM94", 4, 11138},
	{"CM95", 4, 11139},
	{"CM96", 4, 11140},
	{"CM97", 4, 11141},
	{"CM98", 4, 11142},
	{"CM99", 4, 11143},
	{"CN00", 4, 11144},
	{"CN01", 4, 11145},
	{"CN02", 4, 11146},
	{"CN03", 4, 11147},
	{"CN04", 4, 11148},
	{"CN05", 4, 11149},
	{"CN06", 4, 11150},
	{"CN07", 4, 11151},
	{"CN08", 4, 11152},
	{"CN09", 4, 11153},
	{"CN10", 4, 11154},
	{"CN11", 4, 11155},
	{"CN12", 4, 11156},
	{"CN13", 4, 11157},
	{"CN14", 4, 11158},
	{"CN15", 4, 11159},
	{"CN16", 4, 11160},
	{"CN17", 4, 11161},
	{"CN18", 4, 11162},
	{"CN19", 4, 11163},
	{"CN20", 4, 11164},
	{"CN21", 4, 11165},
	{"CN22", 4, 11166},
	{"CN23", 4, 11167},
	{"CN24", 4, 11168},
	{"CN25", 4, 11169},
	{"CN26", 4, 11170},
	{"CN27", 4, 11171},
	{"CN28", 4, 11172},
	{"CN29", 4, 11173},
	{"CN30", 4, 11174},
	{"CN31", 4, 11175},
	{"CN32", 4, 11176},
	{"CN33", 4, 11177},
	{"CN34", 4, 11178},
	{"CN35", 4, 11179},
	{"CN36", 4, 11180},
	{"CN37", 4, 11181},
	{"CN38", 4, 11182},
	{"CN39", 4, 11183},
	{"CN40", 4, 11184},
	{"CN41", 4, 11185},
	{"CN42", 4, 11186},
	{"CN43", 4, 11187},
	{"CN44", 4, 11188},
	{"CN45", 4, 11189},
	{"CN46", 4, 11190},
	{"CN47", 4, 11191},
	{"CN48", 4, 11192},
	{"CN49", 4, 11193},
	{"CN50", 4, 11194},
	{"CN51", 4, 11195},
	{"CN52", 4, 11196},
	{"CN53", 4, 11197},
	{"CN54", 4, 11198},
	{"CN55", 4, 11199},
	{"CN56", 4, 11200},
	{"CN57", 4, 11201},
	{"CN58", 4, 11202},
	{"CN59", 4, 11203},
	{"CN60", 4, 11204},
	{"CN61", 4, 11205},
	{"CN62", 4, 11206},
	{"CN63", 4, 11207},
	{"CN64", 4, 11208},
	{"CN65", 4, 11209},
	{"CN66", 4, 11210},
	{"CN67", 4, 11211},
	{"CN68", 4, 11212},
	{"CN69", 4, 11213},
	{"CN70", 4, 11214},
	{"CN71", 4, 11215},
	{"CN72", 4, 11216},
	{"CN73", 4, 11217},
	{"CN74", 4, 11218},
	{"CN75", 4, 11219},
	{"CN76", 4, 11220},
	{"CN77", 4, 11221},
	{"CN78", 4, 11222},
	{"CN79", 4, 11223},
	{"CN80", 4, 11224},
	{"CN81", 4, 11225},
	{"CN82", 4, 11226},
	{"CN83", 4, 11227},
	{"CN84", 4, 11228},
	{"CN85", 4, 11229},
	{"CN86", 4, 11230},
	{"CN87", 4, 11231},
	{"CN88", 4, 11232},
	{"CN89", 4, 11233},
	{"CN90", 4, 11234},
	{"CN91", 4, 11235},
	{"CN92", 4, 11236},
	{"CN93", 4, 11237},
	{"CN94", 4, 11238},
	{"CN95", 4, 11239},
	{"CN96", 4, 11240},
	{"CN97", 4, 11241},
	{"CN98", 4, 11242},
	{"CN99", 4, 11243},
	{"CO00", 4, 11244},
	{"CO01", 4, 11245},
	{"CO02", 4, 11246},
	{"CO03", 4, 11247},
	{"CO04", 4, 11248},
	{"CO05", 4, 11249},
	{"CO06", 4, 11250},
	{"CO07", 4, 11251},
	{"CO08", 4, 11252},
	{"CO09", 4, 11253},
	{"CO10", 4, 11254},
	{"CO11", 4, 11255},
	{"CO12", 4, 11256},
	{"CO13", 4, 11257},
	{"CO14", 4, 11258},
	{"CO15", 4, 11259},
	{"CO16", 4, 11260},
	{"CO17", 4, 11261},
	{"CO18", 4, 11262},
	{"CO19", 4, 11263},
	{"CO20", 4, 11264},
	{"CO21", 4, 11265},
	{"CO22", 4, 11266},
	{"CO23", 4, 11267},
	{"CO24", 4, 11268},
	{"CO25", 4, 11269},
	{"CO26", 4, 11270},
	{"CO27", 4, 11271},
	{"CO28", 4, 11272},
	{"CO29", 4, 11273},
	{"CO30", 4, 11274},
	{"CO31", 4, 11275},
	{"CO32", 4, 11276},
	{"CO33", 4, 11277},
	{"CO34", 4, 11278},
	{"CO35", 4, 11279},
	{"CO36", 4, 11280},
	{"CO37", 4, 11281},
	{"CO38", 4, 11282},
	{"CO39", 4, 11283},
	{"CO40", 4, 11284},
	{"CO41", 4, 11285},
	{"CO42", 4, 11286},
	{"CO43", 4, 11287},
	{"CO44", 4, 11288},
	{"CO45", 4, 11289},
	{"CO46", 4, 11290},
	{"CO47", 4, 11291},
	{"CO48", 4, 11292},
	{"CO49", 4, 11293},
	{"CO50", 4, 11294},
	{"CO51", 4, 11295},
	{"CO52", 4, 11296},
	{"CO53", 4, 11297},
	{"CO54", 4, 11298},
	{"CO55", 4, 11299},
	{"CO56", 4, 11300},
	{"CO57", 4, 11301},
	{"CO58", 4, 11302},
	{"CO59", 4, 11303},
	{"CO60", 4, 11304},
	{"CO61", 4, 11305},
	{"CO62", 4, 11306},
	{"CO63", 4, 11307},
	{"CO64", 4, 11308},
	{"CO65", 4, 11309},
	{"CO66", 4, 11310},
	{"CO67", 4, 11311},
	{"CO68", 4, 11312},
	{"CO69", 4, 11313},
	{"CO70", 4, 11314},
	{"CO71", 4, 11315},
	{"CO72", 4, 11316},
	{"CO73", 4, 11317},
	{"CO74", 4, 11318},
	{"CO75", 4, 11319},
	{"CO76", 4, 11320},
	{"CO77", 4, 11321},
	{"CO78", 4, 11322},
	{"CO79", 4, 11323},
	{"CO80", 4, 11324},
	{"CO81", 4, 11325},
	{"CO82", 4, 11326},
	{"CO83", 4, 11327},
	{"CO84", 4, 11328},
	{"CO85", 4, 11329},
	{"CO86", 4, 11330},
	{"CO87", 4, 11331},
	{"CO88", 4, 11332},
	{"CO89", 4, 11333},
	{"CO90", 4, 11334},
	{"CO91", 4, 11335},
	{"CO92", 4, 11336},
	{"CO93", 4, 11337},
	{"CO94", 4, 11338},
	{"CO95", 4, 11339},
	{"CO96", 4, 11340},
	{"CO97", 4, 11341},
	{"CO98", 4, 11342},
	{"CO99", 4, 11343},
	{"CP00", 4, 11344},
	{"CP01", 4, 11345},
	{"CP02", 4, 11346},
	{"CP03", 4, 11347},
	{"CP04", 4, 11348},
	{"CP05", 4, 11349},
	{"CP06", 4, 11350},
	{"CP07", 4, 11351},
	{"CP08", 4, 11352},
	{"CP09", 4, 11353},
	{"CP10", 4, 11354},
	{"CP11", 4, 11355},
	{"CP12", 4, 11356},
	{"CP13", 4, 11357},
	{"CP14", 4, 11358},
	{"CP15", 4, 11359},
	{"CP16", 4, 11360},
	{"CP17", 4, 11361},
	{"CP18", 4, 11362},
	{"CP19", 4, 11363},
	{"CP20", 4, 11364},
	{"CP21", 4, 11365},
	{"CP22", 4, 11366},
	{"CP23", 4, 11367},
	{"CP24", 4, 11368},
	{"CP25", 4, 11369},
	{"CP26", 4, 11370},
	{"CP27", 4, 11371},
	{"CP28", 4, 11372},
	{"CP29", 4, 11373},
	{"CP30", 4, 11374},
	{"CP31", 4, 11375},
	{"CP32", 4, 11376},
	{"CP33", 4, 11377},
	{"CP34", 4, 11378},
	{"CP35", 4, 11379},
	{"CP36", 4, 11380},
	{"CP37", 4, 11381},
	{"CP38", 4, 11382},
	{"CP39", 4, 11383},
	{"CP40", 4, 11384},
	{"CP41", 4, 11385},
	{"CP42", 4, 11386},
	{"CP43", 4, 11387},
	{"CP44", 4, 11388},
	{"CP45", 4, 11389},
	{"CP46", 4, 11390},
	{"CP47", 4, 11391},
	{"CP48", 4, 11392},
	{"CP49", 4, 11393},
	{"CP50", 4, 11394},
	{"CP51", 4, 11395},
	{"CP52", 4, 11396},
	{"CP53", 4, 11397},
	{"CP54", 4, 11398},
	{"CP55", 4, 11399},
	{"CP56", 4, 11400},
	{"CP57", 4, 11401},
	{"CP58", 4, 11402},
	{"CP59", 4, 11403},
	{"CP60", 4, 11404},
	{"CP61", 4, 11405},
	{"CP62", 4, 11406},
	{"CP63", 4, 11407},
	{"CP64", 4, 11408},
	{"CP65", 4, 11409},
	{"CP66", 4, 11410},
	{"CP67", 4, 11411},
	{"CP68", 4, 11412},
	{"CP69", 4, 11413},
	{"CP70", 4, 11414},
	{"CP71", 4, 11415},
	{"CP72", 4, 11416},
	{"CP73", 4, 11417},
	{"CP74", 4, 11418},
	{"CP75", 4, 11419},
	{"CP76", 4, 11420},
	{"CP77", 4, 11421},
	{"CP78", 4, 11422},
	{"CP79", 4, 11423},
	{"CP80", 4, 11424},
	{"CP81", 4, 11425},
	{"CP82", 4, 11426},
	{"CP83", 4, 11427},
	{"CP84", 4, 11428},
	{"CP85", 4, 11429},
	{"CP86", 4, 11430},
	{"CP87", 4, 11431},
	{"CP88", 4, 11432},
	{"CP89", 4, 11433},
	{"CP90", 4, 11434},
	{"CP91", 4, 11435},
	{"CP92", 4, 11436},
	{"CP93", 4, 11437},
	{"CP94", 4, 11438},
	{"CP95", 4, 11439},
	{"CP96", 4, 11440},
	{"CP97", 4, 11441},
	{"CP98", 4, 11442},
	{"CP99", 4, 11443},
	{"CQ00", 4, 11444},
	{"CQ01", 4, 11445},
	{"CQ02", 4, 11446},
	{"CQ03", 4, 11447},
	{"CQ04", 4, 11448},
	{"CQ05", 4, 11449},
	{"CQ06", 4, 11450},
	{"CQ07", 4, 11451},
	{"CQ08", 4, 11452},
	{"CQ09", 4, 11453},
	{"CQ10", 4, 11454},
	{"CQ11", 4, 11455},
	{"CQ12", 4, 11456},
	{"CQ13", 4, 11457},
	{"CQ14", 4, 11458},
	{"CQ15", 4, 11459},
	{"CQ16", 4, 11460},
	{"CQ17", 4, 11461},
	{"CQ18", 4, 11462},
	{"CQ19", 4, 11463},
	{"CQ20", 4, 11464},
	{"CQ21", 4, 11465},
	{"CQ22", 4, 11466},
	{"CQ23", 4, 11467},
	{"CQ24", 4, 11468},
	{"CQ25", 4, 11469},
	{"CQ26", 4, 11470},
	{"CQ27", 4, 11471},
	{"CQ28", 4, 11472},
	{"CQ29", 4, 11473},
	{"CQ30", 4, 11474},
	{"CQ31", 4, 11475},
	{"CQ32", 4, 11476},
	{"CQ33", 4, 11477},
	{"CQ34", 4, 11478},
	{"CQ35", 4, 11479},
	{"CQ36", 4, 11480},
	{"CQ37", 4, 11481},
	{"CQ38", 4, 11482},
	{"CQ39", 4, 11483},
	{"CQ40", 4, 11484},
	{"CQ41", 4, 11485},
	{"CQ42", 4, 11486},
	{"CQ43", 4, 11487},
	{"CQ44", 4, 11488},
	{"CQ45", 4, 11489},
	{"CQ46", 4, 11490},
	{"CQ47", 4, 11491},
	{"CQ48", 4, 11492},
	{"CQ49", 4, 11493},
	{"CQ50", 4, 11494},
	{"CQ51", 4, 11495},
	{"CQ52", 4, 11496},
	{"CQ53", 4, 11497},
	{"CQ54", 4, 11498},
	{"CQ55", 4, 11499},
	{"CQ56", 4, 11500},
	{"CQ57", 4, 11501},
	{"CQ58", 4, 11502},
	{"CQ59", 4, 11503},
	{"CQ60", 4, 11504},
	{"CQ61", 4, 11505},
	{"CQ62", 4, 11506},
	{"CQ63", 4, 11507},
	{"CQ64", 4, 11508},
	{"CQ65", 4, 11509},
	{"CQ66", 4, 11510},
	{"CQ67", 4, 11511},
	{"CQ68", 4, 11512},
	{"CQ69", 4, 11513},
	{"CQ70", 4, 11514},
	{"CQ71", 4, 11515},
	{"CQ72", 4, 11516},
	{"CQ73", 4, 11517},
	{"CQ74", 4, 11518},
	{"CQ75", 4, 11519},
	{"CQ76", 4, 11520},
	{"CQ77", 4, 11521},
	{"CQ78", 4, 11522},
	{"CQ79", 4, 11523},
	{"CQ80", 4, 11524},
	{"CQ81", 4, 11525},
	{"CQ82", 4, 11526},
	{"CQ83", 4, 11527},
	{"CQ84", 4, 11528},
	{"CQ85", 4, 11529},
	{"CQ86", 4, 11530},
	{"CQ87", 4, 11531},
	{"CQ88", 4, 11532},
	{"CQ89", 4, 11533},
	{"CQ90", 4, 11534},
	{"CQ91", 4, 11535},
	{"CQ92", 4, 11536},
	{"CQ93", 4, 11537},
	{"CQ94", 4, 11538},
	{"CQ95", 4, 11539},
	{"CQ96", 4, 11540},
	{"CQ97", 4, 11541},
	{"CQ98", 4, 11542},
	{"CQ99", 4, 11543},
	{"DB00", 4, 11544},
	{"DB01", 4, 11545},
	{"DB02", 4, 11546},
	{"DB03", 4, 11547},
	{"DB04", 4, 11548},
	{"DB05", 4, 11549},
	{"DB06", 4, 11550},
	{"DB07", 4, 11551},
	{"DB08", 4, 11552},
	{"DB09", 4, 11553},
	{"DB10", 4, 11554},
	{"DB11", 4, 11555},
	{"DB12", 4, 11556},
	{"DB13", 4, 11557},
	{"DB14", 4, 11558},
	{"DB15", 4, 11559},
	{"DB16", 4, 11560},
	{"DB17", 4, 11561},
	{"DB18", 4, 11562},
	{"DB19", 4, 11563},
	{"DB20", 4, 11564},
	{"DB21", 4, 11565},
	{"DB22", 4, 11566},
	{"DB23", 4, 11567},
	{"DB24", 4, 11568},
	{"DB25", 4, 11569},
	{"DB26", 4, 11570},
	{"DB27", 4, 11571},
	{"DB28", 4, 11572},
	{"DB29", 4, 11573},
	{"DB30", 4, 11574},
	{"DB31", 4, 11575},
	{"DB32", 4, 11576},
	{"DB33", 4, 11577},
	{"DB34", 4, 11578},
	{"DB35", 4, 11579},
	{"DB36", 4, 11580},
	{"DB37", 4, 11581},
	{"DB38", 4, 11582},
	{"DB39", 4, 11583},
	{"DB40", 4, 11584},
	{"DB41", 4, 11585},
	{"DB42", 4, 11586},
	{"DB43", 4, 11587},
	{"DB44", 4, 11588},
	{"DB45", 4, 11589},
	{"DB46", 4, 11590},
	{"DB47", 4, 11591},
	{"DB48", 4, 11592},
	{"DB49", 4, 11593},
	{"DB50", 4, 11594},
	{"DB51", 4, 11595},
	{"DB52", 4, 11596},
	{"DB53", 4, 11597},
	{"DB54", 4, 11598},
	{"DB55", 4, 11599},
	{"DB56", 4, 11600},
	{"DB57", 4, 11601},
	{"DB58", 4, 11602},
	{"DB59", 4, 11603},
	{"DB60", 4, 11604},
	{"DB61", 4, 11605},
	{"DB62", 4, 11606},
	{"DB63", 4, 11607},
	{"DB64", 4, 11608},
	{"DB65", 4, 11609},
	{"DB66", 4, 11610},
	{"DB67", 4, 11611},
	{"DB68", 4, 11612},
	{"DB69", 4, 11613},
	{"DB70", 4, 11614},
	{"DB71", 4, 11615},
	{"DB72", 4, 11616},
	{"DB73", 4, 11617},
	{"DB74", 4, 11618},
	{"DB75", 4, 11619},
	{"DB76", 4, 11620},
	{"DB77", 4, 11621},
	{"DB78", 4, 11622},
	{"DB79", 4, 11623},
	{"DB80", 4, 11624},
	{"DB81", 4, 11625},
	{"DB82", 4, 11626},
	{"DB83", 4, 11627},
	{"DB84", 4, 11628},
	{"DB85", 4, 11629},
	{"DB86", 4, 11630},
	{"DB87", 4, 11631},
	{"DB88", 4, 11632},
	{"DB89", 4, 11633},
	{"DB90", 4, 11634},
	{"DB91", 4, 11635},
	{"DB92", 4, 11636},
	{"DB93", 4, 11637},
	{"DB94", 4, 11638},
	{"DB95", 4, 11639},
	{"DB96", 4, 11640},
	{"DB97", 4, 11641},
	{"DB98", 4, 11642},
	{"DB99", 4, 11643},
	{"DK00", 4, 11644},
	{"DK01", 4, 11645},
	{"DK02", 4, 11646},
	{"DK03", 4, 11647},
	{"DK04", 4, 11648},
	{"DK05", 4, 11649},
	{"DK06", 4, 11650},
	{"DK07", 4, 11651},
	{"DK08", 4, 11652},
	{"DK09", 4, 11653},
	{"DK10", 4, 11654},
	{"DK11", 4, 11655},
	{"DK12", 4, 11656},
	{"DK13", 4, 11657},
	{"DK14", 4, 11658},
	{"DK15", 4, 11659},
	{"DK16", 4, 11660},
	{"DK17", 4, 11661},
	{"DK18", 4, 11662},
	{"DK19", 4, 11663},
	{"DK20", 4, 11664},
	{"DK21", 4, 11665},
	{"DK22", 4, 11666},
	{"DK23", 4, 11667},
	{"DK24", 4, 11668},
	{"DK25", 4, 11669},
	{"DK26", 4, 11670},
	{"DK27", 4, 11671},
	{"DK28", 4, 11672},
	{"DK29", 4, 11673},
	{"DK30", 4, 11674},
	{"DK31", 4, 11675},
	{"DK32", 4, 11676},
	{"DK33", 4, 11677},
	{"DK34", 4, 11678},
	{"DK35", 4, 11679},
	{"DK36", 4, 11680},
	{"DK37", 4, 11681},
	{"DK38", 4, 11682},
	{"DK39", 4, 11683},
	{"DK40", 4, 11684},
	{"DK41", 4, 11685},
	{"DK42", 4, 11686},
	{"DK43", 4, 11687},
	{"DK44", 4, 11688},
	{"DK45", 4, 11689},
	{"DK46", 4, 11690},
	{"DK47", 4, 11691},
	{"DK48", 4, 11692},
	{"DK49", 4, 11693},
	{"DK50", 4, 11694},
	{"DK51", 4, 11695},
	{"DK52", 4, 11696},
	{"DK53", 4, 11697},
	{"DK54", 4, 11698},
	{"DK55", 4, 11699},
	{"DK56", 4, 11700},
	{"DK57", 4, 11701},
	{"DK58", 4, 11702},
	{"DK59", 4, 11703},
	{"DK60", 4, 11704},
	{"DK61", 4, 11705},
	{"DK62", 4, 11706},
	{"DK63", 4, 11707},
	{"DK64", 4, 11708},
	{"DK65", 4, 11709},
	{"DK66", 4, 11710},
	{"DK67", 4, 11711},
	{"DK68", 4, 11712},
	{"DK69", 4, 11713},
	{"DK70", 4, 11714},
	{"DK71", 4, 11715},
	{"DK72", 4, 11716},
	{"DK73", 4, 11717},
	{"DK74", 4, 11718},
	{"DK75", 4, 11719},
	{"DK76", 4, 11720},
	{"DK77", 4, 11721},
	{"DK78", 4, 11722},
	{"DK79", 4, 11723},
	{"DK80", 4, 11724},
	{"DK81", 4, 11725},
	{"DK82", 4, 11726},
	{"DK83", 4, 11727},
	{"DK84", 4, 11728},
	{"DK85", 4, 11729},
	{"DK86", 4, 11730},
	{"DK87", 4, 11731},
	{"DK88", 4, 11732},
	{"DK89", 4, 11733},
	{"DK90", 4, 11734},
	{"DK91", 4, 11735},
	{"DK92", 4, 11736},
	{"DK93", 4, 11737},
	{"DK94", 4, 11738},
	{"DK95", 4, 11739},
	{"DK96", 4, 11740},
	{"DK97", 4, 11741},
	{"DK98", 4, 11742},
	{"DK99", 4, 11743},
	{"DL00", 4, 11744},
	{"DL01", 4, 11745},
	{"DL02", 4, 11746},
	{"DL03", 4, 11747},
	{"DL04", 4, 11748},
	{"DL05", 4, 11749},
	{"DL06", 4, 11750},
	{"DL07", 4, 11751},
	{"DL08", 4, 11752},
	{"DL09", 4, 11753},
	{"DL10", 4, 11754},
	{"DL11", 4, 11755},
	{"DL12", 4, 11756},
	{"DL13", 4, 11757},
	{"DL14", 4, 11758},
	{"DL15", 4, 11759},
	{"DL16", 4, 11760},
	{"DL17", 4, 11761},
	{"DL18", 4, 11762},
	{"DL19", 4, 11763},
	{"DL20", 4, 11764},
	{"DL21", 4, 11765},
	{"DL22", 4, 11766},
	{"DL23", 4, 11767},
	{"DL24", 4, 11768},
	{"DL25", 4, 11769},
	{"DL26", 4, 11770},
	{"DL27", 4, 11771},
	{"DL28", 4, 11772},
	{"DL29", 4, 11773},
	{"DL30", 4, 11774},
	{"DL31", 4, 11775},
	{"DL32", 4, 11776},
	{"DL33", 4, 11777},
	{"DL34", 4, 11778},
	{"DL35", 4, 11779},
	{"DL36", 4, 11780},
	{"DL37", 4, 11781},
	{"DL38", 4, 11782},
	{"DL39", 4, 11783},
	{"DL40", 4, 11784},
	{"DL41", 4, 11785},
	{"DL42", 4, 11786},
	{"DL43", 4, 11787},
	{"DL44", 4, 11788},
	{"DL45", 4, 11789},
	{"DL46", 4, 11790},
	{"DL47", 4, 11791},
	{"DL48", 4, 11792},
	{"DL49", 4, 11793},
	{"DL50", 4, 11794},
	{"DL51", 4, 11795},
	{"DL52", 4, 11796},
	{"DL53", 4, 11797},
	{"DL54", 4, 11798},
	{"DL55", 4, 11799},
	{"DL56", 4, 11800},
	{"DL57", 4, 11801},
	{"DL58", 4, 11802},
	{"DL59", 4, 11803},
	{"DL60", 4, 11804},
	{"DL61", 4, 11805},
	{"DL62", 4, 11806},
	{"DL63", 4, 11807},
	{"DL64", 4, 11808},
	{"DL65", 4, 11809},
	{"DL66", 4, 11810},
	{"DL67", 4, 11811},
	{"DL68", 4, 11812},
	{"DL69", 4, 11813},
	{"DL70", 4, 11814},
	{"DL71", 4, 11815},
	{"DL72", 4, 11816},
	{"DL73", 4, 11817},
	{"DL74", 4, 11818},
	{"DL75", 4, 11819},
	{"DL76", 4, 11820},
	{"DL77", 4, 11821},
	{"DL78", 4, 11822},
	{"DL79", 4, 11823},
	{"DL80", 4, 11824},
	{"DL81", 4, 11825},
	{"DL82", 4, 11826},
	{"DL83", 4, 11827},
	{"DL84", 4, 11828},
	{"DL85", 4, 11829},
	{"DL86", 4, 11830},
	{"DL87", 4, 11831},
	{"DL88", 4, 11832},
	{"DL89", 4, 11833},
	{"DL90", 4, 11834},
	{"DL91", 4, 11835},
	{"DL92", 4, 11836},
	{"DL93", 4, 11837},
	{"DL94", 4, 11838},
	{"DL95", 4, 11839},
	{"DL96", 4, 11840},
	{"DL97", 4, 11841},
	{"DL98", 4, 11842},
	{"DL99", 4, 11843},
	{"DM00", 4, 11844},
	{"DM01", 4, 11845},
	{"DM02", 4, 11846},
	{"DM03", 4, 11847},
	{"DM04", 4, 11848},
	{"DM05", 4, 11849},
	{"DM06", 4, 11850},
	{"DM07", 4, 11851},
	{"DM08", 4, 11852},
	{"DM09", 4, 11853},
	{"DM10", 4, 11854},
	{"DM11", 4, 11855},
	{"DM12", 4, 11856},
	{"DM13", 4, 11857},
	{"DM14", 4, 11858},
	{"DM15", 4, 11859},
	{"DM16", 4, 11860},
	{"DM17", 4, 11861},
	{"DM18", 4, 11862},
	{"DM19", 4, 11863},
	{"DM20", 4, 11864},
	{"DM21", 4, 11865},
	{"DM22", 4, 11866},
	{"DM23", 4, 11867},
	{"DM24", 4, 11868},
	{"DM25", 4, 11869},
	{"DM26", 4, 11870},
	{"DM27", 4, 11871},
	{"DM28", 4, 11872},
	{"DM29", 4, 11873},
	{"DM30", 4, 11874},
	{"DM31", 4, 11875},
	{"DM32", 4, 11876},
	{"DM33", 4, 11877},
	{"DM34", 4, 11878},
	{"DM35", 4, 11879},
	{"DM36", 4, 11880},
	{"DM37", 4, 11881},
	{"DM38", 4, 11882},
	{"DM39", 4, 11883},
	{"DM40", 4, 11884},
	{"DM41", 4, 11885},
	{"DM42", 4, 11886},
	{"DM43", 4, 11887},
	{"DM44", 4, 11888},
	{"DM45", 4, 11889},
	{"DM46", 4, 11890},
	{"DM47", 4, 11891},
	{"DM48", 4, 11892},
	{"DM49", 4, 11893},
	{"DM50", 4, 11894},
	{"DM51", 4, 11895},
	{"DM52", 4, 11896},
	{"DM53", 4, 11897},
	{"DM54", 4, 11898},
	{"DM55", 4, 11899},
	{"DM56", 4, 11900},
	{"DM57", 4, 11901},
	{"DM58", 4, 11902},
	{"DM59", 4, 11903},
	{"DM60", 4, 11904},
	{"DM61", 4, 11905},
	{"DM62", 4, 11906},
	{"DM63", 4, 11907},
	{"DM64", 4, 11908},
	{"DM65", 4, 11909},
	{"DM66", 4, 11910},
	{"DM67", 4, 11911},
	{"DM68", 4, 11912},
	{"DM69", 4, 11913},
	{"DM70", 4, 11914},
	{"DM71", 4, 11915},
	{"DM72", 4, 11916},
	{"DM73", 4, 11917},
	{"DM74", 4, 11918},
	{"DM75", 4, 11919},
	{"DM76", 4, 11920},
	{"DM77", 4, 11921},
	{"DM78", 4, 11922},
	{"DM79", 4, 11923},
	{"DM80", 4, 11924},
	{"DM81", 4, 11925},
	{"DM82", 4, 11926},
	{"DM83", 4, 11927},
	{"DM84", 4, 11928},
	{"DM85", 4, 11929},
	{"DM86", 4, 11930},
	{"DM87", 4, 11931},
	{"DM88", 4, 11932},
	{"DM89", 4, 11933},
	{"DM90", 4, 11934},
	{"DM91", 4, 11935},
	{"DM92", 4, 11936},
	{"DM93", 4, 11937},
	{"DM94", 4, 11938},
	{"DM95", 4, 11939},
	{"DM96", 4, 11940},
	{"DM97", 4, 11941},
	{"DM98", 4, 11942},
	{"DM99", 4, 11943},
	{"DN00", 4, 11944},
	{"DN01", 4, 11945},
	{"DN02", 4, 11946},
	{"DN03", 4, 11947},
	{"DN04", 4, 11948},
	{"DN05", 4, 11949},
	{"DN06", 4, 11950},
	{"DN07", 4, 11951},
	{"DN08", 4, 11952},
	{"DN09", 4, 11953},
	{"DN10", 4, 11954},
	{"DN11", 4, 11955},
	{"DN12", 4, 11956},
	{"DN13", 4, 11957},
	{"DN14", 4, 11958},
	{"DN15", 4, 11959},
	{"DN16", 4, 11960},
	{"DN17", 4, 11961},
	{"DN18", 4, 11962},
	{"DN19", 4, 11963},
	{"DN20", 4, 11964},
	{"DN21", 4, 11965},
	{"DN22", 4, 11966},
	{"DN23", 4, 11967},
	{"DN24", 4, 11968},
	{"DN25", 4, 11969},
	{"DN26", 4, 11970},
	{"DN27", 4, 11971},
	{"DN28", 4, 11972},
	{"DN29", 4, 11973},
	{"DN30", 4, 11974},
	{"DN31", 4, 11975},
	{"DN32", 4, 11976},
	{"DN33", 4, 11977},
	{"DN34", 4, 11978},
	{"DN35", 4, 11979},
	{"DN36", 4, 11980},
	{"DN37", 4, 11981},
	{"DN38", 4, 11982},
	{"DN39", 4, 11983},
	{"DN40", 4, 11984},
	{"DN41", 4, 11985},
	{"DN42", 4, 11986},
	{"DN43", 4, 11987},
	{"DN44", 4, 11988},
	{"DN45", 4, 11989},
	{"DN46", 4, 11990},
	{"DN47", 4, 11991},
	{"DN48", 4, 11992},
	{"DN49", 4, 11993},
	{"DN50", 4, 11994},
	{"DN51", 4, 11995},
	{"DN52", 4, 11996},
	{"DN53", 4, 11997},
	{"DN54", 4, 11998},
	{"DN55", 4, 11999},
	{"DN56", 4, 12000},
	{"DN57", 4, 12001},
	{"DN58", 4, 12002},
	{"DN59", 4, 12003},
	{"DN60", 4, 12004},
	{"DN61", 4, 12005},
	{"DN62", 4, 12006},
	{"DN63", 4, 12007},
	{"DN64", 4, 12008},
	{"DN65", 4, 12009},
	{"DN66", 4, 12010},
	{"DN67", 4, 12011},
	{"DN68", 4, 12012},
	{"DN69", 4, 12013},
	{"DN70", 4, 12014},
	{"DN71", 4, 12015},
	{"DN72", 4, 12016},
	{"DN73", 4, 12017},
	{"DN74", 4, 12018},
	{"DN75", 4, 12019},
	{"DN76", 4, 12020},
	{"DN77", 4, 12021},
	{"DN78", 4, 12022},
	{"DN79", 4, 12023},
	{"DN80", 4, 12024},
	{"DN81", 4, 12025},
	{"DN82", 4, 12026},
	{"DN83", 4, 12027},
	{"DN84", 4, 12028},
	{"DN85", 4, 12029},
	{"DN86", 4, 12030},
	{"DN87", 4, 12031},
	{"DN88", 4, 12032},
	{"DN89", 4, 12033},
	{"DN90", 4, 12034},
	{"DN91", 4, 12035},
	{"DN92", 4, 12036},
	{"DN93", 4, 12037},
	{"DN94", 4, 12038},
	{"DN95", 4, 12039},
	{"DN96", 4, 12040},
	{"DN97", 4, 12041},
	{"DN98", 4, 12042},
	{"DN99", 4, 12043},
	{"DO00", 4, 12044},
	{"DO01", 4, 12045},
	{"DO02", 4, 12046},
	{"DO03", 4, 12047},
	{"DO04", 4, 12048},
	{"DO05", 4, 12049},
	{"DO06", 4, 12050},
	{"DO07", 4, 12051},
	{"DO08", 4, 12052},
	{"DO09", 4, 12053},
	{"DO10", 4, 12054},
	{"DO11", 4, 12055},
	{"DO12", 4, 12056},
	{"DO13", 4, 12057},
	{"DO14", 4, 12058},
	{"DO15", 4, 12059},
	{"DO16", 4, 12060},
	{"DO17", 4, 12061},
	{"DO18", 4, 12062},
	{"DO19", 4, 12063},
	{"DO20", 4, 12064},
	{"DO21", 4, 12065},
	{"DO22", 4, 12066},
	{"DO23", 4, 12067},
	{"DO24", 4, 12068},
	{"DO25", 4, 12069},
	{"DO26", 4, 12070},
	{"DO27", 4, 12071},
	{"DO28", 4, 12072},
	{"DO29", 4, 12073},
	{"DO30", 4, 12074},
	{"DO31", 4, 12075},
	{"DO32", 4, 12076},
	{"DO33", 4, 12077},
	{"DO34", 4, 12078},
	{"DO35", 4, 12079},
	{"DO36", 4, 12080},
	{"DO37", 4, 12081},
	{"DO38", 4, 12082},
	{"DO39", 4, 12083},
	{"DO40", 4, 12084},
	{"DO41", 4, 12085},
	{"DO42", 4, 12086},
	{"DO43", 4, 12087},
	{"DO44", 4, 12088},
	{"DO45", 4, 12089},
	{"DO46", 4, 12090},
	{"DO47", 4, 12091},
	{"DO48", 4, 12092},
	{"DO49", 4, 12093},
	{"DO50", 4, 12094},
	{"DO51", 4, 12095},
	{"DO52", 4, 12096},
	{"DO53", 4, 12097},
	{"DO54", 4, 12098},
	{"DO55", 4, 12099},
	{"DO56", 4, 12100},
	{"DO57", 4, 12101},
	{"DO58", 4, 12102},
	{"DO59", 4, 12103},
	{"DO60", 4, 12104},
	{"DO61", 4, 12105},
	{"DO62", 4, 12106},
	{"DO63", 4, 12107},
	{"DO64", 4, 12108},
	{"DO65", 4, 12109},
	{"DO66", 4, 12110},
	{"DO67", 4, 12111},
	{"DO68", 4, 12112},
	{"DO69", 4, 12113},
	{"DO70", 4, 12114},
	{"DO71", 4, 12115},
	{"DO72", 4, 12116},
	{"DO73", 4, 12117},
	{"DO74", 4, 12118},
	{"DO75", 4, 12119},
	{"DO76", 4, 12120},
	{"DO77", 4, 12121},
	{"DO78", 4, 12122},
	{"DO79", 4, 12123},
	{"DO80", 4, 12124},
	{"DO81", 4, 12125},
	{"DO82", 4, 12126},
	{"DO83", 4, 12127},
	{"DO84", 4, 12128},
	{"DO85", 4, 12129},
	{"DO86", 4, 12130},
	{"DO87", 4, 12131},
	{"DO88", 4, 12132},
	{"DO89", 4, 12133},
	{"DO90", 4, 12134},
	{"DO91", 4, 12135},
	{"DO92", 4, 12136},
	{"DO93", 4, 12137},
	{"DO94", 4, 12138},
	{"DO95", 4, 12139},
	{"DO96", 4, 12140},
	{"DO97", 4, 12141},
	{"DO98", 4, 12142},
	{"DO99", 4, 12143},
	{"DP00", 4, 12144},
	{"DP01", 4, 12145},
	{"DP02", 4, 12146},
	{"DP03", 4, 12147},
	{"DP04", 4, 12148},
	{"DP05", 4, 12149},
	{"DP06", 4, 12150},
	{"DP07", 4, 12151},
	{"DP08", 4, 12152},
	{"DP09", 4, 12153},
	{"DP10", 4, 12154},
	{"DP11", 4, 12155},
	{"DP12", 4, 12156},
	{"DP13", 4, 12157},
	{"DP14", 4, 12158},
	{"DP15", 4, 12159},
	{"DP16", 4, 12160},
	{"DP17", 4, 12161},
	{"DP18", 4, 12162},
	{"DP19", 4, 12163},
	{"DP20", 4, 12164},
	{"DP21", 4, 12165},
	{"DP22", 4, 12166},
	{"DP23", 4, 12167},
	{"DP24", 4, 12168},
	{"DP25", 4, 12169},
	{"DP26", 4, 12170},
	{"DP27", 4, 12171},
	{"DP28", 4, 12172},
	{"DP29", 4, 12173},
	{"DP30", 4, 12174},
	{"DP31", 4, 12175},
	{"DP32", 4, 12176},
	{"DP33", 4, 12177},
	{"DP34", 4, 12178},
	{"DP35", 4, 12179},
	{"DP36", 4, 12180},
	{"DP37", 4, 12181},
	{"DP38", 4, 12182},
	{"DP39", 4, 12183},
	{"DP40", 4, 12184},
	{"DP41", 4, 12185},
	{"DP42", 4, 12186},
	{"DP43", 4, 12187},
	{"DP44", 4, 12188},
	{"DP45", 4, 12189},
	{"DP46", 4, 12190},
	{"DP47", 4, 12191},
	{"DP48", 4, 12192},
	{"DP49", 4, 12193},
	{"DP50", 4, 12194},
	{"DP51", 4, 12195},
	{"DP52", 4, 12196},
	{"DP53", 4, 12197},
	{"DP54", 4, 12198},
	{"DP55", 4, 12199},
	{"DP56", 4, 12200},
	{"DP57", 4, 12201},
	{"DP58", 4, 12202},
	{"DP59", 4, 12203},
	{"DP60", 4, 12204},
	{"DP61", 4, 12205},
	{"DP62", 4, 12206},
	{"DP63", 4, 12207},
	{"DP64", 4, 12208},
	{"DP65", 4, 12209},
	{"DP66", 4, 12210},
	{"DP67", 4, 12211},
	{"DP68", 4, 12212},
	{"DP69", 4, 12213},
	{"DP70", 4, 12214},
	{"DP71", 4, 12215},
	{"DP72", 4, 12216},
	{"DP73", 4, 12217},
	{"DP74", 4, 12218},
	{"DP75", 4, 12219},
	{"DP76", 4, 12220},
	{"DP77", 4, 12221},
	{"DP78", 4, 12222},
	{"DP79", 4, 12223},
	{"DP80", 4, 12224},
	{"DP81", 4, 12225},
	{"DP82", 4, 12226},
	{"DP83", 4, 12227},
	{"DP84", 4, 12228},
	{"DP85", 4, 12229},
	{"DP86", 4, 12230},
	{"DP87", 4, 12231},
	{"DP88", 4, 12232},
	{"DP89", 4, 12233},
	{"DP90", 4, 12234},
	{"DP91", 4, 12235},
	{"DP92", 4, 12236},
	{"DP93", 4, 12237},
	{"DP94", 4, 12238},
	{"DP95", 4, 12239},
	{"DP96", 4, 12240},
	{"DP97", 4, 12241},
	{"DP98", 4, 12242},
	{"DP99", 4, 12243},
	{"DQ00", 4, 12244},
	{"DQ01", 4, 12245},
	{"DQ02", 4, 12246},
	{"DQ03", 4, 12247},
	{"DQ04", 4, 12248},
	{"DQ05", 4, 12249},
	{"DQ06", 4, 12250},
	{"DQ07", 4, 12251},
	{"DQ08", 4, 12252},
	{"DQ09", 4, 12253},
	{"DQ10", 4, 12254},
	{"DQ11", 4, 12255},
	{"DQ12", 4, 12256},
	{"DQ13", 4, 12257},
	{"DQ14", 4, 12258},
	{"DQ15", 4, 12259},
	{"DQ16", 4, 12260},
	{"DQ17", 4, 12261},
	{"DQ18", 4, 12262},
	{"DQ19", 4, 12263},
	{"DQ20", 4, 12264},
	{"DQ21", 4, 12265},
	{"DQ22", 4, 12266},
	{"DQ23", 4, 12267},
	{"DQ24", 4, 12268},
	{"DQ25", 4, 12269},
	{"DQ26", 4, 12270},
	{"DQ27", 4, 12271},
	{"DQ28", 4, 12272},
	{"DQ29", 4, 12273},
	{"DQ30", 4, 12274},
	{"DQ31", 4, 12275},
	{"DQ32", 4, 12276},
	{"DQ33", 4, 12277},
	{"DQ34", 4, 12278},
	{"DQ35", 4, 12279},
	{"DQ36", 4, 12280},
	{"DQ37", 4, 12281},
	{"DQ38", 4, 12282},
	{"DQ39", 4, 12283},
	{"DQ40", 4, 12284},
	{"DQ41", 4, 12285},
	{"DQ42", 4, 12286},
	{"DQ43", 4, 12287},
	{"DQ44", 4, 12288},
	{"DQ45", 4, 12289},
	{"DQ46", 4, 12290},
	{"DQ47", 4, 12291},
	{"DQ48", 4, 12292},
	{"DQ49", 4, 12293},
	{"DQ50", 4, 12294},
	{"DQ51", 4, 12295},
	{"DQ52", 4, 12296},
	{"DQ53", 4, 12297},
	{"DQ54", 4, 12298},
	{"DQ55", 4, 12299},
	{"DQ56", 4, 12300},
	{"DQ57", 4, 12301},
	{"DQ58", 4, 12302},
	{"DQ59", 4, 12303},
	{"DQ60", 4, 12304},
	{"DQ61", 4, 12305},
	{"DQ62", 4, 12306},
	{"DQ63", 4, 12307},
	{"DQ64", 4, 12308},
	{"DQ65", 4, 12309},
	{"DQ66", 4, 12310},
	{"DQ67", 4, 12311},
	{"DQ68", 4, 12312},
	{"DQ69", 4, 12313},
	{"DQ70", 4, 12314},
	{"DQ71", 4, 12315},
	{"DQ72", 4, 12316},
	{"DQ73", 4, 12317},
	{"DQ74", 4, 12318},
	{"DQ75", 4, 12319},
	{"DQ76", 4, 12320},
	{"DQ77", 4, 12321},
	{"DQ78", 4, 12322},
	{"DQ79", 4, 12323},
	{"DQ80", 4, 12324},
	{"DQ81", 4, 12325},
	{"DQ82", 4, 12326},
	{"DQ83", 4, 12327},
	{"DQ84", 4, 12328},
	{"DQ85", 4, 12329},
	{"DQ86", 4, 12330},
	{"DQ87", 4, 12331},
	{"DQ88", 4, 12332},
	{"DQ89", 4, 12333},
	{"DQ90", 4, 12334},
	{"DQ91", 4, 12335},
	{"DQ92", 4, 12336},
	{"DQ93", 4, 12337},
	{"DQ94", 4, 12338},
	{"DQ95", 4, 12339},
	{"DQ96", 4, 12340},
	{"DQ97", 4, 12341},
	{"DQ98", 4, 12342},
	{"DQ99", 4, 12343},
	{"EB00", 4, 12344},
	{"EB01", 4, 12345},
	{"EB02", 4, 12346},
	{"EB03", 4, 12347},
	{"EB04", 4, 12348},
	{"EB05", 4, 12349},
	{"EB06", 4, 12350},
	{"EB07", 4, 12351},
	{"EB08", 4, 12352},
	{"EB09", 4, 12353},
	{"EB10", 4, 12354},
	{"EB11", 4, 12355},
	{"EB12", 4, 12356},
	{"EB13", 4, 12357},
	{"EB14", 4, 12358},
	{"EB15", 4, 12359},
	{"EB16", 4, 12360},
	{"EB17", 4, 12361},
	{"EB18", 4, 12362},
	{"EB19", 4, 12363},
	{"EB20", 4, 12364},
	{"EB21", 4, 12365},
	{"EB22", 4, 12366},
	{"EB23", 4, 12367},
	{"EB24", 4, 12368},
	{"EB25", 4, 12369},
	{"EB26", 4, 12370},
	{"EB27", 4, 12371},
	{"EB28", 4, 12372},
	{"EB29", 4, 12373},
	{"EB30", 4, 12374},
	{"EB31", 4, 12375},
	{"EB32", 4, 12376},
	{"EB33", 4, 12377},
	{"EB34", 4, 12378},
	{"EB35", 4, 12379},
	{"EB36", 4, 12380},
	{"EB37", 4, 12381},
	{"EB38", 4, 12382},
	{"EB39", 4, 12383},
	{"EB40", 4, 12384},
	{"EB41", 4, 12385},
	{"EB42", 4, 12386},
	{"EB43", 4, 12387},
	{"EB44", 4, 12388},
	{"EB45", 4, 12389},
	{"EB46", 4, 12390},
	{"EB47", 4, 12391},
	{"EB48", 4, 12392},
	{"EB49", 4, 12393},
	{"EB50", 4, 12394},
	{"EB51", 4, 12395},
	{"EB52", 4, 12396},
	{"EB53", 4, 12397},
	{"EB54", 4, 12398},
	{"EB55", 4, 12399},
	{"EB56", 4, 12400},
	{"EB57", 4, 12401},
	{"EB58", 4, 12402},
	{"EB59", 4, 12403},
	{"EB60", 4, 12404},
	{"EB61", 4, 12405},
	{"EB62", 4, 12406},
	{"EB63", 4, 12407},
	{"EB64", 4, 12408},
	{"EB65", 4, 12409},
	{"EB66", 4, 12410},
	{"EB67", 4, 12411},
	{"EB68", 4, 12412},
	{"EB69", 4, 12413},
	{"EB70", 4, 12414},
	{"EB71", 4, 12415},
	{"EB72", 4, 12416},
	{"EB73", 4, 12417},
	{"EB74", 4, 12418},
	{"EB75", 4, 12419},
	{"EB76", 4, 12420},
	{"EB77", 4, 12421},
	{"EB78", 4, 12422},
	{"EB79", 4, 12423},
	{"EB80", 4, 12424},
	{"EB81", 4, 12425},
	{"EB82", 4, 12426},
	{"EB83", 4, 12427},
	{"EB84", 4, 12428},
	{"EB85", 4, 12429},
	{"EB86", 4, 12430},
	{"EB87", 4, 12431},
	{"EB88", 4, 12432},
	{"EB89", 4, 12433},
	{"EB90", 4, 12434},
	{"EB91", 4, 12435},
	{"EB92", 4, 12436},
	{"EB93", 4, 12437},
	{"EB94", 4, 12438},
	{"EB95", 4, 12439},
	{"EB96", 4, 12440},
	{"EB97", 4, 12441},
	{"EB98", 4, 12442},
	{"EB99", 4, 12443},
	{"EJ00", 4, 12444},
	{"EJ01", 4, 12445},
	{"EJ02", 4, 12446},
	{"EJ03", 4, 12447},
	{"EJ04", 4, 12448},
	{"EJ05", 4, 12449},
	{"EJ06", 4, 12450},
	{"EJ07", 4, 12451},
	{"EJ08", 4, 12452},
	{"EJ09", 4, 12453},
	{"EJ10", 4, 12454},
	{"EJ11", 4, 12455},
	{"EJ12", 4, 12456},
	{"EJ13", 4, 12457},
	{"EJ14", 4, 12458},
	{"EJ15", 4, 12459},
	{"EJ16", 4, 12460},
	{"EJ17", 4, 12461},
	{"EJ18", 4, 12462},
	{"EJ19", 4, 12463},
	{"EJ20", 4, 12464},
	{"EJ21", 4, 12465},
	{"EJ22", 4, 12466},
	{"EJ23", 4, 12467},
	{"EJ24", 4, 12468},
	{"EJ25", 4, 12469},
	{"EJ26", 4, 12470},
	{"EJ27", 4, 12471},
	{"EJ28", 4, 12472},
	{"EJ29", 4, 12473},
	{"EJ30", 4, 12474},
	{"EJ31", 4, 12475},
	{"EJ32", 4, 12476},
	{"EJ33", 4, 12477},
	{"EJ34", 4, 12478},
	{"EJ35", 4, 12479},
	{"EJ36", 4, 12480},
	{"EJ37", 4, 12481},
	{"EJ38", 4, 12482},
	{"EJ39", 4, 12483},
	{"EJ40", 4, 12484},
	{"EJ41", 4, 12485},
	{"EJ42", 4, 12486},
	{"EJ43", 4, 12487},
	{"EJ44", 4, 12488},
	{"EJ45", 4, 12489},
	{"EJ46", 4, 12490},
	{"EJ47", 4, 12491},
	{"EJ48", 4, 12492},
	{"EJ49", 4, 12493},
	{"EJ50", 4, 12494},
	{"EJ51", 4, 12495},
	{"EJ52", 4, 12496},
	{"EJ53", 4, 12497},
	{"EJ54", 4, 12498},
	{"EJ55", 4, 12499},
	{"EJ56", 4, 12500},
	{"EJ57", 4, 12501},
	{"EJ58", 4, 12502},
	{"EJ59", 4, 12503},
	{"EJ60", 4, 12504},
	{"EJ61", 4, 12505},
	{"EJ62", 4, 12506},
	{"EJ63", 4, 12507},
	{"EJ64", 4, 12508},
	{"EJ65", 4, 12509},
	{"EJ66", 4, 12510},
	{"EJ67", 4, 12511},
	{"EJ68", 4, 12512},
	{"EJ69", 4, 12513},
	{"EJ70", 4, 12514},
	{"EJ71", 4, 12515},
	{"EJ72", 4, 12516},
	{"EJ73", 4, 12517},
	{"EJ74", 4, 12518},
	{"EJ75", 4, 12519},
	{"EJ76", 4, 12520},
	{"EJ77", 4, 12521},
	{"EJ78", 4, 12522},
	{"EJ79", 4, 12523},
	{"EJ80", 4, 12524},
	{"EJ81", 4, 12525},
	{"EJ82", 4, 12526},
	{"EJ83", 4, 12527},
	{"EJ84", 4, 12528},
	{"EJ85", 4, 12529},
	{"EJ86", 4, 12530},
	{"EJ87", 4, 12531},
	{"EJ88", 4, 12532},
	{"EJ89", 4, 12533},
	{"EJ90", 4, 12534},
	{"EJ91", 4, 12535},
	{"EJ92", 4, 12536},
	{"EJ93", 4, 12537},
	{"EJ94", 4, 12538},
	{"EJ95", 4, 12539},
	{"EJ96", 4, 12540},
	{"EJ97", 4, 12541},
	{"EJ98", 4, 12542},
	{"EJ99", 4, 12543},
	{"EK00", 4, 12544},
	{"EK01", 4, 12545},
	{"EK02", 4, 12546},
	{"EK03", 4, 12547},
	{"EK04", 4, 12548},
	{"EK05", 4, 12549},
	{"EK06", 4, 12550},
	{"EK07", 4, 12551},
	{"EK08", 4, 12552},
	{"EK09", 4, 12553},
	{"EK10", 4, 12554},
	{"EK11", 4, 12555},
	{"EK12", 4, 12556},
	{"EK13", 4, 12557},
	{"EK14", 4, 12558},
	{"EK15", 4, 12559},
	{"EK16", 4, 12560},
	{"EK17", 4, 12561},
	{"EK18", 4, 12562},
	{"EK19", 4, 12563},
	{"EK20", 4, 12564},
	{"EK21", 4, 12565},
	{"EK22", 4, 12566},
	{"EK23", 4, 12567},
	{"EK24", 4, 12568},
	{"EK25", 4, 12569},
	{"EK26", 4, 12570},
	{"EK27", 4, 12571},
	{"EK28", 4, 12572},
	{"EK29", 4, 12573},
	{"EK30", 4, 12574},
	{"EK31", 4, 12575},
	{"EK32", 4, 12576},
	{"EK33", 4, 12577},
	{"EK34", 4, 12578},
	{"EK35", 4, 12579},
	{"EK36", 4, 12580},
	{"EK37", 4, 12581},
	{"EK38", 4, 12582},
	{"EK39", 4, 12583},
	{"EK40", 4, 12584},
	{"EK41", 4, 12585},
	{"EK42", 4, 12586},
	{"EK43", 4, 12587},
	{"EK44", 4, 12588},
	{"EK45", 4, 12589},
	{"EK46", 4, 12590},
	{"EK47", 4, 12591},
	{"EK48", 4, 12592},
	{"EK49", 4, 12593},
	{"EK50", 4, 12594},
	{"EK51", 4, 12595},
	{"EK52", 4, 12596},
	{"EK53", 4, 12597},
	{"EK54", 4, 12598},
	{"EK55", 4, 12599},
	{"EK56", 4, 12600},
	{"EK57", 4, 12601},
	{"EK58", 4, 12602},
	{"EK59", 4, 12603},
	{"EK60", 4, 12604},
	{"EK61", 4, 12605},
	{"EK62", 4, 12606},
	{"EK63", 4, 12607},
	{"EK64", 4, 12608},
	{"EK65", 4, 12609},
	{"EK66", 4, 12610},
	{"EK67", 4, 12611},
	{"EK68", 4, 12612},
	{"EK69", 4, 12613},
	{"EK70", 4, 12614},
	{"EK71", 4, 12615},
	{"EK72", 4, 12616},
	{"EK73", 4, 12617},
	{"EK74", 4, 12618},
	{"EK75", 4, 12619},
	{"EK76", 4, 12620},
	{"EK77", 4, 12621},
	{"EK78", 4, 12622},
	{"EK79", 4, 12623},
	{"EK80", 4, 12624},
	{"EK81", 4, 12625},
	{"EK82", 4, 12626},
	{"EK83", 4, 12627},
	{"EK84", 4, 12628},
	{"EK85", 4, 12629},
	{"EK86", 4, 12630},
	{"EK87", 4, 12631},
	{"EK88", 4, 12632},
	{"EK89", 4, 12633},
	{"EK90", 4, 12634},
	{"EK91", 4, 12635},
	{"EK92", 4, 12636},
	{"EK93", 4, 12637},
	{"EK94", 4, 12638},
	{"EK95", 4, 12639},
	{"EK96", 4, 12640},
	{"EK97", 4, 12641},
	{"EK98", 4, 12642},
	{"EK99", 4, 12643},
	{"EL00", 4, 12644},
	{"EL01", 4, 12645},
	{"EL02", 4, 12646},
	{"EL03", 4, 12647},
	{"EL04", 4, 12648},
	{"EL05", 4, 12649},
	{"EL06", 4, 12650},
	{"EL07", 4, 12651},
	{"EL08", 4, 12652},
	{"EL09", 4, 12653},
	{"EL10", 4, 12654},
	{"EL11", 4, 12655},
	{"EL12", 4, 12656},
	{"EL13", 4, 12657},
	{"EL14", 4, 12658},
	{"EL15", 4, 12659},
	{"EL16", 4, 12660},
	{"EL17", 4, 12661},
	{"EL18", 4, 12662},
	{"EL19", 4, 12663},
	{"EL20", 4, 12664},
	{"EL21", 4, 12665},
	{"EL22", 4, 12666},
	{"EL23", 4, 12667},
	{"EL24", 4, 12668},
	{"EL25", 4, 12669},
	{"EL26", 4, 12670},
	{"EL27", 4, 12671},
	{"EL28", 4, 12672},
	{"EL29", 4, 12673},
	{"EL30", 4, 12674},
	{"EL31", 4, 12675},
	{"EL32", 4, 12676},
	{"EL33", 4, 12677},
	{"EL34", 4, 12678},
	{"EL35", 4, 12679},
	{"EL36", 4, 12680},
	{"EL37", 4, 12681},
	{"EL38", 4, 12682},
	{"EL39", 4, 12683},
	{"EL40", 4, 12684},
	{"EL41", 4, 12685},
	{"EL42", 4, 12686},
	{"EL43", 4, 12687},
	{"EL44", 4, 12688},
	{"EL45", 4, 12689},
	{"EL46", 4, 12690},
	{"EL47", 4, 12691},
	{"EL48", 4, 12692},
	{"EL49", 4, 12693},
	{"EL50", 4, 12694},
	{"EL51", 4, 12695},
	{"EL52", 4, 12696},
	{"EL53", 4, 12697},
	{"EL54", 4, 12698},
	{"EL55", 4, 12699},
	{"EL56", 4, 12700},
	{"EL57", 4, 12701},
	{"EL58", 4, 12702},
	{"EL59", 4, 12703},
	{"EL60", 4, 12704},
	{"EL61", 4, 12705},
	{"EL62", 4, 12706},
	{"EL63", 4, 12707},
	{"EL64", 4, 12708},
	{"EL65", 4, 12709},
	{"EL66", 4, 12710},
	{"EL67", 4, 12711},
	{"EL68", 4, 12712},
	{"EL69", 4, 12713},
	{"EL70", 4, 12714},
	{"EL71", 4, 12715},
	{"EL72", 4, 12716},
	{"EL73", 4, 12717},
	{"EL74", 4, 12718},
	{"EL75", 4, 12719},
	{"EL76", 4, 12720},
	{"EL77", 4, 12721},
	{"EL78", 4, 12722},
	{"EL79", 4, 12723},
	{"EL80", 4, 12724},
	{"EL81", 4, 12725},
	{"EL82", 4, 12726},
	{"EL83", 4, 12727},
	{"EL84", 4, 12728},
	{"EL85", 4, 12729},
	{"EL86", 4, 12730},
	{"EL87", 4, 12731},
	{"EL88", 4, 12732},
	{"EL89", 4, 12733},
	{"EL90", 4, 12734},
	{"EL91", 4, 12735},
	{"EL92", 4, 12736},
	{"EL93", 4, 12737},
	{"EL94", 4, 12738},
	{"EL95", 4, 12739},
	{"EL96", 4, 12740},
	{"EL97", 4, 12741},
	{"EL98", 4, 12742},
	{"EL99", 4, 12743},
	{"EM00", 4, 12744},
	{"EM01", 4, 12745},
	{"EM02", 4, 12746},
	{"EM03", 4, 12747},
	{"EM04", 4, 12748},
	{"EM05", 4, 12749},
	{"EM06", 4, 12750},
	{"EM07", 4, 12751},
	{"EM08", 4, 12752},
	{"EM09", 4, 12753},
	{"EM10", 4, 12754},
	{"EM11", 4, 12755},
	{"EM12", 4, 12756},
	{"EM13", 4, 12757},
	{"EM14", 4, 12758},
	{"EM15", 4, 12759},
	{"EM16", 4, 12760},
	{"EM17", 4, 12761},
	{"EM18", 4, 12762},
	{"EM19", 4, 12763},
	{"EM20", 4, 12764},
	{"EM21", 4, 12765},
	{"EM22", 4, 12766},
	{"EM23", 4, 12767},
	{"EM24", 4, 12768},
	{"EM25", 4, 12769},
	{"EM26", 4, 12770},
	{"EM27", 4, 12771},
	{"EM28", 4, 12772},
	{"EM29", 4, 12773},
	{"EM30", 4, 12774},
	{"EM31", 4, 12775},
	{"EM32", 4, 12776},
	{"EM33", 4, 12777},
	{"EM34", 4, 12778},
	{"EM35", 4, 12779},
	{"EM36", 4, 12780},
	{"EM37", 4, 12781},
	{"EM38", 4, 12782},
	{"EM39", 4, 12783},
	{"EM40", 4, 12784},
	{"EM41", 4, 12785},
	{"EM42", 4, 12786},
	{"EM43", 4, 12787},
	{"EM44", 4, 12788},
	{"EM45", 4, 12789},
	{"EM46", 4, 12790},
	{"EM47", 4, 12791},
	{"EM48", 4, 12792},
	{"EM49", 4, 12793},
	{"EM50", 4, 12794},
	{"EM51", 4, 12795},
	{"EM52", 4, 12796},
	{"EM53", 4, 12797},
	{"EM54", 4, 12798},
	{"EM55", 4, 12799},
	{"EM56", 4, 12800},
	{"EM57", 4, 12801},
	{"EM58", 4, 12802},
	{"EM59", 4, 12803},
	{"EM60", 4, 12804},
	{"EM61", 4, 12805},
	{"EM62", 4, 12806},
	{"EM63", 4, 12807},
	{"EM64", 4, 12808},
	{"EM65", 4, 12809},
	{"EM66", 4, 12810},
	{"EM67", 4, 12811},
	{"EM68", 4, 12812},
	{"EM69", 4, 12813},
	{"EM70", 4, 12814},
	{"EM71", 4, 12815},
	{"EM72", 4, 12816},
	{"EM73", 4, 12817},
	{"EM74", 4, 12818},
	{"EM75", 4, 12819},
	{"EM76", 4, 12820},
	{"EM77", 4, 12821},
	{"EM78", 4, 12822},
	{"EM79", 4, 12823},
	{"EM80", 4, 12824},
	{"EM81", 4, 12825},
	{"EM82", 4, 12826},
	{"EM83", 4, 12827},
	{"EM84", 4, 12828},
	{"EM85", 4, 12829},
	{"EM86", 4, 12830},
	{"EM87", 4, 12831},
	{"EM88", 4, 12832},
	{"EM89", 4, 12833},
	{"EM90", 4, 12834},
	{"EM91", 4, 12835},
	{"EM92", 4, 12836},
	{"EM93", 4, 12837},
	{"EM94", 4, 12838},
	{"EM95", 4, 12839},
	{"EM96", 4, 12840},
	{"EM97", 4, 12841},
	{"EM98", 4, 12842},
	{"EM99", 4, 12843},
	{"EN00", 4, 12844},
	{"EN01", 4, 12845},
	{"EN02", 4, 12846},
	{"EN03", 4, 12847},
	{"EN04", 4, 12848},
	{"EN05", 4, 12849},
	{"EN06", 4, 12850},
	{"EN07", 4, 12851},
	{"EN08", 4, 12852},
	{"EN09", 4, 12853},
	{"EN10", 4, 12854},
	{"EN11", 4, 12855},
	{"EN12", 4, 12856},
	{"EN13", 4, 12857},
	{"EN14", 4, 12858},
	{"EN15", 4, 12859},
	{"EN16", 4, 12860},
	{"EN17", 4, 12861},
	{"EN18", 4, 12862},
	{"EN19", 4, 12863},
	{"EN20", 4, 12864},
	{"EN21", 4, 12865},
	{"EN22", 4, 12866},
	{"EN23", 4, 12867},
	{"EN24", 4, 12868},
	{"EN25", 4, 12869},
	{"EN26", 4, 12870},
	{"EN27", 4, 12871},
	{"EN28", 4, 12872},
	{"EN29", 4, 12873},
	{"EN30", 4, 12874},
	{"EN31", 4, 12875},
	{"EN32", 4, 12876},
	{"EN33", 4, 12877},
	{"EN34", 4, 12878},
	{"EN35", 4, 12879},
	{"EN36", 4, 12880},
	{"EN37", 4, 12881},
	{"EN38", 4, 12882},
	{"EN39", 4, 12883},
	{"EN40", 4, 12884},
	{"EN41", 4, 12885},
	{"EN42", 4, 12886},
	{"EN43", 4, 12887},
	{"EN44", 4, 12888},
	{"EN45", 4, 12889},
	{"EN46", 4, 12890},
	{"EN47", 4, 12891},
	{"EN48", 4, 12892},
	{"EN49", 4, 12893},
	{"EN50", 4, 12894},
	{"EN51", 4, 12895},
	{"EN52", 4, 12896},
	{"EN53", 4, 12897},
	{"EN54", 4, 12898},
	{"EN55", 4, 12899},
	{"EN56", 4, 12900},
	{"EN57", 4, 12901},
	{"EN58", 4, 12902},
	{"EN59", 4, 12903},
	{"EN60", 4, 12904},
	{"EN61", 4, 12905},
	{"EN62", 4, 12906},
	{"EN63", 4, 12907},
	{"EN64", 4, 12908},
	{"EN65", 4, 12909},
	{"EN66", 4, 12910},
	{"EN67", 4, 12911},
	{"EN68", 4, 12912},
	{"EN69", 4, 12913},
	{"EN70", 4, 12914},
	{"EN71", 4, 12915},
	{"EN72", 4, 12916},
	{"EN73", 4, 12917},
	{"EN74", 4, 12918},
	{"EN75", 4, 12919},
	{"EN76", 4, 12920},
	{"EN77", 4, 12921},
	{"EN78", 4, 12922},
	{"EN79", 4, 12923},
	{"EN80", 4, 12924},
	{"EN81", 4, 12925},
	{"EN82", 4, 12926},
	{"EN83", 4, 12927},
	{"EN84", 4, 12928},
	{"EN85", 4, 12929},
	{"EN86", 4, 12930},
	{"EN87", 4, 12931},
	{"EN88", 4, 12932},
	{"EN89", 4, 12933},
	{"EN90", 4, 12934},
	{"EN91", 4, 12935},
	{"EN92", 4, 12936},
	{"EN93", 4, 12937},
	{"EN94", 4, 12938},
	{"EN95", 4, 12939},
	{"EN96", 4, 12940},
	{"EN97", 4, 12941},
	{"EN98", 4, 12942},
	{"EN99", 4, 12943},
	{"EO00", 4, 12944},
	{"EO01", 4, 12945},
	{"EO02", 4, 12946},
	{"EO03", 4, 12947},
	{"EO04", 4, 12948},
	{"EO05", 4, 12949},
	{"EO06", 4, 12950},
	{"EO07", 4, 12951},
	{"EO08", 4, 12952},
	{"EO09", 4, 12953},
	{"EO10", 4, 12954},
	{"EO11", 4, 12955},
	{"EO12", 4, 12956},
	{"EO13", 4, 12957},
	{"EO14", 4, 12958},
	{"EO15", 4, 12959},
	{"EO16", 4, 12960},
	{"EO17", 4, 12961},
	{"EO18", 4, 12962},
	{"EO19", 4, 12963},
	{"EO20", 4, 12964},
	{"EO21", 4, 12965},
	{"EO22", 4, 12966},
	{"EO23", 4, 12967},
	{"EO24", 4, 12968},
	{"EO25", 4, 12969},
	{"EO26", 4, 12970},
	{"EO27", 4, 12971},
	{"EO28", 4, 12972},
	{"EO29", 4, 12973},
	{"EO30", 4, 12974},
	{"EO31", 4, 12975},
	{"EO32", 4, 12976},
	{"EO33", 4, 12977},
	{"EO34", 4, 12978},
	{"EO35", 4, 12979},
	{"EO36", 4, 12980},
	{"EO37", 4, 12981},
	{"EO38", 4, 12982},
	{"EO39", 4, 12983},
	{"EO40", 4, 12984},
	{"EO41", 4, 12985},
	{"EO42", 4, 12986},
	{"EO43", 4, 12987},
	{"EO44", 4, 12988},
	{"EO45", 4, 12989},
	{"EO46", 4, 12990},
	{"EO47", 4, 12991},
	{"EO48", 4, 12992},
	{"EO49", 4, 12993},
	{"EO50", 4, 12994},
	{"EO51", 4, 12995},
	{"EO52", 4, 12996},
	{"EO53", 4, 12997},
	{"EO54", 4, 12998},
	{"EO55", 4, 12999},
	{"EO56", 4, 13000},
	{"EO57", 4, 13001},
	{"EO58", 4, 13002},
	{"EO59", 4, 13003},
	{"EO60", 4, 13004},
	{"EO61", 4, 13005},
	{"EO62", 4, 13006},
	{"EO63", 4, 13007},
	{"EO64", 4, 13008},
	{"EO65", 4, 13009},
	{"EO66", 4, 13010},
	{"EO67", 4, 13011},
	{"EO68", 4, 13012},
	{"EO69", 4, 13013},
	{"EO70", 4, 13014},
	{"EO71", 4, 13015},
	{"EO72", 4, 13016},
	{"EO73", 4, 13017},
	{"EO74", 4, 13018},
	{"EO75", 4, 13019},
	{"EO76", 4, 13020},
	{"EO77", 4, 13021},
	{"EO78", 4, 13022},
	{"EO79", 4, 13023},
	{"EO80", 4, 13024},
	{"EO81", 4, 13025},
	{"EO82", 4, 13026},
	{"EO83", 4, 13027},
	{"EO84", 4, 13028},
	{"EO85", 4, 13029},
	{"EO86", 4, 13030},
	{"EO87", 4, 13031},
	{"EO88", 4, 13032},
	{"EO89", 4, 13033},
	{"EO90", 4, 13034},
	{"EO91", 4, 13035},
	{"EO92", 4, 13036},
	{"EO93", 4, 13037},
	{"EO94", 4, 13038},
	{"EO95", 4, 13039},
	{"EO96", 4, 13040},
	{"EO97", 4, 13041},
	{"EO98", 4, 13042},
	{"EO99", 4, 13043},
	{"EP00", 4, 13044},
	{"EP01", 4, 13045},
	{"EP02", 4, 13046},
	{"EP03", 4, 13047},
	{"EP04", 4, 13048},
	{"EP05", 4, 13049},
	{"EP06", 4, 13050},
	{"EP07", 4, 13051},
	{"EP08", 4, 13052},
	{"EP09", 4, 13053},
	{"EP10", 4, 13054},
	{"EP11", 4, 13055},
	{"EP12", 4, 13056},
	{"EP13", 4, 13057},
	{"EP14", 4, 13058},
	{"EP15", 4, 13059},
	{"EP16", 4, 13060},
	{"EP17", 4, 13061},
	{"EP18", 4, 13062},
	{"EP19", 4, 13063},
	{"EP20", 4, 13064},
	{"EP21", 4, 13065},
	{"EP22", 4, 13066},
	{"EP23", 4, 13067},
	{"EP24", 4, 13068},
	{"EP25", 4, 13069},
	{"EP26", 4, 13070},
	{"EP27", 4, 13071},
	{"EP28", 4, 13072},
	{"EP29", 4, 13073},
	{"EP30", 4, 13074},
	{"EP31", 4, 13075},
	{"EP32", 4, 13076},
	{"EP33", 4, 13077},
	{"EP34", 4, 13078},
	{"EP35", 4, 13079},
	{"EP36", 4, 13080},
	{"EP37", 4, 13081},
	{"EP38", 4, 13082},
	{"EP39", 4, 13083},
	{"EP40", 4, 13084},
	{"EP41", 4, 13085},
	{"EP42", 4, 13086},
	{"EP43", 4, 13087},
	{"EP44", 4, 13088},
	{"EP45", 4, 13089},
	{"EP46", 4, 13090},
	{"EP47", 4, 13091},
	{"EP48", 4, 13092},
	{"EP49", 4, 13093},
	{"EP50", 4, 13094},
	{"EP51", 4, 13095},
	{"EP52", 4, 13096},
	{"EP53", 4, 13097},
	{"EP54", 4, 13098},
	{"EP55", 4, 13099},
	{"EP56", 4, 13100},
	{"EP57", 4, 13101},
	{"EP58", 4, 13102},
	{"EP59", 4, 13103},
	{"EP60", 4, 13104},
	{"EP61", 4, 13105},
	{"EP62", 4, 13106},
	{"EP63", 4, 13107},
	{"EP64", 4, 13108},
	{"EP65", 4, 13109},
	{"EP66", 4, 13110},
	{"EP67", 4, 13111},
	{"EP68", 4, 13112},
	{"EP69", 4, 13113},
	{"EP70", 4, 13114},
	{"EP71", 4, 13115},
	{"EP72", 4, 13116},
	{"EP73", 4, 13117},
	{"EP74", 4, 13118},
	{"EP75", 4, 13119},
	{"EP76", 4, 13120},
	{"EP77", 4, 13121},
	{"EP78", 4, 13122},
	{"EP79", 4, 13123},
	{"EP80", 4, 13124},
	{"EP81", 4, 13125},
	{"EP82", 4, 13126},
	{"EP83", 4, 13127},
	{"EP84", 4, 13128},
	{"EP85", 4, 13129},
	{"EP86", 4, 13130},
	{"EP87", 4, 13131},
	{"EP88", 4, 13132},
	{"EP89", 4, 13133},
	{"EP90", 4, 13134},
	{"EP91", 4, 13135},
	{"EP92", 4, 13136},
	{"EP93", 4, 13137},
	{"EP94", 4, 13138},
	{"EP95", 4, 13139},
	{"EP96", 4, 13140},
	{"EP97", 4, 13141},
	{"EP98", 4, 13142},
	{"EP99", 4, 13143},
	{"EQ00", 4, 13144},
	{"EQ01", 4, 13145},
	{"EQ02", 4, 13146},
	{"EQ03", 4, 13147},
	{"EQ04", 4, 13148},
	{"EQ05", 4, 13149},
	{"EQ06", 4, 13150},
	{"EQ07", 4, 13151},
	{"EQ08", 4, 13152},
	{"EQ09", 4, 13153},
	{"EQ10", 4, 13154},
	{"EQ11", 4, 13155},
	{"EQ12", 4, 13156},
	{"EQ13", 4, 13157},
	{"EQ14", 4, 13158},
	{"EQ15", 4, 13159},
	{"EQ16", 4, 13160},
	{"EQ17", 4, 13161},
	{"EQ18", 4, 13162},
	{"EQ19", 4, 13163},
	{"EQ20", 4, 13164},
	{"EQ21", 4, 13165},
	{"EQ22", 4, 13166},
	{"EQ23", 4, 13167},
	{"EQ24", 4, 13168},
	{"EQ25", 4, 13169},
	{"EQ26", 4, 13170},
	{"EQ27", 4, 13171},
	{"EQ28", 4, 13172},
	{"EQ29", 4, 13173},
	{"EQ30", 4, 13174},
	{"EQ31", 4, 13175},
	{"EQ32", 4, 13176},
	{"EQ33", 4, 13177},
	{"EQ34", 4, 13178},
	{"EQ35", 4, 13179},
	{"EQ36", 4, 13180},
	{"EQ37", 4, 13181},
	{"EQ38", 4, 13182},
	{"EQ39", 4, 13183},
	{"EQ40", 4, 13184},
	{"EQ41", 4, 13185},
	{"EQ42", 4, 13186},
	{"EQ43", 4, 13187},
	{"EQ44", 4, 13188},
	{"EQ45", 4, 13189},
	{"EQ46", 4, 13190},
	{"EQ47", 4, 13191},
	{"EQ48", 4, 13192},
	{"EQ49", 4, 13193},
	{"EQ50", 4, 13194},
	{"EQ51", 4, 13195},
	{"EQ52", 4, 13196},
	{"EQ53", 4, 13197},
	{"EQ54", 4, 13198},
	{"EQ55", 4, 13199},
	{"EQ56", 4, 13200},
	{"EQ57", 4, 13201},
	{"EQ58", 4, 13202},
	{"EQ59", 4, 13203},
	{"EQ60", 4, 13204},
	{"EQ61", 4, 13205},
	{"EQ62", 4, 13206},
	{"EQ63", 4, 13207},
	{"EQ64", 4, 13208},
	{"EQ65", 4, 13209},
	{"EQ66", 4, 13210},
	{"EQ67", 4, 13211},
	{"EQ68", 4, 13212},
	{"EQ69", 4, 13213},
	{"EQ70", 4, 13214},
	{"EQ71", 4, 13215},
	{"EQ72", 4, 13216},
	{"EQ73", 4, 13217},
	{"EQ74", 4, 13218},
	{"EQ75", 4, 13219},
	{"EQ76", 4, 13220},
	{"EQ77", 4, 13221},
	{"EQ78", 4, 13222},
	{"EQ79", 4, 13223},
	{"EQ80", 4, 13224},
	{"EQ81", 4, 13225},
	{"EQ82", 4, 13226},
	{"EQ83", 4, 13227},
	{"EQ84", 4, 13228},
	{"EQ85", 4, 13229},
	{"EQ86", 4, 13230},
	{"EQ87", 4, 13231},
	{"EQ88", 4, 13232},
	{"EQ89", 4, 13233},
	{"EQ90", 4, 13234},
	{"EQ91", 4, 13235},
	{"EQ92", 4, 13236},
	{"EQ93", 4, 13237},
	{"EQ94", 4, 13238},
	{"EQ95", 4, 13239},
	{"EQ96", 4, 13240},
	{"EQ97", 4, 13241},
	{"EQ98", 4, 13242},
	{"EQ99", 4, 13243},
	{"FB00", 4, 13244},
	{"FB01", 4, 13245},
	{"FB02", 4, 13246},
	{"FB03", 4, 13247},
	{"FB04", 4, 13248},
	{"FB05", 4, 13249},
	{"FB06", 4, 13250},
	{"FB07", 4, 13251},
	{"FB08", 4, 13252},
	{"FB09", 4, 13253},
	{"FB10", 4, 13254},
	{"FB11", 4, 13255},
	{"FB12", 4, 13256},
	{"FB13", 4, 13257},
	{"FB14", 4, 13258},
	{"FB15", 4, 13259},
	{"FB16", 4, 13260},
	{"FB17", 4, 13261},
	{"FB18", 4, 13262},
	{"FB19", 4, 13263},
	{"FB20", 4, 13264},
	{"FB21", 4, 13265},
	{"FB22", 4, 13266},
	{"FB23", 4, 13267},
	{"FB24", 4, 13268},
	{"FB25", 4, 13269},
	{"FB26", 4, 13270},
	{"FB27", 4, 13271},
	{"FB28", 4, 13272},
	{"FB29", 4, 13273},
	{"FB30", 4, 13274},
	{"FB31", 4, 13275},
	{"FB32", 4, 13276},
	{"FB33", 4, 13277},
	{"FB34", 4, 13278},
	{"FB35", 4, 13279},
	{"FB36", 4, 13280},
	{"FB37", 4, 13281},
	{"FB38", 4, 13282},
	{"FB39", 4, 13283},
	{"FB40", 4, 13284},
	{"FB41", 4, 13285},
	{"FB42", 4, 13286},
	{"FB43", 4, 13287},
	{"FB44", 4, 13288},
	{"FB45", 4, 13289},
	{"FB46", 4, 13290},
	{"FB47", 4, 13291},
	{"FB48", 4, 13292},
	{"FB49", 4, 13293},
	{"FB50", 4, 13294},
	{"FB51", 4, 13295},
	{"FB52", 4, 13296},
	{"FB53", 4, 13297},
	{"FB54", 4, 13298},
	{"FB55", 4, 13299},
	{"FB56", 4, 13300},
	{"FB57", 4, 13301},
	{"FB58", 4, 13302},
	{"FB59", 4, 13303},
	{"FB60", 4, 13304},
	{"FB61", 4, 13305},
	{"FB62", 4, 13306},
	{"FB63", 4, 13307},
	{"FB64", 4, 13308},
	{"FB65", 4, 13309},
	{"FB66", 4, 13310},
	{"FB67", 4, 13311},
	{"FB68", 4, 13312},
	{"FB69", 4, 13313},
	{"FB70", 4, 13314},
	{"FB71", 4, 13315},
	{"FB72", 4, 13316},
	{"FB73", 4, 13317},
	{"FB74", 4, 13318},
	{"FB75", 4, 13319},
	{"FB76", 4, 13320},
	{"FB77", 4, 13321},
	{"FB78", 4, 13322},
	{"FB79", 4, 13323},
	{"FB80", 4, 13324},
	{"FB81", 4, 13325},
	{"FB82", 4, 13326},
	{"FB83", 4, 13327},
	{"FB84", 4, 13328},
	{"FB85", 4, 13329},
	{"FB86", 4, 13330},
	{"FB87", 4, 13331},
	{"FB88", 4, 13332},
	{"FB89", 4, 13333},
	{"FB90", 4, 13334},
	{"FB91", 4, 13335},
	{"FB92", 4, 13336},
	{"FB93", 4, 13337},
	{"FB94", 4, 13338},
	{"FB95", 4, 13339},
	{"FB96", 4, 13340},
	{"FB97", 4, 13341},
	{"FB98", 4, 13342},
	{"FB99", 4, 13343},
	{"FC00", 4, 13344},
	{"FC01", 4, 13345},
	{"FC02", 4, 13346},
	{"FC03", 4, 13347},
	{"FC04", 4, 13348},
	{"FC05", 4, 13349},
	{"FC06", 4, 13350},
	{"FC07", 4, 13351},
	{"FC08", 4, 13352},
	{"FC09", 4, 13353},
	{"FC10", 4, 13354},
	{"FC11", 4, 13355},
	{"FC12", 4, 13356},
	{"FC13", 4, 13357},
	{"FC14", 4, 13358},
	{"FC15", 4, 13359},
	{"FC16", 4, 13360},
	{"FC17", 4, 13361},
	{"FC18", 4, 13362},
	{"FC19", 4, 13363},
	{"FC20", 4, 13364},
	{"FC21", 4, 13365},
	{"FC22", 4, 13366},
	{"FC23", 4, 13367},
	{"FC24", 4, 13368},
	{"FC25", 4, 13369},
	{"FC26", 4, 13370},
	{"FC27", 4, 13371},
	{"FC28", 4, 13372},
	{"FC29", 4, 13373},
	{"FC30", 4, 13374},
	{"FC31", 4, 13375},
	{"FC32", 4, 13376},
	{"FC33", 4, 13377},
	{"FC34", 4, 13378},
	{"FC35", 4, 13379},
	{"FC36", 4, 13380},
	{"FC37", 4, 13381},
	{"FC38", 4, 13382},
	{"FC39", 4, 13383},
	{"FC40", 4, 13384},
	{"FC41", 4, 13385},
	{"FC42", 4, 13386},
	{"FC43", 4, 13387},
	{"FC44", 4, 13388},
	{"FC45", 4, 13389},
	{"FC46", 4, 13390},
	{"FC47", 4, 13391},
	{"FC48", 4, 13392},
	{"FC49", 4, 13393},
	{"FC50", 4, 13394},
	{"FC51", 4, 13395},
	{"FC52", 4, 13396},
	{"FC53", 4, 13397},
	{"FC54", 4, 13398},
	{"FC55", 4, 13399},
	{"FC56", 4, 13400},
	{"FC57", 4, 13401},
	{"FC58", 4, 13402},
	{"FC59", 4, 13403},
	{"FC60", 4, 13404},
	{"FC61", 4, 13405},
	{"FC62", 4, 13406},
	{"FC63", 4, 13407},
	{"FC64", 4, 13408},
	{"FC65", 4, 13409},
	{"FC66", 4, 13410},
	{"FC67", 4, 13411},
	{"FC68", 4, 13412},
	{"FC69", 4, 13413},
	{"FC70", 4, 13414},
	{"FC71", 4, 13415},
	{"FC72", 4, 13416},
	{"FC73", 4, 13417},
	{"FC74", 4, 13418},
	{"FC75", 4, 13419},
	{"FC76", 4, 13420},
	{"FC77", 4, 13421},
	{"FC78", 4, 13422},
	{"FC79", 4, 13423},
	{"FC80", 4, 13424},
	{"FC81", 4, 13425},
	{"FC82", 4, 13426},
	{"FC83", 4, 13427},
	{"FC84", 4, 13428},
	{"FC85", 4, 13429},
	{"FC86", 4, 13430},
	{"FC87", 4, 13431},
	{"FC88", 4, 13432},
	{"FC89", 4, 13433},
	{"FC90", 4, 13434},
	{"FC91", 4, 13435},
	{"FC92", 4, 13436},
	{"FC93", 4, 13437},
	{"FC94", 4, 13438},
	{"FC95", 4, 13439},
	{"FC96", 4, 13440},
	{"FC97", 4, 13441},
	{"FC98", 4, 13442},
	{"FC99", 4, 13443},
	{"FD00", 4, 13444},
	{"FD01", 4, 13445},
	{"FD02", 4, 13446},
	{"FD03", 4, 13447},
	{"FD04", 4, 13448},
	{"FD05", 4, 13449},
	{"FD06", 4, 13450},
	{"FD07", 4, 13451},
	{"FD08", 4, 13452},
	{"FD09", 4, 13453},
	{"FD10", 4, 13454},
	{"FD11", 4, 13455},
	{"FD12", 4, 13456},
	{"FD13", 4, 13457},
	{"FD14", 4, 13458},
	{"FD15", 4, 13459},
	{"FD16", 4, 13460},
	{"FD17", 4, 13461},
	{"FD18", 4, 13462},
	{"FD19", 4, 13463},
	{"FD20", 4, 13464},
	{"FD21", 4, 13465},
	{"FD22", 4, 13466},
	{"FD23", 4, 13467},
	{"FD24", 4, 13468},
	{"FD25", 4, 13469},
	{"FD26", 4, 13470},
	{"FD27", 4, 13471},
	{"FD28", 4, 13472},
	{"FD29", 4, 13473},
	{"FD30", 4, 13474},
	{"FD31", 4, 13475},
	{"FD32", 4, 13476},
	{"FD33", 4, 13477},
	{"FD34", 4, 13478},
	{"FD35", 4, 13479},
	{"FD36", 4, 13480},
	{"FD37", 4, 13481},
	{"FD38", 4, 13482},
	{"FD39", 4, 13483},
	{"FD40", 4, 13484},
	{"FD41", 4, 13485},
	{"FD42", 4, 13486},
	{"FD43", 4, 13487},
	{"FD44", 4, 13488},
	{"FD45", 4, 13489},
	{"FD46", 4, 13490},
	{"FD47", 4, 13491},
	{"FD48", 4, 13492},
	{"FD49", 4, 13493},
	{"FD50", 4, 13494},
	{"FD51", 4, 13495},
	{"FD52", 4, 13496},
	{"FD53", 4, 13497},
	{"FD54", 4, 13498},
	{"FD55", 4, 13499},
	{"FD56", 4, 13500},
	{"FD57", 4, 13501},
	{"FD58", 4, 13502},
	{"FD59", 4, 13503},
	{"FD60", 4, 13504},
	{"FD61", 4, 13505},
	{"FD62", 4, 13506},
	{"FD63", 4, 13507},
	{"FD64", 4, 13508},
	{"FD65", 4, 13509},
	{"FD66", 4, 13510},
	{"FD67", 4, 13511},
	{"FD68", 4, 13512},
	{"FD69", 4, 13513},
	{"FD70", 4, 13514},
	{"FD71", 4, 13515},
	{"FD72", 4, 13516},
	{"FD73", 4, 13517},
	{"FD74", 4, 13518},
	{"FD75", 4, 13519},
	{"FD76", 4, 13520},
	{"FD77", 4, 13521},
	{"FD78", 4, 13522},
	{"FD79", 4, 13523},
	{"FD80", 4, 13524},
	{"FD81", 4, 13525},
	{"FD82", 4, 13526},
	{"FD83", 4, 13527},
	{"FD84", 4, 13528},
	{"FD85", 4, 13529},
	{"FD86", 4, 13530},
	{"FD87", 4, 13531},
	{"FD88", 4, 13532},
	{"FD89", 4, 13533},
	{"FD90", 4, 13534},
	{"FD91", 4, 13535},
	{"FD92", 4, 13536},
	{"FD93", 4, 13537},
	{"FD94", 4, 13538},
	{"FD95", 4, 13539},
	{"FD96", 4, 13540},
	{"FD97", 4, 13541},
	{"FD98", 4, 13542},
	{"FD99", 4, 13543},
	{"FE00", 4, 13544},
	{"FE01", 4, 13545},
	{"FE02", 4, 13546},
	{"FE03", 4, 13547},
	{"FE04", 4, 13548},
	{"FE05", 4, 13549},
	{"FE06", 4, 13550},
	{"FE07", 4, 13551},
	{"FE08", 4, 13552},
	{"FE09", 4, 13553},
	{"FE10", 4, 13554},
	{"FE11", 4, 13555},
	{"FE12", 4, 13556},
	{"FE13", 4, 13557},
	{"FE14", 4, 13558},
	{"FE15", 4, 13559},
	{"FE16", 4, 13560},
	{"FE17", 4, 13561},
	{"FE18", 4, 13562},
	{"FE19", 4, 13563},
	{"FE20", 4, 13564},
	{"FE21", 4, 13565},
	{"FE22", 4, 13566},
	{"FE23", 4, 13567},
	{"FE24", 4, 13568},
	{"FE25", 4, 13569},
	{"FE26", 4, 13570},
	{"FE27", 4, 13571},
	{"FE28", 4, 13572},
	{"FE29", 4, 13573},
	{"FE30", 4, 13574},
	{"FE31", 4, 13575},
	{"FE32", 4, 13576},
	{"FE33", 4, 13577},
	{"FE34", 4, 13578},
	{"FE35", 4, 13579},
	{"FE36", 4, 13580},
	{"FE37", 4, 13581},
	{"FE38", 4, 13582},
	{"FE39", 4, 13583},
	{"FE40", 4, 13584},
	{"FE41", 4, 13585},
	{"FE42", 4, 13586},
	{"FE43", 4, 13587},
	{"FE44", 4, 13588},
	{"FE45", 4, 13589},
	{"FE46", 4, 13590},
	{"FE47", 4, 13591},
	{"FE48", 4, 13592},
	{"FE49", 4, 13593},
	{"FE50", 4, 13594},
	{"FE51", 4, 13595},
	{"FE52", 4, 13596},
	{"FE53", 4, 13597},
	{"FE54", 4, 13598},
	{"FE55", 4, 13599},
	{"FE56", 4, 13600},
	{"FE57", 4, 13601},
	{"FE58", 4, 13602},
	{"FE59", 4, 13603},
	{"FE60", 4, 13604},
	{"FE61", 4, 13605},
	{"FE62", 4, 13606},
	{"FE63", 4, 13607},
	{"FE64", 4, 13608},
	{"FE65", 4, 13609},
	{"FE66", 4, 13610},
	{"FE67", 4, 13611},
	{"FE68", 4, 13612},
	{"FE69", 4, 13613},
	{"FE70", 4, 13614},
	{"FE71", 4, 13615},
	{"FE72", 4, 13616},
	{"FE73", 4, 13617},
	{"FE74", 4, 13618},
	{"FE75", 4, 13619},
	{"FE76", 4, 13620},
	{"FE77", 4, 13621},
	{"FE78", 4, 13622},
	{"FE79", 4, 13623},
	{"FE80", 4, 13624},
	{"FE81", 4, 13625},
	{"FE82", 4, 13626},
	{"FE83", 4, 13627},
	{"FE84", 4, 13628},
	{"FE85", 4, 13629},
	{"FE86", 4, 13630},
	{"FE87", 4, 13631},
	{"FE88", 4, 13632},
	{"FE89", 4, 13633},
	{"FE90", 4, 13634},
	{"FE91", 4, 13635},
	{"FE92", 4, 13636},
	{"FE93", 4, 13637},
	{"FE94", 4, 13638},
	{"FE95", 4, 13639},
	{"FE96", 4, 13640},
	{"FE97", 4, 13641},
	{"FE98", 4, 13642},
	{"FE99", 4, 13643},
	{"FF00", 4, 13644},
	{"FF01", 4, 13645},
	{"FF02", 4, 13646},
	{"FF03", 4, 13647},
	{"FF04", 4, 13648},
	{"FF05", 4, 13649},
	{"FF06", 4, 13650},
	{"FF07", 4, 13651},
	{"FF08", 4, 13652},
	{"FF09", 4, 13653},
	{"FF10", 4, 13654},
	{"FF11", 4, 13655},
	{"FF12", 4, 13656},
	{"FF13", 4, 13657},
	{"FF14", 4, 13658},
	{"FF15", 4, 13659},
	{"FF16", 4, 13660},
	{"FF17", 4, 13661},
	{"FF18", 4, 13662},
	{"FF19", 4, 13663},
	{"FF20", 4, 13664},
	{"FF21", 4, 13665},
	{"FF22", 4, 13666},
	{"FF23", 4, 13667},
	{"FF24", 4, 13668},
	{"FF25", 4, 13669},
	{"FF26", 4, 13670},
	{"FF27", 4, 13671},
	{"FF28", 4, 13672},
	{"FF29", 4, 13673},
	{"FF30", 4, 13674},
	{"FF31", 4, 13675},
	{"FF32", 4, 13676},
	{"FF33", 4, 13677},
	{"FF34", 4, 13678},
	{"FF35", 4, 13679},
	{"FF36", 4, 13680},
	{"FF37", 4, 13681},
	{"FF38", 4, 13682},
	{"FF39", 4, 13683},
	{"FF40", 4, 13684},
	{"FF41", 4, 13685},
	{"FF42", 4, 13686},
	{"FF43", 4, 13687},
	{"FF44", 4, 13688},
	{"FF45", 4, 13689},
	{"FF46", 4, 13690},
	{"FF47", 4, 13691},
	{"FF48", 4, 13692},
	{"FF49", 4, 13693},
	{"FF50", 4, 13694},
	{"FF51", 4, 13695},
	{"FF52", 4, 13696},
	{"FF53", 4, 13697},
	{"FF54", 4, 13698},
	{"FF55", 4, 13699},
	{"FF56", 4, 13700},
	{"FF57", 4, 13701},
	{"FF58", 4, 13702},
	{"FF59", 4, 13703},
	{"FF60", 4, 13704},
	{"FF61", 4, 13705},
	{"FF62", 4, 13706},
	{"FF63", 4, 13707},
	{"FF64", 4, 13708},
	{"FF65", 4, 13709},
	{"FF66", 4, 13710},
	{"FF67", 4, 13711},
	{"FF68", 4, 13712},
	{"FF69", 4, 13713},
	{"FF70", 4, 13714},
	{"FF71", 4, 13715},
	{"FF72", 4, 13716},
	{"FF73", 4, 13717},
	{"FF74", 4, 13718},
	{"FF75", 4, 13719},
	{"FF76", 4, 13720},
	{"FF77", 4, 13721},
	{"FF78", 4, 13722},
	{"FF79", 4, 13723},
	{"FF80", 4, 13724},
	{"FF81", 4, 13725},
	{"FF82", 4, 13726},
	{"FF83", 4, 13727},
	{"FF84", 4, 13728},
	{"FF85", 4, 13729},
	{"FF86", 4, 13730},
	{"FF87", 4, 13731},
	{"FF88", 4, 13732},
	{"FF89", 4, 13733},
	{"FF90", 4, 13734},
	{"FF91", 4, 13735},
	{"FF92", 4, 13736},
	{"FF93", 4, 13737},
	{"FF94", 4, 13738},
	{"FF95", 4, 13739},
	{"FF96", 4, 13740},
	{"FF97", 4, 13741},
	{"FF98", 4, 13742},
	{"FF99", 4, 13743},
	{"FG00", 4, 13744},
	{"FG01", 4, 13745},
	{"FG02", 4, 13746},
	{"FG03", 4, 13747},
	{"FG04", 4, 13748},
	{"FG05", 4, 13749},
	{"FG06", 4, 13750},
	{"FG07", 4, 13751},
	{"FG08", 4, 13752},
	{"FG09", 4, 13753},
	{"FG10", 4, 13754},
	{"FG11", 4, 13755},
	{"FG12", 4, 13756},
	{"FG13", 4, 13757},
	{"FG14", 4, 13758},
	{"FG15", 4, 13759},
	{"FG16", 4, 13760},
	{"FG17", 4, 13761},
	{"FG18", 4, 13762},
	{"FG19", 4, 13763},
	{"FG20", 4, 13764},
	{"FG21", 4, 13765},
	{"FG22", 4, 13766},
	{"FG23", 4, 13767},
	{"FG24", 4, 13768},
	{"FG25", 4, 13769},
	{"FG26", 4, 13770},
	{"FG27", 4, 13771},
	{"FG28", 4, 13772},
	{"FG29", 4, 13773},
	{"FG30", 4, 13774},
	{"FG31", 4, 13775},
	{"FG32", 4, 13776},
	{"FG33", 4, 13777},
	{"FG34", 4, 13778},
	{"FG35", 4, 13779},
	{"FG36", 4, 13780},
	{"FG37", 4, 13781},
	{"FG38", 4, 13782},
	{"FG39", 4, 13783},
	{"FG40", 4, 13784},
	{"FG41", 4, 13785},
	{"FG42", 4, 13786},
	{"FG43", 4, 13787},
	{"FG44", 4, 13788},
	{"FG45", 4, 13789},
	{"FG46", 4, 13790},
	{"FG47", 4, 13791},
	{"FG48", 4, 13792},
	{"FG49", 4, 13793},
	{"FG50", 4, 13794},
	{"FG51", 4, 13795},
	{"FG52", 4, 13796},
	{"FG53", 4, 13797},
	{"FG54", 4, 13798},
	{"FG55", 4, 13799},
	{"FG56", 4, 13800},
	{"FG57", 4, 13801},
	{"FG58", 4, 13802},
	{"FG59", 4, 13803},
	{"FG60", 4, 13804},
	{"FG61", 4, 13805},
	{"FG62", 4, 13806},
	{"FG63", 4, 13807},
	{"FG64", 4, 13808},
	{"FG65", 4, 13809},
	{"FG66", 4, 13810},
	{"FG67", 4, 13811},
	{"FG68", 4, 13812},
	{"FG69", 4, 13813},
	{"FG70", 4, 13814},
	{"FG71", 4, 13815},
	{"FG72", 4, 13816},
	{"FG73", 4, 13817},
	{"FG74", 4, 13818},
	{"FG75", 4, 13819},
	{"FG76", 4, 13820},
	{"FG77", 4, 13821},
	{"FG78", 4, 13822},
	{"FG79", 4, 13823},
	{"FG80", 4, 13824},
	{"FG81", 4, 13825},
	{"FG82", 4, 13826},
	{"FG83", 4, 13827},
	{"FG84", 4, 13828},
	{"FG85", 4, 13829},
	{"FG86", 4, 13830},
	{"FG87", 4, 13831},
	{"FG88", 4, 13832},
	{"FG89", 4, 13833},
	{"FG90", 4, 13834},
	{"FG91", 4, 13835},
	{"FG92", 4, 13836},
	{"FG93", 4, 13837},
	{"FG94", 4, 13838},
	{"FG95", 4, 13839},
	{"FG96", 4, 13840},
	{"FG97", 4, 13841},
	{"FG98", 4, 13842},
	{"FG99", 4, 13843},
	{"FH00", 4, 13844},
	{"FH01", 4, 13845},
	{"FH02", 4, 13846},
	{"FH03", 4, 13847},
	{"FH04", 4, 13848},
	{"FH05", 4, 13849},
	{"FH06", 4, 13850},
	{"FH07", 4, 13851},
	{"FH08", 4, 13852},
	{"FH09", 4, 13853},
	{"FH10", 4, 13854},
	{"FH11", 4, 13855},
	{"FH12", 4, 13856},
	{"FH13", 4, 13857},
	{"FH14", 4, 13858},
	{"FH15", 4, 13859},
	{"FH16", 4, 13860},
	{"FH17", 4, 13861},
	{"FH18", 4, 13862},
	{"FH19", 4, 13863},
	{"FH20", 4, 13864},
	{"FH21", 4, 13865},
	{"FH22", 4, 13866},
	{"FH23", 4, 13867},
	{"FH24", 4, 13868},
	{"FH25", 4, 13869},
	{"FH26", 4, 13870},
	{"FH27", 4, 13871},
	{"FH28", 4, 13872},
	{"FH29", 4, 13873},
	{"FH30", 4, 13874},
	{"FH31", 4, 13875},
	{"FH32", 4, 13876},
	{"FH33", 4, 13877},
	{"FH34", 4, 13878},
	{"FH35", 4, 13879},
	{"FH36", 4, 13880},
	{"FH37", 4, 13881},
	{"FH38", 4, 13882},
	{"FH39", 4, 13883},
	{"FH40", 4, 13884},
	{"FH41", 4, 13885},
	{"FH42", 4, 13886},
	{"FH43", 4, 13887},
	{"FH44", 4, 13888},
	{"FH45", 4, 13889},
	{"FH46", 4, 13890},
	{"FH47", 4, 13891},
	{"FH48", 4, 13892},
	{"FH49", 4, 13893},
	{"FH50", 4, 13894},
	{"FH51", 4, 13895},
	{"FH52", 4, 13896},
	{"FH53", 4, 13897},
	{"FH54", 4, 13898},
	{"FH55", 4, 13899},
	{"FH56", 4, 13900},
	{"FH57", 4, 13901},
	{"FH58", 4, 13902},
	{"FH59", 4, 13903},
	{"FH60", 4, 13904},
	{"FH61", 4, 13905},
	{"FH62", 4, 13906},
	{"FH63", 4, 13907},
	{"FH64", 4, 13908},
	{"FH65", 4, 13909},
	{"FH66", 4, 13910},
	{"FH67", 4, 13911},
	{"FH68", 4, 13912},
	{"FH69", 4, 13913},
	{"FH70", 4, 13914},
	{"FH71", 4, 13915},
	{"FH72", 4, 13916},
	{"FH73", 4, 13917},
	{"FH74", 4, 13918},
	{"FH75", 4, 13919},
	{"FH76", 4, 13920},
	{"FH77", 4, 13921},
	{"FH78", 4, 13922},
	{"FH79", 4, 13923},
	{"FH80", 4, 13924},
	{"FH81", 4, 13925},
	{"FH82", 4, 13926},
	{"FH83", 4, 13927},
	{"FH84", 4, 13928},
	{"FH85", 4, 13929},
	{"FH86", 4, 13930},
	{"FH87", 4, 13931},
	{"FH88", 4, 13932},
	{"FH89", 4, 13933},
	{"FH90", 4, 13934},
	{"FH91", 4, 13935},
	{"FH92", 4, 13936},
	{"FH93", 4, 13937},
	{"FH94", 4, 13938},
	{"FH95", 4, 13939},
	{"FH96", 4, 13940},
	{"FH97", 4, 13941},
	{"FH98", 4, 13942},
	{"FH99", 4, 13943},
	{"FI00", 4, 13944},
	{"FI01", 4, 13945},
	{"FI02", 4, 13946},
	{"FI03", 4, 13947},
	{"FI04", 4, 13948},
	{"FI05", 4, 13949},
	{"FI06", 4, 13950},
	{"FI07", 4, 13951},
	{"FI08", 4, 13952},
	{"FI09", 4, 13953},
	{"FI10", 4, 13954},
	{"FI11", 4, 13955},
	{"FI12", 4, 13956},
	{"FI13", 4, 13957},
	{"FI14", 4, 13958},
	{"FI15", 4, 13959},
	{"FI16", 4, 13960},
	{"FI17", 4, 13961},
	{"FI18", 4, 13962},
	{"FI19", 4, 13963},
	{"FI20", 4, 13964},
	{"FI21", 4, 13965},
	{"FI22", 4, 13966},
	{"FI23", 4, 13967},
	{"FI24", 4, 13968},
	{"FI25", 4, 13969},
	{"FI26", 4, 13970},
	{"FI27", 4, 13971},
	{"FI28", 4, 13972},
	{"FI29", 4, 13973},
	{"FI30", 4, 13974},
	{"FI31", 4, 13975},
	{"FI32", 4, 13976},
	{"FI33", 4, 13977},
	{"FI34", 4, 13978},
	{"FI35", 4, 13979},
	{"FI36", 4, 13980},
	{"FI37", 4, 13981},
	{"FI38", 4, 13982},
	{"FI39", 4, 13983},
	{"FI40", 4, 13984},
	{"FI41", 4, 13985},
	{"FI42", 4, 13986},
	{"FI43", 4, 13987},
	{"FI44", 4, 13988},
	{"FI45", 4, 13989},
	{"FI46", 4, 13990},
	{"FI47", 4, 13991},
	{"FI48", 4, 13992},
	{"FI49", 4, 13993},
	{"FI50", 4, 13994},
	{"FI51", 4, 13995},
	{"FI52", 4, 13996},
	{"FI53", 4, 13997},
	{"FI54", 4, 13998},
	{"FI55", 4, 13999},
	{"FI56", 4, 14000},
	{"FI57", 4, 14001},
	{"FI58", 4, 14002},
	{"FI59", 4, 14003},
	{"FI60", 4, 14004},
	{"FI61", 4, 14005},
	{"FI62", 4, 14006},
	{"FI63", 4, 14007},
	{"FI64", 4, 14008},
	{"FI65", 4, 14009},
	{"FI66", 4, 14010},
	{"FI67", 4, 14011},
	{"FI68", 4, 14012},
	{"FI69", 4, 14013},
	{"FI70", 4, 14014},
	{"FI71", 4, 14015},
	{"FI72", 4, 14016},
	{"FI73", 4, 14017},
	{"FI74", 4, 14018},
	{"FI75", 4, 14019},
	{"FI76", 4, 14020},
	{"FI77", 4, 14021},
	{"FI78", 4, 14022},
	{"FI79", 4, 14023},
	{"FI80", 4, 14024},
	{"FI81", 4, 14025},
	{"FI82", 4, 14026},
	{"FI83", 4, 14027},
	{"FI84", 4, 14028},
	{"FI85", 4, 14029},
	{"FI86", 4, 14030},
	{"FI87", 4, 14031},
	{"FI88", 4, 14032},
	{"FI89", 4, 14033},
	{"FI90", 4, 14034},
	{"FI91", 4, 14035},
	{"FI92", 4, 14036},
	{"FI93", 4, 14037},
	{"FI94", 4, 14038},
	{"FI95", 4, 14039},
	{"FI96", 4, 14040},
	{"FI97", 4, 14041},
	{"FI98", 4, 14042},
	{"FI99", 4, 14043},
	{"FJ00", 4, 14044},
	{"FJ01", 4, 14045},
	{"FJ02", 4, 14046},
	{"FJ03", 4, 14047},
	{"FJ04", 4, 14048},
	{"FJ05", 4, 14049},
	{"FJ06", 4, 14050},
	{"FJ07", 4, 14051},
	{"FJ08", 4, 14052},
	{"FJ09", 4, 14053},
	{"FJ10", 4, 14054},
	{"FJ11", 4, 14055},
	{"FJ12", 4, 14056},
	{"FJ13", 4, 14057},
	{"FJ14", 4, 14058},
	{"FJ15", 4, 14059},
	{"FJ16", 4, 14060},
	{"FJ17", 4, 14061},
	{"FJ18", 4, 14062},
	{"FJ19", 4, 14063},
	{"FJ20", 4, 14064},
	{"FJ21", 4, 14065},
	{"FJ22", 4, 14066},
	{"FJ23", 4, 14067},
	{"FJ24", 4, 14068},
	{"FJ25", 4, 14069},
	{"FJ26", 4, 14070},
	{"FJ27", 4, 14071},
	{"FJ28", 4, 14072},
	{"FJ29", 4, 14073},
	{"FJ30", 4, 14074},
	{"FJ31", 4, 14075},
	{"FJ32", 4, 14076},
	{"FJ33", 4, 14077},
	{"FJ34", 4, 14078},
	{"FJ35", 4, 14079},
	{"FJ36", 4, 14080},
	{"FJ37", 4, 14081},
	{"FJ38", 4, 14082},
	{"FJ39", 4, 14083},
	{"FJ40", 4, 14084},
	{"FJ41", 4, 14085},
	{"FJ42", 4, 14086},
	{"FJ43", 4, 14087},
	{"FJ44", 4, 14088},
	{"FJ45", 4, 14089},
	{"FJ46", 4, 14090},
	{"FJ47", 4, 14091},
	{"FJ48", 4, 14092},
	{"FJ49", 4, 14093},
	{"FJ50", 4, 14094},
	{"FJ51", 4, 14095},
	{"FJ52", 4, 14096},
	{"FJ53", 4, 14097},
	{"FJ54", 4, 14098},
	{"FJ55", 4, 14099},
	{"FJ56", 4, 14100},
	{"FJ57", 4, 14101},
	{"FJ58", 4, 14102},
	{"FJ59", 4, 14103},
	{"FJ60", 4, 14104},
	{"FJ61", 4, 14105},
	{"FJ62", 4, 14106},
	{"FJ63", 4, 14107},
	{"FJ64", 4, 14108},
	{"FJ65", 4, 14109},
	{"FJ66", 4, 14110},
	{"FJ67", 4, 14111},
	{"FJ68", 4, 14112},
	{"FJ69", 4, 14113},
	{"FJ70", 4, 14114},
	{"FJ71", 4, 14115},
	{"FJ72", 4, 14116},
	{"FJ73", 4, 14117},
	{"FJ74", 4, 14118},
	{"FJ75", 4, 14119},
	{"FJ76", 4, 14120},
	{"FJ77", 4, 14121},
	{"FJ78", 4, 14122},
	{"FJ79", 4, 14123},
	{"FJ80", 4, 14124},
	{"FJ81", 4, 14125},
	{"FJ82", 4, 14126},
	{"FJ83", 4, 14127},
	{"FJ84", 4, 14128},
	{"FJ85", 4, 14129},
	{"FJ86", 4, 14130},
	{"FJ87", 4, 14131},
	{"FJ88", 4, 14132},
	{"FJ89", 4, 14133},
	{"FJ90", 4, 14134},
	{"FJ91", 4, 14135},
	{"FJ92", 4, 14136},
	{"FJ93", 4, 14137},
	{"FJ94", 4, 14138},
	{"FJ95", 4, 14139},
	{"FJ96", 4, 14140},
	{"FJ97", 4, 14141},
	{"FJ98", 4, 14142},
	{"FJ99", 4, 14143},
	{"FK00", 4, 14144},
	{"FK01", 4, 14145},
	{"FK02", 4, 14146},
	{"FK03", 4, 14147},
	{"FK04", 4, 14148},
	{"FK05", 4, 14149},
	{"FK06", 4, 14150},
	{"FK07", 4, 14151},
	{"FK08", 4, 14152},
	{"FK09", 4, 14153},
	{"FK10", 4, 14154},
	{"FK11", 4, 14155},
	{"FK12", 4, 14156},
	{"FK13", 4, 14157},
	{"FK14", 4, 14158},
	{"FK15", 4, 14159},
	{"FK16", 4, 14160},
	{"FK17", 4, 14161},
	{"FK18", 4, 14162},
	{"FK19", 4, 14163},
	{"FK20", 4, 14164},
	{"FK21", 4, 14165},
	{"FK22", 4, 14166},
	{"FK23", 4, 14167},
	{"FK24", 4, 14168},
	{"FK25", 4, 14169},
	{"FK26", 4, 14170},
	{"FK27", 4, 14171},
	{"FK28", 4, 14172},
	{"FK29", 4, 14173},
	{"FK30", 4, 14174},
	{"FK31", 4, 14175},
	{"FK32", 4, 14176},
	{"FK33", 4, 14177},
	{"FK34", 4, 14178},
	{"FK35", 4, 14179},
	{"FK36", 4, 14180},
	{"FK37", 4, 14181},
	{"FK38", 4, 14182},
	{"FK39", 4, 14183},
	{"FK40", 4, 14184},
	{"FK41", 4, 14185},
	{"FK42", 4, 14186},
	{"FK43", 4, 14187},
	{"FK44", 4, 14188},
	{"FK45", 4, 14189},
	{"FK46", 4, 14190},
	{"FK47", 4, 14191},
	{"FK48", 4, 14192},
	{"FK49", 4, 14193},
	{"FK50", 4, 14194},
	{"FK51", 4, 14195},
	{"FK52", 4, 14196},
	{"FK53", 4, 14197},
	{"FK54", 4, 14198},
	{"FK55", 4, 14199},
	{"FK56", 4, 14200},
	{"FK57", 4, 14201},
	{"FK58", 4, 14202},
	{"FK59", 4, 14203},
	{"FK60", 4, 14204},
	{"FK61", 4, 14205},
	{"FK62", 4, 14206},
	{"FK63", 4, 14207},
	{"FK64", 4, 14208},
	{"FK65", 4, 14209},
	{"FK66", 4, 14210},
	{"FK67", 4, 14211},
	{"FK68", 4, 14212},
	{"FK69", 4, 14213},
	{"FK70", 4, 14214},
	{"FK71", 4, 14215},
	{"FK72", 4, 14216},
	{"FK73", 4, 14217},
	{"FK74", 4, 14218},
	{"FK75", 4, 14219},
	{"FK76", 4, 14220},
	{"FK77", 4, 14221},
	{"FK78", 4, 14222},
	{"FK79", 4, 14223},
	{"FK80", 4, 14224},
	{"FK81", 4, 14225},
	{"FK82", 4, 14226},
	{"FK83", 4, 14227},
	{"FK84", 4, 14228},
	{"FK85", 4, 14229},
	{"FK86", 4, 14230},
	{"FK87", 4, 14231},
	{"FK88", 4, 14232},
	{"FK89", 4, 14233},
	{"FK90", 4, 14234},
	{"FK91", 4, 14235},
	{"FK92", 4, 14236},
	{"FK93", 4, 14237},
	{"FK94", 4, 14238},
	{"FK95", 4, 14239},
	{"FK96", 4, 14240},
	{"FK97", 4, 14241},
	{"FK98", 4, 14242},
	{"FK99", 4, 14243},
	{"FL00", 4, 14244},
	{"FL01", 4, 14245},
	{"FL02", 4, 14246},
	{"FL03", 4, 14247},
	{"FL04", 4, 14248},
	{"FL05", 4, 14249},
	{"FL06", 4, 14250},
	{"FL07", 4, 14251},
	{"FL08", 4, 14252},
	{"FL09", 4, 14253},
	{"FL10", 4, 14254},
	{"FL11", 4, 14255},
	{"FL12", 4, 14256},
	{"FL13", 4, 14257},
	{"FL14", 4, 14258},
	{"FL15", 4, 14259},
	{"FL16", 4, 14260},
	{"FL17", 4, 14261},
	{"FL18", 4, 14262},
	{"FL19", 4, 14263},
	{"FL20", 4, 14264},
	{"FL21", 4, 14265},
	{"FL22", 4, 14266},
	{"FL23", 4, 14267},
	{"FL24", 4, 14268},
	{"FL25", 4, 14269},
	{"FL26", 4, 14270},
	{"FL27", 4, 14271},
	{"FL28", 4, 14272},
	{"FL29", 4, 14273},
	{"FL30", 4, 14274},
	{"FL31", 4, 14275},
	{"FL32", 4, 14276},
	{"FL33", 4, 14277},
	{"FL34", 4, 14278},
	{"FL35", 4, 14279},
	{"FL36", 4, 14280},
	{"FL37", 4, 14281},
	{"FL38", 4, 14282},
	{"FL39", 4, 14283},
	{"FL40", 4, 14284},
	{"FL41", 4, 14285},
	{"FL42", 4, 14286},
	{"FL43", 4, 14287},
	{"FL44", 4, 14288},
	{"FL45", 4, 14289},
	{"FL46", 4, 14290},
	{"FL47", 4, 14291},
	{"FL48", 4, 14292},
	{"FL49", 4, 14293},
	{"FL50", 4, 14294},
	{"FL51", 4, 14295},
	{"FL52", 4, 14296},
	{"FL53", 4, 14297},
	{"FL54", 4, 14298},
	{"FL55", 4, 14299},
	{"FL56", 4, 14300},
	{"FL57", 4, 14301},
	{"FL58", 4, 14302},
	{"FL59", 4, 14303},
	{"FL60", 4, 14304},
	{"FL61", 4, 14305},
	{"FL62", 4, 14306},
	{"FL63", 4, 14307},
	{"FL64", 4, 14308},
	{"FL65", 4, 14309},
	{"FL66", 4, 14310},
	{"FL67", 4, 14311},
	{"FL68", 4, 14312},
	{"FL69", 4, 14313},
	{"FL70", 4, 14314},
	{"FL71", 4, 14315},
	{"FL72", 4, 14316},
	{"FL73", 4, 14317},
	{"FL74", 4, 14318},
	{"FL75", 4, 14319},
	{"FL76", 4, 14320},
	{"FL77", 4, 14321},
	{"FL78", 4, 14322},
	{"FL79", 4, 14323},
	{"FL80", 4, 14324},
	{"FL81", 4, 14325},
	{"FL82", 4, 14326},
	{"FL83", 4, 14327},
	{"FL84", 4, 14328},
	{"FL85", 4, 14329},
	{"FL86", 4, 14330},
	{"FL87", 4, 14331},
	{"FL88", 4, 14332},
	{"FL89", 4, 14333},
	{"FL90", 4, 14334},
	{"FL91", 4, 14335},
	{"FL92", 4, 14336},
	{"FL93", 4, 14337},
	{"FL94", 4, 14338},
	{"FL95", 4, 14339},
	{"FL96", 4, 14340},
	{"FL97", 4, 14341},
	{"FL98", 4, 14342},
	{"FL99", 4, 14343},
	{"FM00", 4, 14344},
	{"FM01", 4, 14345},
	{"FM02", 4, 14346},
	{"FM03", 4, 14347},
	{"FM04", 4, 14348},
	{"FM05", 4, 14349},
	{"FM06", 4, 14350},
	{"FM07", 4, 14351},
	{"FM08", 4, 14352},
	{"FM09", 4, 14353},
	{"FM10", 4, 14354},
	{"FM11", 4, 14355},
	{"FM12", 4, 14356},
	{"FM13", 4, 14357},
	{"FM14", 4, 14358},
	{"FM15", 4, 14359},
	{"FM16", 4, 14360},
	{"FM17", 4, 14361},
	{"FM18", 4, 14362},
	{"FM19", 4, 14363},
	{"FM20", 4, 14364},
	{"FM21", 4, 14365},
	{"FM22", 4, 14366},
	{"FM23", 4, 14367},
	{"FM24", 4, 14368},
	{"FM25", 4, 14369},
	{"FM26", 4, 14370},
	{"FM27", 4, 14371},
	{"FM28", 4, 14372},
	{"FM29", 4, 14373},
	{"FM30", 4, 14374},
	{"FM31", 4, 14375},
	{"FM32", 4, 14376},
	{"FM33", 4, 14377},
	{"FM34", 4, 14378},
	{"FM35", 4, 14379},
	{"FM36", 4, 14380},
	{"FM37", 4, 14381},
	{"FM38", 4, 14382},
	{"FM39", 4, 14383},
	{"FM40", 4, 14384},
	{"FM41", 4, 14385},
	{"FM42", 4, 14386},
	{"FM43", 4, 14387},
	{"FM44", 4, 14388},
	{"FM45", 4, 14389},
	{"FM46", 4, 14390},
	{"FM47", 4, 14391},
	{"FM48", 4, 14392},
	{"FM49", 4, 14393},
	{"FM50", 4, 14394},
	{"FM51", 4, 14395},
	{"FM52", 4, 14396},
	{"FM53", 4, 14397},
	{"FM54", 4, 14398},
	{"FM55", 4, 14399},
	{"FM56", 4, 14400},
	{"FM57", 4, 14401},
	{"FM58", 4, 14402},
	{"FM59", 4, 14403},
	{"FM60", 4, 14404},
	{"FM61", 4, 14405},
	{"FM62", 4, 14406},
	{"FM63", 4, 14407},
	{"FM64", 4, 14408},
	{"FM65", 4, 14409},
	{"FM66", 4, 14410},
	{"FM67", 4, 14411},
	{"FM68", 4, 14412},
	{"FM69", 4, 14413},
	{"FM70", 4, 14414},
	{"FM71", 4, 14415},
	{"FM72", 4, 14416},
	{"FM73", 4, 14417},
	{"FM74", 4, 14418},
	{"FM75", 4, 14419},
	{"FM76", 4, 14420},
	{"FM77", 4, 14421},
	{"FM78", 4, 14422},
	{"FM79", 4, 14423},
	{"FM80", 4, 14424},
	{"FM81", 4, 14425},
	{"FM82", 4, 14426},
	{"FM83", 4, 14427},
	{"FM84", 4, 14428},
	{"FM85", 4, 14429},
	{"FM86", 4, 14430},
	{"FM87", 4, 14431},
	{"FM88", 4, 14432},
	{"FM89", 4, 14433},
	{"FM90", 4, 14434},
	{"FM91", 4, 14435},
	{"FM92", 4, 14436},
	{"FM93", 4, 14437},
	{"FM94", 4, 14438},
	{"FM95", 4, 14439},
	{"FM96", 4, 14440},
	{"FM97", 4, 14441},
	{"FM98", 4, 14442},
	{"FM99", 4, 14443},
	{"FN00", 4, 14444},
	{"FN01", 4, 14445},
	{"FN02", 4, 14446},
	{"FN03", 4, 14447},
	{"FN04", 4, 14448},
	{"FN05", 4, 14449},
	{"FN06", 4, 14450},
	{"FN07", 4, 14451},
	{"FN08", 4, 14452},
	{"FN09", 4, 14453},
	{"FN10", 4, 14454},
	{"FN11", 4, 14455},
	{"FN12", 4, 14456},
	{"FN13", 4, 14457},
	{"FN14", 4, 14458},
	{"FN15", 4, 14459},
	{"FN16", 4, 14460},
	{"FN17", 4, 14461},
	{"FN18", 4, 14462},
	{"FN19", 4, 14463},
	{"FN20", 4, 14464},
	{"FN21", 4, 14465},
	{"FN22", 4, 14466},
	{"FN23", 4, 14467},
	{"FN24", 4, 14468},
	{"FN25", 4, 14469},
	{"FN26", 4, 14470},
	{"FN27", 4, 14471},
	{"FN28", 4, 14472},
	{"FN29", 4, 14473},
	{"FN30", 4, 14474},
	{"FN31", 4, 14475},
	{"FN32", 4, 14476},
	{"FN33", 4, 14477},
	{"FN34", 4, 14478},
	{"FN35", 4, 14479},
	{"FN36", 4, 14480},
	{"FN37", 4, 14481},
	{"FN38", 4, 14482},
	{"FN39", 4, 14483},
	{"FN40", 4, 14484},
	{"FN41", 4, 14485},
	{"FN42", 4, 14486},
	{"FN43", 4, 14487},
	{"FN44", 4, 14488},
	{"FN45", 4, 14489},
	{"FN46", 4, 14490},
	{"FN47", 4, 14491},
	{"FN48", 4, 14492},
	{"FN49", 4, 14493},
	{"FN50", 4, 14494},
	{"FN51", 4, 14495},
	{"FN52", 4, 14496},
	{"FN53", 4, 14497},
	{"FN54", 4, 14498},
	{"FN55", 4, 14499},
	{"FN56", 4, 14500},
	{"FN57", 4, 14501},
	{"FN58", 4, 14502},
	{"FN59", 4, 14503},
	{"FN60", 4, 14504},
	{"FN61", 4, 14505},
	{"FN62", 4, 14506},
	{"FN63", 4, 14507},
	{"FN64", 4, 14508},
	{"FN65", 4, 14509},
	{"FN66", 4, 14510},
	{"FN67", 4, 14511},
	{"FN68", 4, 14512},
	{"FN69", 4, 14513},
	{"FN70", 4, 14514},
	{"FN71", 4, 14515},
	{"FN72", 4, 14516},
	{"FN73", 4, 14517},
	{"FN74", 4, 14518},
	{"FN75", 4, 14519},
	{"FN76", 4, 14520},
	{"FN77", 4, 14521},
	{"FN78", 4, 14522},
	{"FN79", 4, 14523},
	{"FN80", 4, 14524},
	{"FN81", 4, 14525},
	{"FN82", 4, 14526},
	{"FN83", 4, 14527},
	{"FN84", 4, 14528},
	{"FN85", 4, 14529},
	{"FN86", 4, 14530},
	{"FN87", 4, 14531},
	{"FN88", 4, 14532},
	{"FN89", 4, 14533},
	{"FN90", 4, 14534},
	{"FN91", 4, 14535},
	{"FN92", 4, 14536},
	{"FN93", 4, 14537},
	{"FN94", 4, 14538},
	{"FN95", 4, 14539},
	{"FN96", 4, 14540},
	{"FN97", 4, 14541},
	{"FN98", 4, 14542},
	{"FN99", 4, 14543},
	{"FO00", 4, 14544},
	{"FO01", 4, 14545},
	{"FO02", 4, 14546},
	{"FO03", 4, 14547},
	{"FO04", 4, 14548},
	{"FO05", 4, 14549},
	{"FO06", 4, 14550},
	{"FO07", 4, 14551},
	{"FO08", 4, 14552},
	{"FO09", 4, 14553},
	{"FO10", 4, 14554},
	{"FO11", 4, 14555},
	{"FO12", 4, 14556},
	{"FO13", 4, 14557},
	{"FO14", 4, 14558},
	{"FO15", 4, 14559},
	{"FO16", 4, 14560},
	{"FO17", 4, 14561},
	{"FO18", 4, 14562},
	{"FO19", 4, 14563},
	{"FO20", 4, 14564},
	{"FO21", 4, 14565},
	{"FO22", 4, 14566},
	{"FO23", 4, 14567},
	{"FO24", 4, 14568},
	{"FO25", 4, 14569},
	{"FO26", 4, 14570},
	{"FO27", 4, 14571},
	{"FO28", 4, 14572},
	{"FO29", 4, 14573},
	{"FO30", 4, 14574},
	{"FO31", 4, 14575},
	{"FO32", 4, 14576},
	{"FO33", 4, 14577},
	{"FO34", 4, 14578},
	{"FO35", 4, 14579},
	{"FO36", 4, 14580},
	{"FO37", 4, 14581},
	{"FO38", 4, 14582},
	{"FO39", 4, 14583},
	{"FO40", 4, 14584},
	{"FO41", 4, 14585},
	{"FO42", 4, 14586},
	{"FO43", 4, 14587},
	{"FO44", 4, 14588},
	{"FO45", 4, 14589},
	{"FO46", 4, 14590},
	{"FO47", 4, 14591},
	{"FO48", 4, 14592},
	{"FO49", 4, 14593},
	{"FO50", 4, 14594},
	{"FO51", 4, 14595},
	{"FO52", 4, 14596},
	{"FO53", 4, 14597},
	{"FO54", 4, 14598},
	{"FO55", 4, 14599},
	{"FO56", 4, 14600},
	{"FO57", 4, 14601},
	{"FO58", 4, 14602},
	{"FO59", 4, 14603},
	{"FO60", 4, 14604},
	{"FO61", 4, 14605},
	{"FO62", 4, 14606},
	{"FO63", 4, 14607},
	{"FO64", 4, 14608},
	{"FO65", 4, 14609},
	{"FO66", 4, 14610},
	{"FO67", 4, 14611},
	{"FO68", 4, 14612},
	{"FO69", 4, 14613},
	{"FO70", 4, 14614},
	{"FO71", 4, 14615},
	{"FO72", 4, 14616},
	{"FO73", 4, 14617},
	{"FO74", 4, 14618},
	{"FO75", 4, 14619},
	{"FO76", 4, 14620},
	{"FO77", 4, 14621},
	{"FO78", 4, 14622},
	{"FO79", 4, 14623},
	{"FO80", 4, 14624},
	{"FO81", 4, 14625},
	{"FO82", 4, 14626},
	{"FO83", 4, 14627},
	{"FO84", 4, 14628},
	{"FO85", 4, 14629},
	{"FO86", 4, 14630},
	{"FO87", 4, 14631},
	{"FO88", 4, 14632},
	{"FO89", 4, 14633},
	{"FO90", 4, 14634},
	{"FO91", 4, 14635},
	{"FO92", 4, 14636},
	{"FO93", 4, 14637},
	{"FO94", 4, 14638},
	{"FO95", 4, 14639},
	{"FO96", 4, 14640},
	{"FO97", 4, 14641},
	{"FO98", 4, 14642},
	{"FO99", 4, 14643},
	{"FP00", 4, 14644},
	{"FP01", 4, 14645},
	{"FP02", 4, 14646},
	{"FP03", 4, 14647},
	{"FP04", 4, 14648},
	{"FP05", 4, 14649},
	{"FP06", 4, 14650},
	{"FP07", 4, 14651},
	{"FP08", 4, 14652},
	{"FP09", 4, 14653},
	{"FP10", 4, 14654},
	{"FP11", 4, 14655},
	{"FP12", 4, 14656},
	{"FP13", 4, 14657},
	{"FP14", 4, 14658},
	{"FP15", 4, 14659},
	{"FP16", 4, 14660},
	{"FP17", 4, 14661},
	{"FP18", 4, 14662},
	{"FP19", 4, 14663},
	{"FP20", 4, 14664},
	{"FP21", 4, 14665},
	{"FP22", 4, 14666},
	{"FP23", 4, 14667},
	{"FP24", 4, 14668},
	{"FP25", 4, 14669},
	{"FP26", 4, 14670},
	{"FP27", 4, 14671},
	{"FP28", 4, 14672},
	{"FP29", 4, 14673},
	{"FP30", 4, 14674},
	{"FP31", 4, 14675},
	{"FP32", 4, 14676},
	{"FP33", 4, 14677},
	{"FP34", 4, 14678},
	{"FP35", 4, 14679},
	{"FP36", 4, 14680},
	{"FP37", 4, 14681},
	{"FP38", 4, 14682},
	{"FP39", 4, 14683},
	{"FP40", 4, 14684},
	{"FP41", 4, 14685},
	{"FP42", 4, 14686},
	{"FP43", 4, 14687},
	{"FP44", 4, 14688},
	{"FP45", 4, 14689},
	{"FP46", 4, 14690},
	{"FP47", 4, 14691},
	{"FP48", 4, 14692},
	{"FP49", 4, 14693},
	{"FP50", 4, 14694},
	{"FP51", 4, 14695},
	{"FP52", 4, 14696},
	{"FP53", 4, 14697},
	{"FP54", 4, 14698},
	{"FP55", 4, 14699},
	{"FP56", 4, 14700},
	{"FP57", 4, 14701},
	{"FP58", 4, 14702},
	{"FP59", 4, 14703},
	{"FP60", 4, 14704},
	{"FP61", 4, 14705},
	{"FP62", 4, 14706},
	{"FP63", 4, 14707},
	{"FP64", 4, 14708},
	{"FP65", 4, 14709},
	{"FP66", 4, 14710},
	{"FP67", 4, 14711},
	{"FP68", 4, 14712},
	{"FP69", 4, 14713},
	{"FP70", 4, 14714},
	{"FP71", 4, 14715},
	{"FP72", 4, 14716},
	{"FP73", 4, 14717},
	{"FP74", 4, 14718},
	{"FP75", 4, 14719},
	{"FP76", 4, 14720},
	{"FP77", 4, 14721},
	{"FP78", 4, 14722},
	{"FP79", 4, 14723},
	{"FP80", 4, 14724},
	{"FP81", 4, 14725},
	{"FP82", 4, 14726},
	{"FP83", 4, 14727},
	{"FP84", 4, 14728},
	{"FP85", 4, 14729},
	{"FP86", 4, 14730},
	{"FP87", 4, 14731},
	{"FP88", 4, 14732},
	{"FP89", 4, 14733},
	{"FP90", 4, 14734},
	{"FP91", 4, 14735},
	{"FP92", 4, 14736},
	{"FP93", 4, 14737},
	{"FP94", 4, 14738},
	{"FP95", 4, 14739},
	{"FP96", 4, 14740},
	{"FP97", 4, 14741},
	{"FP98", 4, 14742},
	{"FP99", 4, 14743},
	{"FQ00", 4, 14744},
	{"FQ01", 4, 14745},
	{"FQ02", 4, 14746},
	{"FQ03", 4, 14747},
	{"FQ04", 4, 14748},
	{"FQ05", 4, 14749},
	{"FQ06", 4, 14750},
	{"FQ07", 4, 14751},
	{"FQ08", 4, 14752},
	{"FQ09", 4, 14753},
	{"FQ10", 4, 14754},
	{"FQ11", 4, 14755},
	{"FQ12", 4, 14756},
	{"FQ13", 4, 14757},
	{"FQ14", 4, 14758},
	{"FQ15", 4, 14759},
	{"FQ16", 4, 14760},
	{"FQ17", 4, 14761},
	{"FQ18", 4, 14762},
	{"FQ19", 4, 14763},
	{"FQ20", 4, 14764},
	{"FQ21", 4, 14765},
	{"FQ22", 4, 14766},
	{"FQ23", 4, 14767},
	{"FQ24", 4, 14768},
	{"FQ25", 4, 14769},
	{"FQ26", 4, 14770},
	{"FQ27", 4, 14771},
	{"FQ28", 4, 14772},
	{"FQ29", 4, 14773},
	{"FQ30", 4, 14774},
	{"FQ31", 4, 14775},
	{"FQ32", 4, 14776},
	{"FQ33", 4, 14777},
	{"FQ34", 4, 14778},
	{"FQ35", 4, 14779},
	{"FQ36", 4, 14780},
	{"FQ37", 4, 14781},
	{"FQ38", 4, 14782},
	{"FQ39", 4, 14783},
	{"FQ40", 4, 14784},
	{"FQ41", 4, 14785},
	{"FQ42", 4, 14786},
	{"FQ43", 4, 14787},
	{"FQ44", 4, 14788},
	{"FQ45", 4, 14789},
	{"FQ46", 4, 14790},
	{"FQ47", 4, 14791},
	{"FQ48", 4, 14792},
	{"FQ49", 4, 14793},
	{"FQ50", 4, 14794},
	{"FQ51", 4, 14795},
	{"FQ52", 4, 14796},
	{"FQ53", 4, 14797},
	{"FQ54", 4, 14798},
	{"FQ55", 4, 14799},
	{"FQ56", 4, 14800},
	{"FQ57", 4, 14801},
	{"FQ58", 4, 14802},
	{"FQ59", 4, 14803},
	{"FQ60", 4, 14804},
	{"FQ61", 4, 14805},
	{"FQ62", 4, 14806},
	{"FQ63", 4, 14807},
	{"FQ64", 4, 14808},
	{"FQ65", 4, 14809},
	{"FQ66", 4, 14810},
	{"FQ67", 4, 14811},
	{"FQ68", 4, 14812},
	{"FQ69", 4, 14813},
	{"FQ70", 4, 14814},
	{"FQ71", 4, 14815},
	{"FQ72", 4, 14816},
	{"FQ73", 4, 14817},
	{"FQ74", 4, 14818},
	{"FQ75", 4, 14819},
	{"FQ76", 4, 14820},
	{"FQ77", 4, 14821},
	{"FQ78", 4, 14822},
	{"FQ79", 4, 14823},
	{"FQ80", 4, 14824},
	{"FQ81", 4, 14825},
	{"FQ82", 4, 14826},
	{"FQ83", 4, 14827},
	{"FQ84", 4, 14828},
	{"FQ85", 4, 14829},
	{"FQ86", 4, 14830},
	{"FQ87", 4, 14831},
	{"FQ88", 4, 14832},
	{"FQ89", 4, 14833},
	{"FQ90", 4, 14834},
	{"FQ91", 4, 14835},
	{"FQ92", 4, 14836},
	{"FQ93", 4, 14837},
	{"FQ94", 4, 14838},
	{"FQ95", 4, 14839},
	{"FQ96", 4, 14840},
	{"FQ97", 4, 14841},
	{"FQ98", 4, 14842},
	{"FQ99", 4, 14843},
	{"GF00", 4, 14844},
	{"GF01", 4, 14845},
	{"GF02", 4, 14846},
	{"GF03", 4, 14847},
	{"GF04", 4, 14848},
	{"GF05", 4, 14849},
	{"GF06", 4, 14850},
	{"GF07", 4, 14851},
	{"GF08", 4, 14852},
	{"GF09", 4, 14853},
	{"GF10", 4, 14854},
	{"GF11", 4, 14855},
	{"GF12", 4, 14856},
	{"GF13", 4, 14857},
	{"GF14", 4, 14858},
	{"GF15", 4, 14859},
	{"GF16", 4, 14860},
	{"GF17", 4, 14861},
	{"GF18", 4, 14862},
	{"GF19", 4, 14863},
	{"GF20", 4, 14864},
	{"GF21", 4, 14865},
	{"GF22", 4, 14866},
	{"GF23", 4, 14867},
	{"GF24", 4, 14868},
	{"GF25", 4, 14869},
	{"GF26", 4, 14870},
	{"GF27", 4, 14871},
	{"GF28", 4, 14872},
	{"GF29", 4, 14873},
	{"GF30", 4, 14874},
	{"GF31", 4, 14875},
	{"GF32", 4, 14876},
	{"GF33", 4, 14877},
	{"GF34", 4, 14878},
	{"GF35", 4, 14879},
	{"GF36", 4, 14880},
	{"GF37", 4, 14881},
	{"GF38", 4, 14882},
	{"GF39", 4, 14883},
	{"GF40", 4, 14884},
	{"GF41", 4, 14885},
	{"GF42", 4, 14886},
	{"GF43", 4, 14887},
	{"GF44", 4, 14888},
	{"GF45", 4, 14889},
	{"GF46", 4, 14890},
	{"GF47", 4, 14891},
	{"GF48", 4, 14892},
	{"GF49", 4, 14893},
	{"GF50", 4, 14894},
	{"GF51", 4, 14895},
	{"GF52", 4, 14896},
	{"GF53", 4, 14897},
	{"GF54", 4, 14898},
	{"GF55", 4, 14899},
	{"GF56", 4, 14900},
	{"GF57", 4, 14901},
	{"GF58", 4, 14902},
	{"GF59", 4, 14903},
	{"GF60", 4, 14904},
	{"GF61", 4, 14905},
	{"GF62", 4, 14906},
	{"GF63", 4, 14907},
	{"GF64", 4, 14908},
	{"GF65", 4, 14909},
	{"GF66", 4, 14910},
	{"GF67", 4, 14911},
	{"GF68", 4, 14912},
	{"GF69", 4, 14913},
	{"GF70", 4, 14914},
	{"GF71", 4, 14915},
	{"GF72", 4, 14916},
	{"GF73", 4, 14917},
	{"GF74", 4, 14918},
	{"GF75", 4, 14919},
	{"GF76", 4, 14920},
	{"GF77", 4, 14921},
	{"GF78", 4, 14922},
	{"GF79", 4, 14923},
	{"GF80", 4, 14924},
	{"GF81", 4, 14925},
	{"GF82", 4, 14926},
	{"GF83", 4, 14927},
	{"GF84", 4, 14928},
	{"GF85", 4, 14929},
	{"GF86", 4, 14930},
	{"GF87", 4, 14931},
	{"GF88", 4, 14932},
	{"GF89", 4, 14933},
	{"GF90", 4, 14934},
	{"GF91", 4, 14935},
	{"GF92", 4, 14936},
	{"GF93", 4, 14937},
	{"GF94", 4, 14938},
	{"GF95", 4, 14939},
	{"GF96", 4, 14940},
	{"GF97", 4, 14941},
	{"GF98", 4, 14942},
	{"GF99", 4, 14943},
	{"GG00", 4, 14944},
	{"GG01", 4, 14945},
	{"GG02", 4, 14946},
	{"GG03", 4, 14947},
	{"GG04", 4, 14948},
	{"GG05", 4, 14949},
	{"GG06", 4, 14950},
	{"GG07", 4, 14951},
	{"GG08", 4, 14952},
	{"GG09", 4, 14953},
	{"GG10", 4, 14954},
	{"GG11", 4, 14955},
	{"GG12", 4, 14956},
	{"GG13", 4, 14957},
	{"GG14", 4, 14958},
	{"GG15", 4, 14959},
	{"GG16", 4, 14960},
	{"GG17", 4, 14961},
	{"GG18", 4, 14962},
	{"GG19", 4, 14963},
	{"GG20", 4, 14964},
	{"GG21", 4, 14965},
	{"GG22", 4, 14966},
	{"GG23", 4, 14967},
	{"GG24", 4, 14968},
	{"GG25", 4, 14969},
	{"GG26", 4, 14970},
	{"GG27", 4, 14971},
	{"GG28", 4, 14972},
	{"GG29", 4, 14973},
	{"GG30", 4, 14974},
	{"GG31", 4, 14975},
	{"GG32", 4, 14976},
	{"GG33", 4, 14977},
	{"GG34", 4, 14978},
	{"GG35", 4, 14979},
	{"GG36", 4, 14980},
	{"GG37", 4, 14981},
	{"GG38", 4, 14982},
	{"GG39", 4, 14983},
	{"GG40", 4, 14984},
	{"GG41", 4, 14985},
	{"GG42", 4, 14986},
	{"GG43", 4, 14987},
	{"GG44", 4, 14988},
	{"GG45", 4, 14989},
	{"GG46", 4, 14990},
	{"GG47", 4, 14991},
	{"GG48", 4, 14992},
	{"GG49", 4, 14993},
	{"GG50", 4, 14994},
	{"GG51", 4, 14995},
	{"GG52", 4, 14996},
	{"GG53", 4, 14997},
	{"GG54", 4, 14998},
	{"GG55", 4, 14999},
	{"GG56", 4, 15000},
	{"GG57", 4, 15001},
	{"GG58", 4, 15002},
	{"GG59", 4, 15003},
	{"GG60", 4, 15004},
	{"GG61", 4, 15005},
	{"GG62", 4, 15006},
	{"GG63", 4, 15007},
	{"GG64", 4, 15008},
	{"GG65", 4, 15009},
	{"GG66", 4, 15010},
	{"GG67", 4, 15011},
	{"GG68", 4, 15012},
	{"GG69", 4, 15013},
	{"GG70", 4, 15014},
	{"GG71", 4, 15015},
	{"GG72", 4, 15016},
	{"GG73", 4, 15017},
	{"GG74", 4, 15018},
	{"GG75", 4, 15019},
	{"GG76", 4, 15020},
	{"GG77", 4, 15021},
	{"GG78", 4, 15022},
	{"GG79", 4, 15023},
	{"GG80", 4, 15024},
	{"GG81", 4, 15025},
	{"GG82", 4, 15026},
	{"GG83", 4, 15027},
	{"GG84", 4, 15028},
	{"GG85", 4, 15029},
	{"GG86", 4, 15030},
	{"GG87", 4, 15031},
	{"GG88", 4, 15032},
	{"GG89", 4, 15033},
	{"GG90", 4, 15034},
	{"GG91", 4, 15035},
	{"GG92", 4, 15036},
	{"GG93", 4, 15037},
	{"GG94", 4, 15038},
	{"GG95", 4, 15039},
	{"GG96", 4, 15040},
	{"GG97", 4, 15041},
	{"GG98", 4, 15042},
	{"GG99", 4, 15043},
	{"GH00", 4, 15044},
	{"GH01", 4, 15045},
	{"GH02", 4, 15046},
	{"GH03", 4, 15047},
	{"GH04", 4, 15048},
	{"GH05", 4, 15049},
	{"GH06", 4, 15050},
	{"GH07", 4, 15051},
	{"GH08", 4, 15052},
	{"GH09", 4, 15053},
	{"GH10", 4, 15054},
	{"GH11", 4, 15055},
	{"GH12", 4, 15056},
	{"GH13", 4, 15057},
	{"GH14", 4, 15058},
	{"GH15", 4, 15059},
	{"GH16", 4, 15060},
	{"GH17", 4, 15061},
	{"GH18", 4, 15062},
	{"GH19", 4, 15063},
	{"GH20", 4, 15064},
	{"GH21", 4, 15065},
	{"GH22", 4, 15066},
	{"GH23", 4, 15067},
	{"GH24", 4, 15068},
	{"GH25", 4, 15069},
	{"GH26", 4, 15070},
	{"GH27", 4, 15071},
	{"GH28", 4, 15072},
	{"GH29", 4, 15073},
	{"GH30", 4, 15074},
	{"GH31", 4, 15075},
	{"GH32", 4, 15076},
	{"GH33", 4, 15077},
	{"GH34", 4, 15078},
	{"GH35", 4, 15079},
	{"GH36", 4, 15080},
	{"GH37", 4, 15081},
	{"GH38", 4, 15082},
	{"GH39", 4, 15083},
	{"GH40", 4, 15084},
	{"GH41", 4, 15085},
	{"GH42", 4, 15086},
	{"GH43", 4, 15087},
	{"GH44", 4, 15088},
	{"GH45", 4, 15089},
	{"GH46", 4, 15090},
	{"GH47", 4, 15091},
	{"GH48", 4, 15092},
	{"GH49", 4, 15093},
	{"GH50", 4, 15094},
	{"GH51", 4, 15095},
	{"GH52", 4, 15096},
	{"GH53", 4, 15097},
	{"GH54", 4, 15098},
	{"GH55", 4, 15099},
	{"GH56", 4, 15100},
	{"GH57", 4, 15101},
	{"GH58", 4, 15102},
	{"GH59", 4, 15103},
	{"GH60", 4, 15104},
	{"GH61", 4, 15105},
	{"GH62", 4, 15106},
	{"GH63", 4, 15107},
	{"GH64", 4, 15108},
	{"GH65", 4, 15109},
	{"GH66", 4, 15110},
	{"GH67", 4, 15111},
	{"GH68", 4, 15112},
	{"GH69", 4, 15113},
	{"GH70", 4, 15114},
	{"GH71", 4, 15115},
	{"GH72", 4, 15116},
	{"GH73", 4, 15117},
	{"GH74", 4, 15118},
	{"GH75", 4, 15119},
	{"GH76", 4, 15120},
	{"GH77", 4, 15121},
	{"GH78", 4, 15122},
	{"GH79", 4, 15123},
	{"GH80", 4, 15124},
	{"GH81", 4, 15125},
	{"GH82", 4, 15126},
	{"GH83", 4, 15127},
	{"GH84", 4, 15128},
	{"GH85", 4, 15129},
	{"GH86", 4, 15130},
	{"GH87", 4, 15131},
	{"GH88", 4, 15132},
	{"GH89", 4, 15133},
	{"GH90", 4, 15134},
	{"GH91", 4, 15135},
	{"GH92", 4, 15136},
	{"GH93", 4, 15137},
	{"GH94", 4, 15138},
	{"GH95", 4, 15139},
	{"GH96", 4, 15140},
	{"GH97", 4, 15141},
	{"GH98", 4, 15142},
	{"GH99", 4, 15143},
	{"GI00", 4, 15144},
	{"GI01", 4, 15145},
	{"GI02", 4, 15146},
	{"GI03", 4, 15147},
	{"GI04", 4, 15148},
	{"GI05", 4, 15149},
	{"GI06", 4, 15150},
	{"GI07", 4, 15151},
	{"GI08", 4, 15152},
	{"GI09", 4, 15153},
	{"GI10", 4, 15154},
	{"GI11", 4, 15155},
	{"GI12", 4, 15156},
	{"GI13", 4, 15157},
	{"GI14", 4, 15158},
	{"GI15", 4, 15159},
	{"GI16", 4, 15160},
	{"GI17", 4, 15161},
	{"GI18", 4, 15162},
	{"GI19", 4, 15163},
	{"GI20", 4, 15164},
	{"GI21", 4, 15165},
	{"GI22", 4, 15166},
	{"GI23", 4, 15167},
	{"GI24", 4, 15168},
	{"GI25", 4, 15169},
	{"GI26", 4, 15170},
	{"GI27", 4, 15171},
	{"GI28", 4, 15172},
	{"GI29", 4, 15173},
	{"GI30", 4, 15174},
	{"GI31", 4, 15175},
	{"GI32", 4, 15176},
	{"GI33", 4, 15177},
	{"GI34", 4, 15178},
	{"GI35", 4, 15179},
	{"GI36", 4, 15180},
	{"GI37", 4, 15181},
	{"GI38", 4, 15182},
	{"GI39", 4, 15183},
	{"GI40", 4, 15184},
	{"GI41", 4, 15185},
	{"GI42", 4, 15186},
	{"GI43", 4, 15187},
	{"GI44", 4, 15188},
	{"GI45", 4, 15189},
	{"GI46", 4, 15190},
	{"GI47", 4, 15191},
	{"GI48", 4, 15192},
	{"GI49", 4, 15193},
	{"GI50", 4, 15194},
	{"GI51", 4, 15195},
	{"GI52", 4, 15196},
	{"GI53", 4, 15197},
	{"GI54", 4, 15198},
	{"GI55", 4, 15199},
	{"GI56", 4, 15200},
	{"GI57", 4, 15201},
	{"GI58", 4, 15202},
	{"GI59", 4, 15203},
	{"GI60", 4, 15204},
	{"GI61", 4, 15205},
	{"GI62", 4, 15206},
	{"GI63", 4, 15207},
	{"GI64", 4, 15208},
	{"GI65", 4, 15209},
	{"GI66", 4, 15210},
	{"GI67", 4, 15211},
	{"GI68", 4, 15212},
	{"GI69", 4, 15213},
	{"GI70", 4, 15214},
	{"GI71", 4, 15215},
	{"GI72", 4, 15216},
	{"GI73", 4, 15217},
	{"GI74", 4, 15218},
	{"GI75", 4, 15219},
	{"GI76", 4, 15220},
	{"GI77", 4, 15221},
	{"GI78", 4, 15222},
	{"GI79", 4, 15223},
	{"GI80", 4, 15224},
	{"GI81", 4, 15225},
	{"GI82", 4, 15226},
	{"GI83", 4, 15227},
	{"GI84", 4, 15228},
	{"GI85", 4, 15229},
	{"GI86", 4, 15230},
	{"GI87", 4, 15231},
	{"GI88", 4, 15232},
	{"GI89", 4, 15233},
	{"GI90", 4, 15234},
	{"GI91", 4, 15235},
	{"GI92", 4, 15236},
	{"GI93", 4, 15237},
	{"GI94", 4, 15238},
	{"GI95", 4, 15239},
	{"GI96", 4, 15240},
	{"GI97", 4, 15241},
	{"GI98", 4, 15242},
	{"GI99", 4, 15243},
	{"GJ00", 4, 15244},
	{"GJ01", 4, 15245},
	{"GJ02", 4, 15246},
	{"GJ03", 4, 15247},
	{"GJ04", 4, 15248},
	{"GJ05", 4, 15249},
	{"GJ06", 4, 15250},
	{"GJ07", 4, 15251},
	{"GJ08", 4, 15252},
	{"GJ09", 4, 15253},
	{"GJ10", 4, 15254},
	{"GJ11", 4, 15255},
	{"GJ12", 4, 15256},
	{"GJ13", 4, 15257},
	{"GJ14", 4, 15258},
	{"GJ15", 4, 15259},
	{"GJ16", 4, 15260},
	{"GJ17", 4, 15261},
	{"GJ18", 4, 15262},
	{"GJ19", 4, 15263},
	{"GJ20", 4, 15264},
	{"GJ21", 4, 15265},
	{"GJ22", 4, 15266},
	{"GJ23", 4, 15267},
	{"GJ24", 4, 15268},
	{"GJ25", 4, 15269},
	{"GJ26", 4, 15270},
	{"GJ27", 4, 15271},
	{"GJ28", 4, 15272},
	{"GJ29", 4, 15273},
	{"GJ30", 4, 15274},
	{"GJ31", 4, 15275},
	{"GJ32", 4, 15276},
	{"GJ33", 4, 15277},
	{"GJ34", 4, 15278},
	{"GJ35", 4, 15279},
	{"GJ36", 4, 15280},
	{"GJ37", 4, 15281},
	{"GJ38", 4, 15282},
	{"GJ39", 4, 15283},
	{"GJ40", 4, 15284},
	{"GJ41", 4, 15285},
	{"GJ42", 4, 15286},
	{"GJ43", 4, 15287},
	{"GJ44", 4, 15288},
	{"GJ45", 4, 15289},
	{"GJ46", 4, 15290},
	{"GJ47", 4, 15291},
	{"GJ48", 4, 15292},
	{"GJ49", 4, 15293},
	{"GJ50", 4, 15294},
	{"GJ51", 4, 15295},
	{"GJ52", 4, 15296},
	{"GJ53", 4, 15297},
	{"GJ54", 4, 15298},
	{"GJ55", 4, 15299},
	{"GJ56", 4, 15300},
	{"GJ57", 4, 15301},
	{"GJ58", 4, 15302},
	{"GJ59", 4, 15303},
	{"GJ60", 4, 15304},
	{"GJ61", 4, 15305},
	{"GJ62", 4, 15306},
	{"GJ63", 4, 15307},
	{"GJ64", 4, 15308},
	{"GJ65", 4, 15309},
	{"GJ66", 4, 15310},
	{"GJ67", 4, 15311},
	{"GJ68", 4, 15312},
	{"GJ69", 4, 15313},
	{"GJ70", 4, 15314},
	{"GJ71", 4, 15315},
	{"GJ72", 4, 15316},
	{"GJ73", 4, 15317},
	{"GJ74", 4, 15318},
	{"GJ75", 4, 15319},
	{"GJ76", 4, 15320},
	{"GJ77", 4, 15321},
	{"GJ78", 4, 15322},
	{"GJ79", 4, 15323},
	{"GJ80", 4, 15324},
	{"GJ81", 4, 15325},
	{"GJ82", 4, 15326},
	{"GJ83", 4, 15327},
	{"GJ84", 4, 15328},
	{"GJ85", 4, 15329},
	{"GJ86", 4, 15330},
	{"GJ87", 4, 15331},
	{"GJ88", 4, 15332},
	{"GJ89", 4, 15333},
	{"GJ90", 4, 15334},
	{"GJ91", 4, 15335},
	{"GJ92", 4, 15336},
	{"GJ93", 4, 15337},
	{"GJ94", 4, 15338},
	{"GJ95", 4, 15339},
	{"GJ96", 4, 15340},
	{"GJ97", 4, 15341},
	{"GJ98", 4, 15342},
	{"GJ99", 4, 15343},
	{"GN00", 4, 15344},
	{"GN01", 4, 15345},
	{"GN02", 4, 15346},
	{"GN03", 4, 15347},
	{"GN04", 4, 15348},
	{"GN05", 4, 15349},
	{"GN06", 4, 15350},
	{"GN07", 4, 15351},
	{"GN08", 4, 15352},
	{"GN09", 4, 15353},
	{"GN10", 4, 15354},
	{"GN11", 4, 15355},
	{"GN12", 4, 15356},
	{"GN13", 4, 15357},
	{"GN14", 4, 15358},
	{"GN15", 4, 15359},
	{"GN16", 4, 15360},
	{"GN17", 4, 15361},
	{"GN18", 4, 15362},
	{"GN19", 4, 15363},
	{"GN20", 4, 15364},
	{"GN21", 4, 15365},
	{"GN22", 4, 15366},
	{"GN23", 4, 15367},
	{"GN24", 4, 15368},
	{"GN25", 4, 15369},
	{"GN26", 4, 15370},
	{"GN27", 4, 15371},
	{"GN28", 4, 15372},
	{"GN29", 4, 15373},
	{"GN30", 4, 15374},
	{"GN31", 4, 15375},
	{"GN32", 4, 15376},
	{"GN33", 4, 15377},
	{"GN34", 4, 15378},
	{"GN35", 4, 15379},
	{"GN36", 4, 15380},
	{"GN37", 4, 15381},
	{"GN38", 4, 15382},
	{"GN39", 4, 15383},
	{"GN40", 4, 15384},
	{"GN41", 4, 15385},
	{"GN42", 4, 15386},
	{"GN43", 4, 15387},
	{"GN44", 4, 15388},
	{"GN45", 4, 15389},
	{"GN46", 4, 15390},
	{"GN47", 4, 15391},
	{"GN48", 4, 15392},
	{"GN49", 4, 15393},
	{"GN50", 4, 15394},
	{"GN51", 4, 15395},
	{"GN52", 4, 15396},
	{"GN53", 4, 15397},
	{"GN54", 4, 15398},
	{"GN55", 4, 15399},
	{"GN56", 4, 15400},
	{"GN57", 4, 15401},
	{"GN58", 4, 15402},
	{"GN59", 4, 15403},
	{"GN60", 4, 15404},
	{"GN61", 4, 15405},
	{"GN62", 4, 15406},
	{"GN63", 4, 15407},
	{"GN64", 4, 15408},
	{"GN65", 4, 15409},
	{"GN66", 4, 15410},
	{"GN67", 4, 15411},
	{"GN68", 4, 15412},
	{"GN69", 4, 15413},
	{"GN70", 4, 15414},
	{"GN71", 4, 15415},
	{"GN72", 4, 15416},
	{"GN73", 4, 15417},
	{"GN74", 4, 15418},
	{"GN75", 4, 15419},
	{"GN76", 4, 15420},
	{"GN77", 4, 15421},
	{"GN78", 4, 15422},
	{"GN79", 4, 15423},
	{"GN80", 4, 15424},
	{"GN81", 4, 15425},
	{"GN82", 4, 15426},
	{"GN83", 4, 15427},
	{"GN84", 4, 15428},
	{"GN85", 4, 15429},
	{"GN86", 4, 15430},
	{"GN87", 4, 15431},
	{"GN88", 4, 15432},
	{"GN89", 4, 15433},
	{"GN90", 4, 15434},
	{"GN91", 4, 15435},
	{"GN92", 4, 15436},
	{"GN93", 4, 15437},
	{"GN94", 4, 15438},
	{"GN95", 4, 15439},
	{"GN96", 4, 15440},
	{"GN97", 4, 15441},
	{"GN98", 4, 15442},
	{"GN99", 4, 15443},
	{"GO00", 4, 15444},
	{"GO01", 4, 15445},
	{"GO02", 4, 15446},
	{"GO03", 4, 15447},
	{"GO04", 4, 15448},
	{"GO05", 4, 15449},
	{"GO06", 4, 15450},
	{"GO07", 4, 15451},
	{"GO08", 4, 15452},
	{"GO09", 4, 15453},
	{"GO10", 4, 15454},
	{"GO11", 4, 15455},
	{"GO12", 4, 15456},
	{"GO13", 4, 15457},
	{"GO14", 4, 15458},
	{"GO15", 4, 15459},
	{"GO16", 4, 15460},
	{"GO17", 4, 15461},
	{"GO18", 4, 15462},
	{"GO19", 4, 15463},
	{"GO20", 4, 15464},
	{"GO21", 4, 15465},
	{"GO22", 4, 15466},
	{"GO23", 4, 15467},
	{"GO24", 4, 15468},
	{"GO25", 4, 15469},
	{"GO26", 4, 15470},
	{"GO27", 4, 15471},
	{"GO28", 4, 15472},
	{"GO29", 4, 15473},
	{"GO30", 4, 15474},
	{"GO31", 4, 15475},
	{"GO32", 4, 15476},
	{"GO33", 4, 15477},
	{"GO34", 4, 15478},
	{"GO35", 4, 15479},
	{"GO36", 4, 15480},
	{"GO37", 4, 15481},
	{"GO38", 4, 15482},
	{"GO39", 4, 15483},
	{"GO40", 4, 15484},
	{"GO41", 4, 15485},
	{"GO42", 4, 15486},
	{"GO43", 4, 15487},
	{"GO44", 4, 15488},
	{"GO45", 4, 15489},
	{"GO46", 4, 15490},
	{"GO47", 4, 15491},
	{"GO48", 4, 15492},
	{"GO49", 4, 15493},
	{"GO50", 4, 15494},
	{"GO51", 4, 15495},
	{"GO52", 4, 15496},
	{"GO53", 4, 15497},
	{"GO54", 4, 15498},
	{"GO55", 4, 15499},
	{"GO56", 4, 15500},
	{"GO57", 4, 15501},
	{"GO58", 4, 15502},
	{"GO59", 4, 15503},
	{"GO60", 4, 15504},
	{"GO61", 4, 15505},
	{"GO62", 4, 15506},
	{"GO63", 4, 15507},
	{"GO64", 4, 15508},
	{"GO65", 4, 15509},
	{"GO66", 4, 15510},
	{"GO67", 4, 15511},
	{"GO68", 4, 15512},
	{"GO69", 4, 15513},
	{"GO70", 4, 15514},
	{"GO71", 4, 15515},
	{"GO72", 4, 15516},
	{"GO73", 4, 15517},
	{"GO74", 4, 15518},
	{"GO75", 4, 15519},
	{"GO76", 4, 15520},
	{"GO77", 4, 15521},
	{"GO78", 4, 15522},
	{"GO79", 4, 15523},
	{"GO80", 4, 15524},
	{"GO81", 4, 15525},
	{"GO82", 4, 15526},
	{"GO83", 4, 15527},
	{"GO84", 4, 15528},
	{"GO85", 4, 15529},
	{"GO86", 4, 15530},
	{"GO87", 4, 15531},
	{"GO88", 4, 15532},
	{"GO89", 4, 15533},
	{"GO90", 4, 15534},
	{"GO91", 4, 15535},
	{"GO92", 4, 15536},
	{"GO93", 4, 15537},
	{"GO94", 4, 15538},
	{"GO95", 4, 15539},
	{"GO96", 4, 15540},
	{"GO97", 4, 15541},
	{"GO98", 4, 15542},
	{"GO99", 4, 15543},
	{"GP00", 4, 15544},
	{"GP01", 4, 15545},
	{"GP02", 4, 15546},
	{"GP03", 4, 15547},
	{"GP04", 4, 15548},
	{"GP05", 4, 15549},
	{"GP06", 4, 15550},
	{"GP07", 4, 15551},
	{"GP08", 4, 15552},
	{"GP09", 4, 15553},
	{"GP10", 4, 15554},
	{"GP11", 4, 15555},
	{"GP12", 4, 15556},
	{"GP13", 4, 15557},
	{"GP14", 4, 15558},
	{"GP15", 4, 15559},
	{"GP16", 4, 15560},
	{"GP17", 4, 15561},
	{"GP18", 4, 15562},
	{"GP19", 4, 15563},
	{"GP20", 4, 15564},
	{"GP21", 4, 15565},
	{"GP22", 4, 15566},
	{"GP23", 4, 15567},
	{"GP24", 4, 15568},
	{"GP25", 4, 15569},
	{"GP26", 4, 15570},
	{"GP27", 4, 15571},
	{"GP28", 4, 15572},
	{"GP29", 4, 15573},
	{"GP30", 4, 15574},
	{"GP31", 4, 15575},
	{"GP32", 4, 15576},
	{"GP33", 4, 15577},
	{"GP34", 4, 15578},
	{"GP35", 4, 15579},
	{"GP36", 4, 15580},
	{"GP37", 4, 15581},
	{"GP38", 4, 15582},
	{"GP39", 4, 15583},
	{"GP40", 4, 15584},
	{"GP41", 4, 15585},
	{"GP42", 4, 15586},
	{"GP43", 4, 15587},
	{"GP44", 4, 15588},
	{"GP45", 4, 15589},
	{"GP46", 4, 15590},
	{"GP47", 4, 15591},
	{"GP48", 4, 15592},
	{"GP49", 4, 15593},
	{"GP50", 4, 15594},
	{"GP51", 4, 15595},
	{"GP52", 4, 15596},
	{"GP53", 4, 15597},
	{"GP54", 4, 15598},
	{"GP55", 4, 15599},
	{"GP56", 4, 15600},
	{"GP57", 4, 15601},
	{"GP58", 4, 15602},
	{"GP59", 4, 15603},
	{"GP60", 4, 15604},
	{"GP61", 4, 15605},
	{"GP62", 4, 15606},
	{"GP63", 4, 15607},
	{"GP64", 4, 15608},
	{"GP65", 4, 15609},
	{"GP66", 4, 15610},
	{"GP67", 4, 15611},
	{"GP68", 4, 15612},
	{"GP69", 4, 15613},
	{"GP70", 4, 15614},
	{"GP71", 4, 15615},
	{"GP72", 4, 15616},
	{"GP73", 4, 15617},
	{"GP74", 4, 15618},
	{"GP75", 4, 15619},
	{"GP76", 4, 15620},
	{"GP77", 4, 15621},
	{"GP78", 4, 15622},
	{"GP79", 4, 15623},
	{"GP80", 4, 15624},
	{"GP81", 4, 15625},
	{"GP82", 4, 15626},
	{"GP83", 4, 15627},
	{"GP84", 4, 15628},
	{"GP85", 4, 15629},
	{"GP86", 4, 15630},
	{"GP87", 4, 15631},
	{"GP88", 4, 15632},
	{"GP89", 4, 15633},
	{"GP90", 4, 15634},
	{"GP91", 4, 15635},
	{"GP92", 4, 15636},
	{"GP93", 4, 15637},
	{"GP94", 4, 15638},
	{"GP95", 4, 15639},
	{"GP96", 4, 15640},
	{"GP97", 4, 15641},
	{"GP98", 4, 15642},
	{"GP99", 4, 15643},
	{"GQ00", 4, 15644},
	{"GQ01", 4, 15645},
	{"GQ02", 4, 15646},
	{"GQ03", 4, 15647},
	{"GQ04", 4, 15648},
	{"GQ05", 4, 15649},
	{"GQ06", 4, 15650},
	{"GQ07", 4, 15651},
	{"GQ08", 4, 15652},
	{"GQ09", 4, 15653},
	{"GQ10", 4, 15654},
	{"GQ11", 4, 15655},
	{"GQ12", 4, 15656},
	{"GQ13", 4, 15657},
	{"GQ14", 4, 15658},
	{"GQ15", 4, 15659},
	{"GQ16", 4, 15660},
	{"GQ17", 4, 15661},
	{"GQ18", 4, 15662},
	{"GQ19", 4, 15663},
	{"GQ20", 4, 15664},
	{"GQ21", 4, 15665},
	{"GQ22", 4, 15666},
	{"GQ23", 4, 15667},
	{"GQ24", 4, 15668},
	{"GQ25", 4, 15669},
	{"GQ26", 4, 15670},
	{"GQ27", 4, 15671},
	{"GQ28", 4, 15672},
	{"GQ29", 4, 15673},
	{"GQ30", 4, 15674},
	{"GQ31", 4, 15675},
	{"GQ32", 4, 15676},
	{"GQ33", 4, 15677},
	{"GQ34", 4, 15678},
	{"GQ35", 4, 15679},
	{"GQ36", 4, 15680},
	{"GQ37", 4, 15681},
	{"GQ38", 4, 15682},
	{"GQ39", 4, 15683},
	{"GQ40", 4, 15684},
	{"GQ41", 4, 15685},
	{"GQ42", 4, 15686},
	{"GQ43", 4, 15687},
	{"GQ44", 4, 15688},
	{"GQ45", 4, 15689},
	{"GQ46", 4, 15690},
	{"GQ47", 4, 15691},
	{"GQ48", 4, 15692},
	{"GQ49", 4, 15693},
	{"GQ50", 4, 15694},
	{"GQ51", 4, 15695},
	{"GQ52", 4, 15696},
	{"GQ53", 4, 15697},
	{"GQ54", 4, 15698},
	{"GQ55", 4, 15699},
	{"GQ56", 4, 15700},
	{"GQ57", 4, 15701},
	{"GQ58", 4, 15702},
	{"GQ59", 4, 15703},
	{"GQ60", 4, 15704},
	{"GQ61", 4, 15705},
	{"GQ62", 4, 15706},
	{"GQ63", 4, 15707},
	{"GQ64", 4, 15708},
	{"GQ65", 4, 15709},
	{"GQ66", 4, 15710},
	{"GQ67", 4, 15711},
	{"GQ68", 4, 15712},
	{"GQ69", 4, 15713},
	{"GQ70", 4, 15714},
	{"GQ71", 4, 15715},
	{"GQ72", 4, 15716},
	{"GQ73", 4, 15717},
	{"GQ74", 4, 15718},
	{"GQ75", 4, 15719},
	{"GQ76", 4, 15720},
	{"GQ77", 4, 15721},
	{"GQ78", 4, 15722},
	{"GQ79", 4, 15723},
	{"GQ80", 4, 15724},
	{"GQ81", 4, 15725},
	{"GQ82", 4, 15726},
	{"GQ83", 4, 15727},
	{"GQ84", 4, 15728},
	{"GQ85", 4, 15729},
	{"GQ86", 4, 15730},
	{"GQ87", 4, 15731},
	{"GQ88", 4, 15732},
	{"GQ89", 4, 15733},
	{"GQ90", 4, 15734},
	{"GQ91", 4, 15735},
	{"GQ92", 4, 15736},
	{"GQ93", 4, 15737},
	{"GQ94", 4, 15738},
	{"GQ95", 4, 15739},
	{"GQ96", 4, 15740},
	{"GQ97", 4, 15741},
	{"GQ98", 4, 15742},
	{"GQ99", 4, 15743},
	{"HB00", 4, 15744},
	{"HB01", 4, 15745},
	{"HB02", 4, 15746},
	{"HB03", 4, 15747},
	{"HB04", 4, 15748},
	{"HB05", 4, 15749},
	{"HB06", 4, 15750},
	{"HB07", 4, 15751},
	{"HB08", 4, 15752},
	{"HB09", 4, 15753},
	{"HB10", 4, 15754},
	{"HB11", 4, 15755},
	{"HB12", 4, 15756},
	{"HB13", 4, 15757},
	{"HB14", 4, 15758},
	{"HB15", 4, 15759},
	{"HB16", 4, 15760},
	{"HB17", 4, 15761},
	{"HB18", 4, 15762},
	{"HB19", 4, 15763},
	{"HB20", 4, 15764},
	{"HB21", 4, 15765},
	{"HB22", 4, 15766},
	{"HB23", 4, 15767},
	{"HB24", 4, 15768},
	{"HB25", 4, 15769},
	{"HB26", 4, 15770},
	{"HB27", 4, 15771},
	{"HB28", 4, 15772},
	{"HB29", 4, 15773},
	{"HB30", 4, 15774},
	{"HB31", 4, 15775},
	{"HB32", 4, 15776},
	{"HB33", 4, 15777},
	{"HB34", 4, 15778},
	{"HB35", 4, 15779},
	{"HB36", 4, 15780},
	{"HB37", 4, 15781},
	{"HB38", 4, 15782},
	{"HB39", 4, 15783},
	{"HB40", 4, 15784},
	{"HB41", 4, 15785},
	{"HB42", 4, 15786},
	{"HB43", 4, 15787},
	{"HB44", 4, 15788},
	{"HB45", 4, 15789},
	{"HB46", 4, 15790},
	{"HB47", 4, 15791},
	{"HB48", 4, 15792},
	{"HB49", 4, 15793},
	{"HB50", 4, 15794},
	{"HB51", 4, 15795},
	{"HB52", 4, 15796},
	{"HB53", 4, 15797},
	{"HB54", 4, 15798},
	{"HB55", 4, 15799},
	{"HB56", 4, 15800},
	{"HB57", 4, 15801},
	{"HB58", 4, 15802},
	{"HB59", 4, 15803},
	{"HB60", 4, 15804},
	{"HB61", 4, 15805},
	{"HB62", 4, 15806},
	{"HB63", 4, 15807},
	{"HB64", 4, 15808},
	{"HB65", 4, 15809},
	{"HB66", 4, 15810},
	{"HB67", 4, 15811},
	{"HB68", 4, 15812},
	{"HB69", 4, 15813},
	{"HB70", 4, 15814},
	{"HB71", 4, 15815},
	{"HB72", 4, 15816},
	{"HB73", 4, 15817},
	{"HB74", 4, 15818},
	{"HB75", 4, 15819},
	{"HB76", 4, 15820},
	{"HB77", 4, 15821},
	{"HB78", 4, 15822},
	{"HB79", 4, 15823},
	{"HB80", 4, 15824},
	{"HB81", 4, 15825},
	{"HB82", 4, 15826},
	{"HB83", 4, 15827},
	{"HB84", 4, 15828},
	{"HB85", 4, 15829},
	{"HB86", 4, 15830},
	{"HB87", 4, 15831},
	{"HB88", 4, 15832},
	{"HB89", 4, 15833},
	{"HB90", 4, 15834},
	{"HB91", 4, 15835},
	{"HB92", 4, 15836},
	{"HB93", 4, 15837},
	{"HB94", 4, 15838},
	{"HB95", 4, 15839},
	{"HB96", 4, 15840},
	{"HB97", 4, 15841},
	{"HB98", 4, 15842},
	{"HB99", 4, 15843},
	{"HD00", 4, 15844},
	{"HD01", 4, 15845},
	{"HD02", 4, 15846},
	{"HD03", 4, 15847},
	{"HD04", 4, 15848},
	{"HD05", 4, 15849},
	{"HD06", 4, 15850},
	{"HD07", 4, 15851},
	{"HD08", 4, 15852},
	{"HD09", 4, 15853},
	{"HD10", 4, 15854},
	{"HD11", 4, 15855},
	{"HD12", 4, 15856},
	{"HD13", 4, 15857},
	{"HD14", 4, 15858},
	{"HD15", 4, 15859},
	{"HD16", 4, 15860},
	{"HD17", 4, 15861},
	{"HD18", 4, 15862},
	{"HD19", 4, 15863},
	{"HD20", 4, 15864},
	{"HD21", 4, 15865},
	{"HD22", 4, 15866},
	{"HD23", 4, 15867},
	{"HD24", 4, 15868},
	{"HD25", 4, 15869},
	{"HD26", 4, 15870},
	{"HD27", 4, 15871},
	{"HD28", 4, 15872},
	{"HD29", 4, 15873},
	{"HD30", 4, 15874},
	{"HD31", 4, 15875},
	{"HD32", 4, 15876},
	{"HD33", 4, 15877},
	{"HD34", 4, 15878},
	{"HD35", 4, 15879},
	{"HD36", 4, 15880},
	{"HD37", 4, 15881},
	{"HD38", 4, 15882},
	{"HD39", 4, 15883},
	{"HD40", 4, 15884},
	{"HD41", 4, 15885},
	{"HD42", 4, 15886},
	{"HD43", 4, 15887},
	{"HD44", 4, 15888},
	{"HD45", 4, 15889},
	{"HD46", 4, 15890},
	{"HD47", 4, 15891},
	{"HD48", 4, 15892},
	{"HD49", 4, 15893},
	{"HD50", 4, 15894},
	{"HD51", 4, 15895},
	{"HD52", 4, 15896},
	{"HD53", 4, 15897},
	{"HD54", 4, 15898},
	{"HD55", 4, 15899},
	{"HD56", 4, 15900},
	{"HD57", 4, 15901},
	{"HD58", 4, 15902},
	{"HD59", 4, 15903},
	{"HD60", 4, 15904},
	{"HD61", 4, 15905},
	{"HD62", 4, 15906},
	{"HD63", 4, 15907},
	{"HD64", 4, 15908},
	{"HD65", 4, 15909},
	{"HD66", 4, 15910},
	{"HD67", 4, 15911},
	{"HD68", 4, 15912},
	{"HD69", 4, 15913},
	{"HD70", 4, 15914},
	{"HD71", 4, 15915},
	{"HD72", 4, 15916},
	{"HD73", 4, 15917},
	{"HD74", 4, 15918},
	{"HD75", 4, 15919},
	{"HD76", 4, 15920},
	{"HD77", 4, 15921},
	{"HD78", 4, 15922},
	{"HD79", 4, 15923},
	{"HD80", 4, 15924},
	{"HD81", 4, 15925},
	{"HD82", 4, 15926},
	{"HD83", 4, 15927},
	{"HD84", 4, 15928},
	{"HD85", 4, 15929},
	{"HD86", 4, 15930},
	{"HD87", 4, 15931},
	{"HD88", 4, 15932},
	{"HD89", 4, 15933},
	{"HD90", 4, 15934},
	{"HD91", 4, 15935},
	{"HD92", 4, 15936},
	{"HD93", 4, 15937},
	{"HD94", 4, 15938},
	{"HD95", 4, 15939},
	{"HD96", 4, 15940},
	{"HD97", 4, 15941},
	{"HD98", 4, 15942},
	{"HD99", 4, 15943},
	{"HH00", 4, 15944},
	{"HH01", 4, 15945},
	{"HH02", 4, 15946},
	{"HH03", 4, 15947},
	{"HH04", 4, 15948},
	{"HH05", 4, 15949},
	{"HH06", 4, 15950},
	{"HH07", 4, 15951},
	{"HH08", 4, 15952},
	{"HH09", 4, 15953},
	{"HH10", 4, 15954},
	{"HH11", 4, 15955},
	{"HH12", 4, 15956},
	{"HH13", 4, 15957},
	{"HH14", 4, 15958},
	{"HH15", 4, 15959},
	{"HH16", 4, 15960},
	{"HH17", 4, 15961},
	{"HH18", 4, 15962},
	{"HH19", 4, 15963},
	{"HH20", 4, 15964},
	{"HH21", 4, 15965},
	{"HH22", 4, 15966},
	{"HH23", 4, 15967},
	{"HH24", 4, 15968},
	{"HH25", 4, 15969},
	{"HH26", 4, 15970},
	{"HH27", 4, 15971},
	{"HH28", 4, 15972},
	{"HH29", 4, 15973},
	{"HH30", 4, 15974},
	{"HH31", 4, 15975},
	{"HH32", 4, 15976},
	{"HH33", 4, 15977},
	{"HH34", 4, 15978},
	{"HH35", 4, 15979},
	{"HH36", 4, 15980},
	{"HH37", 4, 15981},
	{"HH38", 4, 15982},
	{"HH39", 4, 15983},
	{"HH40", 4, 15984},
	{"HH41", 4, 15985},
	{"HH42", 4, 15986},
	{"HH43", 4, 15987},
	{"HH44", 4, 15988},
	{"HH45", 4, 15989},
	{"HH46", 4, 15990},
	{"HH47", 4, 15991},
	{"HH48", 4, 15992},
	{"HH49", 4, 15993},
	{"HH50", 4, 15994},
	{"HH51", 4, 15995},
	{"HH52", 4, 15996},
	{"HH53", 4, 15997},
	{"HH54", 4, 15998},
	{"HH55", 4, 15999},
	{"HH56", 4, 16000},
	{"HH57", 4, 16001},
	{"HH58", 4, 16002},
	{"HH59", 4, 16003},
	{"HH60", 4, 16004},
	{"HH61", 4, 16005},
	{"HH62", 4, 16006},
	{"HH63", 4, 16007},
	{"HH64", 4, 16008},
	{"HH65", 4, 16009},
	{"HH66", 4, 16010},
	{"HH67", 4, 16011},
	{"HH68", 4, 16012},
	{"HH69", 4, 16013},
	{"HH70", 4, 16014},
	{"HH71", 4, 16015},
	{"HH72", 4, 16016},
	{"HH73", 4, 16017},
	{"HH74", 4, 16018},
	{"HH75", 4, 16019},
	{"HH76", 4, 16020},
	{"HH77", 4, 16021},
	{"HH78", 4, 16022},
	{"HH79", 4, 16023},
	{"HH80", 4, 16024},
	{"HH81", 4, 16025},
	{"HH82", 4, 16026},
	{"HH83", 4, 16027},
	{"HH84", 4, 16028},
	{"HH85", 4, 16029},
	{"HH86", 4, 16030},
	{"HH87", 4, 16031},
	{"HH88", 4, 16032},
	{"HH89", 4, 16033},
	{"HH90", 4, 16034},
	{"HH91", 4, 16035},
	{"HH92", 4, 16036},
	{"HH93", 4, 16037},
	{"HH94", 4, 16038},
	{"HH95", 4, 16039},
	{"HH96", 4, 16040},
	{"HH97", 4, 16041},
	{"HH98", 4, 16042},
	{"HH99", 4, 16043},
	{"HI00", 4, 16044},
	{"HI01", 4, 16045},
	{"HI02", 4, 16046},
	{"HI03", 4, 16047},
	{"HI04", 4, 16048},
	{"HI05", 4, 16049},
	{"HI06", 4, 16050},
	{"HI07", 4, 16051},
	{"HI08", 4, 16052},
	{"HI09", 4, 16053},
	{"HI10", 4, 16054},
	{"HI11", 4, 16055},
	{"HI12", 4, 16056},
	{"HI13", 4, 16057},
	{"HI14", 4, 16058},
	{"HI15", 4, 16059},
	{"HI16", 4, 16060},
	{"HI17", 4, 16061},
	{"HI18", 4, 16062},
	{"HI19", 4, 16063},
	{"HI20", 4, 16064},
	{"HI21", 4, 16065},
	{"HI22", 4, 16066},
	{"HI23", 4, 16067},
	{"HI24", 4, 16068},
	{"HI25", 4, 16069},
	{"HI26", 4, 16070},
	{"HI27", 4, 16071},
	{"HI28", 4, 16072},
	{"HI29", 4, 16073},
	{"HI30", 4, 16074},
	{"HI31", 4, 16075},
	{"HI32", 4, 16076},
	{"HI33", 4, 16077},
	{"HI34", 4, 16078},
	{"HI35", 4, 16079},
	{"HI36", 4, 16080},
	{"HI37", 4, 16081},
	{"HI38", 4, 16082},
	{"HI39", 4, 16083},
	{"HI40", 4, 16084},
	{"HI41", 4, 16085},
	{"HI42", 4, 16086},
	{"HI43", 4, 16087},
	{"HI44", 4, 16088},
	{"HI45", 4, 16089},
	{"HI46", 4, 16090},
	{"HI47", 4, 16091},
	{"HI48", 4, 16092},
	{"HI49", 4, 16093},
	{"HI50", 4, 16094},
	{"HI51", 4, 16095},
	{"HI52", 4, 16096},
	{"HI53", 4, 16097},
	{"HI54", 4, 16098},
	{"HI55", 4, 16099},
	{"HI56", 4, 16100},
	{"HI57", 4, 16101},
	{"HI58", 4, 16102},
	{"HI59", 4, 16103},
	{"HI60", 4, 16104},
	{"HI61", 4, 16105},
	{"HI62", 4, 16106},
	{"HI63", 4, 16107},
	{"HI64", 4, 16108},
	{"HI65", 4, 16109},
	{"HI66", 4, 16110},
	{"HI67", 4, 16111},
	{"HI68", 4, 16112},
	{"HI69", 4, 16113},
	{"HI70", 4, 16114},
	{"HI71", 4, 16115},
	{"HI72", 4, 16116},
	{"HI73", 4, 16117},
	{"HI74", 4, 16118},
	{"HI75", 4, 16119},
	{"HI76", 4, 16120},
	{"HI77", 4, 16121},
	{"HI78", 4, 16122},
	{"HI79", 4, 16123},
	{"HI80", 4, 16124},
	{"HI81", 4, 16125},
	{"HI82", 4, 16126},
	{"HI83", 4, 16127},
	{"HI84", 4, 16128},
	{"HI85", 4, 16129},
	{"HI86", 4, 16130},
	{"HI87", 4, 16131},
	{"HI88", 4, 16132},
	{"HI89", 4, 16133},
	{"HI90", 4, 16134},
	{"HI91", 4, 16135},
	{"HI92", 4, 16136},
	{"HI93", 4, 16137},
	{"HI94", 4, 16138},
	{"HI95", 4, 16139},
	{"HI96", 4, 16140},
	{"HI97", 4, 16141},
	{"HI98", 4, 16142},
	{"HI99", 4, 16143},
	{"HP00", 4, 16144},
	{"HP01", 4, 16145},
	{"HP02", 4, 16146},
	{"HP03", 4, 16147},
	{"HP04", 4, 16148},
	{"HP05", 4, 16149},
	{"HP06", 4, 16150},
	{"HP07", 4, 16151},
	{"HP08", 4, 16152},
	{"HP09", 4, 16153},
	{"HP10", 4, 16154},
	{"HP11", 4, 16155},
	{"HP12", 4, 16156},
	{"HP13", 4, 16157},
	{"HP14", 4, 16158},
	{"HP15", 4, 16159},
	{"HP16", 4, 16160},
	{"HP17", 4, 16161},
	{"HP18", 4, 16162},
	{"HP19", 4, 16163},
	{"HP20", 4, 16164},
	{"HP21", 4, 16165},
	{"HP22", 4, 16166},
	{"HP23", 4, 16167},
	{"HP24", 4, 16168},
	{"HP25", 4, 16169},
	{"HP26", 4, 16170},
	{"HP27", 4, 16171},
	{"HP28", 4, 16172},
	{"HP29", 4, 16173},
	{"HP30", 4, 16174},
	{"HP31", 4, 16175},
	{"HP32", 4, 16176},
	{"HP33", 4, 16177},
	{"HP34", 4, 16178},
	{"HP35", 4, 16179},
	{"HP36", 4, 16180},
	{"HP37", 4, 16181},
	{"HP38", 4, 16182},
	{"HP39", 4, 16183},
	{"HP40", 4, 16184},
	{"HP41", 4, 16185},
	{"HP42", 4, 16186},
	{"HP43", 4, 16187},
	{"HP44", 4, 16188},
	{"HP45", 4, 16189},
	{"HP46", 4, 16190},
	{"HP47", 4, 16191},
	{"HP48", 4, 16192},
	{"HP49", 4, 16193},
	{"HP50", 4, 16194},
	{"HP51", 4, 16195},
	{"HP52", 4, 16196},
	{"HP53", 4, 16197},
	{"HP54", 4, 16198},
	{"HP55", 4, 16199},
	{"HP56", 4, 16200},
	{"HP57", 4, 16201},
	{"HP58", 4, 16202},
	{"HP59", 4, 16203},
	{"HP60", 4, 16204},
	{"HP61", 4, 16205},
	{"HP62", 4, 16206},
	{"HP63", 4, 16207},
	{"HP64", 4, 16208},
	{"HP65", 4, 16209},
	{"HP66", 4, 16210},
	{"HP67", 4, 16211},
	{"HP68", 4, 16212},
	{"HP69", 4, 16213},
	{"HP70", 4, 16214},
	{"HP71", 4, 16215},
	{"HP72", 4, 16216},
	{"HP73", 4, 16217},
	{"HP74", 4, 16218},
	{"HP75", 4, 16219},
	{"HP76", 4, 16220},
	{"HP77", 4, 16221},
	{"HP78", 4, 16222},
	{"HP79", 4, 16223},
	{"HP80", 4, 16224},
	{"HP81", 4, 16225},
	{"HP82", 4, 16226},
	{"HP83", 4, 16227},
	{"HP84", 4, 16228},
	{"HP85", 4, 16229},
	{"HP86", 4, 16230},
	{"HP87", 4, 16231},
	{"HP88", 4, 16232},
	{"HP89", 4, 16233},
	{"HP90", 4, 16234},
	{"HP91", 4, 16235},
	{"HP92", 4, 16236},
	{"HP93", 4, 16237},
	{"HP94", 4, 16238},
	{"HP95", 4, 16239},
	{"HP96", 4, 16240},
	{"HP97", 4, 16241},
	{"HP98", 4, 16242},
	{"HP99", 4, 16243},
	{"HQ00", 4, 16244},
	{"HQ01", 4, 16245},
	{"HQ02", 4, 16246},
	{"HQ03", 4, 16247},
	{"HQ04", 4, 16248},
	{"HQ05", 4, 16249},
	{"HQ06", 4, 16250},
	{"HQ07", 4, 16251},
	{"HQ08", 4, 16252},
	{"HQ09", 4, 16253},
	{"HQ10", 4, 16254},
	{"HQ11", 4, 16255},
	{"HQ12", 4, 16256},
	{"HQ13", 4, 16257},
	{"HQ14", 4, 16258},
	{"HQ15", 4, 16259},
	{"HQ16", 4, 16260},
	{"HQ17", 4, 16261},
	{"HQ18", 4, 16262},
	{"HQ19", 4, 16263},
	{"HQ20", 4, 16264},
	{"HQ21", 4, 16265},
	{"HQ22", 4, 16266},
	{"HQ23", 4, 16267},
	{"HQ24", 4, 16268},
	{"HQ25", 4, 16269},
	{"HQ26", 4, 16270},
	{"HQ27", 4, 16271},
	{"HQ28", 4, 16272},
	{"HQ29", 4, 16273},
	{"HQ30", 4, 16274},
	{"HQ31", 4, 16275},
	{"HQ32", 4, 16276},
	{"HQ33", 4, 16277},
	{"HQ34", 4, 16278},
	{"HQ35", 4, 16279},
	{"HQ36", 4, 16280},
	{"HQ37", 4, 16281},
	{"HQ38", 4, 16282},
	{"HQ39", 4, 16283},
	{"HQ40", 4, 16284},
	{"HQ41", 4, 16285},
	{"HQ42", 4, 16286},
	{"HQ43", 4, 16287},
	{"HQ44", 4, 16288},
	{"HQ45", 4, 16289},
	{"HQ46", 4, 16290},
	{"HQ47", 4, 16291},
	{"HQ48", 4, 16292},
	{"HQ49", 4, 16293},
	{"HQ50", 4, 16294},
	{"HQ51", 4, 16295},
	{"HQ52", 4, 16296},
	{"HQ53", 4, 16297},
	{"HQ54", 4, 16298},
	{"HQ55", 4, 16299},
	{"HQ56", 4, 16300},
	{"HQ57", 4, 16301},
	{"HQ58", 4, 16302},
	{"HQ59", 4, 16303},
	{"HQ60", 4, 16304},
	{"HQ61", 4, 16305},
	{"HQ62", 4, 16306},
	{"HQ63", 4, 16307},
	{"HQ64", 4, 16308},
	{"HQ65", 4, 16309},
	{"HQ66", 4, 16310},
	{"HQ67", 4, 16311},
	{"HQ68", 4, 16312},
	{"HQ69", 4, 16313},
	{"HQ70", 4, 16314},
	{"HQ71", 4, 16315},
	{"HQ72", 4, 16316},
	{"HQ73", 4, 16317},
	{"HQ74", 4, 16318},
	{"HQ75", 4, 16319},
	{"HQ76", 4, 16320},
	{"HQ77", 4, 16321},
	{"HQ78", 4, 16322},
	{"HQ79", 4, 16323},
	{"HQ80", 4, 16324},
	{"HQ81", 4, 16325},
	{"HQ82", 4, 16326},
	{"HQ83", 4, 16327},
	{"HQ84", 4, 16328},
	{"HQ85", 4, 16329},
	{"HQ86", 4, 16330},
	{"HQ87", 4, 16331},
	{"HQ88", 4, 16332},
	{"HQ89", 4, 16333},
	{"HQ90", 4, 16334},
	{"HQ91", 4, 16335},
	{"HQ92", 4, 16336},
	{"HQ93", 4, 16337},
	{"HQ94", 4, 16338},
	{"HQ95", 4, 16339},
	{"HQ96", 4, 16340},
	{"HQ97", 4, 16341},
	{"HQ98", 4, 16342},
	{"HQ99", 4, 16343},
	{"IB00", 4, 16344},
	{"IB01", 4, 16345},
	{"IB02", 4, 16346},
	{"IB03", 4, 16347},
	{"IB04", 4, 16348},
	{"IB05", 4, 16349},
	{"IB06", 4, 16350},
	{"IB07", 4, 16351},
	{"IB08", 4, 16352},
	{"IB09", 4, 16353},
	{"IB10", 4, 16354},
	{"IB11", 4, 16355},
	{"IB12", 4, 16356},
	{"IB13", 4, 16357},
	{"IB14", 4, 16358},
	{"IB15", 4, 16359},
	{"IB16", 4, 16360},
	{"IB17", 4, 16361},
	{"IB18", 4, 16362},
	{"IB19", 4, 16363},
	{"IB20", 4, 16364},
	{"IB21", 4, 16365},
	{"IB22", 4, 16366},
	{"IB23", 4, 16367},
	{"IB24", 4, 16368},
	{"IB25", 4, 16369},
	{"IB26", 4, 16370},
	{"IB27", 4, 16371},
	{"IB28", 4, 16372},
	{"IB29", 4, 16373},
	{"IB30", 4, 16374},
	{"IB31", 4, 16375},
	{"IB32", 4, 16376},
	{"IB33", 4, 16377},
	{"IB34", 4, 16378},
	{"IB35", 4, 16379},
	{"IB36", 4, 16380},
	{"IB37", 4, 16381},
	{"IB38", 4, 16382},
	{"IB39", 4, 16383},
	{"IB40", 4, 16384},
	{"IB41", 4, 16385},
	{"IB42", 4, 16386},
	{"IB43", 4, 16387},
	{"IB44", 4, 16388},
	{"IB45", 4, 16389},
	{"IB46", 4, 16390},
	{"IB47", 4, 16391},
	{"IB48", 4, 16392},
	{"IB49", 4, 16393},
	{"IB50", 4, 16394},
	{"IB51", 4, 16395},
	{"IB52", 4, 16396},
	{"IB53", 4, 16397},
	{"IB54", 4, 16398},
	{"IB55", 4, 16399},
	{"IB56", 4, 16400},
	{"IB57", 4, 16401},
	{"IB58", 4, 16402},
	{"IB59", 4, 16403},
	{"IB60", 4, 16404},
	{"IB61", 4, 16405},
	{"IB62", 4, 16406},
	{"IB63", 4, 16407},
	{"IB64", 4, 16408},
	{"IB65", 4, 16409},
	{"IB66", 4, 16410},
	{"IB67", 4, 16411},
	{"IB68", 4, 16412},
	{"IB69", 4, 16413},
	{"IB70", 4, 16414},
	{"IB71", 4, 16415},
	{"IB72", 4, 16416},
	{"IB73", 4, 16417},
	{"IB74", 4, 16418},
	{"IB75", 4, 16419},
	{"IB76", 4, 16420},
	{"IB77", 4, 16421},
	{"IB78", 4, 16422},
	{"IB79", 4, 16423},
	{"IB80", 4, 16424},
	{"IB81", 4, 16425},
	{"IB82", 4, 16426},
	{"IB83", 4, 16427},
	{"IB84", 4, 16428},
	{"IB85", 4, 16429},
	{"IB86", 4, 16430},
	{"IB87", 4, 16431},
	{"IB88", 4, 16432},
	{"IB89", 4, 16433},
	{"IB90", 4, 16434},
	{"IB91", 4, 16435},
	{"IB92", 4, 16436},
	{"IB93", 4, 16437},
	{"IB94", 4, 16438},
	{"IB95", 4, 16439},
	{"IB96", 4, 16440},
	{"IB97", 4, 16441},
	{"IB98", 4, 16442},
	{"IB99", 4, 16443},
	{"IJ00", 4, 16444},
	{"IJ01", 4, 16445},
	{"IJ02", 4, 16446},
	{"IJ03", 4, 16447},
	{"IJ04", 4, 16448},
	{"IJ05", 4, 16449},
	{"IJ06", 4, 16450},
	{"IJ07", 4, 16451},
	{"IJ08", 4, 16452},
	{"IJ09", 4, 16453},
	{"IJ10", 4, 16454},
	{"IJ11", 4, 16455},
	{"IJ12", 4, 16456},
	{"IJ13", 4, 16457},
	{"IJ14", 4, 16458},
	{"IJ15", 4, 16459},
	{"IJ16", 4, 16460},
	{"IJ17", 4, 16461},
	{"IJ18", 4, 16462},
	{"IJ19", 4, 16463},
	{"IJ20", 4, 16464},
	{"IJ21", 4, 16465},
	{"IJ22", 4, 16466},
	{"IJ23", 4, 16467},
	{"IJ24", 4, 16468},
	{"IJ25", 4, 16469},
	{"IJ26", 4, 16470},
	{"IJ27", 4, 16471},
	{"IJ28", 4, 16472},
	{"IJ29", 4, 16473},
	{"IJ30", 4, 16474},
	{"IJ31", 4, 16475},
	{"IJ32", 4, 16476},
	{"IJ33", 4, 16477},
	{"IJ34", 4, 16478},
	{"IJ35", 4, 16479},
	{"IJ36", 4, 16480},
	{"IJ37", 4, 16481},
	{"IJ38", 4, 16482},
	{"IJ39", 4, 16483},
	{"IJ40", 4, 16484},
	{"IJ41", 4, 16485},
	{"IJ42", 4, 16486},
	{"IJ43", 4, 16487},
	{"IJ44", 4, 16488},
	{"IJ45", 4, 16489},
	{"IJ46", 4, 16490},
	{"IJ47", 4, 16491},
	{"IJ48", 4, 16492},
	{"IJ49", 4, 16493},
	{"IJ50", 4, 16494},
	{"IJ51", 4, 16495},
	{"IJ52", 4, 16496},
	{"IJ53", 4, 16497},
	{"IJ54", 4, 16498},
	{"IJ55", 4, 16499},
	{"IJ56", 4, 16500},
	{"IJ57", 4, 16501},
	{"IJ58", 4, 16502},
	{"IJ59", 4, 16503},
	{"IJ60", 4, 16504},
	{"IJ61", 4, 16505},
	{"IJ62", 4, 16506},
	{"IJ63", 4, 16507},
	{"IJ64", 4, 16508},
	{"IJ65", 4, 16509},
	{"IJ66", 4, 16510},
	{"IJ67", 4, 16511},
	{"IJ68", 4, 16512},
	{"IJ69", 4, 16513},
	{"IJ70", 4, 16514},
	{"IJ71", 4, 16515},
	{"IJ72", 4, 16516},
	{"IJ73", 4, 16517},
	{"IJ74", 4, 16518},
	{"IJ75", 4, 16519},
	{"IJ76", 4, 16520},
	{"IJ77", 4, 16521},
	{"IJ78", 4, 16522},
	{"IJ79", 4, 16523},
	{"IJ80", 4, 16524},
	{"IJ81", 4, 16525},
	{"IJ82", 4, 16526},
	{"IJ83", 4, 16527},
	{"IJ84", 4, 16528},
	{"IJ85", 4, 16529},
	{"IJ86", 4, 16530},
	{"IJ87", 4, 16531},
	{"IJ88", 4, 16532},
	{"IJ89", 4, 16533},
	{"IJ90", 4, 16534},
	{"IJ91", 4, 16535},
	{"IJ92", 4, 16536},
	{"IJ93", 4, 16537},
	{"IJ94", 4, 16538},
	{"IJ95", 4, 16539},
	{"IJ96", 4, 16540},
	{"IJ97", 4, 16541},
	{"IJ98", 4, 16542},
	{"IJ99", 4, 16543},
	{"IK00", 4, 16544},
	{"IK01", 4, 16545},
	{"IK02", 4, 16546},
	{"IK03", 4, 16547},
	{"IK04", 4, 16548},
	{"IK05", 4, 16549},
	{"IK06", 4, 16550},
	{"IK07", 4, 16551},
	{"IK08", 4, 16552},
	{"IK09", 4, 16553},
	{"IK10", 4, 16554},
	{"IK11", 4, 16555},
	{"IK12", 4, 16556},
	{"IK13", 4, 16557},
	{"IK14", 4, 16558},
	{"IK15", 4, 16559},
	{"IK16", 4, 16560},
	{"IK17", 4, 16561},
	{"IK18", 4, 16562},
	{"IK19", 4, 16563},
	{"IK20", 4, 16564},
	{"IK21", 4, 16565},
	{"IK22", 4, 16566},
	{"IK23", 4, 16567},
	{"IK24", 4, 16568},
	{"IK25", 4, 16569},
	{"IK26", 4, 16570},
	{"IK27", 4, 16571},
	{"IK28", 4, 16572},
	{"IK29", 4, 16573},
	{"IK30", 4, 16574},
	{"IK31", 4, 16575},
	{"IK32", 4, 16576},
	{"IK33", 4, 16577},
	{"IK34", 4, 16578},
	{"IK35", 4, 16579},
	{"IK36", 4, 16580},
	{"IK37", 4, 16581},
	{"IK38", 4, 16582},
	{"IK39", 4, 16583},
	{"IK40", 4, 16584},
	{"IK41", 4, 16585},
	{"IK42", 4, 16586},
	{"IK43", 4, 16587},
	{"IK44", 4, 16588},
	{"IK45", 4, 16589},
	{"IK46", 4, 16590},
	{"IK47", 4, 16591},
	{"IK48", 4, 16592},
	{"IK49", 4, 16593},
	{"IK50", 4, 16594},
	{"IK51", 4, 16595},
	{"IK52", 4, 16596},
	{"IK53", 4, 16597},
	{"IK54", 4, 16598},
	{"IK55", 4, 16599},
	{"IK56", 4, 16600},
	{"IK57", 4, 16601},
	{"IK58", 4, 16602},
	{"IK59", 4, 16603},
	{"IK60", 4, 16604},
	{"IK61", 4, 16605},
	{"IK62", 4, 16606},
	{"IK63", 4, 16607},
	{"IK64", 4, 16608},
	{"IK65", 4, 16609},
	{"IK66", 4, 16610},
	{"IK67", 4, 16611},
	{"IK68", 4, 16612},
	{"IK69", 4, 16613},
	{"IK70", 4, 16614},
	{"IK71", 4, 16615},
	{"IK72", 4, 16616},
	{"IK73", 4, 16617},
	{"IK74", 4, 16618},
	{"IK75", 4, 16619},
	{"IK76", 4, 16620},
	{"IK77", 4, 16621},
	{"IK78", 4, 16622},
	{"IK79", 4, 16623},
	{"IK80", 4, 16624},
	{"IK81", 4, 16625},
	{"IK82", 4, 16626},
	{"IK83", 4, 16627},
	{"IK84", 4, 16628},
	{"IK85", 4, 16629},
	{"IK86", 4, 16630},
	{"IK87", 4, 16631},
	{"IK88", 4, 16632},
	{"IK89", 4, 16633},
	{"IK90", 4, 16634},
	{"IK91", 4, 16635},
	{"IK92", 4, 16636},
	{"IK93", 4, 16637},
	{"IK94", 4, 16638},
	{"IK95", 4, 16639},
	{"IK96", 4, 16640},
	{"IK97", 4, 16641},
	{"IK98", 4, 16642},
	{"IK99", 4, 16643},
	{"IL00", 4, 16644},
	{"IL01", 4, 16645},
	{"IL02", 4, 16646},
	{"IL03", 4, 16647},
	{"IL04", 4, 16648},
	{"IL05", 4, 16649},
	{"IL06", 4, 16650},
	{"IL07", 4, 16651},
	{"IL08", 4, 16652},
	{"IL09", 4, 16653},
	{"IL10", 4, 16654},
	{"IL11", 4, 16655},
	{"IL12", 4, 16656},
	{"IL13", 4, 16657},
	{"IL14", 4, 16658},
	{"IL15", 4, 16659},
	{"IL16", 4, 16660},
	{"IL17", 4, 16661},
	{"IL18", 4, 16662},
	{"IL19", 4, 16663},
	{"IL20", 4, 16664},
	{"IL21", 4, 16665},
	{"IL22", 4, 16666},
	{"IL23", 4, 16667},
	{"IL24", 4, 16668},
	{"IL25", 4, 16669},
	{"IL26", 4, 16670},
	{"IL27", 4, 16671},
	{"IL28", 4, 16672},
	{"IL29", 4, 16673},
	{"IL30", 4, 16674},
	{"IL31", 4, 16675},
	{"IL32", 4, 16676},
	{"IL33", 4, 16677},
	{"IL34", 4, 16678},
	{"IL35", 4, 16679},
	{"IL36", 4, 16680},
	{"IL37", 4, 16681},
	{"IL38", 4, 16682},
	{"IL39", 4, 16683},
	{"IL40", 4, 16684},
	{"IL41", 4, 16685},
	{"IL42", 4, 16686},
	{"IL43", 4, 16687},
	{"IL44", 4, 16688},
	{"IL45", 4, 16689},
	{"IL46", 4, 16690},
	{"IL47", 4, 16691},
	{"IL48", 4, 16692},
	{"IL49", 4, 16693},
	{"IL50", 4, 16694},
	{"IL51", 4, 16695},
	{"IL52", 4, 16696},
	{"IL53", 4, 16697},
	{"IL54", 4, 16698},
	{"IL55", 4, 16699},
	{"IL56", 4, 16700},
	{"IL57", 4, 16701},
	{"IL58", 4, 16702},
	{"IL59", 4, 16703},
	{"IL60", 4, 16704},
	{"IL61", 4, 16705},
	{"IL62", 4, 16706},
	{"IL63", 4, 16707},
	{"IL64", 4, 16708},
	{"IL65", 4, 16709},
	{"IL66", 4, 16710},
	{"IL67", 4, 16711},
	{"IL68", 4, 16712},
	{"IL69", 4, 16713},
	{"IL70", 4, 16714},
	{"IL71", 4, 16715},
	{"IL72", 4, 16716},
	{"IL73", 4, 16717},
	{"IL74", 4, 16718},
	{"IL75", 4, 16719},
	{"IL76", 4, 16720},
	{"IL77", 4, 16721},
	{"IL78", 4, 16722},
	{"IL79", 4, 16723},
	{"IL80", 4, 16724},
	{"IL81", 4, 16725},
	{"IL82", 4, 16726},
	{"IL83", 4, 16727},
	{"IL84", 4, 16728},
	{"IL85", 4, 16729},
	{"IL86", 4, 16730},
	{"IL87", 4, 16731},
	{"IL88", 4, 16732},
	{"IL89", 4, 16733},
	{"IL90", 4, 16734},
	{"IL91", 4, 16735},
	{"IL92", 4, 16736},
	{"IL93", 4, 16737},
	{"IL94", 4, 16738},
	{"IL95", 4, 16739},
	{"IL96", 4, 16740},
	{"IL97", 4, 16741},
	{"IL98", 4, 16742},
	{"IL99", 4, 16743},
	{"IM00", 4, 16744},
	{"IM01", 4, 16745},
	{"IM02", 4, 16746},
	{"IM03", 4, 16747},
	{"IM04", 4, 16748},
	{"IM05", 4, 16749},
	{"IM06", 4, 16750},
	{"IM07", 4, 16751},
	{"IM08", 4, 16752},
	{"IM09", 4, 16753},
	{"IM10", 4, 16754},
	{"IM11", 4, 16755},
	{"IM12", 4, 16756},
	{"IM13", 4, 16757},
	{"IM14", 4, 16758},
	{"IM15", 4, 16759},
	{"IM16", 4, 16760},
	{"IM17", 4, 16761},
	{"IM18", 4, 16762},
	{"IM19", 4, 16763},
	{"IM20", 4, 16764},
	{"IM21", 4, 16765},
	{"IM22", 4, 16766},
	{"IM23", 4, 16767},
	{"IM24", 4, 16768},
	{"IM25", 4, 16769},
	{"IM26", 4, 16770},
	{"IM27", 4, 16771},
	{"IM28", 4, 16772},
	{"IM29", 4, 16773},
	{"IM30", 4, 16774},
	{"IM31", 4, 16775},
	{"IM32", 4, 16776},
	{"IM33", 4, 16777},
	{"IM34", 4, 16778},
	{"IM35", 4, 16779},
	{"IM36", 4, 16780},
	{"IM37", 4, 16781},
	{"IM38", 4, 16782},
	{"IM39", 4, 16783},
	{"IM40", 4, 16784},
	{"IM41", 4, 16785},
	{"IM42", 4, 16786},
	{"IM43", 4, 16787},
	{"IM44", 4, 16788},
	{"IM45", 4, 16789},
	{"IM46", 4, 16790},
	{"IM47", 4, 16791},
	{"IM48", 4, 16792},
	{"IM49", 4, 16793},
	{"IM50", 4, 16794},
	{"IM51", 4, 16795},
	{"IM52", 4, 16796},
	{"IM53", 4, 16797},
	{"IM54", 4, 16798},
	{"IM55", 4, 16799},
	{"IM56", 4, 16800},
	{"IM57", 4, 16801},
	{"IM58", 4, 16802},
	{"IM59", 4, 16803},
	{"IM60", 4, 16804},
	{"IM61", 4, 16805},
	{"IM62", 4, 16806},
	{"IM63", 4, 16807},
	{"IM64", 4, 16808},
	{"IM65", 4, 16809},
	{"IM66", 4, 16810},
	{"IM67", 4, 16811},
	{"IM68", 4, 16812},
	{"IM69", 4, 16813},
	{"IM70", 4, 16814},
	{"IM71", 4, 16815},
	{"IM72", 4, 16816},
	{"IM73", 4, 16817},
	{"IM74", 4, 16818},
	{"IM75", 4, 16819},
	{"IM76", 4, 16820},
	{"IM77", 4, 16821},
	{"IM78", 4, 16822},
	{"IM79", 4, 16823},
	{"IM80", 4, 16824},
	{"IM81", 4, 16825},
	{"IM82", 4, 16826},
	{"IM83", 4, 16827},
	{"IM84", 4, 16828},
	{"IM85", 4, 16829},
	{"IM86", 4, 16830},
	{"IM87", 4, 16831},
	{"IM88", 4, 16832},
	{"IM89", 4, 16833},
	{"IM90", 4, 16834},
	{"IM91", 4, 16835},
	{"IM92", 4, 16836},
	{"IM93", 4, 16837},
	{"IM94", 4, 16838},
	{"IM95", 4, 16839},
	{"IM96", 4, 16840},
	{"IM97", 4, 16841},
	{"IM98", 4, 16842},
	{"IM99", 4, 16843},
	{"IN00", 4, 16844},
	{"IN01", 4, 16845},
	{"IN02", 4, 16846},
	{"IN03", 4, 16847},
	{"IN04", 4, 16848},
	{"IN05", 4, 16849},
	{"IN06", 4, 16850},
	{"IN07", 4, 16851},
	{"IN08", 4, 16852},
	{"IN09", 4, 16853},
	{"IN10", 4, 16854},
	{"IN11", 4, 16855},
	{"IN12", 4, 16856},
	{"IN13", 4, 16857},
	{"IN14", 4, 16858},
	{"IN15", 4, 16859},
	{"IN16", 4, 16860},
	{"IN17", 4, 16861},
	{"IN18", 4, 16862},
	{"IN19", 4, 16863},
	{"IN20", 4, 16864},
	{"IN21", 4, 16865},
	{"IN22", 4, 16866},
	{"IN23", 4, 16867},
	{"IN24", 4, 16868},
	{"IN25", 4, 16869},
	{"IN26", 4, 16870},
	{"IN27", 4, 16871},
	{"IN28", 4, 16872},
	{"IN29", 4, 16873},
	{"IN30", 4, 16874},
	{"IN31", 4, 16875},
	{"IN32", 4, 16876},
	{"IN33", 4, 16877},
	{"IN34", 4, 16878},
	{"IN35", 4, 16879},
	{"IN36", 4, 16880},
	{"IN37", 4, 16881},
	{"IN38", 4, 16882},
	{"IN39", 4, 16883},
	{"IN40", 4, 16884},
	{"IN41", 4, 16885},
	{"IN42", 4, 16886},
	{"IN43", 4, 16887},
	{"IN44", 4, 16888},
	{"IN45", 4, 16889},
	{"IN46", 4, 16890},
	{"IN47", 4, 16891},
	{"IN48", 4, 16892},
	{"IN49", 4, 16893},
	{"IN50", 4, 16894},
	{"IN51", 4, 16895},
	{"IN52", 4, 16896},
	{"IN53", 4, 16897},
	{"IN54", 4, 16898},
	{"IN55", 4, 16899},
	{"IN56", 4, 16900},
	{"IN57", 4, 16901},
	{"IN58", 4, 16902},
	{"IN59", 4, 16903},
	{"IN60", 4, 16904},
	{"IN61", 4, 16905},
	{"IN62", 4, 16906},
	{"IN63", 4, 16907},
	{"IN64", 4, 16908},
	{"IN65", 4, 16909},
	{"IN66", 4, 16910},
	{"IN67", 4, 16911},
	{"IN68", 4, 16912},
	{"IN69", 4, 16913},
	{"IN70", 4, 16914},
	{"IN71", 4, 16915},
	{"IN72", 4, 16916},
	{"IN73", 4, 16917},
	{"IN74", 4, 16918},
	{"IN75", 4, 16919},
	{"IN76", 4, 16920},
	{"IN77", 4, 16921},
	{"IN78", 4, 16922},
	{"IN79", 4, 16923},
	{"IN80", 4, 16924},
	{"IN81", 4, 16925},
	{"IN82", 4, 16926},
	{"IN83", 4, 16927},
	{"IN84", 4, 16928},
	{"IN85", 4, 16929},
	{"IN86", 4, 16930},
	{"IN87", 4, 16931},
	{"IN88", 4, 16932},
	{"IN89", 4, 16933},
	{"IN90", 4, 16934},
	{"IN91", 4, 16935},
	{"IN92", 4, 16936},
	{"IN93", 4, 16937},
	{"IN94", 4, 16938},
	{"IN95", 4, 16939},
	{"IN96", 4, 16940},
	{"IN97", 4, 16941},
	{"IN98", 4, 16942},
	{"IN99", 4, 16943},
	{"IO00", 4, 16944},
	{"IO01", 4, 16945},
	{"IO02", 4, 16946},
	{"IO03", 4, 16947},
	{"IO04", 4, 16948},
	{"IO05", 4, 16949},
	{"IO06", 4, 16950},
	{"IO07", 4, 16951},
	{"IO08", 4, 16952},
	{"IO09", 4, 16953},
	{"IO10", 4, 16954},
	{"IO11", 4, 16955},
	{"IO12", 4, 16956},
	{"IO13", 4, 16957},
	{"IO14", 4, 16958},
	{"IO15", 4, 16959},
	{"IO16", 4, 16960},
	{"IO17", 4, 16961},
	{"IO18", 4, 16962},
	{"IO19", 4, 16963},
	{"IO20", 4, 16964},
	{"IO21", 4, 16965},
	{"IO22", 4, 16966},
	{"IO23", 4, 16967},
	{"IO24", 4, 16968},
	{"IO25", 4, 16969},
	{"IO26", 4, 16970},
	{"IO27", 4, 16971},
	{"IO28", 4, 16972},
	{"IO29", 4, 16973},
	{"IO30", 4, 16974},
	{"IO31", 4, 16975},
	{"IO32", 4, 16976},
	{"IO33", 4, 16977},
	{"IO34", 4, 16978},
	{"IO35", 4, 16979},
	{"IO36", 4, 16980},
	{"IO37", 4, 16981},
	{"IO38", 4, 16982},
	{"IO39", 4, 16983},
	{"IO40", 4, 16984},
	{"IO41", 4, 16985},
	{"IO42", 4, 16986},
	{"IO43", 4, 16987},
	{"IO44", 4, 16988},
	{"IO45", 4, 16989},
	{"IO46", 4, 16990},
	{"IO47", 4, 16991},
	{"IO48", 4, 16992},
	{"IO49", 4, 16993},
	{"IO50", 4, 16994},
	{"IO51", 4, 16995},
	{"IO52", 4, 16996},
	{"IO53", 4, 16997},
	{"IO54", 4, 16998},
	{"IO55", 4, 16999},
	{"IO56", 4, 17000},
	{"IO57", 4, 17001},
	{"IO58", 4, 17002},
	{"IO59", 4, 17003},
	{"IO60", 4, 17004},
	{"IO61", 4, 17005},
	{"IO62", 4, 17006},
	{"IO63", 4, 17007},
	{"IO64", 4, 17008},
	{"IO65", 4, 17009},
	{"IO66", 4, 17010},
	{"IO67", 4, 17011},
	{"IO68", 4, 17012},
	{"IO69", 4, 17013},
	{"IO70", 4, 17014},
	{"IO71", 4, 17015},
	{"IO72", 4, 17016},
	{"IO73", 4, 17017},
	{"IO74", 4, 17018},
	{"IO75", 4, 17019},
	{"IO76", 4, 17020},
	{"IO77", 4, 17021},
	{"IO78", 4, 17022},
	{"IO79", 4, 17023},
	{"IO80", 4, 17024},
	{"IO81", 4, 17025},
	{"IO82", 4, 17026},
	{"IO83", 4, 17027},
	{"IO84", 4, 17028},
	{"IO85", 4, 17029},
	{"IO86", 4, 17030},
	{"IO87", 4, 17031},
	{"IO88", 4, 17032},
	{"IO89", 4, 17033},
	{"IO90", 4, 17034},
	{"IO91", 4, 17035},
	{"IO92", 4, 17036},
	{"IO93", 4, 17037},
	{"IO94", 4, 17038},
	{"IO95", 4, 17039},
	{"IO96", 4, 17040},
	{"IO97", 4, 17041},
	{"IO98", 4, 17042},
	{"IO99", 4, 17043},
	{"IP00", 4, 17044},
	{"IP01", 4, 17045},
	{"IP02", 4, 17046},
	{"IP03", 4, 17047},
	{"IP04", 4, 17048},
	{"IP05", 4, 17049},
	{"IP06", 4, 17050},
	{"IP07", 4, 17051},
	{"IP08", 4, 17052},
	{"IP09", 4, 17053},
	{"IP10", 4, 17054},
	{"IP11", 4, 17055},
	{"IP12", 4, 17056},
	{"IP13", 4, 17057},
	{"IP14", 4, 17058},
	{"IP15", 4, 17059},
	{"IP16", 4, 17060},
	{"IP17", 4, 17061},
	{"IP18", 4, 17062},
	{"IP19", 4, 17063},
	{"IP20", 4, 17064},
	{"IP21", 4, 17065},
	{"IP22", 4, 17066},
	{"IP23", 4, 17067},
	{"IP24", 4, 17068},
	{"IP25", 4, 17069},
	{"IP26", 4, 17070},
	{"IP27", 4, 17071},
	{"IP28", 4, 17072},
	{"IP29", 4, 17073},
	{"IP30", 4, 17074},
	{"IP31", 4, 17075},
	{"IP32", 4, 17076},
	{"IP33", 4, 17077},
	{"IP34", 4, 17078},
	{"IP35", 4, 17079},
	{"IP36", 4, 17080},
	{"IP37", 4, 17081},
	{"IP38", 4, 17082},
	{"IP39", 4, 17083},
	{"IP40", 4, 17084},
	{"IP41", 4, 17085},
	{"IP42", 4, 17086},
	{"IP43", 4, 17087},
	{"IP44", 4, 17088},
	{"IP45", 4, 17089},
	{"IP46", 4, 17090},
	{"IP47", 4, 17091},
	{"IP48", 4, 17092},
	{"IP49", 4, 17093},
	{"IP50", 4, 17094},
	{"IP51", 4, 17095},
	{"IP52", 4, 17096},
	{"IP53", 4, 17097},
	{"IP54", 4, 17098},
	{"IP55", 4, 17099},
	{"IP56", 4, 17100},
	{"IP57", 4, 17101},
	{"IP58", 4, 17102},
	{"IP59", 4, 17103},
	{"IP60", 4, 17104},
	{"IP61", 4, 17105},
	{"IP62", 4, 17106},
	{"IP63", 4, 17107},
	{"IP64", 4, 17108},
	{"IP65", 4, 17109},
	{"IP66", 4, 17110},
	{"IP67", 4, 17111},
	{"IP68", 4, 17112},
	{"IP69", 4, 17113},
	{"IP70", 4, 17114},
	{"IP71", 4, 17115},
	{"IP72", 4, 17116},
	{"IP73", 4, 17117},
	{"IP74", 4, 17118},
	{"IP75", 4, 17119},
	{"IP76", 4, 17120},
	{"IP77", 4, 17121},
	{"IP78", 4, 17122},
	{"IP79", 4, 17123},
	{"IP80", 4, 17124},
	{"IP81", 4, 17125},
	{"IP82", 4, 17126},
	{"IP83", 4, 17127},
	{"IP84", 4, 17128},
	{"IP85", 4, 17129},
	{"IP86", 4, 17130},
	{"IP87", 4, 17131},
	{"IP88", 4, 17132},
	{"IP89", 4, 17133},
	{"IP90", 4, 17134},
	{"IP91", 4, 17135},
	{"IP92", 4, 17136},
	{"IP93", 4, 17137},
	{"IP94", 4, 17138},
	{"IP95", 4, 17139},
	{"IP96", 4, 17140},
	{"IP97", 4, 17141},
	{"IP98", 4, 17142},
	{"IP99", 4, 17143},
	{"JB00", 4, 17144},
	{"JB01", 4, 17145},
	{"JB02", 4, 17146},
	{"JB03", 4, 17147},
	{"JB04", 4, 17148},
	{"JB05", 4, 17149},
	{"JB06", 4, 17150},
	{"JB07", 4, 17151},
	{"JB08", 4, 17152},
	{"JB09", 4, 17153},
	{"JB10", 4, 17154},
	{"JB11", 4, 17155},
	{"JB12", 4, 17156},
	{"JB13", 4, 17157},
	{"JB14", 4, 17158},
	{"JB15", 4, 17159},
	{"JB16", 4, 17160},
	{"JB17", 4, 17161},
	{"JB18", 4, 17162},
	{"JB19", 4, 17163},
	{"JB20", 4, 17164},
	{"JB21", 4, 17165},
	{"JB22", 4, 17166},
	{"JB23", 4, 17167},
	{"JB24", 4, 17168},
	{"JB25", 4, 17169},
	{"JB26", 4, 17170},
	{"JB27", 4, 17171},
	{"JB28", 4, 17172},
	{"JB29", 4, 17173},
	{"JB30", 4, 17174},
	{"JB31", 4, 17175},
	{"JB32", 4, 17176},
	{"JB33", 4, 17177},
	{"JB34", 4, 17178},
	{"JB35", 4, 17179},
	{"JB36", 4, 17180},
	{"JB37", 4, 17181},
	{"JB38", 4, 17182},
	{"JB39", 4, 17183},
	{"JB40", 4, 17184},
	{"JB41", 4, 17185},
	{"JB42", 4, 17186},
	{"JB43", 4, 17187},
	{"JB44", 4, 17188},
	{"JB45", 4, 17189},
	{"JB46", 4, 17190},
	{"JB47", 4, 17191},
	{"JB48", 4, 17192},
	{"JB49", 4, 17193},
	{"JB50", 4, 17194},
	{"JB51", 4, 17195},
	{"JB52", 4, 17196},
	{"JB53", 4, 17197},
	{"JB54", 4, 17198},
	{"JB55", 4, 17199},
	{"JB56", 4, 17200},
	{"JB57", 4, 17201},
	{"JB58", 4, 17202},
	{"JB59", 4, 17203},
	{"JB60", 4, 17204},
	{"JB61", 4, 17205},
	{"JB62", 4, 17206},
	{"JB63", 4, 17207},
	{"JB64", 4, 17208},
	{"JB65", 4, 17209},
	{"JB66", 4, 17210},
	{"JB67", 4, 17211},
	{"JB68", 4, 17212},
	{"JB69", 4, 17213},
	{"JB70", 4, 17214},
	{"JB71", 4, 17215},
	{"JB72", 4, 17216},
	{"JB73", 4, 17217},
	{"JB74", 4, 17218},
	{"JB75", 4, 17219},
	{"JB76", 4, 17220},
	{"JB77", 4, 17221},
	{"JB78", 4, 17222},
	{"JB79", 4, 17223},
	{"JB80", 4, 17224},
	{"JB81", 4, 17225},
	{"JB82", 4, 17226},
	{"JB83", 4, 17227},
	{"JB84", 4, 17228},
	{"JB85", 4, 17229},
	{"JB86", 4, 17230},
	{"JB87", 4, 17231},
	{"JB88", 4, 17232},
	{"JB89", 4, 17233},
	{"JB90", 4, 17234},
	{"JB91", 4, 17235},
	{"JB92", 4, 17236},
	{"JB93", 4, 17237},
	{"JB94", 4, 17238},
	{"JB95", 4, 17239},
	{"JB96", 4, 17240},
	{"JB97", 4, 17241},
	{"JB98", 4, 17242},
	{"JB99", 4, 17243},
	{"JF00", 4, 17244},
	{"JF01", 4, 17245},
	{"JF02", 4, 17246},
	{"JF03", 4, 17247},
	{"JF04", 4, 17248},
	{"JF05", 4, 17249},
	{"JF06", 4, 17250},
	{"JF07", 4, 17251},
	{"JF08", 4, 17252},
	{"JF09", 4, 17253},
	{"JF10", 4, 17254},
	{"JF11", 4, 17255},
	{"JF12", 4, 17256},
	{"JF13", 4, 17257},
	{"JF14", 4, 17258},
	{"JF15", 4, 17259},
	{"JF16", 4, 17260},
	{"JF17", 4, 17261},
	{"JF18", 4, 17262},
	{"JF19", 4, 17263},
	{"JF20", 4, 17264},
	{"JF21", 4, 17265},
	{"JF22", 4, 17266},
	{"JF23", 4, 17267},
	{"JF24", 4, 17268},
	{"JF25", 4, 17269},
	{"JF26", 4, 17270},
	{"JF27", 4, 17271},
	{"JF28", 4, 17272},
	{"JF29", 4, 17273},
	{"JF30", 4, 17274},
	{"JF31", 4, 17275},
	{"JF32", 4, 17276},
	{"JF33", 4, 17277},
	{"JF34", 4, 17278},
	{"JF35", 4, 17279},
	{"JF36", 4, 17280},
	{"JF37", 4, 17281},
	{"JF38", 4, 17282},
	{"JF39", 4, 17283},
	{"JF40", 4, 17284},
	{"JF41", 4, 17285},
	{"JF42", 4, 17286},
	{"JF43", 4, 17287},
	{"JF44", 4, 17288},
	{"JF45", 4, 17289},
	{"JF46", 4, 17290},
	{"JF47", 4, 17291},
	{"JF48", 4, 17292},
	{"JF49", 4, 17293},
	{"JF50", 4, 17294},
	{"JF51", 4, 17295},
	{"JF52", 4, 17296},
	{"JF53", 4, 17297},
	{"JF54", 4, 17298},
	{"JF55", 4, 17299},
	{"JF56", 4, 17300},
	{"JF57", 4, 17301},
	{"JF58", 4, 17302},
	{"JF59", 4, 17303},
	{"JF60", 4, 17304},
	{"JF61", 4, 17305},
	{"JF62", 4, 17306},
	{"JF63", 4, 17307},
	{"JF64", 4, 17308},
	{"JF65", 4, 17309},
	{"JF66", 4, 17310},
	{"JF67", 4, 17311},
	{"JF68", 4, 17312},
	{"JF69", 4, 17313},
	{"JF70", 4, 17314},
	{"JF71", 4, 17315},
	{"JF72", 4, 17316},
	{"JF73", 4, 17317},
	{"JF74", 4, 17318},
	{"JF75", 4, 17319},
	{"JF76", 4, 17320},
	{"JF77", 4, 17321},
	{"JF78", 4, 17322},
	{"JF79", 4, 17323},
	{"JF80", 4, 17324},
	{"JF81", 4, 17325},
	{"JF82", 4, 17326},
	{"JF83", 4, 17327},
	{"JF84", 4, 17328},
	{"JF85", 4, 17329},
	{"JF86", 4, 17330},
	{"JF87", 4, 17331},
	{"JF88", 4, 17332},
	{"JF89", 4, 17333},
	{"JF90", 4, 17334},
	{"JF91", 4, 17335},
	{"JF92", 4, 17336},
	{"JF93", 4, 17337},
	{"JF94", 4, 17338},
	{"JF95", 4, 17339},
	{"JF96", 4, 17340},
	{"JF97", 4, 17341},
	{"JF98", 4, 17342},
	{"JF99", 4, 17343},
	{"JG00", 4, 17344},
	{"JG01", 4, 17345},
	{"JG02", 4, 17346},
	{"JG03", 4, 17347},
	{"JG04", 4, 17348},
	{"JG05", 4, 17349},
	{"JG06", 4, 17350},
	{"JG07", 4, 17351},
	{"JG08", 4, 17352},
	{"JG09", 4, 17353},
	{"JG10", 4, 17354},
	{"JG11", 4, 17355},
	{"JG12", 4, 17356},
	{"JG13", 4, 17357},
	{"JG14", 4, 17358},
	{"JG15", 4, 17359},
	{"JG16", 4, 17360},
	{"JG17", 4, 17361},
	{"JG18", 4, 17362},
	{"JG19", 4, 17363},
	{"JG20", 4, 17364},
	{"JG21", 4, 17365},
	{"JG22", 4, 17366},
	{"JG23", 4, 17367},
	{"JG24", 4, 17368},
	{"JG25", 4, 17369},
	{"JG26", 4, 17370},
	{"JG27", 4, 17371},
	{"JG28", 4, 17372},
	{"JG29", 4, 17373},
	{"JG30", 4, 17374},
	{"JG31", 4, 17375},
	{"JG32", 4, 17376},
	{"JG33", 4, 17377},
	{"JG34", 4, 17378},
	{"JG35", 4, 17379},
	{"JG36", 4, 17380},
	{"JG37", 4, 17381},
	{"JG38", 4, 17382},
	{"JG39", 4, 17383},
	{"JG40", 4, 17384},
	{"JG41", 4, 17385},
	{"JG42", 4, 17386},
	{"JG43", 4, 17387},
	{"JG44", 4, 17388},
	{"JG45", 4, 17389},
	{"JG46", 4, 17390},
	{"JG47", 4, 17391},
	{"JG48", 4, 17392},
	{"JG49", 4, 17393},
	{"JG50", 4, 17394},
	{"JG51", 4, 17395},
	{"JG52", 4, 17396},
	{"JG53", 4, 17397},
	{"JG54", 4, 17398},
	{"JG55", 4, 17399},
	{"JG56", 4, 17400},
	{"JG57", 4, 17401},
	{"JG58", 4, 17402},
	{"JG59", 4, 17403},
	{"JG60", 4, 17404},
	{"JG61", 4, 17405},
	{"JG62", 4, 17406},
	{"JG63", 4, 17407},
	{"JG64", 4, 17408},
	{"JG65", 4, 17409},
	{"JG66", 4, 17410},
	{"JG67", 4, 17411},
	{"JG68", 4, 17412},
	{"JG69", 4, 17413},
	{"JG70", 4, 17414},
	{"JG71", 4, 17415},
	{"JG72", 4, 17416},
	{"JG73", 4, 17417},
	{"JG74", 4, 17418},
	{"JG75", 4, 17419},
	{"JG76", 4, 17420},
	{"JG77", 4, 17421},
	{"JG78", 4, 17422},
	{"JG79", 4, 17423},
	{"JG80", 4, 17424},
	{"JG81", 4, 17425},
	{"JG82", 4, 17426},
	{"JG83", 4, 17427},
	{"JG84", 4, 17428},
	{"JG85", 4, 17429},
	{"JG86", 4, 17430},
	{"JG87", 4, 17431},
	{"JG88", 4, 17432},
	{"JG89", 4, 17433},
	{"JG90", 4, 17434},
	{"JG91", 4, 17435},
	{"JG92", 4, 17436},
	{"JG93", 4, 17437},
	{"JG94", 4, 17438},
	{"JG95", 4, 17439},
	{"JG96", 4, 17440},
	{"JG97", 4, 17441},
	{"JG98", 4, 17442},
	{"JG99", 4, 17443},
	{"JH00", 4, 17444},
	{"JH01", 4, 17445},
	{"JH02", 4, 17446},
	{"JH03", 4, 17447},
	{"JH04", 4, 17448},
	{"JH05", 4, 17449},
	{"JH06", 4, 17450},
	{"JH07", 4, 17451},
	{"JH08", 4, 17452},
	{"JH09", 4, 17453},
	{"JH10", 4, 17454},
	{"JH11", 4, 17455},
	{"JH12", 4, 17456},
	{"JH13", 4, 17457},
	{"JH14", 4, 17458},
	{"JH15", 4, 17459},
	{"JH16", 4, 17460},
	{"JH17", 4, 17461},
	{"JH18", 4, 17462},
	{"JH19", 4, 17463},
	{"JH20", 4, 17464},
	{"JH21", 4, 17465},
	{"JH22", 4, 17466},
	{"JH23", 4, 17467},
	{"JH24", 4, 17468},
	{"JH25", 4, 17469},
	{"JH26", 4, 17470},
	{"JH27", 4, 17471},
	{"JH28", 4, 17472},
	{"JH29", 4, 17473},
	{"JH30", 4, 17474},
	{"JH31", 4, 17475},
	{"JH32", 4, 17476},
	{"JH33", 4, 17477},
	{"JH34", 4, 17478},
	{"JH35", 4, 17479},
	{"JH36", 4, 17480},
	{"JH37", 4, 17481},
	{"JH38", 4, 17482},
	{"JH39", 4, 17483},
	{"JH40", 4, 17484},
	{"JH41", 4, 17485},
	{"JH42", 4, 17486},
	{"JH43", 4, 17487},
	{"JH44", 4, 17488},
	{"JH45", 4, 17489},
	{"JH46", 4, 17490},
	{"JH47", 4, 17491},
	{"JH48", 4, 17492},
	{"JH49", 4, 17493},
	{"JH50", 4, 17494},
	{"JH51", 4, 17495},
	{"JH52", 4, 17496},
	{"JH53", 4, 17497},
	{"JH54", 4, 17498},
	{"JH55", 4, 17499},
	{"JH56", 4, 17500},
	{"JH57", 4, 17501},
	{"JH58", 4, 17502},
	{"JH59", 4, 17503},
	{"JH60", 4, 17504},
	{"JH61", 4, 17505},
	{"JH62", 4, 17506},
	{"JH63", 4, 17507},
	{"JH64", 4, 17508},
	{"JH65", 4, 17509},
	{"JH66", 4, 17510},
	{"JH67", 4, 17511},
	{"JH68", 4, 17512},
	{"JH69", 4, 17513},
	{"JH70", 4, 17514},
	{"JH71", 4, 17515},
	{"JH72", 4, 17516},
	{"JH73", 4, 17517},
	{"JH74", 4, 17518},
	{"JH75", 4, 17519},
	{"JH76", 4, 17520},
	{"JH77", 4, 17521},
	{"JH78", 4, 17522},
	{"JH79", 4, 17523},
	{"JH80", 4, 17524},
	{"JH81", 4, 17525},
	{"JH82", 4, 17526},
	{"JH83", 4, 17527},
	{"JH84", 4, 17528},
	{"JH85", 4, 17529},
	{"JH86", 4, 17530},
	{"JH87", 4, 17531},
	{"JH88", 4, 17532},
	{"JH89", 4, 17533},
	{"JH90", 4, 17534},
	{"JH91", 4, 17535},
	{"JH92", 4, 17536},
	{"JH93", 4, 17537},
	{"JH94", 4, 17538},
	{"JH95", 4, 17539},
	{"JH96", 4, 17540},
	{"JH97", 4, 17541},
	{"JH98", 4, 17542},
	{"JH99", 4, 17543},
	{"JI00", 4, 17544},
	{"JI01", 4, 17545},
	{"JI02", 4, 17546},
	{"JI03", 4, 17547},
	{"JI04", 4, 17548},
	{"JI05", 4, 17549},
	{"JI06", 4, 17550},
	{"JI07", 4, 17551},
	{"JI08", 4, 17552},
	{"JI09", 4, 17553},
	{"JI10", 4, 17554},
	{"JI11", 4, 17555},
	{"JI12", 4, 17556},
	{"JI13", 4, 17557},
	{"JI14", 4, 17558},
	{"JI15", 4, 17559},
	{"JI16", 4, 17560},
	{"JI17", 4, 17561},
	{"JI18", 4, 17562},
	{"JI19", 4, 17563},
	{"JI20", 4, 17564},
	{"JI21", 4, 17565},
	{"JI22", 4, 17566},
	{"JI23", 4, 17567},
	{"JI24", 4, 17568},
	{"JI25", 4, 17569},
	{"JI26", 4, 17570},
	{"JI27", 4, 17571},
	{"JI28", 4, 17572},
	{"JI29", 4, 17573},
	{"JI30", 4, 17574},
	{"JI31", 4, 17575},
	{"JI32", 4, 17576},
	{"JI33", 4, 17577},
	{"JI34", 4, 17578},
	{"JI35", 4, 17579},
	{"JI36", 4, 17580},
	{"JI37", 4, 17581},
	{"JI38", 4, 17582},
	{"JI39", 4, 17583},
	{"JI40", 4, 17584},
	{"JI41", 4, 17585},
	{"JI42", 4, 17586},
	{"JI43", 4, 17587},
	{"JI44", 4, 17588},
	{"JI45", 4, 17589},
	{"JI46", 4, 17590},
	{"JI47", 4, 17591},
	{"JI48", 4, 17592},
	{"JI49", 4, 17593},
	{"JI50", 4, 17594},
	{"JI51", 4, 17595},
	{"JI52", 4, 17596},
	{"JI53", 4, 17597},
	{"JI54", 4, 17598},
	{"JI55", 4, 17599},
	{"JI56", 4, 17600},
	{"JI57", 4, 17601},
	{"JI58", 4, 17602},
	{"JI59", 4, 17603},
	{"JI60", 4, 17604},
	{"JI61", 4, 17605},
	{"JI62", 4, 17606},
	{"JI63", 4, 17607},
	{"JI64", 4, 17608},
	{"JI65", 4, 17609},
	{"JI66", 4, 17610},
	{"JI67", 4, 17611},
	{"JI68", 4, 17612},
	{"JI69", 4, 17613},
	{"JI70", 4, 17614},
	{"JI71", 4, 17615},
	{"JI72", 4, 17616},
	{"JI73", 4, 17617},
	{"JI74", 4, 17618},
	{"JI75", 4, 17619},
	{"JI76", 4, 17620},
	{"JI77", 4, 17621},
	{"JI78", 4, 17622},
	{"JI79", 4, 17623},
	{"JI80", 4, 17624},
	{"JI81", 4, 17625},
	{"JI82", 4, 17626},
	{"JI83", 4, 17627},
	{"JI84", 4, 17628},
	{"JI85", 4, 17629},
	{"JI86", 4, 17630},
	{"JI87", 4, 17631},
	{"JI88", 4, 17632},
	{"JI89", 4, 17633},
	{"JI90", 4, 17634},
	{"JI91", 4, 17635},
	{"JI92", 4, 17636},
	{"JI93", 4, 17637},
	{"JI94", 4, 17638},
	{"JI95", 4, 17639},
	{"JI96", 4, 17640},
	{"JI97", 4, 17641},
	{"JI98", 4, 17642},
	{"JI99", 4, 17643},
	{"JJ00", 4, 17644},
	{"JJ01", 4, 17645},
	{"JJ02", 4, 17646},
	{"JJ03", 4, 17647},
	{"JJ04", 4, 17648},
	{"JJ05", 4, 17649},
	{"JJ06", 4, 17650},
	{"JJ07", 4, 17651},
	{"JJ08", 4, 17652},
	{"JJ09", 4, 17653},
	{"JJ10", 4, 17654},
	{"JJ11", 4, 17655},
	{"JJ12", 4, 17656},
	{"JJ13", 4, 17657},
	{"JJ14", 4, 17658},
	{"JJ15", 4, 17659},
	{"JJ16", 4, 17660},
	{"JJ17", 4, 17661},
	{"JJ18", 4, 17662},
	{"JJ19", 4, 17663},
	{"JJ20", 4, 17664},
	{"JJ21", 4, 17665},
	{"JJ22", 4, 17666},
	{"JJ23", 4, 17667},
	{"JJ24", 4, 17668},
	{"JJ25", 4, 17669},
	{"JJ26", 4, 17670},
	{"JJ27", 4, 17671},
	{"JJ28", 4, 17672},
	{"JJ29", 4, 17673},
	{"JJ30", 4, 17674},
	{"JJ31", 4, 17675},
	{"JJ32", 4, 17676},
	{"JJ33", 4, 17677},
	{"JJ34", 4, 17678},
	{"JJ35", 4, 17679},
	{"JJ36", 4, 17680},
	{"JJ37", 4, 17681},
	{"JJ38", 4, 17682},
	{"JJ39", 4, 17683},
	{"JJ40", 4, 17684},
	{"JJ41", 4, 17685},
	{"JJ42", 4, 17686},
	{"JJ43", 4, 17687},
	{"JJ44", 4, 17688},
	{"JJ45", 4, 17689},
	{"JJ46", 4, 17690},
	{"JJ47", 4, 17691},
	{"JJ48", 4, 17692},
	{"JJ49", 4, 17693},
	{"JJ50", 4, 17694},
	{"JJ51", 4, 17695},
	{"JJ52", 4, 17696},
	{"JJ53", 4, 17697},
	{"JJ54", 4, 17698},
	{"JJ55", 4, 17699},
	{"JJ56", 4, 17700},
	{"JJ57", 4, 17701},
	{"JJ58", 4, 17702},
	{"JJ59", 4, 17703},
	{"JJ60", 4, 17704},
	{"JJ61", 4, 17705},
	{"JJ62", 4, 17706},
	{"JJ63", 4, 17707},
	{"JJ64", 4, 17708},
	{"JJ65", 4, 17709},
	{"JJ66", 4, 17710},
	{"JJ67", 4, 17711},
	{"JJ68", 4, 17712},
	{"JJ69", 4, 17713},
	{"JJ70", 4, 17714},
	{"JJ71", 4, 17715},
	{"JJ72", 4, 17716},
	{"JJ73", 4, 17717},
	{"JJ74", 4, 17718},
	{"JJ75", 4, 17719},
	{"JJ76", 4, 17720},
	{"JJ77", 4, 17721},
	{"JJ78", 4, 17722},
	{"JJ79", 4, 17723},
	{"JJ80", 4, 17724},
	{"JJ81", 4, 17725},
	{"JJ82", 4, 17726},
	{"JJ83", 4, 17727},
	{"JJ84", 4, 17728},
	{"JJ85", 4, 17729},
	{"JJ86", 4, 17730},
	{"JJ87", 4, 17731},
	{"JJ88", 4, 17732},
	{"JJ89", 4, 17733},
	{"JJ90", 4, 17734},
	{"JJ91", 4, 17735},
	{"JJ92", 4, 17736},
	{"JJ93", 4, 17737},
	{"JJ94", 4, 17738},
	{"JJ95", 4, 17739},
	{"JJ96", 4, 17740},
	{"JJ97", 4, 17741},
	{"JJ98", 4, 17742},
	{"JJ99", 4, 17743},
	{"JK00", 4, 17744},
	{"JK01", 4, 17745},
	{"JK02", 4, 17746},
	{"JK03", 4, 17747},
	{"JK04", 4, 17748},
	{"JK05", 4, 17749},
	{"JK06", 4, 17750},
	{"JK07", 4, 17751},
	{"JK08", 4, 17752},
	{"JK09", 4, 17753},
	{"JK10", 4, 17754},
	{"JK11", 4, 17755},
	{"JK12", 4, 17756},
	{"JK13", 4, 17757},
	{"JK14", 4, 17758},
	{"JK15", 4, 17759},
	{"JK16", 4, 17760},
	{"JK17", 4, 17761},
	{"JK18", 4, 17762},
	{"JK19", 4, 17763},
	{"JK20", 4, 17764},
	{"JK21", 4, 17765},
	{"JK22", 4, 17766},
	{"JK23", 4, 17767},
	{"JK24", 4, 17768},
	{"JK25", 4, 17769},
	{"JK26", 4, 17770},
	{"JK27", 4, 17771},
	{"JK28", 4, 17772},
	{"JK29", 4, 17773},
	{"JK30", 4, 17774},
	{"JK31", 4, 17775},
	{"JK32", 4, 17776},
	{"JK33", 4, 17777},
	{"JK34", 4, 17778},
	{"JK35", 4, 17779},
	{"JK36", 4, 17780},
	{"JK37", 4, 17781},
	{"JK38", 4, 17782},
	{"JK39", 4, 17783},
	{"JK40", 4, 17784},
	{"JK41", 4, 17785},
	{"JK42", 4, 17786},
	{"JK43", 4, 17787},
	{"JK44", 4, 17788},
	{"JK45", 4, 17789},
	{"JK46", 4, 17790},
	{"JK47", 4, 17791},
	{"JK48", 4, 17792},
	{"JK49", 4, 17793},
	{"JK50", 4, 17794},
	{"JK51", 4, 17795},
	{"JK52", 4, 17796},
	{"JK53", 4, 17797},
	{"JK54", 4, 17798},
	{"JK55", 4, 17799},
	{"JK56", 4, 17800},
	{"JK57", 4, 17801},
	{"JK58", 4, 17802},
	{"JK59", 4, 17803},
	{"JK60", 4, 17804},
	{"JK61", 4, 17805},
	{"JK62", 4, 17806},
	{"JK63", 4, 17807},
	{"JK64", 4, 17808},
	{"JK65", 4, 17809},
	{"JK66", 4, 17810},
	{"JK67", 4, 17811},
	{"JK68", 4, 17812},
	{"JK69", 4, 17813},
	{"JK70", 4, 17814},
	{"JK71", 4, 17815},
	{"JK72", 4, 17816},
	{"JK73", 4, 17817},
	{"JK74", 4, 17818},
	{"JK75", 4, 17819},
	{"JK76", 4, 17820},
	{"JK77", 4, 17821},
	{"JK78", 4, 17822},
	{"JK79", 4, 17823},
	{"JK80", 4, 17824},
	{"JK81", 4, 17825},
	{"JK82", 4, 17826},
	{"JK83", 4, 17827},
	{"JK84", 4, 17828},
	{"JK85", 4, 17829},
	{"JK86", 4, 17830},
	{"JK87", 4, 17831},
	{"JK88", 4, 17832},
	{"JK89", 4, 17833},
	{"JK90", 4, 17834},
	{"JK91", 4, 17835},
	{"JK92", 4, 17836},
	{"JK93", 4, 17837},
	{"JK94", 4, 17838},
	{"JK95", 4, 17839},
	{"JK96", 4, 17840},
	{"JK97", 4, 17841},
	{"JK98", 4, 17842},
	{"JK99", 4, 17843},
	{"JL00", 4, 17844},
	{"JL01", 4, 17845},
	{"JL02", 4, 17846},
	{"JL03", 4, 17847},
	{"JL04", 4, 17848},
	{"JL05", 4, 17849},
	{"JL06", 4, 17850},
	{"JL07", 4, 17851},
	{"JL08", 4, 17852},
	{"JL09", 4, 17853},
	{"JL10", 4, 17854},
	{"JL11", 4, 17855},
	{"JL12", 4, 17856},
	{"JL13", 4, 17857},
	{"JL14", 4, 17858},
	{"JL15", 4, 17859},
	{"JL16", 4, 17860},
	{"JL17", 4, 17861},
	{"JL18", 4, 17862},
	{"JL19", 4, 17863},
	{"JL20", 4, 17864},
	{"JL21", 4, 17865},
	{"JL22", 4, 17866},
	{"JL23", 4, 17867},
	{"JL24", 4, 17868},
	{"JL25", 4, 17869},
	{"JL26", 4, 17870},
	{"JL27", 4, 17871},
	{"JL28", 4, 17872},
	{"JL29", 4, 17873},
	{"JL30", 4, 17874},
	{"JL31", 4, 17875},
	{"JL32", 4, 17876},
	{"JL33", 4, 17877},
	{"JL34", 4, 17878},
	{"JL35", 4, 17879},
	{"JL36", 4, 17880},
	{"JL37", 4, 17881},
	{"JL38", 4, 17882},
	{"JL39", 4, 17883},
	{"JL40", 4, 17884},
	{"JL41", 4, 17885},
	{"JL42", 4, 17886},
	{"JL43", 4, 17887},
	{"JL44", 4, 17888},
	{"JL45", 4, 17889},
	{"JL46", 4, 17890},
	{"JL47", 4, 17891},
	{"JL48", 4, 17892},
	{"JL49", 4, 17893},
	{"JL50", 4, 17894},
	{"JL51", 4, 17895},
	{"JL52", 4, 17896},
	{"JL53", 4, 17897},
	{"JL54", 4, 17898},
	{"JL55", 4, 17899},
	{"JL56", 4, 17900},
	{"JL57", 4, 17901},
	{"JL58", 4, 17902},
	{"JL59", 4, 17903},
	{"JL60", 4, 17904},
	{"JL61", 4, 17905},
	{"JL62", 4, 17906},
	{"JL63", 4, 17907},
	{"JL64", 4, 17908},
	{"JL65", 4, 17909},
	{"JL66", 4, 17910},
	{"JL67", 4, 17911},
	{"JL68", 4, 17912},
	{"JL69", 4, 17913},
	{"JL70", 4, 17914},
	{"JL71", 4, 17915},
	{"JL72", 4, 17916},
	{"JL73", 4, 17917},
	{"JL74", 4, 17918},
	{"JL75", 4, 17919},
	{"JL76", 4, 17920},
	{"JL77", 4, 17921},
	{"JL78", 4, 17922},
	{"JL79", 4, 17923},
	{"JL80", 4, 17924},
	{"JL81", 4, 17925},
	{"JL82", 4, 17926},
	{"JL83", 4, 17927},
	{"JL84", 4, 17928},
	{"JL85", 4, 17929},
	{"JL86", 4, 17930},
	{"JL87", 4, 17931},
	{"JL88", 4, 17932},
	{"JL89", 4, 17933},
	{"JL90", 4, 17934},
	{"JL91", 4, 17935},
	{"JL92", 4, 17936},
	{"JL93", 4, 17937},
	{"JL94", 4, 17938},
	{"JL95", 4, 17939},
	{"JL96", 4, 17940},
	{"JL97", 4, 17941},
	{"JL98", 4, 17942},
	{"JL99", 4, 17943},
	{"JM00", 4, 17944},
	{"JM01", 4, 17945},
	{"JM02", 4, 17946},
	{"JM03", 4, 17947},
	{"JM04", 4, 17948},
	{"JM05", 4, 17949},
	{"JM06", 4, 17950},
	{"JM07", 4, 17951},
	{"JM08", 4, 17952},
	{"JM09", 4, 17953},
	{"JM10", 4, 17954},
	{"JM11", 4, 17955},
	{"JM12", 4, 17956},
	{"JM13", 4, 17957},
	{"JM14", 4, 17958},
	{"JM15", 4, 17959},
	{"JM16", 4, 17960},
	{"JM17", 4, 17961},
	{"JM18", 4, 17962},
	{"JM19", 4, 17963},
	{"JM20", 4, 17964},
	{"JM21", 4, 17965},
	{"JM22", 4, 17966},
	{"JM23", 4, 17967},
	{"JM24", 4, 17968},
	{"JM25", 4, 17969},
	{"JM26", 4, 17970},
	{"JM27", 4, 17971},
	{"JM28", 4, 17972},
	{"JM29", 4, 17973},
	{"JM30", 4, 17974},
	{"JM31", 4, 17975},
	{"JM32", 4, 17976},
	{"JM33", 4, 17977},
	{"JM34", 4, 17978},
	{"JM35", 4, 17979},
	{"JM36", 4, 17980},
	{"JM37", 4, 17981},
	{"JM38", 4, 17982},
	{"JM39", 4, 17983},
	{"JM40", 4, 17984},
	{"JM41", 4, 17985},
	{"JM42", 4, 17986},
	{"JM43", 4, 17987},
	{"JM44", 4, 17988},
	{"JM45", 4, 17989},
	{"JM46", 4, 17990},
	{"JM47", 4, 17991},
	{"JM48", 4, 17992},
	{"JM49", 4, 17993},
	{"JM50", 4, 17994},
	{"JM51", 4, 17995},
	{"JM52", 4, 17996},
	{"JM53", 4, 17997},
	{"JM54", 4, 17998},
	{"JM55", 4, 17999},
	{"JM56", 4, 18000},
	{"JM57", 4, 18001},
	{"JM58", 4, 18002},
	{"JM59", 4, 18003},
	{"JM60", 4, 18004},
	{"JM61", 4, 18005},
	{"JM62", 4, 18006},
	{"JM63", 4, 18007},
	{"JM64", 4, 18008},
	{"JM65", 4, 18009},
	{"JM66", 4, 18010},
	{"JM67", 4, 18011},
	{"JM68", 4, 18012},
	{"JM69", 4, 18013},
	{"JM70", 4, 18014},
	{"JM71", 4, 18015},
	{"JM72", 4, 18016},
	{"JM73", 4, 18017},
	{"JM74", 4, 18018},
	{"JM75", 4, 18019},
	{"JM76", 4, 18020},
	{"JM77", 4, 18021},
	{"JM78", 4, 18022},
	{"JM79", 4, 18023},
	{"JM80", 4, 18024},
	{"JM81", 4, 18025},
	{"JM82", 4, 18026},
	{"JM83", 4, 18027},
	{"JM84", 4, 18028},
	{"JM85", 4, 18029},
	{"JM86", 4, 18030},
	{"JM87", 4, 18031},
	{"JM88", 4, 18032},
	{"JM89", 4, 18033},
	{"JM90", 4, 18034},
	{"JM91", 4, 18035},
	{"JM92", 4, 18036},
	{"JM93", 4, 18037},
	{"JM94", 4, 18038},
	{"JM95", 4, 18039},
	{"JM96", 4, 18040},
	{"JM97", 4, 18041},
	{"JM98", 4, 18042},
	{"JM99", 4, 18043},
	{"JN00", 4, 18044},
	{"JN01", 4, 18045},
	{"JN02", 4, 18046},
	{"JN03", 4, 18047},
	{"JN04", 4, 18048},
	{"JN05", 4, 18049},
	{"JN06", 4, 18050},
	{"JN07", 4, 18051},
	{"JN08", 4, 18052},
	{"JN09", 4, 18053},
	{"JN10", 4, 18054},
	{"JN11", 4, 18055},
	{"JN12", 4, 18056},
	{"JN13", 4, 18057},
	{"JN14", 4, 18058},
	{"JN15", 4, 18059},
	{"JN16", 4, 18060},
	{"JN17", 4, 18061},
	{"JN18", 4, 18062},
	{"JN19", 4, 18063},
	{"JN20", 4, 18064},
	{"JN21", 4, 18065},
	{"JN22", 4, 18066},
	{"JN23", 4, 18067},
	{"JN24", 4, 18068},
	{"JN25", 4, 18069},
	{"JN26", 4, 18070},
	{"JN27", 4, 18071},
	{"JN28", 4, 18072},
	{"JN29", 4, 18073},
	{"JN30", 4, 18074},
	{"JN31", 4, 18075},
	{"JN32", 4, 18076},
	{"JN33", 4, 18077},
	{"JN34", 4, 18078},
	{"JN35", 4, 18079},
	{"JN36", 4, 18080},
	{"JN37", 4, 18081},
	{"JN38", 4, 18082},
	{"JN39", 4, 18083},
	{"JN40", 4, 18084},
	{"JN41", 4, 18085},
	{"JN42", 4, 18086},
	{"JN43", 4, 18087},
	{"JN44", 4, 18088},
	{"JN45", 4, 18089},
	{"JN46", 4, 18090},
	{"JN47", 4, 18091},
	{"JN48", 4, 18092},
	{"JN49", 4, 18093},
	{"JN50", 4, 18094},
	{"JN51", 4, 18095},
	{"JN52", 4, 18096},
	{"JN53", 4, 18097},
	{"JN54", 4, 18098},
	{"JN55", 4, 18099},
	{"JN56", 4, 18100},
	{"JN57", 4, 18101},
	{"JN58", 4, 18102},
	{"JN59", 4, 18103},
	{"JN60", 4, 18104},
	{"JN61", 4, 18105},
	{"JN62", 4, 18106},
	{"JN63", 4, 18107},
	{"JN64", 4, 18108},
	{"JN65", 4, 18109},
	{"JN66", 4, 18110},
	{"JN67", 4, 18111},
	{"JN68", 4, 18112},
	{"JN69", 4, 18113},
	{"JN70", 4, 18114},
	{"JN71", 4, 18115},
	{"JN72", 4, 18116},
	{"JN73", 4, 18117},
	{"JN74", 4, 18118},
	{"JN75", 4, 18119},
	{"JN76", 4, 18120},
	{"JN77", 4, 18121},
	{"JN78", 4, 18122},
	{"JN79", 4, 18123},
	{"JN80", 4, 18124},
	{"JN81", 4, 18125},
	{"JN82", 4, 18126},
	{"JN83", 4, 18127},
	{"JN84", 4, 18128},
	{"JN85", 4, 18129},
	{"JN86", 4, 18130},
	{"JN87", 4, 18131},
	{"JN88", 4, 18132},
	{"JN89", 4, 18133},
	{"JN90", 4, 18134},
	{"JN91", 4, 18135},
	{"JN92", 4, 18136},
	{"JN93", 4, 18137},
	{"JN94", 4, 18138},
	{"JN95", 4, 18139},
	{"JN96", 4, 18140},
	{"JN97", 4, 18141},
	{"JN98", 4, 18142},
	{"JN99", 4, 18143},
	{"JO00", 4, 18144},
	{"JO01", 4, 18145},
	{"JO02", 4, 18146},
	{"JO03", 4, 18147},
	{"JO04", 4, 18148},
	{"JO05", 4, 18149},
	{"JO06", 4, 18150},
	{"JO07", 4, 18151},
	{"JO08", 4, 18152},
	{"JO09", 4, 18153},
	{"JO10", 4, 18154},
	{"JO11", 4, 18155},
	{"JO12", 4, 18156},
	{"JO13", 4, 18157},
	{"JO14", 4, 18158},
	{"JO15", 4, 18159},
	{"JO16", 4, 18160},
	{"JO17", 4, 18161},
	{"JO18", 4, 18162},
	{"JO19", 4, 18163},
	{"JO20", 4, 18164},
	{"JO21", 4, 18165},
	{"JO22", 4, 18166},
	{"JO23", 4, 18167},
	{"JO24", 4, 18168},
	{"JO25", 4, 18169},
	{"JO26", 4, 18170},
	{"JO27", 4, 18171},
	{"JO28", 4, 18172},
	{"JO29", 4, 18173},
	{"JO30", 4, 18174},
	{"JO31", 4, 18175},
	{"JO32", 4, 18176},
	{"JO33", 4, 18177},
	{"JO34", 4, 18178},
	{"JO35", 4, 18179},
	{"JO36", 4, 18180},
	{"JO37", 4, 18181},
	{"JO38", 4, 18182},
	{"JO39", 4, 18183},
	{"JO40", 4, 18184},
	{"JO41", 4, 18185},
	{"JO42", 4, 18186},
	{"JO43", 4, 18187},
	{"JO44", 4, 18188},
	{"JO45", 4, 18189},
	{"JO46", 4, 18190},
	{"JO47", 4, 18191},
	{"JO48", 4, 18192},
	{"JO49", 4, 18193},
	{"JO50", 4, 18194},
	{"JO51", 4, 18195},
	{"JO52", 4, 18196},
	{"JO53", 4, 18197},
	{"JO54", 4, 18198},
	{"JO55", 4, 18199},
	{"JO56", 4, 18200},
	{"JO57", 4, 18201},
	{"JO58", 4, 18202},
	{"JO59", 4, 18203},
	{"JO60", 4, 18204},
	{"JO61", 4, 18205},
	{"JO62", 4, 18206},
	{"JO63", 4, 18207},
	{"JO64", 4, 18208},
	{"JO65", 4, 18209},
	{"JO66", 4, 18210},
	{"JO67", 4, 18211},
	{"JO68", 4, 18212},
	{"JO69", 4, 18213},
	{"JO70", 4, 18214},
	{"JO71", 4, 18215},
	{"JO72", 4, 18216},
	{"JO73", 4, 18217},
	{"JO74", 4, 18218},
	{"JO75", 4, 18219},
	{"JO76", 4, 18220},
	{"JO77", 4, 18221},
	{"JO78", 4, 18222},
	{"JO79", 4, 18223},
	{"JO80", 4, 18224},
	{"JO81", 4, 18225},
	{"JO82", 4, 18226},
	{"JO83", 4, 18227},
	{"JO84", 4, 18228},
	{"JO85", 4, 18229},
	{"JO86", 4, 18230},
	{"JO87", 4, 18231},
	{"JO88", 4, 18232},
	{"JO89", 4, 18233},
	{"JO90", 4, 18234},
	{"JO91", 4, 18235},
	{"JO92", 4, 18236},
	{"JO93", 4, 18237},
	{"JO94", 4, 18238},
	{"JO95", 4, 18239},
	{"JO96", 4, 18240},
	{"JO97", 4, 18241},
	{"JO98", 4, 18242},
	{"JO99", 4, 18243},
	{"JP00", 4, 18244},
	{"JP01", 4, 18245},
	{"JP02", 4, 18246},
	{"JP03", 4, 18247},
	{"JP04", 4, 18248},
	{"JP05", 4, 18249},
	{"JP06", 4, 18250},
	{"JP07", 4, 18251},
	{"JP08", 4, 18252},
	{"JP09", 4, 18253},
	{"JP10", 4, 18254},
	{"JP11", 4, 18255},
	{"JP12", 4, 18256},
	{"JP13", 4, 18257},
	{"JP14", 4, 18258},
	{"JP15", 4, 18259},
	{"JP16", 4, 18260},
	{"JP17", 4, 18261},
	{"JP18", 4, 18262},
	{"JP19", 4, 18263},
	{"JP20", 4, 18264},
	{"JP21", 4, 18265},
	{"JP22", 4, 18266},
	{"JP23", 4, 18267},
	{"JP24", 4, 18268},
	{"JP25", 4, 18269},
	{"JP26", 4, 18270},
	{"JP27", 4, 18271},
	{"JP28", 4, 18272},
	{"JP29", 4, 18273},
	{"JP30", 4, 18274},
	{"JP31", 4, 18275},
	{"JP32", 4, 18276},
	{"JP33", 4, 18277},
	{"JP34", 4, 18278},
	{"JP35", 4, 18279},
	{"JP36", 4, 18280},
	{"JP37", 4, 18281},
	{"JP38", 4, 18282},
	{"JP39", 4, 18283},
	{"JP40", 4, 18284},
	{"JP41", 4, 18285},
	{"JP42", 4, 18286},
	{"JP43", 4, 18287},
	{"JP44", 4, 18288},
	{"JP45", 4, 18289},
	{"JP46", 4, 18290},
	{"JP47", 4, 18291},
	{"JP48", 4, 18292},
	{"JP49", 4, 18293},
	{"JP50", 4, 18294},
	{"JP51", 4, 18295},
	{"JP52", 4, 18296},
	{"JP53", 4, 18297},
	{"JP54", 4, 18298},
	{"JP55", 4, 18299},
	{"JP56", 4, 18300},
	{"JP57", 4, 18301},
	{"JP58", 4, 18302},
	{"JP59", 4, 18303},
	{"JP60", 4, 18304},
	{"JP61", 4, 18305},
	{"JP62", 4, 18306},
	{"JP63", 4, 18307},
	{"JP64", 4, 18308},
	{"JP65", 4, 18309},
	{"JP66", 4, 18310},
	{"JP67", 4, 18311},
	{"JP68", 4, 18312},
	{"JP69", 4, 18313},
	{"JP70", 4, 18314},
	{"JP71", 4, 18315},
	{"JP72", 4, 18316},
	{"JP73", 4, 18317},
	{"JP74", 4, 18318},
	{"JP75", 4, 18319},
	{"JP76", 4, 18320},
	{"JP77", 4, 18321},
	{"JP78", 4, 18322},
	{"JP79", 4, 18323},
	{"JP80", 4, 18324},
	{"JP81", 4, 18325},
	{"JP82", 4, 18326},
	{"JP83", 4, 18327},
	{"JP84", 4, 18328},
	{"JP85", 4, 18329},
	{"JP86", 4, 18330},
	{"JP87", 4, 18331},
	{"JP88", 4, 18332},
	{"JP89", 4, 18333},
	{"JP90", 4, 18334},
	{"JP91", 4, 18335},
	{"JP92", 4, 18336},
	{"JP93", 4, 18337},
	{"JP94", 4, 18338},
	{"JP95", 4, 18339},
	{"JP96", 4, 18340},
	{"JP97", 4, 18341},
	{"JP98", 4, 18342},
	{"JP99", 4, 18343},
	{"JQ00", 4, 18344},
	{"JQ01", 4, 18345},
	{"JQ02", 4, 18346},
	{"JQ03", 4, 18347},
	{"JQ04", 4, 18348},
	{"JQ05", 4, 18349},
	{"JQ06", 4, 18350},
	{"JQ07", 4, 18351},
	{"JQ08", 4, 18352},
	{"JQ09", 4, 18353},
	{"JQ10", 4, 18354},
	{"JQ11", 4, 18355},
	{"JQ12", 4, 18356},
	{"JQ13", 4, 18357},
	{"JQ14", 4, 18358},
	{"JQ15", 4, 18359},
	{"JQ16", 4, 18360},
	{"JQ17", 4, 18361},
	{"JQ18", 4, 18362},
	{"JQ19", 4, 18363},
	{"JQ20", 4, 18364},
	{"JQ21", 4, 18365},
	{"JQ22", 4, 18366},
	{"JQ23", 4, 18367},
	{"JQ24", 4, 18368},
	{"JQ25", 4, 18369},
	{"JQ26", 4, 18370},
	{"JQ27", 4, 18371},
	{"JQ28", 4, 18372},
	{"JQ29", 4, 18373},
	{"JQ30", 4, 18374},
	{"JQ31", 4, 18375},
	{"JQ32", 4, 18376},
	{"JQ33", 4, 18377},
	{"JQ34", 4, 18378},
	{"JQ35", 4, 18379},
	{"JQ36", 4, 18380},
	{"JQ37", 4, 18381},
	{"JQ38", 4, 18382},
	{"JQ39", 4, 18383},
	{"JQ40", 4, 18384},
	{"JQ41", 4, 18385},
	{"JQ42", 4, 18386},
	{"JQ43", 4, 18387},
	{"JQ44", 4, 18388},
	{"JQ45", 4, 18389},
	{"JQ46", 4, 18390},
	{"JQ47", 4, 18391},
	{"JQ48", 4, 18392},
	{"JQ49", 4, 18393},
	{"JQ50", 4, 18394},
	{"JQ51", 4, 18395},
	{"JQ52", 4, 18396},
	{"JQ53", 4, 18397},
	{"JQ54", 4, 18398},
	{"JQ55", 4, 18399},
	{"JQ56", 4, 18400},
	{"JQ57", 4, 18401},
	{"JQ58", 4, 18402},
	{"JQ59", 4, 18403},
	{"JQ60", 4, 18404},
	{"JQ61", 4, 18405},
	{"JQ62", 4, 18406},
	{"JQ63", 4, 18407},
	{"JQ64", 4, 18408},
	{"JQ65", 4, 18409},
	{"JQ66", 4, 18410},
	{"JQ67", 4, 18411},
	{"JQ68", 4, 18412},
	{"JQ69", 4, 18413},
	{"JQ70", 4, 18414},
	{"JQ71", 4, 18415},
	{"JQ72", 4, 18416},
	{"JQ73", 4, 18417},
	{"JQ74", 4, 18418},
	{"JQ75", 4, 18419},
	{"JQ76", 4, 18420},
	{"JQ77", 4, 18421},
	{"JQ78", 4, 18422},
	{"JQ79", 4, 18423},
	{"JQ80", 4, 18424},
	{"JQ81", 4, 18425},
	{"JQ82", 4, 18426},
	{"JQ83", 4, 18427},
	{"JQ84", 4, 18428},
	{"JQ85", 4, 18429},
	{"JQ86", 4, 18430},
	{"JQ87", 4, 18431},
	{"JQ88", 4, 18432},
	{"JQ89", 4, 18433},
	{"JQ90", 4, 18434},
	{"JQ91", 4, 18435},
	{"JQ92", 4, 18436},
	{"JQ93", 4, 18437},
	{"JQ94", 4, 18438},
	{"JQ95", 4, 18439},
	{"JQ96", 4, 18440},
	{"JQ97", 4, 18441},
	{"JQ98", 4, 18442},
	{"JQ99", 4, 18443},
	{"KB00", 4, 18444},
	{"KB01", 4, 18445},
	{"KB02", 4, 18446},
	{"KB03", 4, 18447},
	{"KB04", 4, 18448},
	{"KB05", 4, 18449},
	{"KB06", 4, 18450},
	{"KB07", 4, 18451},
	{"KB08", 4, 18452},
	{"KB09", 4, 18453},
	{"KB10", 4, 18454},
	{"KB11", 4, 18455},
	{"KB12", 4, 18456},
	{"KB13", 4, 18457},
	{"KB14", 4, 18458},
	{"KB15", 4, 18459},
	{"KB16", 4, 18460},
	{"KB17", 4, 18461},
	{"KB18", 4, 18462},
	{"KB19", 4, 18463},
	{"KB20", 4, 18464},
	{"KB21", 4, 18465},
	{"KB22", 4, 18466},
	{"KB23", 4, 18467},
	{"KB24", 4, 18468},
	{"KB25", 4, 18469},
	{"KB26", 4, 18470},
	{"KB27", 4, 18471},
	{"KB28", 4, 18472},
	{"KB29", 4, 18473},
	{"KB30", 4, 18474},
	{"KB31", 4, 18475},
	{"KB32", 4, 18476},
	{"KB33", 4, 18477},
	{"KB34", 4, 18478},
	{"KB35", 4, 18479},
	{"KB36", 4, 18480},
	{"KB37", 4, 18481},
	{"KB38", 4, 18482},
	{"KB39", 4, 18483},
	{"KB40", 4, 18484},
	{"KB41", 4, 18485},
	{"KB42", 4, 18486},
	{"KB43", 4, 18487},
	{"KB44", 4, 18488},
	{"KB45", 4, 18489},
	{"KB46", 4, 18490},
	{"KB47", 4, 18491},
	{"KB48", 4, 18492},
	{"KB49", 4, 18493},
	{"KB50", 4, 18494},
	{"KB51", 4, 18495},
	{"KB52", 4, 18496},
	{"KB53", 4, 18497},
	{"KB54", 4, 18498},
	{"KB55", 4, 18499},
	{"KB56", 4, 18500},
	{"KB57", 4, 18501},
	{"KB58", 4, 18502},
	{"KB59", 4, 18503},
	{"KB60", 4, 18504},
	{"KB61", 4, 18505},
	{"KB62", 4, 18506},
	{"KB63", 4, 18507},
	{"KB64", 4, 18508},
	{"KB65", 4, 18509},
	{"KB66", 4, 18510},
	{"KB67", 4, 18511},
	{"KB68", 4, 18512},
	{"KB69", 4, 18513},
	{"KB70", 4, 18514},
	{"KB71", 4, 18515},
	{"KB72", 4, 18516},
	{"KB73", 4, 18517},
	{"KB74", 4, 18518},
	{"KB75", 4, 18519},
	{"KB76", 4, 18520},
	{"KB77", 4, 18521},
	{"KB78", 4, 18522},
	{"KB79", 4, 18523},
	{"KB80", 4, 18524},
	{"KB81", 4, 18525},
	{"KB82", 4, 18526},
	{"KB83", 4, 18527},
	{"KB84", 4, 18528},
	{"KB85", 4, 18529},
	{"KB86", 4, 18530},
	{"KB87", 4, 18531},
	{"KB88", 4, 18532},
	{"KB89", 4, 18533},
	{"KB90", 4, 18534},
	{"KB91", 4, 18535},
	{"KB92", 4, 18536},
	{"KB93", 4, 18537},
	{"KB94", 4, 18538},
	{"KB95", 4, 18539},
	{"KB96", 4, 18540},
	{"KB97", 4, 18541},
	{"KB98", 4, 18542},
	{"KB99", 4, 18543},
	{"KC00", 4, 18544},
	{"KC01", 4, 18545},
	{"KC02", 4, 18546},
	{"KC03", 4, 18547},
	{"KC04", 4, 18548},
	{"KC05", 4, 18549},
	{"KC06", 4, 18550},
	{"KC07", 4, 18551},
	{"KC08", 4, 18552},
	{"KC09", 4, 18553},
	{"KC10", 4, 18554},
	{"KC11", 4, 18555},
	{"KC12", 4, 18556},
	{"KC13", 4, 18557},
	{"KC14", 4, 18558},
	{"KC15", 4, 18559},
	{"KC16", 4, 18560},
	{"KC17", 4, 18561},
	{"KC18", 4, 18562},
	{"KC19", 4, 18563},
	{"KC20", 4, 18564},
	{"KC21", 4, 18565},
	{"KC22", 4, 18566},
	{"KC23", 4, 18567},
	{"KC24", 4, 18568},
	{"KC25", 4, 18569},
	{"KC26", 4, 18570},
	{"KC27", 4, 18571},
	{"KC28", 4, 18572},
	{"KC29", 4, 18573},
	{"KC30", 4, 18574},
	{"KC31", 4, 18575},
	{"KC32", 4, 18576},
	{"KC33", 4, 18577},
	{"KC34", 4, 18578},
	{"KC35", 4, 18579},
	{"KC36", 4, 18580},
	{"KC37", 4, 18581},
	{"KC38", 4, 18582},
	{"KC39", 4, 18583},
	{"KC40", 4, 18584},
	{"KC41", 4, 18585},
	{"KC42", 4, 18586},
	{"KC43", 4, 18587},
	{"KC44", 4, 18588},
	{"KC45", 4, 18589},
	{"KC46", 4, 18590},
	{"KC47", 4, 18591},
	{"KC48", 4, 18592},
	{"KC49", 4, 18593},
	{"KC50", 4, 18594},
	{"KC51", 4, 18595},
	{"KC52", 4, 18596},
	{"KC53", 4, 18597},
	{"KC54", 4, 18598},
	{"KC55", 4, 18599},
	{"KC56", 4, 18600},
	{"KC57", 4, 18601},
	{"KC58", 4, 18602},
	{"KC59", 4, 18603},
	{"KC60", 4, 18604},
	{"KC61", 4, 18605},
	{"KC62", 4, 18606},
	{"KC63", 4, 18607},
	{"KC64", 4, 18608},
	{"KC65", 4, 18609},
	{"KC66", 4, 18610},
	{"KC67", 4, 18611},
	{"KC68", 4, 18612},
	{"KC69", 4, 18613},
	{"KC70", 4, 18614},
	{"KC71", 4, 18615},
	{"KC72", 4, 18616},
	{"KC73", 4, 18617},
	{"KC74", 4, 18618},
	{"KC75", 4, 18619},
	{"KC76", 4, 18620},
	{"KC77", 4, 18621},
	{"KC78", 4, 18622},
	{"KC79", 4, 18623},
	{"KC80", 4, 18624},
	{"KC81", 4, 18625},
	{"KC82", 4, 18626},
	{"KC83", 4, 18627},
	{"KC84", 4, 18628},
	{"KC85", 4, 18629},
	{"KC86", 4, 18630},
	{"KC87", 4, 18631},
	{"KC88", 4, 18632},
	{"KC89", 4, 18633},
	{"KC90", 4, 18634},
	{"KC91", 4, 18635},
	{"KC92", 4, 18636},
	{"KC93", 4, 18637},
	{"KC94", 4, 18638},
	{"KC95", 4, 18639},
	{"KC96", 4, 18640},
	{"KC97", 4, 18641},
	{"KC98", 4, 18642},
	{"KC99", 4, 18643},
	{"KF00", 4, 18644},
	{"KF01", 4, 18645},
	{"KF02", 4, 18646},
	{"KF03", 4, 18647},
	{"KF04", 4, 18648},
	{"KF05", 4, 18649},
	{"KF06", 4, 18650},
	{"KF07", 4, 18651},
	{"KF08", 4, 18652},
	{"KF09", 4, 18653},
	{"KF10", 4, 18654},
	{"KF11", 4, 18655},
	{"KF12", 4, 18656},
	{"KF13", 4, 18657},
	{"KF14", 4, 18658},
	{"KF15", 4, 18659},
	{"KF16", 4, 18660},
	{"KF17", 4, 18661},
	{"KF18", 4, 18662},
	{"KF19", 4, 18663},
	{"KF20", 4, 18664},
	{"KF21", 4, 18665},
	{"KF22", 4, 18666},
	{"KF23", 4, 18667},
	{"KF24", 4, 18668},
	{"KF25", 4, 18669},
	{"KF26", 4, 18670},
	{"KF27", 4, 18671},
	{"KF28", 4, 18672},
	{"KF29", 4, 18673},
	{"KF30", 4, 18674},
	{"KF31", 4, 18675},
	{"KF32", 4, 18676},
	{"KF33", 4, 18677},
	{"KF34", 4, 18678},
	{"KF35", 4, 18679},
	{"KF36", 4, 18680},
	{"KF37", 4, 18681},
	{"KF38", 4, 18682},
	{"KF39", 4, 18683},
	{"KF40", 4, 18684},
	{"KF41", 4, 18685},
	{"KF42", 4, 18686},
	{"KF43", 4, 18687},
	{"KF44", 4, 18688},
	{"KF45", 4, 18689},
	{"KF46", 4, 18690},
	{"KF47", 4, 18691},
	{"KF48", 4, 18692},
	{"KF49", 4, 18693},
	{"KF50", 4, 18694},
	{"KF51", 4, 18695},
	{"KF52", 4, 18696},
	{"KF53", 4, 18697},
	{"KF54", 4, 18698},
	{"KF55", 4, 18699},
	{"KF56", 4, 18700},
	{"KF57", 4, 18701},
	{"KF58", 4, 18702},
	{"KF59", 4, 18703},
	{"KF60", 4, 18704},
	{"KF61", 4, 18705},
	{"KF62", 4, 18706},
	{"KF63", 4, 18707},
	{"KF64", 4, 18708},
	{"KF65", 4, 18709},
	{"KF66", 4, 18710},
	{"KF67", 4, 18711},
	{"KF68", 4, 18712},
	{"KF69", 4, 18713},
	{"KF70", 4, 18714},
	{"KF71", 4, 18715},
	{"KF72", 4, 18716},
	{"KF73", 4, 18717},
	{"KF74", 4, 18718},
	{"KF75", 4, 18719},
	{"KF76", 4, 18720},
	{"KF77", 4, 18721},
	{"KF78", 4, 18722},
	{"KF79", 4, 18723},
	{"KF80", 4, 18724},
	{"KF81", 4, 18725},
	{"KF82", 4, 18726},
	{"KF83", 4, 18727},
	{"KF84", 4, 18728},
	{"KF85", 4, 18729},
	{"KF86", 4, 18730},
	{"KF87", 4, 18731},
	{"KF88", 4, 18732},
	{"KF89", 4, 18733},
	{"KF90", 4, 18734},
	{"KF91", 4, 18735},
	{"KF92", 4, 18736},
	{"KF93", 4, 18737},
	{"KF94", 4, 18738},
	{"KF95", 4, 18739},
	{"KF96", 4, 18740},
	{"KF97", 4, 18741},
	{"KF98", 4, 18742},
	{"KF99", 4, 18743},
	{"KG00", 4, 18744},
	{"KG01", 4, 18745},
	{"KG02", 4, 18746},
	{"KG03", 4, 18747},
	{"KG04", 4, 18748},
	{"KG05", 4, 18749},
	{"KG06", 4, 18750},
	{"KG07", 4, 18751},
	{"KG08", 4, 18752},
	{"KG09", 4, 18753},
	{"KG10", 4, 18754},
	{"KG11", 4, 18755},
	{"KG12", 4, 18756},
	{"KG13", 4, 18757},
	{"KG14", 4, 18758},
	{"KG15", 4, 18759},
	{"KG16", 4, 18760},
	{"KG17", 4, 18761},
	{"KG18", 4, 18762},
	{"KG19", 4, 18763},
	{"KG20", 4, 18764},
	{"KG21", 4, 18765},
	{"KG22", 4, 18766},
	{"KG23", 4, 18767},
	{"KG24", 4, 18768},
	{"KG25", 4, 18769},
	{"KG26", 4, 18770},
	{"KG27", 4, 18771},
	{"KG28", 4, 18772},
	{"KG29", 4, 18773},
	{"KG30", 4, 18774},
	{"KG31", 4, 18775},
	{"KG32", 4, 18776},
	{"KG33", 4, 18777},
	{"KG34", 4, 18778},
	{"KG35", 4, 18779},
	{"KG36", 4, 18780},
	{"KG37", 4, 18781},
	{"KG38", 4, 18782},
	{"KG39", 4, 18783},
	{"KG40", 4, 18784},
	{"KG41", 4, 18785},
	{"KG42", 4, 18786},
	{"KG43", 4, 18787},
	{"KG44", 4, 18788},
	{"KG45", 4, 18789},
	{"KG46", 4, 18790},
	{"KG47", 4, 18791},
	{"KG48", 4, 18792},
	{"KG49", 4, 18793},
	{"KG50", 4, 18794},
	{"KG51", 4, 18795},
	{"KG52", 4, 18796},
	{"KG53", 4, 18797},
	{"KG54", 4, 18798},
	{"KG55", 4, 18799},
	{"KG56", 4, 18800},
	{"KG57", 4, 18801},
	{"KG58", 4, 18802},
	{"KG59", 4, 18803},
	{"KG60", 4, 18804},
	{"KG61", 4, 18805},
	{"KG62", 4, 18806},
	{"KG63", 4, 18807},
	{"KG64", 4, 18808},
	{"KG65", 4, 18809},
	{"KG66", 4, 18810},
	{"KG67", 4, 18811},
	{"KG68", 4, 18812},
	{"KG69", 4, 18813},
	{"KG70", 4, 18814},
	{"KG71", 4, 18815},
	{"KG72", 4, 18816},
	{"KG73", 4, 18817},
	{"KG74", 4, 18818},
	{"KG75", 4, 18819},
	{"KG76", 4, 18820},
	{"KG77", 4, 18821},
	{"KG78", 4, 18822},
	{"KG79", 4, 18823},
	{"KG80", 4, 18824},
	{"KG81", 4, 18825},
	{"KG82", 4, 18826},
	{"KG83", 4, 18827},
	{"KG84", 4, 18828},
	{"KG85", 4, 18829},
	{"KG86", 4, 18830},
	{"KG87", 4, 18831},
	{"KG88", 4, 18832},
	{"KG89", 4, 18833},
	{"KG90", 4, 18834},
	{"KG91", 4, 18835},
	{"KG92", 4, 18836},
	{"KG93", 4, 18837},
	{"KG94", 4, 18838},
	{"KG95", 4, 18839},
	{"KG96", 4, 18840},
	{"KG97", 4, 18841},
	{"KG98", 4, 18842},
	{"KG99", 4, 18843},
	{"KH00", 4, 18844},
	{"KH01", 4, 18845},
	{"KH02", 4, 18846},
	{"KH03", 4, 18847},
	{"KH04", 4, 18848},
	{"KH05", 4, 18849},
	{"KH06", 4, 18850},
	{"KH07", 4, 18851},
	{"KH08", 4, 18852},
	{"KH09", 4, 18853},
	{"KH10", 4, 18854},
	{"KH11", 4, 18855},
	{"KH12", 4, 18856},
	{"KH13", 4, 18857},
	{"KH14", 4, 18858},
	{"KH15", 4, 18859},
	{"KH16", 4, 18860},
	{"KH17", 4, 18861},
	{"KH18", 4, 18862},
	{"KH19", 4, 18863},
	{"KH20", 4, 18864},
	{"KH21", 4, 18865},
	{"KH22", 4, 18866},
	{"KH23", 4, 18867},
	{"KH24", 4, 18868},
	{"KH25", 4, 18869},
	{"KH26", 4, 18870},
	{"KH27", 4, 18871},
	{"KH28", 4, 18872},
	{"KH29", 4, 18873},
	{"KH30", 4, 18874},
	{"KH31", 4, 18875},
	{"KH32", 4, 18876},
	{"KH33", 4, 18877},
	{"KH34", 4, 18878},
	{"KH35", 4, 18879},
	{"KH36", 4, 18880},
	{"KH37", 4, 18881},
	{"KH38", 4, 18882},
	{"KH39", 4, 18883},
	{"KH40", 4, 18884},
	{"KH41", 4, 18885},
	{"KH42", 4, 18886},
	{"KH43", 4, 18887},
	{"KH44", 4, 18888},
	{"KH45", 4, 18889},
	{"KH46", 4, 18890},
	{"KH47", 4, 18891},
	{"KH48", 4, 18892},
	{"KH49", 4, 18893},
	{"KH50", 4, 18894},
	{"KH51", 4, 18895},
	{"KH52", 4, 18896},
	{"KH53", 4, 18897},
	{"KH54", 4, 18898},
	{"KH55", 4, 18899},
	{"KH56", 4, 18900},
	{"KH57", 4, 18901},
	{"KH58", 4, 18902},
	{"KH59", 4, 18903},
	{"KH60", 4, 18904},
	{"KH61", 4, 18905},
	{"KH62", 4, 18906},
	{"KH63", 4, 18907},
	{"KH64", 4, 18908},
	{"KH65", 4, 18909},
	{"KH66", 4, 18910},
	{"KH67", 4, 18911},
	{"KH68", 4, 18912},
	{"KH69", 4, 18913},
	{"KH70", 4, 18914},
	{"KH71", 4, 18915},
	{"KH72", 4, 18916},
	{"KH73", 4, 18917},
	{"KH74", 4, 18918},
	{"KH75", 4, 18919},
	{"KH76", 4, 18920},
	{"KH77", 4, 18921},
	{"KH78", 4, 18922},
	{"KH79", 4, 18923},
	{"KH80", 4, 18924},
	{"KH81", 4, 18925},
	{"KH82", 4, 18926},
	{"KH83", 4, 18927},
	{"KH84", 4, 18928},
	{"KH85", 4, 18929},
	{"KH86", 4, 18930},
	{"KH87", 4, 18931},
	{"KH88", 4, 18932},
	{"KH89", 4, 18933},
	{"KH90", 4, 18934},
	{"KH91", 4, 18935},
	{"KH92", 4, 18936},
	{"KH93", 4, 18937},
	{"KH94", 4, 18938},
	{"KH95", 4, 18939},
	{"KH96", 4, 18940},
	{"KH97", 4, 18941},
	{"KH98", 4, 18942},
	{"KH99", 4, 18943},
	{"KI00", 4, 18944},
	{"KI01", 4, 18945},
	{"KI02", 4, 18946},
	{"KI03", 4, 18947},
	{"KI04", 4, 18948},
	{"KI05", 4, 18949},
	{"KI06", 4, 18950},
	{"KI07", 4, 18951},
	{"KI08", 4, 18952},
	{"KI09", 4, 18953},
	{"KI10", 4, 18954},
	{"KI11", 4, 18955},
	{"KI12", 4, 18956},
	{"KI13", 4, 18957},
	{"KI14", 4, 18958},
	{"KI15", 4, 18959},
	{"KI16", 4, 18960},
	{"KI17", 4, 18961},
	{"KI18", 4, 18962},
	{"KI19", 4, 18963},
	{"KI20", 4, 18964},
	{"KI21", 4, 18965},
	{"KI22", 4, 18966},
	{"KI23", 4, 18967},
	{"KI24", 4, 18968},
	{"KI25", 4, 18969},
	{"KI26", 4, 18970},
	{"KI27", 4, 18971},
	{"KI28", 4, 18972},
	{"KI29", 4, 18973},
	{"KI30", 4, 18974},
	{"KI31", 4, 18975},
	{"KI32", 4, 18976},
	{"KI33", 4, 18977},
	{"KI34", 4, 18978},
	{"KI35", 4, 18979},
	{"KI36", 4, 18980},
	{"KI37", 4, 18981},
	{"KI38", 4, 18982},
	{"KI39", 4, 18983},
	{"KI40", 4, 18984},
	{"KI41", 4, 18985},
	{"KI42", 4, 18986},
	{"KI43", 4, 18987},
	{"KI44", 4, 18988},
	{"KI45", 4, 18989},
	{"KI46", 4, 18990},
	{"KI47", 4, 18991},
	{"KI48", 4, 18992},
	{"KI49", 4, 18993},
	{"KI50", 4, 18994},
	{"KI51", 4, 18995},
	{"KI52", 4, 18996},
	{"KI53", 4, 18997},
	{"KI54", 4, 18998},
	{"KI55", 4, 18999},
	{"KI56", 4, 19000},
	{"KI57", 4, 19001},
	{"KI58", 4, 19002},
	{"KI59", 4, 19003},
	{"KI60", 4, 19004},
	{"KI61", 4, 19005},
	{"KI62", 4, 19006},
	{"KI63", 4, 19007},
	{"KI64", 4, 19008},
	{"KI65", 4, 19009},
	{"KI66", 4, 19010},
	{"KI67", 4, 19011},
	{"KI68", 4, 19012},
	{"KI69", 4, 19013},
	{"KI70", 4, 19014},
	{"KI71", 4, 19015},
	{"KI72", 4, 19016},
	{"KI73", 4, 19017},
	{"KI74", 4, 19018},
	{"KI75", 4, 19019},
	{"KI76", 4, 19020},
	{"KI77", 4, 19021},
	{"KI78", 4, 19022},
	{"KI79", 4, 19023},
	{"KI80", 4, 19024},
	{"KI81", 4, 19025},
	{"KI82", 4, 19026},
	{"KI83", 4, 19027},
	{"KI84", 4, 19028},
	{"KI85", 4, 19029},
	{"KI86", 4, 19030},
	{"KI87", 4, 19031},
	{"KI88", 4, 19032},
	{"KI89", 4, 19033},
	{"KI90", 4, 19034},
	{"KI91", 4, 19035},
	{"KI92", 4, 19036},
	{"KI93", 4, 19037},
	{"KI94", 4, 19038},
	{"KI95", 4, 19039},
	{"KI96", 4, 19040},
	{"KI97", 4, 19041},
	{"KI98", 4, 19042},
	{"KI99", 4, 19043},
	{"KJ00", 4, 19044},
	{"KJ01", 4, 19045},
	{"KJ02", 4, 19046},
	{"KJ03", 4, 19047},
	{"KJ04", 4, 19048},
	{"KJ05", 4, 19049},
	{"KJ06", 4, 19050},
	{"KJ07", 4, 19051},
	{"KJ08", 4, 19052},
	{"KJ09", 4, 19053},
	{"KJ10", 4, 19054},
	{"KJ11", 4, 19055},
	{"KJ12", 4, 19056},
	{"KJ13", 4, 19057},
	{"KJ14", 4, 19058},
	{"KJ15", 4, 19059},
	{"KJ16", 4, 19060},
	{"KJ17", 4, 19061},
	{"KJ18", 4, 19062},
	{"KJ19", 4, 19063},
	{"KJ20", 4, 19064},
	{"KJ21", 4, 19065},
	{"KJ22", 4, 19066},
	{"KJ23", 4, 19067},
	{"KJ24", 4, 19068},
	{"KJ25", 4, 19069},
	{"KJ26", 4, 19070},
	{"KJ27", 4, 19071},
	{"KJ28", 4, 19072},
	{"KJ29", 4, 19073},
	{"KJ30", 4, 19074},
	{"KJ31", 4, 19075},
	{"KJ32", 4, 19076},
	{"KJ33", 4, 19077},
	{"KJ34", 4, 19078},
	{"KJ35", 4, 19079},
	{"KJ36", 4, 19080},
	{"KJ37", 4, 19081},
	{"KJ38", 4, 19082},
	{"KJ39", 4, 19083},
	{"KJ40", 4, 19084},
	{"KJ41", 4, 19085},
	{"KJ42", 4, 19086},
	{"KJ43", 4, 19087},
	{"KJ44", 4, 19088},
	{"KJ45", 4, 19089},
	{"KJ46", 4, 19090},
	{"KJ47", 4, 19091},
	{"KJ48", 4, 19092},
	{"KJ49", 4, 19093},
	{"KJ50", 4, 19094},
	{"KJ51", 4, 19095},
	{"KJ52", 4, 19096},
	{"KJ53", 4, 19097},
	{"KJ54", 4, 19098},
	{"KJ55", 4, 19099},
	{"KJ56", 4, 19100},
	{"KJ57", 4, 19101},
	{"KJ58", 4, 19102},
	{"KJ59", 4, 19103},
	{"KJ60", 4, 19104},
	{"KJ61", 4, 19105},
	{"KJ62", 4, 19106},
	{"KJ63", 4, 19107},
	{"KJ64", 4, 19108},
	{"KJ65", 4, 19109},
	{"KJ66", 4, 19110},
	{"KJ67", 4, 19111},
	{"KJ68", 4, 19112},
	{"KJ69", 4, 19113},
	{"KJ70", 4, 19114},
	{"KJ71", 4, 19115},
	{"KJ72", 4, 19116},
	{"KJ73", 4, 19117},
	{"KJ74", 4, 19118},
	{"KJ75", 4, 19119},
	{"KJ76", 4, 19120},
	{"KJ77", 4, 19121},
	{"KJ78", 4, 19122},
	{"KJ79", 4, 19123},
	{"KJ80", 4, 19124},
	{"KJ81", 4, 19125},
	{"KJ82", 4, 19126},
	{"KJ83", 4, 19127},
	{"KJ84", 4, 19128},
	{"KJ85", 4, 19129},
	{"KJ86", 4, 19130},
	{"KJ87", 4, 19131},
	{"KJ88", 4, 19132},
	{"KJ89", 4, 19133},
	{"KJ90", 4, 19134},
	{"KJ91", 4, 19135},
	{"KJ92", 4, 19136},
	{"KJ93", 4, 19137},
	{"KJ94", 4, 19138},
	{"KJ95", 4, 19139},
	{"KJ96", 4, 19140},
	{"KJ97", 4, 19141},
	{"KJ98", 4, 19142},
	{"KJ99", 4, 19143},
	{"KK00", 4, 19144},
	{"KK01", 4, 19145},
	{"KK02", 4, 19146},
	{"KK03", 4, 19147},
	{"KK04", 4, 19148},
	{"KK05", 4, 19149},
	{"KK06", 4, 19150},
	{"KK07", 4, 19151},
	{"KK08", 4, 19152},
	{"KK09", 4, 19153},
	{"KK10", 4, 19154},
	{"KK11", 4, 19155},
	{"KK12", 4, 19156},
	{"KK13", 4, 19157},
	{"KK14", 4, 19158},
	{"KK15", 4, 19159},
	{"KK16", 4, 19160},
	{"KK17", 4, 19161},
	{"KK18", 4, 19162},
	{"KK19", 4, 19163},
	{"KK20", 4, 19164},
	{"KK21", 4, 19165},
	{"KK22", 4, 19166},
	{"KK23", 4, 19167},
	{"KK24", 4, 19168},
	{"KK25", 4, 19169},
	{"KK26", 4, 19170},
	{"KK27", 4, 19171},
	{"KK28", 4, 19172},
	{"KK29", 4, 19173},
	{"KK30", 4, 19174},
	{"KK31", 4, 19175},
	{"KK32", 4, 19176},
	{"KK33", 4, 19177},
	{"KK34", 4, 19178},
	{"KK35", 4, 19179},
	{"KK36", 4, 19180},
	{"KK37", 4, 19181},
	{"KK38", 4, 19182},
	{"KK39", 4, 19183},
	{"KK40", 4, 19184},
	{"KK41", 4, 19185},
	{"KK42", 4, 19186},
	{"KK43", 4, 19187},
	{"KK44", 4, 19188},
	{"KK45", 4, 19189},
	{"KK46", 4, 19190},
	{"KK47", 4, 19191},
	{"KK48", 4, 19192},
	{"KK49", 4, 19193},
	{"KK50", 4, 19194},
	{"KK51", 4, 19195},
	{"KK52", 4, 19196},
	{"KK53", 4, 19197},
	{"KK54", 4, 19198},
	{"KK55", 4, 19199},
	{"KK56", 4, 19200},
	{"KK57", 4, 19201},
	{"KK58", 4, 19202},
	{"KK59", 4, 19203},
	{"KK60", 4, 19204},
	{"KK61", 4, 19205},
	{"KK62", 4, 19206},
	{"KK63", 4, 19207},
	{"KK64", 4, 19208},
	{"KK65", 4, 19209},
	{"KK66", 4, 19210},
	{"KK67", 4, 19211},
	{"KK68", 4, 19212},
	{"KK69", 4, 19213},
	{"KK70", 4, 19214},
	{"KK71", 4, 19215},
	{"KK72", 4, 19216},
	{"KK73", 4, 19217},
	{"KK74", 4, 19218},
	{"KK75", 4, 19219},
	{"KK76", 4, 19220},
	{"KK77", 4, 19221},
	{"KK78", 4, 19222},
	{"KK79", 4, 19223},
	{"KK80", 4, 19224},
	{"KK81", 4, 19225},
	{"KK82", 4, 19226},
	{"KK83", 4, 19227},
	{"KK84", 4, 19228},
	{"KK85", 4, 19229},
	{"KK86", 4, 19230},
	{"KK87", 4, 19231},
	{"KK88", 4, 19232},
	{"KK89", 4, 19233},
	{"KK90", 4, 19234},
	{"KK91", 4, 19235},
	{"KK92", 4, 19236},
	{"KK93", 4, 19237},
	{"KK94", 4, 19238},
	{"KK95", 4, 19239},
	{"KK96", 4, 19240},
	{"KK97", 4, 19241},
	{"KK98", 4, 19242},
	{"KK99", 4, 19243},
	{"KL00", 4, 19244},
	{"KL01", 4, 19245},
	{"KL02", 4, 19246},
	{"KL03", 4, 19247},
	{"KL04", 4, 19248},
	{"KL05", 4, 19249},
	{"KL06", 4, 19250},
	{"KL07", 4, 19251},
	{"KL08", 4, 19252},
	{"KL09", 4, 19253},
	{"KL10", 4, 19254},
	{"KL11", 4, 19255},
	{"KL12", 4, 19256},
	{"KL13", 4, 19257},
	{"KL14", 4, 19258},
	{"KL15", 4, 19259},
	{"KL16", 4, 19260},
	{"KL17", 4, 19261},
	{"KL18", 4, 19262},
	{"KL19", 4, 19263},
	{"KL20", 4, 19264},
	{"KL21", 4, 19265},
	{"KL22", 4, 19266},
	{"KL23", 4, 19267},
	{"KL24", 4, 19268},
	{"KL25", 4, 19269},
	{"KL26", 4, 19270},
	{"KL27", 4, 19271},
	{"KL28", 4, 19272},
	{"KL29", 4, 19273},
	{"KL30", 4, 19274},
	{"KL31", 4, 19275},
	{"KL32", 4, 19276},
	{"KL33", 4, 19277},
	{"KL34", 4, 19278},
	{"KL35", 4, 19279},
	{"KL36", 4, 19280},
	{"KL37", 4, 19281},
	{"KL38", 4, 19282},
	{"KL39", 4, 19283},
	{"KL40", 4, 19284},
	{"KL41", 4, 19285},
	{"KL42", 4, 19286},
	{"KL43", 4, 19287},
	{"KL44", 4, 19288},
	{"KL45", 4, 19289},
	{"KL46", 4, 19290},
	{"KL47", 4, 19291},
	{"KL48", 4, 19292},
	{"KL49", 4, 19293},
	{"KL50", 4, 19294},
	{"KL51", 4, 19295},
	{"KL52", 4, 19296},
	{"KL53", 4, 19297},
	{"KL54", 4, 19298},
	{"KL55", 4, 19299},
	{"KL56", 4, 19300},
	{"KL57", 4, 19301},
	{"KL58", 4, 19302},
	{"KL59", 4, 19303},
	{"KL60", 4, 19304},
	{"KL61", 4, 19305},
	{"KL62", 4, 19306},
	{"KL63", 4, 19307},
	{"KL64", 4, 19308},
	{"KL65", 4, 19309},
	{"KL66", 4, 19310},
	{"KL67", 4, 19311},
	{"KL68", 4, 19312},
	{"KL69", 4, 19313},
	{"KL70", 4, 19314},
	{"KL71", 4, 19315},
	{"KL72", 4, 19316},
	{"KL73", 4, 19317},
	{"KL74", 4, 19318},
	{"KL75", 4, 19319},
	{"KL76", 4, 19320},
	{"KL77", 4, 19321},
	{"KL78", 4, 19322},
	{"KL79", 4, 19323},
	{"KL80", 4, 19324},
	{"KL81", 4, 19325},
	{"KL82", 4, 19326},
	{"KL83", 4, 19327},
	{"KL84", 4, 19328},
	{"KL85", 4, 19329},
	{"KL86", 4, 19330},
	{"KL87", 4, 19331},
	{"KL88", 4, 19332},
	{"KL89", 4, 19333},
	{"KL90", 4, 19334},
	{"KL91", 4, 19335},
	{"KL92", 4, 19336},
	{"KL93", 4, 19337},
	{"KL94", 4, 19338},
	{"KL95", 4, 19339},
	{"KL96", 4, 19340},
	{"KL97", 4, 19341},
	{"KL98", 4, 19342},
	{"KL99", 4, 19343},
	{"KM00", 4, 19344},
	{"KM01", 4, 19345},
	{"KM02", 4, 19346},
	{"KM03", 4, 19347},
	{"KM04", 4, 19348},
	{"KM05", 4, 19349},
	{"KM06", 4, 19350},
	{"KM07", 4, 19351},
	{"KM08", 4, 19352},
	{"KM09", 4, 19353},
	{"KM10", 4, 19354},
	{"KM11", 4, 19355},
	{"KM12", 4, 19356},
	{"KM13", 4, 19357},
	{"KM14", 4, 19358},
	{"KM15", 4, 19359},
	{"KM16", 4, 19360},
	{"KM17", 4, 19361},
	{"KM18", 4, 19362},
	{"KM19", 4, 19363},
	{"KM20", 4, 19364},
	{"KM21", 4, 19365},
	{"KM22", 4, 19366},
	{"KM23", 4, 19367},
	{"KM24", 4, 19368},
	{"KM25", 4, 19369},
	{"KM26", 4, 19370},
	{"KM27", 4, 19371},
	{"KM28", 4, 19372},
	{"KM29", 4, 19373},
	{"KM30", 4, 19374},
	{"KM31", 4, 19375},
	{"KM32", 4, 19376},
	{"KM33", 4, 19377},
	{"KM34", 4, 19378},
	{"KM35", 4, 19379},
	{"KM36", 4, 19380},
	{"KM37", 4, 19381},
	{"KM38", 4, 19382},
	{"KM39", 4, 19383},
	{"KM40", 4, 19384},
	{"KM41", 4, 19385},
	{"KM42", 4, 19386},
	{"KM43", 4, 19387},
	{"KM44", 4, 19388},
	{"KM45", 4, 19389},
	{"KM46", 4, 19390},
	{"KM47", 4, 19391},
	{"KM48", 4, 19392},
	{"KM49", 4, 19393},
	{"KM50", 4, 19394},
	{"KM51", 4, 19395},
	{"KM52", 4, 19396},
	{"KM53", 4, 19397},
	{"KM54", 4, 19398},
	{"KM55", 4, 19399},
	{"KM56", 4, 19400},
	{"KM57", 4, 19401},
	{"KM58", 4, 19402},
	{"KM59", 4, 19403},
	{"KM60", 4, 19404},
	{"KM61", 4, 19405},
	{"KM62", 4, 19406},
	{"KM63", 4, 19407},
	{"KM64", 4, 19408},
	{"KM65", 4, 19409},
	{"KM66", 4, 19410},
	{"KM67", 4, 19411},
	{"KM68", 4, 19412},
	{"KM69", 4, 19413},
	{"KM70", 4, 19414},
	{"KM71", 4, 19415},
	{"KM72", 4, 19416},
	{"KM73", 4, 19417},
	{"KM74", 4, 19418},
	{"KM75", 4, 19419},
	{"KM76", 4, 19420},
	{"KM77", 4, 19421},
	{"KM78", 4, 19422},
	{"KM79", 4, 19423},
	{"KM80", 4, 19424},
	{"KM81", 4, 19425},
	{"KM82", 4, 19426},
	{"KM83", 4, 19427},
	{"KM84", 4, 19428},
	{"KM85", 4, 19429},
	{"KM86", 4, 19430},
	{"KM87", 4, 19431},
	{"KM88", 4, 19432},
	{"KM89", 4, 19433},
	{"KM90", 4, 19434},
	{"KM91", 4, 19435},
	{"KM92", 4, 19436},
	{"KM93", 4, 19437},
	{"KM94", 4, 19438},
	{"KM95", 4, 19439},
	{"KM96", 4, 19440},
	{"KM97", 4, 19441},
	{"KM98", 4, 19442},
	{"KM99", 4, 19443},
	{"KN00", 4, 19444},
	{"KN01", 4, 19445},
	{"KN02", 4, 19446},
	{"KN03", 4, 19447},
	{"KN04", 4, 19448},
	{"KN05", 4, 19449},
	{"KN06", 4, 19450},
	{"KN07", 4, 19451},
	{"KN08", 4, 19452},
	{"KN09", 4, 19453},
	{"KN10", 4, 19454},
	{"KN11", 4, 19455},
	{"KN12", 4, 19456},
	{"KN13", 4, 19457},
	{"KN14", 4, 19458},
	{"KN15", 4, 19459},
	{"KN16", 4, 19460},
	{"KN17", 4, 19461},
	{"KN18", 4, 19462},
	{"KN19", 4, 19463},
	{"KN20", 4, 19464},
	{"KN21", 4, 19465},
	{"KN22", 4, 19466},
	{"KN23", 4, 19467},
	{"KN24", 4, 19468},
	{"KN25", 4, 19469},
	{"KN26", 4, 19470},
	{"KN27", 4, 19471},
	{"KN28", 4, 19472},
	{"KN29", 4, 19473},
	{"KN30", 4, 19474},
	{"KN31", 4, 19475},
	{"KN32", 4, 19476},
	{"KN33", 4, 19477},
	{"KN34", 4, 19478},
	{"KN35", 4, 19479},
	{"KN36", 4, 19480},
	{"KN37", 4, 19481},
	{"KN38", 4, 19482},
	{"KN39", 4, 19483},
	{"KN40", 4, 19484},
	{"KN41", 4, 19485},
	{"KN42", 4, 19486},
	{"KN43", 4, 19487},
	{"KN44", 4, 19488},
	{"KN45", 4, 19489},
	{"KN46", 4, 19490},
	{"KN47", 4, 19491},
	{"KN48", 4, 19492},
	{"KN49", 4, 19493},
	{"KN50", 4, 19494},
	{"KN51", 4, 19495},
	{"KN52", 4, 19496},
	{"KN53", 4, 19497},
	{"KN54", 4, 19498},
	{"KN55", 4, 19499},
	{"KN56", 4, 19500},
	{"KN57", 4, 19501},
	{"KN58", 4, 19502},
	{"KN59", 4, 19503},
	{"KN60", 4, 19504},
	{"KN61", 4, 19505},
	{"KN62", 4, 19506},
	{"KN63", 4, 19507},
	{"KN64", 4, 19508},
	{"KN65", 4, 19509},
	{"KN66", 4, 19510},
	{"KN67", 4, 19511},
	{"KN68", 4, 19512},
	{"KN69", 4, 19513},
	{"KN70", 4, 19514},
	{"KN71", 4, 19515},
	{"KN72", 4, 19516},
	{"KN73", 4, 19517},
	{"KN74", 4, 19518},
	{"KN75", 4, 19519},
	{"KN76", 4, 19520},
	{"KN77", 4, 19521},
	{"KN78", 4, 19522},
	{"KN79", 4, 19523},
	{"KN80", 4, 19524},
	{"KN81", 4, 19525},
	{"KN82", 4, 19526},
	{"KN83", 4, 19527},
	{"KN84", 4, 19528},
	{"KN85", 4, 19529},
	{"KN86", 4, 19530},
	{"KN87", 4, 19531},
	{"KN88", 4, 19532},
	{"KN89", 4, 19533},
	{"KN90", 4, 19534},
	{"KN91", 4, 19535},
	{"KN92", 4, 19536},
	{"KN93", 4, 19537},
	{"KN94", 4, 19538},
	{"KN95", 4, 19539},
	{"KN96", 4, 19540},
	{"KN97", 4, 19541},
	{"KN98", 4, 19542},
	{"KN99", 4, 19543},
	{"KO00", 4, 19544},
	{"KO01", 4, 19545},
	{"KO02", 4, 19546},
	{"KO03", 4, 19547},
	{"KO04", 4, 19548},
	{"KO05", 4, 19549},
	{"KO06", 4, 19550},
	{"KO07", 4, 19551},
	{"KO08", 4, 19552},
	{"KO09", 4, 19553},
	{"KO10", 4, 19554},
	{"KO11", 4, 19555},
	{"KO12", 4, 19556},
	{"KO13", 4, 19557},
	{"KO14", 4, 19558},
	{"KO15", 4, 19559},
	{"KO16", 4, 19560},
	{"KO17", 4, 19561},
	{"KO18", 4, 19562},
	{"KO19", 4, 19563},
	{"KO20", 4, 19564},
	{"KO21", 4, 19565},
	{"KO22", 4, 19566},
	{"KO23", 4, 19567},
	{"KO24", 4, 19568},
	{"KO25", 4, 19569},
	{"KO26", 4, 19570},
	{"KO27", 4, 19571},
	{"KO28", 4, 19572},
	{"KO29", 4, 19573},
	{"KO30", 4, 19574},
	{"KO31", 4, 19575},
	{"KO32", 4, 19576},
	{"KO33", 4, 19577},
	{"KO34", 4, 19578},
	{"KO35", 4, 19579},
	{"KO36", 4, 19580},
	{"KO37", 4, 19581},
	{"KO38", 4, 19582},
	{"KO39", 4, 19583},
	{"KO40", 4, 19584},
	{"KO41", 4, 19585},
	{"KO42", 4, 19586},
	{"KO43", 4, 19587},
	{"KO44", 4, 19588},
	{"KO45", 4, 19589},
	{"KO46", 4, 19590},
	{"KO47", 4, 19591},
	{"KO48", 4, 19592},
	{"KO49", 4, 19593},
	{"KO50", 4, 19594},
	{"KO51", 4, 19595},
	{"KO52", 4, 19596},
	{"KO53", 4, 19597},
	{"KO54", 4, 19598},
	{"KO55", 4, 19599},
	{"KO56", 4, 19600},
	{"KO57", 4, 19601},
	{"KO58", 4, 19602},
	{"KO59", 4, 19603},
	{"KO60", 4, 19604},
	{"KO61", 4, 19605},
	{"KO62", 4, 19606},
	{"KO63", 4, 19607},
	{"KO64", 4, 19608},
	{"KO65", 4, 19609},
	{"KO66", 4, 19610},
	{"KO67", 4, 19611},
	{"KO68", 4, 19612},
	{"KO69", 4, 19613},
	{"KO70", 4, 19614},
	{"KO71", 4, 19615},
	{"KO72", 4, 19616},
	{"KO73", 4, 19617},
	{"KO74", 4, 19618},
	{"KO75", 4, 19619},
	{"KO76", 4, 19620},
	{"KO77", 4, 19621},
	{"KO78", 4, 19622},
	{"KO79", 4, 19623},
	{"KO80", 4, 19624},
	{"KO81", 4, 19625},
	{"KO82", 4, 19626},
	{"KO83", 4, 19627},
	{"KO84", 4, 19628},
	{"KO85", 4, 19629},
	{"KO86", 4, 19630},
	{"KO87", 4, 19631},
	{"KO88", 4, 19632},
	{"KO89", 4, 19633},
	{"KO90", 4, 19634},
	{"KO91", 4, 19635},
	{"KO92", 4, 19636},
	{"KO93", 4, 19637},
	{"KO94", 4, 19638},
	{"KO95", 4, 19639},
	{"KO96", 4, 19640},
	{"KO97", 4, 19641},
	{"KO98", 4, 19642},
	{"KO99", 4, 19643},
	{"KP00", 4, 19644},
	{"KP01", 4, 19645},
	{"KP02", 4, 19646},
	{"KP03", 4, 19647},
	{"KP04", 4, 19648},
	{"KP05", 4, 19649},
	{"KP06", 4, 19650},
	{"KP07", 4, 19651},
	{"KP08", 4, 19652},
	{"KP09", 4, 19653},
	{"KP10", 4, 19654},
	{"KP11", 4, 19655},
	{"KP12", 4, 19656},
	{"KP13", 4, 19657},
	{"KP14", 4, 19658},
	{"KP15", 4, 19659},
	{"KP16", 4, 19660},
	{"KP17", 4, 19661},
	{"KP18", 4, 19662},
	{"KP19", 4, 19663},
	{"KP20", 4, 19664},
	{"KP21", 4, 19665},
	{"KP22", 4, 19666},
	{"KP23", 4, 19667},
	{"KP24", 4, 19668},
	{"KP25", 4, 19669},
	{"KP26", 4, 19670},
	{"KP27", 4, 19671},
	{"KP28", 4, 19672},
	{"KP29", 4, 19673},
	{"KP30", 4, 19674},
	{"KP31", 4, 19675},
	{"KP32", 4, 19676},
	{"KP33", 4, 19677},
	{"KP34", 4, 19678},
	{"KP35", 4, 19679},
	{"KP36", 4, 19680},
	{"KP37", 4, 19681},
	{"KP38", 4, 19682},
	{"KP39", 4, 19683},
	{"KP40", 4, 19684},
	{"KP41", 4, 19685},
	{"KP42", 4, 19686},
	{"KP43", 4, 19687},
	{"KP44", 4, 19688},
	{"KP45", 4, 19689},
	{"KP46", 4, 19690},
	{"KP47", 4, 19691},
	{"KP48", 4, 19692},
	{"KP49", 4, 19693},
	{"KP50", 4, 19694},
	{"KP51", 4, 19695},
	{"KP52", 4, 19696},
	{"KP53", 4, 19697},
	{"KP54", 4, 19698},
	{"KP55", 4, 19699},
	{"KP56", 4, 19700},
	{"KP57", 4, 19701},
	{"KP58", 4, 19702},
	{"KP59", 4, 19703},
	{"KP60", 4, 19704},
	{"KP61", 4, 19705},
	{"KP62", 4, 19706},
	{"KP63", 4, 19707},
	{"KP64", 4, 19708},
	{"KP65", 4, 19709},
	{"KP66", 4, 19710},
	{"KP67", 4, 19711},
	{"KP68", 4, 19712},
	{"KP69", 4, 19713},
	{"KP70", 4, 19714},
	{"KP71", 4, 19715},
	{"KP72", 4, 19716},
	{"KP73", 4, 19717},
	{"KP74", 4, 19718},
	{"KP75", 4, 19719},
	{"KP76", 4, 19720},
	{"KP77", 4, 19721},
	{"KP78", 4, 19722},
	{"KP79", 4, 19723},
	{"KP80", 4, 19724},
	{"KP81", 4, 19725},
	{"KP82", 4, 19726},
	{"KP83", 4, 19727},
	{"KP84", 4, 19728},
	{"KP85", 4, 19729},
	{"KP86", 4, 19730},
	{"KP87", 4, 19731},
	{"KP88", 4, 19732},
	{"KP89", 4, 19733},
	{"KP90", 4, 19734},
	{"KP91", 4, 19735},
	{"KP92", 4, 19736},
	{"KP93", 4, 19737},
	{"KP94", 4, 19738},
	{"KP95", 4, 19739},
	{"KP96", 4, 19740},
	{"KP97", 4, 19741},
	{"KP98", 4, 19742},
	{"KP99", 4, 19743},
	{"KQ00", 4, 19744},
	{"KQ01", 4, 19745},
	{"KQ02", 4, 19746},
	{"KQ03", 4, 19747},
	{"KQ04", 4, 19748},
	{"KQ05", 4, 19749},
	{"KQ06", 4, 19750},
	{"KQ07", 4, 19751},
	{"KQ08", 4, 19752},
	{"KQ09", 4, 19753},
	{"KQ10", 4, 19754},
	{"KQ11", 4, 19755},
	{"KQ12", 4, 19756},
	{"KQ13", 4, 19757},
	{"KQ14", 4, 19758},
	{"KQ15", 4, 19759},
	{"KQ16", 4, 19760},
	{"KQ17", 4, 19761},
	{"KQ18", 4, 19762},
	{"KQ19", 4, 19763},
	{"KQ20", 4, 19764},
	{"KQ21", 4, 19765},
	{"KQ22", 4, 19766},
	{"KQ23", 4, 19767},
	{"KQ24", 4, 19768},
	{"KQ25", 4, 19769},
	{"KQ26", 4, 19770},
	{"KQ27", 4, 19771},
	{"KQ28", 4, 19772},
	{"KQ29", 4, 19773},
	{"KQ30", 4, 19774},
	{"KQ31", 4, 19775},
	{"KQ32", 4, 19776},
	{"KQ33", 4, 19777},
	{"KQ34", 4, 19778},
	{"KQ35", 4, 19779},
	{"KQ36", 4, 19780},
	{"KQ37", 4, 19781},
	{"KQ38", 4, 19782},
	{"KQ39", 4, 19783},
	{"KQ40", 4, 19784},
	{"KQ41", 4, 19785},
	{"KQ42", 4, 19786},
	{"KQ43", 4, 19787},
	{"KQ44", 4, 19788},
	{"KQ45", 4, 19789},
	{"KQ46", 4, 19790},
	{"KQ47", 4, 19791},
	{"KQ48", 4, 19792},
	{"KQ49", 4, 19793},
	{"KQ50", 4, 19794},
	{"KQ51", 4, 19795},
	{"KQ52", 4, 19796},
	{"KQ53", 4, 19797},
	{"KQ54", 4, 19798},
	{"KQ55", 4, 19799},
	{"KQ56", 4, 19800},
	{"KQ57", 4, 19801},
	{"KQ58", 4, 19802},
	{"KQ59", 4, 19803},
	{"KQ60", 4, 19804},
	{"KQ61", 4, 19805},
	{"KQ62", 4, 19806},
	{"KQ63", 4, 19807},
	{"KQ64", 4, 19808},
	{"KQ65", 4, 19809},
	{"KQ66", 4, 19810},
	{"KQ67", 4, 19811},
	{"KQ68", 4, 19812},
	{"KQ69", 4, 19813},
	{"KQ70", 4, 19814},
	{"KQ71", 4, 19815},
	{"KQ72", 4, 19816},
	{"KQ73", 4, 19817},
	{"KQ74", 4, 19818},
	{"KQ75", 4, 19819},
	{"KQ76", 4, 19820},
	{"KQ77", 4, 19821},
	{"KQ78", 4, 19822},
	{"KQ79", 4, 19823},
	{"KQ80", 4, 19824},
	{"KQ81", 4, 19825},
	{"KQ82", 4, 19826},
	{"KQ83", 4, 19827},
	{"KQ84", 4, 19828},
	{"KQ85", 4, 19829},
	{"KQ86", 4, 19830},
	{"KQ87", 4, 19831},
	{"KQ88", 4, 19832},
	{"KQ89", 4, 19833},
	{"KQ90", 4, 19834},
	{"KQ91", 4, 19835},
	{"KQ92", 4, 19836},
	{"KQ93", 4, 19837},
	{"KQ94", 4, 19838},
	{"KQ95", 4, 19839},
	{"KQ96", 4, 19840},
	{"KQ97", 4, 19841},
	{"KQ98", 4, 19842},
	{"KQ99", 4, 19843},
	{"LB00", 4, 19844},
	{"LB01", 4, 19845},
	{"LB02", 4, 19846},
	{"LB03", 4, 19847},
	{"LB04", 4, 19848},
	{"LB05", 4, 19849},
	{"LB06", 4, 19850},
	{"LB07", 4, 19851},
	{"LB08", 4, 19852},
	{"LB09", 4, 19853},
	{"LB10", 4, 19854},
	{"LB11", 4, 19855},
	{"LB12", 4, 19856},
	{"LB13", 4, 19857},
	{"LB14", 4, 19858},
	{"LB15", 4, 19859},
	{"LB16", 4, 19860},
	{"LB17", 4, 19861},
	{"LB18", 4, 19862},
	{"LB19", 4, 19863},
	{"LB20", 4, 19864},
	{"LB21", 4, 19865},
	{"LB22", 4, 19866},
	{"LB23", 4, 19867},
	{"LB24", 4, 19868},
	{"LB25", 4, 19869},
	{"LB26", 4, 19870},
	{"LB27", 4, 19871},
	{"LB28", 4, 19872},
	{"LB29", 4, 19873},
	{"LB30", 4, 19874},
	{"LB31", 4, 19875},
	{"LB32", 4, 19876},
	{"LB33", 4, 19877},
	{"LB34", 4, 19878},
	{"LB35", 4, 19879},
	{"LB36", 4, 19880},
	{"LB37", 4, 19881},
	{"LB38", 4, 19882},
	{"LB39", 4, 19883},
	{"LB40", 4, 19884},
	{"LB41", 4, 19885},
	{"LB42", 4, 19886},
	{"LB43", 4, 19887},
	{"LB44", 4, 19888},
	{"LB45", 4, 19889},
	{"LB46", 4, 19890},
	{"LB47", 4, 19891},
	{"LB48", 4, 19892},
	{"LB49", 4, 19893},
	{"LB50", 4, 19894},
	{"LB51", 4, 19895},
	{"LB52", 4, 19896},
	{"LB53", 4, 19897},
	{"LB54", 4, 19898},
	{"LB55", 4, 19899},
	{"LB56", 4, 19900},
	{"LB57", 4, 19901},
	{"LB58", 4, 19902},
	{"LB59", 4, 19903},
	{"LB60", 4, 19904},
	{"LB61", 4, 19905},
	{"LB62", 4, 19906},
	{"LB63", 4, 19907},
	{"LB64", 4, 19908},
	{"LB65", 4, 19909},
	{"LB66", 4, 19910},
	{"LB67", 4, 19911},
	{"LB68", 4, 19912},
	{"LB69", 4, 19913},
	{"LB70", 4, 19914},
	{"LB71", 4, 19915},
	{"LB72", 4, 19916},
	{"LB73", 4, 19917},
	{"LB74", 4, 19918},
	{"LB75", 4, 19919},
	{"LB76", 4, 19920},
	{"LB77", 4, 19921},
	{"LB78", 4, 19922},
	{"LB79", 4, 19923},
	{"LB80", 4, 19924},
	{"LB81", 4, 19925},
	{"LB82", 4, 19926},
	{"LB83", 4, 19927},
	{"LB84", 4, 19928},
	{"LB85", 4, 19929},
	{"LB86", 4, 19930},
	{"LB87", 4, 19931},
	{"LB88", 4, 19932},
	{"LB89", 4, 19933},
	{"LB90", 4, 19934},
	{"LB91", 4, 19935},
	{"LB92", 4, 19936},
	{"LB93", 4, 19937},
	{"LB94", 4, 19938},
	{"LB95", 4, 19939},
	{"LB96", 4, 19940},
	{"LB97", 4, 19941},
	{"LB98", 4, 19942},
	{"LB99", 4, 19943},
	{"LC00", 4, 19944},
	{"LC01", 4, 19945},
	{"LC02", 4, 19946},
	{"LC03", 4, 19947},
	{"LC04", 4, 19948},
	{"LC05", 4, 19949},
	{"LC06", 4, 19950},
	{"LC07", 4, 19951},
	{"LC08", 4, 19952},
	{"LC09", 4, 19953},
	{"LC10", 4, 19954},
	{"LC11", 4, 19955},
	{"LC12", 4, 19956},
	{"LC13", 4, 19957},
	{"LC14", 4, 19958},
	{"LC15", 4, 19959},
	{"LC16", 4, 19960},
	{"LC17", 4, 19961},
	{"LC18", 4, 19962},
	{"LC19", 4, 19963},
	{"LC20", 4, 19964},
	{"LC21", 4, 19965},
	{"LC22", 4, 19966},
	{"LC23", 4, 19967},
	{"LC24", 4, 19968},
	{"LC25", 4, 19969},
	{"LC26", 4, 19970},
	{"LC27", 4, 19971},
	{"LC28", 4, 19972},
	{"LC29", 4, 19973},
	{"LC30", 4, 19974},
	{"LC31", 4, 19975},
	{"LC32", 4, 19976},
	{"LC33", 4, 19977},
	{"LC34", 4, 19978},
	{"LC35", 4, 19979},
	{"LC36", 4, 19980},
	{"LC37", 4, 19981},
	{"LC38", 4, 19982},
	{"LC39", 4, 19983},
	{"LC40", 4, 19984},
	{"LC41", 4, 19985},
	{"LC42", 4, 19986},
	{"LC43", 4, 19987},
	{"LC44", 4, 19988},
	{"LC45", 4, 19989},
	{"LC46", 4, 19990},
	{"LC47", 4, 19991},
	{"LC48", 4, 19992},
	{"LC49", 4, 19993},
	{"LC50", 4, 19994},
	{"LC51", 4, 19995},
	{"LC52", 4, 19996},
	{"LC53", 4, 19997},
	{"LC54", 4, 19998},
	{"LC55", 4, 19999},
	{"LC56", 4, 20000},
	{"LC57", 4, 20001},
	{"LC58", 4, 20002},
	{"LC59", 4, 20003},
	{"LC60", 4, 20004},
	{"LC61", 4, 20005},
	{"LC62", 4, 20006},
	{"LC63", 4, 20007},
	{"LC64", 4, 20008},
	{"LC65", 4, 20009},
	{"LC66", 4, 20010},
	{"LC67", 4, 20011},
	{"LC68", 4, 20012},
	{"LC69", 4, 20013},
	{"LC70", 4, 20014},
	{"LC71", 4, 20015},
	{"LC72", 4, 20016},
	{"LC73", 4, 20017},
	{"LC74", 4, 20018},
	{"LC75", 4, 20019},
	{"LC76", 4, 20020},
	{"LC77", 4, 20021},
	{"LC78", 4, 20022},
	{"LC79", 4, 20023},
	{"LC80", 4, 20024},
	{"LC81", 4, 20025},
	{"LC82", 4, 20026},
	{"LC83", 4, 20027},
	{"LC84", 4, 20028},
	{"LC85", 4, 20029},
	{"LC86", 4, 20030},
	{"LC87", 4, 20031},
	{"LC88", 4, 20032},
	{"LC89", 4, 20033},
	{"LC90", 4, 20034},
	{"LC91", 4, 20035},
	{"LC92", 4, 20036},
	{"LC93", 4, 20037},
	{"LC94", 4, 20038},
	{"LC95", 4, 20039},
	{"LC96", 4, 20040},
	{"LC97", 4, 20041},
	{"LC98", 4, 20042},
	{"LC99", 4, 20043},
	{"LG00", 4, 20044},
	{"LG01", 4, 20045},
	{"LG02", 4, 20046},
	{"LG03", 4, 20047},
	{"LG04", 4, 20048},
	{"LG05", 4, 20049},
	{"LG06", 4, 20050},
	{"LG07", 4, 20051},
	{"LG08", 4, 20052},
	{"LG09", 4, 20053},
	{"LG10", 4, 20054},
	{"LG11", 4, 20055},
	{"LG12", 4, 20056},
	{"LG13", 4, 20057},
	{"LG14", 4, 20058},
	{"LG15", 4, 20059},
	{"LG16", 4, 20060},
	{"LG17", 4, 20061},
	{"LG18", 4, 20062},
	{"LG19", 4, 20063},
	{"LG20", 4, 20064},
	{"LG21", 4, 20065},
	{"LG22", 4, 20066},
	{"LG23", 4, 20067},
	{"LG24", 4, 20068},
	{"LG25", 4, 20069},
	{"LG26", 4, 20070},
	{"LG27", 4, 20071},
	{"LG28", 4, 20072},
	{"LG29", 4, 20073},
	{"LG30", 4, 20074},
	{"LG31", 4, 20075},
	{"LG32", 4, 20076},
	{"LG33", 4, 20077},
	{"LG34", 4, 20078},
	{"LG35", 4, 20079},
	{"LG36", 4, 20080},
	{"LG37", 4, 20081},
	{"LG38", 4, 20082},
	{"LG39", 4, 20083},
	{"LG40", 4, 20084},
	{"LG41", 4, 20085},
	{"LG42", 4, 20086},
	{"LG43", 4, 20087},
	{"LG44", 4, 20088},
	{"LG45", 4, 20089},
	{"LG46", 4, 20090},
	{"LG47", 4, 20091},
	{"LG48", 4, 20092},
	{"LG49", 4, 20093},
	{"LG50", 4, 20094},
	{"LG51", 4, 20095},
	{"LG52", 4, 20096},
	{"LG53", 4, 20097},
	{"LG54", 4, 20098},
	{"LG55", 4, 20099},
	{"LG56", 4, 20100},
	{"LG57", 4, 20101},
	{"LG58", 4, 20102},
	{"LG59", 4, 20103},
	{"LG60", 4, 20104},
	{"LG61", 4, 20105},
	{"LG62", 4, 20106},
	{"LG63", 4, 20107},
	{"LG64", 4, 20108},
	{"LG65", 4, 20109},
	{"LG66", 4, 20110},
	{"LG67", 4, 20111},
	{"LG68", 4, 20112},
	{"LG69", 4, 20113},
	{"LG70", 4, 20114},
	{"LG71", 4, 20115},
	{"LG72", 4, 20116},
	{"LG73", 4, 20117},
	{"LG74", 4, 20118},
	{"LG75", 4, 20119},
	{"LG76", 4, 20120},
	{"LG77", 4, 20121},
	{"LG78", 4, 20122},
	{"LG79", 4, 20123},
	{"LG80", 4, 20124},
	{"LG81", 4, 20125},
	{"LG82", 4, 20126},
	{"LG83", 4, 20127},
	{"LG84", 4, 20128},
	{"LG85", 4, 20129},
	{"LG86", 4, 20130},
	{"LG87", 4, 20131},
	{"LG88", 4, 20132},
	{"LG89", 4, 20133},
	{"LG90", 4, 20134},
	{"LG91", 4, 20135},
	{"LG92", 4, 20136},
	{"LG93", 4, 20137},
	{"LG94", 4, 20138},
	{"LG95", 4, 20139},
	{"LG96", 4, 20140},
	{"LG97", 4, 20141},
	{"LG98", 4, 20142},
	{"LG99", 4, 20143},
	{"LH00", 4, 20144},
	{"LH01", 4, 20145},
	{"LH02", 4, 20146},
	{"LH03", 4, 20147},
	{"LH04", 4, 20148},
	{"LH05", 4, 20149},
	{"LH06", 4, 20150},
	{"LH07", 4, 20151},
	{"LH08", 4, 20152},
	{"LH09", 4, 20153},
	{"LH10", 4, 20154},
	{"LH11", 4, 20155},
	{"LH12", 4, 20156},
	{"LH13", 4, 20157},
	{"LH14", 4, 20158},
	{"LH15", 4, 20159},
	{"LH16", 4, 20160},
	{"LH17", 4, 20161},
	{"LH18", 4, 20162},
	{"LH19", 4, 20163},
	{"LH20", 4, 20164},
	{"LH21", 4, 20165},
	{"LH22", 4, 20166},
	{"LH23", 4, 20167},
	{"LH24", 4, 20168},
	{"LH25", 4, 20169},
	{"LH26", 4, 20170},
	{"LH27", 4, 20171},
	{"LH28", 4, 20172},
	{"LH29", 4, 20173},
	{"LH30", 4, 20174},
	{"LH31", 4, 20175},
	{"LH32", 4, 20176},
	{"LH33", 4, 20177},
	{"LH34", 4, 20178},
	{"LH35", 4, 20179},
	{"LH36", 4, 20180},
	{"LH37", 4, 20181},
	{"LH38", 4, 20182},
	{"LH39", 4, 20183},
	{"LH40", 4, 20184},
	{"LH41", 4, 20185},
	{"LH42", 4, 20186},
	{"LH43", 4, 20187},
	{"LH44", 4, 20188},
	{"LH45", 4, 20189},
	{"LH46", 4, 20190},
	{"LH47", 4, 20191},
	{"LH48", 4, 20192},
	{"LH49", 4, 20193},
	{"LH50", 4, 20194},
	{"LH51", 4, 20195},
	{"LH52", 4, 20196},
	{"LH53", 4, 20197},
	{"LH54", 4, 20198},
	{"LH55", 4, 20199},
	{"LH56", 4, 20200},
	{"LH57", 4, 20201},
	{"LH58", 4, 20202},
	{"LH59", 4, 20203},
	{"LH60", 4, 20204},
	{"LH61", 4, 20205},
	{"LH62", 4, 20206},
	{"LH63", 4, 20207},
	{"LH64", 4, 20208},
	{"LH65", 4, 20209},
	{"LH66", 4, 20210},
	{"LH67", 4, 20211},
	{"LH68", 4, 20212},
	{"LH69", 4, 20213},
	{"LH70", 4, 20214},
	{"LH71", 4, 20215},
	{"LH72", 4, 20216},
	{"LH73", 4, 20217},
	{"LH74", 4, 20218},
	{"LH75", 4, 20219},
	{"LH76", 4, 20220},
	{"LH77", 4, 20221},
	{"LH78", 4, 20222},
	{"LH79", 4, 20223},
	{"LH80", 4, 20224},
	{"LH81", 4, 20225},
	{"LH82", 4, 20226},
	{"LH83", 4, 20227},
	{"LH84", 4, 20228},
	{"LH85", 4, 20229},
	{"LH86", 4, 20230},
	{"LH87", 4, 20231},
	{"LH88", 4, 20232},
	{"LH89", 4, 20233},
	{"LH90", 4, 20234},
	{"LH91", 4, 20235},
	{"LH92", 4, 20236},
	{"LH93", 4, 20237},
	{"LH94", 4, 20238},
	{"LH95", 4, 20239},
	{"LH96", 4, 20240},
	{"LH97", 4, 20241},
	{"LH98", 4, 20242},
	{"LH99", 4, 20243},
	{"LI00", 4, 20244},
	{"LI01", 4, 20245},
	{"LI02", 4, 20246},
	{"LI03", 4, 20247},
	{"LI04", 4, 20248},
	{"LI05", 4, 20249},
	{"LI06", 4, 20250},
	{"LI07", 4, 20251},
	{"LI08", 4, 20252},
	{"LI09", 4, 20253},
	{"LI10", 4, 20254},
	{"LI11", 4, 20255},
	{"LI12", 4, 20256},
	{"LI13", 4, 20257},
	{"LI14", 4, 20258},
	{"LI15", 4, 20259},
	{"LI16", 4, 20260},
	{"LI17", 4, 20261},
	{"LI18", 4, 20262},
	{"LI19", 4, 20263},
	{"LI20", 4, 20264},
	{"LI21", 4, 20265},
	{"LI22", 4, 20266},
	{"LI23", 4, 20267},
	{"LI24", 4, 20268},
	{"LI25", 4, 20269},
	{"LI26", 4, 20270},
	{"LI27", 4, 20271},
	{"LI28", 4, 20272},
	{"LI29", 4, 20273},
	{"LI30", 4, 20274},
	{"LI31", 4, 20275},
	{"LI32", 4, 20276},
	{"LI33", 4, 20277},
	{"LI34", 4, 20278},
	{"LI35", 4, 20279},
	{"LI36", 4, 20280},
	{"LI37", 4, 20281},
	{"LI38", 4, 20282},
	{"LI39", 4, 20283},
	{"LI40", 4, 20284},
	{"LI41", 4, 20285},
	{"LI42", 4, 20286},
	{"LI43", 4, 20287},
	{"LI44", 4, 20288},
	{"LI45", 4, 20289},
	{"LI46", 4, 20290},
	{"LI47", 4, 20291},
	{"LI48", 4, 20292},
	{"LI49", 4, 20293},
	{"LI50", 4, 20294},
	{"LI51", 4, 20295},
	{"LI52", 4, 20296},
	{"LI53", 4, 20297},
	{"LI54", 4, 20298},
	{"LI55", 4, 20299},
	{"LI56", 4, 20300},
	{"LI57", 4, 20301},
	{"LI58", 4, 20302},
	{"LI59", 4, 20303},
	{"LI60", 4, 20304},
	{"LI61", 4, 20305},
	{"LI62", 4, 20306},
	{"LI63", 4, 20307},
	{"LI64", 4, 20308},
	{"LI65", 4, 20309},
	{"LI66", 4, 20310},
	{"LI67", 4, 20311},
	{"LI68", 4, 20312},
	{"LI69", 4, 20313},
	{"LI70", 4, 20314},
	{"LI71", 4, 20315},
	{"LI72", 4, 20316},
	{"LI73", 4, 20317},
	{"LI74", 4, 20318},
	{"LI75", 4, 20319},
	{"LI76", 4, 20320},
	{"LI77", 4, 20321},
	{"LI78", 4, 20322},
	{"LI79", 4, 20323},
	{"LI80", 4, 20324},
	{"LI81", 4, 20325},
	{"LI82", 4, 20326},
	{"LI83", 4, 20327},
	{"LI84", 4, 20328},
	{"LI85", 4, 20329},
	{"LI86", 4, 20330},
	{"LI87", 4, 20331},
	{"LI88", 4, 20332},
	{"LI89", 4, 20333},
	{"LI90", 4, 20334},
	{"LI91", 4, 20335},
	{"LI92", 4, 20336},
	{"LI93", 4, 20337},
	{"LI94", 4, 20338},
	{"LI95", 4, 20339},
	{"LI96", 4, 20340},
	{"LI97", 4, 20341},
	{"LI98", 4, 20342},
	{"LI99", 4, 20343},
	{"LJ00", 4, 20344},
	{"LJ01", 4, 20345},
	{"LJ02", 4, 20346},
	{"LJ03", 4, 20347},
	{"LJ04", 4, 20348},
	{"LJ05", 4, 20349},
	{"LJ06", 4, 20350},
	{"LJ07", 4, 20351},
	{"LJ08", 4, 20352},
	{"LJ09", 4, 20353},
	{"LJ10", 4, 20354},
	{"LJ11", 4, 20355},
	{"LJ12", 4, 20356},
	{"LJ13", 4, 20357},
	{"LJ14", 4, 20358},
	{"LJ15", 4, 20359},
	{"LJ16", 4, 20360},
	{"LJ17", 4, 20361},
	{"LJ18", 4, 20362},
	{"LJ19", 4, 20363},
	{"LJ20", 4, 20364},
	{"LJ21", 4, 20365},
	{"LJ22", 4, 20366},
	{"LJ23", 4, 20367},
	{"LJ24", 4, 20368},
	{"LJ25", 4, 20369},
	{"LJ26", 4, 20370},
	{"LJ27", 4, 20371},
	{"LJ28", 4, 20372},
	{"LJ29", 4, 20373},
	{"LJ30", 4, 20374},
	{"LJ31", 4, 20375},
	{"LJ32", 4, 20376},
	{"LJ33", 4, 20377},
	{"LJ34", 4, 20378},
	{"LJ35", 4, 20379},
	{"LJ36", 4, 20380},
	{"LJ37", 4, 20381},
	{"LJ38", 4, 20382},
	{"LJ39", 4, 20383},
	{"LJ40", 4, 20384},
	{"LJ41", 4, 20385},
	{"LJ42", 4, 20386},
	{"LJ43", 4, 20387},
	{"LJ44", 4, 20388},
	{"LJ45", 4, 20389},
	{"LJ46", 4, 20390},
	{"LJ47", 4, 20391},
	{"LJ48", 4, 20392},
	{"LJ49", 4, 20393},
	{"LJ50", 4, 20394},
	{"LJ51", 4, 20395},
	{"LJ52", 4, 20396},
	{"LJ53", 4, 20397},
	{"LJ54", 4, 20398},
	{"LJ55", 4, 20399},
	{"LJ56", 4, 20400},
	{"LJ57", 4, 20401},
	{"LJ58", 4, 20402},
	{"LJ59", 4, 20403},
	{"LJ60", 4, 20404},
	{"LJ61", 4, 20405},
	{"LJ62", 4, 20406},
	{"LJ63", 4, 20407},
	{"LJ64", 4, 20408},
	{"LJ65", 4, 20409},
	{"LJ66", 4, 20410},
	{"LJ67", 4, 20411},
	{"LJ68", 4, 20412},
	{"LJ69", 4, 20413},
	{"LJ70", 4, 20414},
	{"LJ71", 4, 20415},
	{"LJ72", 4, 20416},
	{"LJ73", 4, 20417},
	{"LJ74", 4, 20418},
	{"LJ75", 4, 20419},
	{"LJ76", 4, 20420},
	{"LJ77", 4, 20421},
	{"LJ78", 4, 20422},
	{"LJ79", 4, 20423},
	{"LJ80", 4, 20424},
	{"LJ81", 4, 20425},
	{"LJ82", 4, 20426},
	{"LJ83", 4, 20427},
	{"LJ84", 4, 20428},
	{"LJ85", 4, 20429},
	{"LJ86", 4, 20430},
	{"LJ87", 4, 20431},
	{"LJ88", 4, 20432},
	{"LJ89", 4, 20433},
	{"LJ90", 4, 20434},
	{"LJ91", 4, 20435},
	{"LJ92", 4, 20436},
	{"LJ93", 4, 20437},
	{"LJ94", 4, 20438},
	{"LJ95", 4, 20439},
	{"LJ96", 4, 20440},
	{"LJ97", 4, 20441},
	{"LJ98", 4, 20442},
	{"LJ99", 4, 20443},
	{"LK00", 4, 20444},
	{"LK01", 4, 20445},
	{"LK02", 4, 20446},
	{"LK03", 4, 20447},
	{"LK04", 4, 20448},
	{"LK05", 4, 20449},
	{"LK06", 4, 20450},
	{"LK07", 4, 20451},
	{"LK08", 4, 20452},
	{"LK09", 4, 20453},
	{"LK10", 4, 20454},
	{"LK11", 4, 20455},
	{"LK12", 4, 20456},
	{"LK13", 4, 20457},
	{"LK14", 4, 20458},
	{"LK15", 4, 20459},
	{"LK16", 4, 20460},
	{"LK17", 4, 20461},
	{"LK18", 4, 20462},
	{"LK19", 4, 20463},
	{"LK20", 4, 20464},
	{"LK21", 4, 20465},
	{"LK22", 4, 20466},
	{"LK23", 4, 20467},
	{"LK24", 4, 20468},
	{"LK25", 4, 20469},
	{"LK26", 4, 20470},
	{"LK27", 4, 20471},
	{"LK28", 4, 20472},
	{"LK29", 4, 20473},
	{"LK30", 4, 20474},
	{"LK31", 4, 20475},
	{"LK32", 4, 20476},
	{"LK33", 4, 20477},
	{"LK34", 4, 20478},
	{"LK35", 4, 20479},
	{"LK36", 4, 20480},
	{"LK37", 4, 20481},
	{"LK38", 4, 20482},
	{"LK39", 4, 20483},
	{"LK40", 4, 20484},
	{"LK41", 4, 20485},
	{"LK42", 4, 20486},
	{"LK43", 4, 20487},
	{"LK44", 4, 20488},
	{"LK45", 4, 20489},
	{"LK46", 4, 20490},
	{"LK47", 4, 20491},
	{"LK48", 4, 20492},
	{"LK49", 4, 20493},
	{"LK50", 4, 20494},
	{"LK51", 4, 20495},
	{"LK52", 4, 20496},
	{"LK53", 4, 20497},
	{"LK54", 4, 20498},
	{"LK55", 4, 20499},
	{"LK56", 4, 20500},
	{"LK57", 4, 20501},
	{"LK58", 4, 20502},
	{"LK59", 4, 20503},
	{"LK60", 4, 20504},
	{"LK61", 4, 20505},
	{"LK62", 4, 20506},
	{"LK63", 4, 20507},
	{"LK64", 4, 20508},
	{"LK65", 4, 20509},
	{"LK66", 4, 20510},
	{"LK67", 4, 20511},
	{"LK68", 4, 20512},
	{"LK69", 4, 20513},
	{"LK70", 4, 20514},
	{"LK71", 4, 20515},
	{"LK72", 4, 20516},
	{"LK73", 4, 20517},
	{"LK74", 4, 20518},
	{"LK75", 4, 20519},
	{"LK76", 4, 20520},
	{"LK77", 4, 20521},
	{"LK78", 4, 20522},
	{"LK79", 4, 20523},
	{"LK80", 4, 20524},
	{"LK81", 4, 20525},
	{"LK82", 4, 20526},
	{"LK83", 4, 20527},
	{"LK84", 4, 20528},
	{"LK85", 4, 20529},
	{"LK86", 4, 20530},
	{"LK87", 4, 20531},
	{"LK88", 4, 20532},
	{"LK89", 4, 20533},
	{"LK90", 4, 20534},
	{"LK91", 4, 20535},
	{"LK92", 4, 20536},
	{"LK93", 4, 20537},
	{"LK94", 4, 20538},
	{"LK95", 4, 20539},
	{"LK96", 4, 20540},
	{"LK97", 4, 20541},
	{"LK98", 4, 20542},
	{"LK99", 4, 20543},
	{"LL00", 4, 20544},
	{"LL01", 4, 20545},
	{"LL02", 4, 20546},
	{"LL03", 4, 20547},
	{"LL04", 4, 20548},
	{"LL05", 4, 20549},
	{"LL06", 4, 20550},
	{"LL07", 4, 20551},
	{"LL08", 4, 20552},
	{"LL09", 4, 20553},
	{"LL10", 4, 20554},
	{"LL11", 4, 20555},
	{"LL12", 4, 20556},
	{"LL13", 4, 20557},
	{"LL14", 4, 20558},
	{"LL15", 4, 20559},
	{"LL16", 4, 20560},
	{"LL17", 4, 20561},
	{"LL18", 4, 20562},
	{"LL19", 4, 20563},
	{"LL20", 4, 20564},
	{"LL21", 4, 20565},
	{"LL22", 4, 20566},
	{"LL23", 4, 20567},
	{"LL24", 4, 20568},
	{"LL25", 4, 20569},
	{"LL26", 4, 20570},
	{"LL27", 4, 20571},
	{"LL28", 4, 20572},
	{"LL29", 4, 20573},
	{"LL30", 4, 20574},
	{"LL31", 4, 20575},
	{"LL32", 4, 20576},
	{"LL33", 4, 20577},
	{"LL34", 4, 20578},
	{"LL35", 4, 20579},
	{"LL36", 4, 20580},
	{"LL37", 4, 20581},
	{"LL38", 4, 20582},
	{"LL39", 4, 20583},
	{"LL40", 4, 20584},
	{"LL41", 4, 20585},
	{"LL42", 4, 20586},
	{"LL43", 4, 20587},
	{"LL44", 4, 20588},
	{"LL45", 4, 20589},
	{"LL46", 4, 20590},
	{"LL47", 4, 20591},
	{"LL48", 4, 20592},
	{"LL49", 4, 20593},
	{"LL50", 4, 20594},
	{"LL51", 4, 20595},
	{"LL52", 4, 20596},
	{"LL53", 4, 20597},
	{"LL54", 4, 20598},
	{"LL55", 4, 20599},
	{"LL56", 4, 20600},
	{"LL57", 4, 20601},
	{"LL58", 4, 20602},
	{"LL59", 4, 20603},
	{"LL60", 4, 20604},
	{"LL61", 4, 20605},
	{"LL62", 4, 20606},
	{"LL63", 4, 20607},
	{"LL64", 4, 20608},
	{"LL65", 4, 20609},
	{"LL66", 4, 20610},
	{"LL67", 4, 20611},
	{"LL68", 4, 20612},
	{"LL69", 4, 20613},
	{"LL70", 4, 20614},
	{"LL71", 4, 20615},
	{"LL72", 4, 20616},
	{"LL73", 4, 20617},
	{"LL74", 4, 20618},
	{"LL75", 4, 20619},
	{"LL76", 4, 20620},
	{"LL77", 4, 20621},
	{"LL78", 4, 20622},
	{"LL79", 4, 20623},
	{"LL80", 4, 20624},
	{"LL81", 4, 20625},
	{"LL82", 4, 20626},
	{"LL83", 4, 20627},
	{"LL84", 4, 20628},
	{"LL85", 4, 20629},
	{"LL86", 4, 20630},
	{"LL87", 4, 20631},
	{"LL88", 4, 20632},
	{"LL89", 4, 20633},
	{"LL90", 4, 20634},
	{"LL91", 4, 20635},
	{"LL92", 4, 20636},
	{"LL93", 4, 20637},
	{"LL94", 4, 20638},
	{"LL95", 4, 20639},
	{"LL96", 4, 20640},
	{"LL97", 4, 20641},
	{"LL98", 4, 20642},
	{"LL99", 4, 20643},
	{"LM00", 4, 20644},
	{"LM01", 4, 20645},
	{"LM02", 4, 20646},
	{"LM03", 4, 20647},
	{"LM04", 4, 20648},
	{"LM05", 4, 20649},
	{"LM06", 4, 20650},
	{"LM07", 4, 20651},
	{"LM08", 4, 20652},
	{"LM09", 4, 20653},
	{"LM10", 4, 20654},
	{"LM11", 4, 20655},
	{"LM12", 4, 20656},
	{"LM13", 4, 20657},
	{"LM14", 4, 20658},
	{"LM15", 4, 20659},
	{"LM16", 4, 20660},
	{"LM17", 4, 20661},
	{"LM18", 4, 20662},
	{"LM19", 4, 20663},
	{"LM20", 4, 20664},
	{"LM21", 4, 20665},
	{"LM22", 4, 20666},
	{"LM23", 4, 20667},
	{"LM24", 4, 20668},
	{"LM25", 4, 20669},
	{"LM26", 4, 20670},
	{"LM27", 4, 20671},
	{"LM28", 4, 20672},
	{"LM29", 4, 20673},
	{"LM30", 4, 20674},
	{"LM31", 4, 20675},
	{"LM32", 4, 20676},
	{"LM33", 4, 20677},
	{"LM34", 4, 20678},
	{"LM35", 4, 20679},
	{"LM36", 4, 20680},
	{"LM37", 4, 20681},
	{"LM38", 4, 20682},
	{"LM39", 4, 20683},
	{"LM40", 4, 20684},
	{"LM41", 4, 20685},
	{"LM42", 4, 20686},
	{"LM43", 4, 20687},
	{"LM44", 4, 20688},
	{"LM45", 4, 20689},
	{"LM46", 4, 20690},
	{"LM47", 4, 20691},
	{"LM48", 4, 20692},
	{"LM49", 4, 20693},
	{"LM50", 4, 20694},
	{"LM51", 4, 20695},
	{"LM52", 4, 20696},
	{"LM53", 4, 20697},
	{"LM54", 4, 20698},
	{"LM55", 4, 20699},
	{"LM56", 4, 20700},
	{"LM57", 4, 20701},
	{"LM58", 4, 20702},
	{"LM59", 4, 20703},
	{"LM60", 4, 20704},
	{"LM61", 4, 20705},
	{"LM62", 4, 20706},
	{"LM63", 4, 20707},
	{"LM64", 4, 20708},
	{"LM65", 4, 20709},
	{"LM66", 4, 20710},
	{"LM67", 4, 20711},
	{"LM68", 4, 20712},
	{"LM69", 4, 20713},
	{"LM70", 4, 20714},
	{"LM71", 4, 20715},
	{"LM72", 4, 20716},
	{"LM73", 4, 20717},
	{"LM74", 4, 20718},
	{"LM75", 4, 20719},
	{"LM76", 4, 20720},
	{"LM77", 4, 20721},
	{"LM78", 4, 20722},
	{"LM79", 4, 20723},
	{"LM80", 4, 20724},
	{"LM81", 4, 20725},
	{"LM82", 4, 20726},
	{"LM83", 4, 20727},
	{"LM84", 4, 20728},
	{"LM85", 4, 20729},
	{"LM86", 4, 20730},
	{"LM87", 4, 20731},
	{"LM88", 4, 20732},
	{"LM89", 4, 20733},
	{"LM90", 4, 20734},
	{"LM91", 4, 20735},
	{"LM92", 4, 20736},
	{"LM93", 4, 20737},
	{"LM94", 4, 20738},
	{"LM95", 4, 20739},
	{"LM96", 4, 20740},
	{"LM97", 4, 20741},
	{"LM98", 4, 20742},
	{"LM99", 4, 20743},
	{"LN00", 4, 20744},
	{"LN01", 4, 20745},
	{"LN02", 4, 20746},
	{"LN03", 4, 20747},
	{"LN04", 4, 20748},
	{"LN05", 4, 20749},
	{"LN06", 4, 20750},
	{"LN07", 4, 20751},
	{"LN08", 4, 20752},
	{"LN09", 4, 20753},
	{"LN10", 4, 20754},
	{"LN11", 4, 20755},
	{"LN12", 4, 20756},
	{"LN13", 4, 20757},
	{"LN14", 4, 20758},
	{"LN15", 4, 20759},
	{"LN16", 4, 20760},
	{"LN17", 4, 20761},
	{"LN18", 4, 20762},
	{"LN19", 4, 20763},
	{"LN20", 4, 20764},
	{"LN21", 4, 20765},
	{"LN22", 4, 20766},
	{"LN23", 4, 20767},
	{"LN24", 4, 20768},
	{"LN25", 4, 20769},
	{"LN26", 4, 20770},
	{"LN27", 4, 20771},
	{"LN28", 4, 20772},
	{"LN29", 4, 20773},
	{"LN30", 4, 20774},
	{"LN31", 4, 20775},
	{"LN32", 4, 20776},
	{"LN33", 4, 20777},
	{"LN34", 4, 20778},
	{"LN35", 4, 20779},
	{"LN36", 4, 20780},
	{"LN37", 4, 20781},
	{"LN38", 4, 20782},
	{"LN39", 4, 20783},
	{"LN40", 4, 20784},
	{"LN41", 4, 20785},
	{"LN42", 4, 20786},
	{"LN43", 4, 20787},
	{"LN44", 4, 20788},
	{"LN45", 4, 20789},
	{"LN46", 4, 20790},
	{"LN47", 4, 20791},
	{"LN48", 4, 20792},
	{"LN49", 4, 20793},
	{"LN50", 4, 20794},
	{"LN51", 4, 20795},
	{"LN52", 4, 20796},
	{"LN53", 4, 20797},
	{"LN54", 4, 20798},
	{"LN55", 4, 20799},
	{"LN56", 4, 20800},
	{"LN57", 4, 20801},
	{"LN58", 4, 20802},
	{"LN59", 4, 20803},
	{"LN60", 4, 20804},
	{"LN61", 4, 20805},
	{"LN62", 4, 20806},
	{"LN63", 4, 20807},
	{"LN64", 4, 20808},
	{"LN65", 4, 20809},
	{"LN66", 4, 20810},
	{"LN67", 4, 20811},
	{"LN68", 4, 20812},
	{"LN69", 4, 20813},
	{"LN70", 4, 20814},
	{"LN71", 4, 20815},
	{"LN72", 4, 20816},
	{"LN73", 4, 20817},
	{"LN74", 4, 20818},
	{"LN75", 4, 20819},
	{"LN76", 4, 20820},
	{"LN77", 4, 20821},
	{"LN78", 4, 20822},
	{"LN79", 4, 20823},
	{"LN80", 4, 20824},
	{"LN81", 4, 20825},
	{"LN82", 4, 20826},
	{"LN83", 4, 20827},
	{"LN84", 4, 20828},
	{"LN85", 4, 20829},
	{"LN86", 4, 20830},
	{"LN87", 4, 20831},
	{"LN88", 4, 20832},
	{"LN89", 4, 20833},
	{"LN90", 4, 20834},
	{"LN91", 4, 20835},
	{"LN92", 4, 20836},
	{"LN93", 4, 20837},
	{"LN94", 4, 20838},
	{"LN95", 4, 20839},
	{"LN96", 4, 20840},
	{"LN97", 4, 20841},
	{"LN98", 4, 20842},
	{"LN99", 4, 20843},
	{"LO00", 4, 20844},
	{"LO01", 4, 20845},
	{"LO02", 4, 20846},
	{"LO03", 4, 20847},
	{"LO04", 4, 20848},
	{"LO05", 4, 20849},
	{"LO06", 4, 20850},
	{"LO07", 4, 20851},
	{"LO08", 4, 20852},
	{"LO09", 4, 20853},
	{"LO10", 4, 20854},
	{"LO11", 4, 20855},
	{"LO12", 4, 20856},
	{"LO13", 4, 20857},
	{"LO14", 4, 20858},
	{"LO15", 4, 20859},
	{"LO16", 4, 20860},
	{"LO17", 4, 20861},
	{"LO18", 4, 20862},
	{"LO19", 4, 20863},
	{"LO20", 4, 20864},
	{"LO21", 4, 20865},
	{"LO22", 4, 20866},
	{"LO23", 4, 20867},
	{"LO24", 4, 20868},
	{"LO25", 4, 20869},
	{"LO26", 4, 20870},
	{"LO27", 4, 20871},
	{"LO28", 4, 20872},
	{"LO29", 4, 20873},
	{"LO30", 4, 20874},
	{"LO31", 4, 20875},
	{"LO32", 4, 20876},
	{"LO33", 4, 20877},
	{"LO34", 4, 20878},
	{"LO35", 4, 20879},
	{"LO36", 4, 20880},
	{"LO37", 4, 20881},
	{"LO38", 4, 20882},
	{"LO39", 4, 20883},
	{"LO40", 4, 20884},
	{"LO41", 4, 20885},
	{"LO42", 4, 20886},
	{"LO43", 4, 20887},
	{"LO44", 4, 20888},
	{"LO45", 4, 20889},
	{"LO46", 4, 20890},
	{"LO47", 4, 20891},
	{"LO48", 4, 20892},
	{"LO49", 4, 20893},
	{"LO50", 4, 20894},
	{"LO51", 4, 20895},
	{"LO52", 4, 20896},
	{"LO53", 4, 20897},
	{"LO54", 4, 20898},
	{"LO55", 4, 20899},
	{"LO56", 4, 20900},
	{"LO57", 4, 20901},
	{"LO58", 4, 20902},
	{"LO59", 4, 20903},
	{"LO60", 4, 20904},
	{"LO61", 4, 20905},
	{"LO62", 4, 20906},
	{"LO63", 4, 20907},
	{"LO64", 4, 20908},
	{"LO65", 4, 20909},
	{"LO66", 4, 20910},
	{"LO67", 4, 20911},
	{"LO68", 4, 20912},
	{"LO69", 4, 20913},
	{"LO70", 4, 20914},
	{"LO71", 4, 20915},
	{"LO72", 4, 20916},
	{"LO73", 4, 20917},
	{"LO74", 4, 20918},
	{"LO75", 4, 20919},
	{"LO76", 4, 20920},
	{"LO77", 4, 20921},
	{"LO78", 4, 20922},
	{"LO79", 4, 20923},
	{"LO80", 4, 20924},
	{"LO81", 4, 20925},
	{"LO82", 4, 20926},
	{"LO83", 4, 20927},
	{"LO84", 4, 20928},
	{"LO85", 4, 20929},
	{"LO86", 4, 20930},
	{"LO87", 4, 20931},
	{"LO88", 4, 20932},
	{"LO89", 4, 20933},
	{"LO90", 4, 20934},
	{"LO91", 4, 20935},
	{"LO92", 4, 20936},
	{"LO93", 4, 20937},
	{"LO94", 4, 20938},
	{"LO95", 4, 20939},
	{"LO96", 4, 20940},
	{"LO97", 4, 20941},
	{"LO98", 4, 20942},
	{"LO99", 4, 20943},
	{"LP00", 4, 20944},
	{"LP01", 4, 20945},
	{"LP02", 4, 20946},
	{"LP03", 4, 20947},
	{"LP04", 4, 20948},
	{"LP05", 4, 20949},
	{"LP06", 4, 20950},
	{"LP07", 4, 20951},
	{"LP08", 4, 20952},
	{"LP09", 4, 20953},
	{"LP10", 4, 20954},
	{"LP11", 4, 20955},
	{"LP12", 4, 20956},
	{"LP13", 4, 20957},
	{"LP14", 4, 20958},
	{"LP15", 4, 20959},
	{"LP16", 4, 20960},
	{"LP17", 4, 20961},
	{"LP18", 4, 20962},
	{"LP19", 4, 20963},
	{"LP20", 4, 20964},
	{"LP21", 4, 20965},
	{"LP22", 4, 20966},
	{"LP23", 4, 20967},
	{"LP24", 4, 20968},
	{"LP25", 4, 20969},
	{"LP26", 4, 20970},
	{"LP27", 4, 20971},
	{"LP28", 4, 20972},
	{"LP29", 4, 20973},
	{"LP30", 4, 20974},
	{"LP31", 4, 20975},
	{"LP32", 4, 20976},
	{"LP33", 4, 20977},
	{"LP34", 4, 20978},
	{"LP35", 4, 20979},
	{"LP36", 4, 20980},
	{"LP37", 4, 20981},
	{"LP38", 4, 20982},
	{"LP39", 4, 20983},
	{"LP40", 4, 20984},
	{"LP41", 4, 20985},
	{"LP42", 4, 20986},
	{"LP43", 4, 20987},
	{"LP44", 4, 20988},
	{"LP45", 4, 20989},
	{"LP46", 4, 20990},
	{"LP47", 4, 20991},
	{"LP48", 4, 20992},
	{"LP49", 4, 20993},
	{"LP50", 4, 20994},
	{"LP51", 4, 20995},
	{"LP52", 4, 20996},
	{"LP53", 4, 20997},
	{"LP54", 4, 20998},
	{"LP55", 4, 20999},
	{"LP56", 4, 21000},
	{"LP57", 4, 21001},
	{"LP58", 4, 21002},
	{"LP59", 4, 21003},
	{"LP60", 4, 21004},
	{"LP61", 4, 21005},
	{"LP62", 4, 21006},
	{"LP63", 4, 21007},
	{"LP64", 4, 21008},
	{"LP65", 4, 21009},
	{"LP66", 4, 21010},
	{"LP67", 4, 21011},
	{"LP68", 4, 21012},
	{"LP69", 4, 21013},
	{"LP70", 4, 21014},
	{"LP71", 4, 21015},
	{"LP72", 4, 21016},
	{"LP73", 4, 21017},
	{"LP74", 4, 21018},
	{"LP75", 4, 21019},
	{"LP76", 4, 21020},
	{"LP77", 4, 21021},
	{"LP78", 4, 21022},
	{"LP79", 4, 21023},
	{"LP80", 4, 21024},
	{"LP81", 4, 21025},
	{"LP82", 4, 21026},
	{"LP83", 4, 21027},
	{"LP84", 4, 21028},
	{"LP85", 4, 21029},
	{"LP86", 4, 21030},
	{"LP87", 4, 21031},
	{"LP88", 4, 21032},
	{"LP89", 4, 21033},
	{"LP90", 4, 21034},
	{"LP91", 4, 21035},
	{"LP92", 4, 21036},
	{"LP93", 4, 21037},
	{"LP94", 4, 21038},
	{"LP95", 4, 21039},
	{"LP96", 4, 21040},
	{"LP97", 4, 21041},
	{"LP98", 4, 21042},
	{"LP99", 4, 21043},
	{"LQ00", 4, 21044},
	{"LQ01", 4, 21045},
	{"LQ02", 4, 21046},
	{"LQ03", 4, 21047},
	{"LQ04", 4, 21048},
	{"LQ05", 4, 21049},
	{"LQ06", 4, 21050},
	{"LQ07", 4, 21051},
	{"LQ08", 4, 21052},
	{"LQ09", 4, 21053},
	{"LQ10", 4, 21054},
	{"LQ11", 4, 21055},
	{"LQ12", 4, 21056},
	{"LQ13", 4, 21057},
	{"LQ14", 4, 21058},
	{"LQ15", 4, 21059},
	{"LQ16", 4, 21060},
	{"LQ17", 4, 21061},
	{"LQ18", 4, 21062},
	{"LQ19", 4, 21063},
	{"LQ20", 4, 21064},
	{"LQ21", 4, 21065},
	{"LQ22", 4, 21066},
	{"LQ23", 4, 21067},
	{"LQ24", 4, 21068},
	{"LQ25", 4, 21069},
	{"LQ26", 4, 21070},
	{"LQ27", 4, 21071},
	{"LQ28", 4, 21072},
	{"LQ29", 4, 21073},
	{"LQ30", 4, 21074},
	{"LQ31", 4, 21075},
	{"LQ32", 4, 21076},
	{"LQ33", 4, 21077},
	{"LQ34", 4, 21078},
	{"LQ35", 4, 21079},
	{"LQ36", 4, 21080},
	{"LQ37", 4, 21081},
	{"LQ38", 4, 21082},
	{"LQ39", 4, 21083},
	{"LQ40", 4, 21084},
	{"LQ41", 4, 21085},
	{"LQ42", 4, 21086},
	{"LQ43", 4, 21087},
	{"LQ44", 4, 21088},
	{"LQ45", 4, 21089},
	{"LQ46", 4, 21090},
	{"LQ47", 4, 21091},
	{"LQ48", 4, 21092},
	{"LQ49", 4, 21093},
	{"LQ50", 4, 21094},
	{"LQ51", 4, 21095},
	{"LQ52", 4, 21096},
	{"LQ53", 4, 21097},
	{"LQ54", 4, 21098},
	{"LQ55", 4, 21099},
	{"LQ56", 4, 21100},
	{"LQ57", 4, 21101},
	{"LQ58", 4, 21102},
	{"LQ59", 4, 21103},
	{"LQ60", 4, 21104},
	{"LQ61", 4, 21105},
	{"LQ62", 4, 21106},
	{"LQ63", 4, 21107},
	{"LQ64", 4, 21108},
	{"LQ65", 4, 21109},
	{"LQ66", 4, 21110},
	{"LQ67", 4, 21111},
	{"LQ68", 4, 21112},
	{"LQ69", 4, 21113},
	{"LQ70", 4, 21114},
	{"LQ71", 4, 21115},
	{"LQ72", 4, 21116},
	{"LQ73", 4, 21117},
	{"LQ74", 4, 21118},
	{"LQ75", 4, 21119},
	{"LQ76", 4, 21120},
	{"LQ77", 4, 21121},
	{"LQ78", 4, 21122},
	{"LQ79", 4, 21123},
	{"LQ80", 4, 21124},
	{"LQ81", 4, 21125},
	{"LQ82", 4, 21126},
	{"LQ83", 4, 21127},
	{"LQ84", 4, 21128},
	{"LQ85", 4, 21129},
	{"LQ86", 4, 21130},
	{"LQ87", 4, 21131},
	{"LQ88", 4, 21132},
	{"LQ89", 4, 21133},
	{"LQ90", 4, 21134},
	{"LQ91", 4, 21135},
	{"LQ92", 4, 21136},
	{"LQ93", 4, 21137},
	{"LQ94", 4, 21138},
	{"LQ95", 4, 21139},
	{"LQ96", 4, 21140},
	{"LQ97", 4, 21141},
	{"LQ98", 4, 21142},
	{"LQ99", 4, 21143},
	{"MB00", 4, 21144},
	{"MB01", 4, 21145},
	{"MB02", 4, 21146},
	{"MB03", 4, 21147},
	{"MB04", 4, 21148},
	{"MB05", 4, 21149},
	{"MB06", 4, 21150},
	{"MB07", 4, 21151},
	{"MB08", 4, 21152},
	{"MB09", 4, 21153},
	{"MB10", 4, 21154},
	{"MB11", 4, 21155},
	{"MB12", 4, 21156},
	{"MB13", 4, 21157},
	{"MB14", 4, 21158},
	{"MB15", 4, 21159},
	{"MB16", 4, 21160},
	{"MB17", 4, 21161},
	{"MB18", 4, 21162},
	{"MB19", 4, 21163},
	{"MB20", 4, 21164},
	{"MB21", 4, 21165},
	{"MB22", 4, 21166},
	{"MB23", 4, 21167},
	{"MB24", 4, 21168},
	{"MB25", 4, 21169},
	{"MB26", 4, 21170},
	{"MB27", 4, 21171},
	{"MB28", 4, 21172},
	{"MB29", 4, 21173},
	{"MB30", 4, 21174},
	{"MB31", 4, 21175},
	{"MB32", 4, 21176},
	{"MB33", 4, 21177},
	{"MB34", 4, 21178},
	{"MB35", 4, 21179},
	{"MB36", 4, 21180},
	{"MB37", 4, 21181},
	{"MB38", 4, 21182},
	{"MB39", 4, 21183},
	{"MB40", 4, 21184},
	{"MB41", 4, 21185},
	{"MB42", 4, 21186},
	{"MB43", 4, 21187},
	{"MB44", 4, 21188},
	{"MB45", 4, 21189},
	{"MB46", 4, 21190},
	{"MB47", 4, 21191},
	{"MB48", 4, 21192},
	{"MB49", 4, 21193},
	{"MB50", 4, 21194},
	{"MB51", 4, 21195},
	{"MB52", 4, 21196},
	{"MB53", 4, 21197},
	{"MB54", 4, 21198},
	{"MB55", 4, 21199},
	{"MB56", 4, 21200},
	{"MB57", 4, 21201},
	{"MB58", 4, 21202},
	{"MB59", 4, 21203},
	{"MB60", 4, 21204},
	{"MB61", 4, 21205},
	{"MB62", 4, 21206},
	{"MB63", 4, 21207},
	{"MB64", 4, 21208},
	{"MB65", 4, 21209},
	{"MB66", 4, 21210},
	{"MB67", 4, 21211},
	{"MB68", 4, 21212},
	{"MB69", 4, 21213},
	{"MB70", 4, 21214},
	{"MB71", 4, 21215},
	{"MB72", 4, 21216},
	{"MB73", 4, 21217},
	{"MB74", 4, 21218},
	{"MB75", 4, 21219},
	{"MB76", 4, 21220},
	{"MB77", 4, 21221},
	{"MB78", 4, 21222},
	{"MB79", 4, 21223},
	{"MB80", 4, 21224},
	{"MB81", 4, 21225},
	{"MB82", 4, 21226},
	{"MB83", 4, 21227},
	{"MB84", 4, 21228},
	{"MB85", 4, 21229},
	{"MB86", 4, 21230},
	{"MB87", 4, 21231},
	{"MB88", 4, 21232},
	{"MB89", 4, 21233},
	{"MB90", 4, 21234},
	{"MB91", 4, 21235},
	{"MB92", 4, 21236},
	{"MB93", 4, 21237},
	{"MB94", 4, 21238},
	{"MB95", 4, 21239},
	{"MB96", 4, 21240},
	{"MB97", 4, 21241},
	{"MB98", 4, 21242},
	{"MB99", 4, 21243},
	{"MC00", 4, 21244},
	{"MC01", 4, 21245},
	{"MC02", 4, 21246},
	{"MC03", 4, 21247},
	{"MC04", 4, 21248},
	{"MC05", 4, 21249},
	{"MC06", 4, 21250},
	{"MC07", 4, 21251},
	{"MC08", 4, 21252},
	{"MC09", 4, 21253},
	{"MC10", 4, 21254},
	{"MC11", 4, 21255},
	{"MC12", 4, 21256},
	{"MC13", 4, 21257},
	{"MC14", 4, 21258},
	{"MC15", 4, 21259},
	{"MC16", 4, 21260},
	{"MC17", 4, 21261},
	{"MC18", 4, 21262},
	{"MC19", 4, 21263},
	{"MC20", 4, 21264},
	{"MC21", 4, 21265},
	{"MC22", 4, 21266},
	{"MC23", 4, 21267},
	{"MC24", 4, 21268},
	{"MC25", 4, 21269},
	{"MC26", 4, 21270},
	{"MC27", 4, 21271},
	{"MC28", 4, 21272},
	{"MC29", 4, 21273},
	{"MC30", 4, 21274},
	{"MC31", 4, 21275},
	{"MC32", 4, 21276},
	{"MC33", 4, 21277},
	{"MC34", 4, 21278},
	{"MC35", 4, 21279},
	{"MC36", 4, 21280},
	{"MC37", 4, 21281},
	{"MC38", 4, 21282},
	{"MC39", 4, 21283},
	{"MC40", 4, 21284},
	{"MC41", 4, 21285},
	{"MC42", 4, 21286},
	{"MC43", 4, 21287},
	{"MC44", 4, 21288},
	{"MC45", 4, 21289},
	{"MC46", 4, 21290},
	{"MC47", 4, 21291},
	{"MC48", 4, 21292},
	{"MC49", 4, 21293},
	{"MC50", 4, 21294},
	{"MC51", 4, 21295},
	{"MC52", 4, 21296},
	{"MC53", 4, 21297},
	{"MC54", 4, 21298},
	{"MC55", 4, 21299},
	{"MC56", 4, 21300},
	{"MC57", 4, 21301},
	{"MC58", 4, 21302},
	{"MC59", 4, 21303},
	{"MC60", 4, 21304},
	{"MC61", 4, 21305},
	{"MC62", 4, 21306},
	{"MC63", 4, 21307},
	{"MC64", 4, 21308},
	{"MC65", 4, 21309},
	{"MC66", 4, 21310},
	{"MC67", 4, 21311},
	{"MC68", 4, 21312},
	{"MC69", 4, 21313},
	{"MC70", 4, 21314},
	{"MC71", 4, 21315},
	{"MC72", 4, 21316},
	{"MC73", 4, 21317},
	{"MC74", 4, 21318},
	{"MC75", 4, 21319},
	{"MC76", 4, 21320},
	{"MC77", 4, 21321},
	{"MC78", 4, 21322},
	{"MC79", 4, 21323},
	{"MC80", 4, 21324},
	{"MC81", 4, 21325},
	{"MC82", 4, 21326},
	{"MC83", 4, 21327},
	{"MC84", 4, 21328},
	{"MC85", 4, 21329},
	{"MC86", 4, 21330},
	{"MC87", 4, 21331},
	{"MC88", 4, 21332},
	{"MC89", 4, 21333},
	{"MC90", 4, 21334},
	{"MC91", 4, 21335},
	{"MC92", 4, 21336},
	{"MC93", 4, 21337},
	{"MC94", 4, 21338},
	{"MC95", 4, 21339},
	{"MC96", 4, 21340},
	{"MC97", 4, 21341},
	{"MC98", 4, 21342},
	{"MC99", 4, 21343},
	{"ME00", 4, 21344},
	{"ME01", 4, 21345},
	{"ME02", 4, 21346},
	{"ME03", 4, 21347},
	{"ME04", 4, 21348},
	{"ME05", 4, 21349},
	{"ME06", 4, 21350},
	{"ME07", 4, 21351},
	{"ME08", 4, 21352},
	{"ME09", 4, 21353},
	{"ME10", 4, 21354},
	{"ME11", 4, 21355},
	{"ME12", 4, 21356},
	{"ME13", 4, 21357},
	{"ME14", 4, 21358},
	{"ME15", 4, 21359},
	{"ME16", 4, 21360},
	{"ME17", 4, 21361},
	{"ME18", 4, 21362},
	{"ME19", 4, 21363},
	{"ME20", 4, 21364},
	{"ME21", 4, 21365},
	{"ME22", 4, 21366},
	{"ME23", 4, 21367},
	{"ME24", 4, 21368},
	{"ME25", 4, 21369},
	{"ME26", 4, 21370},
	{"ME27", 4, 21371},
	{"ME28", 4, 21372},
	{"ME29", 4, 21373},
	{"ME30", 4, 21374},
	{"ME31", 4, 21375},
	{"ME32", 4, 21376},
	{"ME33", 4, 21377},
	{"ME34", 4, 21378},
	{"ME35", 4, 21379},
	{"ME36", 4, 21380},
	{"ME37", 4, 21381},
	{"ME38", 4, 21382},
	{"ME39", 4, 21383},
	{"ME40", 4, 21384},
	{"ME41", 4, 21385},
	{"ME42", 4, 21386},
	{"ME43", 4, 21387},
	{"ME44", 4, 21388},
	{"ME45", 4, 21389},
	{"ME46", 4, 21390},
	{"ME47", 4, 21391},
	{"ME48", 4, 21392},
	{"ME49", 4, 21393},
	{"ME50", 4, 21394},
	{"ME51", 4, 21395},
	{"ME52", 4, 21396},
	{"ME53", 4, 21397},
	{"ME54", 4, 21398},
	{"ME55", 4, 21399},
	{"ME56", 4, 21400},
	{"ME57", 4, 21401},
	{"ME58", 4, 21402},
	{"ME59", 4, 21403},
	{"ME60", 4, 21404},
	{"ME61", 4, 21405},
	{"ME62", 4, 21406},
	{"ME63", 4, 21407},
	{"ME64", 4, 21408},
	{"ME65", 4, 21409},
	{"ME66", 4, 21410},
	{"ME67", 4, 21411},
	{"ME68", 4, 21412},
	{"ME69", 4, 21413},
	{"ME70", 4, 21414},
	{"ME71", 4, 21415},
	{"ME72", 4, 21416},
	{"ME73", 4, 21417},
	{"ME74", 4, 21418},
	{"ME75", 4, 21419},
	{"ME76", 4, 21420},
	{"ME77", 4, 21421},
	{"ME78", 4, 21422},
	{"ME79", 4, 21423},
	{"ME80", 4, 21424},
	{"ME81", 4, 21425},
	{"ME82", 4, 21426},
	{"ME83", 4, 21427},
	{"ME84", 4, 21428},
	{"ME85", 4, 21429},
	{"ME86", 4, 21430},
	{"ME87", 4, 21431},
	{"ME88", 4, 21432},
	{"ME89", 4, 21433},
	{"ME90", 4, 21434},
	{"ME91", 4, 21435},
	{"ME92", 4, 21436},
	{"ME93", 4, 21437},
	{"ME94", 4, 21438},
	{"ME95", 4, 21439},
	{"ME96", 4, 21440},
	{"ME97", 4, 21441},
	{"ME98", 4, 21442},
	{"ME99", 4, 21443},
	{"MJ00", 4, 21444},
	{"MJ01", 4, 21445},
	{"MJ02", 4, 21446},
	{"MJ03", 4, 21447},
	{"MJ04", 4, 21448},
	{"MJ05", 4, 21449},
	{"MJ06", 4, 21450},
	{"MJ07", 4, 21451},
	{"MJ08", 4, 21452},
	{"MJ09", 4, 21453},
	{"MJ10", 4, 21454},
	{"MJ11", 4, 21455},
	{"MJ12", 4, 21456},
	{"MJ13", 4, 21457},
	{"MJ14", 4, 21458},
	{"MJ15", 4, 21459},
	{"MJ16", 4, 21460},
	{"MJ17", 4, 21461},
	{"MJ18", 4, 21462},
	{"MJ19", 4, 21463},
	{"MJ20", 4, 21464},
	{"MJ21", 4, 21465},
	{"MJ22", 4, 21466},
	{"MJ23", 4, 21467},
	{"MJ24", 4, 21468},
	{"MJ25", 4, 21469},
	{"MJ26", 4, 21470},
	{"MJ27", 4, 21471},
	{"MJ28", 4, 21472},
	{"MJ29", 4, 21473},
	{"MJ30", 4, 21474},
	{"MJ31", 4, 21475},
	{"MJ32", 4, 21476},
	{"MJ33", 4, 21477},
	{"MJ34", 4, 21478},
	{"MJ35", 4, 21479},
	{"MJ36", 4, 21480},
	{"MJ37", 4, 21481},
	{"MJ38", 4, 21482},
	{"MJ39", 4, 21483},
	{"MJ40", 4, 21484},
	{"MJ41", 4, 21485},
	{"MJ42", 4, 21486},
	{"MJ43", 4, 21487},
	{"MJ44", 4, 21488},
	{"MJ45", 4, 21489},
	{"MJ46", 4, 21490},
	{"MJ47", 4, 21491},
	{"MJ48", 4, 21492},
	{"MJ49", 4, 21493},
	{"MJ50", 4, 21494},
	{"MJ51", 4, 21495},
	{"MJ52", 4, 21496},
	{"MJ53", 4, 21497},
	{"MJ54", 4, 21498},
	{"MJ55", 4, 21499},
	{"MJ56", 4, 21500},
	{"MJ57", 4, 21501},
	{"MJ58", 4, 21502},
	{"MJ59", 4, 21503},
	{"MJ60", 4, 21504},
	{"MJ61", 4, 21505},
	{"MJ62", 4, 21506},
	{"MJ63", 4, 21507},
	{"MJ64", 4, 21508},
	{"MJ65", 4, 21509},
	{"MJ66", 4, 21510},
	{"MJ67", 4, 21511},
	{"MJ68", 4, 21512},
	{"MJ69", 4, 21513},
	{"MJ70", 4, 21514},
	{"MJ71", 4, 21515},
	{"MJ72", 4, 21516},
	{"MJ73", 4, 21517},
	{"MJ74", 4, 21518},
	{"MJ75", 4, 21519},
	{"MJ76", 4, 21520},
	{"MJ77", 4, 21521},
	{"MJ78", 4, 21522},
	{"MJ79", 4, 21523},
	{"MJ80", 4, 21524},
	{"MJ81", 4, 21525},
	{"MJ82", 4, 21526},
	{"MJ83", 4, 21527},
	{"MJ84", 4, 21528},
	{"MJ85", 4, 21529},
	{"MJ86", 4, 21530},
	{"MJ87", 4, 21531},
	{"MJ88", 4, 21532},
	{"MJ89", 4, 21533},
	{"MJ90", 4, 21534},
	{"MJ91", 4, 21535},
	{"MJ92", 4, 21536},
	{"MJ93", 4, 21537},
	{"MJ94", 4, 21538},
	{"MJ95", 4, 21539},
	{"MJ96", 4, 21540},
	{"MJ97", 4, 21541},
	{"MJ98", 4, 21542},
	{"MJ99", 4, 21543},
	{"MK00", 4, 21544},
	{"MK01", 4, 21545},
	{"MK02", 4, 21546},
	{"MK03", 4, 21547},
	{"MK04", 4, 21548},
	{"MK05", 4, 21549},
	{"MK06", 4, 21550},
	{"MK07", 4, 21551},
	{"MK08", 4, 21552},
	{"MK09", 4, 21553},
	{"MK10", 4, 21554},
	{"MK11", 4, 21555},
	{"MK12", 4, 21556},
	{"MK13", 4, 21557},
	{"MK14", 4, 21558},
	{"MK15", 4, 21559},
	{"MK16", 4, 21560},
	{"MK17", 4, 21561},
	{"MK18", 4, 21562},
	{"MK19", 4, 21563},
	{"MK20", 4, 21564},
	{"MK21", 4, 21565},
	{"MK22", 4, 21566},
	{"MK23", 4, 21567},
	{"MK24", 4, 21568},
	{"MK25", 4, 21569},
	{"MK26", 4, 21570},
	{"MK27", 4, 21571},
	{"MK28", 4, 21572},
	{"MK29", 4, 21573},
	{"MK30", 4, 21574},
	{"MK31", 4, 21575},
	{"MK32", 4, 21576},
	{"MK33", 4, 21577},
	{"MK34", 4, 21578},
	{"MK35", 4, 21579},
	{"MK36", 4, 21580},
	{"MK37", 4, 21581},
	{"MK38", 4, 21582},
	{"MK39", 4, 21583},
	{"MK40", 4, 21584},
	{"MK41", 4, 21585},
	{"MK42", 4, 21586},
	{"MK43", 4, 21587},
	{"MK44", 4, 21588},
	{"MK45", 4, 21589},
	{"MK46", 4, 21590},
	{"MK47", 4, 21591},
	{"MK48", 4, 21592},
	{"MK49", 4, 21593},
	{"MK50", 4, 21594},
	{"MK51", 4, 21595},
	{"MK52", 4, 21596},
	{"MK53", 4, 21597},
	{"MK54", 4, 21598},
	{"MK55", 4, 21599},
	{"MK56", 4, 21600},
	{"MK57", 4, 21601},
	{"MK58", 4, 21602},
	{"MK59", 4, 21603},
	{"MK60", 4, 21604},
	{"MK61", 4, 21605},
	{"MK62", 4, 21606},
	{"MK63", 4, 21607},
	{"MK64", 4, 21608},
	{"MK65", 4, 21609},
	{"MK66", 4, 21610},
	{"MK67", 4, 21611},
	{"MK68", 4, 21612},
	{"MK69", 4, 21613},
	{"MK70", 4, 21614},
	{"MK71", 4, 21615},
	{"MK72", 4, 21616},
	{"MK73", 4, 21617},
	{"MK74", 4, 21618},
	{"MK75", 4, 21619},
	{"MK76", 4, 21620},
	{"MK77", 4, 21621},
	{"MK78", 4, 21622},
	{"MK79", 4, 21623},
	{"MK80", 4, 21624},
	{"MK81", 4, 21625},
	{"MK82", 4, 21626},
	{"MK83", 4, 21627},
	{"MK84", 4, 21628},
	{"MK85", 4, 21629},
	{"MK86", 4, 21630},
	{"MK87", 4, 21631},
	{"MK88", 4, 21632},
	{"MK89", 4, 21633},
	{"MK90", 4, 21634},
	{"MK91", 4, 21635},
	{"MK92", 4, 21636},
	{"MK93", 4, 21637},
	{"MK94", 4, 21638},
	{"MK95", 4, 21639},
	{"MK96", 4, 21640},
	{"MK97", 4, 21641},
	{"MK98", 4, 21642},
	{"MK99", 4, 21643},
	{"ML00", 4, 21644},
	{"ML01", 4, 21645},
	{"ML02", 4, 21646},
	{"ML03", 4, 21647},
	{"ML04", 4, 21648},
	{"ML05", 4, 21649},
	{"ML06", 4, 21650},
	{"ML07", 4, 21651},
	{"ML08", 4, 21652},
	{"ML09", 4, 21653},
	{"ML10", 4, 21654},
	{"ML11", 4, 21655},
	{"ML12", 4, 21656},
	{"ML13", 4, 21657},
	{"ML14", 4, 21658},
	{"ML15", 4, 21659},
	{"ML16", 4, 21660},
	{"ML17", 4, 21661},
	{"ML18", 4, 21662},
	{"ML19", 4, 21663},
	{"ML20", 4, 21664},
	{"ML21", 4, 21665},
	{"ML22", 4, 21666},
	{"ML23", 4, 21667},
	{"ML24", 4, 21668},
	{"ML25", 4, 21669},
	{"ML26", 4, 21670},
	{"ML27", 4, 21671},
	{"ML28", 4, 21672},
	{"ML29", 4, 21673},
	{"ML30", 4, 21674},
	{"ML31", 4, 21675},
	{"ML32", 4, 21676},
	{"ML33", 4, 21677},
	{"ML34", 4, 21678},
	{"ML35", 4, 21679},
	{"ML36", 4, 21680},
	{"ML37", 4, 21681},
	{"ML38", 4, 21682},
	{"ML39", 4, 21683},
	{"ML40", 4, 21684},
	{"ML41", 4, 21685},
	{"ML42", 4, 21686},
	{"ML43", 4, 21687},
	{"ML44", 4, 21688},
	{"ML45", 4, 21689},
	{"ML46", 4, 21690},
	{"ML47", 4, 21691},
	{"ML48", 4, 21692},
	{"ML49", 4, 21693},
	{"ML50", 4, 21694},
	{"ML51", 4, 21695},
	{"ML52", 4, 21696},
	{"ML53", 4, 21697},
	{"ML54", 4, 21698},
	{"ML55", 4, 21699},
	{"ML56", 4, 21700},
	{"ML57", 4, 21701},
	{"ML58", 4, 21702},
	{"ML59", 4, 21703},
	{"ML60", 4, 21704},
	{"ML61", 4, 21705},
	{"ML62", 4, 21706},
	{"ML63", 4, 21707},
	{"ML64", 4, 21708},
	{"ML65", 4, 21709},
	{"ML66", 4, 21710},
	{"ML67", 4, 21711},
	{"ML68", 4, 21712},
	{"ML69", 4, 21713},
	{"ML70", 4, 21714},
	{"ML71", 4, 21715},
	{"ML72", 4, 21716},
	{"ML73", 4, 21717},
	{"ML74", 4, 21718},
	{"ML75", 4, 21719},
	{"ML76", 4, 21720},
	{"ML77", 4, 21721},
	{"ML78", 4, 21722},
	{"ML79", 4, 21723},
	{"ML80", 4, 21724},
	{"ML81", 4, 21725},
	{"ML82", 4, 21726},
	{"ML83", 4, 21727},
	{"ML84", 4, 21728},
	{"ML85", 4, 21729},
	{"ML86", 4, 21730},
	{"ML87", 4, 21731},
	{"ML88", 4, 21732},
	{"ML89", 4, 21733},
	{"ML90", 4, 21734},
	{"ML91", 4, 21735},
	{"ML92", 4, 21736},
	{"ML93", 4, 21737},
	{"ML94", 4, 21738},
	{"ML95", 4, 21739},
	{"ML96", 4, 21740},
	{"ML97", 4, 21741},
	{"ML98", 4, 21742},
	{"ML99", 4, 21743},
	{"MM00", 4, 21744},
	{"MM01", 4, 21745},
	{"MM02", 4, 21746},
	{"MM03", 4, 21747},
	{"MM04", 4, 21748},
	{"MM05", 4, 21749},
	{"MM06", 4, 21750},
	{"MM07", 4, 21751},
	{"MM08", 4, 21752},
	{"MM09", 4, 21753},
	{"MM10", 4, 21754},
	{"MM11", 4, 21755},
	{"MM12", 4, 21756},
	{"MM13", 4, 21757},
	{"MM14", 4, 21758},
	{"MM15", 4, 21759},
	{"MM16", 4, 21760},
	{"MM17", 4, 21761},
	{"MM18", 4, 21762},
	{"MM19", 4, 21763},
	{"MM20", 4, 21764},
	{"MM21", 4, 21765},
	{"MM22", 4, 21766},
	{"MM23", 4, 21767},
	{"MM24", 4, 21768},
	{"MM25", 4, 21769},
	{"MM26", 4, 21770},
	{"MM27", 4, 21771},
	{"MM28", 4, 21772},
	{"MM29", 4, 21773},
	{"MM30", 4, 21774},
	{"MM31", 4, 21775},
	{"MM32", 4, 21776},
	{"MM33", 4, 21777},
	{"MM34", 4, 21778},
	{"MM35", 4, 21779},
	{"MM36", 4, 21780},
	{"MM37", 4, 21781},
	{"MM38", 4, 21782},
	{"MM39", 4, 21783},
	{"MM40", 4, 21784},
	{"MM41", 4, 21785},
	{"MM42", 4, 21786},
	{"MM43", 4, 21787},
	{"MM44", 4, 21788},
	{"MM45", 4, 21789},
	{"MM46", 4, 21790},
	{"MM47", 4, 21791},
	{"MM48", 4, 21792},
	{"MM49", 4, 21793},
	{"MM50", 4, 21794},
	{"MM51", 4, 21795},
	{"MM52", 4, 21796},
	{"MM53", 4, 21797},
	{"MM54", 4, 21798},
	{"MM55", 4, 21799},
	{"MM56", 4, 21800},
	{"MM57", 4, 21801},
	{"MM58", 4, 21802},
	{"MM59", 4, 21803},
	{"MM60", 4, 21804},
	{"MM61", 4, 21805},
	{"MM62", 4, 21806},
	{"MM63", 4, 21807},
	{"MM64", 4, 21808},
	{"MM65", 4, 21809},
	{"MM66", 4, 21810},
	{"MM67", 4, 21811},
	{"MM68", 4, 21812},
	{"MM69", 4, 21813},
	{"MM70", 4, 21814},
	{"MM71", 4, 21815},
	{"MM72", 4, 21816},
	{"MM73", 4, 21817},
	{"MM74", 4, 21818},
	{"MM75", 4, 21819},
	{"MM76", 4, 21820},
	{"MM77", 4, 21821},
	{"MM78", 4, 21822},
	{"MM79", 4, 21823},
	{"MM80", 4, 21824},
	{"MM81", 4, 21825},
	{"MM82", 4, 21826},
	{"MM83", 4, 21827},
	{"MM84", 4, 21828},
	{"MM85", 4, 21829},
	{"MM86", 4, 21830},
	{"MM87", 4, 21831},
	{"MM88", 4, 21832},
	{"MM89", 4, 21833},
	{"MM90", 4, 21834},
	{"MM91", 4, 21835},
	{"MM92", 4, 21836},
	{"MM93", 4, 21837},
	{"MM94", 4, 21838},
	{"MM95", 4, 21839},
	{"MM96", 4, 21840},
	{"MM97", 4, 21841},
	{"MM98", 4, 21842},
	{"MM99", 4, 21843},
	{"MN00", 4, 21844},
	{"MN01", 4, 21845},
	{"MN02", 4, 21846},
	{"MN03", 4, 21847},
	{"MN04", 4, 21848},
	{"MN05", 4, 21849},
	{"MN06", 4, 21850},
	{"MN07", 4, 21851},
	{"MN08", 4, 21852},
	{"MN09", 4, 21853},
	{"MN10", 4, 21854},
	{"MN11", 4, 21855},
	{"MN12", 4, 21856},
	{"MN13", 4, 21857},
	{"MN14", 4, 21858},
	{"MN15", 4, 21859},
	{"MN16", 4, 21860},
	{"MN17", 4, 21861},
	{"MN18", 4, 21862},
	{"MN19", 4, 21863},
	{"MN20", 4, 21864},
	{"MN21", 4, 21865},
	{"MN22", 4, 21866},
	{"MN23", 4, 21867},
	{"MN24", 4, 21868},
	{"MN25", 4, 21869},
	{"MN26", 4, 21870},
	{"MN27", 4, 21871},
	{"MN28", 4, 21872},
	{"MN29", 4, 21873},
	{"MN30", 4, 21874},
	{"MN31", 4, 21875},
	{"MN32", 4, 21876},
	{"MN33", 4, 21877},
	{"MN34", 4, 21878},
	{"MN35", 4, 21879},
	{"MN36", 4, 21880},
	{"MN37", 4, 21881},
	{"MN38", 4, 21882},
	{"MN39", 4, 21883},
	{"MN40", 4, 21884},
	{"MN41", 4, 21885},
	{"MN42", 4, 21886},
	{"MN43", 4, 21887},
	{"MN44", 4, 21888},
	{"MN45", 4, 21889},
	{"MN46", 4, 21890},
	{"MN47", 4, 21891},
	{"MN48", 4, 21892},
	{"MN49", 4, 21893},
	{"MN50", 4, 21894},
	{"MN51", 4, 21895},
	{"MN52", 4, 21896},
	{"MN53", 4, 21897},
	{"MN54", 4, 21898},
	{"MN55", 4, 21899},
	{"MN56", 4, 21900},
	{"MN57", 4, 21901},
	{"MN58", 4, 21902},
	{"MN59", 4, 21903},
	{"MN60", 4, 21904},
	{"MN61", 4, 21905},
	{"MN62", 4, 21906},
	{"MN63", 4, 21907},
	{"MN64", 4, 21908},
	{"MN65", 4, 21909},
	{"MN66", 4, 21910},
	{"MN67", 4, 21911},
	{"MN68", 4, 21912},
	{"MN69", 4, 21913},
	{"MN70", 4, 21914},
	{"MN71", 4, 21915},
	{"MN72", 4, 21916},
	{"MN73", 4, 21917},
	{"MN74", 4, 21918},
	{"MN75", 4, 21919},
	{"MN76", 4, 21920},
	{"MN77", 4, 21921},
	{"MN78", 4, 21922},
	{"MN79", 4, 21923},
	{"MN80", 4, 21924},
	{"MN81", 4, 21925},
	{"MN82", 4, 21926},
	{"MN83", 4, 21927},
	{"MN84", 4, 21928},
	{"MN85", 4, 21929},
	{"MN86", 4, 21930},
	{"MN87", 4, 21931},
	{"MN88", 4, 21932},
	{"MN89", 4, 21933},
	{"MN90", 4, 21934},
	{"MN91", 4, 21935},
	{"MN92", 4, 21936},
	{"MN93", 4, 21937},
	{"MN94", 4, 21938},
	{"MN95", 4, 21939},
	{"MN96", 4, 21940},
	{"MN97", 4, 21941},
	{"MN98", 4, 21942},
	{"MN99", 4, 21943},
	{"MO00", 4, 21944},
	{"MO01", 4, 21945},
	{"MO02", 4, 21946},
	{"MO03", 4, 21947},
	{"MO04", 4, 21948},
	{"MO05", 4, 21949},
	{"MO06", 4, 21950},
	{"MO07", 4, 21951},
	{"MO08", 4, 21952},
	{"MO09", 4, 21953},
	{"MO10", 4, 21954},
	{"MO11", 4, 21955},
	{"MO12", 4, 21956},
	{"MO13", 4, 21957},
	{"MO14", 4, 21958},
	{"MO15", 4, 21959},
	{"MO16", 4, 21960},
	{"MO17", 4, 21961},
	{"MO18", 4, 21962},
	{"MO19", 4, 21963},
	{"MO20", 4, 21964},
	{"MO21", 4, 21965},
	{"MO22", 4, 21966},
	{"MO23", 4, 21967},
	{"MO24", 4, 21968},
	{"MO25", 4, 21969},
	{"MO26", 4, 21970},
	{"MO27", 4, 21971},
	{"MO28", 4, 21972},
	{"MO29", 4, 21973},
	{"MO30", 4, 21974},
	{"MO31", 4, 21975},
	{"MO32", 4, 21976},
	{"MO33", 4, 21977},
	{"MO34", 4, 21978},
	{"MO35", 4, 21979},
	{"MO36", 4, 21980},
	{"MO37", 4, 21981},
	{"MO38", 4, 21982},
	{"MO39", 4, 21983},
	{"MO40", 4, 21984},
	{"MO41", 4, 21985},
	{"MO42", 4, 21986},
	{"MO43", 4, 21987},
	{"MO44", 4, 21988},
	{"MO45", 4, 21989},
	{"MO46", 4, 21990},
	{"MO47", 4, 21991},
	{"MO48", 4, 21992},
	{"MO49", 4, 21993},
	{"MO50", 4, 21994},
	{"MO51", 4, 21995},
	{"MO52", 4, 21996},
	{"MO53", 4, 21997},
	{"MO54", 4, 21998},
	{"MO55", 4, 21999},
	{"MO56", 4, 22000},
	{"MO57", 4, 22001},
	{"MO58", 4, 22002},
	{"MO59", 4, 22003},
	{"MO60", 4, 22004},
	{"MO61", 4, 22005},
	{"MO62", 4, 22006},
	{"MO63", 4, 22007},
	{"MO64", 4, 22008},
	{"MO65", 4, 22009},
	{"MO66", 4, 22010},
	{"MO67", 4, 22011},
	{"MO68", 4, 22012},
	{"MO69", 4, 22013},
	{"MO70", 4, 22014},
	{"MO71", 4, 22015},
	{"MO72", 4, 22016},
	{"MO73", 4, 22017},
	{"MO74", 4, 22018},
	{"MO75", 4, 22019},
	{"MO76", 4, 22020},
	{"MO77", 4, 22021},
	{"MO78", 4, 22022},
	{"MO79", 4, 22023},
	{"MO80", 4, 22024},
	{"MO81", 4, 22025},
	{"MO82", 4, 22026},
	{"MO83", 4, 22027},
	{"MO84", 4, 22028},
	{"MO85", 4, 22029},
	{"MO86", 4, 22030},
	{"MO87", 4, 22031},
	{"MO88", 4, 22032},
	{"MO89", 4, 22033},
	{"MO90", 4, 22034},
	{"MO91", 4, 22035},
	{"MO92", 4, 22036},
	{"MO93", 4, 22037},
	{"MO94", 4, 22038},
	{"MO95", 4, 22039},
	{"MO96", 4, 22040},
	{"MO97", 4, 22041},
	{"MO98", 4, 22042},
	{"MO99", 4, 22043},
	{"MP00", 4, 22044},
	{"MP01", 4, 22045},
	{"MP02", 4, 22046},
	{"MP03", 4, 22047},
	{"MP04", 4, 22048},
	{"MP05", 4, 22049},
	{"MP06", 4, 22050},
	{"MP07", 4, 22051},
	{"MP08", 4, 22052},
	{"MP09", 4, 22053},
	{"MP10", 4, 22054},
	{"MP11", 4, 22055},
	{"MP12", 4, 22056},
	{"MP13", 4, 22057},
	{"MP14", 4, 22058},
	{"MP15", 4, 22059},
	{"MP16", 4, 22060},
	{"MP17", 4, 22061},
	{"MP18", 4, 22062},
	{"MP19", 4, 22063},
	{"MP20", 4, 22064},
	{"MP21", 4, 22065},
	{"MP22", 4, 22066},
	{"MP23", 4, 22067},
	{"MP24", 4, 22068},
	{"MP25", 4, 22069},
	{"MP26", 4, 22070},
	{"MP27", 4, 22071},
	{"MP28", 4, 22072},
	{"MP29", 4, 22073},
	{"MP30", 4, 22074},
	{"MP31", 4, 22075},
	{"MP32", 4, 22076},
	{"MP33", 4, 22077},
	{"MP34", 4, 22078},
	{"MP35", 4, 22079},
	{"MP36", 4, 22080},
	{"MP37", 4, 22081},
	{"MP38", 4, 22082},
	{"MP39", 4, 22083},
	{"MP40", 4, 22084},
	{"MP41", 4, 22085},
	{"MP42", 4, 22086},
	{"MP43", 4, 22087},
	{"MP44", 4, 22088},
	{"MP45", 4, 22089},
	{"MP46", 4, 22090},
	{"MP47", 4, 22091},
	{"MP48", 4, 22092},
	{"MP49", 4, 22093},
	{"MP50", 4, 22094},
	{"MP51", 4, 22095},
	{"MP52", 4, 22096},
	{"MP53", 4, 22097},
	{"MP54", 4, 22098},
	{"MP55", 4, 22099},
	{"MP56", 4, 22100},
	{"MP57", 4, 22101},
	{"MP58", 4, 22102},
	{"MP59", 4, 22103},
	{"MP60", 4, 22104},
	{"MP61", 4, 22105},
	{"MP62", 4, 22106},
	{"MP63", 4, 22107},
	{"MP64", 4, 22108},
	{"MP65", 4, 22109},
	{"MP66", 4, 22110},
	{"MP67", 4, 22111},
	{"MP68", 4, 22112},
	{"MP69", 4, 22113},
	{"MP70", 4, 22114},
	{"MP71", 4, 22115},
	{"MP72", 4, 22116},
	{"MP73", 4, 22117},
	{"MP74", 4, 22118},
	{"MP75", 4, 22119},
	{"MP76", 4, 22120},
	{"MP77", 4, 22121},
	{"MP78", 4, 22122},
	{"MP79", 4, 22123},
	{"MP80", 4, 22124},
	{"MP81", 4, 22125},
	{"MP82", 4, 22126},
	{"MP83", 4, 22127},
	{"MP84", 4, 22128},
	{"MP85", 4, 22129},
	{"MP86", 4, 22130},
	{"MP87", 4, 22131},
	{"MP88", 4, 22132},
	{"MP89", 4, 22133},
	{"MP90", 4, 22134},
	{"MP91", 4, 22135},
	{"MP92", 4, 22136},
	{"MP93", 4, 22137},
	{"MP94", 4, 22138},
	{"MP95", 4, 22139},
	{"MP96", 4, 22140},
	{"MP97", 4, 22141},
	{"MP98", 4, 22142},
	{"MP99", 4, 22143},
	{"MQ00", 4, 22144},
	{"MQ01", 4, 22145},
	{"MQ02", 4, 22146},
	{"MQ03", 4, 22147},
	{"MQ04", 4, 22148},
	{"MQ05", 4, 22149},
	{"MQ06", 4, 22150},
	{"MQ07", 4, 22151},
	{"MQ08", 4, 22152},
	{"MQ09", 4, 22153},
	{"MQ10", 4, 22154},
	{"MQ11", 4, 22155},
	{"MQ12", 4, 22156},
	{"MQ13", 4, 22157},
	{"MQ14", 4, 22158},
	{"MQ15", 4, 22159},
	{"MQ16", 4, 22160},
	{"MQ17", 4, 22161},
	{"MQ18", 4, 22162},
	{"MQ19", 4, 22163},
	{"MQ20", 4, 22164},
	{"MQ21", 4, 22165},
	{"MQ22", 4, 22166},
	{"MQ23", 4, 22167},
	{"MQ24", 4, 22168},
	{"MQ25", 4, 22169},
	{"MQ26", 4, 22170},
	{"MQ27", 4, 22171},
	{"MQ28", 4, 22172},
	{"MQ29", 4, 22173},
	{"MQ30", 4, 22174},
	{"MQ31", 4, 22175},
	{"MQ32", 4, 22176},
	{"MQ33", 4, 22177},
	{"MQ34", 4, 22178},
	{"MQ35", 4, 22179},
	{"MQ36", 4, 22180},
	{"MQ37", 4, 22181},
	{"MQ38", 4, 22182},
	{"MQ39", 4, 22183},
	{"MQ40", 4, 22184},
	{"MQ41", 4, 22185},
	{"MQ42", 4, 22186},
	{"MQ43", 4, 22187},
	{"MQ44", 4, 22188},
	{"MQ45", 4, 22189},
	{"MQ46", 4, 22190},
	{"MQ47", 4, 22191},
	{"MQ48", 4, 22192},
	{"MQ49", 4, 22193},
	{"MQ50", 4, 22194},
	{"MQ51", 4, 22195},
	{"MQ52", 4, 22196},
	{"MQ53", 4, 22197},
	{"MQ54", 4, 22198},
	{"MQ55", 4, 22199},
	{"MQ56", 4, 22200},
	{"MQ57", 4, 22201},
	{"MQ58", 4, 22202},
	{"MQ59", 4, 22203},
	{"MQ60", 4, 22204},
	{"MQ61", 4, 22205},
	{"MQ62", 4, 22206},
	{"MQ63", 4, 22207},
	{"MQ64", 4, 22208},
	{"MQ65", 4, 22209},
	{"MQ66", 4, 22210},
	{"MQ67", 4, 22211},
	{"MQ68", 4, 22212},
	{"MQ69", 4, 22213},
	{"MQ70", 4, 22214},
	{"MQ71", 4, 22215},
	{"MQ72", 4, 22216},
	{"MQ73", 4, 22217},
	{"MQ74", 4, 22218},
	{"MQ75", 4, 22219},
	{"MQ76", 4, 22220},
	{"MQ77", 4, 22221},
	{"MQ78", 4, 22222},
	{"MQ79", 4, 22223},
	{"MQ80", 4, 22224},
	{"MQ81", 4, 22225},
	{"MQ82", 4, 22226},
	{"MQ83", 4, 22227},
	{"MQ84", 4, 22228},
	{"MQ85", 4, 22229},
	{"MQ86", 4, 22230},
	{"MQ87", 4, 22231},
	{"MQ88", 4, 22232},
	{"MQ89", 4, 22233},
	{"MQ90", 4, 22234},
	{"MQ91", 4, 22235},
	{"MQ92", 4, 22236},
	{"MQ93", 4, 22237},
	{"MQ94", 4, 22238},
	{"MQ95", 4, 22239},
	{"MQ96", 4, 22240},
	{"MQ97", 4, 22241},
	{"MQ98", 4, 22242},
	{"MQ99", 4, 22243},
	{"NB00", 4, 22244},
	{"NB01", 4, 22245},
	{"NB02", 4, 22246},
	{"NB03", 4, 22247},
	{"NB04", 4, 22248},
	{"NB05", 4, 22249},
	{"NB06", 4, 22250},
	{"NB07", 4, 22251},
	{"NB08", 4, 22252},
	{"NB09", 4, 22253},
	{"NB10", 4, 22254},
	{"NB11", 4, 22255},
	{"NB12", 4, 22256},
	{"NB13", 4, 22257},
	{"NB14", 4, 22258},
	{"NB15", 4, 22259},
	{"NB16", 4, 22260},
	{"NB17", 4, 22261},
	{"NB18", 4, 22262},
	{"NB19", 4, 22263},
	{"NB20", 4, 22264},
	{"NB21", 4, 22265},
	{"NB22", 4, 22266},
	{"NB23", 4, 22267},
	{"NB24", 4, 22268},
	{"NB25", 4, 22269},
	{"NB26", 4, 22270},
	{"NB27", 4, 22271},
	{"NB28", 4, 22272},
	{"NB29", 4, 22273},
	{"NB30", 4, 22274},
	{"NB31", 4, 22275},
	{"NB32", 4, 22276},
	{"NB33", 4, 22277},
	{"NB34", 4, 22278},
	{"NB35", 4, 22279},
	{"NB36", 4, 22280},
	{"NB37", 4, 22281},
	{"NB38", 4, 22282},
	{"NB39", 4, 22283},
	{"NB40", 4, 22284},
	{"NB41", 4, 22285},
	{"NB42", 4, 22286},
	{"NB43", 4, 22287},
	{"NB44", 4, 22288},
	{"NB45", 4, 22289},
	{"NB46", 4, 22290},
	{"NB47", 4, 22291},
	{"NB48", 4, 22292},
	{"NB49", 4, 22293},
	{"NB50", 4, 22294},
	{"NB51", 4, 22295},
	{"NB52", 4, 22296},
	{"NB53", 4, 22297},
	{"NB54", 4, 22298},
	{"NB55", 4, 22299},
	{"NB56", 4, 22300},
	{"NB57", 4, 22301},
	{"NB58", 4, 22302},
	{"NB59", 4, 22303},
	{"NB60", 4, 22304},
	{"NB61", 4, 22305},
	{"NB62", 4, 22306},
	{"NB63", 4, 22307},
	{"NB64", 4, 22308},
	{"NB65", 4, 22309},
	{"NB66", 4, 22310},
	{"NB67", 4, 22311},
	{"NB68", 4, 22312},
	{"NB69", 4, 22313},
	{"NB70", 4, 22314},
	{"NB71", 4, 22315},
	{"NB72", 4, 22316},
	{"NB73", 4, 22317},
	{"NB74", 4, 22318},
	{"NB75", 4, 22319},
	{"NB76", 4, 22320},
	{"NB77", 4, 22321},
	{"NB78", 4, 22322},
	{"NB79", 4, 22323},
	{"NB80", 4, 22324},
	{"NB81", 4, 22325},
	{"NB82", 4, 22326},
	{"NB83", 4, 22327},
	{"NB84", 4, 22328},
	{"NB85", 4, 22329},
	{"NB86", 4, 22330},
	{"NB87", 4, 22331},
	{"NB88", 4, 22332},
	{"NB89", 4, 22333},
	{"NB90", 4, 22334},
	{"NB91", 4, 22335},
	{"NB92", 4, 22336},
	{"NB93", 4, 22337},
	{"NB94", 4, 22338},
	{"NB95", 4, 22339},
	{"NB96", 4, 22340},
	{"NB97", 4, 22341},
	{"NB98", 4, 22342},
	{"NB99", 4, 22343},
	{"NC00", 4, 22344},
	{"NC01", 4, 22345},
	{"NC02", 4, 22346},
	{"NC03", 4, 22347},
	{"NC04", 4, 22348},
	{"NC05", 4, 22349},
	{"NC06", 4, 22350},
	{"NC07", 4, 22351},
	{"NC08", 4, 22352},
	{"NC09", 4, 22353},
	{"NC10", 4, 22354},
	{"NC11", 4, 22355},
	{"NC12", 4, 22356},
	{"NC13", 4, 22357},
	{"NC14", 4, 22358},
	{"NC15", 4, 22359},
	{"NC16", 4, 22360},
	{"NC17", 4, 22361},
	{"NC18", 4, 22362},
	{"NC19", 4, 22363},
	{"NC20", 4, 22364},
	{"NC21", 4, 22365},
	{"NC22", 4, 22366},
	{"NC23", 4, 22367},
	{"NC24", 4, 22368},
	{"NC25", 4, 22369},
	{"NC26", 4, 22370},
	{"NC27", 4, 22371},
	{"NC28", 4, 22372},
	{"NC29", 4, 22373},
	{"NC30", 4, 22374},
	{"NC31", 4, 22375},
	{"NC32", 4, 22376},
	{"NC33", 4, 22377},
	{"NC34", 4, 22378},
	{"NC35", 4, 22379},
	{"NC36", 4, 22380},
	{"NC37", 4, 22381},
	{"NC38", 4, 22382},
	{"NC39", 4, 22383},
	{"NC40", 4, 22384},
	{"NC41", 4, 22385},
	{"NC42", 4, 22386},
	{"NC43", 4, 22387},
	{"NC44", 4, 22388},
	{"NC45", 4, 22389},
	{"NC46", 4, 22390},
	{"NC47", 4, 22391},
	{"NC48", 4, 22392},
	{"NC49", 4, 22393},
	{"NC50", 4, 22394},
	{"NC51", 4, 22395},
	{"NC52", 4, 22396},
	{"NC53", 4, 22397},
	{"NC54", 4, 22398},
	{"NC55", 4, 22399},
	{"NC56", 4, 22400},
	{"NC57", 4, 22401},
	{"NC58", 4, 22402},
	{"NC59", 4, 22403},
	{"NC60", 4, 22404},
	{"NC61", 4, 22405},
	{"NC62", 4, 22406},
	{"NC63", 4, 22407},
	{"NC64", 4, 22408},
	{"NC65", 4, 22409},
	{"NC66", 4, 22410},
	{"NC67", 4, 22411},
	{"NC68", 4, 22412},
	{"NC69", 4, 22413},
	{"NC70", 4, 22414},
	{"NC71", 4, 22415},
	{"NC72", 4, 22416},
	{"NC73", 4, 22417},
	{"NC74", 4, 22418},
	{"NC75", 4, 22419},
	{"NC76", 4, 22420},
	{"NC77", 4, 22421},
	{"NC78", 4, 22422},
	{"NC79", 4, 22423},
	{"NC80", 4, 22424},
	{"NC81", 4, 22425},
	{"NC82", 4, 22426},
	{"NC83", 4, 22427},
	{"NC84", 4, 22428},
	{"NC85", 4, 22429},
	{"NC86", 4, 22430},
	{"NC87", 4, 22431},
	{"NC88", 4, 22432},
	{"NC89", 4, 22433},
	{"NC90", 4, 22434},
	{"NC91", 4, 22435},
	{"NC92", 4, 22436},
	{"NC93", 4, 22437},
	{"NC94", 4, 22438},
	{"NC95", 4, 22439},
	{"NC96", 4, 22440},
	{"NC97", 4, 22441},
	{"NC98", 4, 22442},
	{"NC99", 4, 22443},
	{"NJ00", 4, 22444},
	{"NJ01", 4, 22445},
	{"NJ02", 4, 22446},
	{"NJ03", 4, 22447},
	{"NJ04", 4, 22448},
	{"NJ05", 4, 22449},
	{"NJ06", 4, 22450},
	{"NJ07", 4, 22451},
	{"NJ08", 4, 22452},
	{"NJ09", 4, 22453},
	{"NJ10", 4, 22454},
	{"NJ11", 4, 22455},
	{"NJ12", 4, 22456},
	{"NJ13", 4, 22457},
	{"NJ14", 4, 22458},
	{"NJ15", 4, 22459},
	{"NJ16", 4, 22460},
	{"NJ17", 4, 22461},
	{"NJ18", 4, 22462},
	{"NJ19", 4, 22463},
	{"NJ20", 4, 22464},
	{"NJ21", 4, 22465},
	{"NJ22", 4, 22466},
	{"NJ23", 4, 22467},
	{"NJ24", 4, 22468},
	{"NJ25", 4, 22469},
	{"NJ26", 4, 22470},
	{"NJ27", 4, 22471},
	{"NJ28", 4, 22472},
	{"NJ29", 4, 22473},
	{"NJ30", 4, 22474},
	{"NJ31", 4, 22475},
	{"NJ32", 4, 22476},
	{"NJ33", 4, 22477},
	{"NJ34", 4, 22478},
	{"NJ35", 4, 22479},
	{"NJ36", 4, 22480},
	{"NJ37", 4, 22481},
	{"NJ38", 4, 22482},
	{"NJ39", 4, 22483},
	{"NJ40", 4, 22484},
	{"NJ41", 4, 22485},
	{"NJ42", 4, 22486},
	{"NJ43", 4, 22487},
	{"NJ44", 4, 22488},
	{"NJ45", 4, 22489},
	{"NJ46", 4, 22490},
	{"NJ47", 4, 22491},
	{"NJ48", 4, 22492},
	{"NJ49", 4, 22493},
	{"NJ50", 4, 22494},
	{"NJ51", 4, 22495},
	{"NJ52", 4, 22496},
	{"NJ53", 4, 22497},
	{"NJ54", 4, 22498},
	{"NJ55", 4, 22499},
	{"NJ56", 4, 22500},
	{"NJ57", 4, 22501},
	{"NJ58", 4, 22502},
	{"NJ59", 4, 22503},
	{"NJ60", 4, 22504},
	{"NJ61", 4, 22505},
	{"NJ62", 4, 22506},
	{"NJ63", 4, 22507},
	{"NJ64", 4, 22508},
	{"NJ65", 4, 22509},
	{"NJ66", 4, 22510},
	{"NJ67", 4, 22511},
	{"NJ68", 4, 22512},
	{"NJ69", 4, 22513},
	{"NJ70", 4, 22514},
	{"NJ71", 4, 22515},
	{"NJ72", 4, 22516},
	{"NJ73", 4, 22517},
	{"NJ74", 4, 22518},
	{"NJ75", 4, 22519},
	{"NJ76", 4, 22520},
	{"NJ77", 4, 22521},
	{"NJ78", 4, 22522},
	{"NJ79", 4, 22523},
	{"NJ80", 4, 22524},
	{"NJ81", 4, 22525},
	{"NJ82", 4, 22526},
	{"NJ83", 4, 22527},
	{"NJ84", 4, 22528},
	{"NJ85", 4, 22529},
	{"NJ86", 4, 22530},
	{"NJ87", 4, 22531},
	{"NJ88", 4, 22532},
	{"NJ89", 4, 22533},
	{"NJ90", 4, 22534},
	{"NJ91", 4, 22535},
	{"NJ92", 4, 22536},
	{"NJ93", 4, 22537},
	{"NJ94", 4, 22538},
	{"NJ95", 4, 22539},
	{"NJ96", 4, 22540},
	{"NJ97", 4, 22541},
	{"NJ98", 4, 22542},
	{"NJ99", 4, 22543},
	{"NK00", 4, 22544},
	{"NK01", 4, 22545},
	{"NK02", 4, 22546},
	{"NK03", 4, 22547},
	{"NK04", 4, 22548},
	{"NK05", 4, 22549},
	{"NK06", 4, 22550},
	{"NK07", 4, 22551},
	{"NK08", 4, 22552},
	{"NK09", 4, 22553},
	{"NK10", 4, 22554},
	{"NK11", 4, 22555},
	{"NK12", 4, 22556},
	{"NK13", 4, 22557},
	{"NK14", 4, 22558},
	{"NK15", 4, 22559},
	{"NK16", 4, 22560},
	{"NK17", 4, 22561},
	{"NK18", 4, 22562},
	{"NK19", 4, 22563},
	{"NK20", 4, 22564},
	{"NK21", 4, 22565},
	{"NK22", 4, 22566},
	{"NK23", 4, 22567},
	{"NK24", 4, 22568},
	{"NK25", 4, 22569},
	{"NK26", 4, 22570},
	{"NK27", 4, 22571},
	{"NK28", 4, 22572},
	{"NK29", 4, 22573},
	{"NK30", 4, 22574},
	{"NK31", 4, 22575},
	{"NK32", 4, 22576},
	{"NK33", 4, 22577},
	{"NK34", 4, 22578},
	{"NK35", 4, 22579},
	{"NK36", 4, 22580},
	{"NK37", 4, 22581},
	{"NK38", 4, 22582},
	{"NK39", 4, 22583},
	{"NK40", 4, 22584},
	{"NK41", 4, 22585},
	{"NK42", 4, 22586},
	{"NK43", 4, 22587},
	{"NK44", 4, 22588},
	{"NK45", 4, 22589},
	{"NK46", 4, 22590},
	{"NK47", 4, 22591},
	{"NK48", 4, 22592},
	{"NK49", 4, 22593},
	{"NK50", 4, 22594},
	{"NK51", 4, 22595},
	{"NK52", 4, 22596},
	{"NK53", 4, 22597},
	{"NK54", 4, 22598},
	{"NK55", 4, 22599},
	{"NK56", 4, 22600},
	{"NK57", 4, 22601},
	{"NK58", 4, 22602},
	{"NK59", 4, 22603},
	{"NK60", 4, 22604},
	{"NK61", 4, 22605},
	{"NK62", 4, 22606},
	{"NK63", 4, 22607},
	{"NK64", 4, 22608},
	{"NK65", 4, 22609},
	{"NK66", 4, 22610},
	{"NK67", 4, 22611},
	{"NK68", 4, 22612},
	{"NK69", 4, 22613},
	{"NK70", 4, 22614},
	{"NK71", 4, 22615},
	{"NK72", 4, 22616},
	{"NK73", 4, 22617},
	{"NK74", 4, 22618},
	{"NK75", 4, 22619},
	{"NK76", 4, 22620},
	{"NK77", 4, 22621},
	{"NK78", 4, 22622},
	{"NK79", 4, 22623},
	{"NK80", 4, 22624},
	{"NK81", 4, 22625},
	{"NK82", 4, 22626},
	{"NK83", 4, 22627},
	{"NK84", 4, 22628},
	{"NK85", 4, 22629},
	{"NK86", 4, 22630},
	{"NK87", 4, 22631},
	{"NK88", 4, 22632},
	{"NK89", 4, 22633},
	{"NK90", 4, 22634},
	{"NK91", 4, 22635},
	{"NK92", 4, 22636},
	{"NK93", 4, 22637},
	{"NK94", 4, 22638},
	{"NK95", 4, 22639},
	{"NK96", 4, 22640},
	{"NK97", 4, 22641},
	{"NK98", 4, 22642},
	{"NK99", 4, 22643},
	{"NL00", 4, 22644},
	{"NL01", 4, 22645},
	{"NL02", 4, 22646},
	{"NL03", 4, 22647},
	{"NL04", 4, 22648},
	{"NL05", 4, 22649},
	{"NL06", 4, 22650},
	{"NL07", 4, 22651},
	{"NL08", 4, 22652},
	{"NL09", 4, 22653},
	{"NL10", 4, 22654},
	{"NL11", 4, 22655},
	{"NL12", 4, 22656},
	{"NL13", 4, 22657},
	{"NL14", 4, 22658},
	{"NL15", 4, 22659},
	{"NL16", 4, 22660},
	{"NL17", 4, 22661},
	{"NL18", 4, 22662},
	{"NL19", 4, 22663},
	{"NL20", 4, 22664},
	{"NL21", 4, 22665},
	{"NL22", 4, 22666},
	{"NL23", 4, 22667},
	{"NL24", 4, 22668},
	{"NL25", 4, 22669},
	{"NL26", 4, 22670},
	{"NL27", 4, 22671},
	{"NL28", 4, 22672},
	{"NL29", 4, 22673},
	{"NL30", 4, 22674},
	{"NL31", 4, 22675},
	{"NL32", 4, 22676},
	{"NL33", 4, 22677},
	{"NL34", 4, 22678},
	{"NL35", 4, 22679},
	{"NL36", 4, 22680},
	{"NL37", 4, 22681},
	{"NL38", 4, 22682},
	{"NL39", 4, 22683},
	{"NL40", 4, 22684},
	{"NL41", 4, 22685},
	{"NL42", 4, 22686},
	{"NL43", 4, 22687},
	{"NL44", 4, 22688},
	{"NL45", 4, 22689},
	{"NL46", 4, 22690},
	{"NL47", 4, 22691},
	{"NL48", 4, 22692},
	{"NL49", 4, 22693},
	{"NL50", 4, 22694},
	{"NL51", 4, 22695},
	{"NL52", 4, 22696},
	{"NL53", 4, 22697},
	{"NL54", 4, 22698},
	{"NL55", 4, 22699},
	{"NL56", 4, 22700},
	{"NL57", 4, 22701},
	{"NL58", 4, 22702},
	{"NL59", 4, 22703},
	{"NL60", 4, 22704},
	{"NL61", 4, 22705},
	{"NL62", 4, 22706},
	{"NL63", 4, 22707},
	{"NL64", 4, 22708},
	{"NL65", 4, 22709},
	{"NL66", 4, 22710},
	{"NL67", 4, 22711},
	{"NL68", 4, 22712},
	{"NL69", 4, 22713},
	{"NL70", 4, 22714},
	{"NL71", 4, 22715},
	{"NL72", 4, 22716},
	{"NL73", 4, 22717},
	{"NL74", 4, 22718},
	{"NL75", 4, 22719},
	{"NL76", 4, 22720},
	{"NL77", 4, 22721},
	{"NL78", 4, 22722},
	{"NL79", 4, 22723},
	{"NL80", 4, 22724},
	{"NL81", 4, 22725},
	{"NL82", 4, 22726},
	{"NL83", 4, 22727},
	{"NL84", 4, 22728},
	{"NL85", 4, 22729},
	{"NL86", 4, 22730},
	{"NL87", 4, 22731},
	{"NL88", 4, 22732},
	{"NL89", 4, 22733},
	{"NL90", 4, 22734},
	{"NL91", 4, 22735},
	{"NL92", 4, 22736},
	{"NL93", 4, 22737},
	{"NL94", 4, 22738},
	{"NL95", 4, 22739},
	{"NL96", 4, 22740},
	{"NL97", 4, 22741},
	{"NL98", 4, 22742},
	{"NL99", 4, 22743},
	{"NM00", 4, 22744},
	{"NM01", 4, 22745},
	{"NM02", 4, 22746},
	{"NM03", 4, 22747},
	{"NM04", 4, 22748},
	{"NM05", 4, 22749},
	{"NM06", 4, 22750},
	{"NM07", 4, 22751},
	{"NM08", 4, 22752},
	{"NM09", 4, 22753},
	{"NM10", 4, 22754},
	{"NM11", 4, 22755},
	{"NM12", 4, 22756},
	{"NM13", 4, 22757},
	{"NM14", 4, 22758},
	{"NM15", 4, 22759},
	{"NM16", 4, 22760},
	{"NM17", 4, 22761},
	{"NM18", 4, 22762},
	{"NM19", 4, 22763},
	{"NM20", 4, 22764},
	{"NM21", 4, 22765},
	{"NM22", 4, 22766},
	{"NM23", 4, 22767},
	{"NM24", 4, 22768},
	{"NM25", 4, 22769},
	{"NM26", 4, 22770},
	{"NM27", 4, 22771},
	{"NM28", 4, 22772},
	{"NM29", 4, 22773},
	{"NM30", 4, 22774},
	{"NM31", 4, 22775},
	{"NM32", 4, 22776},
	{"NM33", 4, 22777},
	{"NM34", 4, 22778},
	{"NM35", 4, 22779},
	{"NM36", 4, 22780},
	{"NM37", 4, 22781},
	{"NM38", 4, 22782},
	{"NM39", 4, 22783},
	{"NM40", 4, 22784},
	{"NM41", 4, 22785},
	{"NM42", 4, 22786},
	{"NM43", 4, 22787},
	{"NM44", 4, 22788},
	{"NM45", 4, 22789},
	{"NM46", 4, 22790},
	{"NM47", 4, 22791},
	{"NM48", 4, 22792},
	{"NM49", 4, 22793},
	{"NM50", 4, 22794},
	{"NM51", 4, 22795},
	{"NM52", 4, 22796},
	{"NM53", 4, 22797},
	{"NM54", 4, 22798},
	{"NM55", 4, 22799},
	{"NM56", 4, 22800},
	{"NM57", 4, 22801},
	{"NM58", 4, 22802},
	{"NM59", 4, 22803},
	{"NM60", 4, 22804},
	{"NM61", 4, 22805},
	{"NM62", 4, 22806},
	{"NM63", 4, 22807},
	{"NM64", 4, 22808},
	{"NM65", 4, 22809},
	{"NM66", 4, 22810},
	{"NM67", 4, 22811},
	{"NM68", 4, 22812},
	{"NM69", 4, 22813},
	{"NM70", 4, 22814},
	{"NM71", 4, 22815},
	{"NM72", 4, 22816},
	{"NM73", 4, 22817},
	{"NM74", 4, 22818},
	{"NM75", 4, 22819},
	{"NM76", 4, 22820},
	{"NM77", 4, 22821},
	{"NM78", 4, 22822},
	{"NM79", 4, 22823},
	{"NM80", 4, 22824},
	{"NM81", 4, 22825},
	{"NM82", 4, 22826},
	{"NM83", 4, 22827},
	{"NM84", 4, 22828},
	{"NM85", 4, 22829},
	{"NM86", 4, 22830},
	{"NM87", 4, 22831},
	{"NM88", 4, 22832},
	{"NM89", 4, 22833},
	{"NM90", 4, 22834},
	{"NM91", 4, 22835},
	{"NM92", 4, 22836},
	{"NM93", 4, 22837},
	{"NM94", 4, 22838},
	{"NM95", 4, 22839},
	{"NM96", 4, 22840},
	{"NM97", 4, 22841},
	{"NM98", 4, 22842},
	{"NM99", 4, 22843},
	{"NN00", 4, 22844},
	{"NN01", 4, 22845},
	{"NN02", 4, 22846},
	{"NN03", 4, 22847},
	{"NN04", 4, 22848},
	{"NN05", 4, 22849},
	{"NN06", 4, 22850},
	{"NN07", 4, 22851},
	{"NN08", 4, 22852},
	{"NN09", 4, 22853},
	{"NN10", 4, 22854},
	{"NN11", 4, 22855},
	{"NN12", 4, 22856},
	{"NN13", 4, 22857},
	{"NN14", 4, 22858},
	{"NN15", 4, 22859},
	{"NN16", 4, 22860},
	{"NN17", 4, 22861},
	{"NN18", 4, 22862},
	{"NN19", 4, 22863},
	{"NN20", 4, 22864},
	{"NN21", 4, 22865},
	{"NN22", 4, 22866},
	{"NN23", 4, 22867},
	{"NN24", 4, 22868},
	{"NN25", 4, 22869},
	{"NN26", 4, 22870},
	{"NN27", 4, 22871},
	{"NN28", 4, 22872},
	{"NN29", 4, 22873},
	{"NN30", 4, 22874},
	{"NN31", 4, 22875},
	{"NN32", 4, 22876},
	{"NN33", 4, 22877},
	{"NN34", 4, 22878},
	{"NN35", 4, 22879},
	{"NN36", 4, 22880},
	{"NN37", 4, 22881},
	{"NN38", 4, 22882},
	{"NN39", 4, 22883},
	{"NN40", 4, 22884},
	{"NN41", 4, 22885},
	{"NN42", 4, 22886},
	{"NN43", 4, 22887},
	{"NN44", 4, 22888},
	{"NN45", 4, 22889},
	{"NN46", 4, 22890},
	{"NN47", 4, 22891},
	{"NN48", 4, 22892},
	{"NN49", 4, 22893},
	{"NN50", 4, 22894},
	{"NN51", 4, 22895},
	{"NN52", 4, 22896},
	{"NN53", 4, 22897},
	{"NN54", 4, 22898},
	{"NN55", 4, 22899},
	{"NN56", 4, 22900},
	{"NN57", 4, 22901},
	{"NN58", 4, 22902},
	{"NN59", 4, 22903},
	{"NN60", 4, 22904},
	{"NN61", 4, 22905},
	{"NN62", 4, 22906},
	{"NN63", 4, 22907},
	{"NN64", 4, 22908},
	{"NN65", 4, 22909},
	{"NN66", 4, 22910},
	{"NN67", 4, 22911},
	{"NN68", 4, 22912},
	{"NN69", 4, 22913},
	{"NN70", 4, 22914},
	{"NN71", 4, 22915},
	{"NN72", 4, 22916},
	{"NN73", 4, 22917},
	{"NN74", 4, 22918},
	{"NN75", 4, 22919},
	{"NN76", 4, 22920},
	{"NN77", 4, 22921},
	{"NN78", 4, 22922},
	{"NN79", 4, 22923},
	{"NN80", 4, 22924},
	{"NN81", 4, 22925},
	{"NN82", 4, 22926},
	{"NN83", 4, 22927},
	{"NN84", 4, 22928},
	{"NN85", 4, 22929},
	{"NN86", 4, 22930},
	{"NN87", 4, 22931},
	{"NN88", 4, 22932},
	{"NN89", 4, 22933},
	{"NN90", 4, 22934},
	{"NN91", 4, 22935},
	{"NN92", 4, 22936},
	{"NN93", 4, 22937},
	{"NN94", 4, 22938},
	{"NN95", 4, 22939},
	{"NN96", 4, 22940},
	{"NN97", 4, 22941},
	{"NN98", 4, 22942},
	{"NN99", 4, 22943},
	{"NO00", 4, 22944},
	{"NO01", 4, 22945},
	{"NO02", 4, 22946},
	{"NO03", 4, 22947},
	{"NO04", 4, 22948},
	{"NO05", 4, 22949},
	{"NO06", 4, 22950},
	{"NO07", 4, 22951},
	{"NO08", 4, 22952},
	{"NO09", 4, 22953},
	{"NO10", 4, 22954},
	{"NO11", 4, 22955},
	{"NO12", 4, 22956},
	{"NO13", 4, 22957},
	{"NO14", 4, 22958},
	{"NO15", 4, 22959},
	{"NO16", 4, 22960},
	{"NO17", 4, 22961},
	{"NO18", 4, 22962},
	{"NO19", 4, 22963},
	{"NO20", 4, 22964},
	{"NO21", 4, 22965},
	{"NO22", 4, 22966},
	{"NO23", 4, 22967},
	{"NO24", 4, 22968},
	{"NO25", 4, 22969},
	{"NO26", 4, 22970},
	{"NO27", 4, 22971},
	{"NO28", 4, 22972},
	{"NO29", 4, 22973},
	{"NO30", 4, 22974},
	{"NO31", 4, 22975},
	{"NO32", 4, 22976},
	{"NO33", 4, 22977},
	{"NO34", 4, 22978},
	{"NO35", 4, 22979},
	{"NO36", 4, 22980},
	{"NO37", 4, 22981},
	{"NO38", 4, 22982},
	{"NO39", 4, 22983},
	{"NO40", 4, 22984},
	{"NO41", 4, 22985},
	{"NO42", 4, 22986},
	{"NO43", 4, 22987},
	{"NO44", 4, 22988},
	{"NO45", 4, 22989},
	{"NO46", 4, 22990},
	{"NO47", 4, 22991},
	{"NO48", 4, 22992},
	{"NO49", 4, 22993},
	{"NO50", 4, 22994},
	{"NO51", 4, 22995},
	{"NO52", 4, 22996},
	{"NO53", 4, 22997},
	{"NO54", 4, 22998},
	{"NO55", 4, 22999},
	{"NO56", 4, 23000},
	{"NO57", 4, 23001},
	{"NO58", 4, 23002},
	{"NO59", 4, 23003},
	{"NO60", 4, 23004},
	{"NO61", 4, 23005},
	{"NO62", 4, 23006},
	{"NO63", 4, 23007},
	{"NO64", 4, 23008},
	{"NO65", 4, 23009},
	{"NO66", 4, 23010},
	{"NO67", 4, 23011},
	{"NO68", 4, 23012},
	{"NO69", 4, 23013},
	{"NO70", 4, 23014},
	{"NO71", 4, 23015},
	{"NO72", 4, 23016},
	{"NO73", 4, 23017},
	{"NO74", 4, 23018},
	{"NO75", 4, 23019},
	{"NO76", 4, 23020},
	{"NO77", 4, 23021},
	{"NO78", 4, 23022},
	{"NO79", 4, 23023},
	{"NO80", 4, 23024},
	{"NO81", 4, 23025},
	{"NO82", 4, 23026},
	{"NO83", 4, 23027},
	{"NO84", 4, 23028},
	{"NO85", 4, 23029},
	{"NO86", 4, 23030},
	{"NO87", 4, 23031},
	{"NO88", 4, 23032},
	{"NO89", 4, 23033},
	{"NO90", 4, 23034},
	{"NO91", 4, 23035},
	{"NO92", 4, 23036},
	{"NO93", 4, 23037},
	{"NO94", 4, 23038},
	{"NO95", 4, 23039},
	{"NO96", 4, 23040},
	{"NO97", 4, 23041},
	{"NO98", 4, 23042},
	{"NO99", 4, 23043},
	{"NP00", 4, 23044},
	{"NP01", 4, 23045},
	{"NP02", 4, 23046},
	{"NP03", 4, 23047},
	{"NP04", 4, 23048},
	{"NP05", 4, 23049},
	{"NP06", 4, 23050},
	{"NP07", 4, 23051},
	{"NP08", 4, 23052},
	{"NP09", 4, 23053},
	{"NP10", 4, 23054},
	{"NP11", 4, 23055},
	{"NP12", 4, 23056},
	{"NP13", 4, 23057},
	{"NP14", 4, 23058},
	{"NP15", 4, 23059},
	{"NP16", 4, 23060},
	{"NP17", 4, 23061},
	{"NP18", 4, 23062},
	{"NP19", 4, 23063},
	{"NP20", 4, 23064},
	{"NP21", 4, 23065},
	{"NP22", 4, 23066},
	{"NP23", 4, 23067},
	{"NP24", 4, 23068},
	{"NP25", 4, 23069},
	{"NP26", 4, 23070},
	{"NP27", 4, 23071},
	{"NP28", 4, 23072},
	{"NP29", 4, 23073},
	{"NP30", 4, 23074},
	{"NP31", 4, 23075},
	{"NP32", 4, 23076},
	{"NP33", 4, 23077},
	{"NP34", 4, 23078},
	{"NP35", 4, 23079},
	{"NP36", 4, 23080},
	{"NP37", 4, 23081},
	{"NP38", 4, 23082},
	{"NP39", 4, 23083},
	{"NP40", 4, 23084},
	{"NP41", 4, 23085},
	{"NP42", 4, 23086},
	{"NP43", 4, 23087},
	{"NP44", 4, 23088},
	{"NP45", 4, 23089},
	{"NP46", 4, 23090},
	{"NP47", 4, 23091},
	{"NP48", 4, 23092},
	{"NP49", 4, 23093},
	{"NP50", 4, 23094},
	{"NP51", 4, 23095},
	{"NP52", 4, 23096},
	{"NP53", 4, 23097},
	{"NP54", 4, 23098},
	{"NP55", 4, 23099},
	{"NP56", 4, 23100},
	{"NP57", 4, 23101},
	{"NP58", 4, 23102},
	{"NP59", 4, 23103},
	{"NP60", 4, 23104},
	{"NP61", 4, 23105},
	{"NP62", 4, 23106},
	{"NP63", 4, 23107},
	{"NP64", 4, 23108},
	{"NP65", 4, 23109},
	{"NP66", 4, 23110},
	{"NP67", 4, 23111},
	{"NP68", 4, 23112},
	{"NP69", 4, 23113},
	{"NP70", 4, 23114},
	{"NP71", 4, 23115},
	{"NP72", 4, 23116},
	{"NP73", 4, 23117},
	{"NP74", 4, 23118},
	{"NP75", 4, 23119},
	{"NP76", 4, 23120},
	{"NP77", 4, 23121},
	{"NP78", 4, 23122},
	{"NP79", 4, 23123},
	{"NP80", 4, 23124},
	{"NP81", 4, 23125},
	{"NP82", 4, 23126},
	{"NP83", 4, 23127},
	{"NP84", 4, 23128},
	{"NP85", 4, 23129},
	{"NP86", 4, 23130},
	{"NP87", 4, 23131},
	{"NP88", 4, 23132},
	{"NP89", 4, 23133},
	{"NP90", 4, 23134},
	{"NP91", 4, 23135},
	{"NP92", 4, 23136},
	{"NP93", 4, 23137},
	{"NP94", 4, 23138},
	{"NP95", 4, 23139},
	{"NP96", 4, 23140},
	{"NP97", 4, 23141},
	{"NP98", 4, 23142},
	{"NP99", 4, 23143},
	{"NQ00", 4, 23144},
	{"NQ01", 4, 23145},
	{"NQ02", 4, 23146},
	{"NQ03", 4, 23147},
	{"NQ04", 4, 23148},
	{"NQ05", 4, 23149},
	{"NQ06", 4, 23150},
	{"NQ07", 4, 23151},
	{"NQ08", 4, 23152},
	{"NQ09", 4, 23153},
	{"NQ10", 4, 23154},
	{"NQ11", 4, 23155},
	{"NQ12", 4, 23156},
	{"NQ13", 4, 23157},
	{"NQ14", 4, 23158},
	{"NQ15", 4, 23159},
	{"NQ16", 4, 23160},
	{"NQ17", 4, 23161},
	{"NQ18", 4, 23162},
	{"NQ19", 4, 23163},
	{"NQ20", 4, 23164},
	{"NQ21", 4, 23165},
	{"NQ22", 4, 23166},
	{"NQ23", 4, 23167},
	{"NQ24", 4, 23168},
	{"NQ25", 4, 23169},
	{"NQ26", 4, 23170},
	{"NQ27", 4, 23171},
	{"NQ28", 4, 23172},
	{"NQ29", 4, 23173},
	{"NQ30", 4, 23174},
	{"NQ31", 4, 23175},
	{"NQ32", 4, 23176},
	{"NQ33", 4, 23177},
	{"NQ34", 4, 23178},
	{"NQ35", 4, 23179},
	{"NQ36", 4, 23180},
	{"NQ37", 4, 23181},
	{"NQ38", 4, 23182},
	{"NQ39", 4, 23183},
	{"NQ40", 4, 23184},
	{"NQ41", 4, 23185},
	{"NQ42", 4, 23186},
	{"NQ43", 4, 23187},
	{"NQ44", 4, 23188},
	{"NQ45", 4, 23189},
	{"NQ46", 4, 23190},
	{"NQ47", 4, 23191},
	{"NQ48", 4, 23192},
	{"NQ49", 4, 23193},
	{"NQ50", 4, 23194},
	{"NQ51", 4, 23195},
	{"NQ52", 4, 23196},
	{"NQ53", 4, 23197},
	{"NQ54", 4, 23198},
	{"NQ55", 4, 23199},
	{"NQ56", 4, 23200},
	{"NQ57", 4, 23201},
	{"NQ58", 4, 23202},
	{"NQ59", 4, 23203},
	{"NQ60", 4, 23204},
	{"NQ61", 4, 23205},
	{"NQ62", 4, 23206},
	{"NQ63", 4, 23207},
	{"NQ64", 4, 23208},
	{"NQ65", 4, 23209},
	{"NQ66", 4, 23210},
	{"NQ67", 4, 23211},
	{"NQ68", 4, 23212},
	{"NQ69", 4, 23213},
	{"NQ70", 4, 23214},
	{"NQ71", 4, 23215},
	{"NQ72", 4, 23216},
	{"NQ73", 4, 23217},
	{"NQ74", 4, 23218},
	{"NQ75", 4, 23219},
	{"NQ76", 4, 23220},
	{"NQ77", 4, 23221},
	{"NQ78", 4, 23222},
	{"NQ79", 4, 23223},
	{"NQ80", 4, 23224},
	{"NQ81", 4, 23225},
	{"NQ82", 4, 23226},
	{"NQ83", 4, 23227},
	{"NQ84", 4, 23228},
	{"NQ85", 4, 23229},
	{"NQ86", 4, 23230},
	{"NQ87", 4, 23231},
	{"NQ88", 4, 23232},
	{"NQ89", 4, 23233},
	{"NQ90", 4, 23234},
	{"NQ91", 4, 23235},
	{"NQ92", 4, 23236},
	{"NQ93", 4, 23237},
	{"NQ94", 4, 23238},
	{"NQ95", 4, 23239},
	{"NQ96", 4, 23240},
	{"NQ97", 4, 23241},
	{"NQ98", 4, 23242},
	{"NQ99", 4, 23243},
	{"OB00", 4, 23244},
	{"OB01", 4, 23245},
	{"OB02", 4, 23246},
	{"OB03", 4, 23247},
	{"OB04", 4, 23248},
	{"OB05", 4, 23249},
	{"OB06", 4, 23250},
	{"OB07", 4, 23251},
	{"OB08", 4, 23252},
	{"OB09", 4, 23253},
	{"OB10", 4, 23254},
	{"OB11", 4, 23255},
	{"OB12", 4, 23256},
	{"OB13", 4, 23257},
	{"OB14", 4, 23258},
	{"OB15", 4, 23259},
	{"OB16", 4, 23260},
	{"OB17", 4, 23261},
	{"OB18", 4, 23262},
	{"OB19", 4, 23263},
	{"OB20", 4, 23264},
	{"OB21", 4, 23265},
	{"OB22", 4, 23266},
	{"OB23", 4, 23267},
	{"OB24", 4, 23268},
	{"OB25", 4, 23269},
	{"OB26", 4, 23270},
	{"OB27", 4, 23271},
	{"OB28", 4, 23272},
	{"OB29", 4, 23273},
	{"OB30", 4, 23274},
	{"OB31", 4, 23275},
	{"OB32", 4, 23276},
	{"OB33", 4, 23277},
	{"OB34", 4, 23278},
	{"OB35", 4, 23279},
	{"OB36", 4, 23280},
	{"OB37", 4, 23281},
	{"OB38", 4, 23282},
	{"OB39", 4, 23283},
	{"OB40", 4, 23284},
	{"OB41", 4, 23285},
	{"OB42", 4, 23286},
	{"OB43", 4, 23287},
	{"OB44", 4, 23288},
	{"OB45", 4, 23289},
	{"OB46", 4, 23290},
	{"OB47", 4, 23291},
	{"OB48", 4, 23292},
	{"OB49", 4, 23293},
	{"OB50", 4, 23294},
	{"OB51", 4, 23295},
	{"OB52", 4, 23296},
	{"OB53", 4, 23297},
	{"OB54", 4, 23298},
	{"OB55", 4, 23299},
	{"OB56", 4, 23300},
	{"OB57", 4, 23301},
	{"OB58", 4, 23302},
	{"OB59", 4, 23303},
	{"OB60", 4, 23304},
	{"OB61", 4, 23305},
	{"OB62", 4, 23306},
	{"OB63", 4, 23307},
	{"OB64", 4, 23308},
	{"OB65", 4, 23309},
	{"OB66", 4, 23310},
	{"OB67", 4, 23311},
	{"OB68", 4, 23312},
	{"OB69", 4, 23313},
	{"OB70", 4, 23314},
	{"OB71", 4, 23315},
	{"OB72", 4, 23316},
	{"OB73", 4, 23317},
	{"OB74", 4, 23318},
	{"OB75", 4, 23319},
	{"OB76", 4, 23320},
	{"OB77", 4, 23321},
	{"OB78", 4, 23322},
	{"OB79", 4, 23323},
	{"OB80", 4, 23324},
	{"OB81", 4, 23325},
	{"OB82", 4, 23326},
	{"OB83", 4, 23327},
	{"OB84", 4, 23328},
	{"OB85", 4, 23329},
	{"OB86", 4, 23330},
	{"OB87", 4, 23331},
	{"OB88", 4, 23332},
	{"OB89", 4, 23333},
	{"OB90", 4, 23334},
	{"OB91", 4, 23335},
	{"OB92", 4, 23336},
	{"OB93", 4, 23337},
	{"OB94", 4, 23338},
	{"OB95", 4, 23339},
	{"OB96", 4, 23340},
	{"OB97", 4, 23341},
	{"OB98", 4, 23342},
	{"OB99", 4, 23343},
	{"OC00", 4, 23344},
	{"OC01", 4, 23345},
	{"OC02", 4, 23346},
	{"OC03", 4, 23347},
	{"OC04", 4, 23348},
	{"OC05", 4, 23349},
	{"OC06", 4, 23350},
	{"OC07", 4, 23351},
	{"OC08", 4, 23352},
	{"OC09", 4, 23353},
	{"OC10", 4, 23354},
	{"OC11", 4, 23355},
	{"OC12", 4, 23356},
	{"OC13", 4, 23357},
	{"OC14", 4, 23358},
	{"OC15", 4, 23359},
	{"OC16", 4, 23360},
	{"OC17", 4, 23361},
	{"OC18", 4, 23362},
	{"OC19", 4, 23363},
	{"OC20", 4, 23364},
	{"OC21", 4, 23365},
	{"OC22", 4, 23366},
	{"OC23", 4, 23367},
	{"OC24", 4, 23368},
	{"OC25", 4, 23369},
	{"OC26", 4, 23370},
	{"OC27", 4, 23371},
	{"OC28", 4, 23372},
	{"OC29", 4, 23373},
	{"OC30", 4, 23374},
	{"OC31", 4, 23375},
	{"OC32", 4, 23376},
	{"OC33", 4, 23377},
	{"OC34", 4, 23378},
	{"OC35", 4, 23379},
	{"OC36", 4, 23380},
	{"OC37", 4, 23381},
	{"OC38", 4, 23382},
	{"OC39", 4, 23383},
	{"OC40", 4, 23384},
	{"OC41", 4, 23385},
	{"OC42", 4, 23386},
	{"OC43", 4, 23387},
	{"OC44", 4, 23388},
	{"OC45", 4, 23389},
	{"OC46", 4, 23390},
	{"OC47", 4, 23391},
	{"OC48", 4, 23392},
	{"OC49", 4, 23393},
	{"OC50", 4, 23394},
	{"OC51", 4, 23395},
	{"OC52", 4, 23396},
	{"OC53", 4, 23397},
	{"OC54", 4, 23398},
	{"OC55", 4, 23399},
	{"OC56", 4, 23400},
	{"OC57", 4, 23401},
	{"OC58", 4, 23402},
	{"OC59", 4, 23403},
	{"OC60", 4, 23404},
	{"OC61", 4, 23405},
	{"OC62", 4, 23406},
	{"OC63", 4, 23407},
	{"OC64", 4, 23408},
	{"OC65", 4, 23409},
	{"OC66", 4, 23410},
	{"OC67", 4, 23411},
	{"OC68", 4, 23412},
	{"OC69", 4, 23413},
	{"OC70", 4, 23414},
	{"OC71", 4, 23415},
	{"OC72", 4, 23416},
	{"OC73", 4, 23417},
	{"OC74", 4, 23418},
	{"OC75", 4, 23419},
	{"OC76", 4, 23420},
	{"OC77", 4, 23421},
	{"OC78", 4, 23422},
	{"OC79", 4, 23423},
	{"OC80", 4, 23424},
	{"OC81", 4, 23425},
	{"OC82", 4, 23426},
	{"OC83", 4, 23427},
	{"OC84", 4, 23428},
	{"OC85", 4, 23429},
	{"OC86", 4, 23430},
	{"OC87", 4, 23431},
	{"OC88", 4, 23432},
	{"OC89", 4, 23433},
	{"OC90", 4, 23434},
	{"OC91", 4, 23435},
	{"OC92", 4, 23436},
	{"OC93", 4, 23437},
	{"OC94", 4, 23438},
	{"OC95", 4, 23439},
	{"OC96", 4, 23440},
	{"OC97", 4, 23441},
	{"OC98", 4, 23442},
	{"OC99", 4, 23443},
	{"OF00", 4, 23444},
	{"OF01", 4, 23445},
	{"OF02", 4, 23446},
	{"OF03", 4, 23447},
	{"OF04", 4, 23448},
	{"OF05", 4, 23449},
	{"OF06", 4, 23450},
	{"OF07", 4, 23451},
	{"OF08", 4, 23452},
	{"OF09", 4, 23453},
	{"OF10", 4, 23454},
	{"OF11", 4, 23455},
	{"OF12", 4, 23456},
	{"OF13", 4, 23457},
	{"OF14", 4, 23458},
	{"OF15", 4, 23459},
	{"OF16", 4, 23460},
	{"OF17", 4, 23461},
	{"OF18", 4, 23462},
	{"OF19", 4, 23463},
	{"OF20", 4, 23464},
	{"OF21", 4, 23465},
	{"OF22", 4, 23466},
	{"OF23", 4, 23467},
	{"OF24", 4, 23468},
	{"OF25", 4, 23469},
	{"OF26", 4, 23470},
	{"OF27", 4, 23471},
	{"OF28", 4, 23472},
	{"OF29", 4, 23473},
	{"OF30", 4, 23474},
	{"OF31", 4, 23475},
	{"OF32", 4, 23476},
	{"OF33", 4, 23477},
	{"OF34", 4, 23478},
	{"OF35", 4, 23479},
	{"OF36", 4, 23480},
	{"OF37", 4, 23481},
	{"OF38", 4, 23482},
	{"OF39", 4, 23483},
	{"OF40", 4, 23484},
	{"OF41", 4, 23485},
	{"OF42", 4, 23486},
	{"OF43", 4, 23487},
	{"OF44", 4, 23488},
	{"OF45", 4, 23489},
	{"OF46", 4, 23490},
	{"OF47", 4, 23491},
	{"OF48", 4, 23492},
	{"OF49", 4, 23493},
	{"OF50", 4, 23494},
	{"OF51", 4, 23495},
	{"OF52", 4, 23496},
	{"OF53", 4, 23497},
	{"OF54", 4, 23498},
	{"OF55", 4, 23499},
	{"OF56", 4, 23500},
	{"OF57", 4, 23501},
	{"OF58", 4, 23502},
	{"OF59", 4, 23503},
	{"OF60", 4, 23504},
	{"OF61", 4, 23505},
	{"OF62", 4, 23506},
	{"OF63", 4, 23507},
	{"OF64", 4, 23508},
	{"OF65", 4, 23509},
	{"OF66", 4, 23510},
	{"OF67", 4, 23511},
	{"OF68", 4, 23512},
	{"OF69", 4, 23513},
	{"OF70", 4, 23514},
	{"OF71", 4, 23515},
	{"OF72", 4, 23516},
	{"OF73", 4, 23517},
	{"OF74", 4, 23518},
	{"OF75", 4, 23519},
	{"OF76", 4, 23520},
	{"OF77", 4, 23521},
	{"OF78", 4, 23522},
	{"OF79", 4, 23523},
	{"OF80", 4, 23524},
	{"OF81", 4, 23525},
	{"OF82", 4, 23526},
	{"OF83", 4, 23527},
	{"OF84", 4, 23528},
	{"OF85", 4, 23529},
	{"OF86", 4, 23530},
	{"OF87", 4, 23531},
	{"OF88", 4, 23532},
	{"OF89", 4, 23533},
	{"OF90", 4, 23534},
	{"OF91", 4, 23535},
	{"OF92", 4, 23536},
	{"OF93", 4, 23537},
	{"OF94", 4, 23538},
	{"OF95", 4, 23539},
	{"OF96", 4, 23540},
	{"OF97", 4, 23541},
	{"OF98", 4, 23542},
	{"OF99", 4, 23543},
	{"OG00", 4, 23544},
	{"OG01", 4, 23545},
	{"OG02", 4, 23546},
	{"OG03", 4, 23547},
	{"OG04", 4, 23548},
	{"OG05", 4, 23549},
	{"OG06", 4, 23550},
	{"OG07", 4, 23551},
	{"OG08", 4, 23552},
	{"OG09", 4, 23553},
	{"OG10", 4, 23554},
	{"OG11", 4, 23555},
	{"OG12", 4, 23556},
	{"OG13", 4, 23557},
	{"OG14", 4, 23558},
	{"OG15", 4, 23559},
	{"OG16", 4, 23560},
	{"OG17", 4, 23561},
	{"OG18", 4, 23562},
	{"OG19", 4, 23563},
	{"OG20", 4, 23564},
	{"OG21", 4, 23565},
	{"OG22", 4, 23566},
	{"OG23", 4, 23567},
	{"OG24", 4, 23568},
	{"OG25", 4, 23569},
	{"OG26", 4, 23570},
	{"OG27", 4, 23571},
	{"OG28", 4, 23572},
	{"OG29", 4, 23573},
	{"OG30", 4, 23574},
	{"OG31", 4, 23575},
	{"OG32", 4, 23576},
	{"OG33", 4, 23577},
	{"OG34", 4, 23578},
	{"OG35", 4, 23579},
	{"OG36", 4, 23580},
	{"OG37", 4, 23581},
	{"OG38", 4, 23582},
	{"OG39", 4, 23583},
	{"OG40", 4, 23584},
	{"OG41", 4, 23585},
	{"OG42", 4, 23586},
	{"OG43", 4, 23587},
	{"OG44", 4, 23588},
	{"OG45", 4, 23589},
	{"OG46", 4, 23590},
	{"OG47", 4, 23591},
	{"OG48", 4, 23592},
	{"OG49", 4, 23593},
	{"OG50", 4, 23594},
	{"OG51", 4, 23595},
	{"OG52", 4, 23596},
	{"OG53", 4, 23597},
	{"OG54", 4, 23598},
	{"OG55", 4, 23599},
	{"OG56", 4, 23600},
	{"OG57", 4, 23601},
	{"OG58", 4, 23602},
	{"OG59", 4, 23603},
	{"OG60", 4, 23604},
	{"OG61", 4, 23605},
	{"OG62", 4, 23606},
	{"OG63", 4, 23607},
	{"OG64", 4, 23608},
	{"OG65", 4, 23609},
	{"OG66", 4, 23610},
	{"OG67", 4, 23611},
	{"OG68", 4, 23612},
	{"OG69", 4, 23613},
	{"OG70", 4, 23614},
	{"OG71", 4, 23615},
	{"OG72", 4, 23616},
	{"OG73", 4, 23617},
	{"OG74", 4, 23618},
	{"OG75", 4, 23619},
	{"OG76", 4, 23620},
	{"OG77", 4, 23621},
	{"OG78", 4, 23622},
	{"OG79", 4, 23623},
	{"OG80", 4, 23624},
	{"OG81", 4, 23625},
	{"OG82", 4, 23626},
	{"OG83", 4, 23627},
	{"OG84", 4, 23628},
	{"OG85", 4, 23629},
	{"OG86", 4, 23630},
	{"OG87", 4, 23631},
	{"OG88", 4, 23632},
	{"OG89", 4, 23633},
	{"OG90", 4, 23634},
	{"OG91", 4, 23635},
	{"OG92", 4, 23636},
	{"OG93", 4, 23637},
	{"OG94", 4, 23638},
	{"OG95", 4, 23639},
	{"OG96", 4, 23640},
	{"OG97", 4, 23641},
	{"OG98", 4, 23642},
	{"OG99", 4, 23643},
	{"OI00", 4, 23644},
	{"OI01", 4, 23645},
	{"OI02", 4, 23646},
	{"OI03", 4, 23647},
	{"OI04", 4, 23648},
	{"OI05", 4, 23649},
	{"OI06", 4, 23650},
	{"OI07", 4, 23651},
	{"OI08", 4, 23652},
	{"OI09", 4, 23653},
	{"OI10", 4, 23654},
	{"OI11", 4, 23655},
	{"OI12", 4, 23656},
	{"OI13", 4, 23657},
	{"OI14", 4, 23658},
	{"OI15", 4, 23659},
	{"OI16", 4, 23660},
	{"OI17", 4, 23661},
	{"OI18", 4, 23662},
	{"OI19", 4, 23663},
	{"OI20", 4, 23664},
	{"OI21", 4, 23665},
	{"OI22", 4, 23666},
	{"OI23", 4, 23667},
	{"OI24", 4, 23668},
	{"OI25", 4, 23669},
	{"OI26", 4, 23670},
	{"OI27", 4, 23671},
	{"OI28", 4, 23672},
	{"OI29", 4, 23673},
	{"OI30", 4, 23674},
	{"OI31", 4, 23675},
	{"OI32", 4, 23676},
	{"OI33", 4, 23677},
	{"OI34", 4, 23678},
	{"OI35", 4, 23679},
	{"OI36", 4, 23680},
	{"OI37", 4, 23681},
	{"OI38", 4, 23682},
	{"OI39", 4, 23683},
	{"OI40", 4, 23684},
	{"OI41", 4, 23685},
	{"OI42", 4, 23686},
	{"OI43", 4, 23687},
	{"OI44", 4, 23688},
	{"OI45", 4, 23689},
	{"OI46", 4, 23690},
	{"OI47", 4, 23691},
	{"OI48", 4, 23692},
	{"OI49", 4, 23693},
	{"OI50", 4, 23694},
	{"OI51", 4, 23695},
	{"OI52", 4, 23696},
	{"OI53", 4, 23697},
	{"OI54", 4, 23698},
	{"OI55", 4, 23699},
	{"OI56", 4, 23700},
	{"OI57", 4, 23701},
	{"OI58", 4, 23702},
	{"OI59", 4, 23703},
	{"OI60", 4, 23704},
	{"OI61", 4, 23705},
	{"OI62", 4, 23706},
	{"OI63", 4, 23707},
	{"OI64", 4, 23708},
	{"OI65", 4, 23709},
	{"OI66", 4, 23710},
	{"OI67", 4, 23711},
	{"OI68", 4, 23712},
	{"OI69", 4, 23713},
	{"OI70", 4, 23714},
	{"OI71", 4, 23715},
	{"OI72", 4, 23716},
	{"OI73", 4, 23717},
	{"OI74", 4, 23718},
	{"OI75", 4, 23719},
	{"OI76", 4, 23720},
	{"OI77", 4, 23721},
	{"OI78", 4, 23722},
	{"OI79", 4, 23723},
	{"OI80", 4, 23724},
	{"OI81", 4, 23725},
	{"OI82", 4, 23726},
	{"OI83", 4, 23727},
	{"OI84", 4, 23728},
	{"OI85", 4, 23729},
	{"OI86", 4, 23730},
	{"OI87", 4, 23731},
	{"OI88", 4, 23732},
	{"OI89", 4, 23733},
	{"OI90", 4, 23734},
	{"OI91", 4, 23735},
	{"OI92", 4, 23736},
	{"OI93", 4, 23737},
	{"OI94", 4, 23738},
	{"OI95", 4, 23739},
	{"OI96", 4, 23740},
	{"OI97", 4, 23741},
	{"OI98", 4, 23742},
	{"OI99", 4, 23743},
	{"OJ00", 4, 23744},
	{"OJ01", 4, 23745},
	{"OJ02", 4, 23746},
	{"OJ03", 4, 23747},
	{"OJ04", 4, 23748},
	{"OJ05", 4, 23749},
	{"OJ06", 4, 23750},
	{"OJ07", 4, 23751},
	{"OJ08", 4, 23752},
	{"OJ09", 4, 23753},
	{"OJ10", 4, 23754},
	{"OJ11", 4, 23755},
	{"OJ12", 4, 23756},
	{"OJ13", 4, 23757},
	{"OJ14", 4, 23758},
	{"OJ15", 4, 23759},
	{"OJ16", 4, 23760},
	{"OJ17", 4, 23761},
	{"OJ18", 4, 23762},
	{"OJ19", 4, 23763},
	{"OJ20", 4, 23764},
	{"OJ21", 4, 23765},
	{"OJ22", 4, 23766},
	{"OJ23", 4, 23767},
	{"OJ24", 4, 23768},
	{"OJ25", 4, 23769},
	{"OJ26", 4, 23770},
	{"OJ27", 4, 23771},
	{"OJ28", 4, 23772},
	{"OJ29", 4, 23773},
	{"OJ30", 4, 23774},
	{"OJ31", 4, 23775},
	{"OJ32", 4, 23776},
	{"OJ33", 4, 23777},
	{"OJ34", 4, 23778},
	{"OJ35", 4, 23779},
	{"OJ36", 4, 23780},
	{"OJ37", 4, 23781},
	{"OJ38", 4, 23782},
	{"OJ39", 4, 23783},
	{"OJ40", 4, 23784},
	{"OJ41", 4, 23785},
	{"OJ42", 4, 23786},
	{"OJ43", 4, 23787},
	{"OJ44", 4, 23788},
	{"OJ45", 4, 23789},
	{"OJ46", 4, 23790},
	{"OJ47", 4, 23791},
	{"OJ48", 4, 23792},
	{"OJ49", 4, 23793},
	{"OJ50", 4, 23794},
	{"OJ51", 4, 23795},
	{"OJ52", 4, 23796},
	{"OJ53", 4, 23797},
	{"OJ54", 4, 23798},
	{"OJ55", 4, 23799},
	{"OJ56", 4, 23800},
	{"OJ57", 4, 23801},
	{"OJ58", 4, 23802},
	{"OJ59", 4, 23803},
	{"OJ60", 4, 23804},
	{"OJ61", 4, 23805},
	{"OJ62", 4, 23806},
	{"OJ63", 4, 23807},
	{"OJ64", 4, 23808},
	{"OJ65", 4, 23809},
	{"OJ66", 4, 23810},
	{"OJ67", 4, 23811},
	{"OJ68", 4, 23812},
	{"OJ69", 4, 23813},
	{"OJ70", 4, 23814},
	{"OJ71", 4, 23815},
	{"OJ72", 4, 23816},
	{"OJ73", 4, 23817},
	{"OJ74", 4, 23818},
	{"OJ75", 4, 23819},
	{"OJ76", 4, 23820},
	{"OJ77", 4, 23821},
	{"OJ78", 4, 23822},
	{"OJ79", 4, 23823},
	{"OJ80", 4, 23824},
	{"OJ81", 4, 23825},
	{"OJ82", 4, 23826},
	{"OJ83", 4, 23827},
	{"OJ84", 4, 23828},
	{"OJ85", 4, 23829},
	{"OJ86", 4, 23830},
	{"OJ87", 4, 23831},
	{"OJ88", 4, 23832},
	{"OJ89", 4, 23833},
	{"OJ90", 4, 23834},
	{"OJ91", 4, 23835},
	{"OJ92", 4, 23836},
	{"OJ93", 4, 23837},
	{"OJ94", 4, 23838},
	{"OJ95", 4, 23839},
	{"OJ96", 4, 23840},
	{"OJ97", 4, 23841},
	{"OJ98", 4, 23842},
	{"OJ99", 4, 23843},
	{"OK00", 4, 23844},
	{"OK01", 4, 23845},
	{"OK02", 4, 23846},
	{"OK03", 4, 23847},
	{"OK04", 4, 23848},
	{"OK05", 4, 23849},
	{"OK06", 4, 23850},
	{"OK07", 4, 23851},
	{"OK08", 4, 23852},
	{"OK09", 4, 23853},
	{"OK10", 4, 23854},
	{"OK11", 4, 23855},
	{"OK12", 4, 23856},
	{"OK13", 4, 23857},
	{"OK14", 4, 23858},
	{"OK15", 4, 23859},
	{"OK16", 4, 23860},
	{"OK17", 4, 23861},
	{"OK18", 4, 23862},
	{"OK19", 4, 23863},
	{"OK20", 4, 23864},
	{"OK21", 4, 23865},
	{"OK22", 4, 23866},
	{"OK23", 4, 23867},
	{"OK24", 4, 23868},
	{"OK25", 4, 23869},
	{"OK26", 4, 23870},
	{"OK27", 4, 23871},
	{"OK28", 4, 23872},
	{"OK29", 4, 23873},
	{"OK30", 4, 23874},
	{"OK31", 4, 23875},
	{"OK32", 4, 23876},
	{"OK33", 4, 23877},
	{"OK34", 4, 23878},
	{"OK35", 4, 23879},
	{"OK36", 4, 23880},
	{"OK37", 4, 23881},
	{"OK38", 4, 23882},
	{"OK39", 4, 23883},
	{"OK40", 4, 23884},
	{"OK41", 4, 23885},
	{"OK42", 4, 23886},
	{"OK43", 4, 23887},
	{"OK44", 4, 23888},
	{"OK45", 4, 23889},
	{"OK46", 4, 23890},
	{"OK47", 4, 23891},
	{"OK48", 4, 23892},
	{"OK49", 4, 23893},
	{"OK50", 4, 23894},
	{"OK51", 4, 23895},
	{"OK52", 4, 23896},
	{"OK53", 4, 23897},
	{"OK54", 4, 23898},
	{"OK55", 4, 23899},
	{"OK56", 4, 23900},
	{"OK57", 4, 23901},
	{"OK58", 4, 23902},
	{"OK59", 4, 23903},
	{"OK60", 4, 23904},
	{"OK61", 4, 23905},
	{"OK62", 4, 23906},
	{"OK63", 4, 23907},
	{"OK64", 4, 23908},
	{"OK65", 4, 23909},
	{"OK66", 4, 23910},
	{"OK67", 4, 23911},
	{"OK68", 4, 23912},
	{"OK69", 4, 23913},
	{"OK70", 4, 23914},
	{"OK71", 4, 23915},
	{"OK72", 4, 23916},
	{"OK73", 4, 23917},
	{"OK74", 4, 23918},
	{"OK75", 4, 23919},
	{"OK76", 4, 23920},
	{"OK77", 4, 23921},
	{"OK78", 4, 23922},
	{"OK79", 4, 23923},
	{"OK80", 4, 23924},
	{"OK81", 4, 23925},
	{"OK82", 4, 23926},
	{"OK83", 4, 23927},
	{"OK84", 4, 23928},
	{"OK85", 4, 23929},
	{"OK86", 4, 23930},
	{"OK87", 4, 23931},
	{"OK88", 4, 23932},
	{"OK89", 4, 23933},
	{"OK90", 4, 23934},
	{"OK91", 4, 23935},
	{"OK92", 4, 23936},
	{"OK93", 4, 23937},
	{"OK94", 4, 23938},
	{"OK95", 4, 23939},
	{"OK96", 4, 23940},
	{"OK97", 4, 23941},
	{"OK98", 4, 23942},
	{"OK99", 4, 23943},
	{"OL00", 4, 23944},
	{"OL01", 4, 23945},
	{"OL02", 4, 23946},
	{"OL03", 4, 23947},
	{"OL04", 4, 23948},
	{"OL05", 4, 23949},
	{"OL06", 4, 23950},
	{"OL07", 4, 23951},
	{"OL08", 4, 23952},
	{"OL09", 4, 23953},
	{"OL10", 4, 23954},
	{"OL11", 4, 23955},
	{"OL12", 4, 23956},
	{"OL13", 4, 23957},
	{"OL14", 4, 23958},
	{"OL15", 4, 23959},
	{"OL16", 4, 23960},
	{"OL17", 4, 23961},
	{"OL18", 4, 23962},
	{"OL19", 4, 23963},
	{"OL20", 4, 23964},
	{"OL21", 4, 23965},
	{"OL22", 4, 23966},
	{"OL23", 4, 23967},
	{"OL24", 4, 23968},
	{"OL25", 4, 23969},
	{"OL26", 4, 23970},
	{"OL27", 4, 23971},
	{"OL28", 4, 23972},
	{"OL29", 4, 23973},
	{"OL30", 4, 23974},
	{"OL31", 4, 23975},
	{"OL32", 4, 23976},
	{"OL33", 4, 23977},
	{"OL34", 4, 23978},
	{"OL35", 4, 23979},
	{"OL36", 4, 23980},
	{"OL37", 4, 23981},
	{"OL38", 4, 23982},
	{"OL39", 4, 23983},
	{"OL40", 4, 23984},
	{"OL41", 4, 23985},
	{"OL42", 4, 23986},
	{"OL43", 4, 23987},
	{"OL44", 4, 23988},
	{"OL45", 4, 23989},
	{"OL46", 4, 23990},
	{"OL47", 4, 23991},
	{"OL48", 4, 23992},
	{"OL49", 4, 23993},
	{"OL50", 4, 23994},
	{"OL51", 4, 23995},
	{"OL52", 4, 23996},
	{"OL53", 4, 23997},
	{"OL54", 4, 23998},
	{"OL55", 4, 23999},
	{"OL56", 4, 24000},
	{"OL57", 4, 24001},
	{"OL58", 4, 24002},
	{"OL59", 4, 24003},
	{"OL60", 4, 24004},
	{"OL61", 4, 24005},
	{"OL62", 4, 24006},
	{"OL63", 4, 24007},
	{"OL64", 4, 24008},
	{"OL65", 4, 24009},
	{"OL66", 4, 24010},
	{"OL67", 4, 24011},
	{"OL68", 4, 24012},
	{"OL69", 4, 24013},
	{"OL70", 4, 24014},
	{"OL71", 4, 24015},
	{"OL72", 4, 24016},
	{"OL73", 4, 24017},
	{"OL74", 4, 24018},
	{"OL75", 4, 24019},
	{"OL76", 4, 24020},
	{"OL77", 4, 24021},
	{"OL78", 4, 24022},
	{"OL79", 4, 24023},
	{"OL80", 4, 24024},
	{"OL81", 4, 24025},
	{"OL82", 4, 24026},
	{"OL83", 4, 24027},
	{"OL84", 4, 24028},
	{"OL85", 4, 24029},
	{"OL86", 4, 24030},
	{"OL87", 4, 24031},
	{"OL88", 4, 24032},
	{"OL89", 4, 24033},
	{"OL90", 4, 24034},
	{"OL91", 4, 24035},
	{"OL92", 4, 24036},
	{"OL93", 4, 24037},
	{"OL94", 4, 24038},
	{"OL95", 4, 24039},
	{"OL96", 4, 24040},
	{"OL97", 4, 24041},
	{"OL98", 4, 24042},
	{"OL99", 4, 24043},
	{"OM00", 4, 24044},
	{"OM01", 4, 24045},
	{"OM02", 4, 24046},
	{"OM03", 4, 24047},
	{"OM04", 4, 24048},
	{"OM05", 4, 24049},
	{"OM06", 4, 24050},
	{"OM07", 4, 24051},
	{"OM08", 4, 24052},
	{"OM09", 4, 24053},
	{"OM10", 4, 24054},
	{"OM11", 4, 24055},
	{"OM12", 4, 24056},
	{"OM13", 4, 24057},
	{"OM14", 4, 24058},
	{"OM15", 4, 24059},
	{"OM16", 4, 24060},
	{"OM17", 4, 24061},
	{"OM18", 4, 24062},
	{"OM19", 4, 24063},
	{"OM20", 4, 24064},
	{"OM21", 4, 24065},
	{"OM22", 4, 24066},
	{"OM23", 4, 24067},
	{"OM24", 4, 24068},
	{"OM25", 4, 24069},
	{"OM26", 4, 24070},
	{"OM27", 4, 24071},
	{"OM28", 4, 24072},
	{"OM29", 4, 24073},
	{"OM30", 4, 24074},
	{"OM31", 4, 24075},
	{"OM32", 4, 24076},
	{"OM33", 4, 24077},
	{"OM34", 4, 24078},
	{"OM35", 4, 24079},
	{"OM36", 4, 24080},
	{"OM37", 4, 24081},
	{"OM38", 4, 24082},
	{"OM39", 4, 24083},
	{"OM40", 4, 24084},
	{"OM41", 4, 24085},
	{"OM42", 4, 24086},
	{"OM43", 4, 24087},
	{"OM44", 4, 24088},
	{"OM45", 4, 24089},
	{"OM46", 4, 24090},
	{"OM47", 4, 24091},
	{"OM48", 4, 24092},
	{"OM49", 4, 24093},
	{"OM50", 4, 24094},
	{"OM51", 4, 24095},
	{"OM52", 4, 24096},
	{"OM53", 4, 24097},
	{"OM54", 4, 24098},
	{"OM55", 4, 24099},
	{"OM56", 4, 24100},
	{"OM57", 4, 24101},
	{"OM58", 4, 24102},
	{"OM59", 4, 24103},
	{"OM60", 4, 24104},
	{"OM61", 4, 24105},
	{"OM62", 4, 24106},
	{"OM63", 4, 24107},
	{"OM64", 4, 24108},
	{"OM65", 4, 24109},
	{"OM66", 4, 24110},
	{"OM67", 4, 24111},
	{"OM68", 4, 24112},
	{"OM69", 4, 24113},
	{"OM70", 4, 24114},
	{"OM71", 4, 24115},
	{"OM72", 4, 24116},
	{"OM73", 4, 24117},
	{"OM74", 4, 24118},
	{"OM75", 4, 24119},
	{"OM76", 4, 24120},
	{"OM77", 4, 24121},
	{"OM78", 4, 24122},
	{"OM79", 4, 24123},
	{"OM80", 4, 24124},
	{"OM81", 4, 24125},
	{"OM82", 4, 24126},
	{"OM83", 4, 24127},
	{"OM84", 4, 24128},
	{"OM85", 4, 24129},
	{"OM86", 4, 24130},
	{"OM87", 4, 24131},
	{"OM88", 4, 24132},
	{"OM89", 4, 24133},
	{"OM90", 4, 24134},
	{"OM91", 4, 24135},
	{"OM92", 4, 24136},
	{"OM93", 4, 24137},
	{"OM94", 4, 24138},
	{"OM95", 4, 24139},
	{"OM96", 4, 24140},
	{"OM97", 4, 24141},
	{"OM98", 4, 24142},
	{"OM99", 4, 24143},
	{"ON00", 4, 24144},
	{"ON01", 4, 24145},
	{"ON02", 4, 24146},
	{"ON03", 4, 24147},
	{"ON04", 4, 24148},
	{"ON05", 4, 24149},
	{"ON06", 4, 24150},
	{"ON07", 4, 24151},
	{"ON08", 4, 24152},
	{"ON09", 4, 24153},
	{"ON10", 4, 24154},
	{"ON11", 4, 24155},
	{"ON12", 4, 24156},
	{"ON13", 4, 24157},
	{"ON14", 4, 24158},
	{"ON15", 4, 24159},
	{"ON16", 4, 24160},
	{"ON17", 4, 24161},
	{"ON18", 4, 24162},
	{"ON19", 4, 24163},
	{"ON20", 4, 24164},
	{"ON21", 4, 24165},
	{"ON22", 4, 24166},
	{"ON23", 4, 24167},
	{"ON24", 4, 24168},
	{"ON25", 4, 24169},
	{"ON26", 4, 24170},
	{"ON27", 4, 24171},
	{"ON28", 4, 24172},
	{"ON29", 4, 24173},
	{"ON30", 4, 24174},
	{"ON31", 4, 24175},
	{"ON32", 4, 24176},
	{"ON33", 4, 24177},
	{"ON34", 4, 24178},
	{"ON35", 4, 24179},
	{"ON36", 4, 24180},
	{"ON37", 4, 24181},
	{"ON38", 4, 24182},
	{"ON39", 4, 24183},
	{"ON40", 4, 24184},
	{"ON41", 4, 24185},
	{"ON42", 4, 24186},
	{"ON43", 4, 24187},
	{"ON44", 4, 24188},
	{"ON45", 4, 24189},
	{"ON46", 4, 24190},
	{"ON47", 4, 24191},
	{"ON48", 4, 24192},
	{"ON49", 4, 24193},
	{"ON50", 4, 24194},
	{"ON51", 4, 24195},
	{"ON52", 4, 24196},
	{"ON53", 4, 24197},
	{"ON54", 4, 24198},
	{"ON55", 4, 24199},
	{"ON56", 4, 24200},
	{"ON57", 4, 24201},
	{"ON58", 4, 24202},
	{"ON59", 4, 24203},
	{"ON60", 4, 24204},
	{"ON61", 4, 24205},
	{"ON62", 4, 24206},
	{"ON63", 4, 24207},
	{"ON64", 4, 24208},
	{"ON65", 4, 24209},
	{"ON66", 4, 24210},
	{"ON67", 4, 24211},
	{"ON68", 4, 24212},
	{"ON69", 4, 24213},
	{"ON70", 4, 24214},
	{"ON71", 4, 24215},
	{"ON72", 4, 24216},
	{"ON73", 4, 24217},
	{"ON74", 4, 24218},
	{"ON75", 4, 24219},
	{"ON76", 4, 24220},
	{"ON77", 4, 24221},
	{"ON78", 4, 24222},
	{"ON79", 4, 24223},
	{"ON80", 4, 24224},
	{"ON81", 4, 24225},
	{"ON82", 4, 24226},
	{"ON83", 4, 24227},
	{"ON84", 4, 24228},
	{"ON85", 4, 24229},
	{"ON86", 4, 24230},
	{"ON87", 4, 24231},
	{"ON88", 4, 24232},
	{"ON89", 4, 24233},
	{"ON90", 4, 24234},
	{"ON91", 4, 24235},
	{"ON92", 4, 24236},
	{"ON93", 4, 24237},
	{"ON94", 4, 24238},
	{"ON95", 4, 24239},
	{"ON96", 4, 24240},
	{"ON97", 4, 24241},
	{"ON98", 4, 24242},
	{"ON99", 4, 24243},
	{"OO00", 4, 24244},
	{"OO01", 4, 24245},
	{"OO02", 4, 24246},
	{"OO03", 4, 24247},
	{"OO04", 4, 24248},
	{"OO05", 4, 24249},
	{"OO06", 4, 24250},
	{"OO07", 4, 24251},
	{"OO08", 4, 24252},
	{"OO09", 4, 24253},
	{"OO10", 4, 24254},
	{"OO11", 4, 24255},
	{"OO12", 4, 24256},
	{"OO13", 4, 24257},
	{"OO14", 4, 24258},
	{"OO15", 4, 24259},
	{"OO16", 4, 24260},
	{"OO17", 4, 24261},
	{"OO18", 4, 24262},
	{"OO19", 4, 24263},
	{"OO20", 4, 24264},
	{"OO21", 4, 24265},
	{"OO22", 4, 24266},
	{"OO23", 4, 24267},
	{"OO24", 4, 24268},
	{"OO25", 4, 24269},
	{"OO26", 4, 24270},
	{"OO27", 4, 24271},
	{"OO28", 4, 24272},
	{"OO29", 4, 24273},
	{"OO30", 4, 24274},
	{"OO31", 4, 24275},
	{"OO32", 4, 24276},
	{"OO33", 4, 24277},
	{"OO34", 4, 24278},
	{"OO35", 4, 24279},
	{"OO36", 4, 24280},
	{"OO37", 4, 24281},
	{"OO38", 4, 24282},
	{"OO39", 4, 24283},
	{"OO40", 4, 24284},
	{"OO41", 4, 24285},
	{"OO42", 4, 24286},
	{"OO43", 4, 24287},
	{"OO44", 4, 24288},
	{"OO45", 4, 24289},
	{"OO46", 4, 24290},
	{"OO47", 4, 24291},
	{"OO48", 4, 24292},
	{"OO49", 4, 24293},
	{"OO50", 4, 24294},
	{"OO51", 4, 24295},
	{"OO52", 4, 24296},
	{"OO53", 4, 24297},
	{"OO54", 4, 24298},
	{"OO55", 4, 24299},
	{"OO56", 4, 24300},
	{"OO57", 4, 24301},
	{"OO58", 4, 24302},
	{"OO59", 4, 24303},
	{"OO60", 4, 24304},
	{"OO61", 4, 24305},
	{"OO62", 4, 24306},
	{"OO63", 4, 24307},
	{"OO64", 4, 24308},
	{"OO65", 4, 24309},
	{"OO66", 4, 24310},
	{"OO67", 4, 24311},
	{"OO68", 4, 24312},
	{"OO69", 4, 24313},
	{"OO70", 4, 24314},
	{"OO71", 4, 24315},
	{"OO72", 4, 24316},
	{"OO73", 4, 24317},
	{"OO74", 4, 24318},
	{"OO75", 4, 24319},
	{"OO76", 4, 24320},
	{"OO77", 4, 24321},
	{"OO78", 4, 24322},
	{"OO79", 4, 24323},
	{"OO80", 4, 24324},
	{"OO81", 4, 24325},
	{"OO82", 4, 24326},
	{"OO83", 4, 24327},
	{"OO84", 4, 24328},
	{"OO85", 4, 24329},
	{"OO86", 4, 24330},
	{"OO87", 4, 24331},
	{"OO88", 4, 24332},
	{"OO89", 4, 24333},
	{"OO90", 4, 24334},
	{"OO91", 4, 24335},
	{"OO92", 4, 24336},
	{"OO93", 4, 24337},
	{"OO94", 4, 24338},
	{"OO95", 4, 24339},
	{"OO96", 4, 24340},
	{"OO97", 4, 24341},
	{"OO98", 4, 24342},
	{"OO99", 4, 24343},
	{"OP00", 4, 24344},
	{"OP01", 4, 24345},
	{"OP02", 4, 24346},
	{"OP03", 4, 24347},
	{"OP04", 4, 24348},
	{"OP05", 4, 24349},
	{"OP06", 4, 24350},
	{"OP07", 4, 24351},
	{"OP08", 4, 24352},
	{"OP09", 4, 24353},
	{"OP10", 4, 24354},
	{"OP11", 4, 24355},
	{"OP12", 4, 24356},
	{"OP13", 4, 24357},
	{"OP14", 4, 24358},
	{"OP15", 4, 24359},
	{"OP16", 4, 24360},
	{"OP17", 4, 24361},
	{"OP18", 4, 24362},
	{"OP19", 4, 24363},
	{"OP20", 4, 24364},
	{"OP21", 4, 24365},
	{"OP22", 4, 24366},
	{"OP23", 4, 24367},
	{"OP24", 4, 24368},
	{"OP25", 4, 24369},
	{"OP26", 4, 24370},
	{"OP27", 4, 24371},
	{"OP28", 4, 24372},
	{"OP29", 4, 24373},
	{"OP30", 4, 24374},
	{"OP31", 4, 24375},
	{"OP32", 4, 24376},
	{"OP33", 4, 24377},
	{"OP34", 4, 24378},
	{"OP35", 4, 24379},
	{"OP36", 4, 24380},
	{"OP37", 4, 24381},
	{"OP38", 4, 24382},
	{"OP39", 4, 24383},
	{"OP40", 4, 24384},
	{"OP41", 4, 24385},
	{"OP42", 4, 24386},
	{"OP43", 4, 24387},
	{"OP44", 4, 24388},
	{"OP45", 4, 24389},
	{"OP46", 4, 24390},
	{"OP47", 4, 24391},
	{"OP48", 4, 24392},
	{"OP49", 4, 24393},
	{"OP50", 4, 24394},
	{"OP51", 4, 24395},
	{"OP52", 4, 24396},
	{"OP53", 4, 24397},
	{"OP54", 4, 24398},
	{"OP55", 4, 24399},
	{"OP56", 4, 24400},
	{"OP57", 4, 24401},
	{"OP58", 4, 24402},
	{"OP59", 4, 24403},
	{"OP60", 4, 24404},
	{"OP61", 4, 24405},
	{"OP62", 4, 24406},
	{"OP63", 4, 24407},
	{"OP64", 4, 24408},
	{"OP65", 4, 24409},
	{"OP66", 4, 24410},
	{"OP67", 4, 24411},
	{"OP68", 4, 24412},
	{"OP69", 4, 24413},
	{"OP70", 4, 24414},
	{"OP71", 4, 24415},
	{"OP72", 4, 24416},
	{"OP73", 4, 24417},
	{"OP74", 4, 24418},
	{"OP75", 4, 24419},
	{"OP76", 4, 24420},
	{"OP77", 4, 24421},
	{"OP78", 4, 24422},
	{"OP79", 4, 24423},
	{"OP80", 4, 24424},
	{"OP81", 4, 24425},
	{"OP82", 4, 24426},
	{"OP83", 4, 24427},
	{"OP84", 4, 24428},
	{"OP85", 4, 24429},
	{"OP86", 4, 24430},
	{"OP87", 4, 24431},
	{"OP88", 4, 24432},
	{"OP89", 4, 24433},
	{"OP90", 4, 24434},
	{"OP91", 4, 24435},
	{"OP92", 4, 24436},
	{"OP93", 4, 24437},
	{"OP94", 4, 24438},
	{"OP95", 4, 24439},
	{"OP96", 4, 24440},
	{"OP97", 4, 24441},
	{"OP98", 4, 24442},
	{"OP99", 4, 24443},
	{"OQ00", 4, 24444},
	{"OQ01", 4, 24445},
	{"OQ02", 4, 24446},
	{"OQ03", 4, 24447},
	{"OQ04", 4, 24448},
	{"OQ05", 4, 24449},
	{"OQ06", 4, 24450},
	{"OQ07", 4, 24451},
	{"OQ08", 4, 24452},
	{"OQ09", 4, 24453},
	{"OQ10", 4, 24454},
	{"OQ11", 4, 24455},
	{"OQ12", 4, 24456},
	{"OQ13", 4, 24457},
	{"OQ14", 4, 24458},
	{"OQ15", 4, 24459},
	{"OQ16", 4, 24460},
	{"OQ17", 4, 24461},
	{"OQ18", 4, 24462},
	{"OQ19", 4, 24463},
	{"OQ20", 4, 24464},
	{"OQ21", 4, 24465},
	{"OQ22", 4, 24466},
	{"OQ23", 4, 24467},
	{"OQ24", 4, 24468},
	{"OQ25", 4, 24469},
	{"OQ26", 4, 24470},
	{"OQ27", 4, 24471},
	{"OQ28", 4, 24472},
	{"OQ29", 4, 24473},
	{"OQ30", 4, 24474},
	{"OQ31", 4, 24475},
	{"OQ32", 4, 24476},
	{"OQ33", 4, 24477},
	{"OQ34", 4, 24478},
	{"OQ35", 4, 24479},
	{"OQ36", 4, 24480},
	{"OQ37", 4, 24481},
	{"OQ38", 4, 24482},
	{"OQ39", 4, 24483},
	{"OQ40", 4, 24484},
	{"OQ41", 4, 24485},
	{"OQ42", 4, 24486},
	{"OQ43", 4, 24487},
	{"OQ44", 4, 24488},
	{"OQ45", 4, 24489},
	{"OQ46", 4, 24490},
	{"OQ47", 4, 24491},
	{"OQ48", 4, 24492},
	{"OQ49", 4, 24493},
	{"OQ50", 4, 24494},
	{"OQ51", 4, 24495},
	{"OQ52", 4, 24496},
	{"OQ53", 4, 24497},
	{"OQ54", 4, 24498},
	{"OQ55", 4, 24499},
	{"OQ56", 4, 24500},
	{"OQ57", 4, 24501},
	{"OQ58", 4, 24502},
	{"OQ59", 4, 24503},
	{"OQ60", 4, 24504},
	{"OQ61", 4, 24505},
	{"OQ62", 4, 24506},
	{"OQ63", 4, 24507},
	{"OQ64", 4, 24508},
	{"OQ65", 4, 24509},
	{"OQ66", 4, 24510},
	{"OQ67", 4, 24511},
	{"OQ68", 4, 24512},
	{"OQ69", 4, 24513},
	{"OQ70", 4, 24514},
	{"OQ71", 4, 24515},
	{"OQ72", 4, 24516},
	{"OQ73", 4, 24517},
	{"OQ74", 4, 24518},
	{"OQ75", 4, 24519},
	{"OQ76", 4, 24520},
	{"OQ77", 4, 24521},
	{"OQ78", 4, 24522},
	{"OQ79", 4, 24523},
	{"OQ80", 4, 24524},
	{"OQ81", 4, 24525},
	{"OQ82", 4, 24526},
	{"OQ83", 4, 24527},
	{"OQ84", 4, 24528},
	{"OQ85", 4, 24529},
	{"OQ86", 4, 24530},
	{"OQ87", 4, 24531},
	{"OQ88", 4, 24532},
	{"OQ89", 4, 24533},
	{"OQ90", 4, 24534},
	{"OQ91", 4, 24535},
	{"OQ92", 4, 24536},
	{"OQ93", 4, 24537},
	{"OQ94", 4, 24538},
	{"OQ95", 4, 24539},
	{"OQ96", 4, 24540},
	{"OQ97", 4, 24541},
	{"OQ98", 4, 24542},
	{"OQ99", 4, 24543},
	{"PB00", 4, 24544},
	{"PB01", 4, 24545},
	{"PB02", 4, 24546},
	{"PB03", 4, 24547},
	{"PB04", 4, 24548},
	{"PB05", 4, 24549},
	{"PB06", 4, 24550},
	{"PB07", 4, 24551},
	{"PB08", 4, 24552},
	{"PB09", 4, 24553},
	{"PB10", 4, 24554},
	{"PB11", 4, 24555},
	{"PB12", 4, 24556},
	{"PB13", 4, 24557},
	{"PB14", 4, 24558},
	{"PB15", 4, 24559},
	{"PB16", 4, 24560},
	{"PB17", 4, 24561},
	{"PB18", 4, 24562},
	{"PB19", 4, 24563},
	{"PB20", 4, 24564},
	{"PB21", 4, 24565},
	{"PB22", 4, 24566},
	{"PB23", 4, 24567},
	{"PB24", 4, 24568},
	{"PB25", 4, 24569},
	{"PB26", 4, 24570},
	{"PB27", 4, 24571},
	{"PB28", 4, 24572},
	{"PB29", 4, 24573},
	{"PB30", 4, 24574},
	{"PB31", 4, 24575},
	{"PB32", 4, 24576},
	{"PB33", 4, 24577},
	{"PB34", 4, 24578},
	{"PB35", 4, 24579},
	{"PB36", 4, 24580},
	{"PB37", 4, 24581},
	{"PB38", 4, 24582},
	{"PB39", 4, 24583},
	{"PB40", 4, 24584},
	{"PB41", 4, 24585},
	{"PB42", 4, 24586},
	{"PB43", 4, 24587},
	{"PB44", 4, 24588},
	{"PB45", 4, 24589},
	{"PB46", 4, 24590},
	{"PB47", 4, 24591},
	{"PB48", 4, 24592},
	{"PB49", 4, 24593},
	{"PB50", 4, 24594},
	{"PB51", 4, 24595},
	{"PB52", 4, 24596},
	{"PB53", 4, 24597},
	{"PB54", 4, 24598},
	{"PB55", 4, 24599},
	{"PB56", 4, 24600},
	{"PB57", 4, 24601},
	{"PB58", 4, 24602},
	{"PB59", 4, 24603},
	{"PB60", 4, 24604},
	{"PB61", 4, 24605},
	{"PB62", 4, 24606},
	{"PB63", 4, 24607},
	{"PB64", 4, 24608},
	{"PB65", 4, 24609},
	{"PB66", 4, 24610},
	{"PB67", 4, 24611},
	{"PB68", 4, 24612},
	{"PB69", 4, 24613},
	{"PB70", 4, 24614},
	{"PB71", 4, 24615},
	{"PB72", 4, 24616},
	{"PB73", 4, 24617},
	{"PB74", 4, 24618},
	{"PB75", 4, 24619},
	{"PB76", 4, 24620},
	{"PB77", 4, 24621},
	{"PB78", 4, 24622},
	{"PB79", 4, 24623},
	{"PB80", 4, 24624},
	{"PB81", 4, 24625},
	{"PB82", 4, 24626},
	{"PB83", 4, 24627},
	{"PB84", 4, 24628},
	{"PB85", 4, 24629},
	{"PB86", 4, 24630},
	{"PB87", 4, 24631},
	{"PB88", 4, 24632},
	{"PB89", 4, 24633},
	{"PB90", 4, 24634},
	{"PB91", 4, 24635},
	{"PB92", 4, 24636},
	{"PB93", 4, 24637},
	{"PB94", 4, 24638},
	{"PB95", 4, 24639},
	{"PB96", 4, 24640},
	{"PB97", 4, 24641},
	{"PB98", 4, 24642},
	{"PB99", 4, 24643},
	{"PC00", 4, 24644},
	{"PC01", 4, 24645},
	{"PC02", 4, 24646},
	{"PC03", 4, 24647},
	{"PC04", 4, 24648},
	{"PC05", 4, 24649},
	{"PC06", 4, 24650},
	{"PC07", 4, 24651},
	{"PC08", 4, 24652},
	{"PC09", 4, 24653},
	{"PC10", 4, 24654},
	{"PC11", 4, 24655},
	{"PC12", 4, 24656},
	{"PC13", 4, 24657},
	{"PC14", 4, 24658},
	{"PC15", 4, 24659},
	{"PC16", 4, 24660},
	{"PC17", 4, 24661},
	{"PC18", 4, 24662},
	{"PC19", 4, 24663},
	{"PC20", 4, 24664},
	{"PC21", 4, 24665},
	{"PC22", 4, 24666},
	{"PC23", 4, 24667},
	{"PC24", 4, 24668},
	{"PC25", 4, 24669},
	{"PC26", 4, 24670},
	{"PC27", 4, 24671},
	{"PC28", 4, 24672},
	{"PC29", 4, 24673},
	{"PC30", 4, 24674},
	{"PC31", 4, 24675},
	{"PC32", 4, 24676},
	{"PC33", 4, 24677},
	{"PC34", 4, 24678},
	{"PC35", 4, 24679},
	{"PC36", 4, 24680},
	{"PC37", 4, 24681},
	{"PC38", 4, 24682},
	{"PC39", 4, 24683},
	{"PC40", 4, 24684},
	{"PC41", 4, 24685},
	{"PC42", 4, 24686},
	{"PC43", 4, 24687},
	{"PC44", 4, 24688},
	{"PC45", 4, 24689},
	{"PC46", 4, 24690},
	{"PC47", 4, 24691},
	{"PC48", 4, 24692},
	{"PC49", 4, 24693},
	{"PC50", 4, 24694},
	{"PC51", 4, 24695},
	{"PC52", 4, 24696},
	{"PC53", 4, 24697},
	{"PC54", 4, 24698},
	{"PC55", 4, 24699},
	{"PC56", 4, 24700},
	{"PC57", 4, 24701},
	{"PC58", 4, 24702},
	{"PC59", 4, 24703},
	{"PC60", 4, 24704},
	{"PC61", 4, 24705},
	{"PC62", 4, 24706},
	{"PC63", 4, 24707},
	{"PC64", 4, 24708},
	{"PC65", 4, 24709},
	{"PC66", 4, 24710},
	{"PC67", 4, 24711},
	{"PC68", 4, 24712},
	{"PC69", 4, 24713},
	{"PC70", 4, 24714},
	{"PC71", 4, 24715},
	{"PC72", 4, 24716},
	{"PC73", 4, 24717},
	{"PC74", 4, 24718},
	{"PC75", 4, 24719},
	{"PC76", 4, 24720},
	{"PC77", 4, 24721},
	{"PC78", 4, 24722},
	{"PC79", 4, 24723},
	{"PC80", 4, 24724},
	{"PC81", 4, 24725},
	{"PC82", 4, 24726},
	{"PC83", 4, 24727},
	{"PC84", 4, 24728},
	{"PC85", 4, 24729},
	{"PC86", 4, 24730},
	{"PC87", 4, 24731},
	{"PC88", 4, 24732},
	{"PC89", 4, 24733},
	{"PC90", 4, 24734},
	{"PC91", 4, 24735},
	{"PC92", 4, 24736},
	{"PC93", 4, 24737},
	{"PC94", 4, 24738},
	{"PC95", 4, 24739},
	{"PC96", 4, 24740},
	{"PC97", 4, 24741},
	{"PC98", 4, 24742},
	{"PC99", 4, 24743},
	{"PF00", 4, 24744},
	{"PF01", 4, 24745},
	{"PF02", 4, 24746},
	{"PF03", 4, 24747},
	{"PF04", 4, 24748},
	{"PF05", 4, 24749},
	{"PF06", 4, 24750},
	{"PF07", 4, 24751},
	{"PF08", 4, 24752},
	{"PF09", 4, 24753},
	{"PF10", 4, 24754},
	{"PF11", 4, 24755},
	{"PF12", 4, 24756},
	{"PF13", 4, 24757},
	{"PF14", 4, 24758},
	{"PF15", 4, 24759},
	{"PF16", 4, 24760},
	{"PF17", 4, 24761},
	{"PF18", 4, 24762},
	{"PF19", 4, 24763},
	{"PF20", 4, 24764},
	{"PF21", 4, 24765},
	{"PF22", 4, 24766},
	{"PF23", 4, 24767},
	{"PF24", 4, 24768},
	{"PF25", 4, 24769},
	{"PF26", 4, 24770},
	{"PF27", 4, 24771},
	{"PF28", 4, 24772},
	{"PF29", 4, 24773},
	{"PF30", 4, 24774},
	{"PF31", 4, 24775},
	{"PF32", 4, 24776},
	{"PF33", 4, 24777},
	{"PF34", 4, 24778},
	{"PF35", 4, 24779},
	{"PF36", 4, 24780},
	{"PF37", 4, 24781},
	{"PF38", 4, 24782},
	{"PF39", 4, 24783},
	{"PF40", 4, 24784},
	{"PF41", 4, 24785},
	{"PF42", 4, 24786},
	{"PF43", 4, 24787},
	{"PF44", 4, 24788},
	{"PF45", 4, 24789},
	{"PF46", 4, 24790},
	{"PF47", 4, 24791},
	{"PF48", 4, 24792},
	{"PF49", 4, 24793},
	{"PF50", 4, 24794},
	{"PF51", 4, 24795},
	{"PF52", 4, 24796},
	{"PF53", 4, 24797},
	{"PF54", 4, 24798},
	{"PF55", 4, 24799},
	{"PF56", 4, 24800},
	{"PF57", 4, 24801},
	{"PF58", 4, 24802},
	{"PF59", 4, 24803},
	{"PF60", 4, 24804},
	{"PF61", 4, 24805},
	{"PF62", 4, 24806},
	{"PF63", 4, 24807},
	{"PF64", 4, 24808},
	{"PF65", 4, 24809},
	{"PF66", 4, 24810},
	{"PF67", 4, 24811},
	{"PF68", 4, 24812},
	{"PF69", 4, 24813},
	{"PF70", 4, 24814},
	{"PF71", 4, 24815},
	{"PF72", 4, 24816},
	{"PF73", 4, 24817},
	{"PF74", 4, 24818},
	{"PF75", 4, 24819},
	{"PF76", 4, 24820},
	{"PF77", 4, 24821},
	{"PF78", 4, 24822},
	{"PF79", 4, 24823},
	{"PF80", 4, 24824},
	{"PF81", 4, 24825},
	{"PF82", 4, 24826},
	{"PF83", 4, 24827},
	{"PF84", 4, 24828},
	{"PF85", 4, 24829},
	{"PF86", 4, 24830},
	{"PF87", 4, 24831},
	{"PF88", 4, 24832},
	{"PF89", 4, 24833},
	{"PF90", 4, 24834},
	{"PF91", 4, 24835},
	{"PF92", 4, 24836},
	{"PF93", 4, 24837},
	{"PF94", 4, 24838},
	{"PF95", 4, 24839},
	{"PF96", 4, 24840},
	{"PF97", 4, 24841},
	{"PF98", 4, 24842},
	{"PF99", 4, 24843},
	{"PG00", 4, 24844},
	{"PG01", 4, 24845},
	{"PG02", 4, 24846},
	{"PG03", 4, 24847},
	{"PG04", 4, 24848},
	{"PG05", 4, 24849},
	{"PG06", 4, 24850},
	{"PG07", 4, 24851},
	{"PG08", 4, 24852},
	{"PG09", 4, 24853},
	{"PG10", 4, 24854},
	{"PG11", 4, 24855},
	{"PG12", 4, 24856},
	{"PG13", 4, 24857},
	{"PG14", 4, 24858},
	{"PG15", 4, 24859},
	{"PG16", 4, 24860},
	{"PG17", 4, 24861},
	{"PG18", 4, 24862},
	{"PG19", 4, 24863},
	{"PG20", 4, 24864},
	{"PG21", 4, 24865},
	{"PG22", 4, 24866},
	{"PG23", 4, 24867},
	{"PG24", 4, 24868},
	{"PG25", 4, 24869},
	{"PG26", 4, 24870},
	{"PG27", 4, 24871},
	{"PG28", 4, 24872},
	{"PG29", 4, 24873},
	{"PG30", 4, 24874},
	{"PG31", 4, 24875},
	{"PG32", 4, 24876},
	{"PG33", 4, 24877},
	{"PG34", 4, 24878},
	{"PG35", 4, 24879},
	{"PG36", 4, 24880},
	{"PG37", 4, 24881},
	{"PG38", 4, 24882},
	{"PG39", 4, 24883},
	{"PG40", 4, 24884},
	{"PG41", 4, 24885},
	{"PG42", 4, 24886},
	{"PG43", 4, 24887},
	{"PG44", 4, 24888},
	{"PG45", 4, 24889},
	{"PG46", 4, 24890},
	{"PG47", 4, 24891},
	{"PG48", 4, 24892},
	{"PG49", 4, 24893},
	{"PG50", 4, 24894},
	{"PG51", 4, 24895},
	{"PG52", 4, 24896},
	{"PG53", 4, 24897},
	{"PG54", 4, 24898},
	{"PG55", 4, 24899},
	{"PG56", 4, 24900},
	{"PG57", 4, 24901},
	{"PG58", 4, 24902},
	{"PG59", 4, 24903},
	{"PG60", 4, 24904},
	{"PG61", 4, 24905},
	{"PG62", 4, 24906},
	{"PG63", 4, 24907},
	{"PG64", 4, 24908},
	{"PG65", 4, 24909},
	{"PG66", 4, 24910},
	{"PG67", 4, 24911},
	{"PG68", 4, 24912},
	{"PG69", 4, 24913},
	{"PG70", 4, 24914},
	{"PG71", 4, 24915},
	{"PG72", 4, 24916},
	{"PG73", 4, 24917},
	{"PG74", 4, 24918},
	{"PG75", 4, 24919},
	{"PG76", 4, 24920},
	{"PG77", 4, 24921},
	{"PG78", 4, 24922},
	{"PG79", 4, 24923},
	{"PG80", 4, 24924},
	{"PG81", 4, 24925},
	{"PG82", 4, 24926},
	{"PG83", 4, 24927},
	{"PG84", 4, 24928},
	{"PG85", 4, 24929},
	{"PG86", 4, 24930},
	{"PG87", 4, 24931},
	{"PG88", 4, 24932},
	{"PG89", 4, 24933},
	{"PG90", 4, 24934},
	{"PG91", 4, 24935},
	{"PG92", 4, 24936},
	{"PG93", 4, 24937},
	{"PG94", 4, 24938},
	{"PG95", 4, 24939},
	{"PG96", 4, 24940},
	{"PG97", 4, 24941},
	{"PG98", 4, 24942},
	{"PG99", 4, 24943},
	{"PH00", 4, 24944},
	{"PH01", 4, 24945},
	{"PH02", 4, 24946},
	{"PH03", 4, 24947},
	{"PH04", 4, 24948},
	{"PH05", 4, 24949},
	{"PH06", 4, 24950},
	{"PH07", 4, 24951},
	{"PH08", 4, 24952},
	{"PH09", 4, 24953},
	{"PH10", 4, 24954},
	{"PH11", 4, 24955},
	{"PH12", 4, 24956},
	{"PH13", 4, 24957},
	{"PH14", 4, 24958},
	{"PH15", 4, 24959},
	{"PH16", 4, 24960},
	{"PH17", 4, 24961},
	{"PH18", 4, 24962},
	{"PH19", 4, 24963},
	{"PH20", 4, 24964},
	{"PH21", 4, 24965},
	{"PH22", 4, 24966},
	{"PH23", 4, 24967},
	{"PH24", 4, 24968},
	{"PH25", 4, 24969},
	{"PH26", 4, 24970},
	{"PH27", 4, 24971},
	{"PH28", 4, 24972},
	{"PH29", 4, 24973},
	{"PH30", 4, 24974},
	{"PH31", 4, 24975},
	{"PH32", 4, 24976},
	{"PH33", 4, 24977},
	{"PH34", 4, 24978},
	{"PH35", 4, 24979},
	{"PH36", 4, 24980},
	{"PH37", 4, 24981},
	{"PH38", 4, 24982},
	{"PH39", 4, 24983},
	{"PH40", 4, 24984},
	{"PH41", 4, 24985},
	{"PH42", 4, 24986},
	{"PH43", 4, 24987},
	{"PH44", 4, 24988},
	{"PH45", 4, 24989},
	{"PH46", 4, 24990},
	{"PH47", 4, 24991},
	{"PH48", 4, 24992},
	{"PH49", 4, 24993},
	{"PH50", 4, 24994},
	{"PH51", 4, 24995},
	{"PH52", 4, 24996},
	{"PH53", 4, 24997},
	{"PH54", 4, 24998},
	{"PH55", 4, 24999},
	{"PH56", 4, 25000},
	{"PH57", 4, 25001},
	{"PH58", 4, 25002},
	{"PH59", 4, 25003},
	{"PH60", 4, 25004},
	{"PH61", 4, 25005},
	{"PH62", 4, 25006},
	{"PH63", 4, 25007},
	{"PH64", 4, 25008},
	{"PH65", 4, 25009},
	{"PH66", 4, 25010},
	{"PH67", 4, 25011},
	{"PH68", 4, 25012},
	{"PH69", 4, 25013},
	{"PH70", 4, 25014},
	{"PH71", 4, 25015},
	{"PH72", 4, 25016},
	{"PH73", 4, 25017},
	{"PH74", 4, 25018},
	{"PH75", 4, 25019},
	{"PH76", 4, 25020},
	{"PH77", 4, 25021},
	{"PH78", 4, 25022},
	{"PH79", 4, 25023},
	{"PH80", 4, 25024},
	{"PH81", 4, 25025},
	{"PH82", 4, 25026},
	{"PH83", 4, 25027},
	{"PH84", 4, 25028},
	{"PH85", 4, 25029},
	{"PH86", 4, 25030},
	{"PH87", 4, 25031},
	{"PH88", 4, 25032},
	{"PH89", 4, 25033},
	{"PH90", 4, 25034},
	{"PH91", 4, 25035},
	{"PH92", 4, 25036},
	{"PH93", 4, 25037},
	{"PH94", 4, 25038},
	{"PH95", 4, 25039},
	{"PH96", 4, 25040},
	{"PH97", 4, 25041},
	{"PH98", 4, 25042},
	{"PH99", 4, 25043},
	{"PI00", 4, 25044},
	{"PI01", 4, 25045},
	{"PI02", 4, 25046},
	{"PI03", 4, 25047},
	{"PI04", 4, 25048},
	{"PI05", 4, 25049},
	{"PI06", 4, 25050},
	{"PI07", 4, 25051},
	{"PI08", 4, 25052},
	{"PI09", 4, 25053},
	{"PI10", 4, 25054},
	{"PI11", 4, 25055},
	{"PI12", 4, 25056},
	{"PI13", 4, 25057},
	{"PI14", 4, 25058},
	{"PI15", 4, 25059},
	{"PI16", 4, 25060},
	{"PI17", 4, 25061},
	{"PI18", 4, 25062},
	{"PI19", 4, 25063},
	{"PI20", 4, 25064},
	{"PI21", 4, 25065},
	{"PI22", 4, 25066},
	{"PI23", 4, 25067},
	{"PI24", 4, 25068},
	{"PI25", 4, 25069},
	{"PI26", 4, 25070},
	{"PI27", 4, 25071},
	{"PI28", 4, 25072},
	{"PI29", 4, 25073},
	{"PI30", 4, 25074},
	{"PI31", 4, 25075},
	{"PI32", 4, 25076},
	{"PI33", 4, 25077},
	{"PI34", 4, 25078},
	{"PI35", 4, 25079},
	{"PI36", 4, 25080},
	{"PI37", 4, 25081},
	{"PI38", 4, 25082},
	{"PI39", 4, 25083},
	{"PI40", 4, 25084},
	{"PI41", 4, 25085},
	{"PI42", 4, 25086},
	{"PI43", 4, 25087},
	{"PI44", 4, 25088},
	{"PI45", 4, 25089},
	{"PI46", 4, 25090},
	{"PI47", 4, 25091},
	{"PI48", 4, 25092},
	{"PI49", 4, 25093},
	{"PI50", 4, 25094},
	{"PI51", 4, 25095},
	{"PI52", 4, 25096},
	{"PI53", 4, 25097},
	{"PI54", 4, 25098},
	{"PI55", 4, 25099},
	{"PI56", 4, 25100},
	{"PI57", 4, 25101},
	{"PI58", 4, 25102},
	{"PI59", 4, 25103},
	{"PI60", 4, 25104},
	{"PI61", 4, 25105},
	{"PI62", 4, 25106},
	{"PI63", 4, 25107},
	{"PI64", 4, 25108},
	{"PI65", 4, 25109},
	{"PI66", 4, 25110},
	{"PI67", 4, 25111},
	{"PI68", 4, 25112},
	{"PI69", 4, 25113},
	{"PI70", 4, 25114},
	{"PI71", 4, 25115},
	{"PI72", 4, 25116},
	{"PI73", 4, 25117},
	{"PI74", 4, 25118},
	{"PI75", 4, 25119},
	{"PI76", 4, 25120},
	{"PI77", 4, 25121},
	{"PI78", 4, 25122},
	{"PI79", 4, 25123},
	{"PI80", 4, 25124},
	{"PI81", 4, 25125},
	{"PI82", 4, 25126},
	{"PI83", 4, 25127},
	{"PI84", 4, 25128},
	{"PI85", 4, 25129},
	{"PI86", 4, 25130},
	{"PI87", 4, 25131},
	{"PI88", 4, 25132},
	{"PI89", 4, 25133},
	{"PI90", 4, 25134},
	{"PI91", 4, 25135},
	{"PI92", 4, 25136},
	{"PI93", 4, 25137},
	{"PI94", 4, 25138},
	{"PI95", 4, 25139},
	{"PI96", 4, 25140},
	{"PI97", 4, 25141},
	{"PI98", 4, 25142},
	{"PI99", 4, 25143},
	{"PJ00", 4, 25144},
	{"PJ01", 4, 25145},
	{"PJ02", 4, 25146},
	{"PJ03", 4, 25147},
	{"PJ04", 4, 25148},
	{"PJ05", 4, 25149},
	{"PJ06", 4, 25150},
	{"PJ07", 4, 25151},
	{"PJ08", 4, 25152},
	{"PJ09", 4, 25153},
	{"PJ10", 4, 25154},
	{"PJ11", 4, 25155},
	{"PJ12", 4, 25156},
	{"PJ13", 4, 25157},
	{"PJ14", 4, 25158},
	{"PJ15", 4, 25159},
	{"PJ16", 4, 25160},
	{"PJ17", 4, 25161},
	{"PJ18", 4, 25162},
	{"PJ19", 4, 25163},
	{"PJ20", 4, 25164},
	{"PJ21", 4, 25165},
	{"PJ22", 4, 25166},
	{"PJ23", 4, 25167},
	{"PJ24", 4, 25168},
	{"PJ25", 4, 25169},
	{"PJ26", 4, 25170},
	{"PJ27", 4, 25171},
	{"PJ28", 4, 25172},
	{"PJ29", 4, 25173},
	{"PJ30", 4, 25174},
	{"PJ31", 4, 25175},
	{"PJ32", 4, 25176},
	{"PJ33", 4, 25177},
	{"PJ34", 4, 25178},
	{"PJ35", 4, 25179},
	{"PJ36", 4, 25180},
	{"PJ37", 4, 25181},
	{"PJ38", 4, 25182},
	{"PJ39", 4, 25183},
	{"PJ40", 4, 25184},
	{"PJ41", 4, 25185},
	{"PJ42", 4, 25186},
	{"PJ43", 4, 25187},
	{"PJ44", 4, 25188},
	{"PJ45", 4, 25189},
	{"PJ46", 4, 25190},
	{"PJ47", 4, 25191},
	{"PJ48", 4, 25192},
	{"PJ49", 4, 25193},
	{"PJ50", 4, 25194},
	{"PJ51", 4, 25195},
	{"PJ52", 4, 25196},
	{"PJ53", 4, 25197},
	{"PJ54", 4, 25198},
	{"PJ55", 4, 25199},
	{"PJ56", 4, 25200},
	{"PJ57", 4, 25201},
	{"PJ58", 4, 25202},
	{"PJ59", 4, 25203},
	{"PJ60", 4, 25204},
	{"PJ61", 4, 25205},
	{"PJ62", 4, 25206},
	{"PJ63", 4, 25207},
	{"PJ64", 4, 25208},
	{"PJ65", 4, 25209},
	{"PJ66", 4, 25210},
	{"PJ67", 4, 25211},
	{"PJ68", 4, 25212},
	{"PJ69", 4, 25213},
	{"PJ70", 4, 25214},
	{"PJ71", 4, 25215},
	{"PJ72", 4, 25216},
	{"PJ73", 4, 25217},
	{"PJ74", 4, 25218},
	{"PJ75", 4, 25219},
	{"PJ76", 4, 25220},
	{"PJ77", 4, 25221},
	{"PJ78", 4, 25222},
	{"PJ79", 4, 25223},
	{"PJ80", 4, 25224},
	{"PJ81", 4, 25225},
	{"PJ82", 4, 25226},
	{"PJ83", 4, 25227},
	{"PJ84", 4, 25228},
	{"PJ85", 4, 25229},
	{"PJ86", 4, 25230},
	{"PJ87", 4, 25231},
	{"PJ88", 4, 25232},
	{"PJ89", 4, 25233},
	{"PJ90", 4, 25234},
	{"PJ91", 4, 25235},
	{"PJ92", 4, 25236},
	{"PJ93", 4, 25237},
	{"PJ94", 4, 25238},
	{"PJ95", 4, 25239},
	{"PJ96", 4, 25240},
	{"PJ97", 4, 25241},
	{"PJ98", 4, 25242},
	{"PJ99", 4, 25243},
	{"PK00", 4, 25244},
	{"PK01", 4, 25245},
	{"PK02", 4, 25246},
	{"PK03", 4, 25247},
	{"PK04", 4, 25248},
	{"PK05", 4, 25249},
	{"PK06", 4, 25250},
	{"PK07", 4, 25251},
	{"PK08", 4, 25252},
	{"PK09", 4, 25253},
	{"PK10", 4, 25254},
	{"PK11", 4, 25255},
	{"PK12", 4, 25256},
	{"PK13", 4, 25257},
	{"PK14", 4, 25258},
	{"PK15", 4, 25259},
	{"PK16", 4, 25260},
	{"PK17", 4, 25261},
	{"PK18", 4, 25262},
	{"PK19", 4, 25263},
	{"PK20", 4, 25264},
	{"PK21", 4, 25265},
	{"PK22", 4, 25266},
	{"PK23", 4, 25267},
	{"PK24", 4, 25268},
	{"PK25", 4, 25269},
	{"PK26", 4, 25270},
	{"PK27", 4, 25271},
	{"PK28", 4, 25272},
	{"PK29", 4, 25273},
	{"PK30", 4, 25274},
	{"PK31", 4, 25275},
	{"PK32", 4, 25276},
	{"PK33", 4, 25277},
	{"PK34", 4, 25278},
	{"PK35", 4, 25279},
	{"PK36", 4, 25280},
	{"PK37", 4, 25281},
	{"PK38", 4, 25282},
	{"PK39", 4, 25283},
	{"PK40", 4, 25284},
	{"PK41", 4, 25285},
	{"PK42", 4, 25286},
	{"PK43", 4, 25287},
	{"PK44", 4, 25288},
	{"PK45", 4, 25289},
	{"PK46", 4, 25290},
	{"PK47", 4, 25291},
	{"PK48", 4, 25292},
	{"PK49", 4, 25293},
	{"PK50", 4, 25294},
	{"PK51", 4, 25295},
	{"PK52", 4, 25296},
	{"PK53", 4, 25297},
	{"PK54", 4, 25298},
	{"PK55", 4, 25299},
	{"PK56", 4, 25300},
	{"PK57", 4, 25301},
	{"PK58", 4, 25302},
	{"PK59", 4, 25303},
	{"PK60", 4, 25304},
	{"PK61", 4, 25305},
	{"PK62", 4, 25306},
	{"PK63", 4, 25307},
	{"PK64", 4, 25308},
	{"PK65", 4, 25309},
	{"PK66", 4, 25310},
	{"PK67", 4, 25311},
	{"PK68", 4, 25312},
	{"PK69", 4, 25313},
	{"PK70", 4, 25314},
	{"PK71", 4, 25315},
	{"PK72", 4, 25316},
	{"PK73", 4, 25317},
	{"PK74", 4, 25318},
	{"PK75", 4, 25319},
	{"PK76", 4, 25320},
	{"PK77", 4, 25321},
	{"PK78", 4, 25322},
	{"PK79", 4, 25323},
	{"PK80", 4, 25324},
	{"PK81", 4, 25325},
	{"PK82", 4, 25326},
	{"PK83", 4, 25327},
	{"PK84", 4, 25328},
	{"PK85", 4, 25329},
	{"PK86", 4, 25330},
	{"PK87", 4, 25331},
	{"PK88", 4, 25332},
	{"PK89", 4, 25333},
	{"PK90", 4, 25334},
	{"PK91", 4, 25335},
	{"PK92", 4, 25336},
	{"PK93", 4, 25337},
	{"PK94", 4, 25338},
	{"PK95", 4, 25339},
	{"PK96", 4, 25340},
	{"PK97", 4, 25341},
	{"PK98", 4, 25342},
	{"PK99", 4, 25343},
	{"PL00", 4, 25344},
	{"PL01", 4, 25345},
	{"PL02", 4, 25346},
	{"PL03", 4, 25347},
	{"PL04", 4, 25348},
	{"PL05", 4, 25349},
	{"PL06", 4, 25350},
	{"PL07", 4, 25351},
	{"PL08", 4, 25352},
	{"PL09", 4, 25353},
	{"PL10", 4, 25354},
	{"PL11", 4, 25355},
	{"PL12", 4, 25356},
	{"PL13", 4, 25357},
	{"PL14", 4, 25358},
	{"PL15", 4, 25359},
	{"PL16", 4, 25360},
	{"PL17", 4, 25361},
	{"PL18", 4, 25362},
	{"PL19", 4, 25363},
	{"PL20", 4, 25364},
	{"PL21", 4, 25365},
	{"PL22", 4, 25366},
	{"PL23", 4, 25367},
	{"PL24", 4, 25368},
	{"PL25", 4, 25369},
	{"PL26", 4, 25370},
	{"PL27", 4, 25371},
	{"PL28", 4, 25372},
	{"PL29", 4, 25373},
	{"PL30", 4, 25374},
	{"PL31", 4, 25375},
	{"PL32", 4, 25376},
	{"PL33", 4, 25377},
	{"PL34", 4, 25378},
	{"PL35", 4, 25379},
	{"PL36", 4, 25380},
	{"PL37", 4, 25381},
	{"PL38", 4, 25382},
	{"PL39", 4, 25383},
	{"PL40", 4, 25384},
	{"PL41", 4, 25385},
	{"PL42", 4, 25386},
	{"PL43", 4, 25387},
	{"PL44", 4, 25388},
	{"PL45", 4, 25389},
	{"PL46", 4, 25390},
	{"PL47", 4, 25391},
	{"PL48", 4, 25392},
	{"PL49", 4, 25393},
	{"PL50", 4, 25394},
	{"PL51", 4, 25395},
	{"PL52", 4, 25396},
	{"PL53", 4, 25397},
	{"PL54", 4, 25398},
	{"PL55", 4, 25399},
	{"PL56", 4, 25400},
	{"PL57", 4, 25401},
	{"PL58", 4, 25402},
	{"PL59", 4, 25403},
	{"PL60", 4, 25404},
	{"PL61", 4, 25405},
	{"PL62", 4, 25406},
	{"PL63", 4, 25407},
	{"PL64", 4, 25408},
	{"PL65", 4, 25409},
	{"PL66", 4, 25410},
	{"PL67", 4, 25411},
	{"PL68", 4, 25412},
	{"PL69", 4, 25413},
	{"PL70", 4, 25414},
	{"PL71", 4, 25415},
	{"PL72", 4, 25416},
	{"PL73", 4, 25417},
	{"PL74", 4, 25418},
	{"PL75", 4, 25419},
	{"PL76", 4, 25420},
	{"PL77", 4, 25421},
	{"PL78", 4, 25422},
	{"PL79", 4, 25423},
	{"PL80", 4, 25424},
	{"PL81", 4, 25425},
	{"PL82", 4, 25426},
	{"PL83", 4, 25427},
	{"PL84", 4, 25428},
	{"PL85", 4, 25429},
	{"PL86", 4, 25430},
	{"PL87", 4, 25431},
	{"PL88", 4, 25432},
	{"PL89", 4, 25433},
	{"PL90", 4, 25434},
	{"PL91", 4, 25435},
	{"PL92", 4, 25436},
	{"PL93", 4, 25437},
	{"PL94", 4, 25438},
	{"PL95", 4, 25439},
	{"PL96", 4, 25440},
	{"PL97", 4, 25441},
	{"PL98", 4, 25442},
	{"PL99", 4, 25443},
	{"PM00", 4, 25444},
	{"PM01", 4, 25445},
	{"PM02", 4, 25446},
	{"PM03", 4, 25447},
	{"PM04", 4, 25448},
	{"PM05", 4, 25449},
	{"PM06", 4, 25450},
	{"PM07", 4, 25451},
	{"PM08", 4, 25452},
	{"PM09", 4, 25453},
	{"PM10", 4, 25454},
	{"PM11", 4, 25455},
	{"PM12", 4, 25456},
	{"PM13", 4, 25457},
	{"PM14", 4, 25458},
	{"PM15", 4, 25459},
	{"PM16", 4, 25460},
	{"PM17", 4, 25461},
	{"PM18", 4, 25462},
	{"PM19", 4, 25463},
	{"PM20", 4, 25464},
	{"PM21", 4, 25465},
	{"PM22", 4, 25466},
	{"PM23", 4, 25467},
	{"PM24", 4, 25468},
	{"PM25", 4, 25469},
	{"PM26", 4, 25470},
	{"PM27", 4, 25471},
	{"PM28", 4, 25472},
	{"PM29", 4, 25473},
	{"PM30", 4, 25474},
	{"PM31", 4, 25475},
	{"PM32", 4, 25476},
	{"PM33", 4, 25477},
	{"PM34", 4, 25478},
	{"PM35", 4, 25479},
	{"PM36", 4, 25480},
	{"PM37", 4, 25481},
	{"PM38", 4, 25482},
	{"PM39", 4, 25483},
	{"PM40", 4, 25484},
	{"PM41", 4, 25485},
	{"PM42", 4, 25486},
	{"PM43", 4, 25487},
	{"PM44", 4, 25488},
	{"PM45", 4, 25489},
	{"PM46", 4, 25490},
	{"PM47", 4, 25491},
	{"PM48", 4, 25492},
	{"PM49", 4, 25493},
	{"PM50", 4, 25494},
	{"PM51", 4, 25495},
	{"PM52", 4, 25496},
	{"PM53", 4, 25497},
	{"PM54", 4, 25498},
	{"PM55", 4, 25499},
	{"PM56", 4, 25500},
	{"PM57", 4, 25501},
	{"PM58", 4, 25502},
	{"PM59", 4, 25503},
	{"PM60", 4, 25504},
	{"PM61", 4, 25505},
	{"PM62", 4, 25506},
	{"PM63", 4, 25507},
	{"PM64", 4, 25508},
	{"PM65", 4, 25509},
	{"PM66", 4, 25510},
	{"PM67", 4, 25511},
	{"PM68", 4, 25512},
	{"PM69", 4, 25513},
	{"PM70", 4, 25514},
	{"PM71", 4, 25515},
	{"PM72", 4, 25516},
	{"PM73", 4, 25517},
	{"PM74", 4, 25518},
	{"PM75", 4, 25519},
	{"PM76", 4, 25520},
	{"PM77", 4, 25521},
	{"PM78", 4, 25522},
	{"PM79", 4, 25523},
	{"PM80", 4, 25524},
	{"PM81", 4, 25525},
	{"PM82", 4, 25526},
	{"PM83", 4, 25527},
	{"PM84", 4, 25528},
	{"PM85", 4, 25529},
	{"PM86", 4, 25530},
	{"PM87", 4, 25531},
	{"PM88", 4, 25532},
	{"PM89", 4, 25533},
	{"PM90", 4, 25534},
	{"PM91", 4, 25535},
	{"PM92", 4, 25536},
	{"PM93", 4, 25537},
	{"PM94", 4, 25538},
	{"PM95", 4, 25539},
	{"PM96", 4, 25540},
	{"PM97", 4, 25541},
	{"PM98", 4, 25542},
	{"PM99", 4, 25543},
	{"PN00", 4, 25544},
	{"PN01", 4, 25545},
	{"PN02", 4, 25546},
	{"PN03", 4, 25547},
	{"PN04", 4, 25548},
	{"PN05", 4, 25549},
	{"PN06", 4, 25550},
	{"PN07", 4, 25551},
	{"PN08", 4, 25552},
	{"PN09", 4, 25553},
	{"PN10", 4, 25554},
	{"PN11", 4, 25555},
	{"PN12", 4, 25556},
	{"PN13", 4, 25557},
	{"PN14", 4, 25558},
	{"PN15", 4, 25559},
	{"PN16", 4, 25560},
	{"PN17", 4, 25561},
	{"PN18", 4, 25562},
	{"PN19", 4, 25563},
	{"PN20", 4, 25564},
	{"PN21", 4, 25565},
	{"PN22", 4, 25566},
	{"PN23", 4, 25567},
	{"PN24", 4, 25568},
	{"PN25", 4, 25569},
	{"PN26", 4, 25570},
	{"PN27", 4, 25571},
	{"PN28", 4, 25572},
	{"PN29", 4, 25573},
	{"PN30", 4, 25574},
	{"PN31", 4, 25575},
	{"PN32", 4, 25576},
	{"PN33", 4, 25577},
	{"PN34", 4, 25578},
	{"PN35", 4, 25579},
	{"PN36", 4, 25580},
	{"PN37", 4, 25581},
	{"PN38", 4, 25582},
	{"PN39", 4, 25583},
	{"PN40", 4, 25584},
	{"PN41", 4, 25585},
	{"PN42", 4, 25586},
	{"PN43", 4, 25587},
	{"PN44", 4, 25588},
	{"PN45", 4, 25589},
	{"PN46", 4, 25590},
	{"PN47", 4, 25591},
	{"PN48", 4, 25592},
	{"PN49", 4, 25593},
	{"PN50", 4, 25594},
	{"PN51", 4, 25595},
	{"PN52", 4, 25596},
	{"PN53", 4, 25597},
	{"PN54", 4, 25598},
	{"PN55", 4, 25599},
	{"PN56", 4, 25600},
	{"PN57", 4, 25601},
	{"PN58", 4, 25602},
	{"PN59", 4, 25603},
	{"PN60", 4, 25604},
	{"PN61", 4, 25605},
	{"PN62", 4, 25606},
	{"PN63", 4, 25607},
	{"PN64", 4, 25608},
	{"PN65", 4, 25609},
	{"PN66", 4, 25610},
	{"PN67", 4, 25611},
	{"PN68", 4, 25612},
	{"PN69", 4, 25613},
	{"PN70", 4, 25614},
	{"PN71", 4, 25615},
	{"PN72", 4, 25616},
	{"PN73", 4, 25617},
	{"PN74", 4, 25618},
	{"PN75", 4, 25619},
	{"PN76", 4, 25620},
	{"PN77", 4, 25621},
	{"PN78", 4, 25622},
	{"PN79", 4, 25623},
	{"PN80", 4, 25624},
	{"PN81", 4, 25625},
	{"PN82", 4, 25626},
	{"PN83", 4, 25627},
	{"PN84", 4, 25628},
	{"PN85", 4, 25629},
	{"PN86", 4, 25630},
	{"PN87", 4, 25631},
	{"PN88", 4, 25632},
	{"PN89", 4, 25633},
	{"PN90", 4, 25634},
	{"PN91", 4, 25635},
	{"PN92", 4, 25636},
	{"PN93", 4, 25637},
	{"PN94", 4, 25638},
	{"PN95", 4, 25639},
	{"PN96", 4, 25640},
	{"PN97", 4, 25641},
	{"PN98", 4, 25642},
	{"PN99", 4, 25643},
	{"PO00", 4, 25644},
	{"PO01", 4, 25645},
	{"PO02", 4, 25646},
	{"PO03", 4, 25647},
	{"PO04", 4, 25648},
	{"PO05", 4, 25649},
	{"PO06", 4, 25650},
	{"PO07", 4, 25651},
	{"PO08", 4, 25652},
	{"PO09", 4, 25653},
	{"PO10", 4, 25654},
	{"PO11", 4, 25655},
	{"PO12", 4, 25656},
	{"PO13", 4, 25657},
	{"PO14", 4, 25658},
	{"PO15", 4, 25659},
	{"PO16", 4, 25660},
	{"PO17", 4, 25661},
	{"PO18", 4, 25662},
	{"PO19", 4, 25663},
	{"PO20", 4, 25664},
	{"PO21", 4, 25665},
	{"PO22", 4, 25666},
	{"PO23", 4, 25667},
	{"PO24", 4, 25668},
	{"PO25", 4, 25669},
	{"PO26", 4, 25670},
	{"PO27", 4, 25671},
	{"PO28", 4, 25672},
	{"PO29", 4, 25673},
	{"PO30", 4, 25674},
	{"PO31", 4, 25675},
	{"PO32", 4, 25676},
	{"PO33", 4, 25677},
	{"PO34", 4, 25678},
	{"PO35", 4, 25679},
	{"PO36", 4, 25680},
	{"PO37", 4, 25681},
	{"PO38", 4, 25682},
	{"PO39", 4, 25683},
	{"PO40", 4, 25684},
	{"PO41", 4, 25685},
	{"PO42", 4, 25686},
	{"PO43", 4, 25687},
	{"PO44", 4, 25688},
	{"PO45", 4, 25689},
	{"PO46", 4, 25690},
	{"PO47", 4, 25691},
	{"PO48", 4, 25692},
	{"PO49", 4, 25693},
	{"PO50", 4, 25694},
	{"PO51", 4, 25695},
	{"PO52", 4, 25696},
	{"PO53", 4, 25697},
	{"PO54", 4, 25698},
	{"PO55", 4, 25699},
	{"PO56", 4, 25700},
	{"PO57", 4, 25701},
	{"PO58", 4, 25702},
	{"PO59", 4, 25703},
	{"PO60", 4, 25704},
	{"PO61", 4, 25705},
	{"PO62", 4, 25706},
	{"PO63", 4, 25707},
	{"PO64", 4, 25708},
	{"PO65", 4, 25709},
	{"PO66", 4, 25710},
	{"PO67", 4, 25711},
	{"PO68", 4, 25712},
	{"PO69", 4, 25713},
	{"PO70", 4, 25714},
	{"PO71", 4, 25715},
	{"PO72", 4, 25716},
	{"PO73", 4, 25717},
	{"PO74", 4, 25718},
	{"PO75", 4, 25719},
	{"PO76", 4, 25720},
	{"PO77", 4, 25721},
	{"PO78", 4, 25722},
	{"PO79", 4, 25723},
	{"PO80", 4, 25724},
	{"PO81", 4, 25725},
	{"PO82", 4, 25726},
	{"PO83", 4, 25727},
	{"PO84", 4, 25728},
	{"PO85", 4, 25729},
	{"PO86", 4, 25730},
	{"PO87", 4, 25731},
	{"PO88", 4, 25732},
	{"PO89", 4, 25733},
	{"PO90", 4, 25734},
	{"PO91", 4, 25735},
	{"PO92", 4, 25736},
	{"PO93", 4, 25737},
	{"PO94", 4, 25738},
	{"PO95", 4, 25739},
	{"PO96", 4, 25740},
	{"PO97", 4, 25741},
	{"PO98", 4, 25742},
	{"PO99", 4, 25743},
	{"PP00", 4, 25744},
	{"PP01", 4, 25745},
	{"PP02", 4, 25746},
	{"PP03", 4, 25747},
	{"PP04", 4, 25748},
	{"PP05", 4, 25749},
	{"PP06", 4, 25750},
	{"PP07", 4, 25751},
	{"PP08", 4, 25752},
	{"PP09", 4, 25753},
	{"PP10", 4, 25754},
	{"PP11", 4, 25755},
	{"PP12", 4, 25756},
	{"PP13", 4, 25757},
	{"PP14", 4, 25758},
	{"PP15", 4, 25759},
	{"PP16", 4, 25760},
	{"PP17", 4, 25761},
	{"PP18", 4, 25762},
	{"PP19", 4, 25763},
	{"PP20", 4, 25764},
	{"PP21", 4, 25765},
	{"PP22", 4, 25766},
	{"PP23", 4, 25767},
	{"PP24", 4, 25768},
	{"PP25", 4, 25769},
	{"PP26", 4, 25770},
	{"PP27", 4, 25771},
	{"PP28", 4, 25772},
	{"PP29", 4, 25773},
	{"PP30", 4, 25774},
	{"PP31", 4, 25775},
	{"PP32", 4, 25776},
	{"PP33", 4, 25777},
	{"PP34", 4, 25778},
	{"PP35", 4, 25779},
	{"PP36", 4, 25780},
	{"PP37", 4, 25781},
	{"PP38", 4, 25782},
	{"PP39", 4, 25783},
	{"PP40", 4, 25784},
	{"PP41", 4, 25785},
	{"PP42", 4, 25786},
	{"PP43", 4, 25787},
	{"PP44", 4, 25788},
	{"PP45", 4, 25789},
	{"PP46", 4, 25790},
	{"PP47", 4, 25791},
	{"PP48", 4, 25792},
	{"PP49", 4, 25793},
	{"PP50", 4, 25794},
	{"PP51", 4, 25795},
	{"PP52", 4, 25796},
	{"PP53", 4, 25797},
	{"PP54", 4, 25798},
	{"PP55", 4, 25799},
	{"PP56", 4, 25800},
	{"PP57", 4, 25801},
	{"PP58", 4, 25802},
	{"PP59", 4, 25803},
	{"PP60", 4, 25804},
	{"PP61", 4, 25805},
	{"PP62", 4, 25806},
	{"PP63", 4, 25807},
	{"PP64", 4, 25808},
	{"PP65", 4, 25809},
	{"PP66", 4, 25810},
	{"PP67", 4, 25811},
	{"PP68", 4, 25812},
	{"PP69", 4, 25813},
	{"PP70", 4, 25814},
	{"PP71", 4, 25815},
	{"PP72", 4, 25816},
	{"PP73", 4, 25817},
	{"PP74", 4, 25818},
	{"PP75", 4, 25819},
	{"PP76", 4, 25820},
	{"PP77", 4, 25821},
	{"PP78", 4, 25822},
	{"PP79", 4, 25823},
	{"PP80", 4, 25824},
	{"PP81", 4, 25825},
	{"PP82", 4, 25826},
	{"PP83", 4, 25827},
	{"PP84", 4, 25828},
	{"PP85", 4, 25829},
	{"PP86", 4, 25830},
	{"PP87", 4, 25831},
	{"PP88", 4, 25832},
	{"PP89", 4, 25833},
	{"PP90", 4, 25834},
	{"PP91", 4, 25835},
	{"PP92", 4, 25836},
	{"PP93", 4, 25837},
	{"PP94", 4, 25838},
	{"PP95", 4, 25839},
	{"PP96", 4, 25840},
	{"PP97", 4, 25841},
	{"PP98", 4, 25842},
	{"PP99", 4, 25843},
	{"PQ00", 4, 25844},
	{"PQ01", 4, 25845},
	{"PQ02", 4, 25846},
	{"PQ03", 4, 25847},
	{"PQ04", 4, 25848},
	{"PQ05", 4, 25849},
	{"PQ06", 4, 25850},
	{"PQ07", 4, 25851},
	{"PQ08", 4, 25852},
	{"PQ09", 4, 25853},
	{"PQ10", 4, 25854},
	{"PQ11", 4, 25855},
	{"PQ12", 4, 25856},
	{"PQ13", 4, 25857},
	{"PQ14", 4, 25858},
	{"PQ15", 4, 25859},
	{"PQ16", 4, 25860},
	{"PQ17", 4, 25861},
	{"PQ18", 4, 25862},
	{"PQ19", 4, 25863},
	{"PQ20", 4, 25864},
	{"PQ21", 4, 25865},
	{"PQ22", 4, 25866},
	{"PQ23", 4, 25867},
	{"PQ24", 4, 25868},
	{"PQ25", 4, 25869},
	{"PQ26", 4, 25870},
	{"PQ27", 4, 25871},
	{"PQ28", 4, 25872},
	{"PQ29", 4, 25873},
	{"PQ30", 4, 25874},
	{"PQ31", 4, 25875},
	{"PQ32", 4, 25876},
	{"PQ33", 4, 25877},
	{"PQ34", 4, 25878},
	{"PQ35", 4, 25879},
	{"PQ36", 4, 25880},
	{"PQ37", 4, 25881},
	{"PQ38", 4, 25882},
	{"PQ39", 4, 25883},
	{"PQ40", 4, 25884},
	{"PQ41", 4, 25885},
	{"PQ42", 4, 25886},
	{"PQ43", 4, 25887},
	{"PQ44", 4, 25888},
	{"PQ45", 4, 25889},
	{"PQ46", 4, 25890},
	{"PQ47", 4, 25891},
	{"PQ48", 4, 25892},
	{"PQ49", 4, 25893},
	{"PQ50", 4, 25894},
	{"PQ51", 4, 25895},
	{"PQ52", 4, 25896},
	{"PQ53", 4, 25897},
	{"PQ54", 4, 25898},
	{"PQ55", 4, 25899},
	{"PQ56", 4, 25900},
	{"PQ57", 4, 25901},
	{"PQ58", 4, 25902},
	{"PQ59", 4, 25903},
	{"PQ60", 4, 25904},
	{"PQ61", 4, 25905},
	{"PQ62", 4, 25906},
	{"PQ63", 4, 25907},
	{"PQ64", 4, 25908},
	{"PQ65", 4, 25909},
	{"PQ66", 4, 25910},
	{"PQ67", 4, 25911},
	{"PQ68", 4, 25912},
	{"PQ69", 4, 25913},
	{"PQ70", 4, 25914},
	{"PQ71", 4, 25915},
	{"PQ72", 4, 25916},
	{"PQ73", 4, 25917},
	{"PQ74", 4, 25918},
	{"PQ75", 4, 25919},
	{"PQ76", 4, 25920},
	{"PQ77", 4, 25921},
	{"PQ78", 4, 25922},
	{"PQ79", 4, 25923},
	{"PQ80", 4, 25924},
	{"PQ81", 4, 25925},
	{"PQ82", 4, 25926},
	{"PQ83", 4, 25927},
	{"PQ84", 4, 25928},
	{"PQ85", 4, 25929},
	{"PQ86", 4, 25930},
	{"PQ87", 4, 25931},
	{"PQ88", 4, 25932},
	{"PQ89", 4, 25933},
	{"PQ90", 4, 25934},
	{"PQ91", 4, 25935},
	{"PQ92", 4, 25936},
	{"PQ93", 4, 25937},
	{"PQ94", 4, 25938},
	{"PQ95", 4, 25939},
	{"PQ96", 4, 25940},
	{"PQ97", 4, 25941},
	{"PQ98", 4, 25942},
	{"PQ99", 4, 25943},
	{"QB00", 4, 25944},
	{"QB01", 4, 25945},
	{"QB02", 4, 25946},
	{"QB03", 4, 25947},
	{"QB04", 4, 25948},
	{"QB05", 4, 25949},
	{"QB06", 4, 25950},
	{"QB07", 4, 25951},
	{"QB08", 4, 25952},
	{"QB09", 4, 25953},
	{"QB10", 4, 25954},
	{"QB11", 4, 25955},
	{"QB12", 4, 25956},
	{"QB13", 4, 25957},
	{"QB14", 4, 25958},
	{"QB15", 4, 25959},
	{"QB16", 4, 25960},
	{"QB17", 4, 25961},
	{"QB18", 4, 25962},
	{"QB19", 4, 25963},
	{"QB20", 4, 25964},
	{"QB21", 4, 25965},
	{"QB22", 4, 25966},
	{"QB23", 4, 25967},
	{"QB24", 4, 25968},
	{"QB25", 4, 25969},
	{"QB26", 4, 25970},
	{"QB27", 4, 25971},
	{"QB28", 4, 25972},
	{"QB29", 4, 25973},
	{"QB30", 4, 25974},
	{"QB31", 4, 25975},
	{"QB32", 4, 25976},
	{"QB33", 4, 25977},
	{"QB34", 4, 25978},
	{"QB35", 4, 25979},
	{"QB36", 4, 25980},
	{"QB37", 4, 25981},
	{"QB38", 4, 25982},
	{"QB39", 4, 25983},
	{"QB40", 4, 25984},
	{"QB41", 4, 25985},
	{"QB42", 4, 25986},
	{"QB43", 4, 25987},
	{"QB44", 4, 25988},
	{"QB45", 4, 25989},
	{"QB46", 4, 25990},
	{"QB47", 4, 25991},
	{"QB48", 4, 25992},
	{"QB49", 4, 25993},
	{"QB50", 4, 25994},
	{"QB51", 4, 25995},
	{"QB52", 4, 25996},
	{"QB53", 4, 25997},
	{"QB54", 4, 25998},
	{"QB55", 4, 25999},
	{"QB56", 4, 26000},
	{"QB57", 4, 26001},
	{"QB58", 4, 26002},
	{"QB59", 4, 26003},
	{"QB60", 4, 26004},
	{"QB61", 4, 26005},
	{"QB62", 4, 26006},
	{"QB63", 4, 26007},
	{"QB64", 4, 26008},
	{"QB65", 4, 26009},
	{"QB66", 4, 26010},
	{"QB67", 4, 26011},
	{"QB68", 4, 26012},
	{"QB69", 4, 26013},
	{"QB70", 4, 26014},
	{"QB71", 4, 26015},
	{"QB72", 4, 26016},
	{"QB73", 4, 26017},
	{"QB74", 4, 26018},
	{"QB75", 4, 26019},
	{"QB76", 4, 26020},
	{"QB77", 4, 26021},
	{"QB78", 4, 26022},
	{"QB79", 4, 26023},
	{"QB80", 4, 26024},
	{"QB81", 4, 26025},
	{"QB82", 4, 26026},
	{"QB83", 4, 26027},
	{"QB84", 4, 26028},
	{"QB85", 4, 26029},
	{"QB86", 4, 26030},
	{"QB87", 4, 26031},
	{"QB88", 4, 26032},
	{"QB89", 4, 26033},
	{"QB90", 4, 26034},
	{"QB91", 4, 26035},
	{"QB92", 4, 26036},
	{"QB93", 4, 26037},
	{"QB94", 4, 26038},
	{"QB95", 4, 26039},
	{"QB96", 4, 26040},
	{"QB97", 4, 26041},
	{"QB98", 4, 26042},
	{"QB99", 4, 26043},
	{"QC00", 4, 26044},
	{"QC01", 4, 26045},
	{"QC02", 4, 26046},
	{"QC03", 4, 26047},
	{"QC04", 4, 26048},
	{"QC05", 4, 26049},
	{"QC06", 4, 26050},
	{"QC07", 4, 26051},
	{"QC08", 4, 26052},
	{"QC09", 4, 26053},
	{"QC10", 4, 26054},
	{"QC11", 4, 26055},
	{"QC12", 4, 26056},
	{"QC13", 4, 26057},
	{"QC14", 4, 26058},
	{"QC15", 4, 26059},
	{"QC16", 4, 26060},
	{"QC17", 4, 26061},
	{"QC18", 4, 26062},
	{"QC19", 4, 26063},
	{"QC20", 4, 26064},
	{"QC21", 4, 26065},
	{"QC22", 4, 26066},
	{"QC23", 4, 26067},
	{"QC24", 4, 26068},
	{"QC25", 4, 26069},
	{"QC26", 4, 26070},
	{"QC27", 4, 26071},
	{"QC28", 4, 26072},
	{"QC29", 4, 26073},
	{"QC30", 4, 26074},
	{"QC31", 4, 26075},
	{"QC32", 4, 26076},
	{"QC33", 4, 26077},
	{"QC34", 4, 26078},
	{"QC35", 4, 26079},
	{"QC36", 4, 26080},
	{"QC37", 4, 26081},
	{"QC38", 4, 26082},
	{"QC39", 4, 26083},
	{"QC40", 4, 26084},
	{"QC41", 4, 26085},
	{"QC42", 4, 26086},
	{"QC43", 4, 26087},
	{"QC44", 4, 26088},
	{"QC45", 4, 26089},
	{"QC46", 4, 26090},
	{"QC47", 4, 26091},
	{"QC48", 4, 26092},
	{"QC49", 4, 26093},
	{"QC50", 4, 26094},
	{"QC51", 4, 26095},
	{"QC52", 4, 26096},
	{"QC53", 4, 26097},
	{"QC54", 4, 26098},
	{"QC55", 4, 26099},
	{"QC56", 4, 26100},
	{"QC57", 4, 26101},
	{"QC58", 4, 26102},
	{"QC59", 4, 26103},
	{"QC60", 4, 26104},
	{"QC61", 4, 26105},
	{"QC62", 4, 26106},
	{"QC63", 4, 26107},
	{"QC64", 4, 26108},
	{"QC65", 4, 26109},
	{"QC66", 4, 26110},
	{"QC67", 4, 26111},
	{"QC68", 4, 26112},
	{"QC69", 4, 26113},
	{"QC70", 4, 26114},
	{"QC71", 4, 26115},
	{"QC72", 4, 26116},
	{"QC73", 4, 26117},
	{"QC74", 4, 26118},
	{"QC75", 4, 26119},
	{"QC76", 4, 26120},
	{"QC77", 4, 26121},
	{"QC78", 4, 26122},
	{"QC79", 4, 26123},
	{"QC80", 4, 26124},
	{"QC81", 4, 26125},
	{"QC82", 4, 26126},
	{"QC83", 4, 26127},
	{"QC84", 4, 26128},
	{"QC85", 4, 26129},
	{"QC86", 4, 26130},
	{"QC87", 4, 26131},
	{"QC88", 4, 26132},
	{"QC89", 4, 26133},
	{"QC90", 4, 26134},
	{"QC91", 4, 26135},
	{"QC92", 4, 26136},
	{"QC93", 4, 26137},
	{"QC94", 4, 26138},
	{"QC95", 4, 26139},
	{"QC96", 4, 26140},
	{"QC97", 4, 26141},
	{"QC98", 4, 26142},
	{"QC99", 4, 26143},
	{"QE00", 4, 26144},
	{"QE01", 4, 26145},
	{"QE02", 4, 26146},
	{"QE03", 4, 26147},
	{"QE04", 4, 26148},
	{"QE05", 4, 26149},
	{"QE06", 4, 26150},
	{"QE07", 4, 26151},
	{"QE08", 4, 26152},
	{"QE09", 4, 26153},
	{"QE10", 4, 26154},
	{"QE11", 4, 26155},
	{"QE12", 4, 26156},
	{"QE13", 4, 26157},
	{"QE14", 4, 26158},
	{"QE15", 4, 26159},
	{"QE16", 4, 26160},
	{"QE17", 4, 26161},
	{"QE18", 4, 26162},
	{"QE19", 4, 26163},
	{"QE20", 4, 26164},
	{"QE21", 4, 26165},
	{"QE22", 4, 26166},
	{"QE23", 4, 26167},
	{"QE24", 4, 26168},
	{"QE25", 4, 26169},
	{"QE26", 4, 26170},
	{"QE27", 4, 26171},
	{"QE28", 4, 26172},
	{"QE29", 4, 26173},
	{"QE30", 4, 26174},
	{"QE31", 4, 26175},
	{"QE32", 4, 26176},
	{"QE33", 4, 26177},
	{"QE34", 4, 26178},
	{"QE35", 4, 26179},
	{"QE36", 4, 26180},
	{"QE37", 4, 26181},
	{"QE38", 4, 26182},
	{"QE39", 4, 26183},
	{"QE40", 4, 26184},
	{"QE41", 4, 26185},
	{"QE42", 4, 26186},
	{"QE43", 4, 26187},
	{"QE44", 4, 26188},
	{"QE45", 4, 26189},
	{"QE46", 4, 26190},
	{"QE47", 4, 26191},
	{"QE48", 4, 26192},
	{"QE49", 4, 26193},
	{"QE50", 4, 26194},
	{"QE51", 4, 26195},
	{"QE52", 4, 26196},
	{"QE53", 4, 26197},
	{"QE54", 4, 26198},
	{"QE55", 4, 26199},
	{"QE56", 4, 26200},
	{"QE57", 4, 26201},
	{"QE58", 4, 26202},
	{"QE59", 4, 26203},
	{"QE60", 4, 26204},
	{"QE61", 4, 26205},
	{"QE62", 4, 26206},
	{"QE63", 4, 26207},
	{"QE64", 4, 26208},
	{"QE65", 4, 26209},
	{"QE66", 4, 26210},
	{"QE67", 4, 26211},
	{"QE68", 4, 26212},
	{"QE69", 4, 26213},
	{"QE70", 4, 26214},
	{"QE71", 4, 26215},
	{"QE72", 4, 26216},
	{"QE73", 4, 26217},
	{"QE74", 4, 26218},
	{"QE75", 4, 26219},
	{"QE76", 4, 26220},
	{"QE77", 4, 26221},
	{"QE78", 4, 26222},
	{"QE79", 4, 26223},
	{"QE80", 4, 26224},
	{"QE81", 4, 26225},
	{"QE82", 4, 26226},
	{"QE83", 4, 26227},
	{"QE84", 4, 26228},
	{"QE85", 4, 26229},
	{"QE86", 4, 26230},
	{"QE87", 4, 26231},
	{"QE88", 4, 26232},
	{"QE89", 4, 26233},
	{"QE90", 4, 26234},
	{"QE91", 4, 26235},
	{"QE92", 4, 26236},
	{"QE93", 4, 26237},
	{"QE94", 4, 26238},
	{"QE95", 4, 26239},
	{"QE96", 4, 26240},
	{"QE97", 4, 26241},
	{"QE98", 4, 26242},
	{"QE99", 4, 26243},
	{"QF00", 4, 26244},
	{"QF01", 4, 26245},
	{"QF02", 4, 26246},
	{"QF03", 4, 26247},
	{"QF04", 4, 26248},
	{"QF05", 4, 26249},
	{"QF06", 4, 26250},
	{"QF07", 4, 26251},
	{"QF08", 4, 26252},
	{"QF09", 4, 26253},
	{"QF10", 4, 26254},
	{"QF11", 4, 26255},
	{"QF12", 4, 26256},
	{"QF13", 4, 26257},
	{"QF14", 4, 26258},
	{"QF15", 4, 26259},
	{"QF16", 4, 26260},
	{"QF17", 4, 26261},
	{"QF18", 4, 26262},
	{"QF19", 4, 26263},
	{"QF20", 4, 26264},
	{"QF21", 4, 26265},
	{"QF22", 4, 26266},
	{"QF23", 4, 26267},
	{"QF24", 4, 26268},
	{"QF25", 4, 26269},
	{"QF26", 4, 26270},
	{"QF27", 4, 26271},
	{"QF28", 4, 26272},
	{"QF29", 4, 26273},
	{"QF30", 4, 26274},
	{"QF31", 4, 26275},
	{"QF32", 4, 26276},
	{"QF33", 4, 26277},
	{"QF34", 4, 26278},
	{"QF35", 4, 26279},
	{"QF36", 4, 26280},
	{"QF37", 4, 26281},
	{"QF38", 4, 26282},
	{"QF39", 4, 26283},
	{"QF40", 4, 26284},
	{"QF41", 4, 26285},
	{"QF42", 4, 26286},
	{"QF43", 4, 26287},
	{"QF44", 4, 26288},
	{"QF45", 4, 26289},
	{"QF46", 4, 26290},
	{"QF47", 4, 26291},
	{"QF48", 4, 26292},
	{"QF49", 4, 26293},
	{"QF50", 4, 26294},
	{"QF51", 4, 26295},
	{"QF52", 4, 26296},
	{"QF53", 4, 26297},
	{"QF54", 4, 26298},
	{"QF55", 4, 26299},
	{"QF56", 4, 26300},
	{"QF57", 4, 26301},
	{"QF58", 4, 26302},
	{"QF59", 4, 26303},
	{"QF60", 4, 26304},
	{"QF61", 4, 26305},
	{"QF62", 4, 26306},
	{"QF63", 4, 26307},
	{"QF64", 4, 26308},
	{"QF65", 4, 26309},
	{"QF66", 4, 26310},
	{"QF67", 4, 26311},
	{"QF68", 4, 26312},
	{"QF69", 4, 26313},
	{"QF70", 4, 26314},
	{"QF71", 4, 26315},
	{"QF72", 4, 26316},
	{"QF73", 4, 26317},
	{"QF74", 4, 26318},
	{"QF75", 4, 26319},
	{"QF76", 4, 26320},
	{"QF77", 4, 26321},
	{"QF78", 4, 26322},
	{"QF79", 4, 26323},
	{"QF80", 4, 26324},
	{"QF81", 4, 26325},
	{"QF82", 4, 26326},
	{"QF83", 4, 26327},
	{"QF84", 4, 26328},
	{"QF85", 4, 26329},
	{"QF86", 4, 26330},
	{"QF87", 4, 26331},
	{"QF88", 4, 26332},
	{"QF89", 4, 26333},
	{"QF90", 4, 26334},
	{"QF91", 4, 26335},
	{"QF92", 4, 26336},
	{"QF93", 4, 26337},
	{"QF94", 4, 26338},
	{"QF95", 4, 26339},
	{"QF96", 4, 26340},
	{"QF97", 4, 26341},
	{"QF98", 4, 26342},
	{"QF99", 4, 26343},
	{"QG00", 4, 26344},
	{"QG01", 4, 26345},
	{"QG02", 4, 26346},
	{"QG03", 4, 26347},
	{"QG04", 4, 26348},
	{"QG05", 4, 26349},
	{"QG06", 4, 26350},
	{"QG07", 4, 26351},
	{"QG08", 4, 26352},
	{"QG09", 4, 26353},
	{"QG10", 4, 26354},
	{"QG11", 4, 26355},
	{"QG12", 4, 26356},
	{"QG13", 4, 26357},
	{"QG14", 4, 26358},
	{"QG15", 4, 26359},
	{"QG16", 4, 26360},
	{"QG17", 4, 26361},
	{"QG18", 4, 26362},
	{"QG19", 4, 26363},
	{"QG20", 4, 26364},
	{"QG21", 4, 26365},
	{"QG22", 4, 26366},
	{"QG23", 4, 26367},
	{"QG24", 4, 26368},
	{"QG25", 4, 26369},
	{"QG26", 4, 26370},
	{"QG27", 4, 26371},
	{"QG28", 4, 26372},
	{"QG29", 4, 26373},
	{"QG30", 4, 26374},
	{"QG31", 4, 26375},
	{"QG32", 4, 26376},
	{"QG33", 4, 26377},
	{"QG34", 4, 26378},
	{"QG35", 4, 26379},
	{"QG36", 4, 26380},
	{"QG37", 4, 26381},
	{"QG38", 4, 26382},
	{"QG39", 4, 26383},
	{"QG40", 4, 26384},
	{"QG41", 4, 26385},
	{"QG42", 4, 26386},
	{"QG43", 4, 26387},
	{"QG44", 4, 26388},
	{"QG45", 4, 26389},
	{"QG46", 4, 26390},
	{"QG47", 4, 26391},
	{"QG48", 4, 26392},
	{"QG49", 4, 26393},
	{"QG50", 4, 26394},
	{"QG51", 4, 26395},
	{"QG52", 4, 26396},
	{"QG53", 4, 26397},
	{"QG54", 4, 26398},
	{"QG55", 4, 26399},
	{"QG56", 4, 26400},
	{"QG57", 4, 26401},
	{"QG58", 4, 26402},
	{"QG59", 4, 26403},
	{"QG60", 4, 26404},
	{"QG61", 4, 26405},
	{"QG62", 4, 26406},
	{"QG63", 4, 26407},
	{"QG64", 4, 26408},
	{"QG65", 4, 26409},
	{"QG66", 4, 26410},
	{"QG67", 4, 26411},
	{"QG68", 4, 26412},
	{"QG69", 4, 26413},
	{"QG70", 4, 26414},
	{"QG71", 4, 26415},
	{"QG72", 4, 26416},
	{"QG73", 4, 26417},
	{"QG74", 4, 26418},
	{"QG75", 4, 26419},
	{"QG76", 4, 26420},
	{"QG77", 4, 26421},
	{"QG78", 4, 26422},
	{"QG79", 4, 26423},
	{"QG80", 4, 26424},
	{"QG81", 4, 26425},
	{"QG82", 4, 26426},
	{"QG83", 4, 26427},
	{"QG84", 4, 26428},
	{"QG85", 4, 26429},
	{"QG86", 4, 26430},
	{"QG87", 4, 26431},
	{"QG88", 4, 26432},
	{"QG89", 4, 26433},
	{"QG90", 4, 26434},
	{"QG91", 4, 26435},
	{"QG92", 4, 26436},
	{"QG93", 4, 26437},
	{"QG94", 4, 26438},
	{"QG95", 4, 26439},
	{"QG96", 4, 26440},
	{"QG97", 4, 26441},
	{"QG98", 4, 26442},
	{"QG99", 4, 26443},
	{"QH00", 4, 26444},
	{"QH01", 4, 26445},
	{"QH02", 4, 26446},
	{"QH03", 4, 26447},
	{"QH04", 4, 26448},
	{"QH05", 4, 26449},
	{"QH06", 4, 26450},
	{"QH07", 4, 26451},
	{"QH08", 4, 26452},
	{"QH09", 4, 26453},
	{"QH10", 4, 26454},
	{"QH11", 4, 26455},
	{"QH12", 4, 26456},
	{"QH13", 4, 26457},
	{"QH14", 4, 26458},
	{"QH15", 4, 26459},
	{"QH16", 4, 26460},
	{"QH17", 4, 26461},
	{"QH18", 4, 26462},
	{"QH19", 4, 26463},
	{"QH20", 4, 26464},
	{"QH21", 4, 26465},
	{"QH22", 4, 26466},
	{"QH23", 4, 26467},
	{"QH24", 4, 26468},
	{"QH25", 4, 26469},
	{"QH26", 4, 26470},
	{"QH27", 4, 26471},
	{"QH28", 4, 26472},
	{"QH29", 4, 26473},
	{"QH30", 4, 26474},
	{"QH31", 4, 26475},
	{"QH32", 4, 26476},
	{"QH33", 4, 26477},
	{"QH34", 4, 26478},
	{"QH35", 4, 26479},
	{"QH36", 4, 26480},
	{"QH37", 4, 26481},
	{"QH38", 4, 26482},
	{"QH39", 4, 26483},
	{"QH40", 4, 26484},
	{"QH41", 4, 26485},
	{"QH42", 4, 26486},
	{"QH43", 4, 26487},
	{"QH44", 4, 26488},
	{"QH45", 4, 26489},
	{"QH46", 4, 26490},
	{"QH47", 4, 26491},
	{"QH48", 4, 26492},
	{"QH49", 4, 26493},
	{"QH50", 4, 26494},
	{"QH51", 4, 26495},
	{"QH52", 4, 26496},
	{"QH53", 4, 26497},
	{"QH54", 4, 26498},
	{"QH55", 4, 26499},
	{"QH56", 4, 26500},
	{"QH57", 4, 26501},
	{"QH58", 4, 26502},
	{"QH59", 4, 26503},
	{"QH60", 4, 26504},
	{"QH61", 4, 26505},
	{"QH62", 4, 26506},
	{"QH63", 4, 26507},
	{"QH64", 4, 26508},
	{"QH65", 4, 26509},
	{"QH66", 4, 26510},
	{"QH67", 4, 26511},
	{"QH68", 4, 26512},
	{"QH69", 4, 26513},
	{"QH70", 4, 26514},
	{"QH71", 4, 26515},
	{"QH72", 4, 26516},
	{"QH73", 4, 26517},
	{"QH74", 4, 26518},
	{"QH75", 4, 26519},
	{"QH76", 4, 26520},
	{"QH77", 4, 26521},
	{"QH78", 4, 26522},
	{"QH79", 4, 26523},
	{"QH80", 4, 26524},
	{"QH81", 4, 26525},
	{"QH82", 4, 26526},
	{"QH83", 4, 26527},
	{"QH84", 4, 26528},
	{"QH85", 4, 26529},
	{"QH86", 4, 26530},
	{"QH87", 4, 26531},
	{"QH88", 4, 26532},
	{"QH89", 4, 26533},
	{"QH90", 4, 26534},
	{"QH91", 4, 26535},
	{"QH92", 4, 26536},
	{"QH93", 4, 26537},
	{"QH94", 4, 26538},
	{"QH95", 4, 26539},
	{"QH96", 4, 26540},
	{"QH97", 4, 26541},
	{"QH98", 4, 26542},
	{"QH99", 4, 26543},
	{"QI00", 4, 26544},
	{"QI01", 4, 26545},
	{"QI02", 4, 26546},
	{"QI03", 4, 26547},
	{"QI04", 4, 26548},
	{"QI05", 4, 26549},
	{"QI06", 4, 26550},
	{"QI07", 4, 26551},
	{"QI08", 4, 26552},
	{"QI09", 4, 26553},
	{"QI10", 4, 26554},
	{"QI11", 4, 26555},
	{"QI12", 4, 26556},
	{"QI13", 4, 26557},
	{"QI14", 4, 26558},
	{"QI15", 4, 26559},
	{"QI16", 4, 26560},
	{"QI17", 4, 26561},
	{"QI18", 4, 26562},
	{"QI19", 4, 26563},
	{"QI20", 4, 26564},
	{"QI21", 4, 26565},
	{"QI22", 4, 26566},
	{"QI23", 4, 26567},
	{"QI24", 4, 26568},
	{"QI25", 4, 26569},
	{"QI26", 4, 26570},
	{"QI27", 4, 26571},
	{"QI28", 4, 26572},
	{"QI29", 4, 26573},
	{"QI30", 4, 26574},
	{"QI31", 4, 26575},
	{"QI32", 4, 26576},
	{"QI33", 4, 26577},
	{"QI34", 4, 26578},
	{"QI35", 4, 26579},
	{"QI36", 4, 26580},
	{"QI37", 4, 26581},
	{"QI38", 4, 26582},
	{"QI39", 4, 26583},
	{"QI40", 4, 26584},
	{"QI41", 4, 26585},
	{"QI42", 4, 26586},
	{"QI43", 4, 26587},
	{"QI44", 4, 26588},
	{"QI45", 4, 26589},
	{"QI46", 4, 26590},
	{"QI47", 4, 26591},
	{"QI48", 4, 26592},
	{"QI49", 4, 26593},
	{"QI50", 4, 26594},
	{"QI51", 4, 26595},
	{"QI52", 4, 26596},
	{"QI53", 4, 26597},
	{"QI54", 4, 26598},
	{"QI55", 4, 26599},
	{"QI56", 4, 26600},
	{"QI57", 4, 26601},
	{"QI58", 4, 26602},
	{"QI59", 4, 26603},
	{"QI60", 4, 26604},
	{"QI61", 4, 26605},
	{"QI62", 4, 26606},
	{"QI63", 4, 26607},
	{"QI64", 4, 26608},
	{"QI65", 4, 26609},
	{"QI66", 4, 26610},
	{"QI67", 4, 26611},
	{"QI68", 4, 26612},
	{"QI69", 4, 26613},
	{"QI70", 4, 26614},
	{"QI71", 4, 26615},
	{"QI72", 4, 26616},
	{"QI73", 4, 26617},
	{"QI74", 4, 26618},
	{"QI75", 4, 26619},
	{"QI76", 4, 26620},
	{"QI77", 4, 26621},
	{"QI78", 4, 26622},
	{"QI79", 4, 26623},
	{"QI80", 4, 26624},
	{"QI81", 4, 26625},
	{"QI82", 4, 26626},
	{"QI83", 4, 26627},
	{"QI84", 4, 26628},
	{"QI85", 4, 26629},
	{"QI86", 4, 26630},
	{"QI87", 4, 26631},
	{"QI88", 4, 26632},
	{"QI89", 4, 26633},
	{"QI90", 4, 26634},
	{"QI91", 4, 26635},
	{"QI92", 4, 26636},
	{"QI93", 4, 26637},
	{"QI94", 4, 26638},
	{"QI95", 4, 26639},
	{"QI96", 4, 26640},
	{"QI97", 4, 26641},
	{"QI98", 4, 26642},
	{"QI99", 4, 26643},
	{"QM00", 4, 26644},
	{"QM01", 4, 26645},
	{"QM02", 4, 26646},
	{"QM03", 4, 26647},
	{"QM04", 4, 26648},
	{"QM05", 4, 26649},
	{"QM06", 4, 26650},
	{"QM07", 4, 26651},
	{"QM08", 4, 26652},
	{"QM09", 4, 26653},
	{"QM10", 4, 26654},
	{"QM11", 4, 26655},
	{"QM12", 4, 26656},
	{"QM13", 4, 26657},
	{"QM14", 4, 26658},
	{"QM15", 4, 26659},
	{"QM16", 4, 26660},
	{"QM17", 4, 26661},
	{"QM18", 4, 26662},
	{"QM19", 4, 26663},
	{"QM20", 4, 26664},
	{"QM21", 4, 26665},
	{"QM22", 4, 26666},
	{"QM23", 4, 26667},
	{"QM24", 4, 26668},
	{"QM25", 4, 26669},
	{"QM26", 4, 26670},
	{"QM27", 4, 26671},
	{"QM28", 4, 26672},
	{"QM29", 4, 26673},
	{"QM30", 4, 26674},
	{"QM31", 4, 26675},
	{"QM32", 4, 26676},
	{"QM33", 4, 26677},
	{"QM34", 4, 26678},
	{"QM35", 4, 26679},
	{"QM36", 4, 26680},
	{"QM37", 4, 26681},
	{"QM38", 4, 26682},
	{"QM39", 4, 26683},
	{"QM40", 4, 26684},
	{"QM41", 4, 26685},
	{"QM42", 4, 26686},
	{"QM43", 4, 26687},
	{"QM44", 4, 26688},
	{"QM45", 4, 26689},
	{"QM46", 4, 26690},
	{"QM47", 4, 26691},
	{"QM48", 4, 26692},
	{"QM49", 4, 26693},
	{"QM50", 4, 26694},
	{"QM51", 4, 26695},
	{"QM52", 4, 26696},
	{"QM53", 4, 26697},
	{"QM54", 4, 26698},
	{"QM55", 4, 26699},
	{"QM56", 4, 26700},
	{"QM57", 4, 26701},
	{"QM58", 4, 26702},
	{"QM59", 4, 26703},
	{"QM60", 4, 26704},
	{"QM61", 4, 26705},
	{"QM62", 4, 26706},
	{"QM63", 4, 26707},
	{"QM64", 4, 26708},
	{"QM65", 4, 26709},
	{"QM66", 4, 26710},
	{"QM67", 4, 26711},
	{"QM68", 4, 26712},
	{"QM69", 4, 26713},
	{"QM70", 4, 26714},
	{"QM71", 4, 26715},
	{"QM72", 4, 26716},
	{"QM73", 4, 26717},
	{"QM74", 4, 26718},
	{"QM75", 4, 26719},
	{"QM76", 4, 26720},
	{"QM77", 4, 26721},
	{"QM78", 4, 26722},
	{"QM79", 4, 26723},
	{"QM80", 4, 26724},
	{"QM81", 4, 26725},
	{"QM82", 4, 26726},
	{"QM83", 4, 26727},
	{"QM84", 4, 26728},
	{"QM85", 4, 26729},
	{"QM86", 4, 26730},
	{"QM87", 4, 26731},
	{"QM88", 4, 26732},
	{"QM89", 4, 26733},
	{"QM90", 4, 26734},
	{"QM91", 4, 26735},
	{"QM92", 4, 26736},
	{"QM93", 4, 26737},
	{"QM94", 4, 26738},
	{"QM95", 4, 26739},
	{"QM96", 4, 26740},
	{"QM97", 4, 26741},
	{"QM98", 4, 26742},
	{"QM99", 4, 26743},
	{"QN00", 4, 26744},
	{"QN01", 4, 26745},
	{"QN02", 4, 26746},
	{"QN03", 4, 26747},
	{"QN04", 4, 26748},
	{"QN05", 4, 26749},
	{"QN06", 4, 26750},
	{"QN07", 4, 26751},
	{"QN08", 4, 26752},
	{"QN09", 4, 26753},
	{"QN10", 4, 26754},
	{"QN11", 4, 26755},
	{"QN12", 4, 26756},
	{"QN13", 4, 26757},
	{"QN14", 4, 26758},
	{"QN15", 4, 26759},
	{"QN16", 4, 26760},
	{"QN17", 4, 26761},
	{"QN18", 4, 26762},
	{"QN19", 4, 26763},
	{"QN20", 4, 26764},
	{"QN21", 4, 26765},
	{"QN22", 4, 26766},
	{"QN23", 4, 26767},
	{"QN24", 4, 26768},
	{"QN25", 4, 26769},
	{"QN26", 4, 26770},
	{"QN27", 4, 26771},
	{"QN28", 4, 26772},
	{"QN29", 4, 26773},
	{"QN30", 4, 26774},
	{"QN31", 4, 26775},
	{"QN32", 4, 26776},
	{"QN33", 4, 26777},
	{"QN34", 4, 26778},
	{"QN35", 4, 26779},
	{"QN36", 4, 26780},
	{"QN37", 4, 26781},
	{"QN38", 4, 26782},
	{"QN39", 4, 26783},
	{"QN40", 4, 26784},
	{"QN41", 4, 26785},
	{"QN42", 4, 26786},
	{"QN43", 4, 26787},
	{"QN44", 4, 26788},
	{"QN45", 4, 26789},
	{"QN46", 4, 26790},
	{"QN47", 4, 26791},
	{"QN48", 4, 26792},
	{"QN49", 4, 26793},
	{"QN50", 4, 26794},
	{"QN51", 4, 26795},
	{"QN52", 4, 26796},
	{"QN53", 4, 26797},
	{"QN54", 4, 26798},
	{"QN55", 4, 26799},
	{"QN56", 4, 26800},
	{"QN57", 4, 26801},
	{"QN58", 4, 26802},
	{"QN59", 4, 26803},
	{"QN60", 4, 26804},
	{"QN61", 4, 26805},
	{"QN62", 4, 26806},
	{"QN63", 4, 26807},
	{"QN64", 4, 26808},
	{"QN65", 4, 26809},
	{"QN66", 4, 26810},
	{"QN67", 4, 26811},
	{"QN68", 4, 26812},
	{"QN69", 4, 26813},
	{"QN70", 4, 26814},
	{"QN71", 4, 26815},
	{"QN72", 4, 26816},
	{"QN73", 4, 26817},
	{"QN74", 4, 26818},
	{"QN75", 4, 26819},
	{"QN76", 4, 26820},
	{"QN77", 4, 26821},
	{"QN78", 4, 26822},
	{"QN79", 4, 26823},
	{"QN80", 4, 26824},
	{"QN81", 4, 26825},
	{"QN82", 4, 26826},
	{"QN83", 4, 26827},
	{"QN84", 4, 26828},
	{"QN85", 4, 26829},
	{"QN86", 4, 26830},
	{"QN87", 4, 26831},
	{"QN88", 4, 26832},
	{"QN89", 4, 26833},
	{"QN90", 4, 26834},
	{"QN91", 4, 26835},
	{"QN92", 4, 26836},
	{"QN93", 4, 26837},
	{"QN94", 4, 26838},
	{"QN95", 4, 26839},
	{"QN96", 4, 26840},
	{"QN97", 4, 26841},
	{"QN98", 4, 26842},
	{"QN99", 4, 26843},
	{"QO00", 4, 26844},
	{"QO01", 4, 26845},
	{"QO02", 4, 26846},
	{"QO03", 4, 26847},
	{"QO04", 4, 26848},
	{"QO05", 4, 26849},
	{"QO06", 4, 26850},
	{"QO07", 4, 26851},
	{"QO08", 4, 26852},
	{"QO09", 4, 26853},
	{"QO10", 4, 26854},
	{"QO11", 4, 26855},
	{"QO12", 4, 26856},
	{"QO13", 4, 26857},
	{"QO14", 4, 26858},
	{"QO15", 4, 26859},
	{"QO16", 4, 26860},
	{"QO17", 4, 26861},
	{"QO18", 4, 26862},
	{"QO19", 4, 26863},
	{"QO20", 4, 26864},
	{"QO21", 4, 26865},
	{"QO22", 4, 26866},
	{"QO23", 4, 26867},
	{"QO24", 4, 26868},
	{"QO25", 4, 26869},
	{"QO26", 4, 26870},
	{"QO27", 4, 26871},
	{"QO28", 4, 26872},
	{"QO29", 4, 26873},
	{"QO30", 4, 26874},
	{"QO31", 4, 26875},
	{"QO32", 4, 26876},
	{"QO33", 4, 26877},
	{"QO34", 4, 26878},
	{"QO35", 4, 26879},
	{"QO36", 4, 26880},
	{"QO37", 4, 26881},
	{"QO38", 4, 26882},
	{"QO39", 4, 26883},
	{"QO40", 4, 26884},
	{"QO41", 4, 26885},
	{"QO42", 4, 26886},
	{"QO43", 4, 26887},
	{"QO44", 4, 26888},
	{"QO45", 4, 26889},
	{"QO46", 4, 26890},
	{"QO47", 4, 26891},
	{"QO48", 4, 26892},
	{"QO49", 4, 26893},
	{"QO50", 4, 26894},
	{"QO51", 4, 26895},
	{"QO52", 4, 26896},
	{"QO53", 4, 26897},
	{"QO54", 4, 26898},
	{"QO55", 4, 26899},
	{"QO56", 4, 26900},
	{"QO57", 4, 26901},
	{"QO58", 4, 26902},
	{"QO59", 4, 26903},
	{"QO60", 4, 26904},
	{"QO61", 4, 26905},
	{"QO62", 4, 26906},
	{"QO63", 4, 26907},
	{"QO64", 4, 26908},
	{"QO65", 4, 26909},
	{"QO66", 4, 26910},
	{"QO67", 4, 26911},
	{"QO68", 4, 26912},
	{"QO69", 4, 26913},
	{"QO70", 4, 26914},
	{"QO71", 4, 26915},
	{"QO72", 4, 26916},
	{"QO73", 4, 26917},
	{"QO74", 4, 26918},
	{"QO75", 4, 26919},
	{"QO76", 4, 26920},
	{"QO77", 4, 26921},
	{"QO78", 4, 26922},
	{"QO79", 4, 26923},
	{"QO80", 4, 26924},
	{"QO81", 4, 26925},
	{"QO82", 4, 26926},
	{"QO83", 4, 26927},
	{"QO84", 4, 26928},
	{"QO85", 4, 26929},
	{"QO86", 4, 26930},
	{"QO87", 4, 26931},
	{"QO88", 4, 26932},
	{"QO89", 4, 26933},
	{"QO90", 4, 26934},
	{"QO91", 4, 26935},
	{"QO92", 4, 26936},
	{"QO93", 4, 26937},
	{"QO94", 4, 26938},
	{"QO95", 4, 26939},
	{"QO96", 4, 26940},
	{"QO97", 4, 26941},
	{"QO98", 4, 26942},
	{"QO99", 4, 26943},
	{"QP00", 4, 26944},
	{"QP01", 4, 26945},
	{"QP02", 4, 26946},
	{"QP03", 4, 26947},
	{"QP04", 4, 26948},
	{"QP05", 4, 26949},
	{"QP06", 4, 26950},
	{"QP07", 4, 26951},
	{"QP08", 4, 26952},
	{"QP09", 4, 26953},
	{"QP10", 4, 26954},
	{"QP11", 4, 26955},
	{"QP12", 4, 26956},
	{"QP13", 4, 26957},
	{"QP14", 4, 26958},
	{"QP15", 4, 26959},
	{"QP16", 4, 26960},
	{"QP17", 4, 26961},
	{"QP18", 4, 26962},
	{"QP19", 4, 26963},
	{"QP20", 4, 26964},
	{"QP21", 4, 26965},
	{"QP22", 4, 26966},
	{"QP23", 4, 26967},
	{"QP24", 4, 26968},
	{"QP25", 4, 26969},
	{"QP26", 4, 26970},
	{"QP27", 4, 26971},
	{"QP28", 4, 26972},
	{"QP29", 4, 26973},
	{"QP30", 4, 26974},
	{"QP31", 4, 26975},
	{"QP32", 4, 26976},
	{"QP33", 4, 26977},
	{"QP34", 4, 26978},
	{"QP35", 4, 26979},
	{"QP36", 4, 26980},
	{"QP37", 4, 26981},
	{"QP38", 4, 26982},
	{"QP39", 4, 26983},
	{"QP40", 4, 26984},
	{"QP41", 4, 26985},
	{"QP42", 4, 26986},
	{"QP43", 4, 26987},
	{"QP44", 4, 26988},
	{"QP45", 4, 26989},
	{"QP46", 4, 26990},
	{"QP47", 4, 26991},
	{"QP48", 4, 26992},
	{"QP49", 4, 26993},
	{"QP50", 4, 26994},
	{"QP51", 4, 26995},
	{"QP52", 4, 26996},
	{"QP53", 4, 26997},
	{"QP54", 4, 26998},
	{"QP55", 4, 26999},
	{"QP56", 4, 27000},
	{"QP57", 4, 27001},
	{"QP58", 4, 27002},
	{"QP59", 4, 27003},
	{"QP60", 4, 27004},
	{"QP61", 4, 27005},
	{"QP62", 4, 27006},
	{"QP63", 4, 27007},
	{"QP64", 4, 27008},
	{"QP65", 4, 27009},
	{"QP66", 4, 27010},
	{"QP67", 4, 27011},
	{"QP68", 4, 27012},
	{"QP69", 4, 27013},
	{"QP70", 4, 27014},
	{"QP71", 4, 27015},
	{"QP72", 4, 27016},
	{"QP73", 4, 27017},
	{"QP74", 4, 27018},
	{"QP75", 4, 27019},
	{"QP76", 4, 27020},
	{"QP77", 4, 27021},
	{"QP78", 4, 27022},
	{"QP79", 4, 27023},
	{"QP80", 4, 27024},
	{"QP81", 4, 27025},
	{"QP82", 4, 27026},
	{"QP83", 4, 27027},
	{"QP84", 4, 27028},
	{"QP85", 4, 27029},
	{"QP86", 4, 27030},
	{"QP87", 4, 27031},
	{"QP88", 4, 27032},
	{"QP89", 4, 27033},
	{"QP90", 4, 27034},
	{"QP91", 4, 27035},
	{"QP92", 4, 27036},
	{"QP93", 4, 27037},
	{"QP94", 4, 27038},
	{"QP95", 4, 27039},
	{"QP96", 4, 27040},
	{"QP97", 4, 27041},
	{"QP98", 4, 27042},
	{"QP99", 4, 27043},
	{"QQ00", 4, 27044},
	{"QQ01", 4, 27045},
	{"QQ02", 4, 27046},
	{"QQ03", 4, 27047},
	{"QQ04", 4, 27048},
	{"QQ05", 4, 27049},
	{"QQ06", 4, 27050},
	{"QQ07", 4, 27051},
	{"QQ08", 4, 27052},
	{"QQ09", 4, 27053},
	{"QQ10", 4, 27054},
	{"QQ11", 4, 27055},
	{"QQ12", 4, 27056},
	{"QQ13", 4, 27057},
	{"QQ14", 4, 27058},
	{"QQ15", 4, 27059},
	{"QQ16", 4, 27060},
	{"QQ17", 4, 27061},
	{"QQ18", 4, 27062},
	{"QQ19", 4, 27063},
	{"QQ20", 4, 27064},
	{"QQ21", 4, 27065},
	{"QQ22", 4, 27066},
	{"QQ23", 4, 27067},
	{"QQ24", 4, 27068},
	{"QQ25", 4, 27069},
	{"QQ26", 4, 27070},
	{"QQ27", 4, 27071},
	{"QQ28", 4, 27072},
	{"QQ29", 4, 27073},
	{"QQ30", 4, 27074},
	{"QQ31", 4, 27075},
	{"QQ32", 4, 27076},
	{"QQ33", 4, 27077},
	{"QQ34", 4, 27078},
	{"QQ35", 4, 27079},
	{"QQ36", 4, 27080},
	{"QQ37", 4, 27081},
	{"QQ38", 4, 27082},
	{"QQ39", 4, 27083},
	{"QQ40", 4, 27084},
	{"QQ41", 4, 27085},
	{"QQ42", 4, 27086},
	{"QQ43", 4, 27087},
	{"QQ44", 4, 27088},
	{"QQ45", 4, 27089},
	{"QQ46", 4, 27090},
	{"QQ47", 4, 27091},
	{"QQ48", 4, 27092},
	{"QQ49", 4, 27093},
	{"QQ50", 4, 27094},
	{"QQ51", 4, 27095},
	{"QQ52", 4, 27096},
	{"QQ53", 4, 27097},
	{"QQ54", 4, 27098},
	{"QQ55", 4, 27099},
	{"QQ56", 4, 27100},
	{"QQ57", 4, 27101},
	{"QQ58", 4, 27102},
	{"QQ59", 4, 27103},
	{"QQ60", 4, 27104},
	{"QQ61", 4, 27105},
	{"QQ62", 4, 27106},
	{"QQ63", 4, 27107},
	{"QQ64", 4, 27108},
	{"QQ65", 4, 27109},
	{"QQ66", 4, 27110},
	{"QQ67", 4, 27111},
	{"QQ68", 4, 27112},
	{"QQ69", 4, 27113},
	{"QQ70", 4, 27114},
	{"QQ71", 4, 27115},
	{"QQ72", 4, 27116},
	{"QQ73", 4, 27117},
	{"QQ74", 4, 27118},
	{"QQ75", 4, 27119},
	{"QQ76", 4, 27120},
	{"QQ77", 4, 27121},
	{"QQ78", 4, 27122},
	{"QQ79", 4, 27123},
	{"QQ80", 4, 27124},
	{"QQ81", 4, 27125},
	{"QQ82", 4, 27126},
	{"QQ83", 4, 27127},
	{"QQ84", 4, 27128},
	{"QQ85", 4, 27129},
	{"QQ86", 4, 27130},
	{"QQ87", 4, 27131},
	{"QQ88", 4, 27132},
	{"QQ89", 4, 27133},
	{"QQ90", 4, 27134},
	{"QQ91", 4, 27135},
	{"QQ92", 4, 27136},
	{"QQ93", 4, 27137},
	{"QQ94", 4, 27138},
	{"QQ95", 4, 27139},
	{"QQ96", 4, 27140},
	{"QQ97", 4, 27141},
	{"QQ98", 4, 27142},
	{"QQ99", 4, 27143},
	{"RB00", 4, 27144},
	{"RB01", 4, 27145},
	{"RB02", 4, 27146},
	{"RB03", 4, 27147},
	{"RB04", 4, 27148},
	{"RB05", 4, 27149},
	{"RB06", 4, 27150},
	{"RB07", 4, 27151},
	{"RB08", 4, 27152},
	{"RB09", 4, 27153},
	{"RB10", 4, 27154},
	{"RB11", 4, 27155},
	{"RB12", 4, 27156},
	{"RB13", 4, 27157},
	{"RB14", 4, 27158},
	{"RB15", 4, 27159},
	{"RB16", 4, 27160},
	{"RB17", 4, 27161},
	{"RB18", 4, 27162},
	{"RB19", 4, 27163},
	{"RB20", 4, 27164},
	{"RB21", 4, 27165},
	{"RB22", 4, 27166},
	{"RB23", 4, 27167},
	{"RB24", 4, 27168},
	{"RB25", 4, 27169},
	{"RB26", 4, 27170},
	{"RB27", 4, 27171},
	{"RB28", 4, 27172},
	{"RB29", 4, 27173},
	{"RB30", 4, 27174},
	{"RB31", 4, 27175},
	{"RB32", 4, 27176},
	{"RB33", 4, 27177},
	{"RB34", 4, 27178},
	{"RB35", 4, 27179},
	{"RB36", 4, 27180},
	{"RB37", 4, 27181},
	{"RB38", 4, 27182},
	{"RB39", 4, 27183},
	{"RB40", 4, 27184},
	{"RB41", 4, 27185},
	{"RB42", 4, 27186},
	{"RB43", 4, 27187},
	{"RB44", 4, 27188},
	{"RB45", 4, 27189},
	{"RB46", 4, 27190},
	{"RB47", 4, 27191},
	{"RB48", 4, 27192},
	{"RB49", 4, 27193},
	{"RB50", 4, 27194},
	{"RB51", 4, 27195},
	{"RB52", 4, 27196},
	{"RB53", 4, 27197},
	{"RB54", 4, 27198},
	{"RB55", 4, 27199},
	{"RB56", 4, 27200},
	{"RB57", 4, 27201},
	{"RB58", 4, 27202},
	{"RB59", 4, 27203},
	{"RB60", 4, 27204},
	{"RB61", 4, 27205},
	{"RB62", 4, 27206},
	{"RB63", 4, 27207},
	{"RB64", 4, 27208},
	{"RB65", 4, 27209},
	{"RB66", 4, 27210},
	{"RB67", 4, 27211},
	{"RB68", 4, 27212},
	{"RB69", 4, 27213},
	{"RB70", 4, 27214},
	{"RB71", 4, 27215},
	{"RB72", 4, 27216},
	{"RB73", 4, 27217},
	{"RB74", 4, 27218},
	{"RB75", 4, 27219},
	{"RB76", 4, 27220},
	{"RB77", 4, 27221},
	{"RB78", 4, 27222},
	{"RB79", 4, 27223},
	{"RB80", 4, 27224},
	{"RB81", 4, 27225},
	{"RB82", 4, 27226},
	{"RB83", 4, 27227},
	{"RB84", 4, 27228},
	{"RB85", 4, 27229},
	{"RB86", 4, 27230},
	{"RB87", 4, 27231},
	{"RB88", 4, 27232},
	{"RB89", 4, 27233},
	{"RB90", 4, 27234},
	{"RB91", 4, 27235},
	{"RB92", 4, 27236},
	{"RB93", 4, 27237},
	{"RB94", 4, 27238},
	{"RB95", 4, 27239},
	{"RB96", 4, 27240},
	{"RB97", 4, 27241},
	{"RB98", 4, 27242},
	{"RB99", 4, 27243},
	{"RE00", 4, 27244},
	{"RE01", 4, 27245},
	{"RE02", 4, 27246},
	{"RE03", 4, 27247},
	{"RE04", 4, 27248},
	{"RE05", 4, 27249},
	{"RE06", 4, 27250},
	{"RE07", 4, 27251},
	{"RE08", 4, 27252},
	{"RE09", 4, 27253},
	{"RE10", 4, 27254},
	{"RE11", 4, 27255},
	{"RE12", 4, 27256},
	{"RE13", 4, 27257},
	{"RE14", 4, 27258},
	{"RE15", 4, 27259},
	{"RE16", 4, 27260},
	{"RE17", 4, 27261},
	{"RE18", 4, 27262},
	{"RE19", 4, 27263},
	{"RE20", 4, 27264},
	{"RE21", 4, 27265},
	{"RE22", 4, 27266},
	{"RE23", 4, 27267},
	{"RE24", 4, 27268},
	{"RE25", 4, 27269},
	{"RE26", 4, 27270},
	{"RE27", 4, 27271},
	{"RE28", 4, 27272},
	{"RE29", 4, 27273},
	{"RE30", 4, 27274},
	{"RE31", 4, 27275},
	{"RE32", 4, 27276},
	{"RE33", 4, 27277},
	{"RE34", 4, 27278},
	{"RE35", 4, 27279},
	{"RE36", 4, 27280},
	{"RE37", 4, 27281},
	{"RE38", 4, 27282},
	{"RE39", 4, 27283},
	{"RE40", 4, 27284},
	{"RE41", 4, 27285},
	{"RE42", 4, 27286},
	{"RE43", 4, 27287},
	{"RE44", 4, 27288},
	{"RE45", 4, 27289},
	{"RE46", 4, 27290},
	{"RE47", 4, 27291},
	{"RE48", 4, 27292},
	{"RE49", 4, 27293},
	{"RE50", 4, 27294},
	{"RE51", 4, 27295},
	{"RE52", 4, 27296},
	{"RE53", 4, 27297},
	{"RE54", 4, 27298},
	{"RE55", 4, 27299},
	{"RE56", 4, 27300},
	{"RE57", 4, 27301},
	{"RE58", 4, 27302},
	{"RE59", 4, 27303},
	{"RE60", 4, 27304},
	{"RE61", 4, 27305},
	{"RE62", 4, 27306},
	{"RE63", 4, 27307},
	{"RE64", 4, 27308},
	{"RE65", 4, 27309},
	{"RE66", 4, 27310},
	{"RE67", 4, 27311},
	{"RE68", 4, 27312},
	{"RE69", 4, 27313},
	{"RE70", 4, 27314},
	{"RE71", 4, 27315},
	{"RE72", 4, 27316},
	{"RE73", 4, 27317},
	{"RE74", 4, 27318},
	{"RE75", 4, 27319},
	{"RE76", 4, 27320},
	{"RE77", 4, 27321},
	{"RE78", 4, 27322},
	{"RE79", 4, 27323},
	{"RE80", 4, 27324},
	{"RE81", 4, 27325},
	{"RE82", 4, 27326},
	{"RE83", 4, 27327},
	{"RE84", 4, 27328},
	{"RE85", 4, 27329},
	{"RE86", 4, 27330},
	{"RE87", 4, 27331},
	{"RE88", 4, 27332},
	{"RE89", 4, 27333},
	{"RE90", 4, 27334},
	{"RE91", 4, 27335},
	{"RE92", 4, 27336},
	{"RE93", 4, 27337},
	{"RE94", 4, 27338},
	{"RE95", 4, 27339},
	{"RE96", 4, 27340},
	{"RE97", 4, 27341},
	{"RE98", 4, 27342},
	{"RE99", 4, 27343},
	{"RF00", 4, 27344},
	{"RF01", 4, 27345},
	{"RF02", 4, 27346},
	{"RF03", 4, 27347},
	{"RF04", 4, 27348},
	{"RF05", 4, 27349},
	{"RF06", 4, 27350},
	{"RF07", 4, 27351},
	{"RF08", 4, 27352},
	{"RF09", 4, 27353},
	{"RF10", 4, 27354},
	{"RF11", 4, 27355},
	{"RF12", 4, 27356},
	{"RF13", 4, 27357},
	{"RF14", 4, 27358},
	{"RF15", 4, 27359},
	{"RF16", 4, 27360},
	{"RF17", 4, 27361},
	{"RF18", 4, 27362},
	{"RF19", 4, 27363},
	{"RF20", 4, 27364},
	{"RF21", 4, 27365},
	{"RF22", 4, 27366},
	{"RF23", 4, 27367},
	{"RF24", 4, 27368},
	{"RF25", 4, 27369},
	{"RF26", 4, 27370},
	{"RF27", 4, 27371},
	{"RF28", 4, 27372},
	{"RF29", 4, 27373},
	{"RF30", 4, 27374},
	{"RF31", 4, 27375},
	{"RF32", 4, 27376},
	{"RF33", 4, 27377},
	{"RF34", 4, 27378},
	{"RF35", 4, 27379},
	{"RF36", 4, 27380},
	{"RF37", 4, 27381},
	{"RF38", 4, 27382},
	{"RF39", 4, 27383},
	{"RF40", 4, 27384},
	{"RF41", 4, 27385},
	{"RF42", 4, 27386},
	{"RF43", 4, 27387},
	{"RF44", 4, 27388},
	{"RF45", 4, 27389},
	{"RF46", 4, 27390},
	{"RF47", 4, 27391},
	{"RF48", 4, 27392},
	{"RF49", 4, 27393},
	{"RF50", 4, 27394},
	{"RF51", 4, 27395},
	{"RF52", 4, 27396},
	{"RF53", 4, 27397},
	{"RF54", 4, 27398},
	{"RF55", 4, 27399},
	{"RF56", 4, 27400},
	{"RF57", 4, 27401},
	{"RF58", 4, 27402},
	{"RF59", 4, 27403},
	{"RF60", 4, 27404},
	{"RF61", 4, 27405},
	{"RF62", 4, 27406},
	{"RF63", 4, 27407},
	{"RF64", 4, 27408},
	{"RF65", 4, 27409},
	{"RF66", 4, 27410},
	{"RF67", 4, 27411},
	{"RF68", 4, 27412},
	{"RF69", 4, 27413},
	{"RF70", 4, 27414},
	{"RF71", 4, 27415},
	{"RF72", 4, 27416},
	{"RF73", 4, 27417},
	{"RF74", 4, 27418},
	{"RF75", 4, 27419},
	{"RF76", 4, 27420},
	{"RF77", 4, 27421},
	{"RF78", 4, 27422},
	{"RF79", 4, 27423},
	{"RF80", 4, 27424},
	{"RF81", 4, 27425},
	{"RF82", 4, 27426},
	{"RF83", 4, 27427},
	{"RF84", 4, 27428},
	{"RF85", 4, 27429},
	{"RF86", 4, 27430},
	{"RF87", 4, 27431},
	{"RF88", 4, 27432},
	{"RF89", 4, 27433},
	{"RF90", 4, 27434},
	{"RF91", 4, 27435},
	{"RF92", 4, 27436},
	{"RF93", 4, 27437},
	{"RF94", 4, 27438},
	{"RF95", 4, 27439},
	{"RF96", 4, 27440},
	{"RF97", 4, 27441},
	{"RF98", 4, 27442},
	{"RF99", 4, 27443},
	{"RG00", 4, 27444},
	{"RG01", 4, 27445},
	{"RG02", 4, 27446},
	{"RG03", 4, 27447},
	{"RG04", 4, 27448},
	{"RG05", 4, 27449},
	{"RG06", 4, 27450},
	{"RG07", 4, 27451},
	{"RG08", 4, 27452},
	{"RG09", 4, 27453},
	{"RG10", 4, 27454},
	{"RG11", 4, 27455},
	{"RG12", 4, 27456},
	{"RG13", 4, 27457},
	{"RG14", 4, 27458},
	{"RG15", 4, 27459},
	{"RG16", 4, 27460},
	{"RG17", 4, 27461},
	{"RG18", 4, 27462},
	{"RG19", 4, 27463},
	{"RG20", 4, 27464},
	{"RG21", 4, 27465},
	{"RG22", 4, 27466},
	{"RG23", 4, 27467},
	{"RG24", 4, 27468},
	{"RG25", 4, 27469},
	{"RG26", 4, 27470},
	{"RG27", 4, 27471},
	{"RG28", 4, 27472},
	{"RG29", 4, 27473},
	{"RG30", 4, 27474},
	{"RG31", 4, 27475},
	{"RG32", 4, 27476},
	{"RG33", 4, 27477},
	{"RG34", 4, 27478},
	{"RG35", 4, 27479},
	{"RG36", 4, 27480},
	{"RG37", 4, 27481},
	{"RG38", 4, 27482},
	{"RG39", 4, 27483},
	{"RG40", 4, 27484},
	{"RG41", 4, 27485},
	{"RG42", 4, 27486},
	{"RG43", 4, 27487},
	{"RG44", 4, 27488},
	{"RG45", 4, 27489},
	{"RG46", 4, 27490},
	{"RG47", 4, 27491},
	{"RG48", 4, 27492},
	{"RG49", 4, 27493},
	{"RG50", 4, 27494},
	{"RG51", 4, 27495},
	{"RG52", 4, 27496},
	{"RG53", 4, 27497},
	{"RG54", 4, 27498},
	{"RG55", 4, 27499},
	{"RG56", 4, 27500},
	{"RG57", 4, 27501},
	{"RG58", 4, 27502},
	{"RG59", 4, 27503},
	{"RG60", 4, 27504},
	{"RG61", 4, 27505},
	{"RG62", 4, 27506},
	{"RG63", 4, 27507},
	{"RG64", 4, 27508},
	{"RG65", 4, 27509},
	{"RG66", 4, 27510},
	{"RG67", 4, 27511},
	{"RG68", 4, 27512},
	{"RG69", 4, 27513},
	{"RG70", 4, 27514},
	{"RG71", 4, 27515},
	{"RG72", 4, 27516},
	{"RG73", 4, 27517},
	{"RG74", 4, 27518},
	{"RG75", 4, 27519},
	{"RG76", 4, 27520},
	{"RG77", 4, 27521},
	{"RG78", 4, 27522},
	{"RG79", 4, 27523},
	{"RG80", 4, 27524},
	{"RG81", 4, 27525},
	{"RG82", 4, 27526},
	{"RG83", 4, 27527},
	{"RG84", 4, 27528},
	{"RG85", 4, 27529},
	{"RG86", 4, 27530},
	{"RG87", 4, 27531},
	{"RG88", 4, 27532},
	{"RG89", 4, 27533},
	{"RG90", 4, 27534},
	{"RG91", 4, 27535},
	{"RG92", 4, 27536},
	{"RG93", 4, 27537},
	{"RG94", 4, 27538},
	{"RG95", 4, 27539},
	{"RG96", 4, 27540},
	{"RG97", 4, 27541},
	{"RG98", 4, 27542},
	{"RG99", 4, 27543},
	{"RH00", 4, 27544},
	{"RH01", 4, 27545},
	{"RH02", 4, 27546},
	{"RH03", 4, 27547},
	{"RH04", 4, 27548},
	{"RH05", 4, 27549},
	{"RH06", 4, 27550},
	{"RH07", 4, 27551},
	{"RH08", 4, 27552},
	{"RH09", 4, 27553},
	{"RH10", 4, 27554},
	{"RH11", 4, 27555},
	{"RH12", 4, 27556},
	{"RH13", 4, 27557},
	{"RH14", 4, 27558},
	{"RH15", 4, 27559},
	{"RH16", 4, 27560},
	{"RH17", 4, 27561},
	{"RH18", 4, 27562},
	{"RH19", 4, 27563},
	{"RH20", 4, 27564},
	{"RH21", 4, 27565},
	{"RH22", 4, 27566},
	{"RH23", 4, 27567},
	{"RH24", 4, 27568},
	{"RH25", 4, 27569},
	{"RH26", 4, 27570},
	{"RH27", 4, 27571},
	{"RH28", 4, 27572},
	{"RH29", 4, 27573},
	{"RH30", 4, 27574},
	{"RH31", 4, 27575},
	{"RH32", 4, 27576},
	{"RH33", 4, 27577},
	{"RH34", 4, 27578},
	{"RH35", 4, 27579},
	{"RH36", 4, 27580},
	{"RH37", 4, 27581},
	{"RH38", 4, 27582},
	{"RH39", 4, 27583},
	{"RH40", 4, 27584},
	{"RH41", 4, 27585},
	{"RH42", 4, 27586},
	{"RH43", 4, 27587},
	{"RH44", 4, 27588},
	{"RH45", 4, 27589},
	{"RH46", 4, 27590},
	{"RH47", 4, 27591},
	{"RH48", 4, 27592},
	{"RH49", 4, 27593},
	{"RH50", 4, 27594},
	{"RH51", 4, 27595},
	{"RH52", 4, 27596},
	{"RH53", 4, 27597},
	{"RH54", 4, 27598},
	{"RH55", 4, 27599},
	{"RH56", 4, 27600},
	{"RH57", 4, 27601},
	{"RH58", 4, 27602},
	{"RH59", 4, 27603},
	{"RH60", 4, 27604},
	{"RH61", 4, 27605},
	{"RH62", 4, 27606},
	{"RH63", 4, 27607},
	{"RH64", 4, 27608},
	{"RH65", 4, 27609},
	{"RH66", 4, 27610},
	{"RH67", 4, 27611},
	{"RH68", 4, 27612},
	{"RH69", 4, 27613},
	{"RH70", 4, 27614},
	{"RH71", 4, 27615},
	{"RH72", 4, 27616},
	{"RH73", 4, 27617},
	{"RH74", 4, 27618},
	{"RH75", 4, 27619},
	{"RH76", 4, 27620},
	{"RH77", 4, 27621},
	{"RH78", 4, 27622},
	{"RH79", 4, 27623},
	{"RH80", 4, 27624},
	{"RH81", 4, 27625},
	{"RH82", 4, 27626},
	{"RH83", 4, 27627},
	{"RH84", 4, 27628},
	{"RH85", 4, 27629},
	{"RH86", 4, 27630},
	{"RH87", 4, 27631},
	{"RH88", 4, 27632},
	{"RH89", 4, 27633},
	{"RH90", 4, 27634},
	{"RH91", 4, 27635},
	{"RH92", 4, 27636},
	{"RH93", 4, 27637},
	{"RH94", 4, 27638},
	{"RH95", 4, 27639},
	{"RH96", 4, 27640},
	{"RH97", 4, 27641},
	{"RH98", 4, 27642},
	{"RH99", 4, 27643},
	{"RJ00", 4, 27644},
	{"RJ01", 4, 27645},
	{"RJ02", 4, 27646},
	{"RJ03", 4, 27647},
	{"RJ04", 4, 27648},
	{"RJ05", 4, 27649},
	{"RJ06", 4, 27650},
	{"RJ07", 4, 27651},
	{"RJ08", 4, 27652},
	{"RJ09", 4, 27653},
	{"RJ10", 4, 27654},
	{"RJ11", 4, 27655},
	{"RJ12", 4, 27656},
	{"RJ13", 4, 27657},
	{"RJ14", 4, 27658},
	{"RJ15", 4, 27659},
	{"RJ16", 4, 27660},
	{"RJ17", 4, 27661},
	{"RJ18", 4, 27662},
	{"RJ19", 4, 27663},
	{"RJ20", 4, 27664},
	{"RJ21", 4, 27665},
	{"RJ22", 4, 27666},
	{"RJ23", 4, 27667},
	{"RJ24", 4, 27668},
	{"RJ25", 4, 27669},
	{"RJ26", 4, 27670},
	{"RJ27", 4, 27671},
	{"RJ28", 4, 27672},
	{"RJ29", 4, 27673},
	{"RJ30", 4, 27674},
	{"RJ31", 4, 27675},
	{"RJ32", 4, 27676},
	{"RJ33", 4, 27677},
	{"RJ34", 4, 27678},
	{"RJ35", 4, 27679},
	{"RJ36", 4, 27680},
	{"RJ37", 4, 27681},
	{"RJ38", 4, 27682},
	{"RJ39", 4, 27683},
	{"RJ40", 4, 27684},
	{"RJ41", 4, 27685},
	{"RJ42", 4, 27686},
	{"RJ43", 4, 27687},
	{"RJ44", 4, 27688},
	{"RJ45", 4, 27689},
	{"RJ46", 4, 27690},
	{"RJ47", 4, 27691},
	{"RJ48", 4, 27692},
	{"RJ49", 4, 27693},
	{"RJ50", 4, 27694},
	{"RJ51", 4, 27695},
	{"RJ52", 4, 27696},
	{"RJ53", 4, 27697},
	{"RJ54", 4, 27698},
	{"RJ55", 4, 27699},
	{"RJ56", 4, 27700},
	{"RJ57", 4, 27701},
	{"RJ58", 4, 27702},
	{"RJ59", 4, 27703},
	{"RJ60", 4, 27704},
	{"RJ61", 4, 27705},
	{"RJ62", 4, 27706},
	{"RJ63", 4, 27707},
	{"RJ64", 4, 27708},
	{"RJ65", 4, 27709},
	{"RJ66", 4, 27710},
	{"RJ67", 4, 27711},
	{"RJ68", 4, 27712},
	{"RJ69", 4, 27713},
	{"RJ70", 4, 27714},
	{"RJ71", 4, 27715},
	{"RJ72", 4, 27716},
	{"RJ73", 4, 27717},
	{"RJ74", 4, 27718},
	{"RJ75", 4, 27719},
	{"RJ76", 4, 27720},
	{"RJ77", 4, 27721},
	{"RJ78", 4, 27722},
	{"RJ79", 4, 27723},
	{"RJ80", 4, 27724},
	{"RJ81", 4, 27725},
	{"RJ82", 4, 27726},
	{"RJ83", 4, 27727},
	{"RJ84", 4, 27728},
	{"RJ85", 4, 27729},
	{"RJ86", 4, 27730},
	{"RJ87", 4, 27731},
	{"RJ88", 4, 27732},
	{"RJ89", 4, 27733},
	{"RJ90", 4, 27734},
	{"RJ91", 4, 27735},
	{"RJ92", 4, 27736},
	{"RJ93", 4, 27737},
	{"RJ94", 4, 27738},
	{"RJ95", 4, 27739},
	{"RJ96", 4, 27740},
	{"RJ97", 4, 27741},
	{"RJ98", 4, 27742},
	{"RJ99", 4, 27743},
	{"RK00", 4, 27744},
	{"RK01", 4, 27745},
	{"RK02", 4, 27746},
	{"RK03", 4, 27747},
	{"RK04", 4, 27748},
	{"RK05", 4, 27749},
	{"RK06", 4, 27750},
	{"RK07", 4, 27751},
	{"RK08", 4, 27752},
	{"RK09", 4, 27753},
	{"RK10", 4, 27754},
	{"RK11", 4, 27755},
	{"RK12", 4, 27756},
	{"RK13", 4, 27757},
	{"RK14", 4, 27758},
	{"RK15", 4, 27759},
	{"RK16", 4, 27760},
	{"RK17", 4, 27761},
	{"RK18", 4, 27762},
	{"RK19", 4, 27763},
	{"RK20", 4, 27764},
	{"RK21", 4, 27765},
	{"RK22", 4, 27766},
	{"RK23", 4, 27767},
	{"RK24", 4, 27768},
	{"RK25", 4, 27769},
	{"RK26", 4, 27770},
	{"RK27", 4, 27771},
	{"RK28", 4, 27772},
	{"RK29", 4, 27773},
	{"RK30", 4, 27774},
	{"RK31", 4, 27775},
	{"RK32", 4, 27776},
	{"RK33", 4, 27777},
	{"RK34", 4, 27778},
	{"RK35", 4, 27779},
	{"RK36", 4, 27780},
	{"RK37", 4, 27781},
	{"RK38", 4, 27782},
	{"RK39", 4, 27783},
	{"RK40", 4, 27784},
	{"RK41", 4, 27785},
	{"RK42", 4, 27786},
	{"RK43", 4, 27787},
	{"RK44", 4, 27788},
	{"RK45", 4, 27789},
	{"RK46", 4, 27790},
	{"RK47", 4, 27791},
	{"RK48", 4, 27792},
	{"RK49", 4, 27793},
	{"RK50", 4, 27794},
	{"RK51", 4, 27795},
	{"RK52", 4, 27796},
	{"RK53", 4, 27797},
	{"RK54", 4, 27798},
	{"RK55", 4, 27799},
	{"RK56", 4, 27800},
	{"RK57", 4, 27801},
	{"RK58", 4, 27802},
	{"RK59", 4, 27803},
	{"RK60", 4, 27804},
	{"RK61", 4, 27805},
	{"RK62", 4, 27806},
	{"RK63", 4, 27807},
	{"RK64", 4, 27808},
	{"RK65", 4, 27809},
	{"RK66", 4, 27810},
	{"RK67", 4, 27811},
	{"RK68", 4, 27812},
	{"RK69", 4, 27813},
	{"RK70", 4, 27814},
	{"RK71", 4, 27815},
	{"RK72", 4, 27816},
	{"RK73", 4, 27817},
	{"RK74", 4, 27818},
	{"RK75", 4, 27819},
	{"RK76", 4, 27820},
	{"RK77", 4, 27821},
	{"RK78", 4, 27822},
	{"RK79", 4, 27823},
	{"RK80", 4, 27824},
	{"RK81", 4, 27825},
	{"RK82", 4, 27826},
	{"RK83", 4, 27827},
	{"RK84", 4, 27828},
	{"RK85", 4, 27829},
	{"RK86", 4, 27830},
	{"RK87", 4, 27831},
	{"RK88", 4, 27832},
	{"RK89", 4, 27833},
	{"RK90", 4, 27834},
	{"RK91", 4, 27835},
	{"RK92", 4, 27836},
	{"RK93", 4, 27837},
	{"RK94", 4, 27838},
	{"RK95", 4, 27839},
	{"RK96", 4, 27840},
	{"RK97", 4, 27841},
	{"RK98", 4, 27842},
	{"RK99", 4, 27843},
	{"RO00", 4, 27844},
	{"RO01", 4, 27845},
	{"RO02", 4, 27846},
	{"RO03", 4, 27847},
	{"RO04", 4, 27848},
	{"RO05", 4, 27849},
	{"RO06", 4, 27850},
	{"RO07", 4, 27851},
	{"RO08", 4, 27852},
	{"RO09", 4, 27853},
	{"RO10", 4, 27854},
	{"RO11", 4, 27855},
	{"RO12", 4, 27856},
	{"RO13", 4, 27857},
	{"RO14", 4, 27858},
	{"RO15", 4, 27859},
	{"RO16", 4, 27860},
	{"RO17", 4, 27861},
	{"RO18", 4, 27862},
	{"RO19", 4, 27863},
	{"RO20", 4, 27864},
	{"RO21", 4, 27865},
	{"RO22", 4, 27866},
	{"RO23", 4, 27867},
	{"RO24", 4, 27868},
	{"RO25", 4, 27869},
	{"RO26", 4, 27870},
	{"RO27", 4, 27871},
	{"RO28", 4, 27872},
	{"RO29", 4, 27873},
	{"RO30", 4, 27874},
	{"RO31", 4, 27875},
	{"RO32", 4, 27876},
	{"RO33", 4, 27877},
	{"RO34", 4, 27878},
	{"RO35", 4, 27879},
	{"RO36", 4, 27880},
	{"RO37", 4, 27881},
	{"RO38", 4, 27882},
	{"RO39", 4, 27883},
	{"RO40", 4, 27884},
	{"RO41", 4, 27885},
	{"RO42", 4, 27886},
	{"RO43", 4, 27887},
	{"RO44", 4, 27888},
	{"RO45", 4, 27889},
	{"RO46", 4, 27890},
	{"RO47", 4, 27891},
	{"RO48", 4, 27892},
	{"RO49", 4, 27893},
	{"RO50", 4, 27894},
	{"RO51", 4, 27895},
	{"RO52", 4, 27896},
	{"RO53", 4, 27897},
	{"RO54", 4, 27898},
	{"RO55", 4, 27899},
	{"RO56", 4, 27900},
	{"RO57", 4, 27901},
	{"RO58", 4, 27902},
	{"RO59", 4, 27903},
	{"RO60", 4, 27904},
	{"RO61", 4, 27905},
	{"RO62", 4, 27906},
	{"RO63", 4, 27907},
	{"RO64", 4, 27908},
	{"RO65", 4, 27909},
	{"RO66", 4, 27910},
	{"RO67", 4, 27911},
	{"RO68", 4, 27912},
	{"RO69", 4, 27913},
	{"RO70", 4, 27914},
	{"RO71", 4, 27915},
	{"RO72", 4, 27916},
	{"RO73", 4, 27917},
	{"RO74", 4, 27918},
	{"RO75", 4, 27919},
	{"RO76", 4, 27920},
	{"RO77", 4, 27921},
	{"RO78", 4, 27922},
	{"RO79", 4, 27923},
	{"RO80", 4, 27924},
	{"RO81", 4, 27925},
	{"RO82", 4, 27926},
	{"RO83", 4, 27927},
	{"RO84", 4, 27928},
	{"RO85", 4, 27929},
	{"RO86", 4, 27930},
	{"RO87", 4, 27931},
	{"RO88", 4, 27932},
	{"RO89", 4, 27933},
	{"RO90", 4, 27934},
	{"RO91", 4, 27935},
	{"RO92", 4, 27936},
	{"RO93", 4, 27937},
	{"RO94", 4, 27938},
	{"RO95", 4, 27939},
	{"RO96", 4, 27940},
	{"RO97", 4, 27941},
	{"RO98", 4, 27942},
	{"RO99", 4, 27943},
	{"RP00", 4, 27944},
	{"RP01", 4, 27945},
	{"RP02", 4, 27946},
	{"RP03", 4, 27947},
	{"RP04", 4, 27948},
	{"RP05", 4, 27949},
	{"RP06", 4, 27950},
	{"RP07", 4, 27951},
	{"RP08", 4, 27952},
	{"RP09", 4, 27953},
	{"RP10", 4, 27954},
	{"RP11", 4, 27955},
	{"RP12", 4, 27956},
	{"RP13", 4, 27957},
	{"RP14", 4, 27958},
	{"RP15", 4, 27959},
	{"RP16", 4, 27960},
	{"RP17", 4, 27961},
	{"RP18", 4, 27962},
	{"RP19", 4, 27963},
	{"RP20", 4, 27964},
	{"RP21", 4, 27965},
	{"RP22", 4, 27966},
	{"RP23", 4, 27967},
	{"RP24", 4, 27968},
	{"RP25", 4, 27969},
	{"RP26", 4, 27970},
	{"RP27", 4, 27971},
	{"RP28", 4, 27972},
	{"RP29", 4, 27973},
	{"RP30", 4, 27974},
	{"RP31", 4, 27975},
	{"RP32", 4, 27976},
	{"RP33", 4, 27977},
	{"RP34", 4, 27978},
	{"RP35", 4, 27979},
	{"RP36", 4, 27980},
	{"RP37", 4, 27981},
	{"RP38", 4, 27982},
	{"RP39", 4, 27983},
	{"RP40", 4, 27984},
	{"RP41", 4, 27985},
	{"RP42", 4, 27986},
	{"RP43", 4, 27987},
	{"RP44", 4, 27988},
	{"RP45", 4, 27989},
	{"RP46", 4, 27990},
	{"RP47", 4, 27991},
	{"RP48", 4, 27992},
	{"RP49", 4, 27993},
	{"RP50", 4, 27994},
	{"RP51", 4, 27995},
	{"RP52", 4, 27996},
	{"RP53", 4, 27997},
	{"RP54", 4, 27998},
	{"RP55", 4, 27999},
	{"RP56", 4, 28000},
	{"RP57", 4, 28001},
	{"RP58", 4, 28002},
	{"RP59", 4, 28003},
	{"RP60", 4, 28004},
	{"RP61", 4, 28005},
	{"RP62", 4, 28006},
	{"RP63", 4, 28007},
	{"RP64", 4, 28008},
	{"RP65", 4, 28009},
	{"RP66", 4, 28010},
	{"RP67", 4, 28011},
	{"RP68", 4, 28012},
	{"RP69", 4, 28013},
	{"RP70", 4, 28014},
	{"RP71", 4, 28015},
	{"RP72", 4, 28016},
	{"RP73", 4, 28017},
	{"RP74", 4, 28018},
	{"RP75", 4, 28019},
	{"RP76", 4, 28020},
	{"RP77", 4, 28021},
	{"RP78", 4, 28022},
	{"RP79", 4, 28023},
	{"RP80", 4, 28024},
	{"RP81", 4, 28025},
	{"RP82", 4, 28026},
	{"RP83", 4, 28027},
	{"RP84", 4, 28028},
	{"RP85", 4, 28029},
	{"RP86", 4, 28030},
	{"RP87", 4, 28031},
	{"RP88", 4, 28032},
	{"RP89", 4, 28033},
	{"RP90", 4, 28034},
	{"RP91", 4, 28035},
	{"RP92", 4, 28036},
	{"RP93", 4, 28037},
	{"RP94", 4, 28038},
	{"RP95", 4, 28039},
	{"RP96", 4, 28040},
	{"RP97", 4, 28041},
	{"RP98", 4, 28042},
	{"RP99", 4, 28043},
	{"IALO", 4, 28044},
	{"ASTRONOMY", 9, 28045},
	{"LANKA", 5, 28046},
	{"RYWH", 4, 28047},
	{"ACEF", 4, 28048},
	{"PRIVACY", 7, 28049},
	{"CABIN", 5, 28050},
	{"NDRU", 4, 28051},
	{"EDWARDS", 7, 28052},
	{"DREW", 4, 28053},
	{"CONTESTS", 8, 28054},
	{"FLU", 3, 28055},
	{"COPE", 4, 28056},
	{"UPPE", 4, 28057},
	{"BARREL", 6, 28058},
	{"ANNOUNCES", 9, 28059},
	{"MLB", 3, 28060},
	{"HESL", 4, 28061},
	{"ARSW", 4, 28062},
	{"TAGGED", 6, 28063},
	{"LSER", 4, 28064},
	{"EAGR", 4, 28065},
	{"BERKELEY", 8, 28066},
	{"HDOW", 4, 28067},
	{"VOTED", 5, 28068},
	{"BIKES", 5, 28069},
	{"LYMP", 4, 28070},
	{"NERVE", 5, 28071},
	{"IMEM", 4, 28072},
	{"YWAN", 4, 28073},
	{"GATES", 5, 28074},
	{"RESTRICTION", 11, 28075},
	{"ADJUSTED", 8, 28076},
	{"WORKSHOP", 8, 28077},
	{"BUTC", 4, 28078},
	{"RAP", 3, 28079},
	{"LMIN", 4, 28080},
	{"PULLED", 6, 28081},
	{"PRINCIPAL", 9, 28082},
	{"CONTROVERSIAL", 13, 28083},
	{"LDES", 4, 28084},
	{"SHAPED", 6, 28085},
	{"ANUF", 4, 28086},
	{"INSTRUCTOR", 10, 28087},
	{"COMPRESSION", 11, 28088},
	{"SEASONAL", 8, 28089},
	{"KOFT", 4, 28090},
	{"ESTABLISHING", 12, 28091},
	{"VYU", 3, 28092},
	{"PTIN", 4, 28093},
	{"LIFESTYLE", 9, 28094},
	{"COUNTERS", 8, 28095},
	{"HESY", 4, 28096},
	{"OFFENSIVE", 9, 28097},
	{"PUTS", 4, 28098},
	{"NYIN", 4, 28099},
	{"GOTI", 4, 28100},
	{"PAINFUL", 7, 28101},
	{"IMPRESS", 7, 28102},
	{"GREW", 4, 28103},
	{"THWH", 4, 28104},
	{"VEMA", 4, 28105},
	{"STROKE", 6, 28106},
	{"HYPOTHESIS", 10, 28107},
	{"SKQ", 3, 28108},
	{"CULTURES", 8, 28109},
	{"NORFOLK", 7, 28110},
	{"NSRE", 4, 28111},
	{"COACHING", 8, 28112},
	{"EXAMINED", 8, 28113},
	{"TREK", 4, 28114},
	{"EREQ", 4, 28115},
	{"SOPHISTICATED", 13, 28116},
	{"EREU", 4, 28117},
	{"NUFA", 4, 28118},
	{"AYSB", 4, 28119},
	{"IRCR", 4, 28120},
	{"ENCODING", 8, 28121},
	{"DSTE", 4, 28122},
	{"ROUB", 4, 28123},
	{"LITIGATION", 10, 28124},
	{"GIOU", 4, 28125},
	{"UTOM", 4, 28126},
	{"DMIT", 4, 28127},
	{"UTWE", 4, 28128},
	{"ASSIGNMENT", 10, 28129},
	{"SUBMISSIONS", 11, 28130},
	{"DISCRIMINATION", 14, 28131},
	{"HEROES", 6, 28132},
	{"FLESH", 5, 28133},
	{"PAINTED", 7, 28134},
	{"LYCOS", 5, 28135},
	{"AVEE", 4, 28136},
	{"ZDNET", 5, 28137},
	{"ELLB", 4, 28138},
	{"BROADCASTING", 12, 28139},
	{"RBRO", 4, 28140},
	{"HORIZON", 7, 28141},
	{"HORIZONTAL", 10, 28142},
	{"ARTWORK", 7, 28143},
	{"UETH", 4, 28144},
	{"GAZE", 4, 28145},
	{"COSMETIC", 8, 28146},
	{"NEDU", 4, 28147},
	{"RESULTED", 8, 28148},
	{"INFORMATIONAL", 13, 28149},
	{"CARRIERS", 8, 28150},
	{"ECOMMERCE", 9, 28151},
	{"MOBILITY", 8, 28152},
	{"URNO", 4, 28153},
	{"FLORAL", 6, 28154},
	{"OACC", 4, 28155},
	{"BUILDERS", 8, 28156},
	{"SCHEMES", 7, 28157},
	{"LESP", 4, 28158},
	{"ERGI", 4, 28159},
	{"CONVICTION", 10, 28160},
	{"FISHER", 6, 28161},
	{"HETU", 4, 28162},
	{"GIRLFRIEND", 10, 28163},
	{"LLDO", 4, 28164},
	{"DLAT", 4, 28165},
	{"UNDERGO", 7, 28166},
	{"HEYT", 4, 28167},
	{"SPEARS", 6, 28168},
	{"OPAY", 4, 28169},
	{"TGAM", 4, 28170},
	{"PINE", 4, 28171},
	{"RRET", 4, 28172},
	{"MANUFACTURING", 13, 28173},
	{"WANDER", 6, 28174},
	{"PROSPECTIVE", 11, 28175},
	{"EXPLODE", 7, 28176},
	{"CLUSTER", 7, 28177},
	{"NMIL", 4, 28178},
	{"USTW", 4, 28179},
	{"HEOU", 4, 28180},
	{"SRIG", 4, 28181},
	{"ALSU", 4, 28182},
	{"BEDDING", 7, 28183},
	{"DESO", 4, 28184},
	{"JOINING", 7, 28185},
	{"HEADING", 7, 28186},
	{"BEARING", 7, 28187},
	{"ISHC", 4, 28188},
	{"EFTT", 4, 28189},
	{"BRUSH", 5, 28190},
	{"COORDINATION", 12, 28191},
	{"CONNECTOR", 9, 28192},
	{"LAYT", 4, 28193},
	{"BRAD", 4, 28194},
	{"WAYO", 4, 28195},
	{"ECIE", 4, 28196},
	{"COMBO", 5, 28197},
	{"SENIORS", 7, 28198},
	{"WORLDS", 6, 28199},
	{"SUBSEQUENT", 10, 28200},
	{"DESPERATE", 9, 28201},
	{"EUZ", 3, 28202},
	{"BATTERY", 7, 28203},
	{"IDENTIFICATION", 14, 28204},
	{"AFFILIATED", 10, 28205},
	{"MEDICATION", 10, 28206},
	{"INOU", 4, 28207},
	{"ASPL", 4, 28208},
	{"ACTIVATION", 10, 28209},
	{"TOCL", 4, 28210},
	{"DYQ", 3, 28211},
	{"YSPE", 4, 28212},
	{"IZON", 4, 28213},
	{"SPAP", 4, 28214},
	{"HAVEN", 5, 28215},
	{"TABLET", 6, 28216},
	{"DSEC", 4, 28217},
	{"TPRI", 4, 28218},
	{"RIFI", 4, 28219},
	{"ACID", 4, 28220},
	{"NTSU", 4, 28221},
	{"EISC", 4, 28222},
	{"IKY", 3, 28223},
	{"RSEE", 4, 28224},
	{"SUBSCRIBERS", 11, 28225},
	{"ISBR", 4, 28226},
	{"TSSU", 4, 28227},
	{"ONLE", 4, 28228},
	{"DSEN", 4, 28229},
	{"ABSORB", 6, 28230},
	{"EFAI", 4, 28231},
	{"MITSUBISHI", 10, 28232},
	{"ECONOMICS", 9, 28233},
	{"INFLATION", 9, 28234},
	{"CONSCIOUSNESS", 13, 28235},
	{"ENAG", 4, 28236},
	{"UNDERWEAR", 9, 28237},
	{"ORANGE", 6, 28238},
	{"TNAM", 4, 28239},
	{"CKUP", 4, 28240},
	{"BASIN", 5, 28241},
	{"ROFC", 4, 28242},
	{"OXU", 3, 28243},
	{"DGEO", 4, 28244},
	{"EAVA", 4, 28245},
	{"MODEST", 6, 28246},
	{"RDES", 4, 28247},
	{"ESDO", 4, 28248},
	{"ANYB", 4, 28249},
	{"RSLA", 4, 28250},
	{"PROMPT", 6, 28251},
	{"CONSTRAINTS", 11, 28252},
	{"PHOTOGRAPHER", 12, 28253},
	{"CROSSING", 8, 28254},
	{"CURIOUS", 7, 28255},
	{"CIPL", 4, 28256},
	{"HANDFUL", 7, 28257},
	{"INCLUSIVE", 9, 28258},
	{"COTTON", 6, 28259},
	{"DIMENSIONAL", 11, 28260},
	{"ONSM", 4, 28261},
	{"OWEL", 4, 28262},
	{"DEMONSTRATION", 13, 28263},
	{"SUCCESSFULLY", 12, 28264},
	{"CRIMES", 6, 28265},
	{"RESOLVED", 8, 28266},
	{"AGAZ", 4, 28267},
	{"MOZILLA", 7, 28268},
	{"CZO", 3, 28269},
	{"BYTE", 4, 28270},
	{"DEPICT", 6, 28271},
	{"TONER", 5, 28272},
	{"RTQ", 3, 28273},
	{"FLAME", 5, 28274},
	{"SNEV", 4, 28275},
	{"LATEX", 5, 28276},
	{"RYRE", 4, 28277},
	{"ECRA", 4, 28278},
	{"BRANCHES", 8, 28279},
	{"EMIE", 4, 28280},
	{"VALLEY", 6, 28281},
	{"TZV", 3, 28282},
	{"YREP", 4, 28283},
	{"OCLC", 4, 28284},
	{"DELHI", 5, 28285},
	{"HOLDINGS", 8, 28286},
	{"ECLE", 4, 28287},
	{"STFI", 4, 28288},
	{"NOMINATION", 10, 28289},
	{"DPOI", 4, 28290},
	{"GOD", 3, 28291},
	{"LOCATOR", 7, 28292},
	{"SELECTING", 9, 28293},
	{"STANDING", 8, 28294},
	{"NBRO", 4, 28295},
	{"ESOV", 4, 28296},
	{"AYNI", 4, 28297},
	{"RHOM", 4, 28298},
	{"CIVILIAN", 8, 28299},
	{"SINB", 4, 28300},
	{"PROCESSORS", 10, 28301},
	{"ASBU", 4, 28302},
	{"DISTINCT", 8, 28303},
	{"YZS", 3, 28304},
	{"PLC", 3, 28305},
	{"LDOF", 4, 28306},
	{"BROKE", 5, 28307},
	{"ISPU", 4, 28308},
	{"NEPAL", 5, 28309},
	{"YUZ", 3, 28310},
	{"ZIMBABWE", 8, 28311},
	{"RHOU", 4, 28312},
	{"TEDN", 4, 28313},
	{"EINW", 4, 28314},
	{"EXTENSION", 9, 28315},
	{"VEYE", 4, 28316},
	{"EDIV", 4, 28317},
	{"DIFFICULTIES", 12, 28318},
	{"TGRO", 4, 28319},
	{"HERITAGE", 8, 28320},
	{"SMOV", 4, 28321},
	{"HABITAT", 7, 28322},
	{"DISTINGUISH", 11, 28323},
	{"JUAN", 4, 28324},
	{"DBRI", 4, 28325},
	{"BROWSING", 8, 28326},
	{"IRGI", 4, 28327},
	{"HUMOR", 5, 28328},
	{"HUNGRY", 6, 28329},
	{"OSAL", 4, 28330},
	{"BADLY", 5, 28331},
	{"SBUI", 4, 28332},
	{"BARCELONA", 9, 28333},
	{"SEDH", 4, 28334},
	{"NBYT", 4, 28335},
	{"UEOF", 4, 28336},
	{"COD", 3, 28337},
	{"TERRITORIES", 11, 28338},
	{"MELISSA", 7, 28339},
	{"POWDER", 6, 28340},
	{"EDITION", 7, 28341},
	{"MOSCOW", 6, 28342},
	{"NKST", 4, 28343},
	{"TVV", 3, 28344},
	{"SLIG", 4, 28345},
	{"THESIS", 6, 28346},
	{"ORAG", 4, 28347},
	{"THRU", 4, 28348},
	{"STSU", 4, 28349},
	{"REDP", 4, 28350},
	{"JEWS", 4, 28351},
	{"NYLON", 5, 28352},
	{"PSTH", 4, 28353},
	{"PEOF", 4, 28354},
	{"SUMMIT", 6, 28355},
	{"COLONIAL", 8, 28356},
	{"EAGER", 5, 28357},
	{"EALB", 4, 28358},
	{"DISCS", 5, 28359},
	{"SHOWER", 6, 28360},
	{"ROCKY", 5, 28361},
	{"RTRE", 4, 28362},
	{"ZGO", 3, 28363},
	{"BARGAINS", 8, 28364},
	{"ABSOLUTE", 8, 28365},
	{"ETUP", 4, 28366},
	{"SDID", 4, 28367},
	{"AINB", 4, 28368},
	{"ODEA", 4, 28369},
	{"LFOF", 4, 28370},
	{"NIGERIA", 7, 28371},
	{"ORKW", 4, 28372},
	{"ONAG", 4, 28373},
	{"ELOF", 4, 28374},
	{"LSOM", 4, 28375},
	{"LYDO", 4, 28376},
	{"LLIG", 4, 28377},
	{"PIXELS", 6, 28378},
	{"ENSURING", 8, 28379},
	{"BUTD", 4, 28380},
	{"INAG", 4, 28381},
	{"OXJ", 3, 28382},
	{"YSER", 4, 28383},
	{"COMEDY", 6, 28384},
	{"HOSPITALITY", 11, 28385},
	{"FANY", 4, 28386},
	{"NDJO", 4, 28387},
	{"ONFL", 4, 28388},
	{"PROCUREMENT", 11, 28389},
	{"DIAMONDS", 8, 28390},
	{"ESPN", 4, 28391},
	{"AMPU", 4, 28392},
	{"PITCH", 5, 28393},
	{"RMOF", 4, 28394},
	{"UNTITLED", 8, 28395},
	{"AYSS", 4, 28396},
	{"CORRELATION", 11, 28397},
	{"LLYG", 4, 28398},
	{"SLOO", 4, 28399},
	{"ELET", 4, 28400},
	{"GZI", 3, 28401},
	{"TOTALS", 6, 28402},
	{"MARRIOTT", 8, 28403},
	{"TBEI", 4, 28404},
	{"GARAGE", 6, 28405},
	{"SINGING", 7, 28406},
	{"ONPO", 4, 28407},
	{"EXERCISES", 9, 28408},
	{"ZKA", 3, 28409},
	{"STARRING", 8, 28410},
	{"REFERRAL", 8, 28411},
	{"DIFFERENTLY", 11, 28412},
	{"GHOST", 5, 28413},
	{"HENP", 4, 28414},
	{"ROMANTIC", 8, 28415},
	{"ETHICS", 6, 28416},
	{"TRANSFORMATION", 14, 28417},
	{"GYV", 3, 28418},
	{"TLEB", 4, 28419},
	{"ILSO", 4, 28420},
	{"OPTIMAL", 7, 28421},
	{"OFAD", 4, 28422},
	{"OVERLOOK", 8, 28423},
	{"ASWO", 4, 28424},
	{"PROTOCOLS", 9, 28425},
	{"OWNH", 4, 28426},
	{"OIMP", 4, 28427},
	{"DATH", 4, 28428},
	{"LEGITIMATE", 10, 28429},
	{"LLWI", 4, 28430},
	{"APPOINT", 7, 28431},
	{"GSOF", 4, 28432},
	{"NDUP", 4, 28433},
	{"NTLI", 4, 28434},
	{"SUBSTITUTE", 10, 28435},
	{"NSEV", 4, 28436},
	{"FLEC", 4, 28437},
	{"INCLUSION", 9, 28438},
	{"RMIL", 4, 28439},
	{"AIRM", 4, 28440},
	{"TURNER", 6, 28441},
	{"NFID", 4, 28442},
	{"SUCKING", 7, 28443},
	{"CENTS", 5, 28444},
	{"REUTERS", 7, 28445},
	{"MEDIUM", 6, 28446},
	{"GEL", 3, 28447},
	{"GRAIN", 5, 28448},
	{"TODD", 4, 28449},
	{"IANP", 4, 28450},
	{"SPOKEN", 6, 28451},
	{"RTIF", 4, 28452},
	{"OMEGA", 5, 28453},
	{"GESI", 4, 28454},
	{"EVALUATED", 9, 28455},
	{"SSPO", 4, 28456},
	{"STAYED", 6, 28457},
	{"LPHI", 4, 28458},
	{"KSOF", 4, 28459},
	{"ASSIGNMENTS", 11, 28460},
	{"MZE", 3, 28461},
	{"LLME", 4, 28462},
	{"TWOC", 4, 28463},
	{"MANUALS", 7, 28464},
	{"SUBMIT", 6, 28465},
	{"DOUG", 4, 28466},
	{"AFRE", 4, 28467},
	{"TERMINATION", 11, 28468},
	{"VEAC", 4, 28469},
	{"ZPO", 3, 28470},
	{"LDSA", 4, 28471},
	{"WATCHED", 7, 28472},
	{"BRILLIANT", 9, 28473},
	{"PROVINCE", 8, 28474},
	{"DSFO", 4, 28475},
	{"SAVER", 5, 28476},
	{"THEREOF", 7, 28477},
	{"ALKS", 4, 28478},
	{"GRILL", 5, 28479},
	{"UXP", 3, 28480},
	{"HOUSEHOLDS", 10, 28481},
	{"OPERATING", 9, 28482},
	{"COOKIE", 6, 28483},
	{"RIAG", 4, 28484},
	{"REDEEM", 6, 28485},
	{"ROGERS", 6, 28486},
	{"ERTW", 4, 28487},
	{"LYFR", 4, 28488},
	{"OFUN", 4, 28489},
	{"HIPW", 4, 28490},
	{"BSTA", 4, 28491},
	{"ALLR", 4, 28492},
	{"AUTHENTIC", 9, 28493},
	{"ERID", 4, 28494},
	{"RCZ", 3, 28495},
	{"TEMPORARY", 9, 28496},
	{"WANNA", 5, 28497},
	{"RRIA", 4, 28498},
	{"MONTGOMERY", 10, 28499},
	{"LEGACY", 6, 28500},
	{"EXHIBIT", 7, 28501},
	{"ARCHITECTURAL", 13, 28502},
	{"LOUISVILLE", 10, 28503},
	{"ARBE", 4, 28504},
	{"BOOM", 4, 28505},
	{"ORYI", 4, 28506},
	{"MACINTOSH", 9, 28507},
	{"SERVING", 7, 28508},
	{"MOVEMENTS", 9, 28509},
	{"RYWA", 4, 28510},
	{"MOUSE", 5, 28511},
	{"EBOD", 4, 28512},
	{"ACTRESS", 7, 28513},
	{"BVIO", 4, 28514},
	{"RANGING", 7, 28515},
	{"SEWE", 4, 28516},
	{"MONICA", 6, 28517},
	{"REPAIRS", 7, 28518},
	{"WHOT", 4, 28519},
	{"APHY", 4, 28520},
	{"EBEF", 4, 28521},
	{"YKNO", 4, 28522},
	{"EWRI", 4, 28523},
	{"RWHA", 4, 28524},
	{"EWRO", 4, 28525},
	{"TBEL", 4, 28526},
	{"AMENITIES", 9, 28527},
	{"COLE", 4, 28528},
	{"SMEA", 4, 28529},
	{"IKEM", 4, 28530},
	{"OFBR", 4, 28531},
	{"MART", 4, 28532},
	{"CEDO", 4, 28533},
	{"HANGING", 7, 28534},
	{"COLORED", 7, 28535},
	{"NLYS", 4, 28536},
	{"NGEX", 4, 28537},
	{"NFLI", 4, 28538},
	{"ARTISTIC", 8, 28539},
	{"AUTHORIZATION", 13, 28540},
	{"VERIFIED", 8, 28541},
	{"LYNN", 4, 28542},
	{"PROJECTOR", 9, 28543},
	{"ERJO", 4, 28544},
	{"OCOL", 4, 28545},
	{"SITUATED", 8, 28546},
	{"COMPARATIVE", 11, 28547},
	{"LYAC", 4, 28548},
	{"INVASION", 8, 28549},
	{"MPIR", 4, 28550},
	{"SEEKS", 5, 28551},
	{"TYHA", 4, 28552},
	{"HERBAL", 6, 28553},
	{"LOVING", 6, 28554},
	{"ROUTING", 7, 28555},
	{"ADEQUATE", 8, 28556},
	{"IDID", 4, 28557},
	{"TOFB", 4, 28558},
	{"IONG", 4, 28559},
	{"DOCS", 4, 28560},
	{"WOUND", 5, 28561},
	{"NTDO", 4, 28562},
	{"COOKING", 7, 28563},
	{"CONTINUED", 9, 28564},
	{"WKO", 3, 28565},
	{"TTRI", 4, 28566},
	{"STANLEY", 7, 28567},
	{"RSBU", 4, 28568},
	{"IDEW", 4, 28569},
	{"LLBU", 4, 28570},
	{"NREP", 4, 28571},
	{"REGISTER", 8, 28572},
	{"COUNSEL", 7, 28573},
	{"BLANKET", 7, 28574},
	{"COLLECTIVE", 10, 28575},
	{"EORD", 4, 28576},
	{"AZQ", 3, 28577},
	{"ILMS", 4, 28578},
	{"VITAMINS", 8, 28579},
	{"LFRO", 4, 28580},
	{"COMPETITOR", 10, 28581},
	{"GAINS", 5, 28582},
	{"SONP", 4, 28583},
	{"RENEWAL", 7, 28584},
	{"OWAT", 4, 28585},
	{"VID", 3, 28586},
	{"GENEALOGY", 9, 28587},
	{"NBEF", 4, 28588},
	{"IKEI", 4, 28589},
	{"DEEMED", 6, 28590},
	{"SCORING", 7, 28591},
	{"NOFH", 4, 28592},
	{"YNL", 3, 28593},
	{"EXCEED", 6, 28594},
	{"EXPENDITURE", 11, 28595},
	{"ITUD", 4, 28596},
	{"BROOKLYN", 8, 28597},
	{"NORM", 4, 28598},
	{"STBA", 4, 28599},
	{"LIVERPOOL", 9, 28600},
	{"YLAN", 4, 28601},
	{"SISTERS", 7, 28602},
	{"CRITICS", 7, 28603},
	{"UNCLE", 5, 28604},
	{"CONNECTIVITY", 12, 28605},
	{"UGHE", 4, 28606},
	{"NELI", 4, 28607},
	{"SPOTS", 5, 28608},
	{"OPERATOR", 8, 28609},
	{"ALGORITHMS", 10, 28610},
	{"HACKER", 6, 28611},
	{"YKY", 3, 28612},
	{"VEWI", 4, 28613},
	{"MADRID", 6, 28614},
	{"ANTICIPATE", 10, 28615},
	{"REINFORCE", 9, 28616},
	{"EANC", 4, 28617},
	{"ACKB", 4, 28618},
	{"NBAS", 4, 28619},
	{"HPLA", 4, 28620},
	{"KYV", 3, 28621},
	{"SLICE", 5, 28622},
	{"REDC", 4, 28623},
	{"YIMP", 4, 28624},
	{"MESF", 4, 28625},
	{"FAKE", 4, 28626},
	{"EZK", 3, 28627},
	{"STWH", 4, 28628},
	{"LDSE", 4, 28629},
	{"CONCERNING", 10, 28630},
	{"EIRW", 4, 28631},
	{"LOVELY", 6, 28632},
	{"IERT", 4, 28633},
	{"DEVOTE", 6, 28634},
	{"ILEI", 4, 28635},
	{"SALON", 5, 28636},
	{"RSOL", 4, 28637},
	{"WIDESPREAD", 10, 28638},
	{"TCOL", 4, 28639},
	{"BASKET", 6, 28640},
	{"AYON", 4, 28641},
	{"VENM", 4, 28642},
	{"INSW", 4, 28643},
	{"COLLABORATIVE", 13, 28644},
	{"NORMAN", 6, 28645},
	{"FDA", 3, 28646},
	{"EXCLUDING", 9, 28647},
	{"YTOA", 4, 28648},
	{"XJU", 3, 28649},
	{"TURBO", 5, 28650},
	{"HEADED", 6, 28651},
	{"VOTERS", 6, 28652},
	{"COUNSELING", 10, 28653},
	{"AWFUL", 5, 28654},
	{"ROPE", 4, 28655},
	{"PERMISSION", 10, 28656},
	{"WEEKLY", 6, 28657},
	{"IMPLEMENTATION", 14, 28658},
	{"DECREASE", 8, 28659},
	{"MADONNA", 7, 28660},
	{"LESF", 4, 28661},
	{"MWHI", 4, 28662},
	{"ARCH", 4, 28663},
	{"OMAL", 4, 28664},
	{"DBYC", 4, 28665},
	{"MURPHY", 6, 28666},
	{"THINKS", 6, 28667},
	{"THATS", 5, 28668},
	{"HDTV", 4, 28669},
	{"PHILLIPS", 8, 28670},
	{"VENTURE", 7, 28671},
	{"AIMED", 5, 28672},
	{"JUSTIN", 6, 28673},
	{"TWOD", 4, 28674},
	{"FIGHTING", 8, 28675},
	{"MIRRORS", 7, 28676},
	{"ASDO", 4, 28677},
	{"HEADLINE", 8, 28678},
	{"RUNNING", 7, 28679},
	{"SPOTLIGHT", 9, 28680},
	{"TRICKS", 6, 28681},
	{"TFOU", 4, 28682},
	{"RESET", 5, 28683},
	{"UGLY", 4, 28684},
	{"FREQUENT", 8, 28685},
	{"IALR", 4, 28686},
	{"EXPANSYS", 8, 28687},
	{"PANELS", 6, 28688},
	{"REPEATED", 8, 28689},
	{"EXJ", 3, 28690},
	{"TMAT", 4, 28691},
	{"TCHT", 4, 28692},
	{"YMPI", 4, 28693},
	{"FITNESS", 7, 28694},
	{"LAP", 3, 28695},
	{"CONNECTING", 10, 28696},
	{"THMO", 4, 28697},
	{"BLEP", 4, 28698},
	{"LOGISTICS", 9, 28699},
	{"ANTP", 4, 28700},
	{"KODAK", 5, 28701},
	{"YTOC", 4, 28702},
	{"ATAP", 4, 28703},
	{"EADL", 4, 28704},
	{"CARRIER", 7, 28705},
	{"LSEA", 4, 28706},
	{"CONSENSUS", 9, 28707},
	{"BOWLING", 7, 28708},
	{"RLDC", 4, 28709},
	{"NSFR", 4, 28710},
	{"NGMI", 4, 28711},
	{"GQI", 3, 28712},
	{"DFRE", 4, 28713},
	{"IZET", 4, 28714},
	{"EDTW", 4, 28715},
	{"INTENSITY", 9, 28716},
	{"OFSC", 4, 28717},
	{"DANISH", 6, 28718},
	{"PAL", 3, 28719},
	{"ANTF", 4, 28720},
	{"GHIT", 4, 28721},
	{"SSPR", 4, 28722},
	{"HEKN", 4, 28723},
	{"HISV", 4, 28724},
	{"FILENAME", 8, 28725},
	{"FLORENCE", 8, 28726},
	{"AYLO", 4, 28727},
	{"DEFENDANT", 9, 28728},
	{"ATTRIBUTE", 9, 28729},
	{"ANALYSES", 8, 28730},
	{"RELATED", 7, 28731},
	{"DRAWINGS", 8, 28732},
	{"LEDH", 4, 28733},
	{"HSOM", 4, 28734},
	{"OUVE", 4, 28735},
	{"FTIN", 4, 28736},
	{"MODERATE", 8, 28737},
	{"YLB", 3, 28738},
	{"GHAS", 4, 28739},
	{"BALLOT", 6, 28740},
	{"WORRIED", 7, 28741},
	{"SOCCER", 6, 28742},
	{"LOVERS", 6, 28743},
	{"ATOMIC", 6, 28744},
	{"COUCH", 5, 28745},
	{"APPROX", 6, 28746},
	{"SYMPOSIUM", 9, 28747},
	{"ARABIC", 6, 28748},
	{"LUNG", 4, 28749},
	{"OWZ", 3, 28750},
	{"GAUGE", 5, 28751},
	{"ESSENTIALS", 10, 28752},
	{"PORTRAY", 7, 28753},
	{"JUNCTION", 8, 28754},
	{"NTAB", 4, 28755},
	{"PROTECTING", 10, 28756},
	{"GHTM", 4, 28757},
	{"FACED", 5, 28758},
	{"NWOU", 4, 28759},
	{"RACHEL", 6, 28760},
	{"SHORE", 5, 28761},
	{"RERA", 4, 28762},
	{"SOLVING", 7, 28763},
	{"TRANSMITTED", 11, 28764},
	{"OFSI", 4, 28765},
	{"NGUI", 4, 28766},
	{"ALWO", 4, 28767},
	{"PHYSICS", 7, 28768},
	{"WEEKENDS", 8, 28769},
	{"SCREENSHOTS", 11, 28770},
	{"SBEG", 4, 28771},
	{"PRODUCES", 8, 28772},
	{"LKED", 4, 28773},
	{"SWEAR", 5, 28774},
	{"XCHA", 4, 28775},
	{"INTENSIVE", 9, 28776},
	{"CHAINS", 6, 28777},
	{"KINGSTON", 8, 28778},
	{"ESPL", 4, 28779},
	{"NTGE", 4, 28780},
	{"DEVIANT", 7, 28781},
	{"CEHA", 4, 28782},
	{"SWITCHING", 9, 28783},
	{"QUOTED", 6, 28784},
	{"ADAPTERS", 8, 28785},
	{"PRESCRIPTION", 12, 28786},
	{"CORRESPONDENCE", 14, 28787},
	{"NONETHELESS", 11, 28788},
	{"THFO", 4, 28789},
	{"NEXC", 4, 28790},
	{"NDEE", 4, 28791},
	{"FARMS", 5, 28792},
	{"COLLAPSE", 8, 28793},
	{"EFAR", 4, 28794},
	{"AYSW", 4, 28795},
	{"IMPORTS", 7, 28796},
	{"DFIR", 4, 28797},
	{"SUPERVISION", 11, 28798},
	{"EXPENDITURES", 12, 28799},
	{"OALI", 4, 28800},
	{"UREL", 4, 28801},
	{"PATCH", 5, 28802},
	{"SANDY", 5, 28803},
	{"LKV", 3, 28804},
	{"PAINTER", 7, 28805},
	{"ALSP", 4, 28806},
	{"DEAR", 4, 28807},
	{"LLYL", 4, 28808},
	{"BORROW", 6, 28809},
	{"UTRE", 4, 28810},
	{"HOMELESS", 8, 28811},
	{"CELEBRITIES", 11, 28812},
	{"VEPR", 4, 28813},
	{"TWOW", 4, 28814},
	{"BUTF", 4, 28815},
	{"MACRO", 5, 28816},
	{"SENDER", 6, 28817},
	{"TODR", 4, 28818},
	{"AYNO", 4, 28819},
	{"MANDATORY", 9, 28820},
	{"BOUNDARIES", 10, 28821},
	{"IRFI", 4, 28822},
	{"AWIT", 4, 28823},
	{"INQUIRY", 7, 28824},
	{"HADP", 4, 28825},
	{"VEDB", 4, 28826},
	{"SYNDICATION", 11, 28827},
	{"ROSP", 4, 28828},
	{"KDE", 3, 28829},
	{"ADJACENT", 8, 28830},
	{"NEYA", 4, 28831},
	{"QUESTIONNAIRE", 13, 28832},
	{"FILTERING", 9, 28833},
	{"ANYE", 4, 28834},
	{"AFRICAN-AMERICAN", 16, 28835},
	{"SECONDARY", 9, 28836},
	{"TUITION", 7, 28837},
	{"HIGHLIGHT", 9, 28838},
	{"SIGNUP", 6, 28839},
	{"SZC", 3, 28840},
	{"NTEG", 4, 28841},
	{"OCCUPATION", 10, 28842},
	{"ELLW", 4, 28843},
	{"AGIC", 4, 28844},
	{"VIRTUE", 6, 28845},
	{"THREATS", 7, 28846},
	{"LUXEMBOURG", 10, 28847},
	{"KILLING", 7, 28848},
	{"PUZZLES", 7, 28849},
	{"PTAI", 4, 28850},
	{"TESF", 4, 28851},
	{"SEIZE", 5, 28852},
	{"ODOF", 4, 28853},
	{"NSUC", 4, 28854},
	{"EEPT", 4, 28855},
	{"FLOUR", 5, 28856},
	{"NYWA", 4, 28857},
	{"DERL", 4, 28858},
	{"YTOD", 4, 28859},
	{"YSHA", 4, 28860},
	{"WISE", 4, 28861},
	{"IMPRESSIVE", 10, 28862},
	{"LYLO", 4, 28863},
	{"EAKS", 4, 28864},
	{"REACHING", 8, 28865},
	{"ODDS", 4, 28866},
	{"NDTW", 4, 28867},
	{"YSEL", 4, 28868},
	{"DAMAGED", 7, 28869},
	{"REXP", 4, 28870},
	{"CAMS", 4, 28871},
	{"CAPTAIN", 7, 28872},
	{"EYTH", 4, 28873},
	{"RECEPTOR", 8, 28874},
	{"THAB", 4, 28875},
	{"PISS", 4, 28876},
	{"ZUZ", 3, 28877},
	{"TIPL", 4, 28878},
	{"NWAR", 4, 28879},
	{"UREC", 4, 28880},
	{"SOFG", 4, 28881},
	{"AHOM", 4, 28882},
	{"TSDE", 4, 28883},
	{"TSAB", 4, 28884},
	{"JOEL", 4, 28885},
	{"SLAM", 4, 28886},
	{"SURGICAL", 8, 28887},
	{"CITATION", 8, 28888},
	{"YOJ", 3, 28889},
	{"RALR", 4, 28890},
	{"YBOD", 4, 28891},
	{"BRICK", 5, 28892},
	{"XIW", 3, 28893},
	{"OOFT", 4, 28894},
	{"EVERYDAY", 8, 28895},
	{"REDM", 4, 28896},
	{"AUTOS", 5, 28897},
	{"EPHE", 4, 28898},
	{"INTEGRATE", 9, 28899},
	{"UTOR", 4, 28900},
	{"REPEATEDLY", 10, 28901},
	{"NSMI", 4, 28902},
	{"EXTT", 4, 28903},
	{"EPUR", 4, 28904},
	{"CHANGING", 8, 28905},
	{"USLI", 4, 28906},
	{"NYOT", 4, 28907},
	{"CHARITY", 7, 28908},
	{"PREMISES", 8, 28909},
	{"PERRY", 5, 28910},
	{"PROVED", 6, 28911},
	{"RTOA", 4, 28912},
	{"OFAG", 4, 28913},
	{"ZSU", 3, 28914},
	{"OSUP", 4, 28915},
	{"IMPERIAL", 8, 28916},
	{"EWOM", 4, 28917},
	{"RTOP", 4, 28918},
	{"BENJAMIN", 8, 28919},
	{"DEPLOYMENT", 10, 28920},
	{"ESBA", 4, 28921},
	{"PHYSICALLY", 10, 28922},
	{"TEETH", 5, 28923},
	{"KHY", 3, 28924},
	{"OROT", 4, 28925},
	{"ALHO", 4, 28926},
	{"DARE", 4, 28927},
	{"RRIT", 4, 28928},
	{"STUDYING", 8, 28929},
	{"COLLEAGUES", 10, 28930},
	{"STAMP", 5, 28931},
	{"RECRUIT", 7, 28932},
	{"LOTUS", 5, 28933},
	{"TUNNEL", 6, 28934},
	{"OLYMPUS", 7, 28935},
	{"SEPARATED", 9, 28936},
	{"OFVI", 4, 28937},
	{"EJOB", 4, 28938},
	{"LAUGHTER", 8, 28939},
	{"EXPERIMENTAL", 12, 28940},
	{"LBEC", 4, 28941},
	{"SACRED", 6, 28942},
	{"ETHICAL", 7, 28943},
	{"PROC", 4, 28944},
	{"GROCERY", 7, 28945},
	{"ELYO", 4, 28946},
	{"AYAR", 4, 28947},
	{"ADMIRE", 6, 28948},
	{"ZETH", 4, 28949},
	{"DIRECTIVE", 9, 28950},
	{"ISVE", 4, 28951},
	{"EYMA", 4, 28952},
	{"EXPORT", 6, 28953},
	{"EOWN", 4, 28954},
	{"RHYTHM", 6, 28955},
	{"NEYT", 4, 28956},
	{"YSEE", 4, 28957},
	{"TOAM", 4, 28958},
	{"SALEM", 5, 28959},
	{"FRUSTRATION", 11, 28960},
	{"YTOO", 4, 28961},
	{"UPGRADES", 8, 28962},
	{"PERSUADE", 8, 28963},
	{"LIKES", 5, 28964},
	{"INEP", 4, 28965},
	{"MODIFY", 6, 28966},
	{"CONTINUOUS", 10, 28967},
	{"TDES", 4, 28968},
	{"MARGIN", 6, 28969},
	{"LUGGAGE", 7, 28970},
	{"ORFI", 4, 28971},
	{"TACTIC", 6, 28972},
	{"MEDAL", 5, 28973},
	{"TAPES", 5, 28974},
	{"MFRO", 4, 28975},
	{"ZONES", 5, 28976},
	{"ROSE", 4, 28977},
	{"ZLY", 3, 28978},
	{"AXG", 3, 28979},
	{"EENL", 4, 28980},
	{"REEI", 4, 28981},
	{"ISLE", 4, 28982},
	{"SHINE", 5, 28983},
	{"YSOM", 4, 28984},
	{"MIRACLE", 7, 28985},
	{"TALT", 4, 28986},
	{"CHASE", 5, 28987},
	{"STYLISH", 7, 28988},
	{"SLIM", 4, 28989},
	{"MAPLE", 5, 28990},
	{"LUKE", 4, 28991},
	{"ARCHITECT", 9, 28992},
	{"GWHI", 4, 28993},
	{"LTOT", 4, 28994},
	{"SQB", 3, 28995},
	{"PIANO", 5, 28996},
	{"RSUP", 4, 28997},
	{"ULDD", 4, 28998},
	{"FORMULA", 7, 28999},
	{"GALLERY", 7, 29000},
	{"STEM", 4, 29001},
	{"OFFSHORE", 8, 29002},
	{"GOVERNING", 9, 29003},
	{"CEIT", 4, 29004},
	{"RETAILERS", 9, 29005},
	{"DEPOT", 5, 29006},
	{"ROML", 4, 29007},
	{"DEDS", 4, 29008},
	{"OOLO", 4, 29009},
	{"ODAT", 4, 29010},
	{"KENNETH", 7, 29011},
	{"CONTAINER", 9, 29012},
	{"YLP", 3, 29013},
	{"COMP", 4, 29014},
	{"HARRISON", 8, 29015},
	{"SAKE", 4, 29016},
	{"EDWO", 4, 29017},
	{"BEUS", 4, 29018},
	{"EYIN", 4, 29019},
	{"JULIE", 5, 29020},
	{"TSEV", 4, 29021},
	{"ALLIANCE", 8, 29022},
	{"CBS", 3, 29023},
	{"DINW", 4, 29024},
	{"ATTENDING", 9, 29025},
	{"FACILITATE", 10, 29026},
	{"PETE", 4, 29027},
	{"PREGNANCY", 9, 29028},
	{"SPEC", 4, 29029},
	{"BARE", 4, 29030},
	{"FINEST", 6, 29031},
	{"XUB", 3, 29032},
	{"REALTY", 6, 29033},
	{"PROSECUTION", 11, 29034},
	{"JANET", 5, 29035},
	{"IMEF", 4, 29036},
	{"YCOL", 4, 29037},
	{"ROMN", 4, 29038},
	{"YREL", 4, 29039},
	{"IBLY", 4, 29040},
	{"NMAK", 4, 29041},
	{"PENN", 4, 29042},
	{"RECRUITING", 10, 29043},
	{"LLAP", 4, 29044},
	{"RSDE", 4, 29045},
	{"RFAM", 4, 29046},
	{"FFAI", 4, 29047},
	{"LCAN", 4, 29048},
	{"ROFP", 4, 29049},
	{"NGEV", 4, 29050},
	{"COAL", 4, 29051},
	{"ODIF", 4, 29052},
	{"PHPBB", 5, 29053},
	{"AUTUMN", 6, 29054},
	{"LDTO", 4, 29055},
	{"SCRIPT", 6, 29056},
	{"ELTO", 4, 29057},
	{"TRAVELING", 9, 29058},
	{"FKY", 3, 29059},
	{"ZCL", 3, 29060},
	{"PROBE", 5, 29061},
	{"MIDI", 4, 29062},
	{"OCOU", 4, 29063},
	{"MAKEUP", 6, 29064},
	{"ONDR", 4, 29065},
	{"EANW", 4, 29066},
	{"PTOT", 4, 29067},
	{"PERMISSIONS", 11, 29068},
	{"UTWA", 4, 29069},
	{"OODE", 4, 29070},
	{"BIOTECHNOLOGY", 13, 29071},
	{"BYMA", 4, 29072},
	{"DSAY", 4, 29073},
	{"NDJU", 4, 29074},
	{"EDTR", 4, 29075},
	{"OCAN", 4, 29076},
	{"ERYI", 4, 29077},
	{"RANKED", 6, 29078},
	{"JACKETS", 7, 29079},
	{"ADMINISTRATIVE", 14, 29080},
	{"ROUTES", 6, 29081},
	{"LIGHTLY", 7, 29082},
	{"PACKED", 6, 29083},
	{"EFFECTIVENESS", 13, 29084},
	{"SELY", 4, 29085},
	{"SMAT", 4, 29086},
	{"TOIM", 4, 29087},
	{"LBET", 4, 29088},
	{"NKOF", 4, 29089},
	{"YGY", 3, 29090},
	{"RGUE", 4, 29091},
	{"RITUAL", 6, 29092},
	{"RECEIVER", 8, 29093},
	{"GNIN", 4, 29094},
	{"OUTREACH", 8, 29095},
	{"GHWA", 4, 29096},
	{"HELEN", 5, 29097},
	{"MOUNTING", 8, 29098},
	{"HORROR", 6, 29099},
	{"TIED", 4, 29100},
	{"LOPEZ", 5, 29101},
	{"NPEO", 4, 29102},
	{"PRESCRIBED", 10, 29103},
	{"CONCRETE", 8, 29104},
	{"ACCEPTANCE", 10, 29105},
	{"CATHERINE", 9, 29106},
	{"FYL", 3, 29107},
	{"GRAVE", 5, 29108},
	{"RESIGN", 6, 29109},
	{"RECORDING", 9, 29110},
	{"COMPOSE", 7, 29111},
	{"OMHE", 4, 29112},
	{"TIMELY", 6, 29113},
	{"LDLI", 4, 29114},
	{"TALKED", 6, 29115},
	{"DEBUG", 5, 29116},
	{"DELAYED", 7, 29117},
	{"SALMON", 6, 29118},
	{"GTOM", 4, 29119},
	{"RSSA", 4, 29120},
	{"NHEL", 4, 29121},
	{"AMTO", 4, 29122},
	{"REOR", 4, 29123},
	{"CHUCK", 5, 29124},
	{"ZEJ", 3, 29125},
	{"REGULATE", 8, 29126},
	{"CEAG", 4, 29127},
	{"YOFM", 4, 29128},
	{"OLEI", 4, 29129},
	{"REPRODUCED", 10, 29130},
	{"TOBO", 4, 29131},
	{"JEANS", 5, 29132},
	{"DALE", 4, 29133},
	{"LSHE", 4, 29134},
	{"OWSH", 4, 29135},
	{"ULTT", 4, 29136},
	{"BYCO", 4, 29137},
	{"OPHO", 4, 29138},
	{"INTEGRATION", 11, 29139},
	{"LWHI", 4, 29140},
	{"VILLAS", 6, 29141},
	{"CORRIDOR", 8, 29142},
	{"EBOOK", 5, 29143},
	{"CONSOLIDATED", 12, 29144},
	{"BOOB", 4, 29145},
	{"PEEING", 6, 29146},
	{"OFBU", 4, 29147},
	{"PITCHER", 7, 29148},
	{"OCCASIONS", 9, 29149},
	{"BROOKS", 6, 29150},
	{"ISBU", 4, 29151},
	{"EQUATIONS", 9, 29152},
	{"RAIL", 4, 29153},
	{"NEWTON", 6, 29154},
	{"OILS", 4, 29155},
	{"SEPT", 4, 29156},
	{"EXCEPTIONAL", 11, 29157},
	{"BINGO", 5, 29158},
	{"WHILST", 6, 29159},
	{"SPATIAL", 7, 29160},
	{"ORAF", 4, 29161},
	{"SELI", 4, 29162},
	{"ACKF", 4, 29163},
	{"RESPONDENTS", 11, 29164},
	{"UNTO", 4, 29165},
	{"NITW", 4, 29166},
	{"CERAMIC", 7, 29167},
	{"OURR", 4, 29168},
	{"FLASH", 5, 29169},
	{"MINDS", 5, 29170},
	{"INSECT", 6, 29171},
	{"PRESIDENCY", 10, 29172},
	{"INIM", 4, 29173},
	{"HUNT", 4, 29174},
	{"RECESSION", 9, 29175},
	{"CONSIDERATIONS", 14, 29176},
	{"LPER", 4, 29177},
	{"YITS", 4, 29178},
	{"SREV", 4, 29179},
	{"SCANNERS", 8, 29180},
	{"SEPR", 4, 29181},
	{"RESW", 4, 29182},
	{"PLAYOFF", 7, 29183},
	{"HASF", 4, 29184},
	{"LTOF", 4, 29185},
	{"NDNA", 4, 29186},
	{"INMY", 4, 29187},
	{"XANAX", 5, 29188},
	{"EAMW", 4, 29189},
	{"PAYS", 4, 29190},
	{"COX", 3, 29191},
	{"ABROAD", 6, 29192},
	{"IABL", 4, 29193},
	{"ALLD", 4, 29194},
	{"TRADING", 7, 29195},
	{"FINGERS", 7, 29196},
	{"ONAD", 4, 29197},
	{"INDIGENOUS", 10, 29198},
	{"ONUN", 4, 29199},
	{"EBOOKS", 6, 29200},
	{"DELIVERS", 8, 29201},
	{"SRUN", 4, 29202},
	{"QUEENSLAND", 10, 29203},
	{"NECKLACE", 8, 29204},
	{"EXCLUDE", 7, 29205},
	{"MUSICIANS", 9, 29206},
	{"NGOT", 4, 29207},
	{"LEEDS", 5, 29208},
	{"OEVE", 4, 29209},
	{"LDAL", 4, 29210},
	{"COMPOSITE", 9, 29211},
	{"WNFO", 4, 29212},
	{"AGEB", 4, 29213},
	{"NGCL", 4, 29214},
	{"UNAVAILABLE", 11, 29215},
	{"CEDAR", 5, 29216},
	{"ARRANGED", 8, 29217},
	{"LANG", 4, 29218},
	{"BUTL", 4, 29219},
	{"NGGR", 4, 29220},
	{"THEATERS", 8, 29221},
	{"EOFG", 4, 29222},
	{"ONGL", 4, 29223},
	{"ADVOCACY", 8, 29224},
	{"STFR", 4, 29225},
	{"RALEIGH", 7, 29226},
	{"STUD", 4, 29227},
	{"GENTLE", 6, 29228},
	{"IDSH", 4, 29229},
	{"IDOF", 4, 29230},
	{"IXK", 3, 29231},
	{"DESIGNING", 9, 29232},
	{"THREADED", 8, 29233},
	{"YNEE", 4, 29234},
	{"USON", 4, 29235},
	{"ETYP", 4, 29236},
	{"AIND", 4, 29237},
	{"YFOU", 4, 29238},
	{"INTERRUPT", 9, 29239},
	{"BOYFRIEND", 9, 29240},
	{"ISLAM", 5, 29241},
	{"LPRE", 4, 29242},
	{"UEEN", 4, 29243},
	{"RNST", 4, 29244},
	{"BLAIR", 5, 29245},
	{"EVIDENT", 7, 29246},
	{"HOPES", 5, 29247},
	{"ASSESSMENTS", 11, 29248},
	{"CMS", 3, 29249},
	{"MASON", 5, 29250},
	{"YDIF", 4, 29251},
	{"CONFUSION", 9, 29252},
	{"DIAGRAM", 7, 29253},
	{"BURNS", 5, 29254},
	{"TTOL", 4, 29255},
	{"PUMPS", 5, 29256},
	{"YEDI", 4, 29257},
	{"RRAT", 4, 29258},
	{"MESS", 4, 29259},
	{"FOOTWEAR", 8, 29260},
	{"STLO", 4, 29261},
	{"VIC", 3, 29262},
	{"MPUS", 4, 29263},
	{"BEIJING", 7, 29264},
	{"OFSH", 4, 29265},
	{"PEOPLES", 7, 29266},
	{"VICTOR", 6, 29267},
	{"OFWI", 4, 29268},
	{"TALW", 4, 29269},
	{"MARIO", 5, 29270},
	{"IZR", 3, 29271},
	{"LWHE", 4, 29272},
	{"CCUP", 4, 29273},
	{"LICENSES", 8, 29274},
	{"CLUE", 4, 29275},
	{"UTILS", 5, 29276},
	{"REMOVING", 8, 29277},
	{"ADVISED", 7, 29278},
	{"BRUNSWICK", 9, 29279},
	{"SPIDER", 6, 29280},
	{"UESA", 4, 29281},
	{"PHYS", 4, 29282},
	{"RANGES", 6, 29283},
	{"PAIRS", 5, 29284},
	{"ACCEPTABLE", 10, 29285},
	{"HURRY", 5, 29286},
	{"EXCUSE", 6, 29287},
	{"TRAILS", 6, 29288},
	{"PRESERVATION", 12, 29289},
	{"COURAGE", 7, 29290},
	{"HUDSON", 6, 29291},
	{"NTEM", 4, 29292},
	{"HALLWAY", 7, 29293},
	{"INDICATION", 10, 29294},
	{"DRAMATICALLY", 12, 29295},
	{"CALGARY", 7, 29296},
	{"TSUC", 4, 29297},
	{"INTERIM", 7, 29298},
	{"ASSISTED", 8, 29299},
	{"STREAMING", 9, 29300},
	{"IPME", 4, 29301},
	{"SURPRISINGLY", 12, 29302},
	{"EDBO", 4, 29303},
	{"CHOSE", 5, 29304},
	{"SYNDICATE", 9, 29305},
	{"ERYP", 4, 29306},
	{"EARH", 4, 29307},
	{"EINB", 4, 29308},
	{"DIALOG", 6, 29309},
	{"HADM", 4, 29310},
	{"UESS", 4, 29311},
	{"HISPANIC", 8, 29312},
	{"WERI", 4, 29313},
	{"NTGO", 4, 29314},
	{"OXIM", 4, 29315},
	{"OFDO", 4, 29316},
	{"VENUES", 6, 29317},
	{"UTYO", 4, 29318},
	{"NGGO", 4, 29319},
	{"IEDB", 4, 29320},
	{"RYHA", 4, 29321},
	{"EGOA", 4, 29322},
	{"ZKE", 3, 29323},
	{"WELLNESS", 8, 29324},
	{"CALCIUM", 7, 29325},
	{"NFEB", 4, 29326},
	{"ELDT", 4, 29327},
	{"NEWPORT", 7, 29328},
	{"VENB", 4, 29329},
	{"ANTIVIRUS", 9, 29330},
	{"ANNIVERSARY", 11, 29331},
	{"GTHO", 4, 29332},
	{"COMBAT", 6, 29333},
	{"ALLEGATION", 10, 29334},
	{"ADDRESSING", 10, 29335},
	{"DISCOUNTED", 10, 29336},
	{"RNTH", 4, 29337},
	{"INDIANS", 7, 29338},
	{"SHIELD", 6, 29339},
	{"RVIS", 4, 29340},
	{"DEVELOPER", 9, 29341},
	{"ALHE", 4, 29342},
	{"ODOW", 4, 29343},
	{"HENM", 4, 29344},
	{"MEMBRANE", 8, 29345},
	{"PRAGUE", 6, 29346},
	{"PREVIEWS", 8, 29347},
	{"BANGLADESH", 10, 29348},
	{"REWARD", 6, 29349},
	{"NOTL", 4, 29350},
	{"LEGEND", 6, 29351},
	{"RSWO", 4, 29352},
	{"SCULPTURE", 9, 29353},
	{"INIC", 4, 29354},
	{"RSPR", 4, 29355},
	{"ISTW", 4, 29356},
	{"LOCALLY", 7, 29357},
	{"CONCLUDED", 9, 29358},
	{"INSPECTOR", 9, 29359},
	{"AYHE", 4, 29360},
	{"REAF", 4, 29361},
	{"NORTHWEST", 9, 29362},
	{"ATPO", 4, 29363},
	{"INWE", 4, 29364},
	{"MOTHERS", 7, 29365},
	{"NASCAR", 6, 29366},
	{"GREATLY", 7, 29367},
	{"ICELAND", 7, 29368},
	{"LOGIC", 5, 29369},
	{"GOVERNMENTAL", 12, 29370},
	{"MANUFACTURED", 12, 29371},
	{"CANDLES", 7, 29372},
	{"ESMI", 4, 29373},
	{"MEGA", 4, 29374},
	{"RBEI", 4, 29375},
	{"EXACT", 5, 29376},
	{"DOMAIN", 6, 29377},
	{"SAILING", 7, 29378},
	{"DGRE", 4, 29379},
	{"BISHOP", 6, 29380},
	{"EJD", 3, 29381},
	{"LSHO", 4, 29382},
	{"TYZ", 3, 29383},
	{"TORW", 4, 29384},
	{"VARIATIONS", 10, 29385},
	{"CANDY", 5, 29386},
	{"AUNI", 4, 29387},
	{"MOMS", 4, 29388},
	{"SUPERIOR", 8, 29389},
	{"OLDH", 4, 29390},
	{"ADDICTION", 9, 29391},
	{"MOROCCO", 7, 29392},
	{"FOLD", 4, 29393},
	{"INITIATE", 8, 29394},
	{"HWAY", 4, 29395},
	{"CHROME", 6, 29396},
	{"TGOI", 4, 29397},
	{"OODW", 4, 29398},
	{"TOMMY", 5, 29399},
	{"MMAT", 4, 29400},
	{"EASW", 4, 29401},
	{"YIND", 4, 29402},
	{"SPRINGFIELD", 11, 29403},
	{"REFUSED", 7, 29404},
	{"LLAC", 4, 29405},
	{"TEDU", 4, 29406},
	{"RHOO", 4, 29407},
	{"EXTERIOR", 8, 29408},
	{"FRANKLY", 7, 29409},
	{"ACEB", 4, 29410},
	{"GREETING", 8, 29411},
	{"ACEM", 4, 29412},
	{"NBRI", 4, 29413},
	{"ASOL", 4, 29414},
	{"AYWH", 4, 29415},
	{"PUMP", 4, 29416},
	{"ECOLOGY", 7, 29417},
	{"ENIF", 4, 29418},
	{"TESP", 4, 29419},
	{"OLIVER", 6, 29420},
	{"EBUR", 4, 29421},
	{"LEDU", 4, 29422},
	{"LLOR", 4, 29423},
	{"CONGO", 5, 29424},
	{"GLEN", 4, 29425},
	{"OPUT", 4, 29426},
	{"BOTSWANA", 8, 29427},
	{"YEDT", 4, 29428},
	{"LOG", 3, 29429},
	{"HOSTAGE", 7, 29430},
	{"DELAYS", 6, 29431},
	{"SYNTHESIS", 9, 29432},
	{"NDTI", 4, 29433},
	{"OLIVE", 5, 29434},
	{"DITH", 4, 29435},
	{"RETAIL", 6, 29436},
	{"YCHO", 4, 29437},
	{"RICU", 4, 29438},
	{"NDMU", 4, 29439},
	{"UNDEFINED", 9, 29440},
	{"CLOSET", 6, 29441},
	{"ORGAN", 5, 29442},
	{"HASW", 4, 29443},
	{"EYDI", 4, 29444},
	{"HIPA", 4, 29445},
	{"CYBER", 5, 29446},
	{"NOFM", 4, 29447},
	{"VERIZON", 7, 29448},
	{"RTOB", 4, 29449},
	{"EAMM", 4, 29450},
	{"USTL", 4, 29451},
	{"SCORED", 6, 29452},
	{"ENHANCEMENT", 11, 29453},
	{"GNIZ", 4, 29454},
	{"EARF", 4, 29455},
	{"NEWCASTLE", 9, 29456},
	{"CLONE", 5, 29457},
	{"DWAY", 4, 29458},
	{"DDEC", 4, 29459},
	{"DICKS", 5, 29460},
	{"VELOCITY", 8, 29461},
	{"LAMBDA", 6, 29462},
	{"SWALLOW", 7, 29463},
	{"NHIG", 4, 29464},
	{"RELAY", 5, 29465},
	{"COMPOSED", 8, 29466},
	{"TEARS", 5, 29467},
	{"PLEH", 4, 29468},
	{"NVIT", 4, 29469},
	{"PERFORMANCES", 12, 29470},
	{"EPIT", 4, 29471},
	{"OASIS", 5, 29472},
	{"BASELINE", 8, 29473},
	{"IGHW", 4, 29474},
	{"COMPOUND", 8, 29475},
	{"SLOPE", 5, 29476},
	{"UPSET", 5, 29477},
	{"LLCA", 4, 29478},
	{"ENFR", 4, 29479},
	{"SOCIETIES", 9, 29480},
	{"SILICON", 7, 29481},
	{"ICTH", 4, 29482},
	{"BRAZILIAN", 9, 29483},
	{"LERO", 4, 29484},
	{"NOFP", 4, 29485},
	{"OMOV", 4, 29486},
	{"GNOR", 4, 29487},
	{"SWON", 4, 29488},
	{"PETROLEUM", 9, 29489},
	{"ZJO", 3, 29490},
	{"TYWI", 4, 29491},
	{"NORWEGIAN", 9, 29492},
	{"BEG", 3, 29493},
	{"SPONSOR", 7, 29494},
	{"HONOLULU", 8, 29495},
	{"YCAL", 4, 29496},
	{"BEATLES", 7, 29497},
	{"ODTH", 4, 29498},
	{"ONSL", 4, 29499},
	{"ICOU", 4, 29500},
	{"PILL", 4, 29501},
	{"ELBOW", 5, 29502},
	{"LIPS", 4, 29503},
	{"YDJ", 3, 29504},
	{"ALEL", 4, 29505},
	{"ESCORT", 6, 29506},
	{"RETENTION", 9, 29507},
	{"MELT", 4, 29508},
	{"YHER", 4, 29509},
	{"EXCHANGES", 9, 29510},
	{"OODO", 4, 29511},
	{"ROLLS", 5, 29512},
	{"THOMSON", 7, 29513},
	{"ADIU", 4, 29514},
	{"BARNES", 6, 29515},
	{"LYTR", 4, 29516},
	{"SOUNDTRACK", 10, 29517},
	{"WONDERING", 9, 29518},
	{"SNAKE", 5, 29519},
	{"TICC", 4, 29520},
	{"MALTA", 5, 29521},
	{"DADDY", 5, 29522},
	{"SFOL", 4, 29523},
	{"SURGEON", 7, 29524},
	{"ROPH", 4, 29525},
	{"LPIN", 4, 29526},
	{"FERRY", 5, 29527},
	{"SEATING", 7, 29528},
	{"ADEO", 4, 29529},
	{"UEAN", 4, 29530},
	{"IGIT", 4, 29531},
	{"MANR", 4, 29532},
	{"SEPARATELY", 10, 29533},
	{"NGDA", 4, 29534},
	{"PHYSIOLOGY", 10, 29535},
	{"LIL", 3, 29536},
	{"COLLECTING", 10, 29537},
	{"MAGIC", 5, 29538},
	{"EXPORTS", 7, 29539},
	{"OMAHA", 5, 29540},
	{"PLEASED", 7, 29541},
	{"SCHOLARSHIPS", 12, 29542},
	{"RYBO", 4, 29543},
	{"RDSI", 4, 29544},
	{"RECREATIONAL", 12, 29545},
	{"RHAV", 4, 29546},
	{"DOMINICAN", 9, 29547},
	{"EFAN", 4, 29548},
	{"EXCITED", 7, 29549},
	{"ANEV", 4, 29550},
	{"RSPO", 4, 29551},
	{"CHAD", 4, 29552},
	{"ASOU", 4, 29553},
	{"ELECTRON", 8, 29554},
	{"LOADS", 5, 29555},
	{"IDEOLOGY", 8, 29556},
	{"ONRO", 4, 29557},
	{"HEATHER", 7, 29558},
	{"PASSPORT", 8, 29559},
	{"MOTEL", 5, 29560},
	{"AND/OR", 6, 29561},
	{"NGEI", 4, 29562},
	{"UNIONS", 6, 29563},
	{"TREASURY", 8, 29564},
	{"WARRANT", 7, 29565},
	{"SOLARIS", 7, 29566},
	{"OCCUPIED", 8, 29567},
	{"ECHO", 4, 29568},
	{"JOSH", 4, 29569},
	{"ROYALTY", 7, 29570},
	{"CLASSICAL", 9, 29571},
	{"ERCR", 4, 29572},
	{"SCALES", 6, 29573},
	{"UNEMPLOYMENT", 12, 29574},
	{"HENCE", 5, 29575},
	{"LVY", 3, 29576},
	{"STSW", 4, 29577},
	{"SUNSHINE", 8, 29578},
	{"DTEA", 4, 29579},
	{"OYME", 4, 29580},
	{"ESTIMATED", 9, 29581},
	{"URTO", 4, 29582},
	{"VENW", 4, 29583},
	{"INTEGRITY", 9, 29584},
	{"SUBURBAN", 8, 29585},
	{"ONPE", 4, 29586},
	{"ARRESTED", 8, 29587},
	{"EXPANDING", 9, 29588},
	{"INVENT", 6, 29589},
	{"EFLA", 4, 29590},
	{"PROVINCIAL", 10, 29591},
	{"RDWA", 4, 29592},
	{"YMAK", 4, 29593},
	{"INVESTIGATIONS", 14, 29594},
	{"DIAGNOSIS", 9, 29595},
	{"ATEU", 4, 29596},
	{"REMARK", 6, 29597},
	{"ICQ", 3, 29598},
	{"NFLA", 4, 29599},
	{"TTOF", 4, 29600},
	{"RIPE", 4, 29601},
	{"UCHM", 4, 29602},
	{"ARCHITECTURE", 12, 29603},
	{"YAMAHA", 6, 29604},
	{"HYTH", 4, 29605},
	{"TBYT", 4, 29606},
	{"CIVILIZATION", 12, 29607},
	{"SYCH", 4, 29608},
	{"RENT", 4, 29609},
	{"DRINKING", 8, 29610},
	{"RINF", 4, 29611},
	{"INPL", 4, 29612},
	{"MEDICATIONS", 11, 29613},
	{"SUBTLE", 6, 29614},
	{"HEBREW", 6, 29615},
	{"KOREAN", 6, 29616},
	{"MIDNIGHT", 8, 29617},
	{"GAINED", 6, 29618},
	{"ROCHESTER", 9, 29619},
	{"LONGTIME", 8, 29620},
	{"STUCK", 5, 29621},
	{"ELPI", 4, 29622},
	{"TLYB", 4, 29623},
	{"SOLOMON", 7, 29624},
	{"PLACING", 7, 29625},
	{"STOPS", 5, 29626},
	{"SORD", 4, 29627},
	{"ASSESSED", 8, 29628},
	{"ROMF", 4, 29629},
	{"YWEL", 4, 29630},
	{"ADVERTISER", 10, 29631},
	{"THRI", 4, 29632},
	{"LYCH", 4, 29633},
	{"TSGO", 4, 29634},
	{"ENABLING", 8, 29635},
	{"ACUL", 4, 29636},
	{"ENCRYPTION", 10, 29637},
	{"BRAI", 4, 29638},
	{"ERNC", 4, 29639},
	{"FILLING", 7, 29640},
	{"ORMU", 4, 29641},
	{"DOWNLOADABLE", 12, 29642},
	{"EAPR", 4, 29643},
	{"BERW", 4, 29644},
	{"BEEF", 4, 29645},
	{"IMPOSED", 7, 29646},
	{"NGRI", 4, 29647},
	{"SCSI", 4, 29648},
	{"FOCUSES", 7, 29649},
	{"ULLS", 4, 29650},
	{"TOOF", 4, 29651},
	{"NQUE", 4, 29652},
	{"ARYW", 4, 29653},
	{"MZO", 3, 29654},
	{"HASG", 4, 29655},
	{"LABORATORIES", 12, 29656},
	{"OFON", 4, 29657},
	{"NDIE", 4, 29658},
	{"KNY", 3, 29659},
	{"YTOG", 4, 29660},
	{"TRUNK", 5, 29661},
	{"MEMI", 4, 29662},
	{"CURVE", 5, 29663},
	{"STRONGER", 8, 29664},
	{"VOLUMES", 7, 29665},
	{"RFOU", 4, 29666},
	{"NALW", 4, 29667},
	{"BURST", 5, 29668},
	{"UTLE", 4, 29669},
	{"RPEO", 4, 29670},
	{"EVIL", 4, 29671},
	{"RTHS", 4, 29672},
	{"YDES", 4, 29673},
	{"ESSENCE", 7, 29674},
	{"ADVANCES", 8, 29675},
	{"VEGETABLES", 10, 29676},
	{"T-SHIRT", 7, 29677},
	{"LEGISLATIVE", 11, 29678},
	{"THUMBNAILS", 10, 29679},
	{"TWEL", 4, 29680},
	{"ENTITLE", 7, 29681},
	{"PTY", 3, 29682},
	{"YSOF", 4, 29683},
	{"GCHA", 4, 29684},
	{"LEAP", 4, 29685},
	{"DBYP", 4, 29686},
	{"DEDH", 4, 29687},
	{"ODET", 4, 29688},
	{"NUTS", 4, 29689},
	{"OSOF", 4, 29690},
	{"LELI", 4, 29691},
	{"BIZRATE", 7, 29692},
	{"ERSN", 4, 29693},
	{"VIENNA", 6, 29694},
	{"PPON", 4, 29695},
	{"IMPLIED", 7, 29696},
	{"WRITTEN", 7, 29697},
	{"EKIL", 4, 29698},
	{"INTERIOR", 8, 29699},
	{"ESQU", 4, 29700},
	{"YNAM", 4, 29701},
	{"ICKA", 4, 29702},
	{"SPAN", 4, 29703},
	{"RCLA", 4, 29704},
	{"ELYB", 4, 29705},
	{"STANFORD", 8, 29706},
	{"GREET", 5, 29707},
	{"ENDR", 4, 29708},
	{"STOCKINGS", 9, 29709},
	{"ANMI", 4, 29710},
	{"ERCU", 4, 29711},
	{"PACKING", 7, 29712},
	{"EISR", 4, 29713},
	{"LSWI", 4, 29714},
	{"REJECTED", 8, 29715},
	{"DAYM", 4, 29716},
	{"AVEG", 4, 29717},
	{"BITTER", 6, 29718},
	{"OFMY", 4, 29719},
	{"OWNL", 4, 29720},
	{"DESTROYED", 9, 29721},
	{"KESO", 4, 29722},
	{"DRET", 4, 29723},
	{"HEYP", 4, 29724},
	{"CHAPEL", 6, 29725},
	{"TISL", 4, 29726},
	{"CTWI", 4, 29727},
	{"GAMESPOT", 8, 29728},
	{"UTSH", 4, 29729},
	{"MANUFACTURE", 11, 29730},
	{"CKZ", 3, 29731},
	{"TLEF", 4, 29732},
	{"LAYERS", 6, 29733},
	{"WORDPRESS", 9, 29734},
	{"RESTRICT", 8, 29735},
	{"GUIDED", 6, 29736},
	{"TINV", 4, 29737},
	{"VULNERABILITY", 13, 29738},
	{"RTAB", 4, 29739},
	{"EYST", 4, 29740},
	{"MONTHLY", 7, 29741},
	{"DUCK", 4, 29742},
	{"AUJ", 3, 29743},
	{"NLYB", 4, 29744},
	{"LAUG", 4, 29745},
	{"ACCREDITED", 10, 29746},
	{"YTOR", 4, 29747},
	{"APPLIANCE", 9, 29748},
	{"COMPRESSED", 10, 29749},
	{"TTAL", 4, 29750},
	{"BAHAMAS", 7, 29751},
	{"TCHO", 4, 29752},
	{"POWELL", 6, 29753},
	{"ATDI", 4, 29754},
	{"MOTIVATE", 8, 29755},
	{"REFA", 4, 29756},
	{"EDRU", 4, 29757},
	{"RLIA", 4, 29758},
	{"CESF", 4, 29759},
	{"BEHAVIORAL", 10, 29760},
	{"THEORETICAL", 11, 29761},
	{"EEOF", 4, 29762},
	{"OWIL", 4, 29763},
	{"UNIV", 4, 29764},
	{"TUB", 3, 29765},
	{"NTAK", 4, 29766},
	{"LEBU", 4, 29767},
	{"LENS", 4, 29768},
	{"EENV", 4, 29769},
	{"SCHEDULING", 10, 29770},
	{"LSFO", 4, 29771},
	{"DRIFT", 5, 29772},
	{"RADIUS", 6, 29773},
	{"PERSPECTIVES", 12, 29774},
	{"NDFU", 4, 29775},
	{"HANM", 4, 29776},
	{"ELYR", 4, 29777},
	{"PIG", 3, 29778},
	{"NOTD", 4, 29779},
	{"LOGGING", 7, 29780},
	{"RELIABLE", 8, 29781},
	{"HAMPTON", 7, 29782},
	{"CHRISTIANS", 10, 29783},
	{"BORDERS", 7, 29784},
	{"ROMAN", 5, 29785},
	{"SANDWICH", 8, 29786},
	{"PADS", 4, 29787},
	{"VEMO", 4, 29788},
	{"ASPU", 4, 29789},
	{"BUTTS", 5, 29790},
	{"EGK", 3, 29791},
	{"OWON", 4, 29792},
	{"BOBBY", 5, 29793},
	{"DOSE", 4, 29794},
	{"CKAG", 4, 29795},
	{"RENDER", 6, 29796},
	{"ACCORDINGLY", 11, 29797},
	{"CLOTH", 5, 29798},
	{"IMEH", 4, 29799},
	{"BUTB", 4, 29800},
	{"OOMA", 4, 29801},
	{"XIR", 3, 29802},
	{"FWHA", 4, 29803},
	{"ELYC", 4, 29804},
	{"LZB", 3, 29805},
	{"HERB", 4, 29806},
	{"THPO", 4, 29807},
	{"DINV", 4, 29808},
	{"RERS", 4, 29809},
	{"ALMI", 4, 29810},
	{"LECTURE", 7, 29811},
	{"ANYF", 4, 29812},
	{"OTOG", 4, 29813},
	{"NJUS", 4, 29814},
	{"LECTURES", 8, 29815},
	{"WEAKNESS", 8, 29816},
	{"ANTB", 4, 29817},
	{"DCOA", 4, 29818},
	{"CHALLENGING", 11, 29819},
	{"AWEE", 4, 29820},
	{"ETAX", 4, 29821},
	{"WINES", 5, 29822},
	{"NURSERY", 7, 29823},
	{"HARDER", 6, 29824},
	{"MARCH", 5, 29825},
	{"CUPS", 4, 29826},
	{"MICROWAVE", 9, 29827},
	{"CHEAPEST", 8, 29828},
	{"ICEB", 4, 29829},
	{"TOAB", 4, 29830},
	{"TYWA", 4, 29831},
	{"NHAR", 4, 29832},
	{"CAVE", 4, 29833},
	{"TOOD", 4, 29834},
	{"ACCIDENTS", 9, 29835},
	{"RYWI", 4, 29836},
	{"TRAVESTI", 8, 29837},
	{"RELOCATION", 10, 29838},
	{"ALUA", 4, 29839},
	{"HUMANITY", 8, 29840},
	{"STUART", 6, 29841},
	{"HIMO", 4, 29842},
	{"GTOW", 4, 29843},
	{"EEKA", 4, 29844},
	{"ODEC", 4, 29845},
	{"XOV", 3, 29846},
	{"BACTERIA", 8, 29847},
	{"CONTRIBUTORS", 12, 29848},
	{"NAIL", 4, 29849},
	{"SALVADOR", 8, 29850},
	{"AIRPLANE", 8, 29851},
	{"MONROE", 6, 29852},
	{"NTBA", 4, 29853},
	{"TSOW", 4, 29854},
	{"RTAL", 4, 29855},
	{"ONRA", 4, 29856},
	{"WRIST", 5, 29857},
	{"VIOLATIONS", 10, 29858},
	{"SUBURB", 6, 29859},
	{"CONTEND", 7, 29860},
	{"SPUB", 4, 29861},
	{"FOAM", 4, 29862},
	{"OODP", 4, 29863},
	{"VITAMIN", 7, 29864},
	{"TEMPERATURES", 12, 29865},
	{"PASTE", 5, 29866},
	{"CLOUDS", 6, 29867},
	{"KEDB", 4, 29868},
	{"COMPETITIONS", 12, 29869},
	{"ZEDT", 4, 29870},
	{"DISCRETION", 10, 29871},
	{"SSAL", 4, 29872},
	{"TANZANIA", 8, 29873},
	{"JVC", 3, 29874},
	{"PSON", 4, 29875},
	{"VJA", 3, 29876},
	{"TICP", 4, 29877},
	{"NGAW", 4, 29878},
	{"ENLI", 4, 29879},
	{"UGHL", 4, 29880},
	{"UNSIGNED", 8, 29881},
	{"LLTE", 4, 29882},
	{"STAYING", 7, 29883},
	{"COSMETICS", 9, 29884},
	{"MISSING", 7, 29885},
	{"EASTER", 6, 29886},
	{"GGRE", 4, 29887},
	{"THEORIES", 8, 29888},
	{"REPOSITORY", 10, 29889},
	{"JEREMY", 6, 29890},
	{"YNJ", 3, 29891},
	{"VENICE", 6, 29892},
	{"RESPECTIVELY", 12, 29893},
	{"DMEN", 4, 29894},
	{"CONCENTRATIONS", 14, 29895},
	{"ESTONIA", 7, 29896},
	{"UPFO", 4, 29897},
	{"ERUL", 4, 29898},
	{"SBYT", 4, 29899},
	{"STREAMS", 7, 29900},
	{"SIGNING", 7, 29901},
	{"EXECUTED", 8, 29902},
	{"KATIE", 5, 29903},
	{"NEGOTIATIONS", 12, 29904},
	{"BAY", 3, 29905},
	{"ITME", 4, 29906},
	{"CGI", 3, 29907},
	{"SUCK", 4, 29908},
	{"CURTAIN", 7, 29909},
	{"SHOWCASE", 8, 29910},
	{"WHOR", 4, 29911},
	{"OPHI", 4, 29912},
	{"INTEGRAL", 8, 29913},
	{"ASKS", 4, 29914},
	{"OWMA", 4, 29915},
	{"MZI", 3, 29916},
	{"UMPE", 4, 29917},
	{"DNOW", 4, 29918},
	{"ARPE", 4, 29919},
	{"DUPT", 4, 29920},
	{"DEADLY", 6, 29921},
	{"LLEV", 4, 29922},
	{"YDF", 3, 29923},
	{"ELYD", 4, 29924},
	{"SOUTHWEST", 9, 29925},
	{"NAMIBIA", 7, 29926},
	{"ZDU", 3, 29927},
	{"YDEC", 4, 29928},
	{"GENERATING", 10, 29929},
	{"CHRISTINA", 9, 29930},
	{"THPR", 4, 29931},
	{"SYNOPSIS", 8, 29932},
	{"ANPO", 4, 29933},
	{"ENWO", 4, 29934},
	{"UISI", 4, 29935},
	{"PRAIRIE", 7, 29936},
	{"REUNION", 7, 29937},
	{"OWNERSHIP", 9, 29938},
	{"COMPOSER", 8, 29939},
	{"FRAUD", 5, 29940},
	{"EXAN", 4, 29941},
	{"KYJ", 3, 29942},
	{"OODC", 4, 29943},
	{"SIXTH", 5, 29944},
	{"MAINSTREAM", 10, 29945},
	{"ABSENT", 6, 29946},
	{"PHOTOGRAPHIC", 12, 29947},
	{"IALF", 4, 29948},
	{"FWOR", 4, 29949},
	{"ARRAY", 5, 29950},
	{"SKIRT", 5, 29951},
	{"SELLS", 5, 29952},
	{"MONSTER", 7, 29953},
	{"RIP", 3, 29954},
	{"ECUADOR", 7, 29955},
	{"HOPING", 6, 29956},
	{"ACCESSED", 8, 29957},
	{"OFAF", 4, 29958},
	{"AVEW", 4, 29959},
	{"OCCASIONAL", 10, 29960},
	{"ENFORCE", 7, 29961},
	{"IPTI", 4, 29962},
	{"EXCITEMENT", 10, 29963},
	{"UBSE", 4, 29964},
	{"SPIRITS", 7, 29965},
	{"RONO", 4, 29966},
	{"CAUG", 4, 29967},
	{"MODIFICATIONS", 13, 29968},
	{"ASTRONOMER", 10, 29969},
	{"LDCA", 4, 29970},
	{"CORAL", 5, 29971},
	{"REVERSE", 7, 29972},
	{"PIXEL", 5, 29973},
	{"SHIF", 4, 29974},
	{"DERH", 4, 29975},
	{"LSAI", 4, 29976},
	{"DLAS", 4, 29977},
	{"COLIN", 5, 29978},
	{"IMPORTED", 8, 29979},
	{"IDDE", 4, 29980},
	{"PATHS", 5, 29981},
	{"DWAT", 4, 29982},
	{"POR", 3, 29983},
	{"CSAN", 4, 29984},
	{"ESED", 4, 29985},
	{"LTED", 4, 29986},
	{"PLEAD", 5, 29987},
	{"CONTRARY", 8, 29988},
	{"MENW", 4, 29989},
	{"SBOT", 4, 29990},
	{"MILLENNIUM", 10, 29991},
	{"TRIBUNE", 7, 29992},
	{"COMPANION", 9, 29993},
	{"DBRO", 4, 29994},
	{"ADMINISTER", 10, 29995},
	{"ANYD", 4, 29996},
	{"ACIDS", 5, 29997},
	{"AMENDMENT", 9, 29998},
	{"ALFR", 4, 29999},
	{"BROADCAST", 9, 30000},
	{"FOCUSING", 8, 30001},
	{"INSPECTION", 10, 30002},
	{"YTWO", 4, 30003},
	{"VIRUSES", 7, 30004},
	{"CHEAPER", 7, 30005},
	{"GWOR", 4, 30006},
	{"ADMITTED", 8, 30007},
	{"RSOR", 4, 30008},
	{"OFGE", 4, 30009},
	{"DRAIN", 5, 30010},
	{"FOREHEAD", 8, 30011},
	{"DAIRY", 5, 30012},
	{"DOFH", 4, 30013},
	{"DSEA", 4, 30014},
	{"MEM", 3, 30015},
	{"EWOF", 4, 30016},
	{"DLET", 4, 30017},
	{"FANCY", 5, 30018},
	{"ELOV", 4, 30019},
	{"SAMOA", 5, 30020},
	{"NSUP", 4, 30021},
	{"ACHIEVING", 9, 30022},
	{"ARTW", 4, 30023},
	{"ROPR", 4, 30024},
	{"ARYF", 4, 30025},
	{"DHIG", 4, 30026},
	{"SLAR", 4, 30027},
	{"STICKERS", 8, 30028},
	{"AGEF", 4, 30029},
	{"FISHERIES", 9, 30030},
	{"ESGO", 4, 30031},
	{"ELOR", 4, 30032},
	{"CONSISTENTLY", 12, 30033},
	{"EXCEPTIONS", 10, 30034},
	{"VYY", 3, 30035},
	{"OUTDOOR", 7, 30036},
	{"INGK", 4, 30037},
	{"REACTIONS", 9, 30038},
	{"INNOVATION", 10, 30039},
	{"FNY", 3, 30040},
	{"LEASING", 7, 30041},
	{"TNIG", 4, 30042},
	{"GPAR", 4, 30043},
	{"DATABASE", 8, 30044},
	{"LAUREN", 6, 30045},
	{"HARSH", 5, 30046},
	{"EDUS", 4, 30047},
	{"BELIEFS", 7, 30048},
	{"MACROMEDIA", 10, 30049},
	{"GLEA", 4, 30050},
	{"ASHLEY", 6, 30051},
	{"SCROLL", 6, 30052},
	{"DIVISIONS", 9, 30053},
	{"WAGES", 5, 30054},
	{"ADDITIONALLY", 12, 30055},
	{"DOCTRINE", 8, 30056},
	{"SINL", 4, 30057},
	{"OLDO", 4, 30058},
	{"ONAU", 4, 30059},
	{"OBSTACLE", 8, 30060},
	{"MAXIMUM", 7, 30061},
	{"FORESTS", 7, 30062},
	{"LOYM", 4, 30063},
	{"LVIN", 4, 30064},
	{"APAB", 4, 30065},
	{"YPY", 3, 30066},
	{"EAPA", 4, 30067},
	{"INVALID", 7, 30068},
	{"NGGA", 4, 30069},
	{"EDLO", 4, 30070},
	{"NGTA", 4, 30071},
	{"EEQU", 4, 30072},
	{"DGER", 4, 30073},
	{"CONCERTS", 8, 30074},
	{"CARBOHYDRATE", 12, 30075},
	{"MARTIAL", 7, 30076},
	{"ONFU", 4, 30077},
	{"RICI", 4, 30078},
	{"MALES", 5, 30079},
	{"LYEN", 4, 30080},
	{"RALB", 4, 30081},
	{"XIMA", 4, 30082},
	{"ESIR", 4, 30083},
	{"FEAN", 4, 30084},
	{"VICTORIAN", 9, 30085},
	{"FOFT", 4, 30086},
	{"SUPERVISOR", 10, 30087},
	{"COLOURS", 7, 30088},
	{"VYV", 3, 30089},
	{"NDOL", 4, 30090},
	{"IVEG", 4, 30091},
	{"CONFUSE", 7, 30092},
	{"AXU", 3, 30093},
	{"ANOV", 4, 30094},
	{"GENRES", 6, 30095},
	{"CAMBODIA", 8, 30096},
	{"PATENTS", 7, 30097},
	{"COPYRIGHTS", 10, 30098},
	{"OLYMPICS", 8, 30099},
	{"SRAN", 4, 30100},
	{"LITHUANIA", 9, 30101},
	{"CHRONIC", 7, 30102},
	{"SWEAT", 5, 30103},
	{"MASTERCARD", 10, 30104},
	{"ANYR", 4, 30105},
	{"CRYSTAL", 7, 30106},
	{"REEY", 4, 30107},
	{"CHRONICLES", 10, 30108},
	{"ICSO", 4, 30109},
	{"YTOM", 4, 30110},
	{"OBTAINING", 9, 30111},
	{"OSTF", 4, 30112},
	{"GHHE", 4, 30113},
	{"BEAVER", 6, 30114},
	{"ARYP", 4, 30115},
	{"TRAP", 4, 30116},
	{"MOTIVE", 6, 30117},
	{"ZZP", 3, 30118},
	{"QIG", 3, 30119},
	{"UPDATING", 8, 30120},
	{"READINGS", 8, 30121},
	{"HIFT", 4, 30122},
	{"MUD", 3, 30123},
	{"APOR", 4, 30124},
	{"DECORATIVE", 10, 30125},
	{"KIJIJI", 6, 30126},
	{"RUMOR", 5, 30127},
	{"CONFUSED", 8, 30128},
	{"UTHW", 4, 30129},
	{"MPED", 4, 30130},
	{"LIMB", 4, 30131},
	{"MESB", 4, 30132},
	{"COMPILER", 8, 30133},
	{"WOW", 3, 30134},
	{"GDOW", 4, 30135},
	{"NGEF", 4, 30136},
	{"PLAIN", 5, 30137},
	{"ENLARGEMENT", 11, 30138},
	{"EAGLES", 6, 30139},
	{"BASES", 5, 30140},
	{"STRICT", 6, 30141},
	{"MINIMUM", 7, 30142},
	{"NALG", 4, 30143},
	{"ACCUSED", 7, 30144},
	{"SEEMINGLY", 9, 30145},
	{"CAMPAIGNS", 9, 30146},
	{"ARENA", 5, 30147},
	{"YOX", 3, 30148},
	{"KEDW", 4, 30149},
	{"FISCAL", 6, 30150},
	{"CONJUNCTION", 11, 30151},
	{"FORGIVE", 7, 30152},
	{"AKEH", 4, 30153},
	{"OUBT", 4, 30154},
	{"RATS", 4, 30155},
	{"YSCO", 4, 30156},
	{"SODIUM", 6, 30157},
	{"DEFINES", 7, 30158},
	{"HEYB", 4, 30159},
	{"ASSEMBLE", 8, 30160},
	{"PREDICTION", 10, 30161},
	{"AIRPORTS", 8, 30162},
	{"TSWA", 4, 30163},
	{"YSAY", 4, 30164},
	{"ADOW", 4, 30165},
	{"ITHU", 4, 30166},
	{"INSTANCES", 9, 30167},
	{"BEGUN", 5, 30168},
	{"OWDO", 4, 30169},
	{"CFR", 3, 30170},
	{"BRUNETTE", 8, 30171},
	{"PACKETS", 7, 30172},
	{"WAYW", 4, 30173},
	{"FLOOD", 5, 30174},
	{"ADOPTION", 8, 30175},
	{"ANCHOR", 6, 30176},
	{"IGUE", 4, 30177},
	{"SOCKS", 5, 30178},
	{"VALIDATION", 10, 30179},
	{"GEVE", 4, 30180},
	{"TRAIT", 5, 30181},
	{"MTOT", 4, 30182},
	{"DSTU", 4, 30183},
	{"INCENTIVES", 10, 30184},
	{"TOWEL", 5, 30185},
	{"RSTB", 4, 30186},
	{"IALD", 4, 30187},
	{"YOFH", 4, 30188},
	{"WARRIOR", 7, 30189},
	{"HEYF", 4, 30190},
	{"GTOR", 4, 30191},
	{"GATHERED", 8, 30192},
	{"ILIP", 4, 30193},
	{"POND", 4, 30194},
	{"SLOVENIA", 8, 30195},
	{"NOTIFIED", 8, 30196},
	{"DIFFERENTIAL", 12, 30197},
	{"BEACHES", 7, 30198},
	{"ERSG", 4, 30199},
	{"LYEX", 4, 30200},
	{"FOLDERS", 7, 30201},
	{"MEPR", 4, 30202},
	{"SURFACES", 8, 30203},
	{"RVEY", 4, 30204},
	{"LEND", 4, 30205},
	{"INFRASTRUCTURE", 14, 30206},
	{"SIMULTANEOUSLY", 14, 30207},
	{"VORI", 4, 30208},
	{"UREM", 4, 30209},
	{"ROUTERS", 7, 30210},
	{"CRUZ", 4, 30211},
	{"PENDANT", 7, 30212},
	{"DRESSES", 7, 30213},
	{"BAPTIST", 7, 30214},
	{"STARSMERCHANT", 13, 30215},
	{"HIRING", 6, 30216},
	{"UNDW", 4, 30217},
	{"CLOCKS", 6, 30218},
	{"DYEA", 4, 30219},
	{"ARTHRITIS", 9, 30220},
	{"BIOS", 4, 30221},
	{"YBB", 3, 30222},
	{"NEYE", 4, 30223},
	{"FEMALES", 7, 30224},
	{"NFRI", 4, 30225},
	{"TEMPLE", 6, 30226},
	{"WALLACE", 7, 30227},
	{"OSEF", 4, 30228},
	{"TSWO", 4, 30229},
	{"REFLECTS", 8, 30230},
	{"TAXATION", 8, 30231},
	{"CONVICT", 7, 30232},
	{"ARDB", 4, 30233},
	{"LSOU", 4, 30234},
	{"PMC", 3, 30235},
	{"MANB", 4, 30236},
	{"HTLY", 4, 30237},
	{"ORBO", 4, 30238},
	{"MEOU", 4, 30239},
	{"TUNE", 4, 30240},
	{"FTRA", 4, 30241},
	{"CUISINE", 7, 30242},
	{"EXUA", 4, 30243},
	{"PRACTITIONERS", 13, 30244},
	{"RYX", 3, 30245},
	{"TRANSCRIPT", 10, 30246},
	{"MYSPACE", 7, 30247},
	{"YCHI", 4, 30248},
	{"UCIN", 4, 30249},
	{"THEOREM", 7, 30250},
	{"PARTICLE", 8, 30251},
	{"PRIVILEGE", 9, 30252},
	{"FPER", 4, 30253},
	{"LFAN", 4, 30254},
	{"RUTH", 4, 30255},
	{"STYLUS", 6, 30256},
	{"COMPOUNDS", 9, 30257},
	{"OMOF", 4, 30258},
	{"POPE", 4, 30259},
	{"DRUMS", 5, 30260},
	{"CONTRACTING", 11, 30261},
	{"SOFN", 4, 30262},
	{"ONSD", 4, 30263},
	{"WILDERNESS", 10, 30264},
	{"DOORWAY", 7, 30265},
	{"RHIG", 4, 30266},
	{"PSTO", 4, 30267},
	{"OXK", 3, 30268},
	{"ESFI", 4, 30269},
	{"RADIATION", 9, 30270},
	{"CHME", 4, 30271},
	{"DSWE", 4, 30272},
	{"LYUS", 4, 30273},
	{"EREY", 4, 30274},
	{"FORMAT", 6, 30275},
	{"ARNOLD", 6, 30276},
	{"STRUCTURED", 10, 30277},
	{"LEWO", 4, 30278},
	{"LYIS", 4, 30279},
	{"REASONABLY", 10, 30280},
	{"JEEP", 4, 30281},
	{"DWOU", 4, 30282},
	{"CHICKS", 6, 30283},
	{"WENE", 4, 30284},
	{"OBEE", 4, 30285},
	{"EOUR", 4, 30286},
	{"HUNG", 4, 30287},
	{"MBA", 3, 30288},
	{"RTEN", 4, 30289},
	{"NDBY", 4, 30290},
	{"FFAN", 4, 30291},
	{"GPER", 4, 30292},
	{"GRADUATES", 9, 30293},
	{"DISK", 4, 30294},
	{"ROVER", 5, 30295},
	{"RECOMMENDS", 10, 30296},
	{"CONTROLLING", 11, 30297},
	{"NIGHTMARE", 9, 30298},
	{"RELOAD", 6, 30299},
	{"DISTRIBUTORS", 12, 30300},
	{"DRUNK", 5, 30301},
	{"INEVITABLE", 10, 30302},
	{"IORT", 4, 30303},
	{"AYME", 4, 30304},
	{"HHIM", 4, 30305},
	{"LEVITRA", 7, 30306},
	{"TANKS", 5, 30307},
	{"NDSM", 4, 30308},
	{"GNAN", 4, 30309},
	{"ASSUMING", 8, 30310},
	{"HEGL", 4, 30311},
	{"ALIV", 4, 30312},
	{"SSWI", 4, 30313},
	{"VESW", 4, 30314},
	{"MONETARY", 8, 30315},
	{"OLST", 4, 30316},
	{"ARLINGTON", 9, 30317},
	{"MONO", 4, 30318},
	{"PARTICLES", 9, 30319},
	{"FLOATING", 8, 30320},
	{"OUWA", 4, 30321},
	{"RGEA", 4, 30322},
	{"TWIST", 5, 30323},
	{"URTI", 4, 30324},
	{"LDHE", 4, 30325},
	{"ELLP", 4, 30326},
	{"ADLI", 4, 30327},
	{"STRUCTURAL", 10, 30328},
	{"HILI", 4, 30329},
	{"RETIRED", 7, 30330},
	{"INDICATING", 10, 30331},
	{"BOLIVIA", 7, 30332},
	{"RMTH", 4, 30333},
	{"HOTTEST", 7, 30334},
	{"EANU", 4, 30335},
	{"IKEH", 4, 30336},
	{"STEVENS", 7, 30337},
	{"THEOLOGY", 8, 30338},
	{"LLOV", 4, 30339},
	{"YIJ", 3, 30340},
	{"ANNOUNCEMENT", 12, 30341},
	{"BOOST", 5, 30342},
	{"UCKS", 4, 30343},
	{"KUWAIT", 6, 30344},
	{"RLIF", 4, 30345},
	{"RKSA", 4, 30346},
	{"COMMONLY", 8, 30347},
	{"OCKA", 4, 30348},
	{"GGIN", 4, 30349},
	{"EMILY", 5, 30350},
	{"ISJU", 4, 30351},
	{"THWI", 4, 30352},
	{"WIDESCREEN", 10, 30353},
	{"COMPILE", 7, 30354},
	{"AINP", 4, 30355},
	{"NGUS", 4, 30356},
	{"SQUIRTING", 9, 30357},
	{"EGEO", 4, 30358},
	{"WEBSTER", 7, 30359},
	{"STRUCK", 6, 30360},
	{"FRESHMAN", 8, 30361},
	{"LLFI", 4, 30362},
	{"ILLUSTRATION", 12, 30363},
	{"WALKING", 7, 30364},
	{"PAD", 3, 30365},
	{"CONTINUING", 10, 30366},
	{"AWTH", 4, 30367},
	{"USOF", 4, 30368},
	{"OBAC", 4, 30369},
	{"PLYMOUTH", 8, 30370},
	{"TUNT", 4, 30371},
	{"NGEM", 4, 30372},
	{"OPTH", 4, 30373},
	{"WARNINGS", 8, 30374},
	{"ESYO", 4, 30375},
	{"ERYF", 4, 30376},
	{"AWHE", 4, 30377},
	{"MECHANICAL", 10, 30378},
	{"APPS", 4, 30379},
	{"TGY", 3, 30380},
	{"INQUIRIES", 9, 30381},
	{"BRIDAL", 6, 30382},
	{"OVERWHELMING", 12, 30383},
	{"ANNEX", 5, 30384},
	{"SEDM", 4, 30385},
	{"UNEXPECTED", 10, 30386},
	{"TRANSMISSION", 12, 30387},
	{"NTOG", 4, 30388},
	{"POSSESSION", 10, 30389},
	{"DNOR", 4, 30390},
	{"CATTLE", 6, 30391},
	{"MAG", 3, 30392},
	{"GSM", 3, 30393},
	{"ACTW", 4, 30394},
	{"AFFECTING", 9, 30395},
	{"IKNO", 4, 30396},
	{"COLONY", 6, 30397},
	{"RSLI", 4, 30398},
	{"CANM", 4, 30399},
	{"FREIGHT", 7, 30400},
	{"MEBE", 4, 30401},
	{"RANDOM", 6, 30402},
	{"REBATE", 6, 30403},
	{"ORFR", 4, 30404},
	{"MEETUP", 6, 30405},
	{"LYAR", 4, 30406},
	{"ECLIPSE", 7, 30407},
	{"HCOU", 4, 30408},
	{"SUDAN", 5, 30409},
	{"HORN", 4, 30410},
	{"COMPLEXITY", 10, 30411},
	{"DDR", 3, 30412},
	{"DOWNLOADING", 11, 30413},
	{"UNITY", 5, 30414},
	{"ONEV", 4, 30415},
	{"REC", 3, 30416},
	{"AGGREGATE", 9, 30417},
	{"FCHA", 4, 30418},
	{"SOMU", 4, 30419},
	{"TLYW", 4, 30420},
	{"STUNNING", 8, 30421},
	{"CYCLES", 6, 30422},
	{"AFFECTS", 7, 30423},
	{"FORECASTS", 9, 30424},
	{"HEEU", 4, 30425},
	{"WEDB", 4, 30426},
	{"SPILL", 5, 30427},
	{"CIAO", 4, 30428},
	{"AMPLAND", 7, 30429},
	{"RAILROAD", 8, 30430},
	{"CANVAS", 6, 30431},
	{"PREP", 4, 30432},
	{"ISAW", 4, 30433},
	{"ELER", 4, 30434},
	{"CCUS", 4, 30435},
	{"CHEM", 4, 30436},
	{"FASTEST", 7, 30437},
	{"BUTLER", 6, 30438},
	{"UPRE", 4, 30439},
	{"BELLY", 5, 30440},
	{"SHOPZILLA", 9, 30441},
	{"LYBU", 4, 30442},
	{"ISEM", 4, 30443},
	{"DECORATING", 10, 30444},
	{"OFWE", 4, 30445},
	{"TECHNOLOGICAL", 13, 30446},
	{"DVIC", 4, 30447},
	{"PAYROLL", 7, 30448},
	{"COOKBOOK", 8, 30449},
	{"CONSULT", 7, 30450},
	{"ULDM", 4, 30451},
	{"TINM", 4, 30452},
	{"EXPRESSIONS", 11, 30453},
	{"VIRTUAL", 7, 30454},
	{"FESTIVAL", 8, 30455},
	{"COURIER", 7, 30456},
	{"ALHA", 4, 30457},
	{"SROO", 4, 30458},
	{"ADEH", 4, 30459},
	{"IKD", 3, 30460},
	{"HERS", 4, 30461},
	{"UPLOADED", 8, 30462},
	{"TOKN", 4, 30463},
	{"SPEO", 4, 30464},
	{"UNSE", 4, 30465},
	{"RHETORIC", 8, 30466},
	{"SHAKESPEARE", 11, 30467},
	{"HINTS", 5, 30468},
	{"NDCU", 4, 30469},
	{"EATP", 4, 30470},
	{"CCAI", 4, 30471},
	{"UNDERMINE", 9, 30472},
	{"AMERICAS", 8, 30473},
	{"SEPARATION", 10, 30474},
	{"CONNECTORS", 10, 30475},
	{"TWINKS", 6, 30476},
	{"ULTE", 4, 30477},
	{"LYSO", 4, 30478},
	{"TURKEY", 6, 30479},
	{"ADFO", 4, 30480},
	{"YDV", 3, 30481},
	{"XYM", 3, 30482},
	{"GIF", 3, 30483},
	{"TDON", 4, 30484},
	{"ONGB", 4, 30485},
	{"CURRENCY", 8, 30486},
	{"OZL", 3, 30487},
	{"PROS", 4, 30488},
	{"DFRI", 4, 30489},
	{"YCM", 3, 30490},
	{"RCLE", 4, 30491},
	{"CONFLICTS", 9, 30492},
	{"TECHNO", 6, 30493},
	{"BEVERAGE", 8, 30494},
	{"GUILT", 5, 30495},
	{"RSTW", 4, 30496},
	{"TRIBUTE", 7, 30497},
	{"LTTH", 4, 30498},
	{"WIRED", 5, 30499},
	{"RNES", 4, 30500},
	{"OPHY", 4, 30501},
	{"FORK", 4, 30502},
	{"ELVIS", 5, 30503},
	{"NCIT", 4, 30504},
	{"AYNE", 4, 30505},
	{"SSEV", 4, 30506},
	{"TALB", 4, 30507},
	{"TWON", 4, 30508},
	{"GNIT", 4, 30509},
	{"LATVIA", 6, 30510},
	{"TRAVELERS", 9, 30511},
	{"DPEO", 4, 30512},
	{"FORESTRY", 8, 30513},
	{"BARRIERS", 8, 30514},
	{"CANT", 4, 30515},
	{"FEEDBACK", 8, 30516},
	{"EISM", 4, 30517},
	{"REPLACEMENT", 11, 30518},
	{"LLLE", 4, 30519},
	{"NWIN", 4, 30520},
	{"GPL", 3, 30521},
	{"INFECTED", 8, 30522},
	{"OFFERINGS", 9, 30523},
	{"MARTHA", 6, 30524},
	{"GENESIS", 7, 30525},
	{"INCORRECT", 9, 30526},
	{"DOFC", 4, 30527},
	{"WSAN", 4, 30528},
	{"GRIP", 4, 30529},
	{"TRAINS", 6, 30530},
	{"FMAR", 4, 30531},
	{"TZY", 3, 30532},
	{"METALS", 6, 30533},
	{"MEANINGFUL", 10, 30534},
	{"FURNISHINGS", 11, 30535},
	{"TRADITIONALLY", 13, 30536},
	{"LETTING", 7, 30537},
	{"STRAIN", 6, 30538},
	{"GUITAR", 6, 30539},
	{"GUATEMALA", 9, 30540},
	{"EJOI", 4, 30541},
	{"TPOI", 4, 30542},
	{"WEIRD", 5, 30543},
	{"CELTIC", 6, 30544},
	{"IRC", 3, 30545},
	{"UNDH", 4, 30546},
	{"JAMIE", 5, 30547},
	{"DUCI", 4, 30548},
	{"RPOL", 4, 30549},
	{"PEACEFUL", 8, 30550},
	{"MANDATE", 7, 30551},
	{"GWHE", 4, 30552},
	{"MINERALS", 8, 30553},
	{"USHO", 4, 30554},
	{"NLYI", 4, 30555},
	{"DWID", 4, 30556},
	{"KEDU", 4, 30557},
	{"EATW", 4, 30558},
	{"LLDE", 4, 30559},
	{"SBOO", 4, 30560},
	{"HUMIDITY", 8, 30561},
	{"BOTTLES", 7, 30562},
	{"ETFO", 4, 30563},
	{"BOXING", 6, 30564},
	{"INPU", 4, 30565},
	{"ONDH", 4, 30566},
	{"BANGKOK", 7, 30567},
	{"RENAISSANCE", 11, 30568},
	{"ENBU", 4, 30569},
	{"PATHOLOGY", 9, 30570},
	{"SARA", 4, 30571},
	{"DUMP", 4, 30572},
	{"DTRI", 4, 30573},
	{"OBEP", 4, 30574},
	{"BRA", 3, 30575},
	{"AYMO", 4, 30576},
	{"LEFR", 4, 30577},
	{"DMET", 4, 30578},
	{"RESN", 4, 30579},
	{"RSEY", 4, 30580},
	{"ORDINANCE", 9, 30581},
	{"HUGHES", 6, 30582},
	{"PHOTOGRAPHERS", 13, 30583},
	{"LLPA", 4, 30584},
	{"LMON", 4, 30585},
	{"OUSF", 4, 30586},
	{"ASUP", 4, 30587},
	{"ENGAGEMENT", 10, 30588},
	{"INFECTIONS", 10, 30589},
	{"DCLA", 4, 30590},
	{"ELYW", 4, 30591},
	{"JEFFREY", 7, 30592},
	{"CHESS", 5, 30593},
	{"EXECUTE", 7, 30594},
	{"UNCERTAINTY", 11, 30595},
	{"OPERATES", 8, 30596},
	{"BRISBANE", 8, 30597},
	{"UTET", 4, 30598},
	{"GOVERN", 6, 30599},
	{"SIDEWALK", 8, 30600},
	{"NTEV", 4, 30601},
	{"DDON", 4, 30602},
	{"CONFIGURED", 10, 30603},
	{"WASK", 4, 30604},
	{"UNCOMFORTABLE", 13, 30605},
	{"OUKN", 4, 30606},
	{"YBEE", 4, 30607},
	{"DANCER", 6, 30608},
	{"OSCAR", 5, 30609},
	{"PORTFOLIO", 9, 30610},
	{"LTHY", 4, 30611},
	{"FESTIVALS", 9, 30612},
	{"MENUS", 5, 30613},
	{"PENSION", 7, 30614},
	{"HWHI", 4, 30615},
	{"RYDA", 4, 30616},
	{"XYI", 3, 30617},
	{"THUMB", 5, 30618},
	{"JOAN", 4, 30619},
	{"POSSIBILITIES", 13, 30620},
	{"CANAL", 5, 30621},
	{"CTON", 4, 30622},
	{"SUJ", 3, 30623},
	{"AMINO", 5, 30624},
	{"CONTRIBUTING", 12, 30625},
	{"AYAS", 4, 30626},
	{"ISAV", 4, 30627},
	{"ESIX", 4, 30628},
	{"HERBS", 5, 30629},
	{"EWCO", 4, 30630},
	{"CLINICS", 7, 30631},
	{"MLS", 3, 30632},
	{"LUMN", 4, 30633},
	{"SLIV", 4, 30634},
	{"MANITOBA", 8, 30635},
	{"LANDING", 7, 30636},
	{"ANALYTICAL", 10, 30637},
	{"MISSIONS", 8, 30638},
	{"WATSON", 6, 30639},
	{"ATBA", 4, 30640},
	{"LYING", 5, 30641},
	{"THMI", 4, 30642},
	{"YCD", 3, 30643},
	{"COSTUMES", 8, 30644},
	{"DIVE", 4, 30645},
	{"AIDW", 4, 30646},
	{"SADDAM", 6, 30647},
	{"GRACE", 5, 30648},
	{"CONTRACTOR", 10, 30649},
	{"CIRCULATION", 11, 30650},
	{"ALARM", 5, 30651},
	{"LXL", 3, 30652},
	{"TRIGGER", 7, 30653},
	{"SILY", 4, 30654},
	{"AVIL", 4, 30655},
	{"BRYAN", 5, 30656},
	{"ILVE", 4, 30657},
	{"OLQ", 3, 30658},
	{"TYWH", 4, 30659},
	{"THGR", 4, 30660},
	{"ORDT", 4, 30661},
	{"GTRA", 4, 30662},
	{"RBOR", 4, 30663},
	{"ONJA", 4, 30664},
	{"EBYT", 4, 30665},
	{"JERUSALEM", 9, 30666},
	{"HOBBY", 5, 30667},
	{"HARM", 4, 30668},
	{"TRIES", 5, 30669},
	{"OUTER", 5, 30670},
	{"AKEP", 4, 30671},
	{"NSAY", 4, 30672},
	{"UJE", 3, 30673},
	{"EASP", 4, 30674},
	{"ILIZ", 4, 30675},
	{"NICKNAME", 8, 30676},
	{"OFPL", 4, 30677},
	{"XCIT", 4, 30678},
	{"ZVA", 3, 30679},
	{"RTHC", 4, 30680},
	{"FIJI", 4, 30681},
	{"INLINE", 6, 30682},
	{"YNK", 3, 30683},
	{"EXECUTIVES", 10, 30684},
	{"UCER", 4, 30685},
	{"ENQUIRIES", 9, 30686},
	{"GRATEFUL", 8, 30687},
	{"WASHING", 7, 30688},
	{"CRAWL", 5, 30689},
	{"AUDI", 4, 30690},
	{"STAFFING", 8, 30691},
	{"EXPLORING", 9, 30692},
	{"IALW", 4, 30693},
	{"TISB", 4, 30694},
	{"SHUTTLE", 7, 30695},
	{"YOFP", 4, 30696},
	{"ARDR", 4, 30697},
	{"UMBL", 4, 30698},
	{"ENQUIRY", 7, 30699},
	{"CLOSURE", 7, 30700},
	{"RAID", 4, 30701},
	{"CANF", 4, 30702},
	{"PPC", 3, 30703},
	{"VOLT", 4, 30704},
	{"SOUTHEAST", 9, 30705},
	{"YGET", 4, 30706},
	{"THEREBY", 7, 30707},
	{"TOAF", 4, 30708},
	{"ENDURE", 6, 30709},
	{"DIV", 3, 30710},
	{"PLAYLIST", 8, 30711},
	{"RESERVE", 7, 30712},
	{"CHIN", 4, 30713},
	{"RTLY", 4, 30714},
	{"REGISTRAR", 9, 30715},
	{"SHOWERS", 7, 30716},
	{"REEV", 4, 30717},
	{"SUPPORTERS", 10, 30718},
	{"NZF", 3, 30719},
	{"LBAN", 4, 30720},
	{"OBIN", 4, 30721},
	{"STATUTES", 8, 30722},
	{"UIPM", 4, 30723},
	{"RSOU", 4, 30724},
	{"MYERS", 5, 30725},
	{"INJURE", 6, 30726},
	{"INDICATOR", 9, 30727},
	{"DBEG", 4, 30728},
	{"DROPS", 5, 30729},
	{"PREDICTED", 9, 30730},
	{"WIDER", 5, 30731},
	{"SASKATCHEWAN", 12, 30732},
	{"ODEF", 4, 30733},
	{"ACCOMMODATE", 11, 30734},
	{"DISM", 4, 30735},
	{"CANCELLATION", 12, 30736},
	{"PLUGINS", 7, 30737},
	{"ENROLLED", 8, 30738},
	{"FSOM", 4, 30739},
	{"SENSORS", 7, 30740},
	{"NTMO", 4, 30741},
	{"MINISTERS", 9, 30742},
	{"EGUN", 4, 30743},
	{"EGUY", 4, 30744},
	{"EGOL", 4, 30745},
	{"YLG", 3, 30746},
	{"YSBE", 4, 30747},
	{"AILW", 4, 30748},
	{"HOURLY", 6, 30749},
	{"NDQU", 4, 30750},
	{"YLR", 3, 30751},
	{"GENEVA", 6, 30752},
	{"LOBBY", 5, 30753},
	{"RSWA", 4, 30754},
	{"SCOA", 4, 30755},
	{"HOCO", 4, 30756},
	{"AWAIT", 5, 30757},
	{"FREEBSD", 7, 30758},
	{"LEXP", 4, 30759},
	{"CLICK", 5, 30760},
	{"VETERINARY", 10, 30761},
	{"ACER", 4, 30762},
	{"PROSTORES", 9, 30763},
	{"RESELLER", 8, 30764},
	{"OLOO", 4, 30765},
	{"NUZ", 3, 30766},
	{"WINA", 4, 30767},
	{"BEHAVE", 6, 30768},
	{"DIST", 4, 30769},
	{"YRM", 3, 30770},
	{"ORWO", 4, 30771},
	{"ROMR", 4, 30772},
	{"EUPT", 4, 30773},
	{"EEPS", 4, 30774},
	{"ADEB", 4, 30775},
	{"HANDED", 6, 30776},
	{"SATR", 4, 30777},
	{"HORRIBLE", 8, 30778},
	{"SUFFERED", 8, 30779},
	{"ELEVATOR", 8, 30780},
	{"ONPL", 4, 30781},
	{"INTAKE", 6, 30782},
	{"YFIN", 4, 30783},
	{"RELEVANCE", 9, 30784},
	{"EASK", 4, 30785},
	{"TUCSON", 6, 30786},
	{"CONVEY", 6, 30787},
	{"MECHANICS", 9, 30788},
	{"HSTR", 4, 30789},
	{"DGIV", 4, 30790},
	{"REBEL", 5, 30791},
	{"MPIN", 4, 30792},
	{"DBEL", 4, 30793},
	{"HEADERS", 7, 30794},
	{"MISTAKES", 8, 30795},
	{"NUMERICAL", 9, 30796},
	{"DYTO", 4, 30797},
	{"ARSB", 4, 30798},
	{"TGIV", 4, 30799},
	{"GEEK", 4, 30800},
	{"PRIZE", 5, 30801},
	{"REPUBLIC", 8, 30802},
	{"CORRUPTION", 10, 30803},
	{"TEWH", 4, 30804},
	{"DEFINING", 8, 30805},
	{"XNXX", 4, 30806},
	{"ODRI", 4, 30807},
	{"SADV", 4, 30808},
	{"COUNTING", 8, 30809},
	{"UKNO", 4, 30810},
	{"COMPENSATION", 12, 30811},
	{"HANDSOME", 8, 30812},
	{"LLHI", 4, 30813},
	{"ACCOMPANIED", 11, 30814},
	{"SPOUSE", 6, 30815},
	{"HEMW", 4, 30816},
	{"EWSO", 4, 30817},
	{"DEVOTED", 7, 30818},
	{"PTTO", 4, 30819},
	{"PRINCETON", 9, 30820},
	{"JACOB", 5, 30821},
	{"SSUB", 4, 30822},
	{"CHBE", 4, 30823},
	{"EINJ", 4, 30824},
	{"RANDY", 5, 30825},
	{"SPIRITUALITY", 12, 30826},
	{"MESP", 4, 30827},
	{"CLOSED", 6, 30828},
	{"DSAL", 4, 30829},
	{"TOAV", 4, 30830},
	{"JUROR", 5, 30831},
	{"PROPRIETARY", 11, 30832},
	{"QFO", 3, 30833},
	{"TIMOTHY", 7, 30834},
	{"ERSY", 4, 30835},
	{"TISR", 4, 30836},
	{"CHILDRENS", 9, 30837},
	{"IRTU", 4, 30838},
	{"OBUI", 4, 30839},
	{"STARTER", 7, 30840},
	{"SOFTLY", 6, 30841},
	{"HUZ", 3, 30842},
	{"CHIG", 4, 30843},
	{"APOLOGIZE", 9, 30844},
	{"COUNTERPART", 11, 30845},
	{"AHAR", 4, 30846},
	{"NONPROFIT", 9, 30847},
	{"THUMBZILLA", 10, 30848},
	{"MEDIEVAL", 8, 30849},
	{"KJI", 3, 30850},
	{"PORCELAIN", 9, 30851},
	{"ALEV", 4, 30852},
	{"KESU", 4, 30853},
	{"HUG", 3, 30854},
	{"ANYH", 4, 30855},
	{"BRIDGES", 7, 30856},
	{"PROFOUND", 8, 30857},
	{"KUJ", 3, 30858},
	{"PICHUNTER", 9, 30859},
	{"CAPTURED", 8, 30860},
	{"FROZEN", 6, 30861},
	{"REBUILD", 7, 30862},
	{"ASJU", 4, 30863},
	{"ZCZ", 3, 30864},
	{"NRET", 4, 30865},
	{"WATT", 4, 30866},
	{"THEHUN", 6, 30867},
	{"TOFD", 4, 30868},
	{"ABIN", 4, 30869},
	{"MMIG", 4, 30870},
	{"COMPROMISE", 10, 30871},
	{"VEAT", 4, 30872},
	{"CASTING", 7, 30873},
	{"AKEC", 4, 30874},
	{"LSEC", 4, 30875},
	{"OPHE", 4, 30876},
	{"FLUID", 5, 30877},
	{"DAYTON", 6, 30878},
	{"TRANSLATED", 10, 30879},
	{"HESITATE", 8, 30880},
	{"ARWH", 4, 30881},
	{"SCATTER", 7, 30882},
	{"METAPHOR", 8, 30883},
	{"CAMERON", 7, 30884},
	{"COLUMNISTS", 10, 30885},
	{"ENDLESS", 7, 30886},
	{"TMUS", 4, 30887},
	{"PINS", 4, 30888},
	{"CARLOS", 6, 30889},
	{"EADC", 4, 30890},
	{"ELLH", 4, 30891},
	{"RENO", 4, 30892},
	{"DONNA", 5, 30893},
	{"ANDREAS", 7, 30894},
	{"CHOP", 4, 30895},
	{"BOUNCE", 6, 30896},
	{"RIDER", 5, 30897},
	{"SFRI", 4, 30898},
	{"DIPLOMA", 7, 30899},
	{"ORAL", 4, 30900},
	{"AMEH", 4, 30901},
	{"THPA", 4, 30902},
	{"EPTT", 4, 30903},
	{"SCANNING", 8, 30904},
	{"RSTF", 4, 30905},
	{"LIBERTY", 7, 30906},
	{"DETECTIVE", 9, 30907},
	{"POLO", 4, 30908},
	{"NADV", 4, 30909},
	{"VALIUM", 6, 30910},
	{"COPYING", 7, 30911},
	{"RPG", 3, 30912},
	{"CORDLESS", 8, 30913},
	{"PATRICIA", 8, 30914},
	{"TWEA", 4, 30915},
	{"LLWH", 4, 30916},
	{"DRIVING", 7, 30917},
	{"LSOO", 4, 30918},
	{"TENB", 4, 30919},
	{"EDDIE", 5, 30920},
	{"FDW", 3, 30921},
	{"UGANDA", 6, 30922},
	{"RSST", 4, 30923},
	{"PROVIDED", 8, 30924},
	{"SFIL", 4, 30925},
	{"GSHO", 4, 30926},
	{"FIRED", 5, 30927},
	{"RSTM", 4, 30928},
	{"YBEI", 4, 30929},
	{"HHAD", 4, 30930},
	{"ASVE", 4, 30931},
	{"ERYM", 4, 30932},
	{"HISTORICALLY", 12, 30933},
	{"CHPR", 4, 30934},
	{"HWIL", 4, 30935},
	{"PROT", 4, 30936},
	{"ADYT", 4, 30937},
	{"RYSE", 4, 30938},
	{"TRIVIA", 6, 30939},
	{"RTAK", 4, 30940},
	{"ADIDAS", 6, 30941},
	{"NVIN", 4, 30942},
	{"PERTH", 5, 30943},
	{"ZYE", 3, 30944},
	{"TRANSACTION", 11, 30945},
	{"FROG", 4, 30946},
	{"GRAMMAR", 7, 30947},
	{"USFO", 4, 30948},
	{"PROMOTION", 9, 30949},
	{"PICKUP", 6, 30950},
	{"RESIDENTIAL", 11, 30951},
	{"RDEA", 4, 30952},
	{"SYRIA", 5, 30953},
	{"NTFI", 4, 30954},
	{"ROFH", 4, 30955},
	{"HISU", 4, 30956},
	{"BOUG", 4, 30957},
	{"INQU", 4, 30958},
	{"THYO", 4, 30959},
	{"KLEIN", 5, 30960},
	{"SHOL", 4, 30961},
	{"NDSF", 4, 30962},
	{"YSON", 4, 30963},
	{"HARVEY", 6, 30964},
	{"TIRES", 5, 30965},
	{"EDPL", 4, 30966},
	{"LYPO", 4, 30967},
	{"LOGS", 4, 30968},
	{"TROV", 4, 30969},
	{"UNDERTAKEN", 10, 30970},
	{"EXCLUSIVE", 9, 30971},
	{"TGP", 3, 30972},
	{"RETRO", 5, 30973},
	{"WYM", 3, 30974},
	{"IPHO", 4, 30975},
	{"GUIDANCE", 8, 30976},
	{"ACHU", 4, 30977},
	{"STATEWIDE", 9, 30978},
	{"ANKLE", 5, 30979},
	{"SEMICONDUCTOR", 13, 30980},
	{"TYLI", 4, 30981},
	{"GREGORY", 7, 30982},
	{"EPISODES", 8, 30983},
	{"BOOLEAN", 7, 30984},
	{"CIRCULAR", 8, 30985},
	{"DGRO", 4, 30986},
	{"EGIR", 4, 30987},
	{"DIY", 3, 30988},
	{"RALG", 4, 30989},
	{"TPOL", 4, 30990},
	{"EATB", 4, 30991},
	{"CONVINCED", 9, 30992},
	{"MAINLAND", 8, 30993},
	{"NQUI", 4, 30994},
	{"BIAS", 4, 30995},
	{"ILLUSTRATIONS", 13, 30996},
	{"SUITS", 5, 30997},
	{"RARI", 4, 30998},
	{"IFET", 4, 30999},
	{"BUW", 3, 31000},
	{"WHEREVER", 8, 31001},
	{"HOOK", 4, 31002},
	{"CHANCES", 7, 31003},
	{"TFOL", 4, 31004},
	{"SWHY", 4, 31005},
	{"NHIM", 4, 31006},
	{"PRAISE", 6, 31007},
	{"NEEDLE", 6, 31008},
	{"ARG", 3, 31009},
	{"IRCL", 4, 31010},
	{"BEPR", 4, 31011},
	{"DAYB", 4, 31012},
	{"YBRI", 4, 31013},
	{"INTELLIGENT", 11, 31014},
	{"EQUATION", 8, 31015},
	{"RTSI", 4, 31016},
	{"RGEL", 4, 31017},
	{"ENTHUSIASM", 10, 31018},
	{"NREG", 4, 31019},
	{"BIZARRE", 7, 31020},
	{"OFMU", 4, 31021},
	{"SCARE", 5, 31022},
	{"GNAL", 4, 31023},
	{"GLENN", 5, 31024},
	{"REJU", 4, 31025},
	{"AUCKLAND", 8, 31026},
	{"WILDLIFE", 8, 31027},
	{"OVK", 3, 31028},
	{"FRUITS", 6, 31029},
	{"IDENTIFIER", 10, 31030},
	{"IKEW", 4, 31031},
	{"LDAT", 4, 31032},
	{"UTBE", 4, 31033},
	{"AYIT", 4, 31034},
	{"THME", 4, 31035},
	{"ASQU", 4, 31036},
	{"INVISIBLE", 9, 31037},
	{"CALCULATIONS", 12, 31038},
	{"USTF", 4, 31039},
	{"FFAM", 4, 31040},
	{"RELIEVE", 7, 31041},
	{"PREVENTION", 10, 31042},
	{"DOLL", 4, 31043},
	{"JPEG", 4, 31044},
	{"CONDUCTING", 10, 31045},
	{"NAGR", 4, 31046},
	{"STARTUP", 7, 31047},
	{"SIGNATURE", 9, 31048},
	{"SUNLIGHT", 8, 31049},
	{"FFRE", 4, 31050},
	{"SUZUKI", 6, 31051},
	{"NBEI", 4, 31052},
	{"SHAME", 5, 31053},
	{"ELECTRICAL", 10, 31054},
	{"OUSO", 4, 31055},
	{"ANAF", 4, 31056},
	{"TRINIDAD", 8, 31057},
	{"TIMING", 6, 31058},
	{"KISSING", 7, 31059},
	{"VESU", 4, 31060},
	{"OVEI", 4, 31061},
	{"WAL", 3, 31062},
	{"HANDY", 5, 31063},
	{"SWAP", 4, 31064},
	{"EXEMPT", 6, 31065},
	{"ACQUISITION", 11, 31066},
	{"NTSM", 4, 31067},
	{"CROPS", 5, 31068},
	{"MEHO", 4, 31069},
	{"GENUINE", 7, 31070},
	{"TRAVELER", 8, 31071},
	{"REDUCES", 7, 31072},
	{"IFEI", 4, 31073},
	{"ACCOMPLISHED", 12, 31074},
	{"CALCULATORS", 11, 31075},
	{"EXIT", 4, 31076},
	{"RESIDENCE", 9, 31077},
	{"DELICATE", 8, 31078},
	{"OPERA", 5, 31079},
	{"GEOMETRY", 8, 31080},
	{"SLOVAKIA", 8, 31081},
	{"GUILD", 5, 31082},
	{"DBEI", 4, 31083},
	{"LSZ", 3, 31084},
	{"STDI", 4, 31085},
	{"GORGEOUS", 8, 31086},
	{"CAPITOL", 7, 31087},
	{"DISHES", 6, 31088},
	{"ITHJ", 4, 31089},
	{"OUSH", 4, 31090},
	{"IEDF", 4, 31091},
	{"BARBADOS", 8, 31092},
	{"ACCOUNTING", 10, 31093},
	{"RDEC", 4, 31094},
	{"RDCO", 4, 31095},
	{"OTIV", 4, 31096},
	{"ITHY", 4, 31097},
	{"RYSC", 4, 31098},
	{"CHRYSLER", 8, 31099},
	{"YCLO", 4, 31100},
	{"ACKH", 4, 31101},
	{"EXTENDS", 7, 31102},
	{"FRAGRANCE", 9, 31103},
	{"MCDONALD", 8, 31104},
	{"REPLICA", 7, 31105},
	{"PLUMBING", 8, 31106},
	{"ILEH", 4, 31107},
	{"HATK", 4, 31108},
	{"ULDI", 4, 31109},
	{"DMAY", 4, 31110},
	{"ARSS", 4, 31111},
	{"DGEN", 4, 31112},
	{"EBUL", 4, 31113},
	{"CHAOS", 5, 31114},
	{"BRUSSELS", 8, 31115},
	{"AGEP", 4, 31116},
	{"NEIGHBORS", 9, 31117},
	{"MEPE", 4, 31118},
	{"RETC", 4, 31119},
	{"TRADES", 6, 31120},
	{"ORWE", 4, 31121},
	{"NTCH", 4, 31122},
	{"CKMA", 4, 31123},
	{"SUPERB", 6, 31124},
	{"CARVE", 5, 31125},
	{"EXPLORATION", 11, 31126},
	{"BUZZ", 4, 31127},
	{"TRANSPARENT", 11, 31128},
	{"SZY", 3, 31129},
	{"NUKE", 4, 31130},
	{"OLDW", 4, 31131},
	{"LAMP", 4, 31132},
	{"IRME", 4, 31133},
	{"ONSR", 4, 31134},
	{"RTOM", 4, 31135},
	{"NKER", 4, 31136},
	{"TRINITY", 7, 31137},
	{"ICOF", 4, 31138},
	{"TGRA", 4, 31139},
	{"CHARLESTON", 10, 31140},
	{"XJO", 3, 31141},
	{"ONLO", 4, 31142},
	{"NSTU", 4, 31143},
	{"NBUR", 4, 31144},
	{"HANDLED", 7, 31145},
	{"ATTRACTION", 10, 31146},
	{"LEGENDS", 7, 31147},
	{"EQUITY", 6, 31148},
	{"ONCR", 4, 31149},
	{"EIRN", 4, 31150},
	{"CHAMPIONS", 9, 31151},
	{"ONGH", 4, 31152},
	{"ENTITY", 6, 31153},
	{"YMAY", 4, 31154},
	{"ZZU", 3, 31155},
	{"UBK", 3, 31156},
	{"FLIP", 4, 31157},
	{"REGULATORY", 10, 31158},
	{"FLOORS", 6, 31159},
	{"SELECTIONS", 10, 31160},
	{"EORY", 4, 31161},
	{"PROJECTORS", 10, 31162},
	{"OADD", 4, 31163},
	{"ITYM", 4, 31164},
	{"CEFR", 4, 31165},
	{"ASGR", 4, 31166},
	{"INAPPROPRIATE", 13, 31167},
	{"LLOT", 4, 31168},
	{"AMID", 4, 31169},
	{"COMPARING", 9, 31170},
	{"SHANGHAI", 8, 31171},
	{"GHTR", 4, 31172},
	{"REALM", 5, 31173},
	{"SPEAKS", 6, 31174},
	{"BURTON", 6, 31175},
	{"PASTOR", 6, 31176},
	{"ARDH", 4, 31177},
	{"VOCATIONAL", 10, 31178},
	{"DAVIDSON", 8, 31179},
	{"NGBY", 4, 31180},
	{"COPIED", 6, 31181},
	{"ARHE", 4, 31182},
	{"SCOTIA", 6, 31183},
	{"SREQ", 4, 31184},
	{"FARMING", 7, 31185},
	{"GIBSON", 6, 31186},
	{"DIAGNOSE", 8, 31187},
	{"DERP", 4, 31188},
	{"ELFT", 4, 31189},
	{"IERA", 4, 31190},
	{"PHARMACIES", 10, 31191},
	{"TROY", 4, 31192},
	{"PARENTAL", 8, 31193},
	{"ORKC", 4, 31194},
	{"LYPA", 4, 31195},
	{"DNTH", 4, 31196},
	{"URYE", 4, 31197},
	{"XTJ", 3, 31198},
	{"EWSA", 4, 31199},
	{"ROLLER", 6, 31200},
	{"INTRODUCING", 11, 31201},
	{"BATCH", 5, 31202},
	{"IDENTICAL", 9, 31203},
	{"FPLA", 4, 31204},
	{"AHAL", 4, 31205},
	{"RESUME", 6, 31206},
	{"AYIS", 4, 31207},
	{"GRIN", 4, 31208},
	{"NLYP", 4, 31209},
	{"EEMA", 4, 31210},
	{"ENVELOPE", 8, 31211},
	{"NICOLE", 6, 31212},
	{"EISP", 4, 31213},
	{"LATINO", 6, 31214},
	{"GHANA", 5, 31215},
	{"EDGES", 5, 31216},
	{"BLEND", 5, 31217},
	{"MIXING", 6, 31218},
	{"HANDLES", 7, 31219},
	{"FEVE", 4, 31220},
	{"KEDF", 4, 31221},
	{"EGJ", 3, 31222},
	{"NSCR", 4, 31223},
	{"FITTED", 6, 31224},
	{"CLERK", 5, 31225},
	{"ALBUQUERQUE", 11, 31226},
	{"DISTINGUISHED", 13, 31227},
	{"ASTHMA", 6, 31228},
	{"PROJECTED", 9, 31229},
	{"DONOR", 5, 31230},
	{"ASSUMPTIONS", 11, 31231},
	{"SHAREHOLDERS", 12, 31232},
	{"GYM", 3, 31233},
	{"LSOD", 4, 31234},
	{"TWINS", 5, 31235},
	{"IMEB", 4, 31236},
	{"ARSL", 4, 31237},
	{"SUSPEND", 7, 31238},
	{"ENAP", 4, 31239},
	{"VERBAL", 6, 31240},
	{"DEDICATE", 8, 31241},
	{"ZOPE", 4, 31242},
	{"REGULATED", 9, 31243},
	{"CKWA", 4, 31244},
	{"NLYW", 4, 31245},
	{"AKEU", 4, 31246},
	{"TRIANGLE", 8, 31247},
	{"MBAT", 4, 31248},
	{"AMEND", 5, 31249},
	{"EKID", 4, 31250},
	{"FGHA", 4, 31251},
	{"JAZZ", 4, 31252},
	{"PROCESSING", 10, 31253},
	{"YLH", 3, 31254},
	{"HEIG", 4, 31255},
	{"ANTICIPATED", 11, 31256},
	{"EXPERTISE", 9, 31257},
	{"NHAL", 4, 31258},
	{"RTYA", 4, 31259},
	{"OLLS", 4, 31260},
	{"SUM", 3, 31261},
	{"EDGR", 4, 31262},
	{"SPECTRUM", 8, 31263},
	{"PURPLE", 6, 31264},
	{"ORIENTAL", 8, 31265},
	{"UALA", 4, 31266},
	{"YTOW", 4, 31267},
	{"OWIS", 4, 31268},
	{"ILDE", 4, 31269},
	{"JUDICIAL", 8, 31270},
	{"MEBU", 4, 31271},
	{"WINDSOR", 7, 31272},
	{"MILD", 4, 31273},
	{"PRECISE", 7, 31274},
	{"ZAMBIA", 6, 31275},
	{"FTED", 4, 31276},
	{"COMPLETING", 10, 31277},
	{"GMBH", 4, 31278},
	{"DDEV", 4, 31279},
	{"IONU", 4, 31280},
	{"YGEN", 4, 31281},
	{"BUF", 3, 31282},
	{"YLOR", 4, 31283},
	{"CANDLE", 6, 31284},
	{"EZJ", 3, 31285},
	{"LLOU", 4, 31286},
	{"MBUT", 4, 31287},
	{"DIMP", 4, 31288},
	{"MHAS", 4, 31289},
	{"HEYG", 4, 31290},
	{"HYDROGEN", 8, 31291},
	{"NKIT", 4, 31292},
	{"WEBSHOTS", 8, 31293},
	{"ASTB", 4, 31294},
	{"LASER", 5, 31295},
	{"EGIA", 4, 31296},
	{"ISVI", 4, 31297},
	{"ALOC", 4, 31298},
	{"GNJ", 3, 31299},
	{"SPRINT", 6, 31300},
	{"NGSF", 4, 31301},
	{"LKNO", 4, 31302},
	{"DIPLOMATIC", 10, 31303},
	{"NMAD", 4, 31304},
	{"ALSS", 4, 31305},
	{"SHOC", 4, 31306},
	{"OXYGEN", 6, 31307},
	{"BUSINESSMAN", 11, 31308},
	{"YUND", 4, 31309},
	{"EAUS", 4, 31310},
	{"ASYO", 4, 31311},
	{"FIRMLY", 6, 31312},
	{"CHICK", 5, 31313},
	{"DMOV", 4, 31314},
	{"YINF", 4, 31315},
	{"SUSPICION", 9, 31316},
	{"OTWO", 4, 31317},
	{"EOFN", 4, 31318},
	{"ONTB", 4, 31319},
	{"REPORTING", 9, 31320},
	{"SIMS", 4, 31321},
	{"PEEL", 4, 31322},
	{"OADA", 4, 31323},
	{"BUTR", 4, 31324},
	{"DYNAMIC", 7, 31325},
	{"ORAI", 4, 31326},
	{"OGOT", 4, 31327},
	{"IRFO", 4, 31328},
	{"COPYRIGHTED", 11, 31329},
	{"YCLI", 4, 31330},
	{"DETERMINATION", 13, 31331},
	{"ACHM", 4, 31332},
	{"INPUTS", 6, 31333},
	{"IMNO", 4, 31334},
	{"WARRANTIES", 10, 31335},
	{"LLTA", 4, 31336},
	{"GENOME", 6, 31337},
	{"ESCORTS", 7, 31338},
	{"ENDORSE", 7, 31339},
	{"THONG", 5, 31340},
	{"ERMU", 4, 31341},
	{"ABSTRACT", 8, 31342},
	{"PAPERBACKS", 10, 31343},
	{"TSTU", 4, 31344},
	{"COACHES", 7, 31345},
	{"VESSELS", 7, 31346},
	{"HARBOUR", 7, 31347},
	{"WALKS", 5, 31348},
	{"SUCKS", 5, 31349},
	{"LSOL", 4, 31350},
	{"KEYBOARDS", 9, 31351},
	{"AYMA", 4, 31352},
	{"DGED", 4, 31353},
	{"TONM", 4, 31354},
	{"ROPI", 4, 31355},
	{"IANM", 4, 31356},
	{"SAGE", 4, 31357},
	{"TFEE", 4, 31358},
	{"KNIVES", 6, 31359},
	{"TBRI", 4, 31360},
	{"FCHI", 4, 31361},
	{"VANISH", 6, 31362},
	{"UPAT", 4, 31363},
	{"SVIL", 4, 31364},
	{"CONSCIOUS", 9, 31365},
	{"MTHI", 4, 31366},
	{"BATH", 4, 31367},
	{"ALTOGETHER", 10, 31368},
	{"NTWE", 4, 31369},
	{"HONORS", 6, 31370},
	{"INDIE", 5, 31371},
	{"REFLECTED", 9, 31372},
	{"ASWH", 4, 31373},
	{"UNIFIED", 7, 31374},
	{"MINIMIZE", 8, 31375},
	{"BONES", 5, 31376},
	{"NOMINEE", 7, 31377},
	{"BREED", 5, 31378},
	{"MTOA", 4, 31379},
	{"DETECTOR", 8, 31380},
	{"IGNORED", 7, 31381},
	{"POLAR", 5, 31382},
	{"ATLO", 4, 31383},
	{"FALLEN", 6, 31384},
	{"DMAD", 4, 31385},
	{"LGAM", 4, 31386},
	{"ORKF", 4, 31387},
	{"NEME", 4, 31388},
	{"RESPIRATORY", 11, 31389},
	{"ALIEN", 5, 31390},
	{"HADH", 4, 31391},
	{"GDOM", 4, 31392},
	{"NOTIFICATIONS", 13, 31393},
	{"MSGID", 5, 31394},
	{"TFUL", 4, 31395},
	{"HOWC", 4, 31396},
	{"NMAT", 4, 31397},
	{"PIZZA", 5, 31398},
	{"UNLE", 4, 31399},
	{"SILK", 4, 31400},
	{"INVOICE", 7, 31401},
	{"RECIPIENT", 9, 31402},
	{"IALM", 4, 31403},
	{"EVALUATING", 10, 31404},
	{"ARGI", 4, 31405},
	{"HANP", 4, 31406},
	{"PILLOW", 6, 31407},
	{"ASIG", 4, 31408},
	{"LSCH", 4, 31409},
	{"USTM", 4, 31410},
	{"FZH", 3, 31411},
	{"BANKING", 7, 31412},
	{"STARTING", 8, 31413},
	{"SUBCOMMITTEE", 12, 31414},
	{"MAGNITUDE", 9, 31415},
	{"SUSE", 4, 31416},
	{"MATERNITY", 9, 31417},
	{"BACKED", 6, 31418},
	{"WWHA", 4, 31419},
	{"DEHI", 4, 31420},
	{"ENYE", 4, 31421},
	{"ALFRED", 6, 31422},
	{"ZYR", 3, 31423},
	{"HEOB", 4, 31424},
	{"CAREY", 5, 31425},
	{"DNEV", 4, 31426},
	{"OACT", 4, 31427},
	{"ICHR", 4, 31428},
	{"MOTELS", 6, 31429},
	{"FORMING", 7, 31430},
	{"ECOO", 4, 31431},
	{"LYHI", 4, 31432},
	{"EMBASSY", 7, 31433},
	{"LLPL", 4, 31434},
	{"UZT", 3, 31435},
	{"JOURNALISTS", 11, 31436},
	{"USST", 4, 31437},
	{"INVENTORY", 9, 31438},
	{"DANNY", 5, 31439},
	{"REBECCA", 7, 31440},
	{"ARDP", 4, 31441},
	{"UEIN", 4, 31442},
	{"REPAIR", 6, 31443},
	{"CIVIC", 5, 31444},
	{"PROCEEDS", 8, 31445},
	{"RYLI", 4, 31446},
	{"PHOTOGRAPHY", 11, 31447},
	{"INDIRECT", 8, 31448},
	{"DYNAMICS", 8, 31449},
	{"AMONGST", 7, 31450},
	{"WOOL", 4, 31451},
	{"FOUNDATIONS", 11, 31452},
	{"ENPA", 4, 31453},
	{"MSGSTR", 6, 31454},
	{"RRYI", 4, 31455},
	{"VOLLEYBALL", 10, 31456},
	{"LPRI", 4, 31457},
	{"ITDI", 4, 31458},
	{"CKWI", 4, 31459},
	{"ADIPEX", 6, 31460},
	{"STUMBLE", 7, 31461},
	{"RCIT", 4, 31462},
	{"KCY", 3, 31463},
	{"PROMISING", 9, 31464},
	{"HOWH", 4, 31465},
	{"DIABETES", 8, 31466},
	{"NECESSITY", 9, 31467},
	{"FULT", 4, 31468},
	{"RSTD", 4, 31469},
	{"PURSUIT", 7, 31470},
	{"AKEM", 4, 31471},
	{"POSTER", 6, 31472},
	{"SHARED", 6, 31473},
	{"RDSH", 4, 31474},
	{"EATING", 6, 31475},
	{"TOOLBOX", 7, 31476},
	{"PAYM", 4, 31477},
	{"SERVANT", 7, 31478},
	{"DSWH", 4, 31479},
	{"YISS", 4, 31480},
	{"TRUL", 4, 31481},
	{"ILAT", 4, 31482},
	{"MARINA", 6, 31483},
	{"LIABILITIES", 11, 31484},
	{"PRIZES", 6, 31485},
	{"UREH", 4, 31486},
	{"DIVINE", 6, 31487},
	{"BOSNIA", 6, 31488},
	{"STATUE", 6, 31489},
	{"UROF", 4, 31490},
	{"ELYF", 4, 31491},
	{"EROB", 4, 31492},
	{"BROWSERS", 8, 31493},
	{"AILO", 4, 31494},
	{"DECREASED", 9, 31495},
	{"NTUN", 4, 31496},
	{"PATIO", 5, 31497},
	{"LGOV", 4, 31498},
	{"SURFING", 7, 31499},
	{"OWOU", 4, 31500},
	{"ENROLL", 6, 31501},
	{"RELIABILITY", 11, 31502},
	{"NDJA", 4, 31503},
	{"LLOYD", 5, 31504},
	{"TCEN", 4, 31505},
	{"SPLI", 4, 31506},
	{"ANAB", 4, 31507},
	{"DESCRIBING", 10, 31508},
	{"HTWO", 4, 31509},
	{"OPTICS", 6, 31510},
	{"TLEI", 4, 31511},
	{"ONMI", 4, 31512},
	{"UNDERTAKE", 9, 31513},
	{"ACKG", 4, 31514},
	{"EYED", 4, 31515},
	{"TTOU", 4, 31516},
	{"QUOTATIONS", 10, 31517},
	{"OBOT", 4, 31518},
	{"OUTPUT", 6, 31519},
	{"RKZ", 3, 31520},
	{"KEUP", 4, 31521},
	{"DESTINATION", 11, 31522},
	{"TWOA", 4, 31523},
	{"BRIGHTON", 8, 31524},
	{"BEANS", 5, 31525},
	{"BOOKMARKS", 9, 31526},
	{"ELLIS", 5, 31527},
	{"HAPPINESS", 9, 31528},
	{"DISABLE", 7, 31529},
	{"BSEQ", 4, 31530},
	{"JKO", 3, 31531},
	{"FMIL", 4, 31532},
	{"LEONARD", 7, 31533},
	{"AFGH", 4, 31534},
	{"YFIR", 4, 31535},
	{"TEENAGE", 7, 31536},
	{"LENDING", 7, 31537},
	{"SWORD", 5, 31538},
	{"LYHO", 4, 31539},
	{"LWAR", 4, 31540},
	{"NKAN", 4, 31541},
	{"OOPS", 4, 31542},
	{"RFRE", 4, 31543},
	{"RACISM", 6, 31544},
	{"NIPPLE", 6, 31545},
	{"AILU", 4, 31546},
	{"LDGO", 4, 31547},
	{"NDOP", 4, 31548},
	{"ONTU", 4, 31549},
	{"RYPR", 4, 31550},
	{"OLSA", 4, 31551},
	{"SEARCHED", 8, 31552},
	{"TCHU", 4, 31553},
	{"EDOI", 4, 31554},
	{"RIVERSIDE", 9, 31555},
	{"BATHROOMS", 9, 31556},
	{"PLAINS", 6, 31557},
	{"SLAP", 4, 31558},
	{"SKU", 3, 31559},
	{"INSTRUCTIONAL", 13, 31560},
	{"IFUL", 4, 31561},
	{"TENDER", 6, 31562},
	{"RAYMOND", 7, 31563},
	{"ANWO", 4, 31564},
	{"XXA", 3, 31565},
	{"INSIGHTS", 8, 31566},
	{"PARADE", 6, 31567},
	{"ABILITIES", 9, 31568},
	{"NFRE", 4, 31569},
	{"INITIATED", 9, 31570},
	{"WOUN", 4, 31571},
	{"DSMA", 4, 31572},
	{"DEPARTURE", 9, 31573},
	{"SULLIVAN", 8, 31574},
	{"PRODUCTIVE", 10, 31575},
	{"EGES", 4, 31576},
	{"INPUT", 5, 31577},
	{"MIDWEST", 7, 31578},
	{"TKIN", 4, 31579},
	{"EGED", 4, 31580},
	{"KARAOKE", 7, 31581},
	{"OCKO", 4, 31582},
	{"GRAVITY", 7, 31583},
	{"QVI", 3, 31584},
	{"LYBY", 4, 31585},
	{"NGSY", 4, 31586},
	{"RUME", 4, 31587},
	{"UISE", 4, 31588},
	{"TRIBAL", 6, 31589},
	{"EYSH", 4, 31590},
	{"LANCASTER", 9, 31591},
	{"SUSPENDED", 9, 31592},
	{"LYIT", 4, 31593},
	{"FOOL", 4, 31594},
	{"HEREBY", 6, 31595},
	{"JULIA", 5, 31596},
	{"CONTAINERS", 10, 31597},
	{"OCLA", 4, 31598},
	{"ATTITUDES", 9, 31599},
	{"KARL", 4, 31600},
	{"HOPEFULLY", 9, 31601},
	{"BERRY", 5, 31602},
	{"EHOR", 4, 31603},
	{"XYF", 3, 31604},
	{"THCH", 4, 31605},
	{"STEX", 4, 31606},
	{"YEDB", 4, 31607},
	{"HERY", 4, 31608},
	{"BERMUDA", 7, 31609},
	{"RMSA", 4, 31610},
	{"ANGEL", 5, 31611},
	{"UGHM", 4, 31612},
	{"STADIUM", 7, 31613},
	{"RALH", 4, 31614},
	{"OWCO", 4, 31615},
	{"COLLECTOR", 9, 31616},
	{"AMANDA", 6, 31617},
	{"SOCIOLOGY", 9, 31618},
	{"MOBILES", 7, 31619},
	{"OANY", 4, 31620},
	{"ELEGANT", 7, 31621},
	{"RYMA", 4, 31622},
	{"SCREENSHOT", 10, 31623},
	{"EXHIBITIONS", 11, 31624},
	{"UNDB", 4, 31625},
	{"KELKOO", 6, 31626},
	{"STEEP", 5, 31627},
	{"O'CLOCK", 7, 31628},
	{"ADOU", 4, 31629},
	{"YPOL", 4, 31630},
	{"RETRIEVED", 9, 31631},
	{"EXHIBITS", 8, 31632},
	{"OLOS", 4, 31633},
	{"CONSORTIUM", 10, 31634},
	{"DIES", 4, 31635},
	{"UWAN", 4, 31636},
	{"TERRACE", 7, 31637},
	{"SHARPLY", 7, 31638},
	{"READILY", 7, 31639},
	{"LDME", 4, 31640},
	{"REPLIED", 7, 31641},
	{"PFRO", 4, 31642},
	{"TMAD", 4, 31643},
	{"SEAFOOD", 7, 31644},
	{"NOVELS", 6, 31645},
	{"RRP", 3, 31646},
	{"RECIPIENTS", 10, 31647},
	{"KEOF", 4, 31648},
	{"EEUR", 4, 31649},
	{"DELICIOUS", 9, 31650},
	{"TRADITIONS", 10, 31651},
	{"HQUA", 4, 31652},
	{"PUNISH", 6, 31653},
	{"SUFFERING", 9, 31654},
	{"OOKP", 4, 31655},
	{"DECENT", 6, 31656},
	{"BID", 3, 31657},
	{"TOUCHDOWN", 9, 31658},
	{"ORSS", 4, 31659},
	{"DOSO", 4, 31660},
	{"HARDWARE", 8, 31661},
	{"FINITE", 6, 31662},
	{"KIDNEY", 6, 31663},
	{"GOFA", 4, 31664},
	{"PERIODICALLY", 12, 31665},
	{"FIXES", 5, 31666},
	{"SENDS", 5, 31667},
	{"ELFO", 4, 31668},
	{"DURABLE", 7, 31669},
	{"RULING", 6, 31670},
	{"FCZ", 3, 31671},
	{"DBER", 4, 31672},
	{"GINC", 4, 31673},
	{"CASUAL", 6, 31674},
	{"MAZDA", 5, 31675},
	{"ALLIED", 6, 31676},
	{"SRAT", 4, 31677},
	{"RSID", 4, 31678},
	{"FULL-TIME", 9, 31679},
	{"IMPORT", 6, 31680},
	{"THROWS", 6, 31681},
	{"OMCO", 4, 31682},
	{"MOISTURE", 8, 31683},
	{"ACCURACY", 8, 31684},
	{"HUNGARIAN", 9, 31685},
	{"ECEL", 4, 31686},
	{"GELY", 4, 31687},
	{"ROSTER", 6, 31688},
	{"SFUN", 4, 31689},
	{"ALGR", 4, 31690},
	{"IESM", 4, 31691},
	{"ICHP", 4, 31692},
	{"TOILET", 6, 31693},
	{"RLOS", 4, 31694},
	{"SWAR", 4, 31695},
	{"BOLD", 4, 31696},
	{"HESK", 4, 31697},
	{"UTPE", 4, 31698},
	{"USRE", 4, 31699},
	{"REFERRING", 9, 31700},
	{"TBRO", 4, 31701},
	{"SYMANTEC", 8, 31702},
	{"IKED", 4, 31703},
	{"EONC", 4, 31704},
	{"SPENCER", 7, 31705},
	{"GARBAGE", 7, 31706},
	{"TOVI", 4, 31707},
	{"WICHITA", 7, 31708},
	{"CANCEL", 6, 31709},
	{"DEADLINE", 8, 31710},
	{"NASDAQ", 6, 31711},
	{"URUGUAY", 7, 31712},
	{"DAWN", 4, 31713},
	{"BROKER", 6, 31714},
	{"ANNUALLY", 8, 31715},
	{"WHALE", 5, 31716},
	{"ARFO", 4, 31717},
	{"TIMER", 5, 31718},
	{"ADEP", 4, 31719},
	{"EYFO", 4, 31720},
	{"TABLETS", 7, 31721},
	{"YSMA", 4, 31722},
	{"TYPR", 4, 31723},
	{"JAW", 3, 31724},
	{"HEUP", 4, 31725},
	{"ISOLATE", 7, 31726},
	{"TUNING", 6, 31727},
	{"GOTTEN", 6, 31728},
	{"YTAK", 4, 31729},
	{"NDBL", 4, 31730},
	{"LBEI", 4, 31731},
	{"EDUCATORS", 9, 31732},
	{"NMUS", 4, 31733},
	{"TYLER", 5, 31734},
	{"OSTM", 4, 31735},
	{"PRACTICALLY", 11, 31736},
	{"ASSEMBLY", 8, 31737},
	{"FUTURES", 7, 31738},
	{"URTA", 4, 31739},
	{"REAR", 4, 31740},
	{"DGAM", 4, 31741},
	{"VERSE", 5, 31742},
	{"FYIN", 4, 31743},
	{"SYJ", 3, 31744},
	{"LYPE", 4, 31745},
	{"HIGHS", 5, 31746},
	{"GENEROUS", 8, 31747},
	{"HUMANITIES", 10, 31748},
	{"INDEPENDENTLY", 13, 31749},
	{"WANTING", 7, 31750},
	{"HADF", 4, 31751},
	{"EPLE", 4, 31752},
	{"SESF", 4, 31753},
	{"RBAR", 4, 31754},
	{"UCLE", 4, 31755},
	{"LAUNCHES", 8, 31756},
	{"RECEPTION", 9, 31757},
	{"PERFORMER", 9, 31758},
	{"PROHIBIT", 8, 31759},
	{"DESCEND", 7, 31760},
	{"IPAQ", 4, 31761},
	{"ALIGNMENT", 9, 31762},
	{"MASTURBATING", 12, 31763},
	{"HENDERSON", 9, 31764},
	{"GGED", 4, 31765},
	{"BRITANNICA", 10, 31766},
	{"COMM", 4, 31767},
	{"FYY", 3, 31768},
	{"AGLE", 4, 31769},
	{"ELLEN", 5, 31770},
	{"COMPETITORS", 11, 31771},
	{"IFTE", 4, 31772},
	{"COLLABORATION", 13, 31773},
	{"DAGR", 4, 31774},
	{"AYCO", 4, 31775},
	{"ANOU", 4, 31776},
	{"REVOLUTIONARY", 13, 31777},
	{"FAINT", 5, 31778},
	{"IALB", 4, 31779},
	{"DMED", 4, 31780},
	{"CHWO", 4, 31781},
	{"NDLY", 4, 31782},
	{"RCEL", 4, 31783},
	{"TOWERS", 6, 31784},
	{"HEDF", 4, 31785},
	{"COASTAL", 7, 31786},
	{"RNOO", 4, 31787},
	{"RTOW", 4, 31788},
	{"ULQ", 3, 31789},
	{"PAYI", 4, 31790},
	{"INTENT", 6, 31791},
	{"SCAN", 4, 31792},
	{"HTIM", 4, 31793},
	{"RACKS", 5, 31794},
	{"LACE", 4, 31795},
	{"NKEE", 4, 31796},
	{"ETEM", 4, 31797},
	{"EROY", 4, 31798},
	{"RAGE", 4, 31799},
	{"OLDB", 4, 31800},
	{"VISIBILITY", 10, 31801},
	{"LATITUDE", 8, 31802},
	{"DIMINISH", 8, 31803},
	{"EHUM", 4, 31804},
	{"FYG", 3, 31805},
	{"DEPOSITS", 8, 31806},
	{"ENLY", 4, 31807},
	{"AFOU", 4, 31808},
	{"BEVERLY", 7, 31809},
	{"SCAU", 4, 31810},
	{"MISTRESS", 8, 31811},
	{"TRUSTEES", 8, 31812},
	{"ONBR", 4, 31813},
	{"MPTE", 4, 31814},
	{"LONELY", 6, 31815},
	{"PRO", 3, 31816},
	{"YREG", 4, 31817},
	{"DUNCAN", 6, 31818},
	{"ORTG", 4, 31819},
	{"SCARY", 5, 31820},
	{"EEPA", 4, 31821},
	{"RGIA", 4, 31822},
	{"REPRINTS", 8, 31823},
	{"OSOP", 4, 31824},
	{"HART", 4, 31825},
	{"IGZ", 3, 31826},
	{"BERNARD", 7, 31827},
	{"RESOLUTIONS", 11, 31828},
	{"MENT", 4, 31829},
	{"ACCESSING", 9, 31830},
	{"REAG", 4, 31831},
	{"TUBES", 5, 31832},
	{"SILLY", 5, 31833},
	{"LYFI", 4, 31834},
	{"LYAB", 4, 31835},
	{"ATTEMPTED", 9, 31836},
	{"OFFERING", 8, 31837},
	{"ANEC", 4, 31838},
	{"EDVE", 4, 31839},
	{"ERVO", 4, 31840},
	{"STBU", 4, 31841},
	{"NSBU", 4, 31842},
	{"URTS", 4, 31843},
	{"EFEL", 4, 31844},
	{"ERDR", 4, 31845},
	{"TUCK", 4, 31846},
	{"COL", 3, 31847},
	{"MIDLANDS", 8, 31848},
	{"FLOYD", 5, 31849},
	{"RONALD", 6, 31850},
	{"ANALYSTS", 8, 31851},
	{"YFRI", 4, 31852},
	{"XVO", 3, 31853},
	{"EROP", 4, 31854},
	{"QUEUE", 5, 31855},
	{"ORIZ", 4, 31856},
	{"RELUCTANT", 9, 31857},
	{"DONM", 4, 31858},
	{"OYV", 3, 31859},
	{"STATUTE", 7, 31860},
	{"EDMU", 4, 31861},
	{"TRANCE", 6, 31862},
	{"LOCALE", 6, 31863},
	{"ICKT", 4, 31864},
	{"RMOT", 4, 31865},
	{"NICHOLAS", 8, 31866},
	{"POPULARITY", 10, 31867},
	{"AYAF", 4, 31868},
	{"BIOL", 4, 31869},
	{"TISW", 4, 31870},
	{"QUANTITY", 8, 31871},
	{"YSUP", 4, 31872},
	{"NDFL", 4, 31873},
	{"YTOH", 4, 31874},
	{"YMON", 4, 31875},
	{"NALH", 4, 31876},
	{"HLAN", 4, 31877},
	{"AUTOMOBILE", 10, 31878},
	{"BUNDLE", 6, 31879},
	{"RKTH", 4, 31880},
	{"HAMMER", 6, 31881},
	{"MATHEMATICS", 11, 31882},
	{"WITNESSES", 9, 31883},
	{"UDDE", 4, 31884},
	{"ROWS", 4, 31885},
	{"ADMINISTERED", 12, 31886},
	{"YUJ", 3, 31887},
	{"YINV", 4, 31888},
	{"AUTOMATICALLY", 13, 31889},
	{"CART", 4, 31890},
	{"TISU", 4, 31891},
	{"KFRO", 4, 31892},
	{"ORRU", 4, 31893},
	{"SKINS", 5, 31894},
	{"MAILED", 6, 31895},
	{"IRPR", 4, 31896},
	{"FUJITSU", 7, 31897},
	{"SPELLING", 8, 31898},
	{"CONFESS", 7, 31899},
	{"ARCTIC", 6, 31900},
	{"EXAMS", 5, 31901},
	{"REAW", 4, 31902},
	{"REWARDS", 7, 31903},
	{"WYEA", 4, 31904},
	{"FREDERICK", 9, 31905},
	{"ELDER", 5, 31906},
	{"RRYA", 4, 31907},
	{"OBTA", 4, 31908},
	{"YBEL", 4, 31909},
	{"MEDICAID", 8, 31910},
	{"LSWE", 4, 31911},
	{"OUTSTANDING", 11, 31912},
	{"TREO", 4, 31913},
	{"INFRARED", 8, 31914},
	{"SOVI", 4, 31915},
	{"TESB", 4, 31916},
	{"BOW", 3, 31917},
	{"GODS", 4, 31918},
	{"CANL", 4, 31919},
	{"NZR", 3, 31920},
	{"WELSH", 5, 31921},
	{"WTHI", 4, 31922},
	{"UTFI", 4, 31923},
	{"IDEOLOGICAL", 11, 31924},
	{"QUARTERS", 8, 31925},
	{"BEON", 4, 31926},
	{"STOLEN", 6, 31927},
	{"HTRA", 4, 31928},
	{"YGN", 3, 31929},
	{"SUBLIMEDIRECTORY", 16, 31930},
	{"HIDDEN", 6, 31931},
	{"ANMO", 4, 31932},
	{"REALISTIC", 9, 31933},
	{"SCUL", 4, 31934},
	{"SOONEST", 7, 31935},
	{"BARN", 4, 31936},
	{"GTOO", 4, 31937},
	{"HAITI", 5, 31938},
	{"DISTURBED", 9, 31939},
	{"DETERMINES", 10, 31940},
	{"AXV", 3, 31941},
	{"AYWA", 4, 31942},
	{"TLOS", 4, 31943},
	{"POLY", 4, 31944},
	{"IMBE", 4, 31945},
	{"SHORTAGE", 8, 31946},
	{"LIABILITY", 9, 31947},
	{"EARS", 4, 31948},
	{"NDPI", 4, 31949},
	{"ENLA", 4, 31950},
	{"OYZ", 3, 31951},
	{"DOD", 3, 31952},
	{"OVERSEE", 7, 31953},
	{"NAUS", 4, 31954},
	{"COURTROOM", 9, 31955},
	{"NDYE", 4, 31956},
	{"NATURALS", 8, 31957},
	{"BEMO", 4, 31958},
	{"OFIG", 4, 31959},
	{"ADWA", 4, 31960},
	{"LENDERS", 7, 31961},
	{"YHIG", 4, 31962},
	{"PHARMACOLOGY", 12, 31963},
	{"FITTING", 7, 31964},
	{"FIXTURES", 8, 31965},
	{"BLOGGERS", 8, 31966},
	{"COOPERATE", 9, 31967},
	{"XTER", 4, 31968},
	{"AGREES", 6, 31969},
	{"PASSENGERS", 10, 31970},
	{"VACCINE", 7, 31971},
	{"QUANTITIES", 10, 31972},
	{"ONOC", 4, 31973},
	{"RANCH", 5, 31974},
	{"PETERSBURG", 10, 31975},
	{"OFBI", 4, 31976},
	{"RTOC", 4, 31977},
	{"TINP", 4, 31978},
	{"RKON", 4, 31979},
	{"POWERPOINT", 10, 31980},
	{"SYMBOLIC", 8, 31981},
	{"UCHS", 4, 31982},
	{"ASSOCIATED", 10, 31983},
	{"EROW", 4, 31984},
	{"STDA", 4, 31985},
	{"STFE", 4, 31986},
	{"MYSE", 4, 31987},
	{"CONS", 4, 31988},
	{"SURPLUS", 7, 31989},
	{"ENAD", 4, 31990},
	{"SONIC", 5, 31991},
	{"ERKI", 4, 31992},
	{"NTDI", 4, 31993},
	{"AIDM", 4, 31994},
	{"MPTO", 4, 31995},
	{"OBITUARIES", 10, 31996},
	{"CIRCUIT", 7, 31997},
	{"PEDB", 4, 31998},
	{"YPRI", 4, 31999},
	{"CHEERS", 6, 32000},
	{"TAXI", 4, 32001},
	{"NXR", 3, 32002},
	{"SUBSEQUENTLY", 12, 32003},
	{"DIAMOND", 7, 32004},
	{"CREDIBILITY", 11, 32005},
	{"TLYR", 4, 32006},
	{"BELARUS", 7, 32007},
	{"ZONING", 6, 32008},
	{"PROVIDENCE", 10, 32009},
	{"AYSC", 4, 32010},
	{"FUNCTIONAL", 10, 32011},
	{"IROF", 4, 32012},
	{"BACKGROUNDS", 11, 32013},
	{"TREASURER", 9, 32014},
	{"GUITARS", 7, 32015},
	{"AWIL", 4, 32016},
	{"ANKL", 4, 32017},
	{"AELI", 4, 32018},
	{"ARTIFICIAL", 10, 32019},
	{"CONTINENT", 9, 32020},
	{"DTON", 4, 32021},
	{"FLOORING", 8, 32022},
	{"NTPL", 4, 32023},
	{"LIGHTWEIGHT", 11, 32024},
	{"ETHIOPIA", 8, 32025},
	{"ITEW", 4, 32026},
	{"SELF-ESTEEM", 11, 32027},
	{"HOMELAND", 8, 32028},
	{"BTAI", 4, 32029},
	{"DISAPPOINTED", 12, 32030},
	{"MIGHTY", 6, 32031},
	{"ATHLETES", 8, 32032},
	{"ROCKET", 6, 32033},
	{"DBAN", 4, 32034},
	{"TRANSCRIPTION", 13, 32035},
	{"IMPROVED", 8, 32036},
	{"OSTW", 4, 32037},
	{"TIFU", 4, 32038},
	{"OBEF", 4, 32039},
	{"VEDW", 4, 32040},
	{"MUSL", 4, 32041},
	{"ELYP", 4, 32042},
	{"INMATE", 6, 32043},
	{"WOLF", 4, 32044},
	{"HOLMES", 6, 32045},
	{"COMPLICATIONS", 13, 32046},
	{"PRECIOUS", 8, 32047},
	{"SCHOLARS", 8, 32048},
	{"DPI", 3, 32049},
	{"SCRIPTING", 9, 32050},
	{"REMEMBERED", 10, 32051},
	{"ROFM", 4, 32052},
	{"OOKF", 4, 32053},
	{"THDR", 4, 32054},
	{"TRAILER", 7, 32055},
	{"DDRI", 4, 32056},
	{"CHESTER", 7, 32057},
	{"INOV", 4, 32058},
	{"ESSR", 4, 32059},
	{"TEDG", 4, 32060},
	{"SNAPSHOT", 8, 32061},
	{"UYV", 3, 32062},
	{"CARING", 6, 32063},
	{"LOC", 3, 32064},
	{"WORN", 4, 32065},
	{"SYNTHETIC", 9, 32066},
	{"AYWE", 4, 32067},
	{"MHER", 4, 32068},
	{"ETCO", 4, 32069},
	{"SHAW", 4, 32070},
	{"SEGMENTS", 8, 32071},
	{"KESM", 4, 32072},
	{"ROMANCE", 7, 32073},
	{"LTIE", 4, 32074},
	{"RKIS", 4, 32075},
	{"DILEMMA", 7, 32076},
	{"TESTAMENT", 9, 32077},
	{"EXPO", 4, 32078},
	{"TIDE", 4, 32079},
	{"OWCA", 4, 32080},
	{"STIFF", 5, 32081},
	{"XOB", 3, 32082},
	{"SPECIFICS", 9, 32083},
	{"ITUNES", 6, 32084},
	{"LATELY", 6, 32085},
	{"GASOLINE", 8, 32086},
	{"OWAL", 4, 32087},
	{"RIDICULOUS", 10, 32088},
	{"LLHO", 4, 32089},
	{"OWMU", 4, 32090},
	{"PYV", 3, 32091},
	{"MATE", 4, 32092},
	{"NESP", 4, 32093},
	{"DUTCH", 5, 32094},
	{"BANKRUPTCY", 10, 32095},
	{"RBUS", 4, 32096},
	{"NLYF", 4, 32097},
	{"YGRO", 4, 32098},
	{"LYAP", 4, 32099},
	{"TOFG", 4, 32100},
	{"BURIED", 6, 32101},
	{"EMEE", 4, 32102},
	{"WASJ", 4, 32103},
	{"PLIT", 4, 32104},
	{"NEWBIE", 6, 32105},
	{"XHIB", 4, 32106},
	{"OLDC", 4, 32107},
	{"SIFI", 4, 32108},
	{"OFJU", 4, 32109},
	{"DARWIN", 6, 32110},
	{"RANKS", 5, 32111},
	{"MONUMENT", 8, 32112},
	{"TMOV", 4, 32113},
	{"ITYR", 4, 32114},
	{"GENERATIONS", 11, 32115},
	{"RACK", 4, 32116},
	{"RDWI", 4, 32117},
	{"TOURNAMENTS", 11, 32118},
	{"EJUD", 4, 32119},
	{"IFWE", 4, 32120},
	{"BRADLEY", 7, 32121},
	{"DVEN", 4, 32122},
	{"TOXIC", 5, 32123},
	{"NBEL", 4, 32124},
	{"GATHERING", 9, 32125},
	{"COOPERATIVE", 11, 32126},
	{"EMUC", 4, 32127},
	{"PRACTITIONER", 12, 32128},
	{"TQUA", 4, 32129},
	{"ANATOMY", 7, 32130},
	{"EBOY", 4, 32131},
	{"NRSQ", 4, 32132},
	{"ULDF", 4, 32133},
	{"BALI", 4, 32134},
	{"JUDY", 4, 32135},
	{"SPONSORSHIP", 11, 32136},
	{"DAPR", 4, 32137},
	{"EADW", 4, 32138},
	{"BURNING", 7, 32139},
	{"DRAWER", 6, 32140},
	{"RMOU", 4, 32141},
	{"ASAV", 4, 32142},
	{"HEADPHONES", 10, 32143},
	{"ARYB", 4, 32144},
	{"TEPH", 4, 32145},
	{"DONH", 4, 32146},
	{"AUNT", 4, 32147},
	{"GUPT", 4, 32148},
	{"TRIO", 4, 32149},
	{"PROCEEDING", 10, 32150},
	{"CUBE", 4, 32151},
	{"IRWA", 4, 32152},
	{"SEAL", 4, 32153},
	{"CLIP", 4, 32154},
	{"SENTIMENT", 9, 32155},
	{"ALLEGED", 7, 32156},
	{"CARPET", 6, 32157},
	{"DEFECTS", 7, 32158},
	{"ILYS", 4, 32159},
	{"NSAB", 4, 32160},
	{"VOLKSWAGEN", 10, 32161},
	{"BREAKDOWN", 9, 32162},
	{"MILTON", 6, 32163},
	{"RECONSTRUCTION", 14, 32164},
	{"SUBSIDIARY", 10, 32165},
	{"STRENGTHS", 9, 32166},
	{"NTPO", 4, 32167},
	{"PRODUCTIVITY", 12, 32168},
	{"CLARITY", 7, 32169},
	{"NGCR", 4, 32170},
	{"RUGS", 4, 32171},
	{"OGUE", 4, 32172},
	{"YSTI", 4, 32173},
	{"UALT", 4, 32174},
	{"LTTO", 4, 32175},
	{"YHEL", 4, 32176},
	{"SANDRA", 6, 32177},
	{"ENLE", 4, 32178},
	{"NONC", 4, 32179},
	{"ADELAIDE", 8, 32180},
	{"UCKY", 4, 32181},
	{"TREASURE", 8, 32182},
	{"RYWE", 4, 32183},
	{"FTWO", 4, 32184},
	{"THDI", 4, 32185},
	{"KESI", 4, 32186},
	{"AESTHETIC", 9, 32187},
	{"FURNISHED", 9, 32188},
	{"RCHT", 4, 32189},
	{"MONACO", 6, 32190},
	{"SETTLED", 7, 32191},
	{"TACKLE", 6, 32192},
	{"FOLDING", 7, 32193},
	{"EMIRATES", 8, 32194},
	{"TIGHTLY", 7, 32195},
	{"GREEK", 5, 32196},
	{"RHOW", 4, 32197},
	{"EXTENDED", 8, 32198},
	{"TERRORISTS", 10, 32199},
	{"AIRFARE", 7, 32200},
	{"ALPL", 4, 32201},
	{"COMPARISONS", 11, 32202},
	{"BENEFICIAL", 10, 32203},
	{"DISTRIBUTIONS", 13, 32204},
	{"STATISTICAL", 11, 32205},
	{"RTHT", 4, 32206},
	{"IEWI", 4, 32207},
	{"BELIZE", 6, 32208},
	{"CRAP", 4, 32209},
	{"SHRIMP", 6, 32210},
	{"EWYE", 4, 32211},
	{"OLDF", 4, 32212},
	{"DROU", 4, 32213},
	{"BYX", 3, 32214},
	{"OTFO", 4, 32215},
	{"HIPI", 4, 32216},
	{"NDKI", 4, 32217},
	{"VIEWPICTURE", 11, 32218},
	{"PROMISED", 8, 32219},
	{"UCKE", 4, 32220},
	{"VOLVO", 5, 32221},
	{"PENNY", 5, 32222},
	{"ROBUST", 6, 32223},
	{"WITHDRAWAL", 10, 32224},
	{"BOOKINGS", 8, 32225},
	{"ONTK", 4, 32226},
	{"THREATENED", 10, 32227},
	{"MINOLTA", 7, 32228},
	{"RMUS", 4, 32229},
	{"HCAN", 4, 32230},
	{"REPUBLICANS", 11, 32231},
	{"CAGE", 4, 32232},
	{"AGRICULTURE", 11, 32233},
	{"VOTING", 6, 32234},
	{"LGRO", 4, 32235},
	{"KEDH", 4, 32236},
	{"YOUF", 4, 32237},
	{"DISCUSSES", 9, 32238},
	{"GUI", 3, 32239},
	{"ATRU", 4, 32240},
	{"YRB", 3, 32241},
	{"YRET", 4, 32242},
	{"PORTER", 6, 32243},
	{"NNAM", 4, 32244},
	{"EROM", 4, 32245},
	{"GRAS", 4, 32246},
	{"TALY", 4, 32247},
	{"VER", 3, 32248},
	{"AWYE", 4, 32249},
	{"ILUR", 4, 32250},
	{"QUEST", 5, 32251},
	{"RESPONDED", 9, 32252},
	{"MWHE", 4, 32253},
	{"ABSTRACTS", 9, 32254},
	{"BORH", 4, 32255},
	{"ORMT", 4, 32256},
	{"NOWB", 4, 32257},
	{"IVORY", 5, 32258},
	{"STDO", 4, 32259},
	{"RYCA", 4, 32260},
	{"DREM", 4, 32261},
	{"ALPINE", 6, 32262},
	{"UTILIZE", 7, 32263},
	{"DONATE", 6, 32264},
	{"QUEEN", 5, 32265},
	{"RRUP", 4, 32266},
	{"LOYALTY", 7, 32267},
	{"PHARMACEUTICALS", 15, 32268},
	{"OBEG", 4, 32269},
	{"OMAD", 4, 32270},
	{"NEOU", 4, 32271},
	{"WELC", 4, 32272},
	{"NDAW", 4, 32273},
	{"CUBAN", 5, 32274},
	{"ANDALE", 6, 32275},
	{"HODI", 4, 32276},
	{"ZDR", 3, 32277},
	{"FABULOUS", 8, 32278},
	{"IRDI", 4, 32279},
	{"TTUR", 4, 32280},
	{"EEMO", 4, 32281},
	{"REMIX", 5, 32282},
	{"ALIAS", 5, 32283},
	{"DTOK", 4, 32284},
	{"NDAH", 4, 32285},
	{"THESAURUS", 9, 32286},
	{"INDIVIDUALLY", 12, 32287},
	{"IFIN", 4, 32288},
	{"SACRIFICE", 9, 32289},
	{"GRIEF", 5, 32290},
	{"EDGO", 4, 32291},
	{"BATTLEFIELD", 11, 32292},
	{"NEWER", 5, 32293},
	{"KAY", 3, 32294},
	{"XGU", 3, 32295},
	{"UXK", 3, 32296},
	{"SPICE", 5, 32297},
	{"YMEM", 4, 32298},
	{"EEMI", 4, 32299},
	{"DIGNITY", 7, 32300},
	{"OVAL", 4, 32301},
	{"IMPLIES", 7, 32302},
	{"INSPIRATION", 11, 32303},
	{"TALENTED", 8, 32304},
	{"ICEH", 4, 32305},
	{"MPAT", 4, 32306},
	{"SOMA", 4, 32307},
	{"NDAV", 4, 32308},
	{"NLAW", 4, 32309},
	{"SMEM", 4, 32310},
	{"COOLER", 6, 32311},
	{"AUTOMATIC", 9, 32312},
	{"APPRAISAL", 9, 32313},
	{"IORA", 4, 32314},
	{"CONSISTING", 10, 32315},
	{"GHTY", 4, 32316},
	{"WAGON", 5, 32317},
	{"MARITIME", 8, 32318},
	{"EHOP", 4, 32319},
	{"HEDW", 4, 32320},
	{"THIGH", 5, 32321},
	{"SINJ", 4, 32322},
	{"PERIODIC", 8, 32323},
	{"SUBMITTING", 10, 32324},
	{"OVERHEAD", 8, 32325},
	{"HEDH", 4, 32326},
	{"ASCII", 5, 32327},
	{"YETT", 4, 32328},
	{"DGEA", 4, 32329},
	{"RKFO", 4, 32330},
	{"TEAMMATE", 8, 32331},
	{"DBEN", 4, 32332},
	{"BUBBLE", 6, 32333},
	{"SHIPMENT", 8, 32334},
	{"VESP", 4, 32335},
	{"WNSH", 4, 32336},
	{"NDOV", 4, 32337},
	{"FMON", 4, 32338},
	{"AIRI", 4, 32339},
	{"BREEDING", 8, 32340},
	{"CCON", 4, 32341},
	{"CITATIONS", 9, 32342},
	{"AINR", 4, 32343},
	{"KGRO", 4, 32344},
	{"ISKN", 4, 32345},
	{"XJE", 3, 32346},
	{"GEOGRAPHICAL", 12, 32347},
	{"MOZAMBIQUE", 10, 32348},
	{"RTOD", 4, 32349},
	{"SCUE", 4, 32350},
	{"HREF", 4, 32351},
	{"BENZ", 4, 32352},
	{"CAB", 3, 32353},
	{"SECULAR", 7, 32354},
	{"SHAPES", 6, 32355},
	{"WIFI", 4, 32356},
	{"MMAR", 4, 32357},
	{"EEXA", 4, 32358},
	{"TIER", 4, 32359},
	{"LYMI", 4, 32360},
	{"OFGA", 4, 32361},
	{"FWD", 3, 32362},
	{"OMWH", 4, 32363},
	{"BUDDY", 5, 32364},
	{"USTD", 4, 32365},
	{"EARL", 4, 32366},
	{"MANOR", 5, 32367},
	{"NWV", 3, 32368},
	{"TLYC", 4, 32369},
	{"DIANE", 5, 32370},
	{"YACT", 4, 32371},
	{"UREP", 4, 32372},
	{"ORBU", 4, 32373},
	{"WNOF", 4, 32374},
	{"OBZ", 3, 32375},
	{"DISCLAIMERS", 11, 32376},
	{"SEDP", 4, 32377},
	{"OWOF", 4, 32378},
	{"CHAMPIONSHIPS", 13, 32379},
	{"NSLI", 4, 32380},
	{"BUG", 3, 32381},
	{"TAUG", 4, 32382},
	{"EXCLUDED", 8, 32383},
	{"LANE", 4, 32384},
	{"ANDREA", 6, 32385},
	{"SSWA", 4, 32386},
	{"BREEDS", 6, 32387},
	{"RAPIDS", 6, 32388},
	{"SPECIALIZE", 10, 32389},
	{"REOU", 4, 32390},
	{"DABL", 4, 32391},
	{"DISCO", 5, 32392},
	{"SHEFFIELD", 9, 32393},
	{"BAILEY", 6, 32394},
	{"ICKO", 4, 32395},
	{"ENDIF", 5, 32396},
	{"SEYO", 4, 32397},
	{"PATIENCE", 8, 32398},
	{"RCUL", 4, 32399},
	{"FINISHING", 9, 32400},
	{"BONUS", 5, 32401},
	{"EMOTIONS", 8, 32402},
	{"WELLINGTON", 10, 32403},
	{"OOLT", 4, 32404},
	{"INCOMING", 8, 32405},
	{"ANCESTOR", 8, 32406},
	{"VERDICT", 7, 32407},
	{"PROSPECTS", 9, 32408},
	{"OTGO", 4, 32409},
	{"CKGR", 4, 32410},
	{"LEXMARK", 7, 32411},
	{"CLEANERS", 8, 32412},
	{"BULGARIAN", 9, 32413},
	{"DSLI", 4, 32414},
	{"IESP", 4, 32415},
	{"GHTD", 4, 32416},
	{"HOCA", 4, 32417},
	{"SAIL", 4, 32418},
	{"TEPA", 4, 32419},
	{"YBEF", 4, 32420},
	{"HWY", 3, 32421},
	{"ETERNAL", 7, 32422},
	{"CASHIERS", 8, 32423},
	{"OUSM", 4, 32424},
	{"RGRE", 4, 32425},
	{"GUAM", 4, 32426},
	{"ACHC", 4, 32427},
	{"EEWH", 4, 32428},
	{"SEVENTH", 7, 32429},
	{"IKG", 3, 32430},
	{"EDJU", 4, 32431},
	{"ABORIGINAL", 10, 32432},
	{"RZW", 3, 32433},
	{"NTLO", 4, 32434},
	{"ROTATION", 8, 32435},
	{"BLOODY", 6, 32436},
	{"SHALLOW", 7, 32437},
	{"KEVI", 4, 32438},
	{"GERW", 4, 32439},
	{"SASM", 4, 32440},
	{"TGRE", 4, 32441},
	{"GENIUS", 6, 32442},
	{"PREVENTING", 10, 32443},
	{"RIEV", 4, 32444},
	{"BOULEVARD", 9, 32445},
	{"EUGENE", 6, 32446},
	{"NZC", 3, 32447},
	{"GTER", 4, 32448},
	{"USAL", 4, 32449},
	{"GUW", 3, 32450},
	{"DSUC", 4, 32451},
	{"ALIB", 4, 32452},
	{"EORA", 4, 32453},
	{"GITI", 4, 32454},
	{"PROTECTIVE", 10, 32455},
	{"GDP", 3, 32456},
	{"EGIM", 4, 32457},
	{"UZW", 3, 32458},
	{"METRIC", 6, 32459},
	{"NORTHEAST", 9, 32460},
	{"ANSU", 4, 32461},
	{"UNTH", 4, 32462},
	{"COMPLIANT", 9, 32463},
	{"MINUS", 5, 32464},
	{"YWY", 3, 32465},
	{"UTMO", 4, 32466},
	{"REFRIGERATOR", 12, 32467},
	{"UTEA", 4, 32468},
	{"PENALTIES", 9, 32469},
	{"AFUL", 4, 32470},
	{"YMUS", 4, 32471},
	{"COMBINED", 8, 32472},
	{"SEFR", 4, 32473},
	{"BENNETT", 7, 32474},
	{"IANF", 4, 32475},
	{"ANAV", 4, 32476},
	{"EATC", 4, 32477},
	{"ORPH", 4, 32478},
	{"HOTMAIL", 7, 32479},
	{"IMMUNE", 6, 32480},
	{"LSPE", 4, 32481},
	{"REFURBISHED", 11, 32482},
	{"JOSHUA", 6, 32483},
	{"EDBR", 4, 32484},
	{"PYK", 3, 32485},
	{"ORBIT", 5, 32486},
	{"ITAG", 4, 32487},
	{"RDLE", 4, 32488},
	{"ARMENIA", 7, 32489},
	{"BQU", 3, 32490},
	{"VARIED", 6, 32491},
	{"ILYT", 4, 32492},
	{"EUNT", 4, 32493},
	{"GRANDE", 6, 32494},
	{"ACCENT", 6, 32495},
	{"CONCEIVE", 8, 32496},
	{"HESB", 4, 32497},
	{"PJI", 3, 32498},
	{"ACTIVATED", 9, 32499},
	{"MYSTERIOUS", 10, 32500},
	{"CALM", 4, 32501},
	{"VIAT", 4, 32502},
	{"CONFERENCING", 12, 32503},
	{"CKOU", 4, 32504},
	{"ARMSTRONG", 9, 32505},
	{"POLITICIANS", 11, 32506},
	{"RTWI", 4, 32507},
	{"TRACKBACKS", 10, 32508},
	{"COORDINATOR", 11, 32509},
	{"EPPE", 4, 32510},
	{"VEWA", 4, 32511},
	{"INSTANTLY", 9, 32512},
	{"TIGERS", 6, 32513},
	{"ESFA", 4, 32514},
	{"LINF", 4, 32515},
	{"AURORA", 6, 32516},
	{"ROSO", 4, 32517},
	{"HIPO", 4, 32518},
	{"SLIDES", 6, 32519},
	{"RWOU", 4, 32520},
	{"MILAN", 5, 32521},
	{"NRIG", 4, 32522},
	{"MERCHANT", 8, 32523},
	{"PREMIERE", 8, 32524},
	{"LENDER", 6, 32525},
	{"PTHA", 4, 32526},
	{"TROPICAL", 8, 32527},
	{"NFAN", 4, 32528},
	{"VILLAGES", 8, 32529},
	{"DAYF", 4, 32530},
	{"CHORUS", 6, 32531},
	{"DIFI", 4, 32532},
	{"CHRISTINE", 9, 32533},
	{"TMIG", 4, 32534},
	{"PLEF", 4, 32535},
	{"EFLY", 4, 32536},
	{"ALUMINUM", 8, 32537},
	{"DIGIT", 5, 32538},
	{"ARGUED", 6, 32539},
	{"DIETARY", 7, 32540},
	{"SYMPHONY", 8, 32541},
	{"NDGI", 4, 32542},
	{"IPWI", 4, 32543},
	{"CLARKE", 6, 32544},
	{"CONSEQUENTLY", 12, 32545},
	{"XCLU", 4, 32546},
	{"OFFICIALLY", 10, 32547},
	{"IEWO", 4, 32548},
	{"RBAS", 4, 32549},
	{"DBYB", 4, 32550},
	{"WILLINGNESS", 11, 32551},
	{"INVITATION", 10, 32552},
	{"MTOB", 4, 32553},
	{"ACCEPTING", 9, 32554},
	{"PRECIPITATION", 13, 32555},
	{"MARILYN", 7, 32556},
	{"LIONS", 5, 32557},
	{"OUCO", 4, 32558},
	{"FINDLAW", 7, 32559},
	{"ENPL", 4, 32560},
	{"POOLS", 5, 32561},
	{"MUSHROOM", 8, 32562},
	{"CREATIVITY", 10, 32563},
	{"TONP", 4, 32564},
	{"IFYI", 4, 32565},
	{"MEIT", 4, 32566},
	{"LYRIC", 5, 32567},
	{"ONFA", 4, 32568},
	{"ORGANIZATIONAL", 14, 32569},
	{"EPLO", 4, 32570},
	{"HTWI", 4, 32571},
	{"GLORY", 5, 32572},
	{"ECOLOGICAL", 10, 32573},
	{"CLAIRE", 6, 32574},
	{"INTM", 4, 32575},
	{"NDKE", 4, 32576},
	{"CHLE", 4, 32577},
	{"NLYC", 4, 32578},
	{"CASUALTY", 8, 32579},
	{"EARTHQUAKE", 10, 32580},
	{"HURRICANE", 9, 32581},
	{"ASCL", 4, 32582},
	{"SPEEDS", 6, 32583},
	{"HATU", 4, 32584},
	{"SUSTAINED", 9, 32585},
	{"XYW", 3, 32586},
	{"QAB", 3, 32587},
	{"SHCO", 4, 32588},
	{"EQUIP", 5, 32589},
	{"WASV", 4, 32590},
	{"MATCHED", 7, 32591},
	{"DEPU", 4, 32592},
	{"APPROXIMATE", 11, 32593},
	{"EINL", 4, 32594},
	{"YOUV", 4, 32595},
	{"ZSF", 3, 32596},
	{"TLEW", 4, 32597},
	{"ILEO", 4, 32598},
	{"TUMOR", 5, 32599},
	{"NDOM", 4, 32600},
	{"STEAM", 5, 32601},
	{"CARROLL", 7, 32602},
	{"PROGRAMMER", 10, 32603},
	{"DRUM", 4, 32604},
	{"BREEZE", 6, 32605},
	{"FIGHTERS", 8, 32606},
	{"CHAMBERS", 8, 32607},
	{"OURS", 4, 32608},
	{"SBEA", 4, 32609},
	{"ORYW", 4, 32610},
	{"EHUN", 4, 32611},
	{"EDAU", 4, 32612},
	{"CONDEMN", 7, 32613},
	{"OPPOSED", 7, 32614},
	{"INHERITED", 9, 32615},
	{"WARMING", 7, 32616},
	{"APIN", 4, 32617},
	{"INCOMPLETE", 10, 32618},
	{"RDSW", 4, 32619},
	{"VOCALS", 6, 32620},
	{"WORKOUT", 7, 32621},
	{"CHRONICLE", 9, 32622},
	{"OPTIMISTIC", 10, 32623},
	{"FOUNTAIN", 8, 32624},
	{"WEB", 3, 32625},
	{"CHUBBY", 6, 32626},
	{"IESL", 4, 32627},
	{"ISKI", 4, 32628},
	{"RTIA", 4, 32629},
	{"ATGO", 4, 32630},
	{"EORO", 4, 32631},
	{"BIOGRAPHIES", 11, 32632},
	{"ESSD", 4, 32633},
	{"DRIC", 4, 32634},
	{"IWIL", 4, 32635},
	{"BURNER", 6, 32636},
	{"VECA", 4, 32637},
	{"IGNT", 4, 32638},
	{"EFTH", 4, 32639},
	{"CARTOON", 7, 32640},
	{"GBA", 3, 32641},
	{"RTSC", 4, 32642},
	{"HAUL", 4, 32643},
	{"VALIDITY", 8, 32644},
	{"OOGL", 4, 32645},
	{"THAG", 4, 32646},
	{"MONL", 4, 32647},
	{"FINNISH", 7, 32648},
	{"OWNR", 4, 32649},
	{"DWEA", 4, 32650},
	{"INFU", 4, 32651},
	{"OGAM", 4, 32652},
	{"WAIST", 5, 32653},
	{"PRISONERS", 9, 32654},
	{"ONDC", 4, 32655},
	{"UMED", 4, 32656},
	{"DEEPER", 6, 32657},
	{"MUSLIMS", 7, 32658},
	{"UNITE", 5, 32659},
	{"ORFA", 4, 32660},
	{"MEDITERRANEAN", 13, 32661},
	{"DOFM", 4, 32662},
	{"NIGHTLIFE", 9, 32663},
	{"STFA", 4, 32664},
	{"EVEH", 4, 32665},
	{"FOOTAGE", 7, 32666},
	{"HOWTO", 5, 32667},
	{"RKST", 4, 32668},
	{"OORE", 4, 32669},
	{"RSSU", 4, 32670},
	{"LYPL", 4, 32671},
	{"REVEALS", 7, 32672},
	{"PROGRESSIVE", 11, 32673},
	{"ARCHITECTS", 10, 32674},
	{"SAINTS", 6, 32675},
	{"PERCEIVED", 9, 32676},
	{"LLIK", 4, 32677},
	{"ROMG", 4, 32678},
	{"CARRIES", 7, 32679},
	{"IPTO", 4, 32680},
	{"THOROUGHLY", 10, 32681},
	{"EARG", 4, 32682},
	{"IDEB", 4, 32683},
	{"FREELANCE", 9, 32684},
	{"GYJ", 3, 32685},
	{"PATROL", 6, 32686},
	{"DUO", 3, 32687},
	{"TERJ", 4, 32688},
	{"VEDH", 4, 32689},
	{"DEVON", 5, 32690},
	{"SCREENSAVER", 11, 32691},
	{"ALVE", 4, 32692},
	{"OUSB", 4, 32693},
	{"ANOL", 4, 32694},
	{"HELENA", 6, 32695},
	{"SAVES", 5, 32696},
	{"REGARDED", 8, 32697},
	{"VALUATION", 9, 32698},
	{"MSWI", 4, 32699},
	{"LWIL", 4, 32700},
	{"NDBI", 4, 32701},
	{"MARION", 6, 32702},
	{"HOFA", 4, 32703},
	{"EGYPTIAN", 8, 32704},
	{"QRE", 3, 32705},
	{"IZF", 3, 32706},
	{"ALWE", 4, 32707},
	{"OADI", 4, 32708},
	{"TUNISIA", 7, 32709},
	{"ERPI", 4, 32710},
	{"ISHP", 4, 32711},
	{"METALLICA", 9, 32712},
	{"OUTLINED", 8, 32713},
	{"MEWO", 4, 32714},
	{"HANW", 4, 32715},
	{"TREATING", 8, 32716},
	{"TINW", 4, 32717},
	{"UREB", 4, 32718},
	{"GRASP", 5, 32719},
	{"APPOINTMENTS", 12, 32720},
	{"TERRIFIC", 8, 32721},
	{"RTGA", 4, 32722},
	{"GOTTA", 5, 32723},
	{"DLOO", 4, 32724},
	{"LLWE", 4, 32725},
	{"COWBOY", 6, 32726},
	{"AFTERWARD", 9, 32727},
	{"IANW", 4, 32728},
	{"NWAL", 4, 32729},
	{"OFFL", 4, 32730},
	{"VOJ", 3, 32731},
	{"VOUR", 4, 32732},
	{"COSTUME", 7, 32733},
	{"BAHRAIN", 7, 32734},
	{"KARMA", 5, 32735},
	{"OBUY", 4, 32736},
	{"HMON", 4, 32737},
	{"BULL", 4, 32738},
	{"EKEY", 4, 32739},
	{"DOWI", 4, 32740},
	{"UDET", 4, 32741},
	{"FFRO", 4, 32742},
	{"BETTY", 5, 32743},
	{"QUEENS", 6, 32744},
	{"ACADEMICS", 9, 32745},
	{"EGLO", 4, 32746},
	{"LONT", 4, 32747},
	{"ANLI", 4, 32748},
	{"PUBS", 4, 32749},
	{"QUANTITATIVE", 12, 32750},
	{"LUCAS", 5, 32751},
	{"HBUT", 4, 32752},
	{"SCREENSAVERS", 12, 32753},
	{"DCHE", 4, 32754},
	{"UNDERLYING", 10, 32755},
	{"PERSIAN", 7, 32756},
	{"SUBDIVISION", 11, 32757},
	{"SPITE", 5, 32758},
	{"HIMW", 4, 32759},
	{"TRIBES", 6, 32760},
	{"JEWELRY", 7, 32761},
	{"VIP", 3, 32762},
	{"CLICKS", 6, 32763},
	{"ENFI", 4, 32764},
	{"WMUC", 4, 32765},
	{"OPEO", 4, 32766},
	{"EDOO", 4, 32767},
	{"TSLO", 4, 32768},
	{"BIOLOGY", 7, 32769},
	{"HONDURAS", 8, 32770},
	{"RUNNER", 6, 32771},
	{"SSIL", 4, 32772},
	{"NAUGHTY", 7, 32773},
	{"FRANCHISE", 9, 32774},
	{"HAZARDS", 7, 32775},
	{"NEUTRAL", 7, 32776},
	{"INSURED", 7, 32777},
	{"YBAS", 4, 32778},
	{"HARPER", 6, 32779},
	{"LIVESTOCK", 9, 32780},
	{"OFPU", 4, 32781},
	{"EDIM", 4, 32782},
	{"MARDI", 5, 32783},
	{"EXEMPTION", 9, 32784},
	{"USIV", 4, 32785},
	{"TENANT", 6, 32786},
	{"SUSTAINABILITY", 14, 32787},
	{"OWDE", 4, 32788},
	{"IRCH", 4, 32789},
	{"MIXED", 5, 32790},
	{"SHOVE", 5, 32791},
	{"HEJE", 4, 32792},
	{"CABINETS", 8, 32793},
	{"TATTOO", 6, 32794},
	{"EEAG", 4, 32795},
	{"ALGEBRA", 7, 32796},
	{"BSOL", 4, 32797},
	{"SDRA", 4, 32798},
	{"SHADOWS", 7, 32799},
	{"RXB", 3, 32800},
	{"HOLLY", 5, 32801},
	{"HIPT", 4, 32802},
	{"RLIV", 4, 32803},
	{"FORMATTING", 10, 32804},
	{"OFHU", 4, 32805},
	{"ODEV", 4, 32806},
	{"SHEEP", 5, 32807},
	{"NUTRITIONAL", 11, 32808},
	{"HOSTILE", 7, 32809},
	{"MERCY", 5, 32810},
	{"NMV", 3, 32811},
	{"LMED", 4, 32812},
	{"FISHERMAN", 9, 32813},
	{"HARTFORD", 8, 32814},
	{"LEPH", 4, 32815},
	{"GTOF", 4, 32816},
	{"MARCUS", 6, 32817},
	{"SUNRISE", 7, 32818},
	{"WRAPPING", 8, 32819},
	{"GPEO", 4, 32820},
	{"SKULL", 5, 32821},
	{"FLEXIBLE", 8, 32822},
	{"CHRISTIANITY", 12, 32823},
	{"LLSU", 4, 32824},
	{"NICARAGUA", 9, 32825},
	{"ZEDA", 4, 32826},
	{"DRIG", 4, 32827},
	{"IESD", 4, 32828},
	{"NGBR", 4, 32829},
	{"WEBLOGS", 7, 32830},
	{"TIMELINE", 8, 32831},
	{"BUSH", 4, 32832},
	{"YCAM", 4, 32833},
	{"VMW", 3, 32834},
	{"THPL", 4, 32835},
	{"EISB", 4, 32836},
	{"CONCEDE", 7, 32837},
	{"COMMISSIONER", 12, 32838},
	{"OOUT", 4, 32839},
	{"BELONGS", 7, 32840},
	{"NTYE", 4, 32841},
	{"OFRI", 4, 32842},
	{"REVELATION", 10, 32843},
	{"SDEM", 4, 32844},
	{"LDQU", 4, 32845},
	{"MPTS", 4, 32846},
	{"OWNM", 4, 32847},
	{"LSWH", 4, 32848},
	{"RCIS", 4, 32849},
	{"DOUGH", 5, 32850},
	{"LEDM", 4, 32851},
	{"BLESS", 5, 32852},
	{"OFCL", 4, 32853},
	{"LDFO", 4, 32854},
	{"TORF", 4, 32855},
	{"RGAR", 4, 32856},
	{"EMWI", 4, 32857},
	{"STSP", 4, 32858},
	{"AFFILIATION", 11, 32859},
	{"HAFR", 4, 32860},
	{"OWSO", 4, 32861},
	{"NUDIST", 6, 32862},
	{"DESSERT", 7, 32863},
	{"INFINITE", 8, 32864},
	{"DIANA", 5, 32865},
	{"NGFU", 4, 32866},
	{"ENSURES", 7, 32867},
	{"JAR", 3, 32868},
	{"ACKN", 4, 32869},
	{"MPHA", 4, 32870},
	{"RELATIVES", 9, 32871},
	{"RBON", 4, 32872},
	{"OUWI", 4, 32873},
	{"LINDSAY", 7, 32874},
	{"CLAN", 4, 32875},
	{"EXECUTION", 9, 32876},
	{"UGHW", 4, 32877},
	{"SATISFACTORY", 12, 32878},
	{"SPECTACULAR", 11, 32879},
	{"PLACEMENT", 9, 32880},
	{"BRACELETS", 9, 32881},
	{"LOWL", 4, 32882},
	{"SYNC", 4, 32883},
	{"LSTU", 4, 32884},
	{"SOCK", 4, 32885},
	{"TELEPHONY", 9, 32886},
	{"OFEV", 4, 32887},
	{"HWER", 4, 32888},
	{"MESA", 4, 32889},
	{"ECTF", 4, 32890},
	{"UPSTAIRS", 8, 32891},
	{"LESU", 4, 32892},
	{"REMEDY", 6, 32893},
	{"REALTORS", 8, 32894},
	{"NPUB", 4, 32895},
	{"DAMN", 4, 32896},
	{"THICKNESS", 9, 32897},
	{"EMPIRE", 6, 32898},
	{"BYIN", 4, 32899},
	{"RUIN", 4, 32900},
	{"MMOD", 4, 32901},
	{"ADJUSTMENTS", 11, 32902},
	{"TRANSLATION", 11, 32903},
	{"OTOU", 4, 32904},
	{"GRAPHICAL", 9, 32905},
	{"OZM", 3, 32906},
	{"LETR", 4, 32907},
	{"NGSS", 4, 32908},
	{"DISCUSSING", 10, 32909},
	{"AEROSPACE", 9, 32910},
	{"CONSPIRACY", 10, 32911},
	{"PORK", 4, 32912},
	{"YSTU", 4, 32913},
	{"OCQ", 3, 32914},
	{"ADAPTED", 7, 32915},
	{"LATF", 4, 32916},
	{"ATBR", 4, 32917},
	{"COMPRISE", 8, 32918},
	{"RBES", 4, 32919},
	{"THLO", 4, 32920},
	{"LLKN", 4, 32921},
	{"ESTATES", 7, 32922},
	{"WHIP", 4, 32923},
	{"DEVELOPMENTAL", 13, 32924},
	{"TLEG", 4, 32925},
	{"RUG", 3, 32926},
	{"YREF", 4, 32927},
	{"ISOLATION", 9, 32928},
	{"CALB", 4, 32929},
	{"BOROUGH", 7, 32930},
	{"MAINTAINS", 9, 32931},
	{"FAILING", 7, 32932},
	{"WHOEVER", 7, 32933},
	{"MINISTRY", 8, 32934},
	{"EELA", 4, 32935},
	{"TWOH", 4, 32936},
	{"SHORTCUTS", 9, 32937},
	{"INTERACT", 8, 32938},
	{"MSON", 4, 32939},
	{"RETAINED", 8, 32940},
	{"PAMELA", 6, 32941},
	{"ILEP", 4, 32942},
	{"FPY", 3, 32943},
	{"ANDREWS", 7, 32944},
	{"ANWE", 4, 32945},
	{"PYU", 3, 32946},
	{"NXW", 3, 32947},
	{"CONSENT", 7, 32948},
	{"EXTENDING", 9, 32949},
	{"JESSE", 5, 32950},
	{"ENTREPRENEUR", 12, 32951},
	{"SPECIFIES", 9, 32952},
	{"HULL", 4, 32953},
	{"LOGITECH", 8, 32954},
	{"SURREY", 6, 32955},
	{"FOSTER", 6, 32956},
	{"EIMA", 4, 32957},
	{"TEGY", 4, 32958},
	{"RYDI", 4, 32959},
	{"SUBSIDY", 7, 32960},
	{"ALLEY", 5, 32961},
	{"STGA", 4, 32962},
	{"ILST", 4, 32963},
	{"RSSE", 4, 32964},
	{"UTMI", 4, 32965},
	{"BRIEFING", 8, 32966},
	{"ACTIVELY", 8, 32967},
	{"FASCINATING", 11, 32968},
	{"BELKIN", 6, 32969},
	{"DEM", 3, 32970},
	{"TYST", 4, 32971},
	{"HORMONE", 7, 32972},
	{"ESEG", 4, 32973},
	{"NSEQ", 4, 32974},
	{"ZVE", 3, 32975},
	{"ACCREDITATION", 13, 32976},
	{"WAV", 3, 32977},
	{"RNEA", 4, 32978},
	{"BLACKBERRY", 10, 32979},
	{"ISGU", 4, 32980},
	{"HIGHLAND", 8, 32981},
	{"RCAL", 4, 32982},
	{"ERUP", 4, 32983},
	{"MEDITATION", 10, 32984},
	{"MODULAR", 7, 32985},
	{"MICROPHONE", 10, 32986},
	{"NTAM", 4, 32987},
	{"MACEDONIA", 9, 32988},
	{"ANGS", 4, 32989},
	{"ASEW", 4, 32990},
	{"RSED", 4, 32991},
	{"RKSH", 4, 32992},
	{"COMBINING", 9, 32993},
	{"BRANDON", 7, 32994},
	{"INSTRUMENTAL", 12, 32995},
	{"GIANTS", 6, 32996},
	{"THQU", 4, 32997},
	{"ORGANIZING", 10, 32998},
	{"EYBE", 4, 32999},
	{"ESBO", 4, 33000},
	{"AGGRESSION", 10, 33001},
	{"STIMULUS", 8, 33002},
	{"ECOSYSTEM", 9, 33003},
	{"ILEM", 4, 33004},
	{"EYEBROW", 7, 33005},
	{"IVEU", 4, 33006},
	{"MODERATORS", 10, 33007},
	{"LSTE", 4, 33008},
	{"FILTER", 6, 33009},
	{"ORGANISM", 8, 33010},
	{"SHEER", 5, 33011},
	{"WINSTON", 7, 33012},
	{"IAMI", 4, 33013},
	{"RREG", 4, 33014},
	{"COCAINE", 7, 33015},
	{"MEMO", 4, 33016},
	{"SOLVED", 6, 33017},
	{"CASINO", 6, 33018},
	{"RCEO", 4, 33019},
	{"HNIQ", 4, 33020},
	{"RIMP", 4, 33021},
	{"HELMET", 6, 33022},
	{"KAZAKHSTAN", 10, 33023},
	{"SGOV", 4, 33024},
	{"EJEC", 4, 33025},
	{"ZUH", 3, 33026},
	{"HAWAIIAN", 8, 33027},
	{"STANDINGS", 9, 33028},
	{"TBES", 4, 33029},
	{"PARTITION", 9, 33030},
	{"GRATUIT", 7, 33031},
	{"CONSOLES", 8, 33032},
	{"ODFO", 4, 33033},
	{"EEKT", 4, 33034},
	{"FUNK", 4, 33035},
	{"FBI", 3, 33036},
	{"RONL", 4, 33037},
	{"SPOON", 5, 33038},
	{"QATAR", 5, 33039},
	{"GSHE", 4, 33040},
	{"MAGNET", 6, 33041},
	{"GIND", 4, 33042},
	{"DINL", 4, 33043},
	{"OCKT", 4, 33044},
	{"TRANSLATIONS", 12, 33045},
	{"BOOTH", 5, 33046},
	{"PORSCHE", 7, 33047},
	{"EDEB", 4, 33048},
	{"ATKI", 4, 33049},
	{"CAYMAN", 6, 33050},
	{"TOND", 4, 33051},
	{"LYIM", 4, 33052},
	{"RTRI", 4, 33053},
	{"ARDD", 4, 33054},
	{"MEHA", 4, 33055},
	{"JAGUAR", 6, 33056},
	{"WORKPLACE", 9, 33057},
	{"YHAR", 4, 33058},
	{"REEL", 4, 33059},
	{"ILYO", 4, 33060},
	{"EXOTIC", 6, 33061},
	{"SSAU", 4, 33062},
	{"ETSW", 4, 33063},
	{"EOCC", 4, 33064},
	{"POSING", 6, 33065},
	{"WANG", 4, 33066},
	{"BOIL", 4, 33067},
	{"COUP", 4, 33068},
	{"RTOH", 4, 33069},
	{"DISCOURAGE", 10, 33070},
	{"KILOMETERS", 10, 33071},
	{"EXAM", 4, 33072},
	{"MINIMAL", 7, 33073},
	{"RAND", 4, 33074},
	{"HOPKINS", 7, 33075},
	{"URGENT", 6, 33076},
	{"PRIZ", 4, 33077},
	{"GUARANTEES", 10, 33078},
	{"INFANTS", 7, 33079},
	{"GOTHIC", 6, 33080},
	{"CYLINDER", 8, 33081},
	{"HOCKEY", 6, 33082},
	{"WITCH", 5, 33083},
	{"NLAS", 4, 33084},
	{"DGOA", 4, 33085},
	{"ALONGSIDE", 9, 33086},
	{"COHEN", 5, 33087},
	{"SHARK", 5, 33088},
	{"USGS", 4, 33089},
	{"LWHO", 4, 33090},
	{"PUPPY", 5, 33091},
	{"RSUN", 4, 33092},
	{"AMSO", 4, 33093},
	{"KATHY", 5, 33094},
	{"OBEH", 4, 33095},
	{"INFLUENTIAL", 11, 33096},
	{"PURSE", 5, 33097},
	{"LLGO", 4, 33098},
	{"VJE", 3, 33099},
	{"ACRE", 4, 33100},
	{"GRAPHS", 6, 33101},
	{"BLINK", 5, 33102},
	{"MANIPULATE", 10, 33103},
	{"CIGARETTES", 10, 33104},
	{"WEWI", 4, 33105},
	{"EDIT", 4, 33106},
	{"SYNDROME", 8, 33107},
	{"DISSOLVE", 8, 33108},
	{"RMAY", 4, 33109},
	{"HIMB", 4, 33110},
	{"REVENGE", 7, 33111},
	{"EXPIRES", 7, 33112},
	{"ENEMIES", 7, 33113},
	{"LOWS", 4, 33114},
	{"YKW", 3, 33115},
	{"EBLU", 4, 33116},
	{"HADL", 4, 33117},
	{"EFAT", 4, 33118},
	{"ESHM", 4, 33119},
	{"CONTROLLERS", 11, 33120},
	{"PUZZLE", 6, 33121},
	{"RYPO", 4, 33122},
	{"AQUA", 4, 33123},
	{"CHEN", 4, 33124},
	{"EMMA", 4, 33125},
	{"UITI", 4, 33126},
	{"CONSULTANCY", 11, 33127},
	{"FINANCES", 8, 33128},
	{"GRAC", 4, 33129},
	{"METROPOLITAN", 12, 33130},
	{"FLEXIBILITY", 11, 33131},
	{"ACCEPTS", 7, 33132},
	{"ENJOYING", 8, 33133},
	{"CONVENTIONS", 11, 33134},
	{"CKFO", 4, 33135},
	{"TWOB", 4, 33136},
	{"PABL", 4, 33137},
	{"ERDU", 4, 33138},
	{"EXPECTED", 8, 33139},
	{"ERSQ", 4, 33140},
	{"INTIMATE", 8, 33141},
	{"FPAR", 4, 33142},
	{"INCREDIBLY", 10, 33143},
	{"PEST", 4, 33144},
	{"LARO", 4, 33145},
	{"ITALIANO", 8, 33146},
	{"COORDINATES", 11, 33147},
	{"RCA", 3, 33148},
	{"OFOL", 4, 33149},
	{"MPTT", 4, 33150},
	{"UNEA", 4, 33151},
	{"CARNIVAL", 8, 33152},
	{"YMEA", 4, 33153},
	{"LAWY", 4, 33154},
	{"STICKER", 7, 33155},
	{"PROMISES", 8, 33156},
	{"SBEH", 4, 33157},
	{"EDCR", 4, 33158},
	{"RESPONDING", 10, 33159},
	{"REJE", 4, 33160},
	{"ALWH", 4, 33161},
	{"COSTLY", 6, 33162},
	{"REEF", 4, 33163},
	{"CONSERVATION", 12, 33164},
	{"EAGO", 4, 33165},
	{"STAKEHOLDERS", 12, 33166},
	{"LEFI", 4, 33167},
	{"LESL", 4, 33168},
	{"HYDROCODONE", 11, 33169},
	{"WYOU", 4, 33170},
	{"CORNELL", 7, 33171},
	{"SATIN", 5, 33172},
	{"EATF", 4, 33173},
	{"ATTEMPTING", 10, 33174},
	{"RKWI", 4, 33175},
	{"LEOR", 4, 33176},
	{"MAILTO", 6, 33177},
	{"PROMO", 5, 33178},
	{"KSHO", 4, 33179},
	{"XOC", 3, 33180},
	{"REPRESENTATIONS", 15, 33181},
	{"MESU", 4, 33182},
	{"INSTRUCT", 8, 33183},
	{"CLIFF", 5, 33184},
	{"DVOC", 4, 33185},
	{"AYSL", 4, 33186},
	{"CHAN", 4, 33187},
	{"UIJ", 3, 33188},
	{"EEMT", 4, 33189},
	{"TICT", 4, 33190},
	{"TUNES", 5, 33191},
	{"LPOL", 4, 33192},
	{"IKEO", 4, 33193},
	{"COMPETING", 9, 33194},
	{"TLYD", 4, 33195},
	{"HIKE", 4, 33196},
	{"CONSTITUTION", 12, 33197},
	{"COMBINES", 8, 33198},
	{"YBRO", 4, 33199},
	{"OKSA", 4, 33200},
	{"DRIED", 5, 33201},
	{"STOV", 4, 33202},
	{"LDHO", 4, 33203},
	{"BESU", 4, 33204},
	{"OOLW", 4, 33205},
	{"UGHF", 4, 33206},
	{"DEMOGRAPHIC", 11, 33207},
	{"RTOU", 4, 33208},
	{"BETH", 4, 33209},
	{"SIBLING", 7, 33210},
	{"BRADFORD", 8, 33211},
	{"PHRASES", 7, 33212},
	{"ALHI", 4, 33213},
	{"TEGI", 4, 33214},
	{"CKHA", 4, 33215},
	{"ATDA", 4, 33216},
	{"EWRE", 4, 33217},
	{"PENINSULA", 9, 33218},
	{"CHELSEA", 7, 33219},
	{"HEUK", 4, 33220},
	{"YMAD", 4, 33221},
	{"REYNOLDS", 8, 33222},
	{"REWS", 4, 33223},
	{"DOM", 3, 33224},
	{"JILL", 4, 33225},
	{"RABBIT", 6, 33226},
	{"SEAG", 4, 33227},
	{"SPEECHES", 8, 33228},
	{"MECHANIC", 8, 33229},
	{"ADLE", 4, 33230},
	{"REACHES", 7, 33231},
	{"URTE", 4, 33232},
	{"SCHEMA", 6, 33233},
	{"YZH", 3, 33234},
	{"IZL", 3, 33235},
	{"IPOF", 4, 33236},
	{"CONSIDERS", 9, 33237},
	{"CUTE", 4, 33238},
	{"SFEE", 4, 33239},
	{"CATALOGS", 8, 33240},
	{"PANIC", 5, 33241},
	{"UDZ", 3, 33242},
	{"DONATION", 8, 33243},
	{"MINISTRIES", 10, 33244},
	{"ILZ", 3, 33245},
	{"ERKE", 4, 33246},
	{"HTFO", 4, 33247},
	{"STOVE", 5, 33248},
	{"DHOM", 4, 33249},
	{"VACANCIES", 9, 33250},
	{"QUIZZES", 7, 33251},
	{"OTAC", 4, 33252},
	{"NOFB", 4, 33253},
	{"PARLIAMENTARY", 13, 33254},
	{"OBJ", 3, 33255},
	{"PREFIX", 6, 33256},
	{"LUCIA", 5, 33257},
	{"OWWE", 4, 33258},
	{"EYZ", 3, 33259},
	{"MBOL", 4, 33260},
	{"SAVANNAH", 8, 33261},
	{"INSTINCT", 8, 33262},
	{"TYPING", 6, 33263},
	{"LION", 4, 33264},
	{"DLOC", 4, 33265},
	{"DANS", 4, 33266},
	{"ANSB", 4, 33267},
	{"PLANETS", 7, 33268},
	{"ARTR", 4, 33269},
	{"ISGE", 4, 33270},
	{"TDEF", 4, 33271},
	{"TWOG", 4, 33272},
	{"CORD", 4, 33273},
	{"PUNCH", 5, 33274},
	{"ALSF", 4, 33275},
	{"BOULDER", 7, 33276},
	{"POINTING", 8, 33277},
	{"RENEW", 5, 33278},
	{"COUPLED", 7, 33279},
	{"ERPU", 4, 33280},
	{"GUT", 3, 33281},
	{"INSERT", 6, 33282},
	{"MIGRATION", 9, 33283},
	{"RDRE", 4, 33284},
	{"ROLLING", 7, 33285},
	{"VIII", 4, 33286},
	{"THPE", 4, 33287},
	{"IEDW", 4, 33288},
	{"HMAR", 4, 33289},
	{"MYANMAR", 7, 33290},
	{"METADATA", 8, 33291},
	{"ODST", 4, 33292},
	{"HAROLD", 6, 33293},
	{"HENL", 4, 33294},
	{"PASTA", 5, 33295},
	{"CIRCUITS", 8, 33296},
	{"SCRAMBLE", 8, 33297},
	{"NLYH", 4, 33298},
	{"FLOPPY", 6, 33299},
	{"HANDBAGS", 8, 33300},
	{"GSHA", 4, 33301},
	{"NSWA", 4, 33302},
	{"OFOT", 4, 33303},
	{"OIND", 4, 33304},
	{"SOMERSET", 8, 33305},
	{"INCURRED", 8, 33306},
	{"UDJ", 3, 33307},
	{"QBU", 3, 33308},
	{"APPRECIATION", 12, 33309},
	{"TOCU", 4, 33310},
	{"EEWI", 4, 33311},
	{"ANTIGUA", 7, 33312},
	{"NOTTINGHAM", 10, 33313},
	{"DTUR", 4, 33314},
	{"THUNDER", 7, 33315},
	{"CAUTION", 7, 33316},
	{"EDVI", 4, 33317},
	{"SCENT", 5, 33318},
	{"OOKL", 4, 33319},
	{"OALO", 4, 33320},
	{"IDENTIFIES", 10, 33321},
	{"NEOR", 4, 33322},
	{"TBRE", 4, 33323},
	{"IZK", 3, 33324},
	{"OTLI", 4, 33325},
	{"QUALIFICATION", 13, 33326},
	{"TSLE", 4, 33327},
	{"LOCKS", 5, 33328},
	{"MODELLING", 9, 33329},
	{"DBYR", 4, 33330},
	{"ILIS", 4, 33331},
	{"NAMELY", 6, 33332},
	{"SYMPATHY", 8, 33333},
	{"MINIATURE", 9, 33334},
	{"DEPT", 4, 33335},
	{"DWAL", 4, 33336},
	{"HACK", 4, 33337},
	{"EUROS", 5, 33338},
	{"LLGE", 4, 33339},
	{"STLA", 4, 33340},
	{"ERAW", 4, 33341},
	{"FIXED", 5, 33342},
	{"SWAL", 4, 33343},
	{"INTERSTATE", 10, 33344},
	{"PIRATES", 7, 33345},
	{"AERIAL", 6, 33346},
	{"AMBITIOUS", 9, 33347},
	{"DENSITY", 7, 33348},
	{"HAWK", 4, 33349},
	{"PRESUMABLY", 10, 33350},
	{"HEYV", 4, 33351},
	{"PTON", 4, 33352},
	{"TRAGIC", 6, 33353},
	{"SUPPLIER", 8, 33354},
	{"ELEPHANT", 8, 33355},
	{"SYSTEMATIC", 10, 33356},
	{"RQUE", 4, 33357},
	{"ORIGINS", 7, 33358},
	{"HIRED", 5, 33359},
	{"ORGR", 4, 33360},
	{"ILLUSION", 8, 33361},
	{"TEXTILE", 7, 33362},
	{"LAMB", 4, 33363},
	{"MADAGASCAR", 10, 33364},
	{"GEWI", 4, 33365},
	{"NATHAN", 6, 33366},
	{"LYAD", 4, 33367},
	{"TOBAGO", 6, 33368},
	{"GANY", 4, 33369},
	{"PRESENTING", 10, 33370},
	{"DSPA", 4, 33371},
	{"EXPERIENCED", 11, 33372},
	{"PROTOCOL", 8, 33373},
	{"TROUBLESHOOTING", 15, 33374},
	{"ICON", 4, 33375},
	{"BLYT", 4, 33376},
	{"UZBEKISTAN", 10, 33377},
	{"TSUS", 4, 33378},
	{"ROYAL", 5, 33379},
	{"INDEXES", 7, 33380},
	{"LEGISLATURE", 11, 33381},
	{"OROV", 4, 33382},
	{"PAC", 3, 33383},
	{"CKSI", 4, 33384},
	{"RQI", 3, 33385},
	{"EAUD", 4, 33386},
	{"VENH", 4, 33387},
	{"PATENT", 6, 33388},
	{"ILAD", 4, 33389},
	{"NDAU", 4, 33390},
	{"ROBOT", 5, 33391},
	{"NEPO", 4, 33392},
	{"ERP", 3, 33393},
	{"CENTURIES", 9, 33394},
	{"OVEO", 4, 33395},
	{"NTSL", 4, 33396},
	{"TRAY", 4, 33397},
	{"AVOU", 4, 33398},
	{"FITI", 4, 33399},
	{"RICHARDSON", 10, 33400},
	{"RYAT", 4, 33401},
	{"HINDU", 5, 33402},
	{"RLAT", 4, 33403},
	{"EKAN", 4, 33404},
	{"DSPO", 4, 33405},
	{"ACKP", 4, 33406},
	{"HEMB", 4, 33407},
	{"OSEB", 4, 33408},
	{"FRAGRANCES", 10, 33409},
	{"PERSIST", 7, 33410},
	{"VOCABULARY", 10, 33411},
	{"LICKING", 7, 33412},
	{"CHARTER", 7, 33413},
	{"VPN", 3, 33414},
	{"URMO", 4, 33415},
	{"FUNDRAISING", 11, 33416},
	{"USTP", 4, 33417},
	{"SDRI", 4, 33418},
	{"INBY", 4, 33419},
	{"FCC", 3, 33420},
	{"MARKERS", 7, 33421},
	{"WEIGHTS", 7, 33422},
	{"NOTU", 4, 33423},
	{"YJUS", 4, 33424},
	{"YMOU", 4, 33425},
	{"RIVAL", 5, 33426},
	{"SPRAY", 5, 33427},
	{"WELL-BEING", 10, 33428},
	{"ALBANIA", 7, 33429},
	{"IEFS", 4, 33430},
	{"TSAG", 4, 33431},
	{"GEOLOGICAL", 10, 33432},
	{"HISK", 4, 33433},
	{"ASSESSING", 9, 33434},
	{"QOR", 3, 33435},
	{"LASTING", 7, 33436},
	{"VEUP", 4, 33437},
	{"WICKED", 6, 33438},
	{"SHORT-TERM", 10, 33439},
	{"INTRODUCES", 10, 33440},
	{"KILLS", 5, 33441},
	{"ROOMMATE", 8, 33442},
	{"EXTY", 4, 33443},
	{"DECORATE", 8, 33444},
	{"COLUMNIST", 9, 33445},
	{"PUSHED", 6, 33446},
	{"UPTI", 4, 33447},
	{"OSTD", 4, 33448},
	{"RYAS", 4, 33449},
	{"WEBMASTERS", 10, 33450},
	{"OCEN", 4, 33451},
	{"YSEN", 4, 33452},
	{"NKSA", 4, 33453},
	{"TEXTURE", 7, 33454},
	{"YLK", 3, 33455},
	{"LFRE", 4, 33456},
	{"JEWI", 4, 33457},
	{"RUNO", 4, 33458},
	{"YBAC", 4, 33459},
	{"CESB", 4, 33460},
	{"PULSE", 5, 33461},
	{"SFEA", 4, 33462},
	{"COMPUTATIONAL", 13, 33463},
	{"ACDBENTITY", 10, 33464},
	{"PARTICIPATED", 12, 33465},
	{"JUNK", 4, 33466},
	{"HANDHELDS", 9, 33467},
	{"WAX", 3, 33468},
	{"LUCY", 4, 33469},
	{"ANSWERING", 9, 33470},
	{"IESR", 4, 33471},
	{"DEBUT", 5, 33472},
	{"CRUSH", 5, 33473},
	{"IMPRESSED", 9, 33474},
	{"NTSD", 4, 33475},
	{"OWRI", 4, 33476},
	{"INUN", 4, 33477},
	{"REGGAE", 6, 33478},
	{"FAILURES", 8, 33479},
	{"LYBA", 4, 33480},
	{"SENSITIVITY", 11, 33481},
	{"UCHL", 4, 33482},
	{"ACCOMPLISHMENT", 14, 33483},
	{"SURNAME", 7, 33484},
	{"NAILS", 5, 33485},
	{"EEPO", 4, 33486},
	{"YTEA", 4, 33487},
	{"ZZH", 3, 33488},
	{"RCRE", 4, 33489},
	{"ETUN", 4, 33490},
	{"WHATS", 5, 33491},
	{"RIDES", 5, 33492},
	{"HIMF", 4, 33493},
	{"DSOL", 4, 33494},
	{"REHAB", 5, 33495},
	{"OFEL", 4, 33496},
	{"TALM", 4, 33497},
	{"UHY", 3, 33498},
	{"FORTUNATELY", 11, 33499},
	{"EPIC", 4, 33500},
	{"EWID", 4, 33501},
	{"COMPLIANCE", 10, 33502},
	{"SISW", 4, 33503},
	{"SATURN", 6, 33504},
	{"ORGANIZER", 9, 33505},
	{"LEAC", 4, 33506},
	{"MBRA", 4, 33507},
	{"KESP", 4, 33508},
	{"ALLERGY", 7, 33509},
	{"DAM", 3, 33510},
	{"TEXTBOOK", 8, 33511},
	{"TWISTED", 7, 33512},
	{"COMBINATIONS", 12, 33513},
	{"SEBU", 4, 33514},
	{"PRECEDING", 9, 33515},
	{"RCUS", 4, 33516},
	{"ENZYME", 6, 33517},
	{"ESEW", 4, 33518},
	{"OULL", 4, 33519},
	{"TCOR", 4, 33520},
	{"ACCESSIBLE", 10, 33521},
	{"DLOS", 4, 33522},
	{"CLASSIFY", 8, 33523},
	{"UNDL", 4, 33524},
	{"ZSHOPS", 6, 33525},
	{"ORTC", 4, 33526},
	{"YOPE", 4, 33527},
	{"ATTENDANCE", 10, 33528},
	{"PLANES", 6, 33529},
	{"EDMONTON", 8, 33530},
	{"AMBITION", 8, 33531},
	{"DISKS", 5, 33532},
	{"SEFF", 4, 33533},
	{"CONDO", 5, 33534},
	{"POKEMON", 7, 33535},
	{"AMPLIFIER", 9, 33536},
	{"DEFR", 4, 33537},
	{"DBOT", 4, 33538},
	{"BICYCLE", 7, 33539},
	{"NSDE", 4, 33540},
	{"AMBIEN", 6, 33541},
	{"ARBITRARY", 9, 33542},
	{"EAPE", 4, 33543},
	{"RETRIEVE", 8, 33544},
	{"LEXINGTON", 9, 33545},
	{"CUSTODY", 7, 33546},
	{"VERNON", 6, 33547},
	{"NGMU", 4, 33548},
	{"WORLDCAT", 8, 33549},
	{"TITANIUM", 8, 33550},
	{"UTEL", 4, 33551},
	{"LLWO", 4, 33552},
	{"WONA", 4, 33553},
	{"REQUIRED", 8, 33554},
	{"CONCEPTION", 10, 33555},
	{"FAIRY", 5, 33556},
	{"WYR", 3, 33557},
	{"OODL", 4, 33558},
	{"SOAP", 4, 33559},
	{"DISABLED", 8, 33560},
	{"FNOT", 4, 33561},
	{"UNCERTAIN", 9, 33562},
	{"LYSP", 4, 33563},
	{"LSHI", 4, 33564},
	{"LESM", 4, 33565},
	{"BUILDS", 6, 33566},
	{"CONTACTED", 9, 33567},
	{"ANONYMOUS", 9, 33568},
	{"TMUC", 4, 33569},
	{"SHAFT", 5, 33570},
	{"LIQUID", 6, 33571},
	{"COIN", 4, 33572},
	{"NEYI", 4, 33573},
	{"NBES", 4, 33574},
	{"DIARY", 5, 33575},
	{"BYE", 3, 33576},
	{"CDT", 3, 33577},
	{"UCTO", 4, 33578},
	{"SSFO", 4, 33579},
	{"NYRE", 4, 33580},
	{"LLIF", 4, 33581},
	{"RECORDERS", 9, 33582},
	{"EMERGING", 8, 33583},
	{"CONSTRAINT", 10, 33584},
	{"LESLIE", 6, 33585},
	{"CASIO", 5, 33586},
	{"RATIONAL", 8, 33587},
	{"DEUTSCHE", 8, 33588},
	{"YSEA", 4, 33589},
	{"ISTU", 4, 33590},
	{"PYJ", 3, 33591},
	{"ILQ", 3, 33592},
	{"INSTALLATION", 12, 33593},
	{"POSTINGS", 8, 33594},
	{"UZN", 3, 33595},
	{"PENCIL", 6, 33596},
	{"EQUIVALENT", 10, 33597},
	{"INNOVATIONS", 11, 33598},
	{"NDCE", 4, 33599},
	{"FPRE", 4, 33600},
	{"KITTY", 5, 33601},
	{"BANKER", 6, 33602},
	{"POSTCARDS", 9, 33603},
	{"NTSR", 4, 33604},
	{"DUDE", 4, 33605},
	{"ILTI", 4, 33606},
	{"INFORMAL", 8, 33607},
	{"MONTE", 5, 33608},
	{"YTON", 4, 33609},
	{"KZO", 3, 33610},
	{"ASUB", 4, 33611},
	{"ITYL", 4, 33612},
	{"YOUP", 4, 33613},
	{"KAQ", 3, 33614},
	{"FIRES", 5, 33615},
	{"ALGERIA", 7, 33616},
	{"CATALOG", 7, 33617},
	{"BLESSED", 7, 33618},
	{"LUIS", 4, 33619},
	{"NTYS", 4, 33620},
	{"ERFL", 4, 33621},
	{"TBAN", 4, 33622},
	{"REVIEWING", 9, 33623},
	{"CARDIFF", 7, 33624},
	{"DEQU", 4, 33625},
	{"CORNWALL", 8, 33626},
	{"INNOVATIVE", 10, 33627},
	{"EATD", 4, 33628},
	{"FAVORS", 6, 33629},
	{"GENRE", 5, 33630},
	{"RBER", 4, 33631},
	{"ULDW", 4, 33632},
	{"OWSE", 4, 33633},
	{"RETAILER", 8, 33634},
	{"WERO", 4, 33635},
	{"TOJU", 4, 33636},
	{"EXPLICITLY", 10, 33637},
	{"STICKS", 6, 33638},
	{"ARYM", 4, 33639},
	{"LEONE", 5, 33640},
	{"YOWN", 4, 33641},
	{"ODSA", 4, 33642},
	{"EINR", 4, 33643},
	{"IGHP", 4, 33644},
	{"MOMENTUM", 8, 33645},
	{"REPORTEDLY", 10, 33646},
	{"NGVI", 4, 33647},
	{"ENAF", 4, 33648},
	{"AIRW", 4, 33649},
	{"REFORMS", 7, 33650},
	{"REBR", 4, 33651},
	{"XTYE", 4, 33652},
	{"EXPLOIT", 7, 33653},
	{"ACKC", 4, 33654},
	{"PRELIMINARY", 11, 33655},
	{"NGRU", 4, 33656},
	{"RERI", 4, 33657},
	{"ISOP", 4, 33658},
	{"HPAR", 4, 33659},
	{"RLON", 4, 33660},
	{"MPON", 4, 33661},
	{"STRAND", 6, 33662},
	{"JDU", 3, 33663},
	{"BITO", 4, 33664},
	{"PASSING", 7, 33665},
	{"FROWN", 5, 33666},
	{"CKNO", 4, 33667},
	{"ALCR", 4, 33668},
	{"GCOU", 4, 33669},
	{"ALTO", 4, 33670},
	{"INFORMATIVE", 11, 33671},
	{"BLOOMBERG", 9, 33672},
	{"TDUR", 4, 33673},
	{"OOLB", 4, 33674},
	{"CHEQUE", 6, 33675},
	{"YGRA", 4, 33676},
	{"HIERARCHY", 9, 33677},
	{"STIMULATE", 9, 33678},
	{"INFLUENCED", 10, 33679},
	{"BANNERS", 7, 33680},
	{"FRONTIER", 8, 33681},
	{"AHUG", 4, 33682},
	{"EBIR", 4, 33683},
	{"ENFL", 4, 33684},
	{"URLI", 4, 33685},
	{"YLIF", 4, 33686},
	{"ENSW", 4, 33687},
	{"CZI", 3, 33688},
	{"ABANDONED", 9, 33689},
	{"IERC", 4, 33690},
	{"KNOWN", 5, 33691},
	{"CIRCLES", 7, 33692},
	{"YALT", 4, 33693},
	{"ITALIC", 6, 33694},
	{"DHEH", 4, 33695},
	{"BEATS", 5, 33696},
	{"BACKYARD", 8, 33697},
	{"IRHO", 4, 33698},
	{"SCUBA", 5, 33699},
	{"OIDE", 4, 33700},
	{"ARBU", 4, 33701},
	{"FZU", 3, 33702},
	{"RDEF", 4, 33703},
	{"NYWH", 4, 33704},
	{"SPELL", 5, 33705},
	{"EYNE", 4, 33706},
	{"EDAV", 4, 33707},
	{"UMPT", 4, 33708},
	{"GORE", 4, 33709},
	{"CEBO", 4, 33710},
	{"CORRECTLY", 9, 33711},
	{"NOTEBOOK", 8, 33712},
	{"COMPLEMENT", 10, 33713},
	{"NGOI", 4, 33714},
	{"SENSATION", 9, 33715},
	{"PARTIALLY", 9, 33716},
	{"HARASSMENT", 10, 33717},
	{"PROCESSOR", 9, 33718},
	{"OBEM", 4, 33719},
	{"ORYS", 4, 33720},
	{"CULT", 4, 33721},
	{"DEPL", 4, 33722},
	{"SPHERE", 6, 33723},
	{"DASH", 4, 33724},
	{"PASSIVE", 7, 33725},
	{"OTRY", 4, 33726},
	{"MAURITIUS", 9, 33727},
	{"TISD", 4, 33728},
	{"GINF", 4, 33729},
	{"SACK", 4, 33730},
	{"TRAUMA", 6, 33731},
	{"TFRE", 4, 33732},
	{"VALUED", 6, 33733},
	{"DISCLOSE", 8, 33734},
	{"RTSW", 4, 33735},
	{"IUW", 3, 33736},
	{"EJL", 3, 33737},
	{"IJUS", 4, 33738},
	{"CHECKLIST", 9, 33739},
	{"RTFR", 4, 33740},
	{"BANGBUS", 7, 33741},
	{"EGRI", 4, 33742},
	{"REQUESTING", 10, 33743},
	{"VERDE", 5, 33744},
	{"LAUDERDALE", 10, 33745},
	{"HFRO", 4, 33746},
	{"FEVER", 5, 33747},
	{"ORVI", 4, 33748},
	{"EUSU", 4, 33749},
	{"SCENARIOS", 9, 33750},
	{"GAZETTE", 7, 33751},
	{"ANYL", 4, 33752},
	{"HITACHI", 7, 33753},
	{"DIVX", 4, 33754},
	{"TERRAIN", 7, 33755},
	{"EXTRACTION", 10, 33756},
	{"BATMAN", 6, 33757},
	{"TOLERATE", 8, 33758},
	{"EPTO", 4, 33759},
	{"ELEVATION", 9, 33760},
	{"AYSP", 4, 33761},
	{"ENCOURAGING", 11, 33762},
	{"ALLN", 4, 33763},
	{"HEARINGS", 8, 33764},
	{"COLEMAN", 7, 33765},
	{"ZBY", 3, 33766},
	{"MEVE", 4, 33767},
	{"HUGH", 4, 33768},
	{"MEDF", 4, 33769},
	{"UTILIZATION", 11, 33770},
	{"BEVERAGES", 9, 33771},
	{"TLYO", 4, 33772},
	{"CALIBRATION", 11, 33773},
	{"JAKE", 4, 33774},
	{"ENEG", 4, 33775},
	{"EVAL", 4, 33776},
	{"EFFICIENTLY", 11, 33777},
	{"ANAHEIM", 7, 33778},
	{"UYIN", 4, 33779},
	{"OUTLINE", 7, 33780},
	{"THANKSGIVING", 12, 33781},
	{"ECTW", 4, 33782},
	{"PING", 4, 33783},
	{"HYEA", 4, 33784},
	{"STACK", 5, 33785},
	{"DEXT", 4, 33786},
	{"TSDI", 4, 33787},
	{"RSNO", 4, 33788},
	{"GUME", 4, 33789},
	{"DASO", 4, 33790},
	{"ELTI", 4, 33791},
	{"ENTERTAINING", 12, 33792},
	{"SLEEVE", 6, 33793},
	{"PREREQUISITE", 12, 33794},
	{"AGGE", 4, 33795},
	{"TOEV", 4, 33796},
	{"LUTHER", 6, 33797},
	{"EXCLUSIVELY", 11, 33798},
	{"TOOU", 4, 33799},
	{"OOLD", 4, 33800},
	{"STOPPING", 8, 33801},
	{"REFUGEES", 8, 33802},
	{"OUTFIT", 6, 33803},
	{"KNIGHTS", 7, 33804},
	{"EPQ", 3, 33805},
	{"PALMER", 6, 33806},
	{"AUTONOMY", 8, 33807},
	{"THLA", 4, 33808},
	{"MEDICINES", 9, 33809},
	{"UISH", 4, 33810},
	{"FLUX", 4, 33811},
	{"AMBASSADOR", 10, 33812},
	{"STGO", 4, 33813},
	{"RZS", 3, 33814},
	{"TNOR", 4, 33815},
	{"OCEE", 4, 33816},
	{"DERBY", 5, 33817},
	{"RGUM", 4, 33818},
	{"TRAINER", 7, 33819},
	{"EWOO", 4, 33820},
	{"ALTERED", 7, 33821},
	{"THBA", 4, 33822},
	{"EQUALITY", 8, 33823},
	{"PONTIAC", 7, 33824},
	{"REGRESSION", 10, 33825},
	{"YXA", 3, 33826},
	{"RNAR", 4, 33827},
	{"URYA", 4, 33828},
	{"GTOL", 4, 33829},
	{"YREM", 4, 33830},
	{"SCENIC", 6, 33831},
	{"TRAINERS", 8, 33832},
	{"MUZE", 4, 33833},
	{"YLIK", 4, 33834},
	{"LLYU", 4, 33835},
	{"NSWO", 4, 33836},
	{"YWHA", 4, 33837},
	{"ENHANCEMENTS", 12, 33838},
	{"ELAK", 4, 33839},
	{"RENEWABLE", 9, 33840},
	{"DEDM", 4, 33841},
	{"INTERSECTION", 12, 33842},
	{"YTOL", 4, 33843},
	{"TCOA", 4, 33844},
	{"ESEF", 4, 33845},
	{"LCZ", 3, 33846},
	{"PASSWORDS", 9, 33847},
	{"SEWING", 6, 33848},
	{"SUDD", 4, 33849},
	{"CONSISTENCY", 11, 33850},
	{"AISLE", 5, 33851},
	{"COLLECTORS", 10, 33852},
	{"GRANDCHILD", 10, 33853},
	{"SURROUNDING", 11, 33854},
	{"STREAK", 6, 33855},
	{"FLYI", 4, 33856},
	{"RECOGNISED", 10, 33857},
	{"MUNICH", 6, 33858},
	{"OMAN", 4, 33859},
	{"DQUO", 4, 33860},
	{"ELYH", 4, 33861},
	{"CELEBS", 6, 33862},
	{"ENMI", 4, 33863},
	{"AMPE", 4, 33864},
	{"GMC", 3, 33865},
	{"LIKEWISE", 8, 33866},
	{"BBLE", 4, 33867},
	{"THRA", 4, 33868},
	{"CHEAT", 5, 33869},
	{"KSWI", 4, 33870},
	{"IRONY", 5, 33871},
	{"GESW", 4, 33872},
	{"AZERBAIJAN", 10, 33873},
	{"LIGHTER", 7, 33874},
	{"CPRO", 4, 33875},
	{"ADSL", 4, 33876},
	{"EIGHTH", 6, 33877},
	{"SOCIALLY", 8, 33878},
	{"STANCE", 6, 33879},
	{"MPSO", 4, 33880},
	{"ITYD", 4, 33881},
	{"QUH", 3, 33882},
	{"TRASH", 5, 33883},
	{"PRIX", 4, 33884},
	{"HEOV", 4, 33885},
	{"DISCOUNT", 8, 33886},
	{"VECH", 4, 33887},
	{"ASTROLOGY", 9, 33888},
	{"ADVISORS", 8, 33889},
	{"PAVILION", 8, 33890},
	{"EESP", 4, 33891},
	{"LREP", 4, 33892},
	{"TACTICS", 7, 33893},
	{"AWAKE", 5, 33894},
	{"TRUSTS", 6, 33895},
	{"ATBO", 4, 33896},
	{"OCCURRING", 9, 33897},
	{"GROSS", 5, 33898},
	{"RFIE", 4, 33899},
	{"SUPPLEMENTAL", 12, 33900},
	{"NOFW", 4, 33901},
	{"TRAVELLING", 10, 33902},
	{"DBYF", 4, 33903},
	{"NTPE", 4, 33904},
	{"UNPRECEDENTED", 13, 33905},
	{"BREATHING", 9, 33906},
	{"THLI", 4, 33907},
	{"ANNIE", 5, 33908},
	{"OPAN", 4, 33909},
	{"ALRO", 4, 33910},
	{"WOFT", 4, 33911},
	{"HEAL", 4, 33912},
	{"PLANNER", 7, 33913},
	{"INDUCTION", 9, 33914},
	{"DEREK", 5, 33915},
	{"LLBA", 4, 33916},
	{"SHORTER", 7, 33917},
	{"XIG", 3, 33918},
	{"HARLEY", 6, 33919},
	{"SPREADING", 9, 33920},
	{"PROVINCES", 9, 33921},
	{"MENTALLY", 8, 33922},
	{"RELYING", 7, 33923},
	{"OTJU", 4, 33924},
	{"NSSU", 4, 33925},
	{"NFIL", 4, 33926},
	{"DBYE", 4, 33927},
	{"UOJ", 3, 33928},
	{"TYAR", 4, 33929},
	{"COLLAR", 6, 33930},
	{"UMPI", 4, 33931},
	{"FINALS", 6, 33932},
	{"LIKELIHOOD", 10, 33933},
	{"DLEO", 4, 33934},
	{"PARAGUAY", 8, 33935},
	{"XAMI", 4, 33936},
	{"ROD", 3, 33937},
	{"OMEU", 4, 33938},
	{"PARCEL", 6, 33939},
	{"REFINED", 7, 33940},
	{"BYAL", 4, 33941},
	{"ARSF", 4, 33942},
	{"STGR", 4, 33943},
	{"MORTALITY", 9, 33944},
	{"OUSR", 4, 33945},
	{"WELL-KNOWN", 10, 33946},
	{"FLEET", 5, 33947},
	{"WORLDWIDE", 9, 33948},
	{"NGSL", 4, 33949},
	{"INCIDENCE", 9, 33950},
	{"LLSP", 4, 33951},
	{"XUD", 3, 33952},
	{"NGSB", 4, 33953},
	{"RYSI", 4, 33954},
	{"TSME", 4, 33955},
	{"DNEA", 4, 33956},
	{"SPRINKLE", 8, 33957},
	{"TLYF", 4, 33958},
	{"LTAK", 4, 33959},
	{"FEARS", 5, 33960},
	{"ISEV", 4, 33961},
	{"BOUTIQUE", 8, 33962},
	{"LBES", 4, 33963},
	{"ACRYLIC", 7, 33964},
	{"COLORFUL", 8, 33965},
	{"ARTIFACT", 8, 33966},
	{"ROLLED", 6, 33967},
	{"SANF", 4, 33968},
	{"YDEF", 4, 33969},
	{"TUNER", 5, 33970},
	{"ACKM", 4, 33971},
	{"AVON", 4, 33972},
	{"SHED", 4, 33973},
	{"OMSO", 4, 33974},
	{"WEDA", 4, 33975},
	{"INSTANT", 7, 33976},
	{"DINJ", 4, 33977},
	{"TBEG", 4, 33978},
	{"NONP", 4, 33979},
	{"INCIDENTS", 9, 33980},
	{"YMOV", 4, 33981},
	{"CONFRONTATION", 13, 33982},
	{"MILL", 4, 33983},
	{"MIDST", 5, 33984},
	{"PETERSON", 8, 33985},
	{"ENUN", 4, 33986},
	{"RAYS", 4, 33987},
	{"LEDR", 4, 33988},
	{"SHANNON", 7, 33989},
	{"MINERAL", 7, 33990},
	{"UBUR", 4, 33991},
	{"NTAF", 4, 33992},
	{"DBYD", 4, 33993},
	{"MENTOR", 6, 33994},
	{"UMQ", 3, 33995},
	{"RKQ", 3, 33996},
	{"TODDLER", 7, 33997},
	{"EEKL", 4, 33998},
	{"TBOT", 4, 33999},
	{"ENHANCING", 9, 34000},
	{"PIONEER", 7, 34001},
	{"LAWMAKER", 8, 34002},
	{"MUTTER", 6, 34003},
	{"WALT", 4, 34004},
	{"ARYR", 4, 34005},
	{"METALLIC", 8, 34006},
	{"NGCE", 4, 34007},
	{"ACNE", 4, 34008},
	{"BLOCKED", 7, 34009},
	{"TOFN", 4, 34010},
	{"OTMA", 4, 34011},
	{"HDAY", 4, 34012},
	{"EAKT", 4, 34013},
	{"ONIG", 4, 34014},
	{"SOMEDAY", 7, 34015},
	{"FEATHER", 7, 34016},
	{"INTERFERENCE", 12, 34017},
	{"XYB", 3, 34018},
	{"DINR", 4, 34019},
	{"WARRIORS", 8, 34020},
	{"GHLI", 4, 34021},
	{"NGOL", 4, 34022},
	{"PALESTINE", 9, 34023},
	{"SHAREHOLDER", 11, 34024},
	{"GMAR", 4, 34025},
	{"PROU", 4, 34026},
	{"YBH", 3, 34027},
	{"RSUR", 4, 34028},
	{"EDAI", 4, 34029},
	{"ALIKE", 5, 34030},
	{"KEYO", 4, 34031},
	{"LISTPRICE", 9, 34032},
	{"TFIE", 4, 34033},
	{"DBEH", 4, 34034},
	{"ZPU", 3, 34035},
	{"ASEF", 4, 34036},
	{"LIBS", 4, 34037},
	{"UNDO", 4, 34038},
	{"CADILLAC", 8, 34039},
	{"SWIMMING", 8, 34040},
	{"ATMOSPHERIC", 11, 34041},
	{"MALAWI", 6, 34042},
	{"ENPO", 4, 34043},
	{"OTLA", 4, 34044},
	{"CUTO", 4, 34045},
	{"BOAST", 5, 34046},
	{"PHILOSOPHICAL", 13, 34047},
	{"SAGEM", 5, 34048},
	{"FTHR", 4, 34049},
	{"KNOWLEDGESTORM", 14, 34050},
	{"DANA", 4, 34051},
	{"WHEAT", 5, 34052},
	{"RKOF", 4, 34053},
	{"LBEH", 4, 34054},
	{"IRDE", 4, 34055},
	{"HALO", 4, 34056},
	{"PPM", 3, 34057},
	{"ACHW", 4, 34058},
	{"COMPEL", 6, 34059},
	{"NEDP", 4, 34060},
	{"CURTIS", 6, 34061},
	{"BEHALF", 6, 34062},
	{"VOCAL", 5, 34063},
	{"OPSA", 4, 34064},
	{"DTEL", 4, 34065},
	{"REFERENCED", 10, 34066},
	{"NOTJ", 4, 34067},
	{"PARISH", 6, 34068},
	{"STRIKES", 7, 34069},
	{"LESSER", 6, 34070},
	{"XEG", 3, 34071},
	{"MARATHON", 8, 34072},
	{"YOUB", 4, 34073},
	{"SORR", 4, 34074},
	{"DISTRACT", 8, 34075},
	{"LADDER", 6, 34076},
	{"BUILDER", 7, 34077},
	{"NEMY", 4, 34078},
	{"FEMINIST", 8, 34079},
	{"PROPOSITION", 11, 34080},
	{"CARROT", 6, 34081},
	{"UZY", 3, 34082},
	{"ITOU", 4, 34083},
	{"GAYS", 4, 34084},
	{"PRESSING", 8, 34085},
	{"ERYH", 4, 34086},
	{"ELLM", 4, 34087},
	{"PROCLAIM", 8, 34088},
	{"PARTIAL", 7, 34089},
	{"FEWM", 4, 34090},
	{"SOPR", 4, 34091},
	{"OFAU", 4, 34092},
	{"EAFO", 4, 34093},
	{"DRESSED", 7, 34094},
	{"WERP", 4, 34095},
	{"LLPE", 4, 34096},
	{"SEDD", 4, 34097},
	{"YSIT", 4, 34098},
	{"SCOUT", 5, 34099},
	{"BELFAST", 7, 34100},
	{"EXEC", 4, 34101},
	{"SLAVERY", 7, 34102},
	{"DEALT", 5, 34103},
	{"ALCE", 4, 34104},
	{"SSRE", 4, 34105},
	{"NIAGARA", 7, 34106},
	{"GPRE", 4, 34107},
	{"INTERFERE", 9, 34108},
	{"SIMILARITY", 10, 34109},
	{"INTERVAL", 8, 34110},
	{"WARCRAFT", 8, 34111},
	{"CHARMS", 6, 34112},
	{"CATALYST", 8, 34113},
	{"ARTB", 4, 34114},
	{"TRADER", 6, 34115},
	{"BUCKS", 5, 34116},
	{"IREW", 4, 34117},
	{"IUY", 3, 34118},
	{"ALLOWANCE", 9, 34119},
	{"DESPERATELY", 11, 34120},
	{"OLTH", 4, 34121},
	{"VCR", 3, 34122},
	{"RKTO", 4, 34123},
	{"SPECULATION", 11, 34124},
	{"MONKEY", 6, 34125},
	{"UNCOVER", 7, 34126},
	{"EDCL", 4, 34127},
	{"RHEW", 4, 34128},
	{"URI", 3, 34129},
	{"PREMISE", 7, 34130},
	{"HALFWAY", 7, 34131},
	{"DESIGNATION", 11, 34132},
	{"RYBE", 4, 34133},
	{"ALFT", 4, 34134},
	{"JUNGLE", 6, 34135},
	{"THROWN", 6, 34136},
	{"JURISDICTION", 12, 34137},
	{"NOFE", 4, 34138},
	{"PREPAID", 7, 34139},
	{"OUTSIDER", 8, 34140},
	{"SNEAK", 5, 34141},
	{"KPLA", 4, 34142},
	{"RGOT", 4, 34143},
	{"RAISES", 6, 34144},
	{"UALC", 4, 34145},
	{"ILYI", 4, 34146},
	{"GEM", 3, 34147},
	{"RFRI", 4, 34148},
	{"DUPLICATE", 9, 34149},
	{"ELECTRO", 7, 34150},
	{"BYST", 4, 34151},
	{"VEPL", 4, 34152},
	{"CRITERION", 9, 34153},
	{"ACKD", 4, 34154},
	{"BADGE", 5, 34155},
	{"JOURNALISM", 10, 34156},
	{"THEOLOGICAL", 11, 34157},
	{"YSUC", 4, 34158},
	{"EOFY", 4, 34159},
	{"UNDERGRADUATE", 13, 34160},
	{"NASTY", 5, 34161},
	{"CHUNK", 5, 34162},
	{"PLEB", 4, 34163},
	{"REMINDER", 8, 34164},
	{"HIGH-TECH", 9, 34165},
	{"ORAW", 4, 34166},
	{"AGEH", 4, 34167},
	{"QBT", 3, 34168},
	{"CEASE", 5, 34169},
	{"ANALYZED", 8, 34170},
	{"VIETNAMESE", 10, 34171},
	{"HEATH", 5, 34172},
	{"LEPO", 4, 34173},
	{"CLING", 5, 34174},
	{"ISQU", 4, 34175},
	{"ULDO", 4, 34176},
	{"RIM", 3, 34177},
	{"DYOF", 4, 34178},
	{"CHILL", 5, 34179},
	{"ONGP", 4, 34180},
	{"ATGR", 4, 34181},
	{"LEXUS", 5, 34182},
	{"KINGDOM", 7, 34183},
	{"DEPLOY", 6, 34184},
	{"LIGHTNING", 9, 34185},
	{"OPEF", 4, 34186},
	{"VARYING", 7, 34187},
	{"REMEDIES", 8, 34188},
	{"ANTD", 4, 34189},
	{"OBEO", 4, 34190},
	{"TRUSTEE", 7, 34191},
	{"MAUI", 4, 34192},
	{"UTOU", 4, 34193},
	{"MERIT", 5, 34194},
	{"WHEELCHAIR", 10, 34195},
	{"YCZ", 3, 34196},
	{"CHEW", 4, 34197},
	{"OUSW", 4, 34198},
	{"WEIGHTED", 8, 34199},
	{"ANGOLA", 6, 34200},
	{"SQUIRT", 6, 34201},
	{"TSJU", 4, 34202},
	{"ITHV", 4, 34203},
	{"UGHN", 4, 34204},
	{"PERFORMS", 8, 34205},
	{"PLASTICS", 8, 34206},
	{"TIGHTEN", 7, 34207},
	{"NYPE", 4, 34208},
	{"NGFE", 4, 34209},
	{"ISMU", 4, 34210},
	{"TWOF", 4, 34211},
	{"DIP", 3, 34212},
	{"DHOU", 4, 34213},
	{"YTOF", 4, 34214},
	{"NINM", 4, 34215},
	{"CORRECTED", 9, 34216},
	{"SUPPORTIVE", 10, 34217},
	{"RIB", 3, 34218},
	{"FBEI", 4, 34219},
	{"OOMU", 4, 34220},
	{"TQB", 3, 34221},
	{"JENNY", 5, 34222},
	{"COMMODITY", 9, 34223},
	{"SALARIES", 8, 34224},
	{"POSTCARD", 8, 34225},
	{"STVI", 4, 34226},
	{"UNFAIR", 6, 34227},
	{"RDAT", 4, 34228},
	{"ELEP", 4, 34229},
	{"YEMEN", 5, 34230},
	{"INVADE", 6, 34231},
	{"LLSW", 4, 34232},
	{"OINV", 4, 34233},
	{"MANP", 4, 34234},
	{"ELYN", 4, 34235},
	{"FUW", 3, 34236},
	{"ENCOUNTERED", 11, 34237},
	{"TRYW", 4, 34238},
	{"MARKETPLACE", 11, 34239},
	{"ENPE", 4, 34240},
	{"TSUNAMI", 7, 34241},
	{"NHOL", 4, 34242},
	{"CEOR", 4, 34243},
	{"LEHO", 4, 34244},
	{"YBEG", 4, 34245},
	{"AUQ", 3, 34246},
	{"NICKEL", 6, 34247},
	{"RSEI", 4, 34248},
	{"SLEG", 4, 34249},
	{"HSPE", 4, 34250},
	{"LOGICAL", 7, 34251},
	{"INTERNATIONALLY", 15, 34252},
	{"LSYS", 4, 34253},
	{"SURROUNDED", 10, 34254},
	{"ATBU", 4, 34255},
	{"BUSES", 5, 34256},
	{"EXPEDIA", 7, 34257},
	{"GEOLOGY", 7, 34258},
	{"WEED", 4, 34259},
	{"RBET", 4, 34260},
	{"PCT", 3, 34261},
	{"CREATURES", 9, 34262},
	{"COATING", 7, 34263},
	{"EJV", 3, 34264},
	{"COMMENTED", 9, 34265},
	{"WALLET", 6, 34266},
	{"WEAKEN", 6, 34267},
	{"CLEARED", 7, 34268},
	{"IFEO", 4, 34269},
	{"RMEM", 4, 34270},
	{"OLVI", 4, 34271},
	{"NEDM", 4, 34272},
	{"DEEM", 4, 34273},
	{"EISD", 4, 34274},
	{"IDSO", 4, 34275},
	{"GETR", 4, 34276},
	{"SMILIES", 7, 34277},
	{"OYIN", 4, 34278},
	{"OGRO", 4, 34279},
	{"NFUS", 4, 34280},
	{"HEEF", 4, 34281},
	{"VIDS", 4, 34282},
	{"SKIP", 4, 34283},
	{"BOATING", 7, 34284},
	{"DRAINAGE", 8, 34285},
	{"EXCESSIVE", 9, 34286},
	{"RFAT", 4, 34287},
	{"RISKY", 5, 34288},
	{"RTUA", 4, 34289},
	{"EWTO", 4, 34290},
	{"SHAKIRA", 7, 34291},
	{"TYSE", 4, 34292},
	{"CORNERS", 7, 34293},
	{"CURIOSITY", 9, 34294},
	{"BROADER", 7, 34295},
	{"SCRATCH", 7, 34296},
	{"VEGETARIAN", 10, 34297},
	{"HGRA", 4, 34298},
	{"UXR", 3, 34299},
	{"KYY", 3, 34300},
	{"LVAN", 4, 34301},
	{"ROUGE", 5, 34302},
	{"CEWE", 4, 34303},
	{"YEAST", 5, 34304},
	{"EMBARRASSED", 11, 34305},
	{"CONVERSION", 10, 34306},
	{"TLYH", 4, 34307},
	{"YALE", 4, 34308},
	{"UGHC", 4, 34309},
	{"NEWFOUNDLAND", 12, 34310},
	{"DEDP", 4, 34311},
	{"OTUR", 4, 34312},
	{"QLD", 3, 34313},
	{"OEAR", 4, 34314},
	{"OGOO", 4, 34315},
	{"FIERCE", 6, 34316},
	{"SPECIALTY", 9, 34317},
	{"UVU", 3, 34318},
	{"GEWH", 4, 34319},
	{"CLEARING", 8, 34320},
	{"INVESTIGATED", 12, 34321},
	{"LISTENER", 8, 34322},
	{"AUCTION", 7, 34323},
	{"OSTB", 4, 34324},
	{"NVIL", 4, 34325},
	{"FHEA", 4, 34326},
	{"RCEM", 4, 34327},
	{"USPR", 4, 34328},
	{"WAYB", 4, 34329},
	{"LEDP", 4, 34330},
	{"ENVISION", 8, 34331},
	{"RALLY", 5, 34332},
	{"UGET", 4, 34333},
	{"OWSI", 4, 34334},
	{"OWEE", 4, 34335},
	{"SHRINK", 6, 34336},
	{"ADDED", 5, 34337},
	{"COATED", 6, 34338},
	{"FTAN", 4, 34339},
	{"STEPHANIE", 9, 34340},
	{"YOFW", 4, 34341},
	{"FULF", 4, 34342},
	{"BRIDE", 5, 34343},
	{"EDIB", 4, 34344},
	{"RYBU", 4, 34345},
	{"CONTACTING", 10, 34346},
	{"VEGETATION", 10, 34347},
	{"DOOM", 4, 34348},
	{"FINDARTICLES", 12, 34349},
	{"NFOL", 4, 34350},
	{"LOUISE", 6, 34351},
	{"KENNY", 5, 34352},
	{"UGAR", 4, 34353},
	{"SPECIALLY", 9, 34354},
	{"PEASANT", 7, 34355},
	{"OWEN", 4, 34356},
	{"TOPM", 4, 34357},
	{"ROUTINES", 8, 34358},
	{"HITTING", 7, 34359},
	{"DOFP", 4, 34360},
	{"YUKON", 5, 34361},
	{"ASSW", 4, 34362},
	{"NTEC", 4, 34363},
	{"NFIG", 4, 34364},
	{"BEINGS", 6, 34365},
	{"AYSF", 4, 34366},
	{"PEANUT", 6, 34367},
	{"HTHR", 4, 34368},
	{"AQUATIC", 7, 34369},
	{"CITIZENSHIP", 11, 34370},
	{"RELIANCE", 8, 34371},
	{"UMOF", 4, 34372},
	{"EKSA", 4, 34373},
	{"GUED", 4, 34374},
	{"SOWH", 4, 34375},
	{"ASGI", 4, 34376},
	{"COMPARABLE", 10, 34377},
	{"ONOV", 4, 34378},
	{"HABITS", 6, 34379},
	{"YOFL", 4, 34380},
	{"SAFR", 4, 34381},
	{"INFECTIOUS", 10, 34382},
	{"PODCASTS", 8, 34383},
	{"STEAK", 5, 34384},
	{"GEDB", 4, 34385},
	{"SINGH", 5, 34386},
	{"ANER", 4, 34387},
	{"GIG", 3, 34388},
	{"ITRA", 4, 34389},
	{"GILBERT", 7, 34390},
	{"FERRARI", 7, 34391},
	{"VEWO", 4, 34392},
	{"FWIT", 4, 34393},
	{"LEGISLATOR", 10, 34394},
	{"RTCO", 4, 34395},
	{"CONTINUITY", 10, 34396},
	{"LYFA", 4, 34397},
	{"BROOK", 5, 34398},
	{"DCLO", 4, 34399},
	{"OUTPUTS", 7, 34400},
	{"TWES", 4, 34401},
	{"MEUP", 4, 34402},
	{"SLAU", 4, 34403},
	{"TINB", 4, 34404},
	{"ENSEMBLE", 8, 34405},
	{"TOLL", 4, 34406},
	{"INSULIN", 7, 34407},
	{"NDET", 4, 34408},
	{"ASSURED", 7, 34409},
	{"BIBLICAL", 8, 34410},
	{"BLANK", 5, 34411},
	{"ECEP", 4, 34412},
	{"NOFR", 4, 34413},
	{"RTHD", 4, 34414},
	{"CEMETERY", 8, 34415},
	{"MYSIMON", 7, 34416},
	{"WIVES", 5, 34417},
	{"AMBIENT", 7, 34418},
	{"PSOF", 4, 34419},
	{"ATOP", 4, 34420},
	{"MILEAGE", 7, 34421},
	{"CALCULATION", 11, 34422},
	{"KKY", 3, 34423},
	{"OECD", 4, 34424},
	{"ITEF", 4, 34425},
	{"PROSTATE", 8, 34426},
	{"POKE", 4, 34427},
	{"ADAPTOR", 7, 34428},
	{"LDHI", 4, 34429},
	{"AUBURN", 6, 34430},
	{"UNLOCK", 6, 34431},
	{"HYUNDAI", 7, 34432},
	{"PLEDGE", 6, 34433},
	{"LEPL", 4, 34434},
	{"VAMPIRE", 7, 34435},
	{"ANGELA", 6, 34436},
	{"RELATES", 7, 34437},
	{"NHOM", 4, 34438},
	{"VENC", 4, 34439},
	{"GSWE", 4, 34440},
	{"EENU", 4, 34441},
	{"NITROGEN", 8, 34442},
	{"XEROX", 5, 34443},
	{"ELYM", 4, 34444},
	{"DPUB", 4, 34445},
	{"DICE", 4, 34446},
	{"MERGER", 6, 34447},
	{"SOFTBALL", 8, 34448},
	{"REFERRALS", 9, 34449},
	{"GLIMPSE", 7, 34450},
	{"QUAD", 4, 34451},
	{"FIREWIRE", 8, 34452},
	{"MODS", 4, 34453},
	{"NEXTEL", 6, 34454},
	{"YWOO", 4, 34455},
	{"FRAMING", 7, 34456},
	{"MESM", 4, 34457},
	{"KSTA", 4, 34458},
	{"INHERIT", 7, 34459},
	{"VESF", 4, 34460},
	{"RVET", 4, 34461},
	{"ORGANISED", 9, 34462},
	{"NDHU", 4, 34463},
	{"RNSA", 4, 34464},
	{"GELI", 4, 34465},
	{"OPENLY", 6, 34466},
	{"TWO-THIRDS", 10, 34467},
	{"BLOCKING", 8, 34468},
	{"PUBLICITY", 9, 34469},
	{"DTHU", 4, 34470},
	{"RWANDA", 6, 34471},
	{"TFEW", 4, 34472},
	{"SVIS", 4, 34473},
	{"THFR", 4, 34474},
	{"SORTS", 5, 34475},
	{"INTEGRATING", 11, 34476},
	{"VSNET", 5, 34477},
	{"LIMITING", 8, 34478},
	{"UPSE", 4, 34479},
	{"DISPATCH", 8, 34480},
	{"REVISIONS", 9, 34481},
	{"HSOF", 4, 34482},
	{"OFJA", 4, 34483},
	{"THTW", 4, 34484},
	{"DDAN", 4, 34485},
	{"PAPUA", 5, 34486},
	{"RESTORED", 8, 34487},
	{"ARMOR", 5, 34488},
	{"RIDERS", 6, 34489},
	{"CHARGERS", 8, 34490},
	{"FCOL", 4, 34491},
	{"DOZENS", 6, 34492},
	{"VARIES", 6, 34493},
	{"ULLT", 4, 34494},
	{"NXC", 3, 34495},
	{"OUPA", 4, 34496},
	{"OTAP", 4, 34497},
	{"ICHL", 4, 34498},
	{"REHABILITATION", 14, 34499},
	{"MSIE", 4, 34500},
	{"REASONING", 9, 34501},
	{"MEAG", 4, 34502},
	{"MEPL", 4, 34503},
	{"DSUR", 4, 34504},
	{"DEPRESSED", 9, 34505},
	{"VENDOR", 6, 34506},
	{"GETB", 4, 34507},
	{"EUSI", 4, 34508},
	{"LIZ", 3, 34509},
	{"ROMU", 4, 34510},
	{"RENDERED", 8, 34511},
	{"SOVEREIGNTY", 11, 34512},
	{"PICKING", 7, 34513},
	{"SDUE", 4, 34514},
	{"ONTG", 4, 34515},
	{"LHER", 4, 34516},
	{"CHARITABLE", 10, 34517},
	{"GUARDS", 6, 34518},
	{"YCLA", 4, 34519},
	{"ANNOTATED", 9, 34520},
	{"CCD", 3, 34521},
	{"OPENINGS", 8, 34522},
	{"YWW", 3, 34523},
	{"YFF", 3, 34524},
	{"FASTER", 6, 34525},
	{"BUYS", 4, 34526},
	{"MBLY", 4, 34527},
	{"MUNICIPAL", 9, 34528},
	{"BURLINGTON", 10, 34529},
	{"BUTP", 4, 34530},
	{"GLET", 4, 34531},
	{"RCEI", 4, 34532},
	{"SOLE", 4, 34533},
	{"REPLACING", 9, 34534},
	{"UTLO", 4, 34535},
	{"WATERSHED", 9, 34536},
	{"NEYF", 4, 34537},
	{"COUNCILS", 8, 34538},
	{"OCCUPATIONS", 11, 34539},
	{"YSOU", 4, 34540},
	{"STRICTLY", 8, 34541},
	{"DISTURB", 7, 34542},
	{"FVU", 3, 34543},
	{"ACKNOWLEDGED", 12, 34544},
	{"TONF", 4, 34545},
	{"NUDITY", 6, 34546},
	{"ELIGIBLE", 8, 34547},
	{"OUGE", 4, 34548},
	{"BEARD", 5, 34549},
	{"YMIL", 4, 34550},
	{"KRUGER", 6, 34551},
	{"POCKETS", 7, 34552},
	{"GRANNY", 6, 34553},
	{"LEEA", 4, 34554},
	{"EQUILIBRIUM", 11, 34555},
	{"EWMO", 4, 34556},
	{"GYK", 3, 34557},
	{"KSHA", 4, 34558},
	{"BRAKE", 5, 34559},
	{"VIRAL", 5, 34560},
	{"KOFA", 4, 34561},
	{"NEBU", 4, 34562},
	{"GETE", 4, 34563},
	{"INQUIRE", 7, 34564},
	{"SQUAD", 5, 34565},
	{"LVU", 3, 34566},
	{"INKW", 4, 34567},
	{"PIPES", 5, 34568},
	{"CHARACTERIZED", 13, 34569},
	{"LADEN", 5, 34570},
	{"OTWA", 4, 34571},
	{"ARUBA", 5, 34572},
	{"COTTAGES", 8, 34573},
	{"STRIKING", 8, 34574},
	{"NSOC", 4, 34575},
	{"REALTOR", 7, 34576},
	{"MERGE", 5, 34577},
	{"TOLERANCE", 9, 34578},
	{"JJO", 3, 34579},
	{"NGDR", 4, 34580},
	{"EYVE", 4, 34581},
	{"OWLI", 4, 34582},
	{"EDGAR", 5, 34583},
	{"DEVELOPS", 8, 34584},
	{"QUALIFYING", 10, 34585},
	{"VALID", 5, 34586},
	{"SPOW", 4, 34587},
	{"CHASSIS", 7, 34588},
	{"LDCH", 4, 34589},
	{"REAA", 4, 34590},
	{"PROGRAMMING", 11, 34591},
	{"IRMI", 4, 34592},
	{"ARFR", 4, 34593},
	{"CLOSEST", 7, 34594},
	{"XERC", 4, 34595},
	{"DUBAI", 5, 34596},
	{"ESTIMATION", 10, 34597},
	{"PUSHING", 7, 34598},
	{"LLP", 3, 34599},
	{"REFUGE", 6, 34600},
	{"DYING", 5, 34601},
	{"VOLUNTARY", 9, 34602},
	{"FLEECE", 6, 34603},
	{"DDEA", 4, 34604},
	{"PEDIATRIC", 9, 34605},
	{"BOC", 3, 34606},
	{"SFIE", 4, 34607},
	{"EDGA", 4, 34608},
	{"OMIL", 4, 34609},
	{"ASUS", 4, 34610},
	{"PIERCE", 6, 34611},
	{"RESF", 4, 34612},
	{"STYP", 4, 34613},
	{"OADW", 4, 34614},
	{"NROL", 4, 34615},
	{"ALLAN", 5, 34616},
	{"ELAU", 4, 34617},
	{"SOFA", 4, 34618},
	{"DRESSING", 8, 34619},
	{"TECHREPUBLIC", 12, 34620},
	{"SPERM", 5, 34621},
	{"BALD", 4, 34622},
	{"FILME", 5, 34623},
	{"CRAPS", 5, 34624},
	{"FUJI", 4, 34625},
	{"OUTLET", 6, 34626},
	{"DEPOSIT", 7, 34627},
	{"BNX", 3, 34628},
	{"NUIN", 4, 34629},
	{"FROST", 5, 34630},
	{"LEDD", 4, 34631},
	{"THBO", 4, 34632},
	{"LEON", 4, 34633},
	{"LGET", 4, 34634},
	{"INSTITUTES", 10, 34635},
	{"DKIN", 4, 34636},
	{"SPARE", 5, 34637},
	{"MOLD", 4, 34638},
	{"DEBRIS", 6, 34639},
	{"RTHU", 4, 34640},
	{"DAME", 4, 34641},
	{"PLUNGE", 6, 34642},
	{"BUTT", 4, 34643},
	{"THRESHOLD", 9, 34644},
	{"NLOC", 4, 34645},
	{"YERA", 4, 34646},
	{"ADSE", 4, 34647},
	{"RMUL", 4, 34648},
	{"OWYO", 4, 34649},
	{"REMOVAL", 7, 34650},
	{"SALLY", 5, 34651},
	{"YACHT", 5, 34652},
	{"LSEE", 4, 34653},
	{"TRACY", 5, 34654},
	{"PREFERS", 7, 34655},
	{"NMOV", 4, 34656},
	{"DRILLING", 8, 34657},
	{"BROCHURES", 9, 34658},
	{"DUMB", 4, 34659},
	{"BALANCED", 8, 34660},
	{"AUSI", 4, 34661},
	{"UDEA", 4, 34662},
	{"RSTG", 4, 34663},
	{"FAME", 4, 34664},
	{"LTIT", 4, 34665},
	{"TMP", 3, 34666},
	{"ALOT", 4, 34667},
	{"AIDF", 4, 34668},
	{"LEGALLY", 7, 34669},
	{"BREACH", 6, 34670},
	{"OZW", 3, 34671},
	{"FREA", 4, 34672},
	{"TRAVELLER", 9, 34673},
	{"SYLV", 4, 34674},
	{"VESC", 4, 34675},
	{"DNEY", 4, 34676},
	{"HCHA", 4, 34677},
	{"APPROPRIATIONS", 14, 34678},
	{"ISOLATED", 8, 34679},
	{"ISCE", 4, 34680},
	{"SUSPECTED", 9, 34681},
	{"CONSIDERABLY", 12, 34682},
	{"TOMATOES", 8, 34683},
	{"BENCHMARK", 9, 34684},
	{"BEGINNERS", 9, 34685},
	{"INSTRUCTORS", 11, 34686},
	{"HIGHLIGHTED", 11, 34687},
	{"BEDFORD", 7, 34688},
	{"RESM", 4, 34689},
	{"REGRET", 6, 34690},
	{"BLOND", 5, 34691},
	{"STATIONERY", 10, 34692},
	{"OTPR", 4, 34693},
	{"VEPA", 4, 34694},
	{"IDLE", 4, 34695},
	{"ORBR", 4, 34696},
	{"MEBO", 4, 34697},
	{"ICHB", 4, 34698},
	{"MUSTANG", 7, 34699},
	{"DASM", 4, 34700},
	{"RINV", 4, 34701},
	{"UNAUTHORIZED", 12, 34702},
	{"RRIO", 4, 34703},
	{"CLUSTERS", 8, 34704},
	{"ANTIBODY", 8, 34705},
	{"COMPETENT", 9, 34706},
	{"NLYR", 4, 34707},
	{"DAPO", 4, 34708},
	{"WIRING", 6, 34709},
	{"THRIVE", 6, 34710},
	{"NORG", 4, 34711},
	{"RLOO", 4, 34712},
	{"EASM", 4, 34713},
	{"CONSECUTIVE", 11, 34714},
	{"FKW", 3, 34715},
	{"RDIA", 4, 34716},
	{"CURE", 4, 34717},
	{"SLEY", 4, 34718},
	{"CALVIN", 6, 34719},
	{"TCRE", 4, 34720},
	{"EXPEDITION", 10, 34721},
	{"KNEEL", 5, 34722},
	{"FUR", 3, 34723},
	{"LSUP", 4, 34724},
	{"CEND", 4, 34725},
	{"RLAS", 4, 34726},
	{"NPOI", 4, 34727},
	{"DISAPPOINTMENT", 14, 34728},
	{"NEDR", 4, 34729},
	{"REGULATOR", 9, 34730},
	{"UFK", 3, 34731},
	{"EXPLICIT", 8, 34732},
	{"TSDO", 4, 34733},
	{"HUNGER", 6, 34734},
	{"OGYA", 4, 34735},
	{"ARSP", 4, 34736},
	{"DEMONSTRATES", 12, 34737},
	{"PHASES", 6, 34738},
	{"GOAT", 4, 34739},
	{"DRIVEWAY", 8, 34740},
	{"UTEV", 4, 34741},
	{"BANANA", 6, 34742},
	{"TWENTIETH", 9, 34743},
	{"EMERALD", 7, 34744},
	{"LAUGHING", 8, 34745},
	{"GROWS", 5, 34746},
	{"SOLELY", 6, 34747},
	{"DESIRABLE", 9, 34748},
	{"THSU", 4, 34749},
	{"INTEGRATED", 10, 34750},
	{"TRACT", 5, 34751},
	{"BALLET", 6, 34752},
	{"RCHR", 4, 34753},
	{"UMST", 4, 34754},
	{"ABRAHAM", 7, 34755},
	{"STEER", 5, 34756},
	{"COMPLY", 6, 34757},
	{"SUPPOSEDLY", 10, 34758},
	{"ALLEGEDLY", 9, 34759},
	{"SUNC", 4, 34760},
	{"YWC", 3, 34761},
	{"ONQU", 4, 34762},
	{"BUMPER", 6, 34763},
	{"AFTERWARDS", 10, 34764},
	{"WEBPAGE", 7, 34765},
	{"THFI", 4, 34766},
	{"SEEW", 4, 34767},
	{"UTHS", 4, 34768},
	{"MOLECULE", 8, 34769},
	{"RELIGIONS", 9, 34770},
	{"GEFR", 4, 34771},
	{"ANBO", 4, 34772},
	{"NYZ", 3, 34773},
	{"CHEER", 5, 34774},
	{"GSON", 4, 34775},
	{"RTSH", 4, 34776},
	{"HOSTELS", 7, 34777},
	{"ENACT", 5, 34778},
	{"ALAL", 4, 34779},
	{"SENEGAL", 7, 34780},
	{"RPOW", 4, 34781},
	{"HAPT", 4, 34782},
	{"MISSIONARY", 10, 34783},
	{"BVO", 3, 34784},
	{"CRUISE", 6, 34785},
	{"BANNED", 6, 34786},
	{"WENDY", 5, 34787},
	{"ALYE", 4, 34788},
	{"OOLE", 4, 34789},
	{"BRIEFS", 6, 34790},
	{"SIGNATURES", 10, 34791},
	{"ILEW", 4, 34792},
	{"RTYT", 4, 34793},
	{"DIFFS", 5, 34794},
	{"TOURISM", 7, 34795},
	{"COVE", 4, 34796},
	{"RPET", 4, 34797},
	{"RTWA", 4, 34798},
	{"HATJ", 4, 34799},
	{"OILE", 4, 34800},
	{"NEUP", 4, 34801},
	{"DFLO", 4, 34802},
	{"NUTRIENT", 8, 34803},
	{"MUMBAI", 6, 34804},
	{"VEPO", 4, 34805},
	{"OZONE", 5, 34806},
	{"ONDW", 4, 34807},
	{"HPOI", 4, 34808},
	{"DISCIPLINES", 11, 34809},
	{"NSMO", 4, 34810},
	{"CASA", 4, 34811},
	{"OSEV", 4, 34812},
	{"IGHA", 4, 34813},
	{"DAUGHTERS", 9, 34814},
	{"UNFOLD", 6, 34815},
	{"INEVITABLY", 10, 34816},
	{"CONVERSATIONS", 13, 34817},
	{"NFOO", 4, 34818},
	{"ETOK", 4, 34819},
	{"RADIOS", 6, 34820},
	{"FORUM", 5, 34821},
	{"TARIFF", 6, 34822},
	{"TONR", 4, 34823},
	{"NVIDIA", 6, 34824},
	{"OFFENDER", 8, 34825},
	{"NGOP", 4, 34826},
	{"EACR", 4, 34827},
	{"SIMPLIFIED", 10, 34828},
	{"MUSCLES", 7, 34829},
	{"SERUM", 5, 34830},
	{"LIVER", 5, 34831},
	{"RTYO", 4, 34832},
	{"WRAPPED", 7, 34833},
	{"IGNM", 4, 34834},
	{"SUSPICIOUS", 10, 34835},
	{"WWIT", 4, 34836},
	{"SWIFT", 5, 34837},
	{"HARMONY", 7, 34838},
	{"RWER", 4, 34839},
	{"MOTHERBOARD", 11, 34840},
	{"ACCOUNTABILITY", 14, 34841},
	{"LSAL", 4, 34842},
	{"RUNTIME", 7, 34843},
	{"SCREENING", 9, 34844},
	{"INBOX", 5, 34845},
	{"FOCAL", 5, 34846},
	{"BIBLIOGRAPHIC", 13, 34847},
	{"EMSO", 4, 34848},
	{"RLDA", 4, 34849},
	{"LIQU", 4, 34850},
	{"RYSA", 4, 34851},
	{"EDEN", 4, 34852},
	{"INCL", 4, 34853},
	{"NTTR", 4, 34854},
	{"MEPO", 4, 34855},
	{"CHAMPAGNE", 9, 34856},
	{"OUNE", 4, 34857},
	{"DECIMAL", 7, 34858},
	{"ESTG", 4, 34859},
	{"DISC", 4, 34860},
	{"DEVIATION", 9, 34861},
	{"SUPERINTENDENT", 14, 34862},
	{"PROPECIA", 8, 34863},
	{"ENLO", 4, 34864},
	{"NBC", 3, 34865},
	{"SAMBA", 5, 34866},
	{"PREDATOR", 8, 34867},
	{"HOSTEL", 6, 34868},
	{"HOUSEWIVES", 10, 34869},
	{"ITFR", 4, 34870},
	{"TDEA", 4, 34871},
	{"MONGOLIA", 8, 34872},
	{"PENGUIN", 7, 34873},
	{"YXM", 3, 34874},
	{"MAGICAL", 7, 34875},
	{"INFLUENCES", 10, 34876},
	{"ISHW", 4, 34877},
	{"UBMI", 4, 34878},
	{"INSPECTIONS", 11, 34879},
	{"EAMB", 4, 34880},
	{"CEFI", 4, 34881},
	{"IRRIGATION", 10, 34882},
	{"OREY", 4, 34883},
	{"EPOO", 4, 34884},
	{"HSID", 4, 34885},
	{"CHSE", 4, 34886},
	{"EAFF", 4, 34887},
	{"SWEATER", 7, 34888},
	{"DGOO", 4, 34889},
	{"MANUALLY", 8, 34890},
	{"LROA", 4, 34891},
	{"ABEA", 4, 34892},
	{"REPRINT", 7, 34893},
	{"REID", 4, 34894},
	{"PTIC", 4, 34895},
	{"SUPERMARKET", 11, 34896},
	{"HYDRAULIC", 9, 34897},
	{"DELIBERATELY", 12, 34898},
	{"RNIT", 4, 34899},
	{"TKW", 3, 34900},
	{"CENTERED", 8, 34901},
	{"ROBERTSON", 9, 34902},
	{"OJOI", 4, 34903},
	{"YEARLY", 6, 34904},
	{"GESH", 4, 34905},
	{"TTEL", 4, 34906},
	{"PENETRATION", 11, 34907},
	{"TIMU", 4, 34908},
	{"EYIS", 4, 34909},
	{"USTG", 4, 34910},
	{"BELLE", 5, 34911},
	{"WARMTH", 6, 34912},
	{"ROSA", 4, 34913},
	{"STHU", 4, 34914},
	{"NDDU", 4, 34915},
	{"ISHL", 4, 34916},
	{"ASDR", 4, 34917},
	{"OMISSIONS", 9, 34918},
	{"WRITINGS", 8, 34919},
	{"RSIA", 4, 34920},
	{"HAMBURG", 7, 34921},
	{"SPECIFY", 7, 34922},
	{"FQI", 3, 34923},
	{"LAZY", 4, 34924},
	{"MAGNETIC", 8, 34925},
	{"BIGB", 4, 34926},
	{"ENAV", 4, 34927},
	{"MPG", 3, 34928},
	{"RSEO", 4, 34929},
	{"SAWE", 4, 34930},
	{"RINH", 4, 34931},
	{"RETRIEVAL", 9, 34932},
	{"QUALITIES", 9, 34933},
	{"CINDY", 5, 34934},
	{"DISTINCTIVE", 11, 34935},
	{"SEFU", 4, 34936},
	{"TESU", 4, 34937},
	{"FATHERS", 7, 34938},
	{"CARB", 4, 34939},
	{"CHARGING", 8, 34940},
	{"NINW", 4, 34941},
	{"RSTY", 4, 34942},
	{"YWON", 4, 34943},
	{"RVAR", 4, 34944},
	{"MARVEL", 6, 34945},
	{"CEDH", 4, 34946},
	{"LINED", 5, 34947},
	{"GSYS", 4, 34948},
	{"RRAY", 4, 34949},
	{"EIMM", 4, 34950},
	{"LDNE", 4, 34951},
	{"DOW", 3, 34952},
	{"PROTOTYPE", 9, 34953},
	{"FARE", 4, 34954},
	{"JYO", 3, 34955},
	{"PETITE", 6, 34956},
	{"SCREW", 5, 34957},
	{"APPARATUS", 9, 34958},
	{"UPC", 3, 34959},
	{"DUI", 3, 34960},
	{"BEAP", 4, 34961},
	{"PENS", 4, 34962},
	{"EXPLAINING", 10, 34963},
	{"IEWA", 4, 34964},
	{"STRIPS", 6, 34965},
	{"RENTAL", 6, 34966},
	{"UOZ", 3, 34967},
	{"GOSSIP", 6, 34968},
	{"NGTW", 4, 34969},
	{"OUTG", 4, 34970},
	{"OSAV", 4, 34971},
	{"TFIV", 4, 34972},
	{"IRAL", 4, 34973},
	{"STRAIGHTEN", 10, 34974},
	{"DAPT", 4, 34975},
	{"ATAD", 4, 34976},
	{"RANGERS", 7, 34977},
	{"NGYE", 4, 34978},
	{"INTACT", 6, 34979},
	{"FORMERLY", 8, 34980},
	{"ARTICULATE", 10, 34981},
	{"EMPIRICAL", 9, 34982},
	{"NETR", 4, 34983},
	{"ELABORATE", 9, 34984},
	{"EEXI", 4, 34985},
	{"ROTARY", 6, 34986},
	{"WORM", 4, 34987},
	{"ANID", 4, 34988},
	{"RNSO", 4, 34989},
	{"DEPENDENCE", 10, 34990},
	{"PALACE", 6, 34991},
	{"DISCRETE", 8, 34992},
	{"BEGINNER", 8, 34993},
	{"LDDO", 4, 34994},
	{"BOXED", 5, 34995},
	{"SOAR", 4, 34996},
	{"SUBSTANTIALLY", 13, 34997},
	{"DNTB", 4, 34998},
	{"NEQU", 4, 34999},
	{"AFOO", 4, 35000},
	{"KLES", 4, 35001},
	{"POLYESTER", 9, 35002},
	{"DFIL", 4, 35003},
	{"WHYT", 4, 35004},
	{"LFTH", 4, 35005},
	{"CUBIC", 5, 35006},
	{"DEAF", 4, 35007},
	{"UNCL", 4, 35008},
	{"NINP", 4, 35009},
	{"COMMITMENTS", 11, 35010},
	{"SUGGESTING", 10, 35011},
	{"THREAD", 6, 35012},
	{"SAPPHIRE", 8, 35013},
	{"KINASE", 6, 35014},
	{"ENTV", 4, 35015},
	{"SUSTAINABLE", 11, 35016},
	{"INHERENT", 8, 35017},
	{"SKIRTS", 6, 35018},
	{"TOBL", 4, 35019},
	{"RDSF", 4, 35020},
	{"TRIUMPH", 7, 35021},
	{"EDKI", 4, 35022},
	{"MATS", 4, 35023},
	{"ZZG", 3, 35024},
	{"STSF", 4, 35025},
	{"TRANSPORT", 9, 35026},
	{"REMAINDER", 9, 35027},
	{"GRANDPARENT", 11, 35028},
	{"CRAWFORD", 8, 35029},
	{"LABELED", 7, 35030},
	{"QBJ", 3, 35031},
	{"PRIVILEGES", 10, 35032},
	{"DSLA", 4, 35033},
	{"LANDMARK", 8, 35034},
	{"PATRON", 6, 35035},
	{"HAPPILY", 7, 35036},
	{"TELEVISIONS", 11, 35037},
	{"SPECIALIZING", 12, 35038},
	{"MARKING", 7, 35039},
	{"HEMF", 4, 35040},
	{"NGAH", 4, 35041},
	{"PZO", 3, 35042},
	{"NREV", 4, 35043},
	{"ESIZ", 4, 35044},
	{"IFEL", 4, 35045},
	{"COMMODITIES", 11, 35046},
	{"PVC", 3, 35047},
	{"ERYG", 4, 35048},
	{"FSHO", 4, 35049},
	{"COTTAGE", 7, 35050},
	{"SERBIA", 6, 35051},
	{"SHERIFF", 7, 35052},
	{"GRIFFIN", 7, 35053},
	{"DECLINED", 8, 35054},
	{"PLEL", 4, 35055},
	{"GUYANA", 6, 35056},
	{"SPIES", 5, 35057},
	{"BULK", 4, 35058},
	{"FAVORABLE", 9, 35059},
	{"BLAH", 4, 35060},
	{"MIME", 4, 35061},
	{"SSRO", 4, 35062},
	{"OZC", 3, 35063},
	{"AMBL", 4, 35064},
	{"EMOTIONALLY", 11, 35065},
	{"SUITE", 5, 35066},
	{"RSUC", 4, 35067},
	{"OFYE", 4, 35068},
	{"IKEC", 4, 35069},
	{"UNDM", 4, 35070},
	{"SSWH", 4, 35071},
	{"MOTORCYCLES", 11, 35072},
	{"CONSCIENCE", 10, 35073},
	{"WNST", 4, 35074},
	{"DSOC", 4, 35075},
	{"STBO", 4, 35076},
	{"ONOP", 4, 35077},
	{"SELECTED", 8, 35078},
	{"INDR", 4, 35079},
	{"TESM", 4, 35080},
	{"HIGHWAYS", 8, 35081},
	{"THINKPAD", 8, 35082},
	{"YMBO", 4, 35083},
	{"RBEF", 4, 35084},
	{"RALW", 4, 35085},
	{"FRACTION", 8, 35086},
	{"LFAS", 4, 35087},
	{"REPRODUCTIVE", 12, 35088},
	{"PLAINTIFF", 9, 35089},
	{"HISJ", 4, 35090},
	{"PRESTON", 7, 35091},
	{"GHEA", 4, 35092},
	{"NXF", 3, 35093},
	{"NBEG", 4, 35094},
	{"WIDOW", 5, 35095},
	{"OADT", 4, 35096},
	{"TLIV", 4, 35097},
	{"FRAGMENT", 8, 35098},
	{"CUNT", 4, 35099},
	{"OWEA", 4, 35100},
	{"URPA", 4, 35101},
	{"FEOF", 4, 35102},
	{"IMPULSE", 7, 35103},
	{"SUMMARY", 7, 35104},
	{"INDH", 4, 35105},
	{"BUNNY", 5, 35106},
	{"CHEVY", 5, 35107},
	{"ISHF", 4, 35108},
	{"MOLECULES", 9, 35109},
	{"ROUNDS", 6, 35110},
	{"TEFR", 4, 35111},
	{"NSLE", 4, 35112},
	{"ORDR", 4, 35113},
	{"LONGEST", 7, 35114},
	{"EADB", 4, 35115},
	{"ASFR", 4, 35116},
	{"STRAW", 5, 35117},
	{"TIONS", 5, 35118},
	{"INTERVALS", 9, 35119},
	{"YOFI", 4, 35120},
	{"ADWI", 4, 35121},
	{"ENME", 4, 35122},
	{"RRAC", 4, 35123},
	{"RTYS", 4, 35124},
	{"SENTENCES", 9, 35125},
	{"SFEL", 4, 35126},
	{"YSEC", 4, 35127},
	{"DENTISTS", 8, 35128},
	{"USDA", 4, 35129},
	{"EXCLUSION", 9, 35130},
	{"INIR", 4, 35131},
	{"YDRO", 4, 35132},
	{"SUITABLE", 8, 35133},
	{"WORKSTATION", 11, 35134},
	{"HOLOCAUST", 9, 35135},
	{"KEEN", 4, 35136},
	{"FLYER", 5, 35137},
	{"PEAS", 4, 35138},
	{"DOSAGE", 6, 35139},
	{"RECEIVERS", 9, 35140},
	{"URLS", 4, 35141},
	{"CUSTOMISE", 9, 35142},
	{"RMET", 4, 35143},
	{"DISPOSITION", 11, 35144},
	{"BBER", 4, 35145},
	{"YEJ", 3, 35146},
	{"PROJECTION", 10, 35147},
	{"CLAY", 4, 35148},
	{"SPIT", 4, 35149},
	{"EDYO", 4, 35150},
	{"ADRO", 4, 35151},
	{"RHAR", 4, 35152},
	{"ICCH", 4, 35153},
	{"ICKN", 4, 35154},
	{"XKM", 3, 35155},
	{"VARIANCE", 8, 35156},
	{"TALR", 4, 35157},
	{"LSEN", 4, 35158},
	{"LBUS", 4, 35159},
	{"NAVIGATOR", 9, 35160},
	{"INVESTIGATORS", 13, 35161},
	{"NDVE", 4, 35162},
	{"CAMEROON", 8, 35163},
	{"FRAI", 4, 35164},
	{"BAKING", 6, 35165},
	{"MARIJUANA", 9, 35166},
	{"ADAPTIVE", 8, 35167},
	{"COMPUTED", 8, 35168},
	{"IPLI", 4, 35169},
	{"BATHS", 5, 35170},
	{"DRILL", 5, 35171},
	{"PREMIUM", 7, 35172},
	{"CATHEDRAL", 9, 35173},
	{"BRAKES", 6, 35174},
	{"POLICEMAN", 9, 35175},
	{"LTIC", 4, 35176},
	{"ISFE", 4, 35177},
	{"OBJECTION", 9, 35178},
	{"NIRVANA", 7, 35179},
	{"FAIRFIELD", 9, 35180},
	{"OWNS", 4, 35181},
	{"WHOB", 4, 35182},
	{"MANM", 4, 35183},
	{"ICOR", 4, 35184},
	{"WNSA", 4, 35185},
	{"NTLA", 4, 35186},
	{"EEXE", 4, 35187},
	{"NBRA", 4, 35188},
	{"INVISION", 8, 35189},
	{"STICKY", 6, 35190},
	{"DESTINY", 7, 35191},
	{"MADNESS", 7, 35192},
	{"EMACS", 5, 35193},
	{"ROUTINELY", 9, 35194},
	{"FANTASTIC", 9, 35195},
	{"TILL", 4, 35196},
	{"BLOWING", 7, 35197},
	{"LANDSCAPES", 10, 35198},
	{"ACEL", 4, 35199},
	{"HEATED", 6, 35200},
	{"YHES", 4, 35201},
	{"NCLO", 4, 35202},
	{"LAFAYETTE", 9, 35203},
	{"JACKIE", 6, 35204},
	{"FWAS", 4, 35205},
	{"COMPUTATION", 11, 35206},
	{"OKIL", 4, 35207},
	{"LFOU", 4, 35208},
	{"TCIT", 4, 35209},
	{"RPAT", 4, 35210},
	{"CARDIOVASCULAR", 14, 35211},
	{"ITEB", 4, 35212},
	{"PISTOL", 6, 35213},
	{"OBAT", 4, 35214},
	{"RKNO", 4, 35215},
	{"CKIS", 4, 35216},
	{"SPARC", 5, 35217},
	{"OMST", 4, 35218},
	{"ATUN", 4, 35219},
	{"CARDIAC", 7, 35220},
	{"SALVATION", 9, 35221},
	{"CALENDAR", 8, 35222},
	{"DOVER", 5, 35223},
	{"ADRIAN", 6, 35224},
	{"HEADACHE", 8, 35225},
	{"ENNY", 4, 35226},
	{"PREDICTIONS", 11, 35227},
	{"WSIN", 4, 35228},
	{"ACCOMPANYING", 12, 35229},
	{"AILT", 4, 35230},
	{"VATICAN", 7, 35231},
	{"LREL", 4, 35232},
	{"LYKN", 4, 35233},
	{"LEARNERS", 8, 35234},
	{"SELECTIVE", 9, 35235},
	{"ARBITRATION", 11, 35236},
	{"TBOO", 4, 35237},
	{"CONFIGURING", 11, 35238},
	{"TOKEN", 5, 35239},
	{"EDITORIALS", 10, 35240},
	{"ZINC", 4, 35241},
	{"LSOE", 4, 35242},
	{"TYON", 4, 35243},
	{"EAKA", 4, 35244},
	{"SEEKERS", 7, 35245},
	{"DANCING", 7, 35246},
	{"NOCO", 4, 35247},
	{"GURU", 4, 35248},
	{"EORE", 4, 35249},
	{"ENBO", 4, 35250},
	{"BLAST", 5, 35251},
	{"ARYH", 4, 35252},
	{"REMOVABLE", 9, 35253},
	{"CONVERGENCE", 11, 35254},
	{"RYHE", 4, 35255},
	{"YIELDS", 6, 35256},
	{"GIBRALTAR", 9, 35257},
	{"LEVY", 4, 35258},
	{"SUITED", 6, 35259},
	{"NUMERIC", 7, 35260},
	{"YSPO", 4, 35261},
	{"SRAI", 4, 35262},
	{"UWIL", 4, 35263},
	{"ANTHROPOLOGY", 12, 35264},
	{"SKATING", 7, 35265},
	{"KINDA", 5, 35266},
	{"DERD", 4, 35267},
	{"ABERDEEN", 8, 35268},
	{"EMPEROR", 7, 35269},
	{"DLIF", 4, 35270},
	{"GRAD", 4, 35271},
	{"MANSION", 7, 35272},
	{"BUCKET", 6, 35273},
	{"MALPRACTICE", 11, 35274},
	{"SBLO", 4, 35275},
	{"DYLAN", 5, 35276},
	{"BRAS", 4, 35277},
	{"VSY", 3, 35278},
	{"HREW", 4, 35279},
	{"NDAI", 4, 35280},
	{"RIDGE", 5, 35281},
	{"IEFO", 4, 35282},
	{"APHO", 4, 35283},
	{"BELTS", 5, 35284},
	{"ISGA", 4, 35285},
	{"UPDATE", 6, 35286},
	{"BLACKS", 6, 35287},
	{"NLOA", 4, 35288},
	{"ECIP", 4, 35289},
	{"TRANSIT", 7, 35290},
	{"EDUCATED", 8, 35291},
	{"REBATES", 7, 35292},
	{"DAYH", 4, 35293},
	{"REPORTERS", 9, 35294},
	{"OAVO", 4, 35295},
	{"AMSW", 4, 35296},
	{"BURKE", 5, 35297},
	{"OBRE", 4, 35298},
	{"NGJU", 4, 35299},
	{"LMEN", 4, 35300},
	{"PROUDLY", 7, 35301},
	{"BLESSING", 8, 35302},
	{"NEFR", 4, 35303},
	{"PIX", 3, 35304},
	{"LIFY", 4, 35305},
	{"RENDERING", 9, 35306},
	{"RADAR", 5, 35307},
	{"FWU", 3, 35308},
	{"BBED", 4, 35309},
	{"MIC", 3, 35310},
	{"INSERTED", 8, 35311},
	{"SAWH", 4, 35312},
	{"YONL", 4, 35313},
	{"GRADUATION", 10, 35314},
	{"EJUN", 4, 35315},
	{"PULLING", 7, 35316},
	{"RBRI", 4, 35317},
	{"BASENAME", 8, 35318},
	{"KYLE", 4, 35319},
	{"OBESITY", 7, 35320},
	{"HERJ", 4, 35321},
	{"CURVES", 6, 35322},
	{"FATIGUE", 7, 35323},
	{"TOURING", 7, 35324},
	{"NBUS", 4, 35325},
	{"EISF", 4, 35326},
	{"PRIVATELY", 9, 35327},
	{"CLARA", 5, 35328},
	{"INVENTION", 9, 35329},
	{"VERTEX", 6, 35330},
	{"ONE-THIRD", 9, 35331},
	{"MARBLE", 6, 35332},
	{"HEPATITIS", 9, 35333},
	{"AUTHORIZE", 9, 35334},
	{"NATIONALLY", 10, 35335},
	{"ARROW", 5, 35336},
	{"KEAS", 4, 35337},
	{"ANDORRA", 7, 35338},
	{"PREVAIL", 7, 35339},
	{"DENIAL", 6, 35340},
	{"OPOR", 4, 35341},
	{"WATERPROOF", 10, 35342},
	{"GESC", 4, 35343},
	{"ILYM", 4, 35344},
	{"VERU", 4, 35345},
	{"EXPIRED", 7, 35346},
	{"EXHAUST", 7, 35347},
	{"RYCL", 4, 35348},
	{"RITW", 4, 35349},
	{"TRAVELS", 7, 35350},
	{"FLUSH", 5, 35351},
	{"WAIVER", 6, 35352},
	{"RIOT", 4, 35353},
	{"ZGI", 3, 35354},
	{"SPECIALTIES", 11, 35355},
	{"UBSI", 4, 35356},
	{"OLD-FASHIONED", 13, 35357},
	{"TILE", 4, 35358},
	{"HAYES", 5, 35359},
	{"HUMANITARIAN", 12, 35360},
	{"GGAM", 4, 35361},
	{"INVITATIONS", 11, 35362},
	{"ONTL", 4, 35363},
	{"FUNCTIONING", 11, 35364},
	{"MYAN", 4, 35365},
	{"GARCIA", 6, 35366},
	{"CROWDED", 7, 35367},
	{"CINGULAR", 8, 35368},
	{"TGAG", 4, 35369},
	{"ECONOMIES", 9, 35370},
	{"REEH", 4, 35371},
	{"SDEL", 4, 35372},
	{"ZTU", 3, 35373},
	{"ALEXANDRIA", 10, 35374},
	{"BACTERIAL", 9, 35375},
	{"MOSES", 5, 35376},
	{"DBRE", 4, 35377},
	{"COUNTED", 7, 35378},
	{"LPTH", 4, 35379},
	{"BRUTAL", 6, 35380},
	{"YMUC", 4, 35381},
	{"ATYE", 4, 35382},
	{"CHEMISTRY", 9, 35383},
	{"RBIT", 4, 35384},
	{"EDEE", 4, 35385},
	{"RUBBER", 6, 35386},
	{"CONTINUOUSLY", 12, 35387},
	{"JOHNS", 5, 35388},
	{"YWIN", 4, 35389},
	{"RORA", 4, 35390},
	{"CYOF", 4, 35391},
	{"VALVES", 6, 35392},
	{"WHOF", 4, 35393},
	{"IQUI", 4, 35394},
	{"GAPS", 4, 35395},
	{"BALLOON", 7, 35396},
	{"IMPAIRED", 8, 35397},
	{"ACHIEVEMENTS", 12, 35398},
	{"DONORS", 6, 35399},
	{"OTIM", 4, 35400},
	{"SOAK", 4, 35401},
	{"CUE", 3, 35402},
	{"FOG", 3, 35403},
	{"DIPLOMAT", 8, 35404},
	{"RROL", 4, 35405},
	{"YOUNGSTER", 9, 35406},
	{"JEWEL", 5, 35407},
	{"TAYI", 4, 35408},
	{"LSCA", 4, 35409},
	{"APOI", 4, 35410},
	{"EJJ", 3, 35411},
	{"RDRI", 4, 35412},
	{"TEDDY", 5, 35413},
	{"CTHA", 4, 35414},
	{"CONVERTIBLE", 11, 35415},
	{"TEACHES", 7, 35416},
	{"RSLE", 4, 35417},
	{"VENTURES", 8, 35418},
	{"DOCK", 4, 35419},
	{"NGBI", 4, 35420},
	{"EORS", 4, 35421},
	{"EMOF", 4, 35422},
	{"OLOU", 4, 35423},
	{"OODR", 4, 35424},
	{"BUFING", 6, 35425},
	{"UAJ", 3, 35426},
	{"DASK", 4, 35427},
	{"JULIAN", 6, 35428},
	{"DMIR", 4, 35429},
	{"PAM", 3, 35430},
	{"DRYER", 5, 35431},
	{"VELVET", 6, 35432},
	{"LEGR", 4, 35433},
	{"YSWI", 4, 35434},
	{"NRUN", 4, 35435},
	{"TRIBUNAL", 8, 35436},
	{"RULED", 5, 35437},
	{"ANTG", 4, 35438},
	{"OVERNIGHT", 9, 35439},
	{"ECONOMICALLY", 12, 35440},
	{"PENSIONS", 8, 35441},
	{"RSDO", 4, 35442},
	{"ODTO", 4, 35443},
	{"PRAYERS", 7, 35444},
	{"SFOO", 4, 35445},
	{"FUNKY", 5, 35446},
	{"ECEO", 4, 35447},
	{"EUPO", 4, 35448},
	{"FORBID", 6, 35449},
	{"SECRETARIAT", 11, 35450},
	{"XJA", 3, 35451},
	{"NUSU", 4, 35452},
	{"GLOBE", 5, 35453},
	{"LLMO", 4, 35454},
	{"DSIT", 4, 35455},
	{"URYT", 4, 35456},
	{"UNHAPPY", 7, 35457},
	{"PARAGRAPHS", 10, 35458},
	{"GALE", 4, 35459},
	{"JOINS", 5, 35460},
	{"RIBBON", 6, 35461},
	{"HAZARD", 6, 35462},
	{"NGAV", 4, 35463},
	{"AVEU", 4, 35464},
	{"NOMINATIONS", 11, 35465},
	{"WESLEY", 6, 35466},
	{"PTIM", 4, 35467},
	{"DIM", 3, 35468},
	{"CHARM", 5, 35469},
	{"BULB", 4, 35470},
	{"MARKER", 6, 35471},
	{"ACCURATELY", 10, 35472},
	{"ROFB", 4, 35473},
	{"ARYD", 4, 35474},
	{"CANCELLED", 9, 35475},
	{"IRONICALLY", 10, 35476},
	{"MARINE", 6, 35477},
	{"SENSOR", 6, 35478},
	{"OUNS", 4, 35479},
	{"ERQU", 4, 35480},
	{"YLON", 4, 35481},
	{"EEDU", 4, 35482},
	{"MATTRESS", 8, 35483},
	{"RCOR", 4, 35484},
	{"COORDINATE", 10, 35485},
	{"MPEGS", 5, 35486},
	{"EOPT", 4, 35487},
	{"NWED", 4, 35488},
	{"BRUNEI", 6, 35489},
	{"INTRODUCTORY", 12, 35490},
	{"RQB", 3, 35491},
	{"TIMBER", 6, 35492},
	{"EGUI", 4, 35493},
	{"SLOVAK", 6, 35494},
	{"DSPR", 4, 35495},
	{"SHORTS", 6, 35496},
	{"BOLT", 4, 35497},
	{"CAKES", 5, 35498},
	{"GWHA", 4, 35499},
	{"RRIG", 4, 35500},
	{"FYEA", 4, 35501},
	{"NIFO", 4, 35502},
	{"IFEE", 4, 35503},
	{"RESERVOIR", 9, 35504},
	{"SEDR", 4, 35505},
	{"LLAD", 4, 35506},
	{"EWSC", 4, 35507},
	{"OCCURRENCE", 10, 35508},
	{"IDOL", 4, 35509},
	{"ACKU", 4, 35510},
	{"MIXER", 5, 35511},
	{"VKO", 3, 35512},
	{"CTSW", 4, 35513},
	{"WORCESTER", 9, 35514},
	{"SBJCT", 5, 35515},
	{"ELLF", 4, 35516},
	{"ANTU", 4, 35517},
	{"CHARMING", 8, 35518},
	{"EIRG", 4, 35519},
	{"DEFENDER", 8, 35520},
	{"YGOT", 4, 35521},
	{"NXU", 3, 35522},
	{"SEVI", 4, 35523},
	{"NINJ", 4, 35524},
	{"DISCIPLINARY", 12, 35525},
	{"RETREAT", 7, 35526},
	{"SURVEILLANCE", 12, 35527},
	{"ANNOYING", 8, 35528},
	{"RESPECTED", 9, 35529},
	{"STAYS", 5, 35530},
	{"LLEL", 4, 35531},
	{"SLOT", 4, 35532},
	{"IMPORTANTLY", 11, 35533},
	{"DROVE", 5, 35534},
	{"WASHER", 6, 35535},
	{"UTIE", 4, 35536},
	{"TAGR", 4, 35537},
	{"SPRINGER", 8, 35538},
	{"CRUEL", 5, 35539},
	{"YCRE", 4, 35540},
	{"MINES", 5, 35541},
	{"MANAGING", 8, 35542},
	{"ILEY", 4, 35543},
	{"PORTRAITS", 9, 35544},
	{"IACO", 4, 35545},
	{"HABO", 4, 35546},
	{"FRAGILE", 7, 35547},
	{"HARVEST", 7, 35548},
	{"SWELL", 5, 35549},
	{"REBOUND", 7, 35550},
	{"IDFO", 4, 35551},
	{"LOGAN", 5, 35552},
	{"CEDW", 4, 35553},
	{"IMOR", 4, 35554},
	{"INTERPRETED", 11, 35555},
	{"EVALUATIONS", 11, 35556},
	{"LCUL", 4, 35557},
	{"RCHS", 4, 35558},
	{"FOUGHT", 6, 35559},
	{"UTAR", 4, 35560},
	{"VETR", 4, 35561},
	{"UESO", 4, 35562},
	{"ENDW", 4, 35563},
	{"CHWH", 4, 35564},
	{"BAGHDAD", 7, 35565},
	{"ELIMINATION", 11, 35566},
	{"METRES", 6, 35567},
	{"USEB", 4, 35568},
	{"BRONZE", 6, 35569},
	{"SCOO", 4, 35570},
	{"HYPOTHETICAL", 12, 35571},
	{"TRANSMIT", 8, 35572},
	{"SUNNY", 5, 35573},
	{"ELECTRONICS", 11, 35574},
	{"IMMIGRANTS", 10, 35575},
	{"COMPLIMENTARY", 13, 35576},
	{"TEPO", 4, 35577},
	{"YHOU", 4, 35578},
	{"WCY", 3, 35579},
	{"RJUS", 4, 35580},
	{"GSAI", 4, 35581},
	{"TRIM", 4, 35582},
	{"ZEDB", 4, 35583},
	{"SOFTEN", 6, 35584},
	{"RJOB", 4, 35585},
	{"IRSE", 4, 35586},
	{"NLYM", 4, 35587},
	{"LHAD", 4, 35588},
	{"SPINE", 5, 35589},
	{"KEHE", 4, 35590},
	{"ABU", 3, 35591},
	{"TITLED", 6, 35592},
	{"ESIL", 4, 35593},
	{"STEREOTYPE", 10, 35594},
	{"COMMISSIONS", 11, 35595},
	{"YDOE", 4, 35596},
	{"LDCU", 4, 35597},
	{"HPRE", 4, 35598},
	{"NOFO", 4, 35599},
	{"ONDP", 4, 35600},
	{"POWERSELLER", 11, 35601},
	{"SEMINAR", 7, 35602},
	{"NATIONWIDE", 10, 35603},
	{"MOSS", 4, 35604},
	{"ICHD", 4, 35605},
	{"RATIOS", 6, 35606},
	{"ONSY", 4, 35607},
	{"TUPT", 4, 35608},
	{"CONCORD", 7, 35609},
	{"GRADUATED", 9, 35610},
	{"OFJO", 4, 35611},
	{"LEBI", 4, 35612},
	{"LHEL", 4, 35613},
	{"ENDORSED", 8, 35614},
	{"BYPR", 4, 35615},
	{"EGAI", 4, 35616},
	{"SGUI", 4, 35617},
	{"TDOO", 4, 35618},
	{"SSLI", 4, 35619},
	{"DROWN", 5, 35620},
	{"WALNUT", 6, 35621},
	{"LANCE", 5, 35622},
	{"LCEN", 4, 35623},
	{"TERRIBLY", 8, 35624},
	{"ITALIA", 6, 35625},
	{"UNNECESSARY", 11, 35626},
	{"LIBERIA", 7, 35627},
	{"EVEI", 4, 35628},
	{"HOMEWORK", 8, 35629},
	{"NEXA", 4, 35630},
	{"SHERMAN", 7, 35631},
	{"CORK", 4, 35632},
	{"ERJU", 4, 35633},
	{"DSOR", 4, 35634},
	{"BYHE", 4, 35635},
	{"NLYD", 4, 35636},
	{"MAXIMIZE", 8, 35637},
	{"HANSEN", 6, 35638},
	{"SENATORS", 8, 35639},
	{"DISL", 4, 35640},
	{"FREELY", 6, 35641},
	{"STEADILY", 8, 35642},
	{"MALI", 4, 35643},
	{"YUGOSLAVIA", 10, 35644},
	{"CONTRIBUTOR", 11, 35645},
	{"EEDF", 4, 35646},
	{"BLEEDING", 8, 35647},
	{"TORB", 4, 35648},
	{"SELLER", 6, 35649},
	{"CHARACTERIZATION", 16, 35650},
	{"WAQ", 3, 35651},
	{"VENP", 4, 35652},
	{"COLON", 5, 35653},
	{"NEIGHBORING", 11, 35654},
	{"ANBR", 4, 35655},
	{"YSUR", 4, 35656},
	{"LAHO", 4, 35657},
	{"LIGHTING", 8, 35658},
	{"NTMI", 4, 35659},
	{"GWIL", 4, 35660},
	{"RCEA", 4, 35661},
	{"ELLC", 4, 35662},
	{"RMAK", 4, 35663},
	{"TUNN", 4, 35664},
	{"MPEN", 4, 35665},
	{"LANES", 5, 35666},
	{"TGOO", 4, 35667},
	{"FUNDAMENTALS", 12, 35668},
	{"CONTAMINATION", 13, 35669},
	{"SPY", 3, 35670},
	{"FOREIGNER", 9, 35671},
	{"AHOU", 4, 35672},
	{"ERJA", 4, 35673},
	{"MTV", 3, 35674},
	{"ENDANGERED", 10, 35675},
	{"ONGD", 4, 35676},
	{"CONFESSION", 10, 35677},
	{"MASTURBATION", 12, 35678},
	{"NBOR", 4, 35679},
	{"OPTIMIZE", 8, 35680},
	{"YERI", 4, 35681},
	{"GMON", 4, 35682},
	{"STATING", 7, 35683},
	{"DOME", 4, 35684},
	{"CAROLINE", 8, 35685},
	{"SPARK", 5, 35686},
	{"RWAT", 4, 35687},
	{"RDIE", 4, 35688},
	{"LEU", 3, 35689},
	{"ORYB", 4, 35690},
	{"EXPIRATION", 10, 35691},
	{"NAMESPACE", 9, 35692},
	{"ALIGN", 5, 35693},
	{"TSAF", 4, 35694},
	{"PERIPHERAL", 10, 35695},
	{"GLIK", 4, 35696},
	{"ENGAGING", 8, 35697},
	{"CREST", 5, 35698},
	{"LOYAL", 5, 35699},
	{"NVAS", 4, 35700},
	{"NESF", 4, 35701},
	{"SMIG", 4, 35702},
	{"OPPONENTS", 9, 35703},
	{"HWAR", 4, 35704},
	{"PREACH", 6, 35705},
	{"PROVOKE", 7, 35706},
	{"LAUNDRY", 7, 35707},
	{"NOMINATED", 9, 35708},
	{"CONFIDENTIALITY", 15, 35709},
	{"RSAY", 4, 35710},
	{"UANT", 4, 35711},
	{"OKFO", 4, 35712},
	{"ELECTORAL", 9, 35713},
	{"LLSF", 4, 35714},
	{"CHANGELOG", 9, 35715},
	{"WELDING", 7, 35716},
	{"YDEP", 4, 35717},
	{"MWIL", 4, 35718},
	{"BRAVE", 5, 35719},
	{"DENSE", 5, 35720},
	{"DEFERRED", 8, 35721},
	{"ALTERNATIVELY", 13, 35722},
	{"ALLOY", 5, 35723},
	{"AMSH", 4, 35724},
	{"OVEW", 4, 35725},
	{"HLIG", 4, 35726},
	{"CONDOS", 6, 35727},
	{"LCOH", 4, 35728},
	{"PLOTS", 5, 35729},
	{"FLYING", 6, 35730},
	{"POLISHED", 8, 35731},
	{"YANG", 4, 35732},
	{"DEVASTATING", 11, 35733},
	{"TFAC", 4, 35734},
	{"GREENSBORO", 10, 35735},
	{"IFER", 4, 35736},
	{"TULSA", 5, 35737},
	{"RSSO", 4, 35738},
	{"LOCKING", 7, 35739},
	{"CASEY", 5, 35740},
	{"ORSF", 4, 35741},
	{"DEVIL", 5, 35742},
	{"REAV", 4, 35743},
	{"DRAWS", 5, 35744},
	{"NNOW", 4, 35745},
	{"FRIDGE", 6, 35746},
	{"TYMA", 4, 35747},
	{"TECHNICIAN", 10, 35748},
	{"NEYW", 4, 35749},
	{"BLOOM", 5, 35750},
	{"FEAS", 4, 35751},
	{"SKILLED", 7, 35752},
	{"GUET", 4, 35753},
	{"ERTU", 4, 35754},
	{"ALMU", 4, 35755},
	{"ACLO", 4, 35756},
	{"YKJ", 3, 35757},
	{"RETW", 4, 35758},
	{"SIMPSONS", 8, 35759},
	{"LLAH", 4, 35760},
	{"LOU", 3, 35761},
	{"HONESTLY", 8, 35762},
	{"EBUD", 4, 35763},
	{"REGAIN", 6, 35764},
	{"RKSO", 4, 35765},
	{"UALP", 4, 35766},
	{"ELLIOTT", 7, 35767},
	{"RECOVERED", 9, 35768},
	{"MANUAL", 6, 35769},
	{"FRASER", 6, 35770},
	{"UPGRADING", 9, 35771},
	{"TILH", 4, 35772},
	{"LERW", 4, 35773},
	{"DFUL", 4, 35774},
	{"BLADES", 6, 35775},
	{"DELIGHT", 7, 35776},
	{"EYSE", 4, 35777},
	{"ULTH", 4, 35778},
	{"TLEC", 4, 35779},
	{"DLIV", 4, 35780},
	{"CKCO", 4, 35781},
	{"UPST", 4, 35782},
	{"ALEO", 4, 35783},
	{"LMUS", 4, 35784},
	{"PGP", 3, 35785},
	{"DEPART", 6, 35786},
	{"SEVERELY", 8, 35787},
	{"UQI", 3, 35788},
	{"CHLI", 4, 35789},
	{"LOOPS", 5, 35790},
	{"YMH", 3, 35791},
	{"BUTTERFLY", 9, 35792},
	{"YANT", 4, 35793},
	{"FPOL", 4, 35794},
	{"TIWA", 4, 35795},
	{"SURGE", 5, 35796},
	{"VACUUM", 6, 35797},
	{"FRONTPAGE", 9, 35798},
	{"NBAN", 4, 35799},
	{"CONTEMPLATE", 11, 35800},
	{"HWOU", 4, 35801},
	{"LGAR", 4, 35802},
	{"TAHOE", 5, 35803},
	{"LLTR", 4, 35804},
	{"MIDDLE-CLASS", 12, 35805},
	{"ADVERT", 6, 35806},
	{"DEMANDING", 9, 35807},
	{"GASI", 4, 35808},
	{"NEYO", 4, 35809},
	{"OSPH", 4, 35810},
	{"MEANTIME", 8, 35811},
	{"DNTS", 4, 35812},
	{"VEPE", 4, 35813},
	{"WAREHOUSE", 9, 35814},
	{"FLASHERS", 8, 35815},
	{"SUBARU", 6, 35816},
	{"IKEB", 4, 35817},
	{"FORBIDDEN", 9, 35818},
	{"OSCH", 4, 35819},
	{"VANILLA", 7, 35820},
	{"PROGRAMMERS", 11, 35821},
	{"BIOGRAPHY", 9, 35822},
	{"WEAVE", 5, 35823},
	{"HEOC", 4, 35824},
	{"MONITORED", 9, 35825},
	{"ILYW", 4, 35826},
	{"SPECULATE", 9, 35827},
	{"OORA", 4, 35828},
	{"FFIL", 4, 35829},
	{"URKE", 4, 35830},
	{"ORGANIZED", 9, 35831},
	{"INSTALLATIONS", 13, 35832},
	{"DEUTSCHLAND", 11, 35833},
	{"PICNIC", 6, 35834},
	{"SOULS", 5, 35835},
	{"EPIDEMIC", 8, 35836},
	{"ARRIVALS", 8, 35837},
	{"SPANK", 5, 35838},
	{"TFIL", 4, 35839},
	{"SELDOM", 6, 35840},
	{"YRW", 3, 35841},
	{"VEIS", 4, 35842},
	{"IONV", 4, 35843},
	{"GAPO", 4, 35844},
	{"YLOS", 4, 35845},
	{"TFOO", 4, 35846},
	{"CHHI", 4, 35847},
	{"TASW", 4, 35848},
	{"ORDW", 4, 35849},
	{"VTW", 3, 35850},
	{"MOTIVATED", 9, 35851},
	{"SMITHSONIAN", 11, 35852},
	{"TGOT", 4, 35853},
	{"HOLLOW", 6, 35854},
	{"EHIL", 4, 35855},
	{"VAULT", 5, 35856},
	{"SECURELY", 8, 35857},
	{"EXAMINING", 9, 35858},
	{"FIORICET", 8, 35859},
	{"GROOVE", 6, 35860},
	{"GACO", 4, 35861},
	{"OWND", 4, 35862},
	{"PLEA", 4, 35863},
	{"NOFL", 4, 35864},
	{"BYSE", 4, 35865},
	{"GERC", 4, 35866},
	{"TBUS", 4, 35867},
	{"YINH", 4, 35868},
	{"DBYI", 4, 35869},
	{"TSFA", 4, 35870},
	{"RVEN", 4, 35871},
	{"ITYE", 4, 35872},
	{"DELEGATION", 10, 35873},
	{"NDSB", 4, 35874},
	{"WIRES", 5, 35875},
	{"COMPELLING", 10, 35876},
	{"DICTIONARIES", 12, 35877},
	{"FSHE", 4, 35878},
	{"AZIL", 4, 35879},
	{"NDPH", 4, 35880},
	{"CUPI", 4, 35881},
	{"XTQ", 3, 35882},
	{"MAILS", 5, 35883},
	{"BACKING", 7, 35884},
	{"VEAB", 4, 35885},
	{"GREENHOUSE", 10, 35886},
	{"SLEEPS", 6, 35887},
	{"TROUBLED", 8, 35888},
	{"CARGO", 5, 35889},
	{"WOWE", 4, 35890},
	{"OTHC", 4, 35891},
	{"DISTURBING", 10, 35892},
	{"NAVAL", 5, 35893},
	{"ELSH", 4, 35894},
	{"URHO", 4, 35895},
	{"BLAKE", 5, 35896},
	{"TRANSPARENCY", 12, 35897},
	{"TRAVIS", 6, 35898},
	{"LYPU", 4, 35899},
	{"OTWI", 4, 35900},
	{"APEA", 4, 35901},
	{"ACCUSATION", 10, 35902},
	{"DLEF", 4, 35903},
	{"RJOH", 4, 35904},
	{"NDGU", 4, 35905},
	{"FIGURED", 7, 35906},
	{"TOAG", 4, 35907},
	{"HWHO", 4, 35908},
	{"TLON", 4, 35909},
	{"CURRENCIES", 10, 35910},
	{"NIGER", 5, 35911},
	{"DDIR", 4, 35912},
	{"OFFU", 4, 35913},
	{"DBYL", 4, 35914},
	{"OROL", 4, 35915},
	{"BACON", 5, 35916},
	{"YHOW", 4, 35917},
	{"LELO", 4, 35918},
	{"SURVIVORS", 9, 35919},
	{"POSITIONING", 11, 35920},
	{"HEATER", 6, 35921},
	{"LTQ", 3, 35922},
	{"OVERWHELM", 9, 35923},
	{"ARKW", 4, 35924},
	{"DWRI", 4, 35925},
	{"APAT", 4, 35926},
	{"UTLA", 4, 35927},
	{"YDUR", 4, 35928},
	{"CANNON", 6, 35929},
	{"CIRCUS", 6, 35930},
	{"ITPR", 4, 35931},
	{"PROMOTED", 8, 35932},
	{"SBRA", 4, 35933},
	{"UARA", 4, 35934},
	{"FORBES", 6, 35935},
	{"IXIN", 4, 35936},
	{"DDRA", 4, 35937},
	{"CONVENIENCE", 11, 35938},
	{"APOLOGY", 7, 35939},
	{"ATFA", 4, 35940},
	{"MOLDOVA", 7, 35941},
	{"MEL", 3, 35942},
	{"NAFR", 4, 35943},
	{"DESCENDING", 10, 35944},
	{"PAXIL", 5, 35945},
	{"KSHE", 4, 35946},
	{"RYGO", 4, 35947},
	{"UXN", 3, 35948},
	{"DSIM", 4, 35949},
	{"DEDC", 4, 35950},
	{"EFIV", 4, 35951},
	{"TROUT", 5, 35952},
	{"ENCLOSED", 8, 35953},
	{"FEAT", 4, 35954},
	{"NTSC", 4, 35955},
	{"COOKED", 6, 35956},
	{"THRILLER", 8, 35957},
	{"UCKI", 4, 35958},
	{"APNIC", 5, 35959},
	{"FATTY", 5, 35960},
	{"GERALD", 6, 35961},
	{"ANOB", 4, 35962},
	{"PRESSED", 7, 35963},
	{"RLYC", 4, 35964},
	{"FREQUENCIES", 11, 35965},
	{"TYSH", 4, 35966},
	{"ICHF", 4, 35967},
	{"EISU", 4, 35968},
	{"OSUC", 4, 35969},
	{"ALAU", 4, 35970},
	{"DENL", 4, 35971},
	{"SCANNED", 7, 35972},
	{"KETC", 4, 35973},
	{"LAYW", 4, 35974},
	{"REFLECTIONS", 11, 35975},
	{"ERGU", 4, 35976},
	{"RTHQ", 4, 35977},
	{"DMOT", 4, 35978},
	{"EFIF", 4, 35979},
	{"MARIAH", 6, 35980},
	{"NFIE", 4, 35981},
	{"EGUA", 4, 35982},
	{"DYHA", 4, 35983},
	{"NFAM", 4, 35984},
	{"MUNICIPALITY", 12, 35985},
	{"USPS", 4, 35986},
	{"TFRI", 4, 35987},
	{"JOYCE", 5, 35988},
	{"TMET", 4, 35989},
	{"ILME", 4, 35990},
	{"YDEV", 4, 35991},
	{"ICFO", 4, 35992},
	{"CEMENT", 6, 35993},
	{"HGY", 3, 35994},
	{"EXPERIENCING", 12, 35995},
	{"APHE", 4, 35996},
	{"TEBU", 4, 35997},
	{"OWBE", 4, 35998},
	{"ZRU", 3, 35999},
	{"YGW", 3, 36000},
	{"IARE", 4, 36001},
	{"FIREPLACE", 9, 36002},
	{"DDER", 4, 36003},
	{"SCRU", 4, 36004},
	{"CHDE", 4, 36005},
	{"ODID", 4, 36006},
	{"IDEH", 4, 36007},
	{"PLANNERS", 8, 36008},
	{"DISPUTES", 8, 36009},
	{"TEXTILES", 8, 36010},
	{"DLAR", 4, 36011},
	{"IDWE", 4, 36012},
	{"IDAL", 4, 36013},
	{"SOMETIME", 8, 36014},
	{"HWHE", 4, 36015},
	{"CTCO", 4, 36016},
	{"RRUN", 4, 36017},
	{"ALPU", 4, 36018},
	{"SFAL", 4, 36019},
	{"IMSO", 4, 36020},
	{"YGG", 3, 36021},
	{"INTRANET", 8, 36022},
	{"DICTATE", 7, 36023},
	{"RBRE", 4, 36024},
	{"RAWH", 4, 36025},
	{"CLOSES", 6, 36026},
	{"ZARD", 4, 36027},
	{"DROO", 4, 36028},
	{"FRUSTRATE", 9, 36029},
	{"PSYCHIATRY", 10, 36030},
	{"KBUT", 4, 36031},
	{"ONGF", 4, 36032},
	{"OFED", 4, 36033},
	{"PERSISTENT", 10, 36034},
	{"DEBORAH", 7, 36035},
	{"CONF", 4, 36036},
	{"MARCO", 5, 36037},
	{"ASSISTS", 7, 36038},
	{"SUMMARIES", 9, 36039},
	{"RSMI", 4, 36040},
	{"GLOW", 4, 36041},
	{"NYTI", 4, 36042},
	{"GABRIEL", 7, 36043},
	{"YOFB", 4, 36044},
	{"IERE", 4, 36045},
	{"LOWO", 4, 36046},
	{"RTIL", 4, 36047},
	{"AUDITOR", 7, 36048},
	{"WMA", 3, 36049},
	{"AQUARIUM", 8, 36050},
	{"VIOLIN", 6, 36051},
	{"PROPHET", 7, 36052},
	{"OTTL", 4, 36053},
	{"ERNT", 4, 36054},
	{"EEDW", 4, 36055},
	{"CIR", 3, 36056},
	{"FSAN", 4, 36057},
	{"RHES", 4, 36058},
	{"ACCELERATE", 10, 36059},
	{"DACR", 4, 36060},
	{"BRACKET", 7, 36061},
	{"LOOKSMART", 9, 36062},
	{"ISAAC", 5, 36063},
	{"OXIDE", 5, 36064},
	{"BORING", 6, 36065},
	{"DFAM", 4, 36066},
	{"LLLO", 4, 36067},
	{"OAKS", 4, 36068},
	{"LYCR", 4, 36069},
	{"YSIM", 4, 36070},
	{"VEDS", 4, 36071},
	{"SBIL", 4, 36072},
	{"RDSS", 4, 36073},
	{"MAGNIFICENT", 11, 36074},
	{"RLDT", 4, 36075},
	{"ERIK", 4, 36076},
	{"IAMO", 4, 36077},
	{"UNGS", 4, 36078},
	{"YELE", 4, 36079},
	{"YCHE", 4, 36080},
	{"NAPLES", 6, 36081},
	{"AYBU", 4, 36082},
	{"PROMPTLY", 8, 36083},
	{"MODEMS", 6, 36084},
	{"TOTU", 4, 36085},
	{"NGSM", 4, 36086},
	{"ADAPTATION", 10, 36087},
	{"HARMFUL", 7, 36088},
	{"UROW", 4, 36089},
	{"LOSU", 4, 36090},
	{"ETWH", 4, 36091},
	{"PAINTBALL", 9, 36092},
	{"PROZAC", 6, 36093},
	{"DDEM", 4, 36094},
	{"ENCLOSURE", 9, 36095},
	{"NGIV", 4, 36096},
	{"ACM", 3, 36097},
	{"DATL", 4, 36098},
	{"UTRI", 4, 36099},
	{"BYDE", 4, 36100},
	{"DIVIDEND", 8, 36101},
	{"GSID", 4, 36102},
	{"NEWARK", 6, 36103},
	{"KEOU", 4, 36104},
	{"PASO", 4, 36105},
	{"GLUCOSE", 7, 36106},
	{"PHANTOM", 7, 36107},
	{"PLAYBACK", 8, 36108},
	{"SUPERVISORS", 11, 36109},
	{"WESTMINSTER", 11, 36110},
	{"NCUR", 4, 36111},
	{"TURTLE", 6, 36112},
	{"IQB", 3, 36113},
	{"OMPT", 4, 36114},
	{"DISTANCES", 9, 36115},
	{"LFIL", 4, 36116},
	{"NGOO", 4, 36117},
	{"ABSORPTION", 10, 36118},
	{"TREASURES", 9, 36119},
	{"OEND", 4, 36120},
	{"DSC", 3, 36121},
	{"WARNED", 6, 36122},
	{"NEURAL", 6, 36123},
	{"WARE", 4, 36124},
	{"FOSSIL", 6, 36125},
	{"RESB", 4, 36126},
	{"HOMETOWN", 8, 36127},
	{"RSTL", 4, 36128},
	{"RTYL", 4, 36129},
	{"RTLE", 4, 36130},
	{"OTEX", 4, 36131},
	{"TRANSCRIPTS", 11, 36132},
	{"USEP", 4, 36133},
	{"LFAC", 4, 36134},
	{"APOLLO", 6, 36135},
	{"TBEH", 4, 36136},
	{"YSLA", 4, 36137},
	{"ILHE", 4, 36138},
	{"ONYM", 4, 36139},
	{"NDTU", 4, 36140},
	{"LBAC", 4, 36141},
	{"SDOM", 4, 36142},
	{"LBEF", 4, 36143},
	{"NEPR", 4, 36144},
	{"HESF", 4, 36145},
	{"CONTINUALLY", 11, 36146},
	{"COMMUNIST", 9, 36147},
	{"DBUR", 4, 36148},
	{"COLLECTIBLE", 11, 36149},
	{"FLIF", 4, 36150},
	{"HANDMADE", 8, 36151},
	{"ARHA", 4, 36152},
	{"AMWI", 4, 36153},
	{"YTOU", 4, 36154},
	{"FOUG", 4, 36155},
	{"EFTO", 4, 36156},
	{"GREENE", 6, 36157},
	{"ENTREPRENEURS", 13, 36158},
	{"BEVE", 4, 36159},
	{"OBUT", 4, 36160},
	{"ROBOTS", 6, 36161},
	{"GRENADA", 7, 36162},
	{"EVIT", 4, 36163},
	{"TLEV", 4, 36164},
	{"CREATIONS", 9, 36165},
	{"ISYO", 4, 36166},
	{"JADE", 4, 36167},
	{"SCOOP", 5, 36168},
	{"ETCA", 4, 36169},
	{"FATAL", 5, 36170},
	{"ONDB", 4, 36171},
	{"ACQUISITIONS", 12, 36172},
	{"OOMI", 4, 36173},
	{"MSHE", 4, 36174},
	{"FOUL", 4, 36175},
	{"UTLI", 4, 36176},
	{"KENO", 4, 36177},
	{"ILOV", 4, 36178},
	{"GTK", 3, 36179},
	{"EARNING", 7, 36180},
	{"MAILMAN", 7, 36181},
	{"DQB", 3, 36182},
	{"SANYO", 5, 36183},
	{"NESTED", 6, 36184},
	{"SMOD", 4, 36185},
	{"BIODIVERSITY", 12, 36186},
	{"SSAD", 4, 36187},
	{"OFRU", 4, 36188},
	{"YPAS", 4, 36189},
	{"GOQ", 3, 36190},
	{"OUSN", 4, 36191},
	{"LLBO", 4, 36192},
	{"TLYP", 4, 36193},
	{"RSDI", 4, 36194},
	{"SOMALIA", 7, 36195},
	{"MOVERS", 6, 36196},
	{"WEDE", 4, 36197},
	{"WRIG", 4, 36198},
	{"NDVA", 4, 36199},
	{"DEWH", 4, 36200},
	{"TJOH", 4, 36201},
	{"ADNE", 4, 36202},
	{"PRESENTLY", 9, 36203},
	{"MTOS", 4, 36204},
	{"CARLO", 5, 36205},
	{"DLON", 4, 36206},
	{"WORKFLOW", 8, 36207},
	{"OROR", 4, 36208},
	{"AWOM", 4, 36209},
	{"NOVELTY", 7, 36210},
	{"BRYANT", 6, 36211},
	{"IBEL", 4, 36212},
	{"TILES", 5, 36213},
	{"YANY", 4, 36214},
	{"VOYUER", 6, 36215},
	{"TTOK", 4, 36216},
	{"LIBRARIAN", 9, 36217},
	{"SUBSIDIARIES", 12, 36218},
	{"OLOC", 4, 36219},
	{"ALSY", 4, 36220},
	{"EBEH", 4, 36221},
	{"UTSE", 4, 36222},
	{"ERNP", 4, 36223},
	{"EABA", 4, 36224},
	{"SWITCHED", 8, 36225},
	{"STOCKHOLM", 9, 36226},
	{"TAMIL", 5, 36227},
	{"OFDR", 4, 36228},
	{"YGIV", 4, 36229},
	{"CKSH", 4, 36230},
	{"GARMIN", 6, 36231},
	{"DBLA", 4, 36232},
	{"OUWO", 4, 36233},
	{"FUZZY", 5, 36234},
	{"INDONESIAN", 10, 36235},
	{"FFTO", 4, 36236},
	{"GRAMS", 5, 36237},
	{"YISN", 4, 36238},
	{"USEL", 4, 36239},
	{"RIPL", 4, 36240},
	{"NSFI", 4, 36241},
	{"RICHARDS", 8, 36242},
	{"MRNA", 4, 36243},
	{"BUDGETS", 7, 36244},
	{"EDYE", 4, 36245},
	{"DCIT", 4, 36246},
	{"LFTO", 4, 36247},
	{"TOOLKIT", 7, 36248},
	{"DJOH", 4, 36249},
	{"RELAXATION", 10, 36250},
	{"IVK", 3, 36251},
	{"CARMEN", 6, 36252},
	{"SNEX", 4, 36253},
	{"THEREAFTER", 10, 36254},
	{"HARDWOOD", 8, 36255},
	{"EROTICA", 7, 36256},
	{"TEMPORAL", 8, 36257},
	{"LLCH", 4, 36258},
	{"OLKS", 4, 36259},
	{"FORGE", 5, 36260},
	{"COMMISSIONERS", 13, 36261},
	{"ICDI", 4, 36262},
	{"ISIB", 4, 36263},
	{"CEMO", 4, 36264},
	{"SISP", 4, 36265},
	{"ODOI", 4, 36266},
	{"DKNO", 4, 36267},
	{"STGE", 4, 36268},
	{"FORWARDING", 10, 36269},
	{"PTST", 4, 36270},
	{"LUNC", 4, 36271},
	{"REDUCTIONS", 10, 36272},
	{"SOUTHAMPTON", 11, 36273},
	{"DISG", 4, 36274},
	{"GSWI", 4, 36275},
	{"ISTANBUL", 8, 36276},
	{"SHEG", 4, 36277},
	{"FEWY", 4, 36278},
	{"UABL", 4, 36279},
	{"IFEW", 4, 36280},
	{"LBOA", 4, 36281},
	{"URPL", 4, 36282},
	{"UGHB", 4, 36283},
	{"ONCI", 4, 36284},
	{"ORGANISMS", 9, 36285},
	{"SEGA", 4, 36286},
	{"LLDI", 4, 36287},
	{"VIEWERS", 7, 36288},
	{"YUF", 3, 36289},
	{"KRH", 3, 36290},
	{"ITHK", 4, 36291},
	{"ASBESTOS", 8, 36292},
	{"IDWA", 4, 36293},
	{"PORTSMOUTH", 10, 36294},
	{"CDNA", 4, 36295},
	{"MEYER", 5, 36296},
	{"ENTERS", 6, 36297},
	{"ATOW", 4, 36298},
	{"POD", 3, 36299},
	{"RCIN", 4, 36300},
	{"DAYC", 4, 36301},
	{"SAVAGE", 6, 36302},
	{"ADVANCEMENT", 11, 36303},
	{"DEMP", 4, 36304},
	{"DBRA", 4, 36305},
	{"WILLOW", 6, 36306},
	{"RESUMES", 7, 36307},
	{"GAGE", 4, 36308},
	{"ENCR", 4, 36309},
	{"ADEW", 4, 36310},
	{"THROWING", 8, 36311},
	{"EXISTED", 7, 36312},
	{"RCHW", 4, 36313},
	{"WHORE", 5, 36314},
	{"GENERATORS", 10, 36315},
	{"TNUM", 4, 36316},
	{"BARBIE", 6, 36317},
	{"LLFA", 4, 36318},
	{"MEAF", 4, 36319},
	{"FAVOUR", 6, 36320},
	{"MYFA", 4, 36321},
	{"FNOR", 4, 36322},
	{"OTEV", 4, 36323},
	{"SMTP", 4, 36324},
	{"PGRA", 4, 36325},
	{"GENERATES", 9, 36326},
	{"POTATOES", 8, 36327},
	{"THOROUGH", 8, 36328},
	{"REPLICATION", 11, 36329},
	{"WSON", 4, 36330},
	{"INEXPENSIVE", 11, 36331},
	{"CKSW", 4, 36332},
	{"KURT", 4, 36333},
	{"RSLO", 4, 36334},
	{"RECEPTORS", 9, 36335},
	{"EJOH", 4, 36336},
	{"PEERS", 5, 36337},
	{"ROLAND", 6, 36338},
	{"OPTIMUM", 7, 36339},
	{"LDTA", 4, 36340},
	{"TFEA", 4, 36341},
	{"INTERVENTIONS", 13, 36342},
	{"QUILT", 5, 36343},
	{"HUNTINGTON", 10, 36344},
	{"OCLO", 4, 36345},
	{"MOUNTS", 6, 36346},
	{"FMOR", 4, 36347},
	{"SYRACUSE", 8, 36348},
	{"INTERNSHIP", 10, 36349},
	{"LONE", 4, 36350},
	{"WLIN", 4, 36351},
	{"REFRESH", 7, 36352},
	{"SRED", 4, 36353},
	{"VEAM", 4, 36354},
	{"ALUMINIUM", 9, 36355},
	{"SNOWBOARD", 9, 36356},
	{"NSLO", 4, 36357},
	{"WEBCAST", 7, 36358},
	{"FRUI", 4, 36359},
	{"MICHEL", 6, 36360},
	{"EVANESCENCE", 11, 36361},
	{"CKWH", 4, 36362},
	{"EMUR", 4, 36363},
	{"NGPI", 4, 36364},
	{"COORDINATED", 11, 36365},
	{"NOTRE", 5, 36366},
	{"SHIPMENTS", 9, 36367},
	{"MALDIVES", 8, 36368},
	{"STRIPES", 7, 36369},
	{"FIRMWARE", 8, 36370},
	{"MBLI", 4, 36371},
	{"ANTARCTICA", 10, 36372},
	{"DMAI", 4, 36373},
	{"ORPU", 4, 36374},
	{"NGPU", 4, 36375},
	{"SHEPHERD", 8, 36376},
	{"REBY", 4, 36377},
	{"UTHC", 4, 36378},
	{"CANBERRA", 8, 36379},
	{"CRADLE", 6, 36380},
	{"NFUL", 4, 36381},
	{"IORC", 4, 36382},
	{"ORFU", 4, 36383},
	{"CHANCELLOR", 10, 36384},
	{"MAMBO", 5, 36385},
	{"LIME", 4, 36386},
	{"SPLE", 4, 36387},
	{"KIRK", 4, 36388},
	{"NKYO", 4, 36389},
	{"SVIC", 4, 36390},
	{"RKHA", 4, 36391},
	{"DFOO", 4, 36392},
	{"RCUR", 4, 36393},
	{"MLIN", 4, 36394},
	{"LSOK", 4, 36395},
	{"ALEG", 4, 36396},
	{"LEGENDARY", 9, 36397},
	{"BOOL", 4, 36398},
	{"FSOU", 4, 36399},
	{"FGRE", 4, 36400},
	{"LMAK", 4, 36401},
	{"CHOIR", 5, 36402},
	{"AVOIDING", 8, 36403},
	{"ARPR", 4, 36404},
	{"BEAUTIFULLY", 11, 36405},
	{"NGJO", 4, 36406},
	{"EXPECTS", 7, 36407},
	{"JUMPING", 7, 36408},
	{"UCOU", 4, 36409},
	{"ITUP", 4, 36410},
	{"FABRICS", 7, 36411},
	{"ANTIBODIES", 10, 36412},
	{"POLYMER", 7, 36413},
	{"HYGIENE", 7, 36414},
	{"IRLA", 4, 36415},
	{"ODYW", 4, 36416},
	{"HWOR", 4, 36417},
	{"LLPO", 4, 36418},
	{"RSCR", 4, 36419},
	{"POULTRY", 7, 36420},
	{"DEPI", 4, 36421},
	{"DBUI", 4, 36422},
	{"EXAMINATIONS", 12, 36423},
	{"BORR", 4, 36424},
	{"SURGEONS", 8, 36425},
	{"NBYA", 4, 36426},
	{"BOUQUET", 7, 36427},
	{"NERB", 4, 36428},
	{"EEPL", 4, 36429},
	{"RLYD", 4, 36430},
	{"IMMUNOLOGY", 10, 36431},
	{"PROMOTES", 8, 36432},
	{"WILEY", 5, 36433},
	{"DEPARTMENTAL", 12, 36434},
	{"CORPUS", 6, 36435},
	{"RWEA", 4, 36436},
	{"JOHNSTON", 8, 36437},
	{"FACO", 4, 36438},
	{"TERMINOLOGY", 11, 36439},
	{"FIBRE", 5, 36440},
	{"REPRODUCE", 9, 36441},
	{"REEG", 4, 36442},
	{"CONVICTED", 9, 36443},
	{"SHADES", 6, 36444},
	{"IRRO", 4, 36445},
	{"INDICES", 7, 36446},
	{"ROOMMATES", 9, 36447},
	{"LDRA", 4, 36448},
	{"ADWARE", 6, 36449},
	{"ELLK", 4, 36450},
	{"DFRA", 4, 36451},
	{"VEEV", 4, 36452},
	{"AKEF", 4, 36453},
	{"DIBL", 4, 36454},
	{"CTFO", 4, 36455},
	{"THREATENING", 11, 36456},
	{"ZOLOFT", 6, 36457},
	{"LEYO", 4, 36458},
	{"ACTIVISTS", 9, 36459},
	{"FRANKFURT", 9, 36460},
	{"DFAC", 4, 36461},
	{"DAISY", 5, 36462},
	{"DDID", 4, 36463},
	{"OWFO", 4, 36464},
	{"TMEM", 4, 36465},
	{"HALIFAX", 7, 36466},
	{"RTHY", 4, 36467},
	{"ENCOURAGES", 10, 36468},
	{"TOQU", 4, 36469},
	{"GHTU", 4, 36470},
	{"ULTRAM", 6, 36471},
	{"RCHF", 4, 36472},
	{"CURSOR", 6, 36473},
	{"ASSEMBLED", 9, 36474},
	{"EARLIEST", 8, 36475},
	{"DONATED", 7, 36476},
	{"STUFFED", 7, 36477},
	{"SIXM", 4, 36478},
	{"RESTRUCTURING", 13, 36479},
	{"INSECTS", 7, 36480},
	{"TERMINALS", 9, 36481},
	{"CRUDE", 5, 36482},
	{"RTYI", 4, 36483},
	{"MORRISON", 8, 36484},
	{"MAIDEN", 6, 36485},
	{"SIMULATIONS", 11, 36486},
	{"KECO", 4, 36487},
	{"EAFR", 4, 36488},
	{"SUFFICIENTLY", 12, 36489},
	{"ADQU", 4, 36490},
	{"EXAMINES", 8, 36491},
	{"VIKING", 6, 36492},
	{"MYRTLE", 6, 36493},
	{"FALO", 4, 36494},
	{"BORED", 5, 36495},
	{"CLEANUP", 7, 36496},
	{"YARN", 4, 36497},
	{"DSRE", 4, 36498},
	{"RFY", 3, 36499},
	{"RBEL", 4, 36500},
	{"CONDITIONAL", 11, 36501},
	{"MUG", 3, 36502},
	{"ENBR", 4, 36503},
	{"CROSSWORD", 9, 36504},
	{"AYSM", 4, 36505},
	{"BUDAPEST", 8, 36506},
	{"NGEC", 4, 36507},
	{"CONCEPTUAL", 10, 36508},
	{"FPRI", 4, 36509},
	{"OWWI", 4, 36510},
	{"DQUI", 4, 36511},
	{"KNITTING", 8, 36512},
	{"LHOU", 4, 36513},
	{"ATTACKED", 8, 36514},
	{"SOFV", 4, 36515},
	{"TSCR", 4, 36516},
	{"MAYT", 4, 36517},
	{"ROUR", 4, 36518},
	{"BHUTAN", 6, 36519},
	{"LIECHTENSTEIN", 13, 36520},
	{"MATING", 6, 36521},
	{"COMPUTE", 7, 36522},
	{"REDHEAD", 7, 36523},
	{"APUB", 4, 36524},
	{"DONF", 4, 36525},
	{"ARRIVES", 7, 36526},
	{"TRANSLATOR", 10, 36527},
	{"AUTOMOBILES", 11, 36528},
	{"TRACTOR", 7, 36529},
	{"ALLAH", 5, 36530},
	{"KDOW", 4, 36531},
	{"EUPA", 4, 36532},
	{"LYOR", 4, 36533},
	{"UNWRAP", 6, 36534},
	{"FARES", 5, 36535},
	{"RSEM", 4, 36536},
	{"LESD", 4, 36537},
	{"LONGITUDE", 9, 36538},
	{"ALKT", 4, 36539},
	{"UCET", 4, 36540},
	{"GERP", 4, 36541},
	{"UKV", 3, 36542},
	{"YBES", 4, 36543},
	{"OOUR", 4, 36544},
	{"NDMY", 4, 36545},
	{"CHALLENGED", 10, 36546},
	{"TELECHARGER", 11, 36547},
	{"HOPED", 5, 36548},
	{"UGHP", 4, 36549},
	{"PIKE", 4, 36550},
	{"SAFER", 5, 36551},
	{"INSERTION", 9, 36552},
	{"ABLO", 4, 36553},
	{"RSFI", 4, 36554},
	{"DCUP", 4, 36555},
	{"INSTRUMENTATION", 15, 36556},
	{"DBLO", 4, 36557},
	{"HUGO", 4, 36558},
	{"ICKU", 4, 36559},
	{"WAGNER", 6, 36560},
	{"GROUNDWATER", 11, 36561},
	{"TOUCHED", 7, 36562},
	{"STRENGTHENING", 13, 36563},
	{"DSIX", 4, 36564},
	{"COLOGNE", 7, 36565},
	{"DBYO", 4, 36566},
	{"GZIP", 4, 36567},
	{"RANGER", 6, 36568},
	{"LGRA", 4, 36569},
	{"SMALLEST", 8, 36570},
	{"TEDK", 4, 36571},
	{"INSULATION", 10, 36572},
	{"NEWMAN", 6, 36573},
	{"MARSH", 5, 36574},
	{"PUTY", 4, 36575},
	{"RBAL", 4, 36576},
	{"RICKY", 5, 36577},
	{"CTRL", 4, 36578},
	{"LOWC", 4, 36579},
	{"LRIG", 4, 36580},
	{"INFRINGEMENT", 12, 36581},
	{"OULO", 4, 36582},
	{"OLDP", 4, 36583},
	{"UGY", 3, 36584},
	{"WEWO", 4, 36585},
	{"SUBJECTIVE", 10, 36586},
	{"MONSTERS", 8, 36587},
	{"DFIV", 4, 36588},
	{"ASYLUM", 6, 36589},
	{"RKEY", 4, 36590},
	{"LIGHTBOX", 8, 36591},
	{"ROBBIE", 6, 36592},
	{"GPOI", 4, 36593},
	{"RPOI", 4, 36594},
	{"COCKTAIL", 8, 36595},
	{"LTOW", 4, 36596},
	{"OUTLETS", 7, 36597},
	{"UNDC", 4, 36598},
	{"IZAB", 4, 36599},
	{"ANYG", 4, 36600},
	{"TREQ", 4, 36601},
	{"LDEC", 4, 36602},
	{"RYMO", 4, 36603},
	{"SWAZILAND", 9, 36604},
	{"ERSK", 4, 36605},
	{"VARIETIES", 9, 36606},
	{"ARBOR", 5, 36607},
	{"MEDIAWIKI", 9, 36608},
	{"RVEA", 4, 36609},
	{"CONFIGURATIONS", 14, 36610},
	{"POISON", 6, 36611},
	{"ETHNICITY", 9, 36612},
	{"DOMINATED", 9, 36613},
	{"NLEY", 4, 36614},
	{"IRDO", 4, 36615},
	{"OBEB", 4, 36616},
	{"RBEA", 4, 36617},
	{"DERIVATIVES", 11, 36618},
	{"PREVENTS", 8, 36619},
	{"ITBU", 4, 36620},
	{"STITCH", 6, 36621},
	{"RISB", 4, 36622},
	{"LESOTHO", 7, 36623},
	{"SEVERITY", 8, 36624},
	{"EMYS", 4, 36625},
	{"RDSC", 4, 36626},
	{"ELYE", 4, 36627},
	{"FAPP", 4, 36628},
	{"RFID", 4, 36629},
	{"NOTABLE", 7, 36630},
	{"ALDR", 4, 36631},
	{"WARFARE", 7, 36632},
	{"TCLE", 4, 36633},
	{"RETAILING", 9, 36634},
	{"JUDICIARY", 9, 36635},
	{"EMBROIDERY", 10, 36636},
	{"MAMA", 4, 36637},
	{"INLAND", 6, 36638},
	{"OSCOMMERCE", 10, 36639},
	{"NONFICTION", 10, 36640},
	{"LSEW", 4, 36641},
	{"HOMEOWNERS", 10, 36642},
	{"LDAY", 4, 36643},
	{"KEAD", 4, 36644},
	{"OCCE", 4, 36645},
	{"WSOF", 4, 36646},
	{"ARKT", 4, 36647},
	{"GREENLAND", 9, 36648},
	{"RCOA", 4, 36649},
	{"YLOO", 4, 36650},
	{"EVEM", 4, 36651},
	{"ACCORD", 6, 36652},
	{"GAMERS", 6, 36653},
	{"NSUB", 4, 36654},
	{"LICENSEE", 8, 36655},
	{"COUNTRYSIDE", 11, 36656},
	{"SORTING", 7, 36657},
	{"LIAISON", 7, 36658},
	{"NFLO", 4, 36659},
	{"ELLU", 4, 36660},
	{"EOFU", 4, 36661},
	{"NCHU", 4, 36662},
	{"NTBY", 4, 36663},
	{"UNUSED", 6, 36664},
	{"BULBS", 5, 36665},
	{"LLFR", 4, 36666},
	{"YBOA", 4, 36667},
	{"UTAF", 4, 36668},
	{"EDFE", 4, 36669},
	{"RAUD", 4, 36670},
	{"CONSUMING", 9, 36671},
	{"INSTALLER", 9, 36672},
	{"VENF", 4, 36673},
	{"TOURISTS", 8, 36674},
	{"RDRO", 4, 36675},
	{"SANDALS", 7, 36676},
	{"YSPR", 4, 36677},
	{"GHCO", 4, 36678},
	{"POWERSHOT", 9, 36679},
	{"BESTSELLING", 11, 36680},
	{"KWHI", 4, 36681},
	{"VEMI", 4, 36682},
	{"INSURE", 6, 36683},
	{"PACKAGED", 8, 36684},
	{"BEHAVIORS", 9, 36685},
	{"CLARIFY", 7, 36686},
	{"OODM", 4, 36687},
	{"EYDE", 4, 36688},
	{"NOFD", 4, 36689},
	{"SECONDED", 8, 36690},
	{"ACTIVATE", 8, 36691},
	{"UNER", 4, 36692},
	{"ATTRIBUTED", 10, 36693},
	{"SEYCHELLES", 10, 36694},
	{"PATRIOT", 7, 36695},
	{"EDOL", 4, 36696},
	{"UREG", 4, 36697},
	{"LOFS", 4, 36698},
	{"GKY", 3, 36699},
	{"SEWER", 5, 36700},
	{"CRYSTALS", 8, 36701},
	{"KATHLEEN", 8, 36702},
	{"MSCO", 4, 36703},
	{"BOSCH", 5, 36704},
	{"YWEA", 4, 36705},
	{"FORTHCOMING", 11, 36706},
	{"SANDISK", 7, 36707},
	{"NSYL", 4, 36708},
	{"GEDF", 4, 36709},
	{"TREATS", 6, 36710},
	{"OMEV", 4, 36711},
	{"MARINO", 6, 36712},
	{"LFUN", 4, 36713},
	{"DETENTION", 9, 36714},
	{"RMAI", 4, 36715},
	{"CARSON", 6, 36716},
	{"TICF", 4, 36717},
	{"YALO", 4, 36718},
	{"VITRO", 5, 36719},
	{"PHOM", 4, 36720},
	{"EXCEEDS", 7, 36721},
	{"DWON", 4, 36722},
	{"COMPLEMENTARY", 13, 36723},
	{"COSPONSORS", 10, 36724},
	{"GALLON", 6, 36725},
	{"WOMO", 4, 36726},
	{"COIL", 4, 36727},
	{"BATTLES", 7, 36728},
	{"HYATT", 5, 36729},
	{"TRADERS", 7, 36730},
	{"CARLTON", 7, 36731},
	{"GTWO", 4, 36732},
	{"MEMORANDUM", 10, 36733},
	{"OUPI", 4, 36734},
	{"LMAT", 4, 36735},
	{"BURNED", 6, 36736},
	{"CARDINAL", 8, 36737},
	{"DRAGONS", 7, 36738},
	{"CONVERTING", 10, 36739},
	{"ROMEO", 5, 36740},
	{"RGIV", 4, 36741},
	{"BURUNDI", 7, 36742},
	{"DSFR", 4, 36743},
	{"LYTW", 4, 36744},
	{"RRIB", 4, 36745},
	{"SBLA", 4, 36746},
	{"DELEGATES", 9, 36747},
	{"MSFO", 4, 36748},
	{"TURKS", 5, 36749},
	{"NGQU", 4, 36750},
	{"ROMA", 4, 36751},
	{"DEMOS", 5, 36752},
	{"BALANCING", 9, 36753},
	{"SIDED", 5, 36754},
	{"CLAIMING", 8, 36755},
	{"ALBR", 4, 36756},
	{"PSYCHIATRIC", 11, 36757},
	{"NPOR", 4, 36758},
	{"TITTENS", 7, 36759},
	{"TEENAGERS", 9, 36760},
	{"COURTYARD", 9, 36761},
	{"PRESIDENTS", 10, 36762},
	{"TLOC", 4, 36763},
	{"RURA", 4, 36764},
	{"TPOP", 4, 36765},
	{"TCAU", 4, 36766},
	{"OFFENDERS", 9, 36767},
	{"VEAD", 4, 36768},
	{"RNOV", 4, 36769},
	{"EAMC", 4, 36770},
	{"GRADING", 7, 36771},
	{"TENANTS", 7, 36772},
	{"EXPRESSLY", 9, 36773},
	{"NLIF", 4, 36774},
	{"GHTG", 4, 36775},
	{"LILY", 4, 36776},
	{"RENW", 4, 36777},
	{"BRACKETS", 8, 36778},
	{"UNOFFICIAL", 10, 36779},
	{"RBEE", 4, 36780},
	{"ITUR", 4, 36781},
	{"OVERSIGHT", 9, 36782},
	{"BIGT", 4, 36783},
	{"VALENTINES", 10, 36784},
	{"VONAGE", 6, 36785},
	{"YTRI", 4, 36786},
	{"AILR", 4, 36787},
	{"WETLANDS", 8, 36788},
	{"MEDW", 4, 36789},
	{"MINDED", 6, 36790},
	{"AMFO", 4, 36791},
	{"STQU", 4, 36792},
	{"LINV", 4, 36793},
	{"RESIN", 5, 36794},
	{"ELLD", 4, 36795},
	{"NEDY", 4, 36796},
	{"ALLIES", 6, 36797},
	{"TWILIGHT", 8, 36798},
	{"LEYW", 4, 36799},
	{"PRESERVED", 9, 36800},
	{"CROSSED", 7, 36801},
	{"EYBO", 4, 36802},
	{"KENSINGTON", 10, 36803},
	{"MONTEREY", 8, 36804},
	{"YRF", 3, 36805},
	{"EGYP", 4, 36806},
	{"LINEN", 5, 36807},
	{"LECL", 4, 36808},
	{"QUICKTIME", 9, 36809},
	{"OMCA", 4, 36810},
	{"LYEV", 4, 36811},
	{"ASCENDING", 9, 36812},
	{"SEALS", 5, 36813},
	{"NOMINAL", 7, 36814},
	{"DEXC", 4, 36815},
	{"ALICIA", 6, 36816},
	{"LKER", 4, 36817},
	{"DECAY", 5, 36818},
	{"WEAKNESSES", 10, 36819},
	{"BERH", 4, 36820},
	{"UNDERWATER", 10, 36821},
	{"QUARTZ", 6, 36822},
	{"XWR", 3, 36823},
	{"DASW", 4, 36824},
	{"TDIR", 4, 36825},
	{"GEPR", 4, 36826},
	{"RLYP", 4, 36827},
	{"REGISTERS", 9, 36828},
	{"USHER", 5, 36829},
	{"URRA", 4, 36830},
	{"JUW", 3, 36831},
	{"DWOM", 4, 36832},
	{"HERBERT", 7, 36833},
	{"SBOD", 4, 36834},
	{"DOFI", 4, 36835},
	{"ICKW", 4, 36836},
	{"LKAB", 4, 36837},
	{"AUTHORISED", 10, 36838},
	{"YZU", 3, 36839},
	{"IMPROVES", 8, 36840},
	{"YBER", 4, 36841},
	{"BOXI", 4, 36842},
	{"ADVOCATES", 9, 36843},
	{"OBOD", 4, 36844},
	{"RYFR", 4, 36845},
	{"KWHE", 4, 36846},
	{"RMEA", 4, 36847},
	{"IREP", 4, 36848},
	{"PAYF", 4, 36849},
	{"PHENOMENA", 9, 36850},
	{"YVER", 4, 36851},
	{"AIDD", 4, 36852},
	{"BUFFET", 6, 36853},
	{"DECIDING", 8, 36854},
	{"ILDC", 4, 36855},
	{"SKATE", 5, 36856},
	{"DREV", 4, 36857},
	{"RDSE", 4, 36858},
	{"VANUATU", 7, 36859},
	{"GCAN", 4, 36860},
	{"RBRA", 4, 36861},
	{"LFRI", 4, 36862},
	{"DJAC", 4, 36863},
	{"LBEL", 4, 36864},
	{"RRAI", 4, 36865},
	{"JOEY", 4, 36866},
	{"RREV", 4, 36867},
	{"EROTIK", 6, 36868},
	{"NCYA", 4, 36869},
	{"HACKERS", 7, 36870},
	{"LCAM", 4, 36871},
	{"RTAR", 4, 36872},
	{"ZGU", 3, 36873},
	{"XYP", 3, 36874},
	{"GRANITE", 7, 36875},
	{"LYNCH", 5, 36876},
	{"TQUI", 4, 36877},
	{"MASSES", 6, 36878},
	{"HADW", 4, 36879},
	{"TRANSFORMED", 11, 36880},
	{"BSID", 4, 36881},
	{"TARGETING", 9, 36882},
	{"FRANC", 5, 36883},
	{"BEAD", 4, 36884},
	{"MESD", 4, 36885},
	{"DBYG", 4, 36886},
	{"PRESCHOOL", 9, 36887},
	{"AMOV", 4, 36888},
	{"LANDLORD", 8, 36889},
	{"RPEN", 4, 36890},
	{"TFUN", 4, 36891},
	{"LEAK", 4, 36892},
	{"TIMOR", 5, 36893},
	{"OFVA", 4, 36894},
	{"ASSORTED", 8, 36895},
	{"ORDF", 4, 36896},
	{"LYCL", 4, 36897},
	{"IMPLEMENTS", 10, 36898},
	{"FLATS", 5, 36899},
	{"VOUCHERS", 8, 36900},
	{"MEGAPIXEL", 9, 36901},
	{"BOOKLET", 7, 36902},
	{"NGRY", 4, 36903},
	{"EXPECTING", 9, 36904},
	{"XICA", 4, 36905},
	{"CANCUN", 6, 36906},
	{"SROU", 4, 36907},
	{"SROL", 4, 36908},
	{"MTOF", 4, 36909},
	{"HEELS", 5, 36910},
	{"RMOV", 4, 36911},
	{"LYGR", 4, 36912},
	{"TURNOVER", 8, 36913},
	{"URINE", 5, 36914},
	{"CHERYL", 6, 36915},
	{"RADEON", 6, 36916},
	{"CAPRI", 5, 36917},
	{"FKG", 3, 36918},
	{"ORYC", 4, 36919},
	{"GINGER", 6, 36920},
	{"ITALICIZED", 10, 36921},
	{"OLDR", 4, 36922},
	{"INGQ", 4, 36923},
	{"EREJ", 4, 36924},
	{"SUBURBS", 7, 36925},
	{"NDIG", 4, 36926},
	{"TCRI", 4, 36927},
	{"IMAGERY", 7, 36928},
	{"CHROMOSOME", 10, 36929},
	{"OPTIMIZED", 9, 36930},
	{"DROV", 4, 36931},
	{"FFAL", 4, 36932},
	{"SEARS", 5, 36933},
	{"VEAG", 4, 36934},
	{"KSLI", 4, 36935},
	{"FWHO", 4, 36936},
	{"HCOL", 4, 36937},
	{"ROFD", 4, 36938},
	{"FFL", 3, 36939},
	{"VEWH", 4, 36940},
	{"FLIES", 5, 36941},
	{"UPGRADED", 8, 36942},
	{"COMPETENCE", 10, 36943},
	{"THBR", 4, 36944},
	{"INADEQUATE", 10, 36945},
	{"NYCA", 4, 36946},
	{"CRYING", 6, 36947},
	{"OVIC", 4, 36948},
	{"MATTHEWS", 8, 36949},
	{"TACL", 4, 36950},
	{"LAYB", 4, 36951},
	{"MERM", 4, 36952},
	{"CRANE", 5, 36953},
	{"DEFENDANTS", 10, 36954},
	{"FFSE", 4, 36955},
	{"YOFE", 4, 36956},
	{"OFKI", 4, 36957},
	{"DEPLOYED", 8, 36958},
	{"GOVERNED", 8, 36959},
	{"ORTB", 4, 36960},
	{"PEDW", 4, 36961},
	{"GSPE", 4, 36962},
	{"INVESTIGATING", 13, 36963},
	{"GSCO", 4, 36964},
	{"ROTTEN", 6, 36965},
	{"GETM", 4, 36966},
	{"POPUP", 5, 36967},
	{"GARNET", 6, 36968},
	{"LBAS", 4, 36969},
	{"SCATTERED", 9, 36970},
	{"OMAM", 4, 36971},
	{"HONOUR", 6, 36972},
	{"USELESS", 7, 36973},
	{"PROTECTS", 8, 36974},
	{"ORKH", 4, 36975},
	{"NORTHWESTERN", 12, 36976},
	{"AUDIENCES", 9, 36977},
	{"YGRE", 4, 36978},
	{"COUPE", 5, 36979},
	{"BENIN", 5, 36980},
	{"UYJ", 3, 36981},
	{"USWI", 4, 36982},
	{"RYSH", 4, 36983},
	{"PPP", 3, 36984},
	{"BACH", 4, 36985},
	{"MANAGES", 7, 36986},
	{"ITYG", 4, 36987},
	{"EROSION", 7, 36988},
	{"OCEANIA", 7, 36989},
	{"ORFE", 4, 36990},
	{"ABUNDANCE", 9, 36991},
	{"BERB", 4, 36992},
	{"CARPENTER", 9, 36993},
	{"INSUFFICIENT", 12, 36994},
	{"ROMJ", 4, 36995},
	{"INMU", 4, 36996},
	{"HIGHLANDS", 9, 36997},
	{"PETERS", 6, 36998},
	{"FERTILITY", 9, 36999},
	{"RNOF", 4, 37000},
	{"FORMULATION", 11, 37001},
	{"DBOO", 4, 37002},
	{"CLEVER", 6, 37003},
	{"PRIMER", 6, 37004},
	{"DFOL", 4, 37005},
	{"LORDS", 5, 37006},
	{"TENDS", 5, 37007},
	{"ALFE", 4, 37008},
	{"FRESNO", 6, 37009},
	{"LYAG", 4, 37010},
	{"ALOP", 4, 37011},
	{"AIRB", 4, 37012},
	{"ENJOYABLE", 9, 37013},
	{"HANDBAG", 7, 37014},
	{"ILEF", 4, 37015},
	{"TYBE", 4, 37016},
	{"MESL", 4, 37017},
	{"BEEX", 4, 37018},
	{"SBRE", 4, 37019},
	{"CRESCENT", 8, 37020},
	{"WAYN", 4, 37021},
	{"BYPASS", 6, 37022},
	{"TOWR", 4, 37023},
	{"PLAYGROUND", 10, 37024},
	{"LOGOUT", 6, 37025},
	{"KEWI", 4, 37026},
	{"UCHB", 4, 37027},
	{"ORGIES", 6, 37028},
	{"PERMANENTLY", 11, 37029},
	{"YCAS", 4, 37030},
	{"LYBR", 4, 37031},
	{"CONCENTRATED", 12, 37032},
	{"CKAT", 4, 37033},
	{"PLYT", 4, 37034},
	{"KWW", 3, 37035},
	{"GUEA", 4, 37036},
	{"LDWE", 4, 37037},
	{"DOFD", 4, 37038},
	{"VALR", 4, 37039},
	{"HOGTIED", 7, 37040},
	{"LPHO", 4, 37041},
	{"ECIR", 4, 37042},
	{"ODOU", 4, 37043},
	{"PROJECTIONS", 11, 37044},
	{"YITW", 4, 37045},
	{"ORPL", 4, 37046},
	{"ILYB", 4, 37047},
	{"CLIPART", 7, 37048},
	{"SECURING", 8, 37049},
	{"RRYS", 4, 37050},
	{"PATHWAY", 7, 37051},
	{"LESR", 4, 37052},
	{"DETECTORS", 9, 37053},
	{"WNCO", 4, 37054},
	{"FULS", 4, 37055},
	{"DSUN", 4, 37056},
	{"GSCH", 4, 37057},
	{"NEWSGROUPS", 10, 37058},
	{"RCET", 4, 37059},
	{"ESBR", 4, 37060},
	{"DKIL", 4, 37061},
	{"SPIKE", 5, 37062},
	{"PLATED", 6, 37063},
	{"IOGR", 4, 37064},
	{"JACQUES", 7, 37065},
	{"GEXP", 4, 37066},
	{"REDG", 4, 37067},
	{"SPECTRA", 7, 37068},
	{"LZU", 3, 37069},
	{"LIFTING", 7, 37070},
	{"DOFB", 4, 37071},
	{"JUDITH", 6, 37072},
	{"DISCLOSED", 9, 37073},
	{"DAVIES", 6, 37074},
	{"EPAP", 4, 37075},
	{"OLIF", 4, 37076},
	{"TACTICAL", 8, 37077},
	{"IKEP", 4, 37078},
	{"AIDP", 4, 37079},
	{"PILOTS", 6, 37080},
	{"MAILBOX", 7, 37081},
	{"OOLC", 4, 37082},
	{"COPENHAGEN", 10, 37083},
	{"FSEV", 4, 37084},
	{"RNCO", 4, 37085},
	{"ROFR", 4, 37086},
	{"OPERATIVE", 9, 37087},
	{"EWME", 4, 37088},
	{"UVER", 4, 37089},
	{"HUMOUR", 6, 37090},
	{"KCIT", 4, 37091},
	{"ATHLON", 6, 37092},
	{"MATURITY", 8, 37093},
	{"CALLER", 6, 37094},
	{"DISTORTION", 10, 37095},
	{"DNUM", 4, 37096},
	{"PTOF", 4, 37097},
	{"ESMU", 4, 37098},
	{"RTEL", 4, 37099},
	{"TYBU", 4, 37100},
	{"LOFH", 4, 37101},
	{"ADEU", 4, 37102},
	{"THBU", 4, 37103},
	{"RIBL", 4, 37104},
	{"ONCU", 4, 37105},
	{"LANDSCAPING", 11, 37106},
	{"GSFO", 4, 37107},
	{"TONGA", 5, 37108},
	{"IMPRINT", 7, 37109},
	{"ICLI", 4, 37110},
	{"YLOC", 4, 37111},
	{"BYSO", 4, 37112},
	{"KORN", 4, 37113},
	{"NATALIE", 7, 37114},
	{"RECEIPTS", 8, 37115},
	{"ASSISTING", 9, 37116},
	{"SHIRLEY", 7, 37117},
	{"NOWC", 4, 37118},
	{"HADG", 4, 37119},
	{"RQUA", 4, 37120},
	{"WWAS", 4, 37121},
	{"EMFO", 4, 37122},
	{"SANCTIONS", 9, 37123},
	{"DIRECTV", 7, 37124},
	{"NGKO", 4, 37125},
	{"COTL", 4, 37126},
	{"USWH", 4, 37127},
	{"GOODBYE", 7, 37128},
	{"ISFU", 4, 37129},
	{"YWAR", 4, 37130},
	{"VIABLE", 6, 37131},
	{"RGOO", 4, 37132},
	{"EMERGED", 7, 37133},
	{"DEVIANTART", 10, 37134},
	{"DEFECT", 6, 37135},
	{"RDEL", 4, 37136},
	{"GECA", 4, 37137},
	{"DMUC", 4, 37138},
	{"DCRI", 4, 37139},
	{"WNLO", 4, 37140},
	{"ABAL", 4, 37141},
	{"POORLY", 6, 37142},
	{"YNOW", 4, 37143},
	{"MEDY", 4, 37144},
	{"GODDESS", 7, 37145},
	{"BACKS", 5, 37146},
	{"IDCO", 4, 37147},
	{"OBSERVERS", 9, 37148},
	{"AQUE", 4, 37149},
	{"MAGNETS", 7, 37150},
	{"FORMULAS", 8, 37151},
	{"MBRI", 4, 37152},
	{"SPACIOUS", 8, 37153},
	{"SHOULDERS", 9, 37154},
	{"ARGUES", 6, 37155},
	{"GERR", 4, 37156},
	{"WADE", 4, 37157},
	{"GAFT", 4, 37158},
	{"VEFR", 4, 37159},
	{"OFOP", 4, 37160},
	{"SOILS", 5, 37161},
	{"ELUC", 4, 37162},
	{"OLEM", 4, 37163},
	{"OVEF", 4, 37164},
	{"ALCI", 4, 37165},
	{"YHAL", 4, 37166},
	{"RXM", 3, 37167},
	{"CHAPMAN", 7, 37168},
	{"ORGANS", 6, 37169},
	{"DLEY", 4, 37170},
	{"TPUB", 4, 37171},
	{"URMA", 4, 37172},
	{"NBUI", 4, 37173},
	{"YSPA", 4, 37174},
	{"ELPO", 4, 37175},
	{"BELOVED", 7, 37176},
	{"ILEB", 4, 37177},
	{"WUW", 3, 37178},
	{"NGMY", 4, 37179},
	{"BALLARD", 7, 37180},
	{"BEATING", 7, 37181},
	{"FAITHFUL", 8, 37182},
	{"EWZE", 4, 37183},
	{"HUNKS", 5, 37184},
	{"APPELLANT", 9, 37185},
	{"LLOO", 4, 37186},
	{"LIBYA", 5, 37187},
	{"OFFENCE", 7, 37188},
	{"SOFU", 4, 37189},
	{"CHDI", 4, 37190},
	{"INVESTED", 8, 37191},
	{"WHATSOEVER", 10, 37192},
	{"NUMBERED", 8, 37193},
	{"RSIM", 4, 37194},
	{"UBZ", 3, 37195},
	{"DLIT", 4, 37196},
	{"TERMINATED", 10, 37197},
	{"DSBE", 4, 37198},
	{"LLIV", 4, 37199},
	{"EXPANDS", 7, 37200},
	{"ULYA", 4, 37201},
	{"LITHIUM", 7, 37202},
	{"SEDAN", 5, 37203},
	{"PONY", 4, 37204},
	{"COMPRISES", 9, 37205},
	{"BOLTON", 6, 37206},
	{"OFBL", 4, 37207},
	{"FOUNDING", 8, 37208},
	{"YSWE", 4, 37209},
	{"PLANTING", 8, 37210},
	{"ALPHABETICALLY", 14, 37211},
	{"FACIALS", 7, 37212},
	{"COVENANT", 8, 37213},
	{"NPOP", 4, 37214},
	{"DROPPING", 8, 37215},
	{"LDGE", 4, 37216},
	{"CALORIES", 8, 37217},
	{"EMSW", 4, 37218},
	{"AIRWAYS", 7, 37219},
	{"ARCHAEOLOGY", 11, 37220},
	{"OMRE", 4, 37221},
	{"YSAR", 4, 37222},
	{"REFILL", 6, 37223},
	{"REAGAN", 6, 37224},
	{"SAILOR", 6, 37225},
	{"FITTINGS", 8, 37226},
	{"LINING", 6, 37227},
	{"BANQUET", 7, 37228},
	{"CARES", 5, 37229},
	{"SANCTUARY", 9, 37230},
	{"FLORA", 5, 37231},
	{"TAXP", 4, 37232},
	{"ECYC", 4, 37233},
	{"KAZAA", 5, 37234},
	{"RLYM", 4, 37235},
	{"EINSTEIN", 8, 37236},
	{"EDDR", 4, 37237},
	{"WZEA", 4, 37238},
	{"HILARY", 6, 37239},
	{"ILRO", 4, 37240},
	{"QUOTATION", 9, 37241},
	{"EQUALS", 6, 37242},
	{"GXU", 3, 37243},
	{"HARDY", 5, 37244},
	{"ERYR", 4, 37245},
	{"VCD", 3, 37246},
	{"JUMPER", 6, 37247},
	{"CARAVAN", 7, 37248},
	{"DIAGRAMS", 8, 37249},
	{"DDEL", 4, 37250},
	{"HARNESS", 7, 37251},
	{"MAJORS", 6, 37252},
	{"HEADSETS", 8, 37253},
	{"TFAL", 4, 37254},
	{"YRIG", 4, 37255},
	{"MANIPULATION", 12, 37256},
	{"BELLS", 5, 37257},
	{"VASCULAR", 8, 37258},
	{"IMPRESSIONS", 11, 37259},
	{"YANKEES", 7, 37260},
	{"YBD", 3, 37261},
	{"TYOR", 4, 37262},
	{"TOXICITY", 8, 37263},
	{"FORWARDED", 9, 37264},
	{"FABO", 4, 37265},
	{"STCL", 4, 37266},
	{"RSIG", 4, 37267},
	{"TRANSMITTER", 11, 37268},
	{"BYPA", 4, 37269},
	{"DOROTHY", 7, 37270},
	{"LYGE", 4, 37271},
	{"FREEMAN", 7, 37272},
	{"DENIM", 5, 37273},
	{"GREENVILLE", 10, 37274},
	{"ANDRE", 5, 37275},
	{"NEIGHBORHOODS", 13, 37276},
	{"NLAR", 4, 37277},
	{"PUPPIES", 7, 37278},
	{"RELAXING", 8, 37279},
	{"TICR", 4, 37280},
	{"DELPHI", 6, 37281},
	{"TROPHY", 6, 37282},
	{"LDRI", 4, 37283},
	{"BUICK", 5, 37284},
	{"SLIPKNOT", 8, 37285},
	{"SDEB", 4, 37286},
	{"SIGHTS", 6, 37287},
	{"UNIFORMS", 8, 37288},
	{"SWID", 4, 37289},
	{"RESIDUAL", 8, 37290},
	{"DISASTERS", 9, 37291},
	{"YRP", 3, 37292},
	{"ASTERISK", 8, 37293},
	{"GONL", 4, 37294},
	{"DABI", 4, 37295},
	{"VERSATILE", 9, 37296},
	{"LIQUOR", 6, 37297},
	{"KINDERGARTEN", 12, 37298},
	{"MYOU", 4, 37299},
	{"ALAG", 4, 37300},
	{"OFCE", 4, 37301},
	{"PROFITABLE", 10, 37302},
	{"WOUNDED", 7, 37303},
	{"DGOT", 4, 37304},
	{"CLAYTON", 7, 37305},
	{"EFUR", 4, 37306},
	{"RTSF", 4, 37307},
	{"RMAD", 4, 37308},
	{"DERIVATIVE", 10, 37309},
	{"SUFFOLK", 7, 37310},
	{"GYPT", 4, 37311},
	{"YERO", 4, 37312},
	{"NECKLACES", 9, 37313},
	{"STORESSHOP", 10, 37314},
	{"RPUB", 4, 37315},
	{"OCCUPANCY", 9, 37316},
	{"POSTGRADUATE", 12, 37317},
	{"DOSES", 5, 37318},
	{"TDRI", 4, 37319},
	{"BAKED", 5, 37320},
	{"ACHB", 4, 37321},
	{"DAYTONA", 7, 37322},
	{"WASTEWATER", 10, 37323},
	{"DROB", 4, 37324},
	{"PREJUDICE", 9, 37325},
	{"HERZEGOVINA", 11, 37326},
	{"ODRE", 4, 37327},
	{"GYEA", 4, 37328},
	{"MSWE", 4, 37329},
	{"CONSTRUCTOR", 11, 37330},
	{"PYOU", 4, 37331},
	{"TECHNICIANS", 11, 37332},
	{"SUBU", 4, 37333},
	{"DEBBIE", 6, 37334},
	{"PROBABLE", 8, 37335},
	{"DFUN", 4, 37336},
	{"ISSUANCE", 8, 37337},
	{"BALDWIN", 7, 37338},
	{"DSMO", 4, 37339},
	{"YPB", 3, 37340},
	{"MBPS", 4, 37341},
	{"INCORPORATION", 13, 37342},
	{"VEOR", 4, 37343},
	{"ONGU", 4, 37344},
	{"EVOLUTIONARY", 12, 37345},
	{"EADQ", 4, 37346},
	{"TCLO", 4, 37347},
	{"BYAC", 4, 37348},
	{"ECTM", 4, 37349},
	{"DECORATION", 10, 37350},
	{"DYTH", 4, 37351},
	{"NATIONALS", 9, 37352},
	{"ILYF", 4, 37353},
	{"TROJAN", 6, 37354},
	{"ASSISTANTS", 10, 37355},
	{"SPINAL", 6, 37356},
	{"BYCA", 4, 37357},
	{"DORD", 4, 37358},
	{"ELIMINATED", 10, 37359},
	{"ALITO", 5, 37360},
	{"SOONER", 6, 37361},
	{"TFAM", 4, 37362},
	{"STRUGGLING", 10, 37363},
	{"ENACTED", 7, 37364},
	{"WATERFRONT", 10, 37365},
	{"TENURE", 6, 37366},
	{"NTGR", 4, 37367},
	{"PLUSH", 5, 37368},
	{"WEBER", 5, 37369},
	{"DIAGNOSED", 9, 37370},
	{"NMEM", 4, 37371},
	{"DCRO", 4, 37372},
	{"BIOTECH", 7, 37373},
	{"UNSTABLE", 8, 37374},
	{"TURKMENISTAN", 12, 37375},
	{"NFED", 4, 37376},
	{"RUNK", 4, 37377},
	{"OUTY", 4, 37378},
	{"WOODLAND", 8, 37379},
	{"IRANIAN", 7, 37380},
	{"DCEN", 4, 37381},
	{"NDCI", 4, 37382},
	{"NELLY", 5, 37383},
	{"FULFILL", 7, 37384},
	{"URGED", 5, 37385},
	{"REFLECTING", 10, 37386},
	{"UNSECURED", 9, 37387},
	{"ANPL", 4, 37388},
	{"ERKN", 4, 37389},
	{"EMUN", 4, 37390},
	{"BRENT", 5, 37391},
	{"NDIW", 4, 37392},
	{"GAINING", 7, 37393},
	{"KYOTO", 5, 37394},
	{"DEFINITIVE", 10, 37395},
	{"APPROPRIATELY", 13, 37396},
	{"ATFR", 4, 37397},
	{"LDFI", 4, 37398},
	{"SHIFTS", 6, 37399},
	{"INACTIVE", 8, 37400},
	{"LANSING", 7, 37401},
	{"TRAVELED", 8, 37402},
	{"BARCODE", 7, 37403},
	{"WINC", 4, 37404},
	{"TSBY", 4, 37405},
	{"PECU", 4, 37406},
	{"EXTRACTED", 9, 37407},
	{"URTR", 4, 37408},
	{"ACCESSION", 9, 37409},
	{"PATTERSON", 9, 37410},
	{"LLCL", 4, 37411},
	{"ADPR", 4, 37412},
	{"LYAM", 4, 37413},
	{"MONW", 4, 37414},
	{"CARRIAGE", 8, 37415},
	{"THEREIN", 7, 37416},
	{"RRYT", 4, 37417},
	{"RDHA", 4, 37418},
	{"TERMINATE", 9, 37419},
	{"ALFU", 4, 37420},
	{"NKLE", 4, 37421},
	{"LFAR", 4, 37422},
	{"IRTY", 4, 37423},
	{"LMER", 4, 37424},
	{"HIPB", 4, 37425},
	{"FUELS", 5, 37426},
	{"UTBY", 4, 37427},
	{"ELFW", 4, 37428},
	{"GERF", 4, 37429},
	{"ELYL", 4, 37430},
	{"POSTCODE", 8, 37431},
	{"DATR", 4, 37432},
	{"SFRA", 4, 37433},
	{"BRETT", 5, 37434},
	{"EJAP", 4, 37435},
	{"MAKEFILE", 8, 37436},
	{"ULOU", 4, 37437},
	{"ANCHORAGE", 9, 37438},
	{"KEAC", 4, 37439},
	{"PAULA", 5, 37440},
	{"NYAR", 4, 37441},
	{"RYSU", 4, 37442},
	{"DBAL", 4, 37443},
	{"EYGE", 4, 37444},
	{"RGOV", 4, 37445},
	{"UZD", 3, 37446},
	{"INRU", 4, 37447},
	{"DCHR", 4, 37448},
	{"EDBI", 4, 37449},
	{"VICODIN", 7, 37450},
	{"GREENS", 6, 37451},
	{"ACKR", 4, 37452},
	{"NAMING", 6, 37453},
	{"RDSP", 4, 37454},
	{"STERN", 5, 37455},
	{"SHAWN", 5, 37456},
	{"UCTA", 4, 37457},
	{"LACROSSE", 8, 37458},
	{"BENTLEY", 7, 37459},
	{"BUD", 3, 37460},
	{"SLAVES", 6, 37461},
	{"DENTIST", 7, 37462},
	{"ASCU", 4, 37463},
	{"UTILIZING", 9, 37464},
	{"CRAFTED", 7, 37465},
	{"EFEW", 4, 37466},
	{"BURKINA", 7, 37467},
	{"ERITREA", 7, 37468},
	{"BBQ", 3, 37469},
	{"TUTOR", 5, 37470},
	{"IDIOT", 5, 37471},
	{"XPOR", 4, 37472},
	{"FSTR", 4, 37473},
	{"COMPRISED", 9, 37474},
	{"ICSW", 4, 37475},
	{"WINNIPEG", 8, 37476},
	{"CHARITIES", 9, 37477},
	{"MICKEY", 6, 37478},
	{"DEBIT", 5, 37479},
	{"SEBASTIAN", 9, 37480},
	{"ALIENS", 6, 37481},
	{"RLYO", 4, 37482},
	{"KERW", 4, 37483},
	{"DOMINO", 6, 37484},
	{"DMX", 3, 37485},
	{"EDITS", 5, 37486},
	{"UNWANTED", 8, 37487},
	{"RAVEN", 5, 37488},
	{"DEFEATED", 8, 37489},
	{"STRAINS", 7, 37490},
	{"DWELLING", 8, 37491},
	{"CSOF", 4, 37492},
	{"SFIG", 4, 37493},
	{"TANNING", 7, 37494},
	{"GAMBIA", 6, 37495},
	{"ASPEN", 5, 37496},
	{"LACKING", 7, 37497},
	{"NMOD", 4, 37498},
	{"OBJECTIONABLE", 13, 37499},
	{"LOWP", 4, 37500},
	{"ANGLES", 6, 37501},
	{"LEMMA", 5, 37502},
	{"KYRGYZSTAN", 10, 37503},
	{"LLGA", 4, 37504},
	{"PRESSURES", 9, 37505},
	{"WEBB", 4, 37506},
	{"SENSING", 7, 37507},
	{"YSRE", 4, 37508},
	{"MEDIATION", 9, 37509},
	{"VENUS", 5, 37510},
	{"POSTGRESQL", 10, 37511},
	{"BUMP", 4, 37512},
	{"TLOU", 4, 37513},
	{"COWBOYS", 7, 37514},
	{"BLYA", 4, 37515},
	{"NOFG", 4, 37516},
	{"FLAMES", 6, 37517},
	{"TFIG", 4, 37518},
	{"DTRE", 4, 37519},
	{"PRIMITIVE", 9, 37520},
	{"KBPS", 4, 37521},
	{"LMET", 4, 37522},
	{"TRAC", 4, 37523},
	{"RTRO", 4, 37524},
	{"OLEC", 4, 37525},
	{"OMOU", 4, 37526},
	{"GRAI", 4, 37527},
	{"STOCKING", 8, 37528},
	{"YOUI", 4, 37529},
	{"YGAM", 4, 37530},
	{"ETPR", 4, 37531},
	{"DOLBY", 5, 37532},
	{"BALLOONS", 8, 37533},
	{"ILDH", 4, 37534},
	{"EABU", 4, 37535},
	{"CALW", 4, 37536},
	{"PKG", 3, 37537},
	{"DASHBOARD", 9, 37538},
	{"MALCOLM", 7, 37539},
	{"NIKKI", 5, 37540},
	{"REMU", 4, 37541},
	{"GEORGETOWN", 10, 37542},
	{"TECHNORATI", 10, 37543},
	{"LMOR", 4, 37544},
	{"NORWICH", 7, 37545},
	{"HALLS", 5, 37546},
	{"OPUR", 4, 37547},
	{"ALZHEIMER", 9, 37548},
	{"DECORATIONS", 11, 37549},
	{"SIMPLICITY", 10, 37550},
	{"POSTSCRIPT", 10, 37551},
	{"DIVIDENDS", 9, 37552},
	{"FINF", 4, 37553},
	{"EOGR", 4, 37554},
	{"RELAXED", 7, 37555},
	{"PERIODICALS", 11, 37556},
	{"PEARSON", 7, 37557},
	{"ILEG", 4, 37558},
	{"DEMON", 5, 37559},
	{"WELCOMED", 8, 37560},
	{"DHED", 4, 37561},
	{"INFINITY", 8, 37562},
	{"RACL", 4, 37563},
	{"NPOW", 4, 37564},
	{"HANDLER", 7, 37565},
	{"TEPP", 4, 37566},
	{"TICD", 4, 37567},
	{"GABON", 5, 37568},
	{"THLY", 4, 37569},
	{"NOTATION", 8, 37570},
	{"CHANDLER", 8, 37571},
	{"GNOF", 4, 37572},
	{"YBYT", 4, 37573},
	{"PEDF", 4, 37574},
	{"INTERVIEWED", 11, 37575},
	{"CROW", 4, 37576},
	{"SEMANTIC", 8, 37577},
	{"ELSW", 4, 37578},
	{"WHYI", 4, 37579},
	{"ONMY", 4, 37580},
	{"NROU", 4, 37581},
	{"DISCONTINUED", 12, 37582},
	{"CONCURRENT", 10, 37583},
	{"DECIDES", 7, 37584},
	{"OFVE", 4, 37585},
	{"RACA", 4, 37586},
	{"CAPTION", 7, 37587},
	{"BARGAINING", 10, 37588},
	{"RLEY", 4, 37589},
	{"GLOBALIZATION", 13, 37590},
	{"YRAN", 4, 37591},
	{"ATARI", 5, 37592},
	{"RIDO", 4, 37593},
	{"GGLI", 4, 37594},
	{"EMOL", 4, 37595},
	{"RTLA", 4, 37596},
	{"PULMONARY", 9, 37597},
	{"ADHESIVE", 8, 37598},
	{"FFIR", 4, 37599},
	{"TOLEDO", 6, 37600},
	{"ALTITUDE", 8, 37601},
	{"YERW", 4, 37602},
	{"VEBU", 4, 37603},
	{"COMPASS", 7, 37604},
	{"REEBOK", 6, 37605},
	{"EVOLVED", 7, 37606},
	{"ROFW", 4, 37607},
	{"GANW", 4, 37608},
	{"OUTU", 4, 37609},
	{"EDOP", 4, 37610},
	{"PROO", 4, 37611},
	{"DOWNS", 5, 37612},
	{"MFG", 3, 37613},
	{"EXCEEDING", 9, 37614},
	{"TWOL", 4, 37615},
	{"ROGUE", 5, 37616},
	{"QBM", 3, 37617},
	{"BLOGTHIS", 8, 37618},
	{"DMIC", 4, 37619},
	{"ELECTRONICALLY", 14, 37620},
	{"RFOO", 4, 37621},
	{"INSPIRATIONAL", 13, 37622},
	{"AUGUSTA", 7, 37623},
	{"OWAB", 4, 37624},
	{"DTAL", 4, 37625},
	{"WILMINGTON", 10, 37626},
	{"INFANTRY", 8, 37627},
	{"ZZD", 3, 37628},
	{"RENOWNED", 8, 37629},
	{"SCRIPTURE", 9, 37630},
	{"CELEBRATING", 11, 37631},
	{"SAHARA", 6, 37632},
	{"JUSTIFICATION", 13, 37633},
	{"LEBY", 4, 37634},
	{"SDRAM", 5, 37635},
	{"VACANT", 6, 37636},
	{"MANUSCRIPT", 10, 37637},
	{"FIXING", 6, 37638},
	{"RALY", 4, 37639},
	{"MOTHERBOARDS", 12, 37640},
	{"URIO", 4, 37641},
	{"GRAM", 4, 37642},
	{"BLK", 3, 37643},
	{"HIDING", 6, 37644},
	{"METHODIST", 9, 37645},
	{"DWEN", 4, 37646},
	{"URKI", 4, 37647},
	{"ALPHABET", 8, 37648},
	{"AWRE", 4, 37649},
	{"DPOW", 4, 37650},
	{"SHELVES", 7, 37651},
	{"CLEANED", 7, 37652},
	{"TEMW", 4, 37653},
	{"HONORED", 7, 37654},
	{"OPTIC", 5, 37655},
	{"HANNAH", 6, 37656},
	{"TELEPHONES", 10, 37657},
	{"TAILORED", 8, 37658},
	{"OOLF", 4, 37659},
	{"MMOR", 4, 37660},
	{"UTPR", 4, 37661},
	{"IDYO", 4, 37662},
	{"RSYS", 4, 37663},
	{"FRANCES", 7, 37664},
	{"DIARIES", 7, 37665},
	{"CHILI", 5, 37666},
	{"LEICESTER", 9, 37667},
	{"VODAFONE", 8, 37668},
	{"DOLPHIN", 7, 37669},
	{"PENDANTS", 8, 37670},
	{"YOFO", 4, 37671},
	{"LDWH", 4, 37672},
	{"WONDERS", 7, 37673},
	{"ROMANIAN", 8, 37674},
	{"VENTILATION", 11, 37675},
	{"RAMB", 4, 37676},
	{"UCLA", 4, 37677},
	{"MASKS", 5, 37678},
	{"CELEB", 5, 37679},
	{"BUST", 4, 37680},
	{"LATERAL", 7, 37681},
	{"UTFR", 4, 37682},
	{"OMUS", 4, 37683},
	{"RAGR", 4, 37684},
	{"DBIL", 4, 37685},
	{"ASSOC", 5, 37686},
	{"NOWM", 4, 37687},
	{"BLEL", 4, 37688},
	{"RDWH", 4, 37689},
	{"QUAKE", 5, 37690},
	{"LSFR", 4, 37691},
	{"PALO", 4, 37692},
	{"USABILITY", 9, 37693},
	{"GARDNER", 7, 37694},
	{"SANDERS", 7, 37695},
	{"PATHWAYS", 8, 37696},
	{"TELEGRAPH", 9, 37697},
	{"LAYF", 4, 37698},
	{"ERAV", 4, 37699},
	{"AMEU", 4, 37700},
	{"PERTAINING", 10, 37701},
	{"NOVELL", 6, 37702},
	{"MEMORABLE", 9, 37703},
	{"FULO", 4, 37704},
	{"YMAT", 4, 37705},
	{"ANYY", 4, 37706},
	{"REFUNDS", 7, 37707},
	{"NEWSROOM", 8, 37708},
	{"PROFESSORS", 10, 37709},
	{"DLYA", 4, 37710},
	{"GYY", 3, 37711},
	{"RBIL", 4, 37712},
	{"AYCA", 4, 37713},
	{"AYBA", 4, 37714},
	{"IDMA", 4, 37715},
	{"FORMALLY", 8, 37716},
	{"COLA", 4, 37717},
	{"TWAIN", 5, 37718},
	{"BOISE", 5, 37719},
	{"OFPH", 4, 37720},
	{"NEVIS", 5, 37721},
	{"LAVENDER", 8, 37722},
	{"OWSW", 4, 37723},
	{"TDEV", 4, 37724},
	{"REFINANCING", 11, 37725},
	{"JUSTIFIED", 9, 37726},
	{"PSWI", 4, 37727},
	{"WITHDRAWN", 9, 37728},
	{"ELYU", 4, 37729},
	{"LDYO", 4, 37730},
	{"DEBATES", 7, 37731},
	{"SOFJ", 4, 37732},
	{"RVAN", 4, 37733},
	{"DADV", 4, 37734},
	{"GEMS", 4, 37735},
	{"NRED", 4, 37736},
	{"CERT", 4, 37737},
	{"XCY", 3, 37738},
	{"BUFFY", 5, 37739},
	{"DESW", 4, 37740},
	{"SOUG", 4, 37741},
	{"LARB", 4, 37742},
	{"DOCTORAL", 8, 37743},
	{"FSUC", 4, 37744},
	{"GSER", 4, 37745},
	{"BEPA", 4, 37746},
	{"BACKPACK", 8, 37747},
	{"IDENTITIES", 10, 37748},
	{"OUTGOING", 8, 37749},
	{"TAJIKISTAN", 10, 37750},
	{"OWUP", 4, 37751},
	{"YANKEE", 6, 37752},
	{"ORCR", 4, 37753},
	{"YBOT", 4, 37754},
	{"OCKW", 4, 37755},
	{"SHERATON", 8, 37756},
	{"UREE", 4, 37757},
	{"OCAM", 4, 37758},
	{"RYOR", 4, 37759},
	{"OQUE", 4, 37760},
	{"ONDL", 4, 37761},
	{"SNACKS", 6, 37762},
	{"DEFICIENCY", 10, 37763},
	{"GHAL", 4, 37764},
	{"BOOSTER", 7, 37765},
	{"TAXABLE", 7, 37766},
	{"GUM", 3, 37767},
	{"PROGRESSION", 11, 37768},
	{"UEFO", 4, 37769},
	{"DIOC", 4, 37770},
	{"SADDLE", 6, 37771},
	{"MALARIA", 7, 37772},
	{"OWBO", 4, 37773},
	{"FITW", 4, 37774},
	{"TORRENT", 7, 37775},
	{"RKSI", 4, 37776},
	{"LINKSYS", 7, 37777},
	{"DENTISTRY", 9, 37778},
	{"MERW", 4, 37779},
	{"RDUR", 4, 37780},
	{"GTOU", 4, 37781},
	{"CHMI", 4, 37782},
	{"RENAL", 5, 37783},
	{"YIEL", 4, 37784},
	{"FEDORA", 6, 37785},
	{"ODYSSEY", 7, 37786},
	{"DBED", 4, 37787},
	{"CAPITA", 6, 37788},
	{"UTDI", 4, 37789},
	{"ZCU", 3, 37790},
	{"DAYP", 4, 37791},
	{"TSUB", 4, 37792},
	{"INACCURACIES", 12, 37793},
	{"YAGE", 4, 37794},
	{"CALEDONIA", 9, 37795},
	{"FREEZER", 7, 37796},
	{"WHOLLY", 6, 37797},
	{"UTILIZED", 8, 37798},
	{"YEDW", 4, 37799},
	{"EDIG", 4, 37800},
	{"RKCI", 4, 37801},
	{"PCR", 3, 37802},
	{"OBRO", 4, 37803},
	{"BINOCULARS", 10, 37804},
	{"LINER", 5, 37805},
	{"MANILA", 6, 37806},
	{"AUXILIARY", 9, 37807},
	{"UYK", 3, 37808},
	{"ELEVATED", 8, 37809},
	{"PURELY", 6, 37810},
	{"TAFR", 4, 37811},
	{"DBYW", 4, 37812},
	{"DEMOGRAPHICS", 12, 37813},
	{"FRY", 3, 37814},
	{"RBYT", 4, 37815},
	{"LDDE", 4, 37816},
	{"NBLA", 4, 37817},
	{"LIFTS", 5, 37818},
	{"VIVID", 5, 37819},
	{"ALLEGATIONS", 11, 37820},
	{"YOFD", 4, 37821},
	{"EAKF", 4, 37822},
	{"STATIONARY", 10, 37823},
	{"OREU", 4, 37824},
	{"CORRESPONDS", 11, 37825},
	{"KITC", 4, 37826},
	{"DAEMON", 6, 37827},
	{"FWAR", 4, 37828},
	{"FOIL", 4, 37829},
	{"WHITNEY", 7, 37830},
	{"GESF", 4, 37831},
	{"GLER", 4, 37832},
	{"CELEBRATED", 10, 37833},
	{"BUDDIES", 7, 37834},
	{"CKLA", 4, 37835},
	{"EXTM", 4, 37836},
	{"DOFL", 4, 37837},
	{"ALARMS", 6, 37838},
	{"YFAC", 4, 37839},
	{"OFFW", 4, 37840},
	{"HUNTERS", 7, 37841},
	{"ALLISON", 7, 37842},
	{"VBY", 3, 37843},
	{"CRASHES", 7, 37844},
	{"STAIRS", 6, 37845},
	{"OUTLINES", 8, 37846},
	{"STEROIDS", 8, 37847},
	{"RKWA", 4, 37848},
	{"POGO", 4, 37849},
	{"NYBO", 4, 37850},
	{"TRSQ", 4, 37851},
	{"ACTED", 5, 37852},
	{"RAPR", 4, 37853},
	{"KONICA", 6, 37854},
	{"HOTLINE", 7, 37855},
	{"AMPS", 4, 37856},
	{"BYRON", 5, 37857},
	{"PLYI", 4, 37858},
	{"LLSS", 4, 37859},
	{"CRITIQUE", 8, 37860},
	{"ACCOUNTANTS", 11, 37861},
	{"COEFFICIENT", 11, 37862},
	{"TRANSVESTITE", 12, 37863},
	{"NDWR", 4, 37864},
	{"UPSTREAM", 8, 37865},
	{"CONTINUATION", 12, 37866},
	{"CARNEGIE", 8, 37867},
	{"DIGG", 4, 37868},
	{"WHYD", 4, 37869},
	{"YFEE", 4, 37870},
	{"FALCON", 6, 37871},
	{"DUTC", 4, 37872},
	{"JOINTLY", 7, 37873},
	{"CANADIANS", 9, 37874},
	{"YFUN", 4, 37875},
	{"YCF", 3, 37876},
	{"OCED", 4, 37877},
	{"ELLR", 4, 37878},
	{"AVOIDED", 7, 37879},
	{"COMPRISING", 10, 37880},
	{"TICK", 4, 37881},
	{"LADYBOY", 7, 37882},
	{"TERRIER", 7, 37883},
	{"LISTENED", 8, 37884},
	{"OUPT", 4, 37885},
	{"EDMY", 4, 37886},
	{"EXPLANATIONS", 12, 37887},
	{"EVIR", 4, 37888},
	{"RENEWED", 7, 37889},
	{"RBOW", 4, 37890},
	{"OOKC", 4, 37891},
	{"HUSSEIN", 7, 37892},
	{"LDLE", 4, 37893},
	{"INCORPORATING", 13, 37894},
	{"VARIANT", 7, 37895},
	{"MEUN", 4, 37896},
	{"YOFR", 4, 37897},
	{"RILEY", 5, 37898},
	{"BIOCHEMISTRY", 12, 37899},
	{"DUPLICATION", 11, 37900},
	{"EQUATORIAL", 10, 37901},
	{"YSCA", 4, 37902},
	{"SEDIMENT", 8, 37903},
	{"TRANSLATORS", 11, 37904},
	{"FEXP", 4, 37905},
	{"SQUARES", 7, 37906},
	{"SCOTTSDALE", 10, 37907},
	{"NINJA", 5, 37908},
	{"AVALON", 6, 37909},
	{"RATL", 4, 37910},
	{"ENUP", 4, 37911},
	{"VOUCHER", 7, 37912},
	{"HONEYMOON", 9, 37913},
	{"PERCUSSION", 10, 37914},
	{"RDWO", 4, 37915},
	{"GLUE", 4, 37916},
	{"NFAV", 4, 37917},
	{"EADF", 4, 37918},
	{"TALF", 4, 37919},
	{"ECKI", 4, 37920},
	{"RCUI", 4, 37921},
	{"LMEM", 4, 37922},
	{"AKEW", 4, 37923},
	{"RNOW", 4, 37924},
	{"CKHO", 4, 37925},
	{"YAGR", 4, 37926},
	{"MYOF", 4, 37927},
	{"NFEC", 4, 37928},
	{"CKBE", 4, 37929},
	{"MARGINS", 7, 37930},
	{"YHEW", 4, 37931},
	{"SANDS", 5, 37932},
	{"SURVIVED", 8, 37933},
	{"NWEL", 4, 37934},
	{"SPINNING", 8, 37935},
	{"EPIDEMIOLOGY", 12, 37936},
	{"TWAL", 4, 37937},
	{"ORDC", 4, 37938},
	{"ADEQUATELY", 10, 37939},
	{"PENTAGON", 8, 37940},
	{"REOV", 4, 37941},
	{"SPECTRAL", 8, 37942},
	{"DIABETIC", 8, 37943},
	{"YEDO", 4, 37944},
	{"DYFO", 4, 37945},
	{"STRESSED", 8, 37946},
	{"LIBDEVEL", 8, 37947},
	{"UPSO", 4, 37948},
	{"PREVALENCE", 10, 37949},
	{"DOMINICA", 8, 37950},
	{"CONTAMINATED", 12, 37951},
	{"UBBE", 4, 37952},
	{"FINISHES", 8, 37953},
	{"YBUI", 4, 37954},
	{"LECTURER", 8, 37955},
	{"BIOMEDICAL", 10, 37956},
	{"EMBROIDERED", 11, 37957},
	{"UTPU", 4, 37958},
	{"VILS", 4, 37959},
	{"ESPU", 4, 37960},
	{"EPLI", 4, 37961},
	{"MEDU", 4, 37962},
	{"GAMEBOY", 7, 37963},
	{"MSUR", 4, 37964},
	{"COMMITS", 7, 37965},
	{"COBRA", 5, 37966},
	{"GQB", 3, 37967},
	{"SUBSET", 6, 37968},
	{"GUCCI", 5, 37969},
	{"ADAG", 4, 37970},
	{"THREW", 5, 37971},
	{"SUTTON", 6, 37972},
	{"DJIBOUTI", 8, 37973},
	{"HTTPS", 5, 37974},
	{"WEBSPHERE", 9, 37975},
	{"LDSH", 4, 37976},
	{"CHENEY", 6, 37977},
	{"TFLO", 4, 37978},
	{"OULE", 4, 37979},
	{"ZOMBIE", 6, 37980},
	{"FYTH", 4, 37981},
	{"AYDE", 4, 37982},
	{"NGBL", 4, 37983},
	{"OODD", 4, 37984},
	{"LKK", 3, 37985},
	{"DOFE", 4, 37986},
	{"NLIG", 4, 37987},
	{"RYCH", 4, 37988},
	{"DIEG", 4, 37989},
	{"KABL", 4, 37990},
	{"DECORATED", 9, 37991},
	{"RYAB", 4, 37992},
	{"CREDITED", 8, 37993},
	{"CHEROKEE", 8, 37994},
	{"ARDN", 4, 37995},
	{"RECYCLED", 8, 37996},
	{"YRED", 4, 37997},
	{"MEDH", 4, 37998},
	{"FOLLOWUP", 8, 37999},
	{"DBYJ", 4, 38000},
	{"SIMMONS", 7, 38001},
	{"GALS", 4, 38002},
	{"RART", 4, 38003},
	{"IDRE", 4, 38004},
	{"SUNL", 4, 38005},
	{"BIDDERS", 7, 38006},
	{"WHEREIN", 7, 38007},
	{"SIMULATOR", 9, 38008},
	{"APPEARANCES", 11, 38009},
	{"ICIZ", 4, 38010},
	{"PERFORMERS", 10, 38011},
	{"RTYP", 4, 38012},
	{"NLIV", 4, 38013},
	{"DISSERTATION", 12, 38014},
	{"EXPORTERS", 9, 38015},
	{"WALSH", 5, 38016},
	{"GCHI", 4, 38017},
	{"MUTANT", 6, 38018},
	{"ILOR", 4, 38019},
	{"HEMC", 4, 38020},
	{"CSCH", 4, 38021},
	{"DONR", 4, 38022},
	{"TWED", 4, 38023},
	{"GGRO", 4, 38024},
	{"BLANKETS", 8, 38025},
	{"LEYC", 4, 38026},
	{"CONFUSING", 9, 38027},
	{"ORJU", 4, 38028},
	{"CELEBRATIONS", 12, 38029},
	{"APPROACHING", 11, 38030},
	{"SPIRAL", 6, 38031},
	{"TBYA", 4, 38032},
	{"GOVERNORS", 9, 38033},
	{"AUTHORING", 9, 38034},
	{"SPECIALIZES", 11, 38035},
	{"WILLS", 5, 38036},
	{"NCEG", 4, 38037},
	{"KATHERINE", 9, 38038},
	{"ATOMS", 5, 38039},
	{"JACOBS", 6, 38040},
	{"MAURITANIA", 10, 38041},
	{"TISSUES", 7, 38042},
	{"REMINDED", 8, 38043},
	{"EWWE", 4, 38044},
	{"IRVINE", 6, 38045},
	{"ONGM", 4, 38046},
	{"DRAKE", 5, 38047},
	{"OLDS", 4, 38048},
	{"RAMP", 4, 38049},
	{"IALG", 4, 38050},
	{"JAKARTA", 7, 38051},
	{"CYNTHIA", 7, 38052},
	{"YCOR", 4, 38053},
	{"IPLO", 4, 38054},
	{"ILTY", 4, 38055},
	{"ROOSEVELT", 9, 38056},
	{"DDEP", 4, 38057},
	{"PRACTICING", 10, 38058},
	{"SCHMIDT", 7, 38059},
	{"NICELY", 6, 38060},
	{"YOFN", 4, 38061},
	{"EXPRESSING", 10, 38062},
	{"DELLA", 5, 38063},
	{"LAUREL", 6, 38064},
	{"UNOF", 4, 38065},
	{"CAROLYN", 7, 38066},
	{"RAILS", 5, 38067},
	{"PGSQL", 5, 38068},
	{"FRIED", 5, 38069},
	{"CAIRO", 5, 38070},
	{"AMBULANCE", 9, 38071},
	{"TRADED", 6, 38072},
	{"SIGNALING", 9, 38073},
	{"EBAD", 4, 38074},
	{"VIVO", 4, 38075},
	{"MALLS", 5, 38076},
	{"JENSEN", 6, 38077},
	{"NGGE", 4, 38078},
	{"ILDL", 4, 38079},
	{"CHORDS", 6, 38080},
	{"NLOV", 4, 38081},
	{"YFAM", 4, 38082},
	{"IMPAIRMENT", 10, 38083},
	{"YHOM", 4, 38084},
	{"SCOOTER", 7, 38085},
	{"GLEC", 4, 38086},
	{"DEDICATION", 10, 38087},
	{"DESIRES", 7, 38088},
	{"NDJE", 4, 38089},
	{"WOODY", 5, 38090},
	{"DISMISSED", 9, 38091},
	{"MCGRAW", 6, 38092},
	{"CHEERLEADER", 11, 38093},
	{"OLEF", 4, 38094},
	{"YKC", 3, 38095},
	{"ELDW", 4, 38096},
	{"LDSI", 4, 38097},
	{"IEFL", 4, 38098},
	{"CRIED", 5, 38099},
	{"PSYCHIC", 7, 38100},
	{"LLIP", 4, 38101},
	{"CRACKS", 6, 38102},
	{"CLET", 4, 38103},
	{"LOTION", 6, 38104},
	{"ANALYZING", 9, 38105},
	{"RINM", 4, 38106},
	{"SUBSTRATE", 9, 38107},
	{"KENB", 4, 38108},
	{"ESUG", 4, 38109},
	{"SINCERELY", 9, 38110},
	{"MMC", 3, 38111},
	{"RMOD", 4, 38112},
	{"NGVE", 4, 38113},
	{"RLDO", 4, 38114},
	{"TICM", 4, 38115},
	{"NSPL", 4, 38116},
	{"YPOI", 4, 38117},
	{"BEATEN", 6, 38118},
	{"PIERCING", 8, 38119},
	{"ERBL", 4, 38120},
	{"ASHANTI", 7, 38121},
	{"RSUE", 4, 38122},
	{"ANTILLES", 8, 38123},
	{"SJOB", 4, 38124},
	{"ELPA", 4, 38125},
	{"HOMEMADE", 8, 38126},
	{"UKRAINIAN", 9, 38127},
	{"ESTABLISHMENTS", 14, 38128},
	{"MARGINAL", 8, 38129},
	{"REMP", 4, 38130},
	{"VISIONS", 7, 38131},
	{"EFFICACY", 8, 38132},
	{"TCHW", 4, 38133},
	{"RGEP", 4, 38134},
	{"FRESHWATER", 10, 38135},
	{"WEKN", 4, 38136},
	{"TOPICAL", 7, 38137},
	{"PRESTIGE", 8, 38138},
	{"TEXC", 4, 38139},
	{"FWAT", 4, 38140},
	{"ACCELERATED", 11, 38141},
	{"YEDF", 4, 38142},
	{"PINNACLE", 8, 38143},
	{"TUCKER", 6, 38144},
	{"URFI", 4, 38145},
	{"TLYM", 4, 38146},
	{"RECOGNIZES", 10, 38147},
	{"PLUGS", 5, 38148},
	{"DOFO", 4, 38149},
	{"GUPA", 4, 38150},
	{"RESPONSIVE", 10, 38151},
	{"DFAI", 4, 38152},
	{"CODED", 5, 38153},
	{"SUPRA", 5, 38154},
	{"OMITTED", 7, 38155},
	{"NFIV", 4, 38156},
	{"MOLLY", 5, 38157},
	{"PROXIMITY", 9, 38158},
	{"WWHE", 4, 38159},
	{"OFCU", 4, 38160},
	{"BYPE", 4, 38161},
	{"ELME", 4, 38162},
	{"ALCATEL", 7, 38163},
	{"BELONGING", 9, 38164},
	{"UNBIASED", 8, 38165},
	{"PEAR", 4, 38166},
	{"SURINAME", 8, 38167},
	{"TBUI", 4, 38168},
	{"RSKI", 4, 38169},
	{"ECIV", 4, 38170},
	{"TLYL", 4, 38171},
	{"TSPL", 4, 38172},
	{"CHIEFS", 6, 38173},
	{"FRANZ", 5, 38174},
	{"LOFC", 4, 38175},
	{"GPRI", 4, 38176},
	{"LOGU", 4, 38177},
	{"COLLISION", 9, 38178},
	{"SUPPLEMENTARY", 13, 38179},
	{"GHOM", 4, 38180},
	{"FEAC", 4, 38181},
	{"EYOF", 4, 38182},
	{"RDME", 4, 38183},
	{"LUEO", 4, 38184},
	{"ZJU", 3, 38185},
	{"MVU", 3, 38186},
	{"BYMO", 4, 38187},
	{"REDN", 4, 38188},
	{"ARVI", 4, 38189},
	{"PARKWAY", 7, 38190},
	{"LSRE", 4, 38191},
	{"UTDE", 4, 38192},
	{"YFRE", 4, 38193},
	{"PALAU", 5, 38194},
	{"DUFF", 4, 38195},
	{"GEBU", 4, 38196},
	{"LODGES", 6, 38197},
	{"DANGERS", 7, 38198},
	{"ORJO", 4, 38199},
	{"OFEM", 4, 38200},
	{"BONUSES", 7, 38201},
	{"SCAM", 4, 38202},
	{"TRAVELLERS", 10, 38203},
	{"BIKING", 6, 38204},
	{"ERIZ", 4, 38205},
	{"DISCREPANCIES", 13, 38206},
	{"NOWF", 4, 38207},
	{"PIRATE", 6, 38208},
	{"FSER", 4, 38209},
	{"LBEG", 4, 38210},
	{"MICROSYSTEMS", 12, 38211},
	{"FHOW", 4, 38212},
	{"TIMEOUT", 7, 38213},
	{"SENSES", 6, 38214},
	{"AEROSMITH", 9, 38215},
	{"KSWE", 4, 38216},
	{"YTEL", 4, 38217},
	{"NBED", 4, 38218},
	{"NTYC", 4, 38219},
	{"REPEATS", 7, 38220},
	{"RESELLERS", 9, 38221},
	{"WILLIE", 6, 38222},
	{"PORTFOLIOS", 10, 38223},
	{"CEDF", 4, 38224},
	{"DONJ", 4, 38225},
	{"PPLA", 4, 38226},
	{"RGEC", 4, 38227},
	{"LFIS", 4, 38228},
	{"WAYH", 4, 38229},
	{"SLOWER", 6, 38230},
	{"SIMULATED", 9, 38231},
	{"CULINARY", 8, 38232},
	{"FAIRFAX", 7, 38233},
	{"BECK", 4, 38234},
	{"FFLE", 4, 38235},
	{"SEMANTICS", 9, 38236},
	{"DNTW", 4, 38237},
	{"RSUI", 4, 38238},
	{"ULIA", 4, 38239},
	{"SCARFACE", 8, 38240},
	{"ACCOUNTANT", 10, 38241},
	{"ORYF", 4, 38242},
	{"BEIGE", 5, 38243},
	{"AUDITING", 8, 38244},
	{"ROLEX", 5, 38245},
	{"PROPAGANDA", 10, 38246},
	{"AMPLIFIERS", 10, 38247},
	{"WATERLOO", 8, 38248},
	{"LDEA", 4, 38249},
	{"WARWICK", 7, 38250},
	{"COLI", 4, 38251},
	{"EXECUTABLE", 10, 38252},
	{"PENTAX", 6, 38253},
	{"FSPE", 4, 38254},
	{"RESTART", 7, 38255},
	{"ROUNDED", 7, 38256},
	{"BOARDING", 8, 38257},
	{"VANITY", 6, 38258},
	{"TALD", 4, 38259},
	{"RTYW", 4, 38260},
	{"LSOG", 4, 38261},
	{"MITIGATION", 10, 38262},
	{"PROF", 4, 38263},
	{"OVERSTOCK", 9, 38264},
	{"HOMER", 5, 38265},
	{"DAYLIGHT", 8, 38266},
	{"MACDONALD", 9, 38267},
	{"GASES", 5, 38268},
	{"YMIS", 4, 38269},
	{"DEPENDENCY", 10, 38270},
	{"DIOXIDE", 7, 38271},
	{"FIREWORKS", 9, 38272},
	{"EKLY", 4, 38273},
	{"GENUS", 5, 38274},
	{"APPROACHED", 10, 38275},
	{"CALH", 4, 38276},
	{"CATCHING", 8, 38277},
	{"YLIV", 4, 38278},
	{"EWSW", 4, 38279},
	{"CUTTER", 6, 38280},
	{"ORKB", 4, 38281},
	{"TPAY", 4, 38282},
	{"NCLI", 4, 38283},
	{"UTAC", 4, 38284},
	{"CONNECTS", 8, 38285},
	{"CKBU", 4, 38286},
	{"YINM", 4, 38287},
	{"LSMA", 4, 38288},
	{"TEDV", 4, 38289},
	{"CEAB", 4, 38290},
	{"UCHF", 4, 38291},
	{"EXPLORES", 8, 38292},
	{"DOFW", 4, 38293},
	{"ILIK", 4, 38294},
	{"LIBERALS", 8, 38295},
	{"XKL", 3, 38296},
	{"VESB", 4, 38297},
	{"EUPP", 4, 38298},
	{"APERTURE", 8, 38299},
	{"OBBE", 4, 38300},
	{"ROOFING", 7, 38301},
	{"DIXON", 5, 38302},
	{"DAFO", 4, 38303},
	{"ELASTIC", 7, 38304},
	{"MELODY", 6, 38305},
	{"PEFU", 4, 38306},
	{"IRBA", 4, 38307},
	{"THFU", 4, 38308},
	{"LEDL", 4, 38309},
	{"TORQUE", 6, 38310},
	{"RECALLS", 7, 38311},
	{"CONSULTATIONS", 13, 38312},
	{"OKOF", 4, 38313},
	{"MEMBERSHIPS", 11, 38314},
	{"DEBTS", 5, 38315},
	{"RENTING", 7, 38316},
	{"FREP", 4, 38317},
	{"ICANN", 5, 38318},
	{"TICKETMASTER", 12, 38319},
	{"CDC", 3, 38320},
	{"MERIDIA", 7, 38321},
	{"PHILLIP", 7, 38322},
	{"BURIAL", 6, 38323},
	{"BALCONY", 7, 38324},
	{"PRESCRIPTIONS", 13, 38325},
	{"DBEP", 4, 38326},
	{"EWJE", 4, 38327},
	{"PROP", 4, 38328},
	{"AVRIL", 5, 38329},
	{"RDEM", 4, 38330},
	{"WILLIS", 6, 38331},
	{"MYTHS", 5, 38332},
	{"CAMDEN", 6, 38333},
	{"WJER", 4, 38334},
	{"EAMP", 4, 38335},
	{"RDRA", 4, 38336},
	{"COUPLING", 8, 38337},
	{"YTUR", 4, 38338},
	{"KNEES", 5, 38339},
	{"ONCOLOGY", 8, 38340},
	{"NEGLECT", 7, 38341},
	{"NGDU", 4, 38342},
	{"FSTU", 4, 38343},
	{"WINCHESTER", 10, 38344},
	{"RYTI", 4, 38345},
	{"BYFO", 4, 38346},
	{"CLUTCH", 6, 38347},
	{"AYLI", 4, 38348},
	{"POETS", 5, 38349},
	{"WOVEN", 5, 38350},
	{"BLOGLINES", 9, 38351},
	{"AUDITORIUM", 10, 38352},
	{"EUPW", 4, 38353},
	{"PEDRO", 5, 38354},
	{"MAID", 4, 38355},
	{"HPRI", 4, 38356},
	{"CZU", 3, 38357},
	{"CARRIE", 6, 38358},
	{"UEBE", 4, 38359},
	{"HELU", 4, 38360},
	{"AUDIOSLAVE", 10, 38361},
	{"TOWELS", 6, 38362},
	{"UTAB", 4, 38363},
	{"WIKIMEDIA", 9, 38364},
	{"CANTERBURY", 10, 38365},
	{"LIPITOR", 7, 38366},
	{"REMODELING", 10, 38367},
	{"TRENT", 5, 38368},
	{"REDHAT", 6, 38369},
	{"BARBER", 6, 38370},
	{"INTUITIVE", 9, 38371},
	{"RYPA", 4, 38372},
	{"ILYH", 4, 38373},
	{"RIGID", 5, 38374},
	{"RADV", 4, 38375},
	{"DGEW", 4, 38376},
	{"SAPL", 4, 38377},
	{"MIFI", 4, 38378},
	{"OMUN", 4, 38379},
	{"OLDD", 4, 38380},
	{"RGEW", 4, 38381},
	{"ARWE", 4, 38382},
	{"DEGRADATION", 11, 38383},
	{"FFOU", 4, 38384},
	{"YWU", 3, 38385},
	{"YMK", 3, 38386},
	{"XYR", 3, 38387},
	{"ORTHODOX", 8, 38388},
	{"ASWR", 4, 38389},
	{"FERGUSON", 8, 38390},
	{"COORDINATING", 12, 38391},
	{"HOLISTIC", 8, 38392},
	{"SALSA", 5, 38393},
	{"SFLO", 4, 38394},
	{"FRAGMENTS", 9, 38395},
	{"ENCARTA", 7, 38396},
	{"MARIANA", 7, 38397},
	{"QUALITATIVE", 11, 38398},
	{"NJAM", 4, 38399},
	{"NYPR", 4, 38400},
	{"WNWI", 4, 38401},
	{"SDRO", 4, 38402},
	{"CLAUDE", 6, 38403},
	{"PBUT", 4, 38404},
	{"MINORITIES", 10, 38405},
	{"CHILDCARE", 9, 38406},
	{"DVR", 3, 38407},
	{"SMOU", 4, 38408},
	{"BLOWN", 5, 38409},
	{"DIFFUSION", 9, 38410},
	{"BATON", 5, 38411},
	{"YADD", 4, 38412},
	{"POLYNESIA", 9, 38413},
	{"BARTON", 6, 38414},
	{"UMBRELLA", 8, 38415},
	{"SOUNDTRACKS", 11, 38416},
	{"NAPSTER", 7, 38417},
	{"SSFR", 4, 38418},
	{"RODS", 4, 38419},
	{"WONG", 4, 38420},
	{"LBEP", 4, 38421},
	{"STIMULATION", 11, 38422},
	{"ABBEY", 5, 38423},
	{"PIGS", 4, 38424},
	{"DEBUGGING", 9, 38425},
	{"OLIVIA", 6, 38426},
	{"RECHARGEABLE", 12, 38427},
	{"ENGINEERED", 10, 38428},
	{"TSGR", 4, 38429},
	{"JERSEYS", 7, 38430},
	{"DPRA", 4, 38431},
	{"CEWO", 4, 38432},
	{"STRAPS", 6, 38433},
	{"MAYA", 4, 38434},
	{"LANCASHIRE", 10, 38435},
	{"RSAW", 4, 38436},
	{"SUPERSTORE", 10, 38437},
	{"IUMS", 4, 38438},
	{"STAINED", 7, 38439},
	{"MARITAL", 7, 38440},
	{"SOCIALIST", 9, 38441},
	{"ARPO", 4, 38442},
	{"KCON", 4, 38443},
	{"DEDD", 4, 38444},
	{"BRUNO", 5, 38445},
	{"ATTRACTED", 9, 38446},
	{"UNDERTAKING", 11, 38447},
	{"TBIL", 4, 38448},
	{"UUD", 3, 38449},
	{"NOTWITHSTANDING", 15, 38450},
	{"RBAT", 4, 38451},
	{"BLOGROLL", 8, 38452},
	{"EVITE", 5, 38453},
	{"EEPR", 4, 38454},
	{"FEASIBLE", 8, 38455},
	{"ROMANS", 6, 38456},
	{"NBRE", 4, 38457},
	{"MICRONESIA", 10, 38458},
	{"FMUS", 4, 38459},
	{"SHORES", 6, 38460},
	{"CKDO", 4, 38461},
	{"THAMES", 6, 38462},
	{"TBLA", 4, 38463},
	{"FLOWING", 7, 38464},
	{"DREAMWEAVER", 11, 38465},
	{"DIETS", 5, 38466},
	{"YERT", 4, 38467},
	{"DEED", 4, 38468},
	{"KMAR", 4, 38469},
	{"EWLY", 4, 38470},
	{"NMIC", 4, 38471},
	{"YPOP", 4, 38472},
	{"VEAF", 4, 38473},
	{"PTIV", 4, 38474},
	{"URGI", 4, 38475},
	{"WHOG", 4, 38476},
	{"RRID", 4, 38477},
	{"RAPO", 4, 38478},
	{"SAUNA", 5, 38479},
	{"FBOT", 4, 38480},
	{"WHIRLPOOL", 9, 38481},
	{"PERFUMES", 8, 38482},
	{"RDEP", 4, 38483},
	{"SWOM", 4, 38484},
	{"NKAB", 4, 38485},
	{"KEAB", 4, 38486},
	{"BAUER", 5, 38487},
	{"ELIMINATING", 11, 38488},
	{"REJECTION", 9, 38489},
	{"GHOW", 4, 38490},
	{"EWUP", 4, 38491},
	{"ROGA", 4, 38492},
	{"MULTIPLAYER", 11, 38493},
	{"CAICOS", 6, 38494},
	{"ODYA", 4, 38495},
	{"BOWLS", 5, 38496},
	{"QAEDA", 5, 38497},
	{"OLFO", 4, 38498},
	{"DISSEMINATION", 13, 38499},
	{"RYFI", 4, 38500},
	{"GCLA", 4, 38501},
	{"ATMU", 4, 38502},
	{"CARDINALS", 9, 38503},
	{"OTYP", 4, 38504},
	{"KITTS", 5, 38505},
	{"SUIC", 4, 38506},
	{"COSMIC", 6, 38507},
	{"LSPO", 4, 38508},
	{"DAWSON", 6, 38509},
	{"NGWR", 4, 38510},
	{"OFCI", 4, 38511},
	{"DEFECTIVE", 9, 38512},
	{"DELETION", 8, 38513},
	{"LENGTHS", 7, 38514},
	{"HBOU", 4, 38515},
	{"EALP", 4, 38516},
	{"HOOVER", 6, 38517},
	{"FFRA", 4, 38518},
	{"MACAU", 5, 38519},
	{"BYMI", 4, 38520},
	{"ZUY", 3, 38521},
	{"ELECTIVE", 8, 38522},
	{"EFTF", 4, 38523},
	{"FORENSIC", 8, 38524},
	{"BRAV", 4, 38525},
	{"YINP", 4, 38526},
	{"AGGI", 4, 38527},
	{"EROV", 4, 38528},
	{"ZFU", 3, 38529},
	{"BOTANICAL", 9, 38530},
	{"DIFT", 4, 38531},
	{"QUARTET", 7, 38532},
	{"LYTI", 4, 38533},
	{"MUDVAYNE", 8, 38534},
	{"UDIC", 4, 38535},
	{"RLYE", 4, 38536},
	{"CERAMICS", 8, 38537},
	{"SUSPENSE", 8, 38538},
	{"DRAFTING", 8, 38539},
	{"OCKB", 4, 38540},
	{"OBSERVING", 9, 38541},
	{"FREESTYLE", 9, 38542},
	{"ILYC", 4, 38543},
	{"ADVERTISED", 10, 38544},
	{"COMMENCEMENT", 12, 38545},
	{"SOUTHWESTERN", 12, 38546},
	{"CONFORM", 7, 38547},
	{"HELMETS", 7, 38548},
	{"FWHE", 4, 38549},
	{"DFAL", 4, 38550},
	{"RBIN", 4, 38551},
	{"ARTP", 4, 38552},
	{"ORGANIZERS", 10, 38553},
	{"FIRING", 6, 38554},
	{"SMARTPHONE", 10, 38555},
	{"RCRI", 4, 38556},
	{"CMD", 3, 38557},
	{"FHUM", 4, 38558},
	{"GHPR", 4, 38559},
	{"IFFS", 4, 38560},
	{"VEUS", 4, 38561},
	{"HIMP", 4, 38562},
	{"UCHW", 4, 38563},
	{"DENISE", 6, 38564},
	{"PSAR", 4, 38565},
	{"EFOC", 4, 38566},
	{"HYPERTENSION", 12, 38567},
	{"SEARCHABLE", 10, 38568},
	{"LINW", 4, 38569},
	{"GERH", 4, 38570},
	{"TOUCHING", 8, 38571},
	{"AGUILERA", 8, 38572},
	{"RLYW", 4, 38573},
	{"VACANCY", 7, 38574},
	{"SERVICING", 9, 38575},
	{"USCL", 4, 38576},
	{"GEDH", 4, 38577},
	{"PAPA", 4, 38578},
	{"RFAI", 4, 38579},
	{"SETTLEMENTS", 11, 38580},
	{"STRAWBERRY", 10, 38581},
	{"CHANG", 5, 38582},
	{"GLORIA", 6, 38583},
	{"COUNSELLING", 11, 38584},
	{"PUPIL", 5, 38585},
	{"KETW", 4, 38586},
	{"EFLI", 4, 38587},
	{"NBLO", 4, 38588},
	{"DTEC", 4, 38589},
	{"FEAST", 5, 38590},
	{"ECARDS", 6, 38591},
	{"GUNI", 4, 38592},
	{"AXPA", 4, 38593},
	{"MAGGIE", 6, 38594},
	{"YFOL", 4, 38595},
	{"REDEMPTION", 10, 38596},
	{"SBYA", 4, 38597},
	{"KTOP", 4, 38598},
	{"CANTON", 6, 38599},
	{"ACURA", 5, 38600},
	{"REGISTERING", 11, 38601},
	{"AWEL", 4, 38602},
	{"CEYO", 4, 38603},
	{"CONSERVATIVES", 13, 38604},
	{"CLIT", 4, 38605},
	{"ACHF", 4, 38606},
	{"YINW", 4, 38607},
	{"RUCE", 4, 38608},
	{"BONNIE", 6, 38609},
	{"LAYING", 6, 38610},
	{"COPS", 4, 38611},
	{"VEEX", 4, 38612},
	{"PROVISIONAL", 11, 38613},
	{"COMPILING", 9, 38614},
	{"WOCO", 4, 38615},
	{"FEDEX", 5, 38616},
	{"RYMU", 4, 38617},
	{"XIMU", 4, 38618},
	{"ODYO", 4, 38619},
	{"STRIVE", 6, 38620},
	{"RERU", 4, 38621},
	{"SNOWBOARDING", 12, 38622},
	{"RELEASING", 9, 38623},
	{"AREJ", 4, 38624},
	{"ORTM", 4, 38625},
	{"LASERJET", 8, 38626},
	{"MARTINIQUE", 10, 38627},
	{"SHELLS", 6, 38628},
	{"LDTR", 4, 38629},
	{"FHIG", 4, 38630},
	{"SCLU", 4, 38631},
	{"COOKER", 6, 38632},
	{"LEAGUES", 7, 38633},
	{"LOFM", 4, 38634},
	{"MONKEYS", 7, 38635},
	{"TGUA", 4, 38636},
	{"LEGO", 4, 38637},
	{"TRANSITIONS", 11, 38638},
	{"PREVENTED", 9, 38639},
	{"DIGITS", 6, 38640},
	{"FLOA", 4, 38641},
	{"ANCR", 4, 38642},
	{"FULI", 4, 38643},
	{"EYLE", 4, 38644},
	{"LREM", 4, 38645},
	{"EASIEST", 7, 38646},
	{"MICROBIOLOGY", 12, 38647},
	{"INTERNSHIPS", 11, 38648},
	{"BAMBOO", 6, 38649},
	{"AJOB", 4, 38650},
	{"DENOTES", 7, 38651},
	{"TACR", 4, 38652},
	{"LAFT", 4, 38653},
	{"COMMUNICATING", 13, 38654},
	{"YSOL", 4, 38655},
	{"VECTORS", 7, 38656},
	{"DOFR", 4, 38657},
	{"DECKS", 5, 38658},
	{"CRAIGSLIST", 10, 38659},
	{"VIBRATION", 9, 38660},
	{"STEPPED", 7, 38661},
	{"BLUNT", 5, 38662},
	{"MBED", 4, 38663},
	{"PROTECTOR", 9, 38664},
	{"HAMAS", 5, 38665},
	{"MEEX", 4, 38666},
	{"EADR", 4, 38667},
	{"CHBU", 4, 38668},
	{"ODDE", 4, 38669},
	{"GCAM", 4, 38670},
	{"IRTR", 4, 38671},
	{"UNDERSTANDS", 11, 38672},
	{"ACOB", 4, 38673},
	{"RREF", 4, 38674},
	{"RISES", 5, 38675},
	{"JORC", 4, 38676},
	{"ISSUING", 7, 38677},
	{"ESJU", 4, 38678},
	{"HEATERS", 7, 38679},
	{"URLE", 4, 38680},
	{"ACCENTS", 7, 38681},
	{"IMFO", 4, 38682},
	{"LREG", 4, 38683},
	{"INSANE", 6, 38684},
	{"BUDDHA", 6, 38685},
	{"VOYAGE", 6, 38686},
	{"RDF", 3, 38687},
	{"LERC", 4, 38688},
	{"DOND", 4, 38689},
	{"ILOF", 4, 38690},
	{"UADR", 4, 38691},
	{"DGUI", 4, 38692},
	{"EVIV", 4, 38693},
	{"COLONEL", 7, 38694},
	{"TRANSITIONAL", 12, 38695},
	{"MOZART", 6, 38696},
	{"ACCELERATION", 12, 38697},
	{"SKETCH", 6, 38698},
	{"HOFFMAN", 7, 38699},
	{"LFCO", 4, 38700},
	{"LIZI", 4, 38701},
	{"BERF", 4, 38702},
	{"BALANCES", 8, 38703},
	{"FIREARMS", 8, 38704},
	{"YREV", 4, 38705},
	{"NIGHTLY", 7, 38706},
	{"REUP", 4, 38707},
	{"VISUALIZATION", 13, 38708},
	{"NMID", 4, 38709},
	{"XTUR", 4, 38710},
	{"EEDG", 4, 38711},
	{"DEDUCTION", 9, 38712},
	{"UPIE", 4, 38713},
	{"RFER", 4, 38714},
	{"MESR", 4, 38715},
	{"LLEX", 4, 38716},
	{"COATS", 5, 38717},
	{"MKY", 3, 38718},
	{"AYSG", 4, 38719},
	{"ORTP", 4, 38720},
	{"UCIA", 4, 38721},
	{"ORSD", 4, 38722},
	{"IREB", 4, 38723},
	{"LYDU", 4, 38724},
	{"CAPSULES", 8, 38725},
	{"KLAH", 4, 38726},
	{"HYDE", 4, 38727},
	{"RFAR", 4, 38728},
	{"AWKS", 4, 38729},
	{"ARPL", 4, 38730},
	{"ARAF", 4, 38731},
	{"PURSUING", 8, 38732},
	{"NEWSWIRE", 8, 38733},
	{"VEFA", 4, 38734},
	{"SPERMSHACK", 10, 38735},
	{"NIMU", 4, 38736},
	{"MUGS", 4, 38737},
	{"BROKERAGE", 9, 38738},
	{"UELA", 4, 38739},
	{"IRLY", 4, 38740},
	{"AFUN", 4, 38741},
	{"WASHED", 6, 38742},
	{"PTOR", 4, 38743},
	{"OVERTIME", 8, 38744},
	{"STAIND", 6, 38745},
	{"YSFO", 4, 38746},
	{"RESONANCE", 9, 38747},
	{"MOSAIC", 6, 38748},
	{"RHODES", 6, 38749},
	{"FIESTA", 6, 38750},
	{"EEDB", 4, 38751},
	{"SOURCING", 8, 38752},
	{"ADYA", 4, 38753},
	{"YRUN", 4, 38754},
	{"FILINGS", 7, 38755},
	{"FORCING", 7, 38756},
	{"NGIM", 4, 38757},
	{"RFOL", 4, 38758},
	{"QUIV", 4, 38759},
	{"FAIRS", 5, 38760},
	{"FLUTE", 5, 38761},
	{"DLOV", 4, 38762},
	{"DURABILITY", 10, 38763},
	{"BOEING", 6, 38764},
	{"SIZING", 6, 38765},
	{"CEBY", 4, 38766},
	{"EXCEEDED", 8, 38767},
	{"LTRE", 4, 38768},
	{"MEADOWS", 7, 38769},
	{"KECA", 4, 38770},
	{"HINDI", 5, 38771},
	{"NJAP", 4, 38772},
	{"TLAW", 4, 38773},
	{"PRESLEY", 7, 38774},
	{"NBAL", 4, 38775},
	{"GODSMACK", 8, 38776},
	{"DLOW", 4, 38777},
	{"CWAS", 4, 38778},
	{"DAUT", 4, 38779},
	{"LABELING", 8, 38780},
	{"LDED", 4, 38781},
	{"SUBSTITUTION", 12, 38782},
	{"WHOIS", 5, 38783},
	{"BURMA", 5, 38784},
	{"DESERVES", 8, 38785},
	{"TGOV", 4, 38786},
	{"UNGP", 4, 38787},
	{"ABOARD", 6, 38788},
	{"PARADIGM", 8, 38789},
	{"IRVING", 6, 38790},
	{"PERFECTION", 10, 38791},
	{"DBYN", 4, 38792},
	{"LOWF", 4, 38793},
	{"EPLY", 4, 38794},
	{"JOINTS", 6, 38795},
	{"LINGUISTICS", 11, 38796},
	{"SNMP", 4, 38797},
	{"STANDARDIZED", 12, 38798},
	{"RBOO", 4, 38799},
	{"IFYT", 4, 38800},
	{"POLES", 5, 38801},
	{"RTSM", 4, 38802},
	{"BOUNDS", 6, 38803},
	{"ORSB", 4, 38804},
	{"LYON", 4, 38805},
	{"NUTRIENTS", 9, 38806},
	{"KOSOVO", 6, 38807},
	{"SANTIAGO", 8, 38808},
	{"VERA", 4, 38809},
	{"EPAG", 4, 38810},
	{"LYOP", 4, 38811},
	{"ADVISING", 8, 38812},
	{"NACR", 4, 38813},
	{"DEVILS", 6, 38814},
	{"RATC", 4, 38815},
	{"OOKW", 4, 38816},
	{"AMWH", 4, 38817},
	{"EUROPA", 6, 38818},
	{"OODY", 4, 38819},
	{"LDIT", 4, 38820},
	{"YBUS", 4, 38821},
	{"BARBUDA", 7, 38822},
	{"IRPL", 4, 38823},
	{"WONDERED", 8, 38824},
	{"CHESHIRE", 8, 38825},
	{"BOYD", 4, 38826},
	{"LSBE", 4, 38827},
	{"SLIDING", 7, 38828},
	{"DESCRIPTIVE", 11, 38829},
	{"FEASIBILITY", 11, 38830},
	{"NICKELBACK", 10, 38831},
	{"NEGOTIATING", 11, 38832},
	{"ELPF", 4, 38833},
	{"PIER", 4, 38834},
	{"ALSB", 4, 38835},
	{"RTWH", 4, 38836},
	{"SIOUX", 5, 38837},
	{"LLRO", 4, 38838},
	{"PREMIUMS", 8, 38839},
	{"JENNA", 5, 38840},
	{"FBRI", 4, 38841},
	{"BBIN", 4, 38842},
	{"ARRAYS", 6, 38843},
	{"LUTHERAN", 8, 38844},
	{"OFPI", 4, 38845},
	{"ZYU", 3, 38846},
	{"SYLLABUS", 8, 38847},
	{"RGB", 3, 38848},
	{"FELLOWS", 7, 38849},
	{"LHAR", 4, 38850},
	{"RIAB", 4, 38851},
	{"VALENCIA", 8, 38852},
	{"SUPERMAN", 8, 38853},
	{"KSWH", 4, 38854},
	{"RODRIGUEZ", 9, 38855},
	{"PERKINS", 7, 38856},
	{"RLEV", 4, 38857},
	{"ANIMATIONS", 10, 38858},
	{"OFFB", 4, 38859},
	{"IDEALLY", 7, 38860},
	{"ONMU", 4, 38861},
	{"EXTF", 4, 38862},
	{"ACTIVISM", 8, 38863},
	{"SPLASH", 6, 38864},
	{"RREM", 4, 38865},
	{"FARGO", 5, 38866},
	{"EXTW", 4, 38867},
	{"OWAY", 4, 38868},
	{"CHAIRPERSON", 11, 38869},
	{"YLAS", 4, 38870},
	{"RKAT", 4, 38871},
	{"YLIT", 4, 38872},
	{"SBOU", 4, 38873},
	{"REGED", 5, 38874},
	{"LEVERAGE", 8, 38875},
	{"PROBATION", 9, 38876},
	{"GRAN", 4, 38877},
	{"COMMISSIONED", 12, 38878},
	{"RPJ", 3, 38879},
	{"HEDGE", 5, 38880},
	{"FEWD", 4, 38881},
	{"ANGUILLA", 8, 38882},
	{"FENDER", 6, 38883},
	{"VIOLET", 6, 38884},
	{"DANCERS", 7, 38885},
	{"MUTATION", 8, 38886},
	{"OFOC", 4, 38887},
	{"RADISSON", 8, 38888},
	{"EWPR", 4, 38889},
	{"ALLE", 4, 38890},
	{"COMPULSORY", 10, 38891},
	{"WHOU", 4, 38892},
	{"HITLER", 6, 38893},
	{"LATU", 4, 38894},
	{"HANDSET", 7, 38895},
	{"HUMB", 4, 38896},
	{"DLEE", 4, 38897},
	{"PREPARATIONS", 12, 38898},
	{"MAXWELL", 7, 38899},
	{"ILLUSTRATES", 11, 38900},
	{"INHERITANCE", 11, 38901},
	{"UFFA", 4, 38902},
	{"CURRY", 5, 38903},
	{"VULNERABILITIES", 15, 38904},
	{"RFIV", 4, 38905},
	{"ERYY", 4, 38906},
	{"BYHA", 4, 38907},
	{"OBLIQUE", 7, 38908},
	{"PEARLS", 6, 38909},
	{"ZEDI", 4, 38910},
	{"WORMS", 5, 38911},
	{"YSEV", 4, 38912},
	{"PALESTINIANS", 12, 38913},
	{"GSUP", 4, 38914},
	{"SCEL", 4, 38915},
	{"AYSD", 4, 38916},
	{"RBUR", 4, 38917},
	{"SATISFYING", 10, 38918},
	{"LDAP", 4, 38919},
	{"SUCCEEDED", 9, 38920},
	{"PREREQUISITES", 13, 38921},
	{"TRAR", 4, 38922},
	{"MAINTAINER", 10, 38923},
	{"ADIV", 4, 38924},
	{"CUSI", 4, 38925},
	{"APPLES", 6, 38926},
	{"DEWEY", 5, 38927},
	{"SURVIVING", 9, 38928},
	{"POUCH", 5, 38929},
	{"ADVENT", 6, 38930},
	{"PROPOSES", 8, 38931},
	{"IPER", 4, 38932},
	{"HOOKS", 5, 38933},
	{"EXPLOITATION", 12, 38934},
	{"PEDH", 4, 38935},
	{"SINGERS", 7, 38936},
	{"NEBY", 4, 38937},
	{"ONGK", 4, 38938},
	{"MAYO", 4, 38939},
	{"RASW", 4, 38940},
	{"TASMANIA", 8, 38941},
	{"RDOW", 4, 38942},
	{"VYJ", 3, 38943},
	{"DKEE", 4, 38944},
	{"EDQU", 4, 38945},
	{"RYWO", 4, 38946},
	{"BENQ", 4, 38947},
	{"OCUT", 4, 38948},
	{"SURRENDER", 9, 38949},
	{"SCHNEIDER", 9, 38950},
	{"TEFU", 4, 38951},
	{"LWU", 3, 38952},
	{"DJV", 3, 38953},
	{"AIDL", 4, 38954},
	{"ARSENAL", 7, 38955},
	{"DUB", 3, 38956},
	{"SCREWS", 6, 38957},
	{"PYRAMID", 7, 38958},
	{"ENJOYS", 6, 38959},
	{"BUYE", 4, 38960},
	{"JORS", 4, 38961},
	{"YCRI", 4, 38962},
	{"EGAV", 4, 38963},
	{"HACKING", 7, 38964},
	{"OBEU", 4, 38965},
	{"STRIPE", 6, 38966},
	{"KNOXVILLE", 9, 38967},
	{"PLOM", 4, 38968},
	{"AVERAGES", 8, 38969},
	{"XPAY", 4, 38970},
	{"PEAKS", 5, 38971},
	{"NGCU", 4, 38972},
	{"VESM", 4, 38973},
	{"EYWH", 4, 38974},
	{"RAMT", 4, 38975},
	{"COMO", 4, 38976},
	{"YSLO", 4, 38977},
	{"OFIM", 4, 38978},
	{"LISP", 4, 38979},
	{"LIMOUSINE", 9, 38980},
	{"CHURCHILL", 9, 38981},
	{"SDAU", 4, 38982},
	{"IMWI", 4, 38983},
	{"DQV", 3, 38984},
	{"MENTORING", 9, 38985},
	{"NSBY", 4, 38986},
	{"DALM", 4, 38987},
	{"ZERS", 4, 38988},
	{"AFFIRMATIVE", 11, 38989},
	{"ARUS", 4, 38990},
	{"KEYNOTE", 7, 38991},
	{"IRWI", 4, 38992},
	{"AIDR", 4, 38993},
	{"USBU", 4, 38994},
	{"DIDNT", 5, 38995},
	{"CLASSROOMS", 10, 38996},
	{"CRIF", 4, 38997},
	{"PLANTED", 7, 38998},
	{"PETITIONER", 10, 38999},
	{"VEDU", 4, 39000},
	{"DDIC", 4, 39001},
	{"LCLA", 4, 39002},
	{"RESIDENCY", 9, 39003},
	{"BOMBS", 5, 39004},
	{"NICHE", 5, 39005},
	{"CYIN", 4, 39006},
	{"DEADLINES", 9, 39007},
	{"REWU", 4, 39008},
	{"LDSU", 4, 39009},
	{"TTRU", 4, 39010},
	{"TWEW", 4, 39011},
	{"EYPR", 4, 39012},
	{"CIGAR", 5, 39013},
	{"EOFV", 4, 39014},
	{"CKHE", 4, 39015},
	{"ARSU", 4, 39016},
	{"CALCULATING", 11, 39017},
	{"TCHF", 4, 39018},
	{"LCRI", 4, 39019},
	{"AYLE", 4, 39020},
	{"ELDB", 4, 39021},
	{"BERKSHIRE", 9, 39022},
	{"ELPR", 4, 39023},
	{"BOOKSHOP", 8, 39024},
	{"PROPORTIONAL", 12, 39025},
	{"GHFO", 4, 39026},
	{"CREDENTIALS", 11, 39027},
	{"RZL", 3, 39028},
	{"AYPA", 4, 39029},
	{"AMPT", 4, 39030},
	{"DEPRECATED", 10, 39031},
	{"MUNICIPALITIES", 14, 39032},
	{"UPFR", 4, 39033},
	{"EDOG", 4, 39034},
	{"PTFO", 4, 39035},
	{"UALF", 4, 39036},
	{"ESUF", 4, 39037},
	{"LOCKER", 6, 39038},
	{"JENKINS", 7, 39039},
	{"SQUASH", 6, 39040},
	{"MTHR", 4, 39041},
	{"GESP", 4, 39042},
	{"NYYE", 4, 39043},
	{"SPOTTED", 7, 39044},
	{"CURSE", 5, 39045},
	{"PMAN", 4, 39046},
	{"AJAX", 4, 39047},
	{"SCUT", 4, 39048},
	{"EDPU", 4, 39049},
	{"LCHI", 4, 39050},
	{"COCONUT", 7, 39051},
	{"CONDUCTOR", 9, 39052},
	{"DEDL", 4, 39053},
	{"LEEX", 4, 39054},
	{"LIBERATION", 10, 39055},
	{"FOREX", 5, 39056},
	{"LBEN", 4, 39057},
	{"DIAGNOSTICS", 11, 39058},
	{"REMOVES", 7, 39059},
	{"LLOS", 4, 39060},
	{"YVL", 3, 39061},
	{"EELL", 4, 39062},
	{"LUXURIOUS", 9, 39063},
	{"RYME", 4, 39064},
	{"RINL", 4, 39065},
	{"DREAMCAST", 9, 39066},
	{"TUMORS", 6, 39067},
	{"BOOKED", 6, 39068},
	{"INDIRECTLY", 10, 39069},
	{"ULNE", 4, 39070},
	{"UTIC", 4, 39071},
	{"MEOR", 4, 39072},
	{"LUMBER", 6, 39073},
	{"KYOCERA", 7, 39074},
	{"OCKH", 4, 39075},
	{"PILLOWS", 7, 39076},
	{"AYSR", 4, 39077},
	{"DCLE", 4, 39078},
	{"RDPA", 4, 39079},
	{"PORTALS", 7, 39080},
	{"DHOP", 4, 39081},
	{"YGD", 3, 39082},
	{"ILLUSTRATOR", 11, 39083},
	{"TIQU", 4, 39084},
	{"LYDR", 4, 39085},
	{"NFAL", 4, 39086},
	{"ULOF", 4, 39087},
	{"POTASSIUM", 9, 39088},
	{"PROMPTED", 8, 39089},
	{"VEFI", 4, 39090},
	{"EAMF", 4, 39091},
	{"EYGO", 4, 39092},
	{"NUDES", 5, 39093},
	{"RATIONALE", 9, 39094},
	{"NDVO", 4, 39095},
	{"HUBS", 4, 39096},
	{"PASADENA", 8, 39097},
	{"ABNORMAL", 8, 39098},
	{"BISSAU", 6, 39099},
	{"FHIM", 4, 39100},
	{"MYLI", 4, 39101},
	{"DUTI", 4, 39102},
	{"SUBWAY", 6, 39103},
	{"OULI", 4, 39104},
	{"EWBU", 4, 39105},
	{"MCAN", 4, 39106},
	{"LIFTED", 6, 39107},
	{"MANKIND", 7, 39108},
	{"RLYF", 4, 39109},
	{"DSKI", 4, 39110},
	{"EDEG", 4, 39111},
	{"NCRO", 4, 39112},
	{"FGETS", 5, 39113},
	{"CITRUS", 6, 39114},
	{"UCKA", 4, 39115},
	{"IKEF", 4, 39116},
	{"YTAL", 4, 39117},
	{"LCOR", 4, 39118},
	{"PARAMOUNT", 9, 39119},
	{"IDWH", 4, 39120},
	{"KESW", 4, 39121},
	{"TADV", 4, 39122},
	{"UPRIGHT", 7, 39123},
	{"RSBA", 4, 39124},
	{"USPI", 4, 39125},
	{"RDAR", 4, 39126},
	{"EIRV", 4, 39127},
	{"GBEC", 4, 39128},
	{"ELDG", 4, 39129},
	{"BREAKFASTS", 10, 39130},
	{"TPOW", 4, 39131},
	{"INSPECTORS", 10, 39132},
	{"EMERGENCIES", 11, 39133},
	{"REUSE", 5, 39134},
	{"ERNEST", 6, 39135},
	{"YOUO", 4, 39136},
	{"NDKA", 4, 39137},
	{"GUNT", 4, 39138},
	{"FWIN", 4, 39139},
	{"SIGHTSEEING", 11, 39140},
	{"DCLI", 4, 39141},
	{"SHOCKED", 7, 39142},
	{"THERAPIES", 9, 39143},
	{"RYHI", 4, 39144},
	{"ALCOHOLIC", 9, 39145},
	{"BAKERY", 6, 39146},
	{"LIEUTENANT", 10, 39147},
	{"ORCHID", 6, 39148},
	{"YAMO", 4, 39149},
	{"DOWH", 4, 39150},
	{"DGOV", 4, 39151},
	{"HISTORIES", 9, 39152},
	{"LOSES", 5, 39153},
	{"WIDGET", 6, 39154},
	{"RSIX", 4, 39155},
	{"RENAULT", 7, 39156},
	{"ATKINS", 6, 39157},
	{"VARIABILITY", 11, 39158},
	{"COMOROS", 7, 39159},
	{"OMYA", 4, 39160},
	{"UTBA", 4, 39161},
	{"SUEDE", 5, 39162},
	{"RHOL", 4, 39163},
	{"NTYP", 4, 39164},
	{"CIZE", 4, 39165},
	{"ZABE", 4, 39166},
	{"OBSERVATORY", 11, 39167},
	{"ECOD", 4, 39168},
	{"WAITED", 6, 39169},
	{"PREVENTIVE", 10, 39170},
	{"RCLO", 4, 39171},
	{"KEFO", 4, 39172},
	{"PEACH", 5, 39173},
	{"DMOD", 4, 39174},
	{"CALCULUS", 8, 39175},
	{"STEFAN", 6, 39176},
	{"USBE", 4, 39177},
	{"UCHH", 4, 39178},
	{"UALM", 4, 39179},
	{"GIBL", 4, 39180},
	{"SELECTOR", 8, 39181},
	{"DIAPER", 6, 39182},
	{"DUNN", 4, 39183},
	{"HOTWIRE", 7, 39184},
	{"SMILING", 7, 39185},
	{"YREN", 4, 39186},
	{"DISB", 4, 39187},
	{"ADYH", 4, 39188},
	{"OUNCES", 6, 39189},
	{"REJO", 4, 39190},
	{"RTRU", 4, 39191},
	{"QBB", 3, 39192},
	{"INDW", 4, 39193},
	{"UNCUT", 5, 39194},
	{"VENL", 4, 39195},
	{"GFIR", 4, 39196},
	{"NOTING", 6, 39197},
	{"SHIFTING", 8, 39198},
	{"SAMURAI", 7, 39199},
	{"EYLO", 4, 39200},
	{"FTWI", 4, 39201},
	{"RSEW", 4, 39202},
	{"RFIL", 4, 39203},
	{"MOINES", 6, 39204},
	{"SUBTOTAL", 8, 39205},
	{"COEFFICIENTS", 12, 39206},
	{"DUPLEX", 6, 39207},
	{"MVP", 3, 39208},
	{"DELEGATE", 8, 39209},
	{"NEGOTIATED", 10, 39210},
	{"LYIF", 4, 39211},
	{"ANALYZER", 8, 39212},
	{"IMOU", 4, 39213},
	{"BYNO", 4, 39214},
	{"HERMAN", 6, 39215},
	{"ORYL", 4, 39216},
	{"CONGESTION", 10, 39217},
	{"DGIN", 4, 39218},
	{"RUNNERS", 7, 39219},
	{"GACT", 4, 39220},
	{"TSUM", 4, 39221},
	{"CHARSET", 7, 39222},
	{"TOFV", 4, 39223},
	{"DAYL", 4, 39224},
	{"CLIN", 4, 39225},
	{"ACCIDENTAL", 10, 39226},
	{"BYAP", 4, 39227},
	{"TALENTS", 7, 39228},
	{"NIXON", 5, 39229},
	{"YACO", 4, 39230},
	{"TFRA", 4, 39231},
	{"DSFI", 4, 39232},
	{"OFQU", 4, 39233},
	{"BRADY", 5, 39234},
	{"GUADELOUPE", 10, 39235},
	{"WALTON", 6, 39236},
	{"ZHANG", 5, 39237},
	{"UNDERWAY", 8, 39238},
	{"CARVED", 6, 39239},
	{"CKRE", 4, 39240},
	{"FREAK", 5, 39241},
	{"OBSTACLES", 9, 39242},
	{"YASP", 4, 39243},
	{"APOW", 4, 39244},
	{"GOVT", 4, 39245},
	{"CBC", 3, 39246},
	{"PREFERABLY", 10, 39247},
	{"BLUFF", 5, 39248},
	{"RYLO", 4, 39249},
	{"EXCERPTS", 8, 39250},
	{"JASPER", 6, 39251},
	{"HREP", 4, 39252},
	{"FORMATTED", 9, 39253},
	{"WHEL", 4, 39254},
	{"OMWI", 4, 39255},
	{"NEWBORN", 7, 39256},
	{"SADLY", 5, 39257},
	{"LAUGHED", 7, 39258},
	{"UCHP", 4, 39259},
	{"UBAN", 4, 39260},
	{"FTOF", 4, 39261},
	{"GORILLAZ", 8, 39262},
	{"AVAIL", 5, 39263},
	{"UNGM", 4, 39264},
	{"EMERSON", 7, 39265},
	{"DONP", 4, 39266},
	{"ORCHARD", 7, 39267},
	{"INHIBITORS", 10, 39268},
	{"WNWA", 4, 39269},
	{"TBLO", 4, 39270},
	{"DASU", 4, 39271},
	{"MYTHOLOGY", 9, 39272},
	{"PRESTIGIOUS", 11, 39273},
	{"AKEB", 4, 39274},
	{"NCAU", 4, 39275},
	{"NKLI", 4, 39276},
	{"TROUSERS", 8, 39277},
	{"GAMEPLAY", 8, 39278},
	{"ULLD", 4, 39279},
	{"HATCH", 5, 39280},
	{"REPLACES", 8, 39281},
	{"RTHB", 4, 39282},
	{"TOMB", 4, 39283},
	{"DRID", 4, 39284},
	{"REGINA", 6, 39285},
	{"OBLA", 4, 39286},
	{"GINM", 4, 39287},
	{"LLSB", 4, 39288},
	{"ADYB", 4, 39289},
	{"HGRE", 4, 39290},
	{"RSFA", 4, 39291},
	{"PRIVILEGED", 10, 39292},
	{"GOODNESS", 8, 39293},
	{"EXTRACTS", 8, 39294},
	{"PROFESSIONS", 11, 39295},
	{"URYS", 4, 39296},
	{"LAWI", 4, 39297},
	{"ODYI", 4, 39298},
	{"EGOD", 4, 39299},
	{"EXPLORED", 8, 39300},
	{"NGGU", 4, 39301},
	{"OWDI", 4, 39302},
	{"KTOB", 4, 39303},
	{"AUTISM", 6, 39304},
	{"TIBL", 4, 39305},
	{"MYSTERIES", 9, 39306},
	{"RCLI", 4, 39307},
	{"FULLER", 6, 39308},
	{"TAXPAYERS", 9, 39309},
	{"MARTINEZ", 8, 39310},
	{"DECREASES", 9, 39311},
	{"LLIC", 4, 39312},
	{"FSUP", 4, 39313},
	{"YSWH", 4, 39314},
	{"MOSP", 4, 39315},
	{"OFJE", 4, 39316},
	{"METRICS", 7, 39317},
	{"OMLA", 4, 39318},
	{"RIGU", 4, 39319},
	{"WINXP", 5, 39320},
	{"ODWA", 4, 39321},
	{"TDEM", 4, 39322},
	{"NKWE", 4, 39323},
	{"CRISP", 5, 39324},
	{"INABILITY", 9, 39325},
	{"CORONARY", 8, 39326},
	{"BLDG", 4, 39327},
	{"MEDIATED", 8, 39328},
	{"EWFO", 4, 39329},
	{"PROM", 4, 39330},
	{"SCANS", 5, 39331},
	{"KEEPER", 6, 39332},
	{"REINFORCED", 10, 39333},
	{"FULC", 4, 39334},
	{"NEGR", 4, 39335},
	{"OQUI", 4, 39336},
	{"JOHANNESBURG", 12, 39337},
	{"SPELLS", 6, 39338},
	{"SPECIFYING", 10, 39339},
	{"BUDDHIST", 8, 39340},
	{"LTOR", 4, 39341},
	{"ETIQUETTE", 9, 39342},
	{"MYIN", 4, 39343},
	{"ILDT", 4, 39344},
	{"DCHO", 4, 39345},
	{"RDLY", 4, 39346},
	{"BZU", 3, 39347},
	{"ROOKIE", 6, 39348},
	{"ENVIRON", 7, 39349},
	{"ALFL", 4, 39350},
	{"PEDU", 4, 39351},
	{"EYLL", 4, 39352},
	{"RROO", 4, 39353},
	{"BYAR", 4, 39354},
	{"THEATRICAL", 10, 39355},
	{"COLOURED", 8, 39356},
	{"AFEL", 4, 39357},
	{"BIRTHS", 6, 39358},
	{"VEDR", 4, 39359},
	{"TPIC", 4, 39360},
	{"EWPO", 4, 39361},
	{"ODWI", 4, 39362},
	{"AMEG", 4, 39363},
	{"AWER", 4, 39364},
	{"TMOD", 4, 39365},
	{"LTOU", 4, 39366},
	{"ODCO", 4, 39367},
	{"CUBS", 4, 39368},
	{"EDIU", 4, 39369},
	{"INTERDISCIPLINARY", 17, 39370},
	{"WHEELER", 7, 39371},
	{"MIGUEL", 6, 39372},
	{"KERALA", 6, 39373},
	{"PULP", 4, 39374},
	{"IXMO", 4, 39375},
	{"MPIL", 4, 39376},
	{"DSAF", 4, 39377},
	{"NDOB", 4, 39378},
	{"NLYG", 4, 39379},
	{"INTERPRETER", 11, 39380},
	{"ENZYMES", 7, 39381},
	{"DBAT", 4, 39382},
	{"MPHI", 4, 39383},
	{"SPECIMENS", 9, 39384},
	{"AYEV", 4, 39385},
	{"VEDM", 4, 39386},
	{"MSLI", 4, 39387},
	{"OWLO", 4, 39388},
	{"INITIATION", 10, 39389},
	{"ANALYTICS", 9, 39390},
	{"ASSAY", 5, 39391},
	{"JACUZZI", 7, 39392},
	{"RECONCILIATION", 14, 39393},
	{"RWEE", 4, 39394},
	{"ATLY", 4, 39395},
	{"YPUT", 4, 39396},
	{"RECOGNIZING", 11, 39397},
	{"PARSER", 6, 39398},
	{"LEIGH", 5, 39399},
	{"RBED", 4, 39400},
	{"ROMV", 4, 39401},
	{"OMAY", 4, 39402},
	{"RAZR", 4, 39403},
	{"TSCL", 4, 39404},
	{"RESPECTS", 8, 39405},
	{"USAB", 4, 39406},
	{"PLAQUE", 6, 39407},
	{"ACCOUNTED", 9, 39408},
	{"DEPOSITED", 9, 39409},
	{"LOWE", 4, 39410},
	{"BEAVERS", 7, 39411},
	{"EDUE", 4, 39412},
	{"CRIB", 4, 39413},
	{"STYLING", 7, 39414},
	{"RYYE", 4, 39415},
	{"SNACK", 5, 39416},
	{"DEFENDING", 9, 39417},
	{"PULLS", 5, 39418},
	{"RKID", 4, 39419},
	{"LARW", 4, 39420},
	{"NGEW", 4, 39421},
	{"CEFU", 4, 39422},
	{"LEEV", 4, 39423},
	{"AUTONOMOUS", 10, 39424},
	{"WEEZER", 6, 39425},
	{"MPTY", 4, 39426},
	{"GRANTING", 8, 39427},
	{"MOTORING", 8, 39428},
	{"APPROPRIATION", 13, 39429},
	{"RDAU", 4, 39430},
	{"RANDOMLY", 8, 39431},
	{"CONDENSED", 9, 39432},
	{"PHILIPPINE", 10, 39433},
	{"ASRU", 4, 39434},
	{"SEMICONDUCTORS", 14, 39435},
	{"SCENERY", 7, 39436},
	{"YLAR", 4, 39437},
	{"YOFG", 4, 39438},
	{"TOCC", 4, 39439},
	{"COCA", 4, 39440},
	{"YSIG", 4, 39441},
	{"WWY", 3, 39442},
	{"RLDI", 4, 39443},
	{"SKEP", 4, 39444},
	{"PEUGEOT", 7, 39445},
	{"BOLLYWOOD", 9, 39446},
	{"HOROSCOPES", 10, 39447},
	{"ADMO", 4, 39448},
	{"EYFI", 4, 39449},
	{"DRYING", 6, 39450},
	{"ASSEMBLIES", 10, 39451},
	{"EDUT", 4, 39452},
	{"KTHR", 4, 39453},
	{"XMAS", 4, 39454},
	{"NFUN", 4, 39455},
	{"SILICONE", 8, 39456},
	{"COLLATERAL", 10, 39457},
	{"LEARNER", 7, 39458},
	{"ONPU", 4, 39459},
	{"WELCOMES", 8, 39460},
	{"IVEV", 4, 39461},
	{"TRANSPLANT", 10, 39462},
	{"WERW", 4, 39463},
	{"SCOREBOARD", 10, 39464},
	{"UTAM", 4, 39465},
	{"PROLIFERATION", 13, 39466},
	{"USENET", 6, 39467},
	{"SQUID", 5, 39468},
	{"MIDW", 4, 39469},
	{"MARINES", 7, 39470},
	{"DFEA", 4, 39471},
	{"UYER", 4, 39472},
	{"YSAL", 4, 39473},
	{"IPSW", 4, 39474},
	{"REEZ", 4, 39475},
	{"LIGHTHOUSE", 10, 39476},
	{"PROVES", 6, 39477},
	{"CUSTOMISED", 10, 39478},
	{"TRILOGY", 7, 39479},
	{"IZAR", 4, 39480},
	{"ELFR", 4, 39481},
	{"ERNU", 4, 39482},
	{"CRAB", 4, 39483},
	{"OUWE", 4, 39484},
	{"IMOF", 4, 39485},
	{"BRIGHTNESS", 10, 39486},
	{"MAURICE", 7, 39487},
	{"BROOKE", 6, 39488},
	{"CONSUMED", 8, 39489},
	{"MAXIM", 5, 39490},
	{"RDAB", 4, 39491},
	{"BORE", 4, 39492},
	{"IMDB", 4, 39493},
	{"DEPRECIATION", 12, 39494},
	{"CLIC", 4, 39495},
	{"NKRU", 4, 39496},
	{"TECHNICALLY", 11, 39497},
	{"LLGR", 4, 39498},
	{"GINW", 4, 39499},
	{"PHARMACIST", 10, 39500},
	{"MARLEY", 6, 39501},
	{"ENJOYMENT", 9, 39502},
	{"TYPEPAD", 7, 39503},
	{"COWS", 4, 39504},
	{"SMEL", 4, 39505},
	{"VEGR", 4, 39506},
	{"DELIVERIES", 10, 39507},
	{"RECRUITERS", 10, 39508},
	{"AUSTRIAN", 8, 39509},
	{"RSUB", 4, 39510},
	{"CORRESPOND", 10, 39511},
	{"SLATE", 5, 39512},
	{"SUZANNE", 7, 39513},
	{"CONFINED", 8, 39514},
	{"SCREAMING", 9, 39515},
	{"INHABITANTS", 11, 39516},
	{"STRAIGHTFORWARD", 15, 39517},
	{"ORSL", 4, 39518},
	{"CYGWIN", 6, 39519},
	{"GEPO", 4, 39520},
	{"DYWA", 4, 39521},
	{"MORTON", 6, 39522},
	{"EGME", 4, 39523},
	{"YDRI", 4, 39524},
	{"GPRS", 4, 39525},
	{"JUPITER", 7, 39526},
	{"SIMULTANEOUS", 12, 39527},
	{"MONOPOLY", 8, 39528},
	{"RWOM", 4, 39529},
	{"INTENTIONS", 10, 39530},
	{"RIBB", 4, 39531},
	{"ROBOTICS", 8, 39532},
	{"RNIG", 4, 39533},
	{"PAGAN", 5, 39534},
	{"EYPL", 4, 39535},
	{"CHOPPED", 7, 39536},
	{"CONTEXTS", 8, 39537},
	{"OFFH", 4, 39538},
	{"OMMY", 4, 39539},
	{"TUAR", 4, 39540},
	{"ILWH", 4, 39541},
	{"RFLO", 4, 39542},
	{"RANDALL", 7, 39543},
	{"ENPU", 4, 39544},
	{"DESM", 4, 39545},
	{"BENSON", 6, 39546},
	{"SLEEVES", 7, 39547},
	{"RSAB", 4, 39548},
	{"FOOTNOTE", 8, 39549},
	{"VIBRANT", 7, 39550},
	{"EVOLVING", 8, 39551},
	{"RTMA", 4, 39552},
	{"BEWI", 4, 39553},
	{"HEYK", 4, 39554},
	{"YYM", 3, 39555},
	{"APPROXIMATION", 13, 39556},
	{"YORA", 4, 39557},
	{"SKIES", 5, 39558},
	{"BEGU", 4, 39559},
	{"BARRETT", 7, 39560},
	{"WYB", 3, 39561},
	{"EOFJ", 4, 39562},
	{"BURNERS", 7, 39563},
	{"GSTU", 4, 39564},
	{"UGHD", 4, 39565},
	{"TCER", 4, 39566},
	{"ATYP", 4, 39567},
	{"ALISON", 6, 39568},
	{"FITZGERALD", 10, 39569},
	{"NCYT", 4, 39570},
	{"KICKS", 5, 39571},
	{"EBOM", 4, 39572},
	{"RINP", 4, 39573},
	{"DISAPPEARED", 11, 39574},
	{"CANOE", 5, 39575},
	{"SOVEREIGN", 9, 39576},
	{"REMINDS", 7, 39577},
	{"ILBE", 4, 39578},
	{"CORRUPT", 7, 39579},
	{"IGIB", 4, 39580},
	{"DYBE", 4, 39581},
	{"OUGO", 4, 39582},
	{"SDRE", 4, 39583},
	{"VIOLATED", 8, 39584},
	{"DROUGHT", 7, 39585},
	{"RAMW", 4, 39586},
	{"DSLE", 4, 39587},
	{"HURRICANES", 10, 39588},
	{"PDY", 3, 39589},
	{"BRYA", 4, 39590},
	{"RCRO", 4, 39591},
	{"DNTG", 4, 39592},
	{"FORECLOSURES", 12, 39593},
	{"REPI", 4, 39594},
	{"PROPAGATION", 11, 39595},
	{"AUDITS", 6, 39596},
	{"IGNORANCE", 9, 39597},
	{"PESTICIDES", 10, 39598},
	{"EXPLOSIVE", 9, 39599},
	{"TMAJ", 4, 39600},
	{"YPUB", 4, 39601},
	{"KUV", 3, 39602},
	{"INVENTOR", 8, 39603},
	{"SCALING", 7, 39604},
	{"JUICY", 5, 39605},
	{"ATCL", 4, 39606},
	{"FAVE", 4, 39607},
	{"MBEC", 4, 39608},
	{"UZL", 3, 39609},
	{"RESIDUES", 8, 39610},
	{"ASHLEE", 6, 39611},
	{"EJEW", 4, 39612},
	{"ADYF", 4, 39613},
	{"MOODY", 5, 39614},
	{"FASHIONED", 9, 39615},
	{"UNPR", 4, 39616},
	{"YEXC", 4, 39617},
	{"AMPB", 4, 39618},
	{"DCAU", 4, 39619},
	{"TROK", 4, 39620},
	{"GRAINS", 6, 39621},
	{"SWRO", 4, 39622},
	{"VICINITY", 8, 39623},
	{"THYROID", 7, 39624},
	{"TARM", 4, 39625},
	{"BLYW", 4, 39626},
	{"VEOU", 4, 39627},
	{"PURIFICATION", 12, 39628},
	{"ORBITZ", 6, 39629},
	{"SOUTHEASTERN", 12, 39630},
	{"WIZARDS", 7, 39631},
	{"HOROSCOPE", 9, 39632},
	{"INVASIVE", 8, 39633},
	{"PROSPERITY", 10, 39634},
	{"VUZ", 3, 39635},
	{"RAINFALL", 8, 39636},
	{"EMIX", 4, 39637},
	{"HELSINKI", 8, 39638},
	{"IAGR", 4, 39639},
	{"HARDBACK", 8, 39640},
	{"RELU", 4, 39641},
	{"RISW", 4, 39642},
	{"MUM", 3, 39643},
	{"LAUNCHING", 9, 39644},
	{"VUITTON", 7, 39645},
	{"NEXTAG", 6, 39646},
	{"PEDAL", 5, 39647},
	{"LLLA", 4, 39648},
	{"INCONSISTENT", 12, 39649},
	{"EDFL", 4, 39650},
	{"PLANTATION", 10, 39651},
	{"NGUL", 4, 39652},
	{"BUTG", 4, 39653},
	{"STORING", 7, 39654},
	{"JUMPED", 6, 39655},
	{"OMYO", 4, 39656},
	{"TUNED", 5, 39657},
	{"YJP", 3, 39658},
	{"ORKP", 4, 39659},
	{"NARNIA", 6, 39660},
	{"PASSIONATE", 10, 39661},
	{"ALFA", 4, 39662},
	{"RYAC", 4, 39663},
	{"STAPLES", 7, 39664},
	{"LEYB", 4, 39665},
	{"MAYER", 5, 39666},
	{"UCKL", 4, 39667},
	{"BACKWARD", 8, 39668},
	{"EFUG", 4, 39669},
	{"SOUR", 4, 39670},
	{"GEOFF", 5, 39671},
	{"RENAME", 6, 39672},
	{"MARKUP", 6, 39673},
	{"COMBUSTION", 10, 39674},
	{"BREAKTHROUGH", 12, 39675},
	{"SCRAP", 5, 39676},
	{"TICB", 4, 39677},
	{"RNEL", 4, 39678},
	{"KEWA", 4, 39679},
	{"NCYC", 4, 39680},
	{"DALR", 4, 39681},
	{"BILATERAL", 9, 39682},
	{"LVET", 4, 39683},
	{"BELLA", 5, 39684},
	{"YFY", 3, 39685},
	{"BLONDES", 7, 39686},
	{"CTWA", 4, 39687},
	{"BENEFICIARIES", 13, 39688},
	{"DISPOSABLE", 10, 39689},
	{"RDAV", 4, 39690},
	{"RHAL", 4, 39691},
	{"WILLIAMSON", 10, 39692},
	{"SEGM", 4, 39693},
	{"GENTLEMEN", 9, 39694},
	{"NYMA", 4, 39695},
	{"GETP", 4, 39696},
	{"COPIER", 6, 39697},
	{"UNCATEGORIZED", 13, 39698},
	{"TERRA", 5, 39699},
	{"LITERAL", 7, 39700},
	{"QUESTIONED", 10, 39701},
	{"GUIDING", 7, 39702},
	{"UTSU", 4, 39703},
	{"CHARCOAL", 8, 39704},
	{"VAPOR", 5, 39705},
	{"BEWARE", 6, 39706},
	{"ALOUD", 5, 39707},
	{"EUPS", 4, 39708},
	{"DENB", 4, 39709},
	{"GLORIOUS", 8, 39710},
	{"RISL", 4, 39711},
	{"GEFORCE", 7, 39712},
	{"OVERLAP", 7, 39713},
	{"EKIC", 4, 39714},
	{"RBLO", 4, 39715},
	{"DEFAULTS", 8, 39716},
	{"FORECLOSURE", 11, 39717},
	{"CLARIFICATION", 13, 39718},
	{"ULFI", 4, 39719},
	{"RGOA", 4, 39720},
	{"OBEW", 4, 39721},
	{"GROUNDED", 8, 39722},
	{"UGHR", 4, 39723},
	{"BAIL", 4, 39724},
	{"GOOSE", 5, 39725},
	{"ESPRESSO", 8, 39726},
	{"RUNF", 4, 39727},
	{"YWEN", 4, 39728},
	{"URHA", 4, 39729},
	{"MERB", 4, 39730},
	{"JUDGEMENT", 9, 39731},
	{"LARF", 4, 39732},
	{"ITBY", 4, 39733},
	{"UTPO", 4, 39734},
	{"CRUISER", 7, 39735},
	{"REWT", 4, 39736},
	{"HENDRIX", 7, 39737},
	{"YHOL", 4, 39738},
	{"ESTEEM", 6, 39739},
	{"RWEN", 4, 39740},
	{"CASCADE", 7, 39741},
	{"STROKES", 7, 39742},
	{"SHELBY", 6, 39743},
	{"HOMEOWNER", 9, 39744},
	{"CKLI", 4, 39745},
	{"ANCESTRY", 8, 39746},
	{"DGEI", 4, 39747},
	{"DOLPHINS", 8, 39748},
	{"ADOPTING", 8, 39749},
	{"LANDED", 6, 39750},
	{"NUCLEUS", 7, 39751},
	{"DETACHED", 8, 39752},
	{"KEPL", 4, 39753},
	{"REWR", 4, 39754},
	{"BSOR", 4, 39755},
	{"SCOUTS", 6, 39756},
	{"LPOW", 4, 39757},
	{"ENUR", 4, 39758},
	{"TTYP", 4, 39759},
	{"WARSAW", 6, 39760},
	{"RPHO", 4, 39761},
	{"GLU", 3, 39762},
	{"DWHY", 4, 39763},
	{"CTWH", 4, 39764},
	{"WINNT", 5, 39765},
	{"VERB", 4, 39766},
	{"ECOP", 4, 39767},
	{"LCAL", 4, 39768},
	{"CHIC", 4, 39769},
	{"IDWI", 4, 39770},
	{"HYDRO", 5, 39771},
	{"NONLINEAR", 9, 39772},
	{"SPOKANE", 7, 39773},
	{"YBAL", 4, 39774},
	{"PHOSPHATE", 9, 39775},
	{"EEKW", 4, 39776},
	{"PLAYA", 5, 39777},
	{"OMWA", 4, 39778},
	{"NOISY", 5, 39779},
	{"ABIDE", 5, 39780},
	{"IRBE", 4, 39781},
	{"CKSC", 4, 39782},
	{"RADIOACTIVE", 11, 39783},
	{"SENTINEL", 8, 39784},
	{"BIRTHDAYS", 9, 39785},
	{"OMAG", 4, 39786},
	{"DESSERTS", 8, 39787},
	{"SOCIO", 5, 39788},
	{"PCMCIA", 6, 39789},
	{"DORG", 4, 39790},
	{"OKOV", 4, 39791},
	{"STPU", 4, 39792},
	{"PRESERVING", 10, 39793},
	{"GROOMING", 8, 39794},
	{"OMLI", 4, 39795},
	{"MERIDIAN", 8, 39796},
	{"MARRIAGES", 9, 39797},
	{"VALIDATE", 8, 39798},
	{"STAKES", 6, 39799},
	{"ROTATING", 8, 39800},
	{"NEDERLANDS", 10, 39801},
	{"ORDH", 4, 39802},
	{"FEDU", 4, 39803},
	{"BRIGADE", 7, 39804},
	{"OMDE", 4, 39805},
	{"LEMW", 4, 39806},
	{"RYTE", 4, 39807},
	{"MOVABLE", 7, 39808},
	{"VERV", 4, 39809},
	{"LTOG", 4, 39810},
	{"NGHU", 4, 39811},
	{"DOUBLES", 7, 39812},
	{"RSPL", 4, 39813},
	{"EOLY", 4, 39814},
	{"BLISS", 5, 39815},
	{"FILMOGRAPHY", 11, 39816},
	{"EAML", 4, 39817},
	{"RYSP", 4, 39818},
	{"HUMILIATION", 11, 39819},
	{"VILW", 4, 39820},
	{"ERJE", 4, 39821},
	{"LITTER", 6, 39822},
	{"TRYC", 4, 39823},
	{"REFLECTIVE", 10, 39824},
	{"RFUN", 4, 39825},
	{"OUTERWEAR", 9, 39826},
	{"BLYB", 4, 39827},
	{"YBEN", 4, 39828},
	{"AMUC", 4, 39829},
	{"TLYE", 4, 39830},
	{"ABBREVIATIONS", 13, 39831},
	{"EXECUTING", 9, 39832},
	{"EERW", 4, 39833},
	{"DFIG", 4, 39834},
	{"EVEG", 4, 39835},
	{"YDOW", 4, 39836},
	{"NRUS", 4, 39837},
	{"OWRO", 4, 39838},
	{"HEDP", 4, 39839},
	{"XXC", 3, 39840},
	{"FECO", 4, 39841},
	{"LKTO", 4, 39842},
	{"GREENWICH", 9, 39843},
	{"FLOODING", 8, 39844},
	{"RTUG", 4, 39845},
	{"EDPI", 4, 39846},
	{"PARSE", 5, 39847},
	{"RUGGED", 6, 39848},
	{"JELLY", 5, 39849},
	{"PWHI", 4, 39850},
	{"IMPLEMENTATIONS", 15, 39851},
	{"RENOVATION", 10, 39852},
	{"PUMA", 4, 39853},
	{"ATTENDEES", 9, 39854},
	{"HFUL", 4, 39855},
	{"TJOB", 4, 39856},
	{"PANTHERS", 8, 39857},
	{"VEBO", 4, 39858},
	{"YRAT", 4, 39859},
	{"PERCEPTIONS", 11, 39860},
	{"GREENWOOD", 9, 39861},
	{"LJUS", 4, 39862},
	{"IGNITION", 8, 39863},
	{"ATCR", 4, 39864},
	{"HUMBLE", 6, 39865},
	{"UERE", 4, 39866},
	{"NYDI", 4, 39867},
	{"URAS", 4, 39868},
	{"KINC", 4, 39869},
	{"BYRO", 4, 39870},
	{"DOWNSTREAM", 10, 39871},
	{"PETROL", 6, 39872},
	{"MIDWAY", 6, 39873},
	{"LASM", 4, 39874},
	{"OCKM", 4, 39875},
	{"SBER", 4, 39876},
	{"OADB", 4, 39877},
	{"MANIA", 5, 39878},
	{"EDWIN", 5, 39879},
	{"WEBCASTS", 8, 39880},
	{"YFAR", 4, 39881},
	{"DLAW", 4, 39882},
	{"YADV", 4, 39883},
	{"ACCELERATOR", 11, 39884},
	{"MASTERBATING", 12, 39885},
	{"IMBU", 4, 39886},
	{"FFOF", 4, 39887},
	{"CLARE", 5, 39888},
	{"GETW", 4, 39889},
	{"ARDU", 4, 39890},
	{"ILOM", 4, 39891},
	{"OOKB", 4, 39892},
	{"DLYT", 4, 39893},
	{"NERU", 4, 39894},
	{"UIVA", 4, 39895},
	{"FLYERS", 6, 39896},
	{"RECOGNISE", 9, 39897},
	{"ROPT", 4, 39898},
	{"TACOMA", 6, 39899},
	{"APHRODITE", 9, 39900},
	{"LSPR", 4, 39901},
	{"RADIOLOGY", 9, 39902},
	{"NIMM", 4, 39903},
	{"RUNC", 4, 39904},
	{"ESTABLISHES", 11, 39905},
	{"YLET", 4, 39906},
	{"WHITES", 6, 39907},
	{"TRAPPED", 7, 39908},
	{"BOLTS", 5, 39909},
	{"LOCALS", 6, 39910},
	{"FRINGE", 6, 39911},
	{"LINGUISTIC", 10, 39912},
	{"INTERNALLY", 10, 39913},
	{"OFAW", 4, 39914},
	{"DSPI", 4, 39915},
	{"PLANETARY", 9, 39916},
	{"LSPA", 4, 39917},
	{"TUNGSTEN", 8, 39918},
	{"TYPED", 5, 39919},
	{"DESC", 4, 39920},
	{"DATASHEET", 9, 39921},
	{"GPY", 3, 39922},
	{"LAURENT", 7, 39923},
	{"FOLI", 4, 39924},
	{"LOWH", 4, 39925},
	{"RINW", 4, 39926},
	{"EDJO", 4, 39927},
	{"SHUTDOWN", 8, 39928},
	{"MANUEL", 6, 39929},
	{"YBOO", 4, 39930},
	{"XENICAL", 7, 39931},
	{"YWAL", 4, 39932},
	{"IRLE", 4, 39933},
	{"COMPUTERWORLD", 13, 39934},
	{"GAZA", 4, 39935},
	{"INFLUENZA", 9, 39936},
	{"UXG", 3, 39937},
	{"FGRA", 4, 39938},
	{"DABR", 4, 39939},
	{"GILL", 4, 39940},
	{"DWED", 4, 39941},
	{"TATTOOS", 7, 39942},
	{"RUDE", 4, 39943},
	{"OWSU", 4, 39944},
	{"ILEL", 4, 39945},
	{"OSQU", 4, 39946},
	{"RPHY", 4, 39947},
	{"AMAW", 4, 39948},
	{"HEYU", 4, 39949},
	{"ARKC", 4, 39950},
	{"STEELE", 6, 39951},
	{"LUAB", 4, 39952},
	{"CITING", 6, 39953},
	{"KCOM", 4, 39954},
	{"UESW", 4, 39955},
	{"VIEWPOINT", 9, 39956},
	{"PEPTIDE", 7, 39957},
	{"VORC", 4, 39958},
	{"UPHI", 4, 39959},
	{"URAB", 4, 39960},
	{"OFGU", 4, 39961},
	{"SWEATSHIRT", 10, 39962},
	{"HASSLE", 6, 39963},
	{"REGENTS", 7, 39964},
	{"SERVANTS", 8, 39965},
	{"GOFO", 4, 39966},
	{"INBL", 4, 39967},
	{"CCEN", 4, 39968},
	{"WNBY", 4, 39969},
	{"MEANINGS", 8, 39970},
	{"LLPH", 4, 39971},
	{"UEWI", 4, 39972},
	{"UNEMPLOYED", 10, 39973},
	{"HEAVENLY", 8, 39974},
	{"RYHO", 4, 39975},
	{"EXETER", 6, 39976},
	{"TYFI", 4, 39977},
	{"EPUL", 4, 39978},
	{"DOCKET", 6, 39979},
	{"DLL", 3, 39980},
	{"WFRO", 4, 39981},
	{"ELSEVIER", 8, 39982},
	{"RLYH", 4, 39983},
	{"OBLO", 4, 39984},
	{"NORDIC", 6, 39985},
	{"KRUP", 4, 39986},
	{"TLIF", 4, 39987},
	{"CURL", 4, 39988},
	{"PRIVAT", 6, 39989},
	{"ALBANIAN", 8, 39990},
	{"UPSI", 4, 39991},
	{"GLEF", 4, 39992},
	{"OVERFLOW", 8, 39993},
	{"GEOMETRIC", 9, 39994},
	{"HASTINGS", 8, 39995},
	{"ILFO", 4, 39996},
	{"LDLO", 4, 39997},
	{"CYTH", 4, 39998},
	{"SUBSIDIES", 9, 39999},
	{"TAXONOMY", 8, 40000},
	{"THIRDS", 6, 40001},
	{"DELI", 4, 40002},
	{"INTERN", 6, 40003},
	{"AYPR", 4, 40004},
	{"IMPLICIT", 8, 40005},
	{"PATRIOTIC", 9, 40006},
	{"SIMPLIFY", 8, 40007},
	{"MWER", 4, 40008},
	{"DARLING", 7, 40009},
	{"SCHWARTZ", 8, 40010},
	{"ORNAMENTS", 9, 40011},
	{"GZU", 3, 40012},
	{"MEGAN", 5, 40013},
	{"ALLERGIES", 9, 40014},
	{"DEFINITE", 8, 40015},
	{"MEAB", 4, 40016},
	{"BANGALORE", 9, 40017},
	{"YASW", 4, 40018},
	{"LREV", 4, 40019},
	{"YLIS", 4, 40020},
	{"CONGREGATION", 12, 40021},
	{"REGIMENT", 8, 40022},
	{"FJUS", 4, 40023},
	{"EVERETT", 7, 40024},
	{"REVIEWERS", 9, 40025},
	{"CLUTTER", 7, 40026},
	{"NCHM", 4, 40027},
	{"DCUR", 4, 40028},
	{"MISLEADING", 10, 40029},
	{"MARTY", 5, 40030},
	{"YWRI", 4, 40031},
	{"RKNE", 4, 40032},
	{"ARSM", 4, 40033},
	{"KVD", 3, 40034},
	{"VALE", 4, 40035},
	{"YRAC", 4, 40036},
	{"LCOA", 4, 40037},
	{"WHEREBY", 7, 40038},
	{"DECEASED", 8, 40039},
	{"LWOU", 4, 40040},
	{"SPARKS", 6, 40041},
	{"XLIBS", 5, 40042},
	{"BYON", 4, 40043},
	{"NDIL", 4, 40044},
	{"LTOP", 4, 40045},
	{"BELGIAN", 7, 40046},
	{"OKSL", 4, 40047},
	{"ADOLESCENTS", 11, 40048},
	{"SIMPLER", 7, 40049},
	{"CAPTURES", 8, 40050},
	{"COVENTRY", 8, 40051},
	{"YSLE", 4, 40052},
	{"SKFO", 4, 40053},
	{"CAPITALISM", 10, 40054},
	{"HANCOCK", 7, 40055},
	{"FALKLAND", 8, 40056},
	{"CLAMP", 5, 40057},
	{"CUR", 3, 40058},
	{"PRICEGRABBER", 12, 40059},
	{"MAMMALS", 7, 40060},
	{"YGP", 3, 40061},
	{"KIDN", 4, 40062},
	{"PLYA", 4, 40063},
	{"CLONING", 7, 40064},
	{"ARGS", 4, 40065},
	{"BIGP", 4, 40066},
	{"MADDEN", 6, 40067},
	{"CECR", 4, 40068},
	{"RUSS", 4, 40069},
	{"PEPPERS", 7, 40070},
	{"LYSC", 4, 40071},
	{"DEEDS", 5, 40072},
	{"LIVELY", 6, 40073},
	{"INEQUALITY", 10, 40074},
	{"EWDE", 4, 40075},
	{"SMUGMUG", 7, 40076},
	{"PREMATURE", 9, 40077},
	{"VISUALLY", 8, 40078},
	{"TRIPOD", 6, 40079},
	{"WREC", 4, 40080},
	{"UBSC", 4, 40081},
	{"ICGR", 4, 40082},
	{"UPID", 4, 40083},
	{"ORQU", 4, 40084},
	{"IPLA", 4, 40085},
	{"ALRIGHT", 7, 40086},
	{"LAGUNA", 6, 40087},
	{"DJUN", 4, 40088},
	{"DHUM", 4, 40089},
	{"LIMO", 4, 40090},
	{"TBRA", 4, 40091},
	{"DEMONSTRATIONS", 14, 40092},
	{"URMI", 4, 40093},
	{"OBSOLETE", 8, 40094},
	{"ALIGNED", 7, 40095},
	{"RUST", 4, 40096},
	{"NCYO", 4, 40097},
	{"SFAV", 4, 40098},
	{"VEWE", 4, 40099},
	{"PESTICIDE", 9, 40100},
	{"YLER", 4, 40101},
	{"TRAPS", 5, 40102},
	{"SHUFFLE", 7, 40103},
	{"WARDROBE", 8, 40104},
	{"TRANSFORMERS", 12, 40105},
	{"IMMY", 4, 40106},
	{"RGEI", 4, 40107},
	{"NTJU", 4, 40108},
	{"SUCCESSES", 9, 40109},
	{"METW", 4, 40110},
	{"DLIG", 4, 40111},
	{"UMTH", 4, 40112},
	{"RACER", 5, 40113},
	{"FABRICATION", 11, 40114},
	{"LBOU", 4, 40115},
	{"LOFP", 4, 40116},
	{"SEPL", 4, 40117},
	{"HKOR", 4, 40118},
	{"LYBO", 4, 40119},
	{"EXPLOITED", 9, 40120},
	{"AVID", 4, 40121},
	{"OUTPATIENT", 10, 40122},
	{"BLADDER", 7, 40123},
	{"INFLAMMATORY", 12, 40124},
	{"RLIK", 4, 40125},
	{"IMMUNITY", 8, 40126},
	{"ENCRYPTED", 9, 40127},
	{"SLYA", 4, 40128},
	{"CCAN", 4, 40129},
	{"WHOLESALERS", 11, 40130},
	{"MSWH", 4, 40131},
	{"MAYW", 4, 40132},
	{"DOYLE", 5, 40133},
	{"DUCKS", 5, 40134},
	{"ICVI", 4, 40135},
	{"COLDFUSION", 10, 40136},
	{"NTCL", 4, 40137},
	{"DCR", 3, 40138},
	{"SHOOTER", 7, 40139},
	{"RKAB", 4, 40140},
	{"SWITCHBOARD", 11, 40141},
	{"PAINTS", 6, 40142},
	{"KEOV", 4, 40143},
	{"VINCE", 5, 40144},
	{"DNIG", 4, 40145},
	{"NEIGHBOURHOOD", 13, 40146},
	{"CHEATING", 8, 40147},
	{"CARR", 4, 40148},
	{"LFOO", 4, 40149},
	{"OLEL", 4, 40150},
	{"LADV", 4, 40151},
	{"FLUORESCENT", 11, 40152},
	{"TASTES", 6, 40153},
	{"COOKWARE", 8, 40154},
	{"UROR", 4, 40155},
	{"STORMS", 6, 40156},
	{"YCIT", 4, 40157},
	{"LAVIGNE", 7, 40158},
	{"DUPW", 4, 40159},
	{"PABI", 4, 40160},
	{"IFLE", 4, 40161},
	{"PARAM", 5, 40162},
	{"SMILED", 6, 40163},
	{"JURISDICTIONS", 13, 40164},
	{"LMEA", 4, 40165},
	{"NWID", 4, 40166},
	{"NNUM", 4, 40167},
	{"SCRUTINY", 8, 40168},
	{"REGENERATION", 12, 40169},
	{"LUNAR", 5, 40170},
	{"DIFFERENTIATION", 15, 40171},
	{"SHIELDS", 7, 40172},
	{"ENVIRONMENTALLY", 15, 40173},
	{"VENR", 4, 40174},
	{"NONSENSE", 8, 40175},
	{"IGNW", 4, 40176},
	{"LLBR", 4, 40177},
	{"OUPW", 4, 40178},
	{"VJU", 3, 40179},
	{"INVENTED", 8, 40180},
	{"RANU", 4, 40181},
	{"GRADIENT", 8, 40182},
	{"YRAI", 4, 40183},
	{"NCBI", 4, 40184},
	{"INSERTS", 7, 40185},
	{"BYSA", 4, 40186},
	{"GREL", 4, 40187},
	{"KVM", 3, 40188},
	{"ELAINE", 6, 40189},
	{"YFAI", 4, 40190},
	{"YAPR", 4, 40191},
	{"RSEP", 4, 40192},
	{"PROGRAMMABLE", 12, 40193},
	{"UDYI", 4, 40194},
	{"EADU", 4, 40195},
	{"POSED", 5, 40196},
	{"CHSU", 4, 40197},
	{"LDLA", 4, 40198},
	{"SUBJECTED", 9, 40199},
	{"CRUC", 4, 40200},
	{"TASTING", 7, 40201},
	{"NCEY", 4, 40202},
	{"GSOU", 4, 40203},
	{"AYAB", 4, 40204},
	{"LLIM", 4, 40205},
	{"DDOE", 4, 40206},
	{"BIBTEX", 6, 40207},
	{"MTOC", 4, 40208},
	{"CHEMOTHERAPY", 12, 40209},
	{"RDSB", 4, 40210},
	{"KEDE", 4, 40211},
	{"YLEF", 4, 40212},
	{"DSID", 4, 40213},
	{"PICI", 4, 40214},
	{"GWEN", 4, 40215},
	{"OFKA", 4, 40216},
	{"DUPI", 4, 40217},
	{"BORROWING", 9, 40218},
	{"ARISES", 6, 40219},
	{"LTRI", 4, 40220},
	{"EPOV", 4, 40221},
	{"PRECAUTIONS", 11, 40222},
	{"FLOU", 4, 40223},
	{"ERWR", 4, 40224},
	{"SMAG", 4, 40225},
	{"OMAB", 4, 40226},
	{"UNKE", 4, 40227},
	{"BRANDED", 7, 40228},
	{"DOFG", 4, 40229},
	{"RSBY", 4, 40230},
	{"DYSFUNCTION", 11, 40231},
	{"MANNING", 7, 40232},
	{"LISBON", 6, 40233},
	{"GNME", 4, 40234},
	{"FORKS", 5, 40235},
	{"MONK", 4, 40236},
	{"BOXER", 5, 40237},
	{"SHINING", 7, 40238},
	{"IDFI", 4, 40239},
	{"LIVEJOURNAL", 11, 40240},
	{"LBED", 4, 40241},
	{"LDFA", 4, 40242},
	{"ABOL", 4, 40243},
	{"RDAM", 4, 40244},
	{"DIAZEPAM", 8, 40245},
	{"LDBU", 4, 40246},
	{"ELWH", 4, 40247},
	{"RODEO", 5, 40248},
	{"GPOL", 4, 40249},
	{"CLERICAL", 8, 40250},
	{"VOYAGER", 7, 40251},
	{"TWEC", 4, 40252},
	{"HOBART", 6, 40253},
	{"GANC", 4, 40254},
	{"RONW", 4, 40255},
	{"LEYT", 4, 40256},
	{"ANPU", 4, 40257},
	{"OWNU", 4, 40258},
	{"SAMPLER", 7, 40259},
	{"ARYG", 4, 40260},
	{"HOWB", 4, 40261},
	{"UTBU", 4, 40262},
	{"MOOSE", 5, 40263},
	{"DAPE", 4, 40264},
	{"ANCU", 4, 40265},
	{"JOVI", 4, 40266},
	{"EMWH", 4, 40267},
	{"EYMO", 4, 40268},
	{"TIMETABLE", 9, 40269},
	{"DORSET", 6, 40270},
	{"YLOW", 4, 40271},
	{"TBUR", 4, 40272},
	{"ULLB", 4, 40273},
	{"KEYT", 4, 40274},
	{"OUSG", 4, 40275},
	{"CORROSION", 9, 40276},
	{"ARDG", 4, 40277},
	{"UNWA", 4, 40278},
	{"POSITIONED", 10, 40279},
	{"CHECKER", 7, 40280},
	{"BUENOS", 6, 40281},
	{"WORKSTATIONS", 12, 40282},
	{"SDEG", 4, 40283},
	{"WARW", 4, 40284},
	{"MEDR", 4, 40285},
	{"CATHY", 5, 40286},
	{"LCIT", 4, 40287},
	{"MYSTIC", 6, 40288},
	{"SOLICITATION", 12, 40289},
	{"GCEN", 4, 40290},
	{"DARREN", 6, 40291},
	{"RUCI", 4, 40292},
	{"CMP", 3, 40293},
	{"GOFS", 4, 40294},
	{"RECTANGULAR", 11, 40295},
	{"FEWH", 4, 40296},
	{"CRAI", 4, 40297},
	{"FISCHER", 7, 40298},
	{"ENTHUSIAST", 10, 40299},
	{"UDP", 3, 40300},
	{"POSITIVELY", 10, 40301},
	{"OXFO", 4, 40302},
	{"LICP", 4, 40303},
	{"SHAPING", 7, 40304},
	{"EDBL", 4, 40305},
	{"NOWP", 4, 40306},
	{"AFGHAN", 6, 40307},
	{"OROB", 4, 40308},
	{"OWLA", 4, 40309},
	{"SKOF", 4, 40310},
	{"PAULO", 5, 40311},
	{"NKIL", 4, 40312},
	{"PUMPING", 7, 40313},
	{"PATENTED", 8, 40314},
	{"REVIVAL", 7, 40315},
	{"LLSM", 4, 40316},
	{"LEVER", 5, 40317},
	{"RBOA", 4, 40318},
	{"REDUNDANT", 9, 40319},
	{"REGENCY", 7, 40320},
	{"MILFSEEKER", 10, 40321},
	{"TASTY", 5, 40322},
	{"ALAF", 4, 40323},
	{"NCYI", 4, 40324},
	{"BRUC", 4, 40325},
	{"RWRI", 4, 40326},
	{"MIDLAND", 7, 40327},
	{"SSUG", 4, 40328},
	{"DNAM", 4, 40329},
	{"EJOU", 4, 40330},
	{"EDJA", 4, 40331},
	{"WSCO", 4, 40332},
	{"SYNCHRONIZATION", 15, 40333},
	{"MCCARTHY", 8, 40334},
	{"INFORMATICS", 11, 40335},
	{"OAKLEY", 6, 40336},
	{"LDWO", 4, 40337},
	{"HECK", 4, 40338},
	{"RANTS", 5, 40339},
	{"TAROT", 5, 40340},
	{"DIDREX", 6, 40341},
	{"BRENDA", 6, 40342},
	{"UNDU", 4, 40343},
	{"CIVILIANS", 9, 40344},
	{"BARK", 4, 40345},
	{"CARTS", 5, 40346},
	{"WASTED", 6, 40347},
	{"WEDH", 4, 40348},
	{"FPUB", 4, 40349},
	{"RPOO", 4, 40350},
	{"LDPO", 4, 40351},
	{"PURDUE", 6, 40352},
	{"YONC", 4, 40353},
	{"ADGE", 4, 40354},
	{"COCOA", 5, 40355},
	{"INVITES", 7, 40356},
	{"CUSHION", 7, 40357},
	{"REVERSED", 8, 40358},
	{"YNOR", 4, 40359},
	{"AVIG", 4, 40360},
	{"LYNX", 4, 40361},
	{"DTRU", 4, 40362},
	{"ORDB", 4, 40363},
	{"FIGURINES", 9, 40364},
	{"ZEOF", 4, 40365},
	{"KWIL", 4, 40366},
	{"FOOTER", 6, 40367},
	{"MATERNAL", 8, 40368},
	{"RNEX", 4, 40369},
	{"SPECIMEN", 8, 40370},
	{"JEDI", 4, 40371},
	{"SEAMLESS", 8, 40372},
	{"OLOM", 4, 40373},
	{"ANCESTORS", 9, 40374},
	{"ICKH", 4, 40375},
	{"PANTHER", 7, 40376},
	{"MIXES", 5, 40377},
	{"GRAVES", 6, 40378},
	{"KPRO", 4, 40379},
	{"BRANDING", 8, 40380},
	{"GHETTO", 6, 40381},
	{"PBEL", 4, 40382},
	{"EPUN", 4, 40383},
	{"EXAMINER", 8, 40384},
	{"VINEYARD", 8, 40385},
	{"MEADOW", 6, 40386},
	{"LECR", 4, 40387},
	{"RYOV", 4, 40388},
	{"WARO", 4, 40389},
	{"LAVO", 4, 40390},
	{"ELOU", 4, 40391},
	{"USMI", 4, 40392},
	{"DSLO", 4, 40393},
	{"AMSF", 4, 40394},
	{"LNEV", 4, 40395},
	{"FEEDER", 6, 40396},
	{"MERCER", 6, 40397},
	{"YBEH", 4, 40398},
	{"ROMS", 4, 40399},
	{"GOODMAN", 7, 40400},
	{"YSID", 4, 40401},
	{"SUBUNIT", 7, 40402},
	{"URGO", 4, 40403},
	{"CHLORIDE", 8, 40404},
	{"BYSI", 4, 40405},
	{"DPOR", 4, 40406},
	{"YSLI", 4, 40407},
	{"RTBE", 4, 40408},
	{"LLOP", 4, 40409},
	{"VUD", 3, 40410},
	{"AWAITING", 8, 40411},
	{"IMSU", 4, 40412},
	{"BECKER", 6, 40413},
	{"AIRES", 5, 40414},
	{"BULLS", 5, 40415},
	{"HBEC", 4, 40416},
	{"DAYD", 4, 40417},
	{"ORION", 5, 40418},
	{"RJJ", 3, 40419},
	{"COMMERCIALS", 11, 40420},
	{"FHOU", 4, 40421},
	{"COUNCILLOR", 10, 40422},
	{"OCKP", 4, 40423},
	{"REGULATORS", 10, 40424},
	{"EDGU", 4, 40425},
	{"RBLA", 4, 40426},
	{"NDYA", 4, 40427},
	{"CLARKSON", 8, 40428},
	{"CARLSON", 7, 40429},
	{"ILYR", 4, 40430},
	{"SRUS", 4, 40431},
	{"MIDT", 4, 40432},
	{"BENEFICIARY", 11, 40433},
	{"BENCHMARKS", 10, 40434},
	{"HANSON", 6, 40435},
	{"AROR", 4, 40436},
	{"OFFSPRING", 9, 40437},
	{"ELWI", 4, 40438},
	{"FEWW", 4, 40439},
	{"PANORAMA", 8, 40440},
	{"RETRIEVING", 10, 40441},
	{"ODOR", 4, 40442},
	{"DATW", 4, 40443},
	{"DEMANDED", 8, 40444},
	{"REACTOR", 7, 40445},
	{"KIRIBATI", 8, 40446},
	{"WASTES", 6, 40447},
	{"TELNET", 6, 40448},
	{"CLASH", 5, 40449},
	{"BIKER", 5, 40450},
	{"FIDELITY", 8, 40451},
	{"LDBY", 4, 40452},
	{"PARKED", 6, 40453},
	{"FINANCIALS", 10, 40454},
	{"CASTRO", 6, 40455},
	{"FLEW", 4, 40456},
	{"ROFG", 4, 40457},
	{"HOLDEN", 6, 40458},
	{"UAKE", 4, 40459},
	{"CONVERTERS", 10, 40460},
	{"NAURU", 5, 40461},
	{"ANKF", 4, 40462},
	{"YROL", 4, 40463},
	{"OAGR", 4, 40464},
	{"RHAPSODY", 8, 40465},
	{"DBEM", 4, 40466},
	{"TRUMPET", 7, 40467},
	{"OLPH", 4, 40468},
	{"LMEE", 4, 40469},
	{"SOLITAIRE", 9, 40470},
	{"EWWI", 4, 40471},
	{"ULFO", 4, 40472},
	{"ADRU", 4, 40473},
	{"DECREASING", 10, 40474},
	{"FREEZING", 8, 40475},
	{"KAISER", 6, 40476},
	{"REXT", 4, 40477},
	{"FGOV", 4, 40478},
	{"DISHWASHER", 10, 40479},
	{"WALLIS", 6, 40480},
	{"ONUM", 4, 40481},
	{"EGIC", 4, 40482},
	{"CRIMINALS", 9, 40483},
	{"NEURONS", 7, 40484},
	{"LHOL", 4, 40485},
	{"TTRY", 4, 40486},
	{"RUMORS", 6, 40487},
	{"RBOD", 4, 40488},
	{"ACCOMPLISHMENTS", 15, 40489},
	{"EMERGENCE", 9, 40490},
	{"RYTR", 4, 40491},
	{"GBEE", 4, 40492},
	{"JORL", 4, 40493},
	{"URDI", 4, 40494},
	{"THEATRES", 8, 40495},
	{"APEX", 4, 40496},
	{"CRIMSON", 7, 40497},
	{"BYPO", 4, 40498},
	{"COMPASSION", 10, 40499},
	{"ULYT", 4, 40500},
	{"BEUN", 4, 40501},
	{"YLAW", 4, 40502},
	{"KOFS", 4, 40503},
	{"DPAY", 4, 40504},
	{"NEEDING", 7, 40505},
	{"DSAV", 4, 40506},
	{"HEXP", 4, 40507},
	{"AGOV", 4, 40508},
	{"ADSU", 4, 40509},
	{"ECOSYSTEMS", 10, 40510},
	{"CHFR", 4, 40511},
	{"BEFI", 4, 40512},
	{"PRONOUNCED", 10, 40513},
	{"EXTENSIVELY", 11, 40514},
	{"DVAL", 4, 40515},
	{"CONRAD", 6, 40516},
	{"WISHED", 6, 40517},
	{"TRANSIENT", 9, 40518},
	{"RSAM", 4, 40519},
	{"UWER", 4, 40520},
	{"WSKI", 4, 40521},
	{"EYBA", 4, 40522},
	{"KICKED", 6, 40523},
	{"USEY", 4, 40524},
	{"COLORING", 8, 40525},
	{"CURB", 4, 40526},
	{"TLIG", 4, 40527},
	{"GADGET", 6, 40528},
	{"TPOR", 4, 40529},
	{"ELCH", 4, 40530},
	{"CCTV", 4, 40531},
	{"LEUKEMIA", 8, 40532},
	{"REIGN", 5, 40533},
	{"TRIVIAL", 7, 40534},
	{"DECO", 4, 40535},
	{"TICKER", 6, 40536},
	{"COKE", 4, 40537},
	{"HABITATS", 8, 40538},
	{"CLAUSES", 7, 40539},
	{"OFUR", 4, 40540},
	{"BARON", 5, 40541},
	{"YQUI", 4, 40542},
	{"MHAD", 4, 40543},
	{"GFAC", 4, 40544},
	{"NGKI", 4, 40545},
	{"REMOVER", 7, 40546},
	{"SENSIBLE", 8, 40547},
	{"UNLAWFUL", 8, 40548},
	{"BATES", 5, 40549},
	{"INCORPORATES", 12, 40550},
	{"RUNB", 4, 40551},
	{"BRASIL", 6, 40552},
	{"LEOP", 4, 40553},
	{"NALV", 4, 40554},
	{"WEBS", 4, 40555},
	{"SWINGING", 8, 40556},
	{"ACCOUNTABLE", 11, 40557},
	{"THRUST", 6, 40558},
	{"PROVING", 7, 40559},
	{"ZWR", 3, 40560},
	{"QUEA", 4, 40561},
	{"UNICODE", 7, 40562},
	{"OPPOSING", 8, 40563},
	{"PROD", 4, 40564},
	{"OCOV", 4, 40565},
	{"NOVICE", 6, 40566},
	{"NLYN", 4, 40567},
	{"LEQU", 4, 40568},
	{"LPEO", 4, 40569},
	{"SPREADSHEET", 11, 40570},
	{"HEWITT", 6, 40571},
	{"GEDL", 4, 40572},
	{"YMET", 4, 40573},
	{"KTOW", 4, 40574},
	{"IGHC", 4, 40575},
	{"CONQ", 4, 40576},
	{"LOWERING", 8, 40577},
	{"DELIGHTFUL", 10, 40578},
	{"NLEF", 4, 40579},
	{"KWAR", 4, 40580},
	{"CRUISING", 8, 40581},
	{"AFIL", 4, 40582},
	{"FURY", 4, 40583},
	{"PERSONALITIES", 13, 40584},
	{"DISCOGRAPHY", 11, 40585},
	{"ECAB", 4, 40586},
	{"ENCODED", 7, 40587},
	{"LSUR", 4, 40588},
	{"ABAM", 4, 40589},
	{"RESEARCHING", 11, 40590},
	{"WORE", 4, 40591},
	{"CHRISTCHURCH", 12, 40592},
	{"LZM", 3, 40593},
	{"RNCA", 4, 40594},
	{"MBEI", 4, 40595},
	{"OFAV", 4, 40596},
	{"PEDIATRICS", 10, 40597},
	{"UNDD", 4, 40598},
	{"FWIL", 4, 40599},
	{"KEAP", 4, 40600},
	{"OSUB", 4, 40601},
	{"TRACES", 6, 40602},
	{"LANW", 4, 40603},
	{"RABBI", 5, 40604},
	{"SUSHI", 5, 40605},
	{"PUFFY", 5, 40606},
	{"WESTON", 6, 40607},
	{"DAFI", 4, 40608},
	{"HEADINGS", 8, 40609},
	{"TKIL", 4, 40610},
	{"CKBA", 4, 40611},
	{"ENTHUSIASTS", 11, 40612},
	{"HOMP", 4, 40613},
	{"SCATTERING", 10, 40614},
	{"RGUA", 4, 40615},
	{"DIDY", 4, 40616},
	{"SECRETARIES", 11, 40617},
	{"ONSITE", 6, 40618},
	{"RUNW", 4, 40619},
	{"MAPQUEST", 8, 40620},
	{"CONTRACTED", 10, 40621},
	{"MGOI", 4, 40622},
	{"DEIG", 4, 40623},
	{"FIGHTS", 6, 40624},
	{"DELETING", 8, 40625},
	{"ECTB", 4, 40626},
	{"CKNE", 4, 40627},
	{"UMIS", 4, 40628},
	{"UNWI", 4, 40629},
	{"WRZ", 3, 40630},
	{"COMPILATIONS", 12, 40631},
	{"RGEB", 4, 40632},
	{"APPEALING", 9, 40633},
	{"LSLI", 4, 40634},
	{"CENC", 4, 40635},
	{"IDLA", 4, 40636},
	{"XCES", 4, 40637},
	{"RTHP", 4, 40638},
	{"SCHOLARLY", 9, 40639},
	{"DEDN", 4, 40640},
	{"FKB", 3, 40641},
	{"DETAILING", 9, 40642},
	{"RWOO", 4, 40643},
	{"STARK", 5, 40644},
	{"LIFESTYLES", 10, 40645},
	{"ROBERTO", 7, 40646},
	{"STRONGEST", 9, 40647},
	{"DCOO", 4, 40648},
	{"ILYD", 4, 40649},
	{"HAMMOND", 7, 40650},
	{"SWIMWEAR", 8, 40651},
	{"PADDED", 6, 40652},
	{"EORC", 4, 40653},
	{"APPLET", 6, 40654},
	{"BYIT", 4, 40655},
	{"PRICETOOL", 9, 40656},
	{"CIRCA", 5, 40657},
	{"ORIM", 4, 40658},
	{"REVISE", 6, 40659},
	{"GOPE", 4, 40660},
	{"CONTRIBUTES", 11, 40661},
	{"DPHO", 4, 40662},
	{"SURROUNDINGS", 12, 40663},
	{"PROFICIENCY", 11, 40664},
	{"DPOP", 4, 40665},
	{"TCUT", 4, 40666},
	{"QUINN", 5, 40667},
	{"URANIUM", 7, 40668},
	{"HONOURS", 7, 40669},
	{"CONSOLIDATE", 11, 40670},
	{"DANIELS", 7, 40671},
	{"BILLIONS", 8, 40672},
	{"YDEA", 4, 40673},
	{"DAEWOO", 6, 40674},
	{"ANTIGEN", 7, 40675},
	{"ORBY", 4, 40676},
	{"ULTRASOUND", 10, 40677},
	{"RROB", 4, 40678},
	{"STAFFORD", 8, 40679},
	{"MGMT", 4, 40680},
	{"RORT", 4, 40681},
	{"PROCEDURAL", 10, 40682},
	{"CKOB", 4, 40683},
	{"LABRADOR", 8, 40684},
	{"AILB", 4, 40685},
	{"NGSD", 4, 40686},
	{"CEMI", 4, 40687},
	{"REFUSAL", 7, 40688},
	{"LIMA", 4, 40689},
	{"SUPPRESSION", 11, 40690},
	{"DALW", 4, 40691},
	{"WEAVER", 6, 40692},
	{"CERN", 4, 40693},
	{"READINESS", 9, 40694},
	{"CTMA", 4, 40695},
	{"BLYS", 4, 40696},
	{"MACROS", 6, 40697},
	{"MAJESTY", 7, 40698},
	{"CKSE", 4, 40699},
	{"FISHERY", 7, 40700},
	{"TERESA", 6, 40701},
	{"DISTRIBUTING", 12, 40702},
	{"ESTIMATING", 10, 40703},
	{"DSBU", 4, 40704},
	{"OUTDATED", 8, 40705},
	{"EPLU", 4, 40706},
	{"AUSSIE", 6, 40707},
	{"ADVISORIES", 10, 40708},
	{"YDEM", 4, 40709},
	{"DUES", 4, 40710},
	{"PEWTER", 6, 40711},
	{"LENDINGTREE", 11, 40712},
	{"BELMONT", 7, 40713},
	{"DISTRESS", 8, 40714},
	{"PUMPKIN", 7, 40715},
	{"NOTABLY", 7, 40716},
	{"INTENDS", 7, 40717},
	{"UVL", 3, 40718},
	{"TREVOR", 6, 40719},
	{"DOLP", 4, 40720},
	{"RATR", 4, 40721},
	{"BYBO", 4, 40722},
	{"LLYK", 4, 40723},
	{"NMAL", 4, 40724},
	{"YLAT", 4, 40725},
	{"GARMENT", 7, 40726},
	{"ACAD", 4, 40727},
	{"BILINGUAL", 9, 40728},
	{"DSAM", 4, 40729},
	{"BARBECUE", 8, 40730},
	{"UDDH", 4, 40731},
	{"LRET", 4, 40732},
	{"LOCALIZATION", 12, 40733},
	{"SUPPLYING", 9, 40734},
	{"SECONDLY", 8, 40735},
	{"ZFL", 3, 40736},
	{"FRJ", 3, 40737},
	{"RAZOR", 5, 40738},
	{"COUGH", 5, 40739},
	{"CEREBRAL", 8, 40740},
	{"EFAU", 4, 40741},
	{"GRANDMA", 7, 40742},
	{"CUSTOMIZATION", 13, 40743},
	{"UWOU", 4, 40744},
	{"GIGS", 4, 40745},
	{"INDEXING", 8, 40746},
	{"LORI", 4, 40747},
	{"OCEANS", 6, 40748},
	{"HEMY", 4, 40749},
	{"DISPLACEMENT", 12, 40750},
	{"CKNA", 4, 40751},
	{"RKSW", 4, 40752},
	{"URWA", 4, 40753},
	{"SPACECRAFT", 10, 40754},
	{"ALRY", 4, 40755},
	{"IVOIRE", 6, 40756},
	{"BACKWARDS", 9, 40757},
	{"ARROWS", 6, 40758},
	{"VOLUNTEERING", 12, 40759},
	{"MONTSERRAT", 10, 40760},
	{"TELECOMMUNICATION", 17, 40761},
	{"TCHB", 4, 40762},
	{"RAQI", 4, 40763},
	{"COATINGS", 8, 40764},
	{"EUREKA", 6, 40765},
	{"CONSTRUCTIVE", 12, 40766},
	{"EWDA", 4, 40767},
	{"BUNDLES", 7, 40768},
	{"PCB", 3, 40769},
	{"RSAD", 4, 40770},
	{"TIBET", 5, 40771},
	{"PREPAREDNESS", 12, 40772},
	{"RLOW", 4, 40773},
	{"RBOU", 4, 40774},
	{"GBAN", 4, 40775},
	{"EELD", 4, 40776},
	{"PRES", 4, 40777},
	{"CETR", 4, 40778},
	{"ISLES", 5, 40779},
	{"STRETCHING", 10, 40780},
	{"OVENS", 5, 40781},
	{"OWNG", 4, 40782},
	{"SYSTEMIC", 8, 40783},
	{"GARRETT", 7, 40784},
	{"RYFE", 4, 40785},
	{"ESTHER", 6, 40786},
	{"PLAYOFFS", 8, 40787},
	{"ABUNDANT", 8, 40788},
	{"DEDUCTIBLE", 10, 40789},
	{"RLYB", 4, 40790},
	{"ADAPTORS", 8, 40791},
	{"PRIESTS", 7, 40792},
	{"COMPARES", 8, 40793},
	{"TYSC", 4, 40794},
	{"FORECASTING", 11, 40795},
	{"ESDR", 4, 40796},
	{"LIDI", 4, 40797},
	{"INSPIRING", 9, 40798},
	{"PREY", 4, 40799},
	{"DEPOSITION", 10, 40800},
	{"DRM", 3, 40801},
	{"LAURIE", 6, 40802},
	{"YWAT", 4, 40803},
	{"IBLI", 4, 40804},
	{"ICKB", 4, 40805},
	{"HEDG", 4, 40806},
	{"ZODIAC", 6, 40807},
	{"DTOJ", 4, 40808},
	{"PAVEMENT", 8, 40809},
	{"MASTERBATION", 12, 40810},
	{"LFIR", 4, 40811},
	{"TUBING", 6, 40812},
	{"KELLER", 6, 40813},
	{"YKIN", 4, 40814},
	{"PEDESTRIAN", 10, 40815},
	{"FENCING", 7, 40816},
	{"BLOOMINGTON", 11, 40817},
	{"ARTERY", 6, 40818},
	{"DZW", 3, 40819},
	{"CONDITIONER", 11, 40820},
	{"YCAP", 4, 40821},
	{"RWEL", 4, 40822},
	{"FEWA", 4, 40823},
	{"PLAINTIFFS", 10, 40824},
	{"INLET", 5, 40825},
	{"LYNA", 4, 40826},
	{"REALISE", 7, 40827},
	{"FLUIDS", 6, 40828},
	{"CONVENIENTLY", 12, 40829},
	{"SBAD", 4, 40830},
	{"LICK", 4, 40831},
	{"VANESSA", 7, 40832},
	{"CKPO", 4, 40833},
	{"STEALTH", 7, 40834},
	{"NUCLEOTIDE", 10, 40835},
	{"BRONX", 5, 40836},
	{"ETFR", 4, 40837},
	{"DEDG", 4, 40838},
	{"YSAF", 4, 40839},
	{"LISTMANIA", 9, 40840},
	{"REPAYMENT", 9, 40841},
	{"RISR", 4, 40842},
	{"MIDDOT", 6, 40843},
	{"ICLA", 4, 40844},
	{"NETGEAR", 7, 40845},
	{"UXV", 3, 40846},
	{"CANOPY", 6, 40847},
	{"GLOSS", 5, 40848},
	{"OUPE", 4, 40849},
	{"AYYO", 4, 40850},
	{"PANDA", 5, 40851},
	{"ERNB", 4, 40852},
	{"HFOU", 4, 40853},
	{"RORG", 4, 40854},
	{"CRC", 3, 40855},
	{"DTRY", 4, 40856},
	{"CHPO", 4, 40857},
	{"SYMBIAN", 7, 40858},
	{"USTU", 4, 40859},
	{"DJOI", 4, 40860},
	{"SFIV", 4, 40861},
	{"YMED", 4, 40862},
	{"RKEL", 4, 40863},
	{"PERTINENT", 9, 40864},
	{"NEYB", 4, 40865},
	{"LIFELONG", 8, 40866},
	{"EMAILED", 7, 40867},
	{"WSER", 4, 40868},
	{"UJR", 3, 40869},
	{"MICD", 4, 40870},
	{"PROMOTER", 8, 40871},
	{"COLLEGIATE", 10, 40872},
	{"CONSTANTS", 9, 40873},
	{"CONSTRUED", 9, 40874},
	{"INTERCHANGE", 11, 40875},
	{"REMOTELY", 8, 40876},
	{"MPOU", 4, 40877},
	{"FLETCHER", 8, 40878},
	{"CONCISE", 7, 40879},
	{"CKAS", 4, 40880},
	{"ICAW", 4, 40881},
	{"ISUZU", 5, 40882},
	{"FIBERS", 6, 40883},
	{"UBBL", 4, 40884},
	{"NEDL", 4, 40885},
	{"BRAINS", 6, 40886},
	{"CURTAINS", 8, 40887},
	{"INDIGO", 6, 40888},
	{"RETAINING", 9, 40889},
	{"GWAY", 4, 40890},
	{"KELLEY", 6, 40891},
	{"RLYR", 4, 40892},
	{"CHDA", 4, 40893},
	{"AUTOBIOGRAPHY", 13, 40894},
	{"IDIC", 4, 40895},
	{"LBRI", 4, 40896},
	{"CONDITIONED", 11, 40897},
	{"EEDL", 4, 40898},
	{"WEBRING", 7, 40899},
	{"MICI", 4, 40900},
	{"PROHIBITION", 11, 40901},
	{"MBRO", 4, 40902},
	{"IDOR", 4, 40903},
	{"ICHG", 4, 40904},
	{"MOTIONS", 7, 40905},
	{"RULI", 4, 40906},
	{"KEDL", 4, 40907},
	{"REDIRECT", 8, 40908},
	{"INTEROPERABILITY", 16, 40909},
	{"BADL", 4, 40910},
	{"URHE", 4, 40911},
	{"BEPL", 4, 40912},
	{"UTAG", 4, 40913},
	{"MPBE", 4, 40914},
	{"EGAC", 4, 40915},
	{"MSRP", 4, 40916},
	{"TUVALU", 6, 40917},
	{"SHAMPOO", 7, 40918},
	{"EXCITE", 6, 40919},
	{"YBAR", 4, 40920},
	{"REBELS", 6, 40921},
	{"RKCO", 4, 40922},
	{"NEOPLASMS", 9, 40923},
	{"LDSC", 4, 40924},
	{"RACU", 4, 40925},
	{"ARTIFACTS", 9, 40926},
	{"MECL", 4, 40927},
	{"BELIEVING", 9, 40928},
	{"HILARIOUS", 9, 40929},
	{"YDNE", 4, 40930},
	{"SALISBURY", 9, 40931},
	{"PSEUDO", 6, 40932},
	{"EEDM", 4, 40933},
	{"DDET", 4, 40934},
	{"DDIV", 4, 40935},
	{"QUOTING", 7, 40936},
	{"SINKS", 5, 40937},
	{"EOFK", 4, 40938},
	{"DINAR", 5, 40939},
	{"LBEO", 4, 40940},
	{"DYNASTY", 7, 40941},
	{"ICMO", 4, 40942},
	{"CREED", 5, 40943},
	{"CARAT", 5, 40944},
	{"MICROPHONES", 11, 40945},
	{"TCRO", 4, 40946},
	{"NEDG", 4, 40947},
	{"AFLO", 4, 40948},
	{"NOBEL", 5, 40949},
	{"RAIDERS", 7, 40950},
	{"GALAXIES", 8, 40951},
	{"SPREADS", 7, 40952},
	{"VERLAG", 6, 40953},
	{"FFZ", 3, 40954},
	{"ELEGANCE", 8, 40955},
	{"VOLATILE", 8, 40956},
	{"GCOL", 4, 40957},
	{"POINTERS", 8, 40958},
	{"FUNI", 4, 40959},
	{"SENSORY", 7, 40960},
	{"NKEY", 4, 40961},
	{"RDIR", 4, 40962},
	{"OREQ", 4, 40963},
	{"ADWH", 4, 40964},
	{"SCRAPBOOK", 9, 40965},
	{"WCAN", 4, 40966},
	{"DJOB", 4, 40967},
	{"DUMMIES", 7, 40968},
	{"THMY", 4, 40969},
	{"ZZLE", 4, 40970},
	{"LONL", 4, 40971},
	{"THRONE", 6, 40972},
	{"MEGR", 4, 40973},
	{"BUTU", 4, 40974},
	{"ISWR", 4, 40975},
	{"ERNF", 4, 40976},
	{"UELE", 4, 40977},
	{"MAGNESIUM", 9, 40978},
	{"PAGINA", 6, 40979},
	{"CHARTERED", 9, 40980},
	{"TLEP", 4, 40981},
	{"ELGI", 4, 40982},
	{"SLOPES", 6, 40983},
	{"RTLI", 4, 40984},
	{"ONDM", 4, 40985},
	{"IBAL", 4, 40986},
	{"ULLP", 4, 40987},
	{"OFDU", 4, 40988},
	{"UNFORTUNATE", 11, 40989},
	{"USMO", 4, 40990},
	{"SEIZED", 6, 40991},
	{"DITF", 4, 40992},
	{"YGOI", 4, 40993},
	{"RKAS", 4, 40994},
	{"NBIL", 4, 40995},
	{"UNFA", 4, 40996},
	{"UECO", 4, 40997},
	{"ROUNDUP", 7, 40998},
	{"TERRITORIAL", 11, 40999},
	{"LEASES", 6, 41000},
	{"IMAC", 4, 41001},
	{"CONSISTED", 9, 41002},
	{"RANDOLPH", 8, 41003},
	{"FAXES", 5, 41004},
	{"PLUMP", 5, 41005},
	{"IGNC", 4, 41006},
	{"MEMOIRS", 7, 41007},
	{"VENY", 4, 41008},
	{"UTHB", 4, 41009},
	{"UIRI", 4, 41010},
	{"ALKALINE", 8, 41011},
	{"NUOU", 4, 41012},
	{"EXPIRE", 6, 41013},
	{"WWII", 4, 41014},
	{"OMBU", 4, 41015},
	{"METHYL", 6, 41016},
	{"CAMPUSES", 8, 41017},
	{"WDOW", 4, 41018},
	{"FSCH", 4, 41019},
	{"RLET", 4, 41020},
	{"OPUB", 4, 41021},
	{"DIFY", 4, 41022},
	{"BORNE", 5, 41023},
	{"RAMADA", 6, 41024},
	{"MUQ", 3, 41025},
	{"LTOB", 4, 41026},
	{"MANSFIELD", 9, 41027},
	{"NEIGHBOURS", 10, 41028},
	{"BYWA", 4, 41029},
	{"TESCO", 5, 41030},
	{"MARVIN", 6, 41031},
	{"AGOW", 4, 41032},
	{"UPHE", 4, 41033},
	{"ULDY", 4, 41034},
	{"BEAF", 4, 41035},
	{"ERSV", 4, 41036},
	{"STCR", 4, 41037},
	{"ARCHITECTURES", 13, 41038},
	{"CONVERSIONS", 11, 41039},
	{"YBLA", 4, 41040},
	{"ACDBLINE", 8, 41041},
	{"ROWL", 4, 41042},
	{"HIDD", 4, 41043},
	{"USABLE", 6, 41044},
	{"TEMPO", 5, 41045},
	{"GETTY", 5, 41046},
	{"WMON", 4, 41047},
	{"TLEY", 4, 41048},
	{"MUTATIONS", 9, 41049},
	{"OLCO", 4, 41050},
	{"CDR", 3, 41051},
	{"READABLE", 8, 41052},
	{"KTIM", 4, 41053},
	{"ALMANAC", 7, 41054},
	{"CONWAY", 6, 41055},
	{"GAIL", 4, 41056},
	{"SEGR", 4, 41057},
	{"RESPONDS", 8, 41058},
	{"DENOTE", 6, 41059},
	{"GGRA", 4, 41060},
	{"SLAYER", 6, 41061},
	{"ALSM", 4, 41062},
	{"PAYNE", 5, 41063},
	{"HOWF", 4, 41064},
	{"PROG", 4, 41065},
	{"YBJ", 3, 41066},
	{"THCL", 4, 41067},
	{"FIREWALLS", 9, 41068},
	{"LDOU", 4, 41069},
	{"TESTER", 6, 41070},
	{"POLLING", 7, 41071},
	{"FIFA", 4, 41072},
	{"PURCHASER", 9, 41073},
	{"RTSB", 4, 41074},
	{"IMIZ", 4, 41075},
	{"RELIES", 6, 41076},
	{"INSERTING", 9, 41077},
	{"TIBETAN", 7, 41078},
	{"PREPARES", 8, 41079},
	{"CONCLUDES", 9, 41080},
	{"IRER", 4, 41081},
	{"ISDU", 4, 41082},
	{"CONSUMABLES", 11, 41083},
	{"WATERFORD", 9, 41084},
	{"YFOO", 4, 41085},
	{"TGER", 4, 41086},
	{"RODNEY", 6, 41087},
	{"CYLINDERS", 9, 41088},
	{"UPWA", 4, 41089},
	{"SELECTS", 7, 41090},
	{"BYME", 4, 41091},
	{"BLEG", 4, 41092},
	{"YINB", 4, 41093},
	{"FULTON", 6, 41094},
	{"DIRECTING", 9, 41095},
	{"NATIONALITY", 11, 41096},
	{"LSCI", 4, 41097},
	{"LYRO", 4, 41098},
	{"XYD", 3, 41099},
	{"HIGHBEAM", 8, 41100},
	{"MSDN", 4, 41101},
	{"STATISTICALLY", 13, 41102},
	{"TORCH", 5, 41103},
	{"ZURICH", 6, 41104},
	{"ODRO", 4, 41105},
	{"STRETCHED", 9, 41106},
	{"YJOH", 4, 41107},
	{"RDLI", 4, 41108},
	{"LEYE", 4, 41109},
	{"ENCOUNTERS", 10, 41110},
	{"KEDM", 4, 41111},
	{"HAUNTED", 7, 41112},
	{"SPARES", 6, 41113},
	{"ASFU", 4, 41114},
	{"EBYS", 4, 41115},
	{"SYMMETRY", 8, 41116},
	{"BOUT", 4, 41117},
	{"ADVERTS", 7, 41118},
	{"YSUB", 4, 41119},
	{"YKG", 3, 41120},
	{"UNBE", 4, 41121},
	{"LTWI", 4, 41122},
	{"AWSU", 4, 41123},
	{"IRSU", 4, 41124},
	{"ORTY", 4, 41125},
	{"PROGRAMMED", 10, 41126},
	{"RROG", 4, 41127},
	{"LOHAN", 5, 41128},
	{"SALONS", 6, 41129},
	{"ROFN", 4, 41130},
	{"LDSP", 4, 41131},
	{"OLYMPIA", 7, 41132},
	{"UGJ", 3, 41133},
	{"REBI", 4, 41134},
	{"NEGLIGENCE", 10, 41135},
	{"UNCLEAR", 7, 41136},
	{"SCREENED", 8, 41137},
	{"HELPER", 6, 41138},
	{"CARLISLE", 8, 41139},
	{"AROMATHERAPY", 12, 41140},
	{"RANCHO", 6, 41141},
	{"TRANSFERRING", 12, 41142},
	{"NEDERLAND", 9, 41143},
	{"STOCKTON", 8, 41144},
	{"CEPO", 4, 41145},
	{"STEPPING", 8, 41146},
	{"LYOV", 4, 41147},
	{"ICWO", 4, 41148},
	{"HACKS", 5, 41149},
	{"CLEARWATER", 10, 41150},
	{"SEBY", 4, 41151},
	{"ATTIC", 5, 41152},
	{"TRUSTPASS", 9, 41153},
	{"TOPOLOGY", 8, 41154},
	{"APPETITE", 8, 41155},
	{"LTAL", 4, 41156},
	{"PIPER", 5, 41157},
	{"AIRBORNE", 8, 41158},
	{"MORALITY", 8, 41159},
	{"HONORABLE", 9, 41160},
	{"NOWR", 4, 41161},
	{"HANDICAP", 8, 41162},
	{"SKINNY", 6, 41163},
	{"SEWAGE", 6, 41164},
	{"ENDOWMENT", 9, 41165},
	{"DEMONSTRATING", 13, 41166},
	{"IMGO", 4, 41167},
	{"ANTENNAS", 8, 41168},
	{"SALB", 4, 41169},
	{"SUNDANCE", 8, 41170},
	{"LIFECYCLE", 9, 41171},
	{"DHCP", 4, 41172},
	{"ERND", 4, 41173},
	{"AVEC", 4, 41174},
	{"TRUCKING", 8, 41175},
	{"AMSP", 4, 41176},
	{"YFIL", 4, 41177},
	{"SONOMA", 6, 41178},
	{"CALN", 4, 41179},
	{"CKSF", 4, 41180},
	{"YMOS", 4, 41181},
	{"MEYO", 4, 41182},
	{"DRAL", 4, 41183},
	{"IRAQIS", 6, 41184},
	{"LLFE", 4, 41185},
	{"SHORTCUT", 8, 41186},
	{"EFTW", 4, 41187},
	{"SLYT", 4, 41188},
	{"GSEV", 4, 41189},
	{"DYET", 4, 41190},
	{"DDAV", 4, 41191},
	{"WRETCH", 6, 41192},
	{"STEMS", 5, 41193},
	{"RACIST", 6, 41194},
	{"PROFITABILITY", 13, 41195},
	{"FAIRMONT", 8, 41196},
	{"VENTURA", 7, 41197},
	{"RDUN", 4, 41198},
	{"DEUP", 4, 41199},
	{"DSMI", 4, 41200},
	{"SEGU", 4, 41201},
	{"DZY", 3, 41202},
	{"DUU", 3, 41203},
	{"EVERGREEN", 9, 41204},
	{"CKIE", 4, 41205},
	{"GLOBALLY", 8, 41206},
	{"OPEW", 4, 41207},
	{"BEARINGS", 8, 41208},
	{"FOND", 4, 41209},
	{"EUTR", 4, 41210},
	{"DFY", 3, 41211},
	{"AALIYAH", 7, 41212},
	{"ODPR", 4, 41213},
	{"REBOOT", 6, 41214},
	{"HEDC", 4, 41215},
	{"NEWSGROUP", 9, 41216},
	{"DABU", 4, 41217},
	{"WSUI", 4, 41218},
	{"RRYO", 4, 41219},
	{"BLINDS", 6, 41220},
	{"SYDN", 4, 41221},
	{"AUDIOVOX", 8, 41222},
	{"TRAITS", 6, 41223},
	{"GRADED", 6, 41224},
	{"LCAP", 4, 41225},
	{"PHUKET", 6, 41226},
	{"SUCCESSOR", 9, 41227},
	{"LONY", 4, 41228},
	{"INTRUSION", 9, 41229},
	{"KSBE", 4, 41230},
	{"LECU", 4, 41231},
	{"SICKNESS", 8, 41232},
	{"WDV", 3, 41233},
	{"MSUN", 4, 41234},
	{"ALLK", 4, 41235},
	{"ENGU", 4, 41236},
	{"BEPU", 4, 41237},
	{"GUIANA", 6, 41238},
	{"UNDERNEATH", 10, 41239},
	{"UTAP", 4, 41240},
	{"IRDR", 4, 41241},
	{"METABOLIC", 9, 41242},
	{"ALGU", 4, 41243},
	{"ABUSED", 6, 41244},
	{"RYFA", 4, 41245},
	{"OADV", 4, 41246},
	{"SARASOTA", 8, 41247},
	{"BILLED", 6, 41248},
	{"AVERY", 5, 41249},
	{"MYMO", 4, 41250},
	{"TCLI", 4, 41251},
	{"FARF", 4, 41252},
	{"DANIELLE", 8, 41253},
	{"BRUSHES", 7, 41254},
	{"ANTHOLOGY", 9, 41255},
	{"BLJ", 3, 41256},
	{"SMILES", 6, 41257},
	{"MERGED", 6, 41258},
	{"AUDITORS", 8, 41259},
	{"GRANDCHILDREN", 13, 41260},
	{"DESKS", 5, 41261},
	{"CAPSULE", 7, 41262},
	{"AIDED", 5, 41263},
	{"RELIED", 6, 41264},
	{"RDBA", 4, 41265},
	{"ORVE", 4, 41266},
	{"KNAM", 4, 41267},
	{"YORS", 4, 41268},
	{"AMPO", 4, 41269},
	{"EFTB", 4, 41270},
	{"OKPL", 4, 41271},
	{"ETERNITY", 8, 41272},
	{"MESOTHELIOMA", 12, 41273},
	{"TRAFFICKING", 11, 41274},
	{"HMAD", 4, 41275},
	{"INTRODUCTIONS", 13, 41276},
	{"ASKF", 4, 41277},
	{"RDOE", 4, 41278},
	{"ANMU", 4, 41279},
	{"KEWH", 4, 41280},
	{"WEIGHING", 8, 41281},
	{"CURRENTS", 8, 41282},
	{"FMED", 4, 41283},
	{"BIZJOURNALS", 11, 41284},
	{"MICHELE", 7, 41285},
	{"AYBY", 4, 41286},
	{"TDIV", 4, 41287},
	{"GWHO", 4, 41288},
	{"MBAC", 4, 41289},
	{"KINDLY", 6, 41290},
	{"CUTIE", 5, 41291},
	{"FIXI", 4, 41292},
	{"LEPI", 4, 41293},
	{"FOFF", 4, 41294},
	{"BYTO", 4, 41295},
	{"RDET", 4, 41296},
	{"PROTESTS", 8, 41297},
	{"UTOB", 4, 41298},
	{"NCYS", 4, 41299},
	{"SLYI", 4, 41300},
	{"SHARKS", 6, 41301},
	{"NOTCH", 5, 41302},
	{"MINORS", 6, 41303},
	{"EDVA", 4, 41304},
	{"KUPT", 4, 41305},
	{"DANCES", 6, 41306},
	{"BYWH", 4, 41307},
	{"LUED", 4, 41308},
	{"REVEALING", 9, 41309},
	{"DATM", 4, 41310},
	{"FGAM", 4, 41311},
	{"REPRINTED", 9, 41312},
	{"FERNANDO", 8, 41313},
	{"MAPPED", 6, 41314},
	{"SORW", 4, 41315},
	{"IERW", 4, 41316},
	{"RESURRECTION", 12, 41317},
	{"LIEU", 4, 41318},
	{"DECREE", 6, 41319},
	{"YUNT", 4, 41320},
	{"TSQU", 4, 41321},
	{"UTUN", 4, 41322},
	{"ICKC", 4, 41323},
	{"ADTW", 4, 41324},
	{"SEOUL", 5, 41325},
	{"PRINTF", 6, 41326},
	{"DISCOVERING", 11, 41327},
	{"TUBERCULOSIS", 12, 41328},
	{"LACKS", 5, 41329},
	{"RLOT", 4, 41330},
	{"OWMO", 4, 41331},
	{"HORIZONS", 8, 41332},
	{"TRANSPLANTATION", 15, 41333},
	{"JEROME", 6, 41334},
	{"DAYTIME", 7, 41335},
	{"MAYC", 4, 41336},
	{"CONTOUR", 7, 41337},
	{"GAMBLE", 6, 41338},
	{"DESCENT", 7, 41339},
	{"FITF", 4, 41340},
	{"GRAVEL", 6, 41341},
	{"ANALYSE", 7, 41342},
	{"ALTW", 4, 41343},
	{"RBEN", 4, 41344},
	{"RAMMSTEIN", 9, 41345},
	{"RPHI", 4, 41346},
	{"JUDGED", 6, 41347},
	{"SHUTTER", 7, 41348},
	{"EDNU", 4, 41349},
	{"LYAV", 4, 41350},
	{"RIFY", 4, 41351},
	{"LWER", 4, 41352},
	{"EALF", 4, 41353},
	{"UMNI", 4, 41354},
	{"SCRAPBOOKING", 12, 41355},
	{"NOTORIOUS", 9, 41356},
	{"IBID", 4, 41357},
	{"RESIDUE", 7, 41358},
	{"REDS", 4, 41359},
	{"ENLARGED", 8, 41360},
	{"DFLA", 4, 41361},
	{"STEPHENS", 8, 41362},
	{"TRANSFORMING", 12, 41363},
	{"SEQUENTIAL", 10, 41364},
	{"RVIL", 4, 41365},
	{"ITJU", 4, 41366},
	{"STRIPPING", 9, 41367},
	{"YKP", 3, 41368},
	{"UNIQUELY", 8, 41369},
	{"DWOO", 4, 41370},
	{"BART", 4, 41371},
	{"GOODIES", 7, 41372},
	{"EOBJ", 4, 41373},
	{"FLUCTUATIONS", 12, 41374},
	{"BOWIE", 5, 41375},
	{"ARCHAEOLOGICAL", 14, 41376},
	{"EPUP", 4, 41377},
	{"OMCH", 4, 41378},
	{"SRUL", 4, 41379},
	{"ERNW", 4, 41380},
	{"NRIV", 4, 41381},
	{"INSPECT", 7, 41382},
	{"THRICE", 6, 41383},
	{"BABYLON", 7, 41384},
	{"SUGABABES", 9, 41385},
	{"EDISON", 6, 41386},
	{"UEDI", 4, 41387},
	{"SOPL", 4, 41388},
	{"OUMI", 4, 41389},
	{"HYOF", 4, 41390},
	{"RCW", 3, 41391},
	{"MUSINGS", 7, 41392},
	{"HEDM", 4, 41393},
	{"KOFC", 4, 41394},
	{"ALQU", 4, 41395},
	{"IDAB", 4, 41396},
	{"NLEG", 4, 41397},
	{"WHISTLER", 8, 41398},
	{"ERSJ", 4, 41399},
	{"ALNU", 4, 41400},
	{"POSES", 5, 41401},
	{"AIRFARES", 8, 41402},
	{"OMBS", 4, 41403},
	{"LDMO", 4, 41404},
	{"HUNTSVILLE", 10, 41405},
	{"RARM", 4, 41406},
	{"MERH", 4, 41407},
	{"WKF", 3, 41408},
	{"OLCA", 4, 41409},
	{"LAYOUTS", 7, 41410},
	{"SERVICEMAGIC", 12, 41411},
	{"DESIGNATE", 9, 41412},
	{"AGOL", 4, 41413},
	{"LDFR", 4, 41414},
	{"SEQUEL", 6, 41415},
	{"NEPL", 4, 41416},
	{"GYMNASTICS", 10, 41417},
	{"FSOC", 4, 41418},
	{"TITANIC", 7, 41419},
	{"KNOB", 4, 41420},
	{"GKON", 4, 41421},
	{"UALE", 4, 41422},
	{"TFAR", 4, 41423},
	{"WOLVES", 6, 41424},
	{"EXQUISITE", 9, 41425},
	{"GINP", 4, 41426},
	{"HERPES", 6, 41427},
	{"UPWARD", 6, 41428},
	{"SENTENCED", 9, 41429},
	{"DUNDEE", 6, 41430},
	{"NEWSGATOR", 9, 41431},
	{"PRINCIPE", 8, 41432},
	{"CONTRACTUAL", 11, 41433},
	{"ULSE", 4, 41434},
	{"ACQUIRING", 9, 41435},
	{"JUDGING", 7, 41436},
	{"UNCHANGED", 9, 41437},
	{"KICKING", 7, 41438},
	{"YCW", 3, 41439},
	{"LFQ", 3, 41440},
	{"YLEO", 4, 41441},
	{"CHFI", 4, 41442},
	{"AKRON", 5, 41443},
	{"FINES", 5, 41444},
	{"MEDM", 4, 41445},
	{"OLEW", 4, 41446},
	{"ODYT", 4, 41447},
	{"KCOU", 4, 41448},
	{"GHED", 4, 41449},
	{"MONC", 4, 41450},
	{"LBRO", 4, 41451},
	{"EMYO", 4, 41452},
	{"OUNCE", 5, 41453},
	{"OCER", 4, 41454},
	{"RYRO", 4, 41455},
	{"DSWO", 4, 41456},
	{"SSPL", 4, 41457},
	{"MCOU", 4, 41458},
	{"THEODORE", 8, 41459},
	{"TEDJ", 4, 41460},
	{"NGVA", 4, 41461},
	{"BUENA", 5, 41462},
	{"IRRELEVANT", 10, 41463},
	{"URON", 4, 41464},
	{"PROFESSIONALLY", 14, 41465},
	{"LIBERTIES", 9, 41466},
	{"SOUNDING", 8, 41467},
	{"LISB", 4, 41468},
	{"YDER", 4, 41469},
	{"REBOUNDS", 8, 41470},
	{"MILANO", 6, 41471},
	{"URLO", 4, 41472},
	{"COMPRESSOR", 10, 41473},
	{"LEAB", 4, 41474},
	{"HOOKED", 6, 41475},
	{"SAMANTHA", 8, 41476},
	{"NICL", 4, 41477},
	{"FFED", 4, 41478},
	{"KNOX", 4, 41479},
	{"WEBMAIL", 7, 41480},
	{"UPBY", 4, 41481},
	{"CARCINOMA", 9, 41482},
	{"TAIPEI", 6, 41483},
	{"UNESCO", 6, 41484},
	{"MUTUALLY", 8, 41485},
	{"RWAN", 4, 41486},
	{"MSOM", 4, 41487},
	{"NGGI", 4, 41488},
	{"OUTK", 4, 41489},
	{"NBEU", 4, 41490},
	{"OOKM", 4, 41491},
	{"KUMAR", 5, 41492},
	{"BEADED", 6, 41493},
	{"REMEMBERING", 11, 41494},
	{"BOCA", 4, 41495},
	{"CKCA", 4, 41496},
	{"PLEE", 4, 41497},
	{"ARIV", 4, 41498},
	{"EXODUS", 6, 41499},
	{"COMPARTMENT", 11, 41500},
	{"GEMINI", 6, 41501},
	{"OWPR", 4, 41502},
	{"BRITTANY", 8, 41503},
	{"DOVE", 4, 41504},
	{"TESTIFIED", 9, 41505},
	{"ORPI", 4, 41506},
	{"CUNNINGHAM", 10, 41507},
	{"RSME", 4, 41508},
	{"AFFINITY", 8, 41509},
	{"PRESBYTERIAN", 12, 41510},
	{"SUPERVISORY", 11, 41511},
	{"ALOV", 4, 41512},
	{"BYAT", 4, 41513},
	{"ORMW", 4, 41514},
	{"BYJO", 4, 41515},
	{"DLAB", 4, 41516},
	{"FOVE", 4, 41517},
	{"BYFA", 4, 41518},
	{"GAPR", 4, 41519},
	{"INDB", 4, 41520},
	{"HFLO", 4, 41521},
	{"BUDDHISM", 8, 41522},
	{"YDIV", 4, 41523},
	{"AMNESTY", 7, 41524},
	{"CHIROPRACTIC", 12, 41525},
	{"BORROWER", 8, 41526},
	{"RPLE", 4, 41527},
	{"MREA", 4, 41528},
	{"LFWA", 4, 41529},
	{"GLOUCESTER", 10, 41530},
	{"IFEB", 4, 41531},
	{"MBUR", 4, 41532},
	{"ICYC", 4, 41533},
	{"UPBE", 4, 41534},
	{"EAMU", 4, 41535},
	{"WARRANTS", 8, 41536},
	{"NWHY", 4, 41537},
	{"OWENS", 5, 41538},
	{"LYGA", 4, 41539},
	{"FAIRNESS", 8, 41540},
	{"NEEDLES", 7, 41541},
	{"COLL", 4, 41542},
	{"NHUM", 4, 41543},
	{"THROUGHPUT", 10, 41544},
	{"QUOTA", 5, 41545},
	{"UTAD", 4, 41546},
	{"NETBSD", 6, 41547},
	{"MERF", 4, 41548},
	{"ELDF", 4, 41549},
	{"DISCREET", 8, 41550},
	{"MISPLACE", 8, 41551},
	{"VERSA", 5, 41552},
	{"USTY", 4, 41553},
	{"GFRE", 4, 41554},
	{"ELRE", 4, 41555},
	{"SERVICED", 8, 41556},
	{"RCHC", 4, 41557},
	{"MACK", 4, 41558},
	{"LEYI", 4, 41559},
	{"LLAF", 4, 41560},
	{"SUNG", 4, 41561},
	{"MMET", 4, 41562},
	{"LVEM", 4, 41563},
	{"NDKN", 4, 41564},
	{"UMON", 4, 41565},
	{"LOWELL", 6, 41566},
	{"WHICHEVER", 9, 41567},
	{"STARR", 5, 41568},
	{"KETP", 4, 41569},
	{"ELLIOT", 6, 41570},
	{"LMOV", 4, 41571},
	{"OPENER", 6, 41572},
	{"BYAD", 4, 41573},
	{"ESYM", 4, 41574},
	{"VACCINES", 8, 41575},
	{"CHOOSES", 7, 41576},
	{"TUSCANY", 7, 41577},
	{"WHYW", 4, 41578},
	{"JIGSAW", 6, 41579},
	{"JUMBO", 5, 41580},
	{"TICKLING", 8, 41581},
	{"ULEA", 4, 41582},
	{"UNSPECIFIED", 11, 41583},
	{"TLYU", 4, 41584},
	{"URYI", 4, 41585},
	{"FWES", 4, 41586},
	{"GHEL", 4, 41587},
	{"TURBINE", 7, 41588},
	{"UNREAL", 6, 41589},
	{"WOUNDS", 6, 41590},
	{"UMAY", 4, 41591},
	{"PERCENTAGES", 11, 41592},
	{"ADVISERS", 8, 41593},
	{"MMEM", 4, 41594},
	{"MANUFACTURES", 12, 41595},
	{"OLLU", 4, 41596},
	{"AMRE", 4, 41597},
	{"PHYSIOLOGICAL", 13, 41598},
	{"SOFY", 4, 41599},
	{"LOWB", 4, 41600},
	{"UMBA", 4, 41601},
	{"MATHS", 5, 41602},
	{"ADDISON", 7, 41603},
	{"DPAI", 4, 41604},
	{"CHARTERS", 8, 41605},
	{"GENERALIZED", 11, 41606},
	{"PROBES", 6, 41607},
	{"RLIS", 4, 41608},
	{"FLINT", 5, 41609},
	{"DUMMY", 5, 41610},
	{"FINANCIALLY", 11, 41611},
	{"SANITATION", 10, 41612},
	{"TSCU", 4, 41613},
	{"FHAR", 4, 41614},
	{"OOMF", 4, 41615},
	{"AMERICANA", 9, 41616},
	{"SWIVEL", 6, 41617},
	{"RGUI", 4, 41618},
	{"CILO", 4, 41619},
	{"DISSOLVED", 9, 41620},
	{"TYAL", 4, 41621},
	{"OKLI", 4, 41622},
	{"CLEANLINESS", 11, 41623},
	{"COMPLEXES", 9, 41624},
	{"YVOT", 4, 41625},
	{"IRWO", 4, 41626},
	{"KUNG", 4, 41627},
	{"VARSITY", 7, 41628},
	{"YORG", 4, 41629},
	{"COLLECTIVELY", 12, 41630},
	{"INSURER", 7, 41631},
	{"FDEF", 4, 41632},
	{"CROATIAN", 8, 41633},
	{"GFOU", 4, 41634},
	{"CIND", 4, 41635},
	{"KPAR", 4, 41636},
	{"IDAD", 4, 41637},
	{"INHIBITION", 10, 41638},
	{"THMU", 4, 41639},
	{"IPUL", 4, 41640},
	{"MULTICAST", 9, 41641},
	{"CERTIFICATIONS", 14, 41642},
	{"TFEL", 4, 41643},
	{"BURNT", 5, 41644},
	{"SOLIDARITY", 10, 41645},
	{"FRUSTRATED", 10, 41646},
	{"MUHAMMAD", 8, 41647},
	{"ALMA", 4, 41648},
	{"ARQU", 4, 41649},
	{"YRIA", 4, 41650},
	{"PRADESH", 7, 41651},
	{"HANOVER", 7, 41652},
	{"INVERSE", 7, 41653},
	{"CLIFTON", 7, 41654},
	{"BYBE", 4, 41655},
	{"LDEP", 4, 41656},
	{"LCRE", 4, 41657},
	{"OFKE", 4, 41658},
	{"MEDALS", 6, 41659},
	{"PROTON", 6, 41660},
	{"DICKINSON", 9, 41661},
	{"CHRISTI", 7, 41662},
	{"YBRE", 4, 41663},
	{"LISTER", 6, 41664},
	{"TYMU", 4, 41665},
	{"RECURRING", 9, 41666},
	{"RDPR", 4, 41667},
	{"STUDS", 5, 41668},
	{"NYCH", 4, 41669},
	{"RYIT", 4, 41670},
	{"MODIFYING", 9, 41671},
	{"INCUBUS", 7, 41672},
	{"TDRA", 4, 41673},
	{"KAPLAN", 6, 41674},
	{"YMOD", 4, 41675},
	{"SURVEYED", 8, 41676},
	{"EBAB", 4, 41677},
	{"CREDITORS", 9, 41678},
	{"DULL", 4, 41679},
	{"OFVO", 4, 41680},
	{"BSCR", 4, 41681},
	{"AUND", 4, 41682},
	{"NYFO", 4, 41683},
	{"GBEF", 4, 41684},
	{"CABINS", 6, 41685},
	{"CHYO", 4, 41686},
	{"COMMENCED", 9, 41687},
	{"BALLROOM", 8, 41688},
	{"EMPLOYING", 9, 41689},
	{"SATELLITES", 10, 41690},
	{"DYZ", 3, 41691},
	{"IGNORING", 8, 41692},
	{"ERIL", 4, 41693},
	{"LINENS", 6, 41694},
	{"STEVENSON", 9, 41695},
	{"COHERENT", 8, 41696},
	{"BEETLE", 6, 41697},
	{"CONVERTS", 8, 41698},
	{"GHMA", 4, 41699},
	{"MAJESTIC", 8, 41700},
	{"YBAN", 4, 41701},
	{"TAPL", 4, 41702},
	{"BICYCLES", 8, 41703},
	{"ICTW", 4, 41704},
	{"ROAST", 5, 41705},
	{"TESTERS", 7, 41706},
	{"ADTR", 4, 41707},
	{"TRYH", 4, 41708},
	{"DQUE", 4, 41709},
	{"DEBUGINFO", 9, 41710},
	{"COMPLAINANT", 11, 41711},
	{"CTSF", 4, 41712},
	{"INHIBITOR", 9, 41713},
	{"CLIFFORD", 8, 41714},
	{"NDSR", 4, 41715},
	{"DTYP", 4, 41716},
	{"NPUR", 4, 41717},
	{"KNOWLEDGEABLE", 13, 41718},
	{"CRITICALLY", 10, 41719},
	{"IGHR", 4, 41720},
	{"EKEP", 4, 41721},
	{"COMPOSERS", 9, 41722},
	{"LOCALITIES", 10, 41723},
	{"PLEG", 4, 41724},
	{"RUMM", 4, 41725},
	{"YFIV", 4, 41726},
	{"JIMI", 4, 41727},
	{"NFAR", 4, 41728},
	{"HUMMER", 6, 41729},
	{"RECIPROCAL", 10, 41730},
	{"YTER", 4, 41731},
	{"ROMK", 4, 41732},
	{"DYIS", 4, 41733},
	{"RLEG", 4, 41734},
	{"EDYA", 4, 41735},
	{"HATRED", 6, 41736},
	{"CEDM", 4, 41737},
	{"QUESTIONING", 11, 41738},
	{"YAVA", 4, 41739},
	{"PUTATIVE", 8, 41740},
	{"YART", 4, 41741},
	{"MANIFEST", 8, 41742},
	{"INDICATIONS", 11, 41743},
	{"PETTY", 5, 41744},
	{"PERMITTING", 10, 41745},
	{"AROW", 4, 41746},
	{"HYPERLINK", 9, 41747},
	{"PRESARIO", 8, 41748},
	{"MOTORSPORTS", 11, 41749},
	{"GETAWAY", 7, 41750},
	{"RORE", 4, 41751},
	{"WAYP", 4, 41752},
	{"ROBBINS", 7, 41753},
	{"FDES", 4, 41754},
	{"ZEPPELIN", 8, 41755},
	{"FELIX", 5, 41756},
	{"SHINY", 5, 41757},
	{"CARMEL", 6, 41758},
	{"ENCORE", 6, 41759},
	{"SSBU", 4, 41760},
	{"UTEF", 4, 41761},
	{"SMASH", 5, 41762},
	{"TYWE", 4, 41763},
	{"ANGELINA", 8, 41764},
	{"KIMBERLY", 8, 41765},
	{"YJC", 3, 41766},
	{"UNSURE", 6, 41767},
	{"ELDH", 4, 41768},
	{"NGNU", 4, 41769},
	{"BRAUN", 5, 41770},
	{"DESTRUCTIVE", 11, 41771},
	{"GHLA", 4, 41772},
	{"SOCKETS", 7, 41773},
	{"RILT", 4, 41774},
	{"UTBR", 4, 41775},
	{"CLAIMANT", 8, 41776},
	{"DINOSAUR", 8, 41777},
	{"AMPLE", 5, 41778},
	{"COUNTLESS", 9, 41779},
	{"ASHLAND", 7, 41780},
	{"ENERGIES", 8, 41781},
	{"ICUT", 4, 41782},
	{"AFIG", 4, 41783},
	{"DLP", 3, 41784},
	{"REPEALED", 8, 41785},
	{"YINJ", 4, 41786},
	{"ROYCE", 5, 41787},
	{"DFEL", 4, 41788},
	{"LISTENERS", 9, 41789},
	{"ABUSIVE", 7, 41790},
	{"ANTIBIOTICS", 11, 41791},
	{"LANDFILL", 8, 41792},
	{"WAREHOUSING", 11, 41793},
	{"FILESIZE", 8, 41794},
	{"ULER", 4, 41795},
	{"MERITS", 6, 41796},
	{"SCARF", 5, 41797},
	{"STRANGERS", 9, 41798},
	{"IGAR", 4, 41799},
	{"GARLAND", 7, 41800},
	{"SICF", 4, 41801},
	{"VOOR", 4, 41802},
	{"CELEBREX", 8, 41803},
	{"VERISIGN", 8, 41804},
	{"RIVIERA", 7, 41805},
	{"GMIL", 4, 41806},
	{"APPRENTICE", 10, 41807},
	{"TMED", 4, 41808},
	{"OBSCURE", 7, 41809},
	{"NAPOLEON", 8, 41810},
	{"REGISTRATIONS", 13, 41811},
	{"RSPI", 4, 41812},
	{"WAVELENGTH", 10, 41813},
	{"RAPY", 4, 41814},
	{"UTME", 4, 41815},
	{"GLAMOUR", 7, 41816},
	{"LDPA", 4, 41817},
	{"SLASHDOT", 8, 41818},
	{"TRANSVESTITES", 13, 41819},
	{"NYWI", 4, 41820},
	{"HATED", 5, 41821},
	{"CHEERLEADERS", 12, 41822},
	{"SAYW", 4, 41823},
	{"GABR", 4, 41824},
	{"TROLLEY", 7, 41825},
	{"PRINCIPALS", 10, 41826},
	{"PPET", 4, 41827},
	{"HOPL", 4, 41828},
	{"DESB", 4, 41829},
	{"SIDNEY", 6, 41830},
	{"RINB", 4, 41831},
	{"FRIEDMAN", 8, 41832},
	{"RNFO", 4, 41833},
	{"COOLPIX", 7, 41834},
	{"SPICY", 5, 41835},
	{"MMAD", 4, 41836},
	{"HTUP", 4, 41837},
	{"BLOCKER", 7, 41838},
	{"OBBI", 4, 41839},
	{"KSTR", 4, 41840},
	{"TAWNEE", 6, 41841},
	{"CHRONOLOGICAL", 13, 41842},
	{"EDGI", 4, 41843},
	{"ENTREPRENEURSHIP", 16, 41844},
	{"CWOR", 4, 41845},
	{"NLYL", 4, 41846},
	{"CCIN", 4, 41847},
	{"ITINERARY", 9, 41848},
	{"FOOLS", 5, 41849},
	{"UTID", 4, 41850},
	{"RBIG", 4, 41851},
	{"EWMI", 4, 41852},
	{"BYWI", 4, 41853},
	{"DISCOVERIES", 11, 41854},
	{"PERCENTILE", 10, 41855},
	{"FDEC", 4, 41856},
	{"LINKAGE", 7, 41857},
	{"YGOV", 4, 41858},
	{"SFUR", 4, 41859},
	{"ECONOMICAL", 10, 41860},
	{"MINIATURES", 10, 41861},
	{"WNPA", 4, 41862},
	{"WEDGE", 5, 41863},
	{"ADJUSTING", 9, 41864},
	{"GJUS", 4, 41865},
	{"TRYB", 4, 41866},
	{"LLRI", 4, 41867},
	{"MOCK", 4, 41868},
	{"MTOG", 4, 41869},
	{"PEGGY", 5, 41870},
	{"LSAY", 4, 41871},
	{"PATRIOTS", 8, 41872},
	{"RASM", 4, 41873},
	{"RUINS", 5, 41874},
	{"ECAV", 4, 41875},
	{"OGYI", 4, 41876},
	{"SHEILA", 6, 41877},
	{"NGSR", 4, 41878},
	{"LAWM", 4, 41879},
	{"NGEB", 4, 41880},
	{"RIPPER", 6, 41881},
	{"DEPENDENCIES", 12, 41882},
	{"ACCOMODATION", 12, 41883},
	{"SPOU", 4, 41884},
	{"ENDB", 4, 41885},
	{"WEBE", 4, 41886},
	{"TRYF", 4, 41887},
	{"RICC", 4, 41888},
	{"BENTON", 6, 41889},
	{"MCAFEE", 6, 41890},
	{"GLAR", 4, 41891},
	{"CHATEAU", 7, 41892},
	{"DENIS", 5, 41893},
	{"YEFF", 4, 41894},
	{"YCAU", 4, 41895},
	{"COUNSELORS", 10, 41896},
	{"HOMESTEAD", 9, 41897},
	{"ERKA", 4, 41898},
	{"COMPETITIVENESS", 15, 41899},
	{"BURGER", 6, 41900},
	{"MICROSCOPY", 10, 41901},
	{"CHANGER", 7, 41902},
	{"SERGEANT", 8, 41903},
	{"DDRO", 4, 41904},
	{"YPTI", 4, 41905},
	{"RDSM", 4, 41906},
	{"GSUC", 4, 41907},
	{"SYRIAN", 6, 41908},
	{"HYPER", 5, 41909},
	{"YNCH", 4, 41910},
	{"MADTHUMBS", 9, 41911},
	{"LINKIN", 6, 41912},
	{"GMAIL", 5, 41913},
	{"ORYH", 4, 41914},
	{"BERP", 4, 41915},
	{"CYPRESS", 7, 41916},
	{"LTEL", 4, 41917},
	{"COURTNEY", 8, 41918},
	{"CITES", 5, 41919},
	{"EHUR", 4, 41920},
	{"DAFR", 4, 41921},
	{"SCOOTERS", 8, 41922},
	{"RESERVEAMERICA", 14, 41923},
	{"ORGANISATIONAL", 14, 41924},
	{"RPUR", 4, 41925},
	{"PROSPECTUS", 10, 41926},
	{"EZINE", 5, 41927},
	{"RINJ", 4, 41928},
	{"PROTECTORS", 10, 41929},
	{"REACTIVE", 8, 41930},
	{"NTCR", 4, 41931},
	{"LEUS", 4, 41932},
	{"INTERIORS", 9, 41933},
	{"DITB", 4, 41934},
	{"BUNC", 4, 41935},
	{"ENCOURAGEMENT", 13, 41936},
	{"BUYA", 4, 41937},
	{"YKB", 3, 41938},
	{"CLIPBOARD", 9, 41939},
	{"GSAL", 4, 41940},
	{"DISADVANTAGES", 13, 41941},
	{"RKOU", 4, 41942},
	{"LINP", 4, 41943},
	{"RGEM", 4, 41944},
	{"GABL", 4, 41945},
	{"GAMER", 5, 41946},
	{"ALEXA", 5, 41947},
	{"OURV", 4, 41948},
	{"RFUT", 4, 41949},
	{"ABBOTT", 6, 41950},
	{"TAILOR", 6, 41951},
	{"MZU", 3, 41952},
	{"POLLUTANTS", 10, 41953},
	{"NEYC", 4, 41954},
	{"USCR", 4, 41955},
	{"DIRECTORATE", 11, 41956},
	{"CHOCOLATES", 10, 41957},
	{"FAUX", 4, 41958},
	{"SBYS", 4, 41959},
	{"SUPERVISED", 10, 41960},
	{"INTERPRETING", 12, 41961},
	{"LHOM", 4, 41962},
	{"SAVVY", 5, 41963},
	{"PASCAL", 6, 41964},
	{"LASW", 4, 41965},
	{"SERENITY", 8, 41966},
	{"LFEA", 4, 41967},
	{"UPLOADS", 7, 41968},
	{"SHERIDAN", 8, 41969},
	{"OWBU", 4, 41970},
	{"RMSI", 4, 41971},
	{"GALLONS", 7, 41972},
	{"ATTAINMENT", 10, 41973},
	{"MCCO", 4, 41974},
	{"ADYO", 4, 41975},
	{"OOMW", 4, 41976},
	{"SANITARY", 8, 41977},
	{"TERRI", 5, 41978},
	{"EXCU", 4, 41979},
	{"DREAMING", 8, 41980},
	{"TCOV", 4, 41981},
	{"LHIG", 4, 41982},
	{"NORMS", 5, 41983},
	{"IMPLANTS", 8, 41984},
	{"FORTUNATE", 9, 41985},
	{"ALIBABA", 7, 41986},
	{"IRBO", 4, 41987},
	{"MUSHROOMS", 9, 41988},
	{"HORMONES", 8, 41989},
	{"IGNP", 4, 41990},
	{"HYPE", 4, 41991},
	{"INTERPRETATIONS", 15, 41992},
	{"GEOFFREY", 8, 41993},
	{"FAULTS", 6, 41994},
	{"ADDR", 4, 41995},
	{"ADBU", 4, 41996},
	{"SILVA", 5, 41997},
	{"CYQ", 3, 41998},
	{"GREASE", 6, 41999},
	{"IRLF", 4, 42000},
	{"DIABLO", 6, 42001},
	{"URINARY", 7, 42002},
	{"CAIRNS", 6, 42003},
	{"INSTITUT", 8, 42004},
	{"PRIMA", 5, 42005},
	{"NTBR", 4, 42006},
	{"CONDOMS", 7, 42007},
	{"DIRECTIVES", 10, 42008},
	{"CINNAMON", 8, 42009},
	{"IEWW", 4, 42010},
	{"OMBR", 4, 42011},
	{"ZELDA", 5, 42012},
	{"DISCHARGED", 10, 42013},
	{"UTWO", 4, 42014},
	{"ALBA", 4, 42015},
	{"AYSU", 4, 42016},
	{"ALJU", 4, 42017},
	{"UNDERWORLD", 10, 42018},
	{"ACUR", 4, 42019},
	{"VARIANTS", 8, 42020},
	{"FETAL", 5, 42021},
	{"EFEC", 4, 42022},
	{"MEDL", 4, 42023},
	{"PALMS", 5, 42024},
	{"LAWSUITS", 8, 42025},
	{"GWEL", 4, 42026},
	{"SEATED", 6, 42027},
	{"LATTICE", 7, 42028},
	{"NGIF", 4, 42029},
	{"EBUC", 4, 42030},
	{"DONG", 4, 42031},
	{"REALIZATION", 11, 42032},
	{"LYVI", 4, 42033},
	{"RQUI", 4, 42034},
	{"ABSORBED", 8, 42035},
	{"LPUB", 4, 42036},
	{"SIRIUS", 6, 42037},
	{"HYDO", 4, 42038},
	{"DGOL", 4, 42039},
	{"BYSH", 4, 42040},
	{"CHORD", 5, 42041},
	{"TICW", 4, 42042},
	{"POFA", 4, 42043},
	{"KUDOZ", 5, 42044},
	{"LHIM", 4, 42045},
	{"LDUS", 4, 42046},
	{"VOUS", 4, 42047},
	{"TURF", 4, 42048},
	{"LMIL", 4, 42049},
	{"ALEW", 4, 42050},
	{"ASPHALT", 7, 42051},
	{"ICKF", 4, 42052},
	{"REPLAY", 6, 42053},
	{"IMPROPER", 8, 42054},
	{"FLAVORS", 7, 42055},
	{"OUBE", 4, 42056},
	{"RNOU", 4, 42057},
	{"REBUILDING", 10, 42058},
	{"LIVINGSTON", 10, 42059},
	{"QUICKCHECK", 10, 42060},
	{"NELY", 4, 42061},
	{"POSU", 4, 42062},
	{"COMMENTING", 10, 42063},
	{"RMYS", 4, 42064},
	{"FOPE", 4, 42065},
	{"SHIFTED", 7, 42066},
	{"GDEA", 4, 42067},
	{"TANGIBLE", 8, 42068},
	{"SMOKED", 6, 42069},
	{"EUNC", 4, 42070},
	{"HAWKS", 5, 42071},
	{"ULDU", 4, 42072},
	{"ZIFF", 4, 42073},
	{"YSMO", 4, 42074},
	{"NGIR", 4, 42075},
	{"PLACEBO", 7, 42076},
	{"IRONS", 5, 42077},
	{"INDM", 4, 42078},
	{"COMET", 5, 42079},
	{"BERG", 4, 42080},
	{"RYEX", 4, 42081},
	{"BALTIC", 6, 42082},
	{"CORRECTIVE", 10, 42083},
	{"COMPETENCY", 10, 42084},
	{"IRVI", 4, 42085},
	{"CEUN", 4, 42086},
	{"MUSE", 4, 42087},
	{"EAPL", 4, 42088},
	{"PROBING", 7, 42089},
	{"EADP", 4, 42090},
	{"TEACHINGS", 9, 42091},
	{"PEDP", 4, 42092},
	{"LOTTO", 5, 42093},
	{"RDUE", 4, 42094},
	{"UTTW", 4, 42095},
	{"FOWLER", 6, 42096},
	{"TDEL", 4, 42097},
	{"XTWE", 4, 42098},
	{"GMEM", 4, 42099},
	{"YOUNGEST", 8, 42100},
	{"CIPI", 4, 42101},
	{"OGYT", 4, 42102},
	{"CONTINGENT", 10, 42103},
	{"RMYA", 4, 42104},
	{"REFRESHING", 10, 42105},
	{"SOFK", 4, 42106},
	{"LTYO", 4, 42107},
	{"HIMM", 4, 42108},
	{"TEXTURES", 8, 42109},
	{"EULT", 4, 42110},
	{"ZLU", 3, 42111},
	{"SYRUP", 5, 42112},
	{"AWOU", 4, 42113},
	{"HAWKINS", 7, 42114},
	{"LUST", 4, 42115},
	{"CORRELATED", 10, 42116},
	{"ASDU", 4, 42117},
	{"AUGUSTINE", 9, 42118},
	{"DOMINION", 8, 42119},
	{"HREG", 4, 42120},
	{"OCOR", 4, 42121},
	{"YDEN", 4, 42122},
	{"OOMB", 4, 42123},
	{"GSWH", 4, 42124},
	{"VUC", 3, 42125},
	{"NDEB", 4, 42126},
	{"VERSES", 6, 42127},
	{"UMBU", 4, 42128},
	{"TYFR", 4, 42129},
	{"OROP", 4, 42130},
	{"GFIE", 4, 42131},
	{"SEAGATE", 7, 42132},
	{"NANOTECHNOLOGY", 14, 42133},
	{"DCUL", 4, 42134},
	{"ASTRONOMICAL", 12, 42135},
	{"OUDI", 4, 42136},
	{"USAD", 4, 42137},
	{"FCHR", 4, 42138},
	{"SOLVENT", 7, 42139},
	{"TOGGLE", 6, 42140},
	{"LUNA", 4, 42141},
	{"LOWR", 4, 42142},
	{"LLMI", 4, 42143},
	{"CHIV", 4, 42144},
	{"UTIM", 4, 42145},
	{"AMPLITUDE", 9, 42146},
	{"COMMERCIALLY", 12, 42147},
	{"WOLFGANG", 8, 42148},
	{"SPACING", 7, 42149},
	{"FRAMEWORKS", 10, 42150},
	{"COMPLETENESS", 12, 42151},
	{"IRREGULAR", 9, 42152},
	{"RGEF", 4, 42153},
	{"NSQU", 4, 42154},
	{"BARKER", 6, 42155},
	{"OGGE", 4, 42156},
	{"SOLIDS", 6, 42157},
	{"MERGERS", 7, 42158},
	{"ANQU", 4, 42159},
	{"CAPTURING", 9, 42160},
	{"FILTRATION", 10, 42161},
	{"CERTIFY", 7, 42162},
	{"CONSULTED", 9, 42163},
	{"REALISED", 8, 42164},
	{"CPUS", 4, 42165},
	{"EDSF", 4, 42166},
	{"JUDE", 4, 42167},
	{"SINGULAR", 8, 42168},
	{"LBEM", 4, 42169},
	{"INCREMENTAL", 11, 42170},
	{"JENNINGS", 8, 42171},
	{"ICBU", 4, 42172},
	{"DEMONS", 6, 42173},
	{"URPE", 4, 42174},
	{"UNACCEPTABLE", 12, 42175},
	{"MICP", 4, 42176},
	{"REDISTRIBUTE", 12, 42177},
	{"COPING", 6, 42178},
	{"ONDF", 4, 42179},
	{"NGCI", 4, 42180},
	{"ELSC", 4, 42181},
	{"IFEC", 4, 42182},
	{"ARFI", 4, 42183},
	{"CORR", 4, 42184},
	{"ORVA", 4, 42185},
	{"BAXTER", 6, 42186},
	{"OUTBREAK", 8, 42187},
	{"ABDOMINAL", 9, 42188},
	{"OREJ", 4, 42189},
	{"TEQU", 4, 42190},
	{"TCRA", 4, 42191},
	{"ECTP", 4, 42192},
	{"LINM", 4, 42193},
	{"VORO", 4, 42194},
	{"OFTU", 4, 42195},
	{"DEFICIENCIES", 12, 42196},
	{"CURVED", 6, 42197},
	{"OLEP", 4, 42198},
	{"GINV", 4, 42199},
	{"MILESTONE", 9, 42200},
	{"ERASE", 5, 42201},
	{"TCUR", 4, 42202},
	{"MASW", 4, 42203},
	{"ADWO", 4, 42204},
	{"BITES", 5, 42205},
	{"PROSE", 5, 42206},
	{"MARX", 4, 42207},
	{"RLFR", 4, 42208},
	{"INCIDENTAL", 10, 42209},
	{"WSWH", 4, 42210},
	{"ARGUING", 7, 42211},
	{"SCALABLE", 8, 42212},
	{"YFRA", 4, 42213},
	{"INTRA", 5, 42214},
	{"GUEW", 4, 42215},
	{"CLOWN", 5, 42216},
	{"URPH", 4, 42217},
	{"SPONTANEOUS", 11, 42218},
	{"GYIN", 4, 42219},
	{"SUMMERS", 7, 42220},
	{"TABOO", 5, 42221},
	{"EQUESTRIAN", 10, 42222},
	{"URBU", 4, 42223},
	{"DEXE", 4, 42224},
	{"EMWA", 4, 42225},
	{"EABR", 4, 42226},
	{"WETLAND", 7, 42227},
	{"OLSON", 5, 42228},
	{"METHODOLOGIES", 13, 42229},
	{"URTT", 4, 42230},
	{"MALICIOUS", 9, 42231},
	{"AMAZED", 6, 42232},
	{"LEGISLATORS", 11, 42233},
	{"VOLCANO", 7, 42234},
	{"CAPACITIES", 10, 42235},
	{"FREMONT", 7, 42236},
	{"YLED", 4, 42237},
	{"OVEB", 4, 42238},
	{"DTWI", 4, 42239},
	{"SKELETON", 8, 42240},
	{"NGYA", 4, 42241},
	{"UMSA", 4, 42242},
	{"DLYS", 4, 42243},
	{"CTSC", 4, 42244},
	{"RDRU", 4, 42245},
	{"SUSPECTS", 8, 42246},
	{"SVOL", 4, 42247},
	{"DISPLACED", 9, 42248},
	{"SOUNDED", 7, 42249},
	{"EXPORTER", 8, 42250},
	{"HONESTY", 7, 42251},
	{"DWARF", 5, 42252},
	{"SDOC", 4, 42253},
	{"TLAR", 4, 42254},
	{"TWWW", 4, 42255},
	{"IDSW", 4, 42256},
	{"WNWH", 4, 42257},
	{"LTAR", 4, 42258},
	{"LLDA", 4, 42259},
	{"LKSA", 4, 42260},
	{"NORTHEASTERN", 12, 42261},
	{"IFDEF", 5, 42262},
	{"KENF", 4, 42263},
	{"IDCA", 4, 42264},
	{"SHOCKS", 6, 42265},
	{"RGOI", 4, 42266},
	{"REWARDING", 9, 42267},
	{"KILLERS", 7, 42268},
	{"BATTALION", 9, 42269},
	{"UELS", 4, 42270},
	{"MULTICULTURAL", 13, 42271},
	{"LASERS", 6, 42272},
	{"CANDID", 6, 42273},
	{"SCHOOLING", 9, 42274},
	{"DATASET", 7, 42275},
	{"LKAN", 4, 42276},
	{"THORNTON", 8, 42277},
	{"SCHOOLGIRL", 10, 42278},
	{"CAESAR", 6, 42279},
	{"SAVERS", 6, 42280},
	{"ZUW", 3, 42281},
	{"WUF", 3, 42282},
	{"POWERPC", 7, 42283},
	{"PINES", 5, 42284},
	{"STEELERS", 8, 42285},
	{"STELLAR", 7, 42286},
	{"RSAP", 4, 42287},
	{"DAVENPORT", 9, 42288},
	{"UGLA", 4, 42289},
	{"LOCATING", 8, 42290},
	{"MONOGRAM", 8, 42291},
	{"PHILIPPE", 8, 42292},
	{"NORL", 4, 42293},
	{"ENHANCES", 8, 42294},
	{"URFO", 4, 42295},
	{"XPED", 4, 42296},
	{"RELATIONAL", 10, 42297},
	{"ORNAMENT", 8, 42298},
	{"DALB", 4, 42299},
	{"ATPU", 4, 42300},
	{"YDAN", 4, 42301},
	{"UTHF", 4, 42302},
	{"GRAFFITI", 8, 42303},
	{"WHOK", 4, 42304},
	{"KWY", 3, 42305},
	{"URSH", 4, 42306},
	{"CASSETTES", 9, 42307},
	{"PUSSIES", 7, 42308},
	{"URGES", 5, 42309},
	{"SOPHIE", 6, 42310},
	{"ACYA", 4, 42311},
	{"DOESNT", 6, 42312},
	{"TIFF", 4, 42313},
	{"SBAL", 4, 42314},
	{"REFRIGERATION", 13, 42315},
	{"ULET", 4, 42316},
	{"TCLU", 4, 42317},
	{"TYWO", 4, 42318},
	{"IGNF", 4, 42319},
	{"ATTACKING", 9, 42320},
	{"MICROSCOPE", 10, 42321},
	{"ERNR", 4, 42322},
	{"ICHU", 4, 42323},
	{"GSLI", 4, 42324},
	{"TBED", 4, 42325},
	{"PSWE", 4, 42326},
	{"LNAM", 4, 42327},
	{"HOUGHTON", 8, 42328},
	{"COUNTDOWN", 9, 42329},
	{"FFOO", 4, 42330},
	{"DECKER", 6, 42331},
	{"EXTERN", 6, 42332},
	{"SORF", 4, 42333},
	{"BADGES", 6, 42334},
	{"ENRON", 5, 42335},
	{"KITTEN", 6, 42336},
	{"CODEC", 5, 42337},
	{"FBUT", 4, 42338},
	{"BROADCASTS", 10, 42339},
	{"BRIDES", 6, 42340},
	{"IXTU", 4, 42341},
	{"CHECKSUM", 8, 42342},
	{"STEALING", 8, 42343},
	{"BULLETS", 7, 42344},
	{"EMPHASIZED", 10, 42345},
	{"ICWI", 4, 42346},
	{"GLOSSY", 6, 42347},
	{"KEME", 4, 42348},
	{"YMIG", 4, 42349},
	{"HAPR", 4, 42350},
	{"INFORMATIONS", 12, 42351},
	{"HAIRED", 6, 42352},
	{"DIRECTIONAL", 11, 42353},
	{"BREEDERS", 8, 42354},
	{"FFSA", 4, 42355},
	{"ALTERATIONS", 11, 42356},
	{"PABLO", 5, 42357},
	{"IRPE", 4, 42358},
	{"LETHAL", 6, 42359},
	{"SGAR", 4, 42360},
	{"UIPP", 4, 42361},
	{"MMAK", 4, 42362},
	{"BIOGRAPHICAL", 12, 42363},
	{"HMIL", 4, 42364},
	{"CONFIRMS", 8, 42365},
	{"FFLI", 4, 42366},
	{"CAVITY", 6, 42367},
	{"RBIA", 4, 42368},
	{"ANRU", 4, 42369},
	{"MCDO", 4, 42370},
	{"YAFF", 4, 42371},
	{"EDHU", 4, 42372},
	{"SSUF", 4, 42373},
	{"MOLDED", 6, 42374},
	{"ONRU", 4, 42375},
	{"LOPP", 4, 42376},
	{"VLADIMIR", 8, 42377},
	{"DIDW", 4, 42378},
	{"FGEN", 4, 42379},
	{"FANC", 4, 42380},
	{"EORM", 4, 42381},
	{"PROBATE", 7, 42382},
	{"PLOI", 4, 42383},
	{"TYSP", 4, 42384},
	{"TERRESTRIAL", 11, 42385},
	{"DECALS", 6, 42386},
	{"COMPLETES", 9, 42387},
	{"BEAMS", 5, 42388},
	{"PROPS", 5, 42389},
	{"INCENSE", 7, 42390},
	{"FORMULATED", 10, 42391},
	{"RLYL", 4, 42392},
	{"UDEO", 4, 42393},
	{"MSOU", 4, 42394},
	{"STOOL", 5, 42395},
	{"RDQU", 4, 42396},
	{"WMAK", 4, 42397},
	{"MACS", 4, 42398},
	{"TOWING", 6, 42399},
	{"WELCH", 5, 42400},
	{"GITW", 4, 42401},
	{"ROSEMARY", 8, 42402},
	{"GBRO", 4, 42403},
	{"ULGA", 4, 42404},
	{"LISL", 4, 42405},
	{"MILLIONAIRE", 11, 42406},
	{"RDIV", 4, 42407},
	{"TURQUOISE", 9, 42408},
	{"OFFM", 4, 42409},
	{"MYWI", 4, 42410},
	{"MEBY", 4, 42411},
	{"LRUN", 4, 42412},
	{"OWIF", 4, 42413},
	{"ARCHIVAL", 8, 42414},
	{"UZF", 3, 42415},
	{"UKJ", 3, 42416},
	{"SEISMIC", 7, 42417},
	{"EXPOSURES", 9, 42418},
	{"NGVO", 4, 42419},
	{"BACCARAT", 8, 42420},
	{"BOONE", 5, 42421},
	{"SUBSTITUTED", 11, 42422},
	{"KWHO", 4, 42423},
	{"EFOF", 4, 42424},
	{"HORDE", 5, 42425},
	{"PAPERWORK", 9, 42426},
	{"MOMMY", 5, 42427},
	{"RSUA", 4, 42428},
	{"EYLI", 4, 42429},
	{"NANNY", 5, 42430},
	{"BYAB", 4, 42431},
	{"HUTCHINSON", 10, 42432},
	{"YREQ", 4, 42433},
	{"SMOKERS", 7, 42434},
	{"COHORT", 6, 42435},
	{"KAFT", 4, 42436},
	{"NABR", 4, 42437},
	{"SUCCESSION", 10, 42438},
	{"DECLINING", 9, 42439},
	{"ALLIANCES", 9, 42440},
	{"SUMS", 4, 42441},
	{"LINEUP", 6, 42442},
	{"LTFO", 4, 42443},
	{"YBLO", 4, 42444},
	{"AVERAGED", 8, 42445},
	{"HOTSPOT", 7, 42446},
	{"BELLEVUE", 8, 42447},
	{"GLACIER", 7, 42448},
	{"PUEBLO", 6, 42449},
	{"WNRE", 4, 42450},
	{"RIGOROUS", 8, 42451},
	{"YSWA", 4, 42452},
	{"GIGABIT", 7, 42453},
	{"MSRE", 4, 42454},
	{"LOTM", 4, 42455},
	{"WORKSHEET", 9, 42456},
	{"ALLOCATE", 8, 42457},
	{"AFTERMATH", 9, 42458},
	{"NEYM", 4, 42459},
	{"ROACH", 5, 42460},
	{"OOLP", 4, 42461},
	{"CLARION", 7, 42462},
	{"OVERRIDE", 8, 42463},
	{"ANGUS", 5, 42464},
	{"ENTHUSIASTIC", 12, 42465},
	{"LAME", 4, 42466},
	{"CONTINUUM", 9, 42467},
	{"ONDD", 4, 42468},
	{"ALLV", 4, 42469},
	{"FENG", 4, 42470},
	{"LCHE", 4, 42471},
	{"BURGUNDY", 8, 42472},
	{"NDRY", 4, 42473},
	{"STRUGGLES", 9, 42474},
	{"OLDG", 4, 42475},
	{"FAREWELL", 8, 42476},
	{"ORMC", 4, 42477},
	{"ALRU", 4, 42478},
	{"VANGUARD", 8, 42479},
	{"NYLONS", 6, 42480},
	{"CHIPSET", 7, 42481},
	{"ARIG", 4, 42482},
	{"NATAL", 5, 42483},
	{"URME", 4, 42484},
	{"PEDR", 4, 42485},
	{"OTRU", 4, 42486},
	{"GLEI", 4, 42487},
	{"OUGL", 4, 42488},
	{"LOWM", 4, 42489},
	{"LOCUS", 5, 42490},
	{"MSNBC", 5, 42491},
	{"HILLARY", 7, 42492},
	{"EVENINGS", 8, 42493},
	{"SKIR", 4, 42494},
	{"DLEC", 4, 42495},
	{"DITU", 4, 42496},
	{"MISSES", 6, 42497},
	{"TROUBLES", 8, 42498},
	{"FACTUAL", 7, 42499},
	{"CARISOPRODOL", 12, 42500},
	{"UMZ", 3, 42501},
	{"OFSM", 4, 42502},
	{"TUTORING", 8, 42503},
	{"SPECTROSCOPY", 12, 42504},
	{"ORYP", 4, 42505},
	{"WSFO", 4, 42506},
	{"GEMSTONE", 8, 42507},
	{"LYYE", 4, 42508},
	{"OMWE", 4, 42509},
	{"PHONEPHONE", 10, 42510},
	{"ELTON", 5, 42511},
	{"RVEI", 4, 42512},
	{"GEMO", 4, 42513},
	{"PURITY", 6, 42514},
	{"SSQU", 4, 42515},
	{"SHAKING", 7, 42516},
	{"RDFR", 4, 42517},
	{"LUCT", 4, 42518},
	{"TVIC", 4, 42519},
	{"RSTQ", 4, 42520},
	{"UNREGISTERED", 12, 42521},
	{"TBIG", 4, 42522},
	{"LBUI", 4, 42523},
	{"WITNESSED", 9, 42524},
	{"CELLAR", 6, 42525},
	{"RDLA", 4, 42526},
	{"DIDH", 4, 42527},
	{"GONZALEZ", 8, 42528},
	{"FRICTION", 8, 42529},
	{"PRONE", 5, 42530},
	{"FFAT", 4, 42531},
	{"VALERIE", 7, 42532},
	{"AFAL", 4, 42533},
	{"ENCLOSURES", 10, 42534},
	{"DIOR", 4, 42535},
	{"DAYJ", 4, 42536},
	{"EQUITABLE", 9, 42537},
	{"EDSW", 4, 42538},
	{"ORDP", 4, 42539},
	{"FUSE", 4, 42540},
	{"GAPA", 4, 42541},
	{"LOBSTER", 7, 42542},
	{"POPS", 4, 42543},
	{"JUDAISM", 7, 42544},
	{"NTMU", 4, 42545},
	{"LASV", 4, 42546},
	{"WAYC", 4, 42547},
	{"TYSU", 4, 42548},
	{"GOLDBERG", 8, 42549},
	{"ATLANTIS", 8, 42550},
	{"IUMI", 4, 42551},
	{"FFUN", 4, 42552},
	{"ELUN", 4, 42553},
	{"HEDD", 4, 42554},
	{"ONIONS", 6, 42555},
	{"IRAB", 4, 42556},
	{"ALSL", 4, 42557},
	{"PRETEEN", 7, 42558},
	{"TYDI", 4, 42559},
	{"BONDING", 7, 42560},
	{"REKN", 4, 42561},
	{"INSURERS", 8, 42562},
	{"PROTOTYPES", 10, 42563},
	{"UNGL", 4, 42564},
	{"CORINTHIANS", 11, 42565},
	{"CROSSES", 7, 42566},
	{"PROACTIVE", 9, 42567},
	{"EEFR", 4, 42568},
	{"GTOK", 4, 42569},
	{"ISSUER", 6, 42570},
	{"SYLVIA", 6, 42571},
	{"FURNACE", 7, 42572},
	{"SPONSORING", 10, 42573},
	{"IRAR", 4, 42574},
	{"WINF", 4, 42575},
	{"TALG", 4, 42576},
	{"POISONING", 9, 42577},
	{"BIGC", 4, 42578},
	{"DOUBLED", 7, 42579},
	{"OQUA", 4, 42580},
	{"MALAYSIAN", 9, 42581},
	{"EAUC", 4, 42582},
	{"CLUES", 5, 42583},
	{"INFLAMMATION", 12, 42584},
	{"QUEB", 4, 42585},
	{"RABBITS", 7, 42586},
	{"PSFO", 4, 42587},
	{"ORAV", 4, 42588},
	{"TRANSPORTED", 11, 42589},
	{"CREWS", 5, 42590},
	{"TOFY", 4, 42591},
	{"EASTON", 6, 42592},
	{"RLAR", 4, 42593},
	{"ICLY", 4, 42594},
	{"GOODWILL", 8, 42595},
	{"SENTENCING", 10, 42596},
	{"TQUE", 4, 42597},
	{"BULLDOGS", 8, 42598},
	{"YPAT", 4, 42599},
	{"WORTHWHILE", 10, 42600},
	{"DVOT", 4, 42601},
	{"TARIFFS", 7, 42602},
	{"NORRIS", 6, 42603},
	{"THFL", 4, 42604},
	{"ETBY", 4, 42605},
	{"DBEB", 4, 42606},
	{"CERVICAL", 8, 42607},
	{"BAPTISM", 7, 42608},
	{"CUTLERY", 7, 42609},
	{"OVERLOOKING", 11, 42610},
	{"RTAX", 4, 42611},
	{"TALLAHASSEE", 11, 42612},
	{"GWAT", 4, 42613},
	{"USERPIC", 7, 42614},
	{"ODFR", 4, 42615},
	{"CKSB", 4, 42616},
	{"ATTRIBUTION", 11, 42617},
	{"LDOW", 4, 42618},
	{"STAFFORDSHIRE", 13, 42619},
	{"FACTORIES", 9, 42620},
	{"SWORDS", 6, 42621},
	{"BYLE", 4, 42622},
	{"ILYP", 4, 42623},
	{"RDCA", 4, 42624},
	{"ADVANCING", 9, 42625},
	{"TIMED", 5, 42626},
	{"YUAN", 4, 42627},
	{"RDBE", 4, 42628},
	{"KETF", 4, 42629},
	{"DIFFERS", 7, 42630},
	{"LAPT", 4, 42631},
	{"NDUL", 4, 42632},
	{"LEASED", 6, 42633},
	{"HMAY", 4, 42634},
	{"SUBSCRIBED", 10, 42635},
	{"LINL", 4, 42636},
	{"RBID", 4, 42637},
	{"STARTERS", 8, 42638},
	{"DARTMOUTH", 9, 42639},
	{"BREWING", 7, 42640},
	{"ARKL", 4, 42641},
	{"COOP", 4, 42642},
	{"UML", 3, 42643},
	{"BUR", 3, 42644},
	{"RAFO", 4, 42645},
	{"BLOSSOM", 7, 42646},
	{"NCOV", 4, 42647},
	{"ILRE", 4, 42648},
	{"NTPU", 4, 42649},
	{"CONFESSIONS", 11, 42650},
	{"XCEE", 4, 42651},
	{"BERGEN", 6, 42652},
	{"LOWERED", 7, 42653},
	{"KRIS", 4, 42654},
	{"RMSW", 4, 42655},
	{"THIEF", 5, 42656},
	{"TPRA", 4, 42657},
	{"PRISONS", 7, 42658},
	{"PICTURED", 8, 42659},
	{"FEMININE", 8, 42660},
	{"SIZEOF", 6, 42661},
	{"GRABBED", 7, 42662},
	{"ROCKING", 7, 42663},
	{"OCKC", 4, 42664},
	{"ORAY", 4, 42665},
	{"OMSC", 4, 42666},
	{"DPUR", 4, 42667},
	{"NICHOLS", 7, 42668},
	{"REGS", 4, 42669},
	{"BLACKWELL", 9, 42670},
	{"SSLY", 4, 42671},
	{"YGB", 3, 42672},
	{"YFEL", 4, 42673},
	{"RIFL", 4, 42674},
	{"VABL", 4, 42675},
	{"BMAR", 4, 42676},
	{"KTOG", 4, 42677},
	{"FULFILLED", 9, 42678},
	{"DAYR", 4, 42679},
	{"SWEETS", 6, 42680},
	{"SAFU", 4, 42681},
	{"NAUTICAL", 8, 42682},
	{"IMPRISONMENT", 12, 42683},
	{"EMPLOYS", 7, 42684},
	{"GUTENBERG", 9, 42685},
	{"BUBBLES", 7, 42686},
	{"MTRA", 4, 42687},
	{"TOFJ", 4, 42688},
	{"ASHTON", 6, 42689},
	{"SHINEDOWN", 9, 42690},
	{"TILW", 4, 42691},
	{"CKSS", 4, 42692},
	{"JUDGMENTS", 9, 42693},
	{"FFWI", 4, 42694},
	{"YDET", 4, 42695},
	{"MUSCULAR", 8, 42696},
	{"GHIG", 4, 42697},
	{"MOTIF", 5, 42698},
	{"ORHU", 4, 42699},
	{"ILLNESSES", 9, 42700},
	{"PLUM", 4, 42701},
	{"ADPO", 4, 42702},
	{"SALOON", 6, 42703},
	{"PROPHECY", 8, 42704},
	{"OLIK", 4, 42705},
	{"ILPR", 4, 42706},
	{"NDSD", 4, 42707},
	{"ELOD", 4, 42708},
	{"LOFT", 4, 42709},
	{"TRAW", 4, 42710},
	{"NGPH", 4, 42711},
	{"DICU", 4, 42712},
	{"YFB", 3, 42713},
	{"YDK", 3, 42714},
	{"LERM", 4, 42715},
	{"RTEX", 4, 42716},
	{"EFLU", 4, 42717},
	{"WALLETS", 7, 42718},
	{"IDENTIFIABLE", 12, 42719},
	{"LDBA", 4, 42720},
	{"RDDE", 4, 42721},
	{"MWHO", 4, 42722},
	{"FACSIMILE", 9, 42723},
	{"HURTS", 5, 42724},
	{"ETHANOL", 7, 42725},
	{"DTRO", 4, 42726},
	{"TSMU", 4, 42727},
	{"HAGR", 4, 42728},
	{"CANNABIS", 8, 42729},
	{"FOLDED", 6, 42730},
	{"RSVP", 4, 42731},
	{"RFEA", 4, 42732},
	{"RFAN", 4, 42733},
	{"SOFIA", 5, 42734},
	{"DYNAMICALLY", 11, 42735},
	{"GRENADINES", 10, 42736},
	{"ECKA", 4, 42737},
	{"LUMP", 4, 42738},
	{"CONSTR", 6, 42739},
	{"DISPOSED", 8, 42740},
	{"RXF", 3, 42741},
	{"OBAR", 4, 42742},
	{"SUBTITLE", 8, 42743},
	{"CHESTNUT", 8, 42744},
	{"LIBRARIANS", 10, 42745},
	{"ENGRAVED", 8, 42746},
	{"WERH", 4, 42747},
	{"MANSON", 6, 42748},
	{"HRIV", 4, 42749},
	{"AVAG", 4, 42750},
	{"OWSK", 4, 42751},
	{"DNAP", 4, 42752},
	{"RDOU", 4, 42753},
	{"UALW", 4, 42754},
	{"RVEL", 4, 42755},
	{"LEYH", 4, 42756},
	{"MHAV", 4, 42757},
	{"YHIM", 4, 42758},
	{"AUTOCAD", 7, 42759},
	{"PTAB", 4, 42760},
	{"PASTORAL", 8, 42761},
	{"UNPAID", 6, 42762},
	{"GHOSTS", 6, 42763},
	{"NLYE", 4, 42764},
	{"POWERBOOK", 9, 42765},
	{"DOUBTS", 6, 42766},
	{"LOCALITY", 8, 42767},
	{"LCLI", 4, 42768},
	{"DAWI", 4, 42769},
	{"OLME", 4, 42770},
	{"NUPT", 4, 42771},
	{"COWB", 4, 42772},
	{"SUBSTANTIVE", 11, 42773},
	{"LWEA", 4, 42774},
	{"LDOR", 4, 42775},
	{"BULLETINS", 9, 42776},
	{"WORRIES", 7, 42777},
	{"OLBO", 4, 42778},
	{"EMIU", 4, 42779},
	{"GLEP", 4, 42780},
	{"KEVE", 4, 42781},
	{"REJECTS", 7, 42782},
	{"SPEAR", 5, 42783},
	{"YBIL", 4, 42784},
	{"EYFR", 4, 42785},
	{"IEDP", 4, 42786},
	{"NIGEL", 5, 42787},
	{"REFEREE", 7, 42788},
	{"OFUL", 4, 42789},
	{"IPRE", 4, 42790},
	{"TRANSPORTER", 11, 42791},
	{"JOLIE", 5, 42792},
	{"OOKU", 4, 42793},
	{"BROADLY", 7, 42794},
	{"ELFD", 4, 42795},
	{"ETHEREAL", 8, 42796},
	{"OLFC", 4, 42797},
	{"CROSSROADS", 10, 42798},
	{"CONSTRUCTING", 12, 42799},
	{"SMOOTHLY", 8, 42800},
	{"ICEV", 4, 42801},
	{"PARSONS", 7, 42802},
	{"YSAW", 4, 42803},
	{"ADYI", 4, 42804},
	{"HROM", 4, 42805},
	{"THJU", 4, 42806},
	{"INFINITI", 8, 42807},
	{"BLANC", 5, 42808},
	{"EYPA", 4, 42809},
	{"TAXC", 4, 42810},
	{"BOUNDED", 7, 42811},
	{"APAL", 4, 42812},
	{"PPL", 3, 42813},
	{"WILLIAMSBURG", 12, 42814},
	{"FONL", 4, 42815},
	{"EWEW", 4, 42816},
	{"BIRCH", 5, 42817},
	{"PPYT", 4, 42818},
	{"ALEB", 4, 42819},
	{"SUPP", 4, 42820},
	{"SLASH", 5, 42821},
	{"SNYDER", 6, 42822},
	{"BUDGETING", 9, 42823},
	{"EXERCISED", 9, 42824},
	{"IDMO", 4, 42825},
	{"BACKPACKS", 9, 42826},
	{"DETECTING", 9, 42827},
	{"RESALE", 6, 42828},
	{"AROC", 4, 42829},
	{"MIKES", 5, 42830},
	{"HOWELL", 6, 42831},
	{"DIGESTIVE", 9, 42832},
	{"SCALAR", 6, 42833},
	{"ENTERTAIN", 9, 42834},
	{"CINDERELLA", 10, 42835},
	{"UNRESOLVED", 10, 42836},
	{"SESAME", 6, 42837},
	{"DUCT", 4, 42838},
	{"TOUCHES", 7, 42839},
	{"VEUN", 4, 42840},
	{"NDSY", 4, 42841},
	{"DPEN", 4, 42842},
	{"SEIKO", 5, 42843},
	{"VEBR", 4, 42844},
	{"RGAI", 4, 42845},
	{"ELECTROMAGNETIC", 15, 42846},
	{"ARIAL", 5, 42847},
	{"JOANNE", 6, 42848},
	{"HOUSEWIFE", 9, 42849},
	{"ZOOFILIA", 8, 42850},
	{"ZJR", 3, 42851},
	{"EYTR", 4, 42852},
	{"RYSL", 4, 42853},
	{"PURSUED", 7, 42854},
	{"VALIDATED", 9, 42855},
	{"LUEA", 4, 42856},
	{"CORVETTE", 8, 42857},
	{"YASK", 4, 42858},
	{"ULTF", 4, 42859},
	{"YACHTS", 6, 42860},
	{"DDAR", 4, 42861},
	{"STACY", 5, 42862},
	{"YPHO", 4, 42863},
	{"CHRISTIE", 8, 42864},
	{"UNRELATED", 9, 42865},
	{"LEVI", 4, 42866},
	{"ANNOTATE", 8, 42867},
	{"STIMULATING", 11, 42868},
	{"JOOMLA", 6, 42869},
	{"MISUSE", 6, 42870},
	{"LFAM", 4, 42871},
	{"CKYA", 4, 42872},
	{"HELIX", 5, 42873},
	{"COSMOS", 6, 42874},
	{"DIXIE", 5, 42875},
	{"ENFORCED", 8, 42876},
	{"SVEG", 4, 42877},
	{"ATJU", 4, 42878},
	{"LEGION", 6, 42879},
	{"FULFILLMENT", 11, 42880},
	{"PWHE", 4, 42881},
	{"OMLO", 4, 42882},
	{"DDOC", 4, 42883},
	{"BIOMASS", 7, 42884},
	{"PBET", 4, 42885},
	{"UALO", 4, 42886},
	{"ASSERTION", 9, 42887},
	{"HIERARCHICAL", 12, 42888},
	{"LESIONS", 7, 42889},
	{"VQU", 3, 42890},
	{"SHOOK", 5, 42891},
	{"LINCOLNSHIRE", 12, 42892},
	{"RKEN", 4, 42893},
	{"FINANCED", 8, 42894},
	{"RVOI", 4, 42895},
	{"DISMISSAL", 9, 42896},
	{"SURNAMES", 8, 42897},
	{"WORU", 4, 42898},
	{"UIDA", 4, 42899},
	{"EYEL", 4, 42900},
	{"RECONDITIONED", 13, 42901},
	{"JRV", 3, 42902},
	{"SHOCKING", 8, 42903},
	{"OUAL", 4, 42904},
	{"ALLERGIC", 8, 42905},
	{"OVERLAND", 8, 42906},
	{"PROLONGED", 9, 42907},
	{"DEBR", 4, 42908},
	{"ISAIAH", 6, 42909},
	{"BACKBONE", 8, 42910},
	{"LAGR", 4, 42911},
	{"UNANIMOUSLY", 11, 42912},
	{"ELIMINATES", 10, 42913},
	{"SAUSAGE", 7, 42914},
	{"AMLE", 4, 42915},
	{"ADDICT", 6, 42916},
	{"AYCH", 4, 42917},
	{"BYDA", 4, 42918},
	{"CHBO", 4, 42919},
	{"MATTE", 5, 42920},
	{"FGOO", 4, 42921},
	{"UNCOMMON", 8, 42922},
	{"CENTRALIZED", 11, 42923},
	{"STRATFORD", 9, 42924},
	{"HEIDI", 5, 42925},
	{"DFUR", 4, 42926},
	{"RMAJ", 4, 42927},
	{"GEOU", 4, 42928},
	{"EYSP", 4, 42929},
	{"MELANIE", 7, 42930},
	{"KKW", 3, 42931},
	{"SLER", 4, 42932},
	{"OBJECTIONS", 10, 42933},
	{"ILOU", 4, 42934},
	{"FEXE", 4, 42935},
	{"CKPA", 4, 42936},
	{"UNPUBLISHED", 11, 42937},
	{"SLAUGHTER", 9, 42938},
	{"LAYM", 4, 42939},
	{"HBRO", 4, 42940},
	{"ENLIGHTENMENT", 13, 42941},
	{"JUNIORS", 7, 42942},
	{"DROA", 4, 42943},
	{"ROCKETS", 7, 42944},
	{"XUM", 3, 42945},
	{"FXC", 3, 42946},
	{"SECUNIA", 7, 42947},
	{"METERING", 8, 42948},
	{"SEYMOUR", 7, 42949},
	{"GENETICALLY", 11, 42950},
	{"ZEBRA", 5, 42951},
	{"UDER", 4, 42952},
	{"LERH", 4, 42953},
	{"RUNWAY", 6, 42954},
	{"ARITHMETIC", 10, 42955},
	{"LVIS", 4, 42956},
	{"NOWD", 4, 42957},
	{"ADMITS", 6, 42958},
	{"DEAG", 4, 42959},
	{"BOMBAY", 6, 42960},
	{"ORIGINALS", 9, 42961},
	{"ENRICHMENT", 10, 42962},
	{"CHENNAI", 7, 42963},
	{"MILFORD", 7, 42964},
	{"BUCKLE", 6, 42965},
	{"BARTLETT", 8, 42966},
	{"FETCH", 5, 42967},
	{"KITCHENS", 8, 42968},
	{"ASSHOLE", 7, 42969},
	{"HOFC", 4, 42970},
	{"DIVERS", 6, 42971},
	{"FAROE", 5, 42972},
	{"OROC", 4, 42973},
	{"TOWNSEND", 8, 42974},
	{"BLACKBURN", 9, 42975},
	{"GLENDALE", 8, 42976},
	{"SPEEDWAY", 8, 42977},
	{"HECY", 4, 42978},
	{"FOUNDERS", 8, 42979},
	{"SWEATSHIRTS", 11, 42980},
	{"SUNDAYS", 7, 42981},
	{"ORTD", 4, 42982},
	{"FIRI", 4, 42983},
	{"UPSIDE", 6, 42984},
	{"HIPM", 4, 42985},
	{"ADMIRAL", 7, 42986},
	{"SRIV", 4, 42987},
	{"SECL", 4, 42988},
	{"GASC", 4, 42989},
	{"EPOU", 4, 42990},
	{"DEOG", 4, 42991},
	{"LOFW", 4, 42992},
	{"SANDWICHES", 10, 42993},
	{"SINCLAIR", 8, 42994},
	{"BOILER", 6, 42995},
	{"YUSI", 4, 42996},
	{"YPOT", 4, 42997},
	{"OEXC", 4, 42998},
	{"AULS", 4, 42999},
	{"GEDU", 4, 43000},
	{"YBRA", 4, 43001},
	{"ACTIVEX", 7, 43002},
	{"LOGON", 5, 43003},
	{"INDUCE", 6, 43004},
	{"ANNAPOLIS", 9, 43005},
	{"PADDING", 7, 43006},
	{"EIRU", 4, 43007},
	{"YCRO", 4, 43008},
	{"NROB", 4, 43009},
	{"RECRUITER", 9, 43010},
	{"OODG", 4, 43011},
	{"POPCORN", 7, 43012},
	{"ESPANOL", 7, 43013},
	{"DISADVANTAGED", 13, 43014},
	{"TRONG", 5, 43015},
	{"DIAGONAL", 8, 43016},
	{"RPAN", 4, 43017},
	{"ARSR", 4, 43018},
	{"MOFS", 4, 43019},
	{"CRACKED", 7, 43020},
	{"MJUS", 4, 43021},
	{"DEBTOR", 6, 43022},
	{"POLK", 4, 43023},
	{"EMYA", 4, 43024},
	{"YAFE", 4, 43025},
	{"SHEAR", 5, 43026},
	{"NFEL", 4, 43027},
	{"MORTAL", 6, 43028},
	{"SPLU", 4, 43029},
	{"REBL", 4, 43030},
	{"YHAP", 4, 43031},
	{"TROB", 4, 43032},
	{"UTSP", 4, 43033},
	{"RSBO", 4, 43034},
	{"FRANCHISES", 10, 43035},
	{"IKEG", 4, 43036},
	{"RAMS", 4, 43037},
	{"CLEANSING", 9, 43038},
	{"MFR", 3, 43039},
	{"RCEC", 4, 43040},
	{"LFTI", 4, 43041},
	{"GGIE", 4, 43042},
	{"HMMM", 4, 43043},
	{"GENOMIC", 7, 43044},
	{"GOWN", 4, 43045},
	{"HELPDESK", 8, 43046},
	{"LBEE", 4, 43047},
	{"TEPL", 4, 43048},
	{"PONDS", 5, 43049},
	{"ARCHERY", 7, 43050},
	{"REFUSES", 7, 43051},
	{"YVAL", 4, 43052},
	{"FULW", 4, 43053},
	{"FULB", 4, 43054},
	{"UPWH", 4, 43055},
	{"ICKM", 4, 43056},
	{"DADM", 4, 43057},
	{"EXCLUDES", 8, 43058},
	{"OWSP", 4, 43059},
	{"SABBATH", 7, 43060},
	{"LLEI", 4, 43061},
	{"TRUMP", 5, 43062},
	{"ESCAPED", 7, 43063},
	{"PRECURSOR", 9, 43064},
	{"MATES", 5, 43065},
	{"SGOL", 4, 43066},
	{"ADHD", 4, 43067},
	{"AVIAN", 5, 43068},
	{"ORYM", 4, 43069},
	{"UDAN", 4, 43070},
	{"STELLA", 6, 43071},
	{"VISAS", 5, 43072},
	{"UCZ", 3, 43073},
	{"MATRICES", 8, 43074},
	{"UKEE", 4, 43075},
	{"WBUT", 4, 43076},
	{"UPPR", 4, 43077},
	{"ANYWAYS", 7, 43078},
	{"ATMY", 4, 43079},
	{"XTREME", 6, 43080},
	{"RAWE", 4, 43081},
	{"PASSAGES", 8, 43082},
	{"AILL", 4, 43083},
	{"TOPC", 4, 43084},
	{"EDVO", 4, 43085},
	{"ETIOLOGY", 8, 43086},
	{"OWFA", 4, 43087},
	{"LOVI", 4, 43088},
	{"RANF", 4, 43089},
	{"TLEL", 4, 43090},
	{"LPEN", 4, 43091},
	{"CEREAL", 6, 43092},
	{"HIPF", 4, 43093},
	{"XYEA", 4, 43094},
	{"KETR", 4, 43095},
	{"COMPREHENSION", 13, 43096},
	{"MYHE", 4, 43097},
	{"DTOV", 4, 43098},
	{"RESOLVING", 9, 43099},
	{"VEDP", 4, 43100},
	{"MELLON", 6, 43101},
	{"EVEB", 4, 43102},
	{"DRILLS", 6, 43103},
	{"WEBMD", 5, 43104},
	{"ALEXANDRA", 9, 43105},
	{"CHAMP", 5, 43106},
	{"PERSONALISED", 12, 43107},
	{"HOSPICE", 7, 43108},
	{"ZERODEGREES", 11, 43109},
	{"RUMB", 4, 43110},
	{"AGREEING", 8, 43111},
	{"RSCL", 4, 43112},
	{"EXHIBITOR", 9, 43113},
	{"REXC", 4, 43114},
	{"RENTED", 6, 43115},
	{"DEDUCTIONS", 10, 43116},
	{"HARRISBURG", 10, 43117},
	{"GOOU", 4, 43118},
	{"ULPT", 4, 43119},
	{"BRUSHED", 7, 43120},
	{"AUGMENTATION", 12, 43121},
	{"ELAG", 4, 43122},
	{"ARKN", 4, 43123},
	{"YISC", 4, 43124},
	{"AKLA", 4, 43125},
	{"ANNUITY", 7, 43126},
	{"ASSORTMENT", 10, 43127},
	{"CREDIBLE", 8, 43128},
	{"ELLL", 4, 43129},
	{"VEMU", 4, 43130},
	{"ARKB", 4, 43131},
	{"SPORTSWEAR", 10, 43132},
	{"CULTURED", 8, 43133},
	{"RLOV", 4, 43134},
	{"IMPORTING", 9, 43135},
	{"RECAP", 5, 43136},
	{"YTAX", 4, 43137},
	{"TODDLERS", 8, 43138},
	{"LLEM", 4, 43139},
	{"ERPH", 4, 43140},
	{"ASTRO", 5, 43141},
	{"OCUR", 4, 43142},
	{"RBUI", 4, 43143},
	{"KEWE", 4, 43144},
	{"CHANEL", 6, 43145},
	{"SPARKLING", 9, 43146},
	{"JABBER", 6, 43147},
	{"BINDINGS", 8, 43148},
	{"RALN", 4, 43149},
	{"CONVINCING", 10, 43150},
	{"ROTATE", 6, 43151},
	{"FLAWS", 5, 43152},
	{"RTYC", 4, 43153},
	{"TRACING", 7, 43154},
	{"DEVIATIONS", 10, 43155},
	{"RCEF", 4, 43156},
	{"INCOMES", 7, 43157},
	{"FEMA", 4, 43158},
	{"SUBWOOFER", 9, 43159},
	{"AMORTIZATION", 12, 43160},
	{"NEUROLOGY", 9, 43161},
	{"UPLI", 4, 43162},
	{"YKIL", 4, 43163},
	{"DCUT", 4, 43164},
	{"YCAT", 4, 43165},
	{"JEREMIAH", 8, 43166},
	{"SAPIENS", 7, 43167},
	{"CEVE", 4, 43168},
	{"OLSEN", 5, 43169},
	{"HEMD", 4, 43170},
	{"SERBIAN", 7, 43171},
	{"RADIATOR", 8, 43172},
	{"YEDU", 4, 43173},
	{"UPRI", 4, 43174},
	{"COMPETENCIES", 12, 43175},
	{"FAUS", 4, 43176},
	{"RESTORING", 9, 43177},
	{"FSCI", 4, 43178},
	{"VEAW", 4, 43179},
	{"SANCHEZ", 7, 43180},
	{"RUSHING", 7, 43181},
	{"LWEL", 4, 43182},
	{"HABL", 4, 43183},
	{"BEHOLD", 6, 43184},
	{"CHPL", 4, 43185},
	{"AMHERST", 7, 43186},
	{"ALTERATION", 10, 43187},
	{"HOTSPOTS", 8, 43188},
	{"WMOR", 4, 43189},
	{"LOWW", 4, 43190},
	{"NORP", 4, 43191},
	{"TRAINEE", 7, 43192},
	{"BYSU", 4, 43193},
	{"NIELSEN", 7, 43194},
	{"ATDR", 4, 43195},
	{"GFIN", 4, 43196},
	{"PODCASTING", 10, 43197},
	{"GSCA", 4, 43198},
	{"CHSP", 4, 43199},
	{"MURDERED", 8, 43200},
	{"FGOD", 4, 43201},
	{"FTRE", 4, 43202},
	{"CENTENNIAL", 10, 43203},
	{"ELDC", 4, 43204},
	{"BLUEGRASS", 9, 43205},
	{"MERD", 4, 43206},
	{"DENW", 4, 43207},
	{"OORL", 4, 43208},
	{"ILLK", 4, 43209},
	{"IGGI", 4, 43210},
	{"HAZEL", 5, 43211},
	{"GHOF", 4, 43212},
	{"LEDGER", 6, 43213},
	{"YLEV", 4, 43214},
	{"LDRU", 4, 43215},
	{"SCARLET", 7, 43216},
	{"CRUSHED", 7, 43217},
	{"ACRONYMS", 8, 43218},
	{"OFGL", 4, 43219},
	{"LAUGHS", 6, 43220},
	{"NWOM", 4, 43221},
	{"CONNIE", 6, 43222},
	{"AUTOGRAPHED", 11, 43223},
	{"AGUI", 4, 43224},
	{"REFERENDUM", 10, 43225},
	{"MODULATION", 10, 43226},
	{"STATUES", 7, 43227},
	{"RFAL", 4, 43228},
	{"DEPTHS", 6, 43229},
	{"SPICES", 6, 43230},
	{"COMMUNION", 9, 43231},
	{"LOADER", 6, 43232},
	{"LINB", 4, 43233},
	{"DNTC", 4, 43234},
	{"BLYI", 4, 43235},
	{"UNCERTAINTIES", 13, 43236},
	{"COLONIES", 8, 43237},
	{"YORT", 4, 43238},
	{"ORKM", 4, 43239},
	{"SFOC", 4, 43240},
	{"FOLLOWERS", 9, 43241},
	{"OCKF", 4, 43242},
	{"CALDWELL", 8, 43243},
	{"DREQ", 4, 43244},
	{"FTOU", 4, 43245},
	{"LATENCY", 7, 43246},
	{"DASB", 4, 43247},
	{"THEMED", 6, 43248},
	{"MESSY", 5, 43249},
	{"SQUADRON", 8, 43250},
	{"DPET", 4, 43251},
	{"YINL", 4, 43252},
	{"DMC", 3, 43253},
	{"LPAT", 4, 43254},
	{"RUPEE", 5, 43255},
	{"FHEW", 4, 43256},
	{"MENTS", 5, 43257},
	{"RLEF", 4, 43258},
	{"DEMOLITION", 10, 43259},
	{"WEMA", 4, 43260},
	{"IRENE", 5, 43261},
	{"YFEA", 4, 43262},
	{"EDCE", 4, 43263},
	{"DDUE", 4, 43264},
	{"EYMI", 4, 43265},
	{"EMPOWERMENT", 11, 43266},
	{"HROP", 4, 43267},
	{"DILY", 4, 43268},
	{"FELONY", 6, 43269},
	{"LYYO", 4, 43270},
	{"LUNGS", 5, 43271},
	{"MONUMENTS", 9, 43272},
	{"GINB", 4, 43273},
	{"VERONICA", 8, 43274},
	{"NCUL", 4, 43275},
	{"FILTERED", 8, 43276},
	{"DDAM", 4, 43277},
	{"REPLACEMENTS", 12, 43278},
	{"GROWERS", 7, 43279},
	{"SRIC", 4, 43280},
	{"VINCI", 5, 43281},
	{"SUBTITLES", 9, 43282},
	{"NGUE", 4, 43283},
	{"GCSE", 4, 43284},
	{"ACUPUNCTURE", 11, 43285},
	{"LTOM", 4, 43286},
	{"WORKLOAD", 8, 43287},
	{"ORSR", 4, 43288},
	{"FCRE", 4, 43289},
	{"DSYS", 4, 43290},
	{"YMOT", 4, 43291},
	{"CLED", 4, 43292},
	{"ACKNOWLEDGEMENT", 15, 43293},
	{"HIGHLIGHTING", 12, 43294},
	{"DULY", 4, 43295},
	{"ROASTED", 7, 43296},
	{"TENDERS", 7, 43297},
	{"INVITING", 8, 43298},
	{"YTRE", 4, 43299},
	{"GRASSROOTS", 10, 43300},
	{"MICK", 4, 43301},
	{"GENTOO", 6, 43302},
	{"REDEVELOPMENT", 13, 43303},
	{"MUSTARD", 7, 43304},
	{"STRAIT", 6, 43305},
	{"MASTERPIECE", 11, 43306},
	{"TUPO", 4, 43307},
	{"OBEY", 4, 43308},
	{"CELLPHONE", 9, 43309},
	{"DONKEY", 6, 43310},
	{"DYCO", 4, 43311},
	{"EWSF", 4, 43312},
	{"BEFR", 4, 43313},
	{"JACKS", 5, 43314},
	{"LYJU", 4, 43315},
	{"NGJA", 4, 43316},
	{"CONCEIVED", 9, 43317},
	{"TRIGGERED", 9, 43318},
	{"BOASTS", 6, 43319},
	{"PRAYING", 7, 43320},
	{"GEDP", 4, 43321},
	{"OPPR", 4, 43322},
	{"MULTIPLY", 8, 43323},
	{"YISL", 4, 43324},
	{"FRONTGATE", 9, 43325},
	{"RADIAL", 6, 43326},
	{"WERL", 4, 43327},
	{"NTYF", 4, 43328},
	{"DCER", 4, 43329},
	{"MARE", 4, 43330},
	{"INSTRUCTED", 10, 43331},
	{"STOLE", 5, 43332},
	{"KIRBY", 5, 43333},
	{"WOLV", 4, 43334},
	{"ARMOUR", 6, 43335},
	{"CHPE", 4, 43336},
	{"SUMMARIZED", 10, 43337},
	{"AVALANCHE", 9, 43338},
	{"TVAR", 4, 43339},
	{"RWES", 4, 43340},
	{"IRDB", 4, 43341},
	{"NORTHAMPTON", 11, 43342},
	{"UPLOADING", 9, 43343},
	{"HMUS", 4, 43344},
	{"MANUSCRIPTS", 11, 43345},
	{"IXOF", 4, 43346},
	{"LETM", 4, 43347},
	{"MANAGERIAL", 10, 43348},
	{"HRIL", 4, 43349},
	{"CARY", 4, 43350},
	{"YSYS", 4, 43351},
	{"VAGE", 4, 43352},
	{"TARB", 4, 43353},
	{"CELINE", 6, 43354},
	{"EXHIBITED", 9, 43355},
	{"DISCIPLES", 9, 43356},
	{"SHAVING", 7, 43357},
	{"LKEE", 4, 43358},
	{"QUOR", 4, 43359},
	{"FINEPIX", 7, 43360},
	{"BISHOPS", 7, 43361},
	{"XTDA", 4, 43362},
	{"USOR", 4, 43363},
	{"DESTROYING", 10, 43364},
	{"HUMOROUS", 8, 43365},
	{"TSPU", 4, 43366},
	{"TONNES", 6, 43367},
	{"HYPERMAIL", 9, 43368},
	{"NDSK", 4, 43369},
	{"RLAW", 4, 43370},
	{"NLIM", 4, 43371},
	{"GASW", 4, 43372},
	{"THUNDERBIRD", 11, 43373},
	{"LGEN", 4, 43374},
	{"OURK", 4, 43375},
	{"UALB", 4, 43376},
	{"CORONA", 6, 43377},
	{"YTRU", 4, 43378},
	{"GRIFFITH", 8, 43379},
	{"INVESTIGATIVE", 13, 43380},
	{"LETRAS", 6, 43381},
	{"BYLAWS", 6, 43382},
	{"SDOU", 4, 43383},
	{"ERECTION", 8, 43384},
	{"QUASI", 5, 43385},
	{"WMV", 3, 43386},
	{"ENERGETIC", 9, 43387},
	{"DISTURBANCE", 11, 43388},
	{"SAUNDERS", 8, 43389},
	{"RIBBONS", 7, 43390},
	{"UALD", 4, 43391},
	{"UMET", 4, 43392},
	{"FACESITTING", 11, 43393},
	{"RGLA", 4, 43394},
	{"EXILE", 5, 43395},
	{"MEDP", 4, 43396},
	{"LGOO", 4, 43397},
	{"WGY", 3, 43398},
	{"BREASTFEEDING", 13, 43399},
	{"UPAL", 4, 43400},
	{"BILDER", 6, 43401},
	{"RESIDE", 6, 43402},
	{"MCCARTNEY", 9, 43403},
	{"ANGLO", 5, 43404},
	{"LLEF", 4, 43405},
	{"CASHIER", 7, 43406},
	{"LENB", 4, 43407},
	{"KATHRYN", 7, 43408},
	{"DEOR", 4, 43409},
	{"FMAT", 4, 43410},
	{"BUTTERFLIES", 11, 43411},
	{"RANDOMIZED", 10, 43412},
	{"KNOTS", 5, 43413},
	{"FLEA", 4, 43414},
	{"FIMP", 4, 43415},
	{"AGEG", 4, 43416},
	{"MOTIVATIONAL", 12, 43417},
	{"OFFENCES", 8, 43418},
	{"HLAR", 4, 43419},
	{"PALS", 4, 43420},
	{"GRATUITE", 8, 43421},
	{"GERRY", 5, 43422},
	{"TAXR", 4, 43423},
	{"LLRA", 4, 43424},
	{"OLDL", 4, 43425},
	{"CELEBRATES", 10, 43426},
	{"LLCR", 4, 43427},
	{"ARMENIAN", 8, 43428},
	{"LONGITUDINAL", 12, 43429},
	{"OALB", 4, 43430},
	{"HISTORIANS", 10, 43431},
	{"REALITIES", 9, 43432},
	{"KAPPA", 5, 43433},
	{"MENTIONS", 8, 43434},
	{"SAMSON", 6, 43435},
	{"NEUROSCIENCE", 12, 43436},
	{"BLENDER", 7, 43437},
	{"JUMPS", 5, 43438},
	{"FLEMING", 7, 43439},
	{"FFLO", 4, 43440},
	{"BYBR", 4, 43441},
	{"BLASTER", 7, 43442},
	{"YORD", 4, 43443},
	{"DDAT", 4, 43444},
	{"TVIR", 4, 43445},
	{"REMEDIATION", 11, 43446},
	{"WASTING", 7, 43447},
	{"DECODER", 7, 43448},
	{"FELO", 4, 43449},
	{"GENOCIDE", 8, 43450},
	{"ACCLAIMED", 9, 43451},
	{"HEATHROW", 8, 43452},
	{"INDY", 4, 43453},
	{"URWI", 4, 43454},
	{"MORROW", 6, 43455},
	{"PANTERA", 7, 43456},
	{"GLITTER", 7, 43457},
	{"GIOVANNI", 8, 43458},
	{"OCKY", 4, 43459},
	{"SIDEBAR", 7, 43460},
	{"AUTHORED", 8, 43461},
	{"LASTED", 6, 43462},
	{"RAOR", 4, 43463},
	{"SNOOP", 5, 43464},
	{"AWHILE", 6, 43465},
	{"CKEL", 4, 43466},
	{"WINERY", 6, 43467},
	{"HYAR", 4, 43468},
	{"YSUN", 4, 43469},
	{"OWSF", 4, 43470},
	{"KEDD", 4, 43471},
	{"GOFH", 4, 43472},
	{"YVIS", 4, 43473},
	{"SCALED", 6, 43474},
	{"LLUP", 4, 43475},
	{"YABL", 4, 43476},
	{"CONTINGENCY", 11, 43477},
	{"PHOTON", 6, 43478},
	{"RKWH", 4, 43479},
	{"WILTSHIRE", 9, 43480},
	{"IXYE", 4, 43481},
	{"VAGUE", 5, 43482},
	{"DDIF", 4, 43483},
	{"OVERLAY", 7, 43484},
	{"ICBE", 4, 43485},
	{"FXF", 3, 43486},
	{"WRAPS", 5, 43487},
	{"DNTR", 4, 43488},
	{"SYAR", 4, 43489},
	{"CONSTITUENTS", 12, 43490},
	{"RUSTY", 5, 43491},
	{"PHARMA", 6, 43492},
	{"HERD", 4, 43493},
	{"MBEN", 4, 43494},
	{"HANDICAPPED", 11, 43495},
	{"GBEA", 4, 43496},
	{"OMFI", 4, 43497},
	{"BIDD", 4, 43498},
	{"RSGO", 4, 43499},
	{"ORJA", 4, 43500},
	{"OARR", 4, 43501},
	{"EXPORTED", 8, 43502},
	{"GMUS", 4, 43503},
	{"FAYETTEVILLE", 12, 43504},
	{"CHAMPAIGN", 9, 43505},
	{"RSRA", 4, 43506},
	{"WARNS", 5, 43507},
	{"EYKN", 4, 43508},
	{"EGEL", 4, 43509},
	{"DLAU", 4, 43510},
	{"PAKISTANI", 9, 43511},
	{"HARMLESS", 8, 43512},
	{"GHRE", 4, 43513},
	{"STING", 5, 43514},
	{"ELFF", 4, 43515},
	{"URBANA", 6, 43516},
	{"BRAVO", 5, 43517},
	{"BELIEVERS", 9, 43518},
	{"IMWH", 4, 43519},
	{"GUEC", 4, 43520},
	{"SECSG", 5, 43521},
	{"FRANCO", 6, 43522},
	{"ANNOUNCING", 10, 43523},
	{"NUEL", 4, 43524},
	{"RDSR", 4, 43525},
	{"DISPERSION", 10, 43526},
	{"TRIVIUM", 7, 43527},
	{"SHOWROOM", 8, 43528},
	{"SWAROVSKI", 9, 43529},
	{"FEWI", 4, 43530},
	{"RESTING", 7, 43531},
	{"MISSILES", 8, 43532},
	{"PERSISTENCE", 11, 43533},
	{"COARSE", 6, 43534},
	{"CONTINENTS", 10, 43535},
	{"FBRO", 4, 43536},
	{"LITER", 5, 43537},
	{"EYCH", 4, 43538},
	{"CARPETS", 7, 43539},
	{"GHDE", 4, 43540},
	{"ARCR", 4, 43541},
	{"CHGR", 4, 43542},
	{"UDYO", 4, 43543},
	{"LBAR", 4, 43544},
	{"ORDL", 4, 43545},
	{"SUBMARINE", 9, 43546},
	{"BEBU", 4, 43547},
	{"BLESSINGS", 9, 43548},
	{"LERB", 4, 43549},
	{"BRENDAN", 7, 43550},
	{"PREVAILING", 10, 43551},
	{"ORIGINATED", 10, 43552},
	{"UTGO", 4, 43553},
	{"EWOL", 4, 43554},
	{"RABR", 4, 43555},
	{"CONDOSAVER", 10, 43556},
	{"FAGR", 4, 43557},
	{"SCULPTURES", 10, 43558},
	{"RFIG", 4, 43559},
	{"AMEX", 4, 43560},
	{"INTRINSIC", 9, 43561},
	{"CLASSICVACATIONS", 16, 43562},
	{"DPIT", 4, 43563},
	{"BLACKPOOL", 9, 43564},
	{"THOUGHTFUL", 10, 43565},
	{"NICHT", 5, 43566},
	{"ARCHER", 6, 43567},
	{"AMWO", 4, 43568},
	{"UTUP", 4, 43569},
	{"RDIC", 4, 43570},
	{"HERTFORDSHIRE", 13, 43571},
	{"INUYASHA", 8, 43572},
	{"YDEL", 4, 43573},
	{"RVEH", 4, 43574},
	{"NOMINEES", 8, 43575},
	{"OFOV", 4, 43576},
	{"AHUM", 4, 43577},
	{"WARMER", 6, 43578},
	{"CUZ", 3, 43579},
	{"GHPO", 4, 43580},
	{"BEWO", 4, 43581},
	{"VIEWSONIC", 9, 43582},
	{"DRYERS", 6, 43583},
	{"YCHR", 4, 43584},
	{"CALF", 4, 43585},
	{"ODUL", 4, 43586},
	{"FUJIFILM", 8, 43587},
	{"BASIL", 5, 43588},
	{"ZEDF", 4, 43589},
	{"OLOW", 4, 43590},
	{"AYJU", 4, 43591},
	{"HALLMARK", 8, 43592},
	{"COUNTERPARTS", 12, 43593},
	{"PACED", 5, 43594},
	{"NYPO", 4, 43595},
	{"EUNL", 4, 43596},
	{"ENGL", 4, 43597},
	{"RTBY", 4, 43598},
	{"GROUPED", 7, 43599},
	{"RDOR", 4, 43600},
	{"RDPL", 4, 43601},
	{"EMFR", 4, 43602},
	{"RMAG", 4, 43603},
	{"ASIANS", 6, 43604},
	{"LROO", 4, 43605},
	{"ORIENT", 6, 43606},
	{"OFEU", 4, 43607},
	{"CONTRA", 6, 43608},
	{"DAMAGING", 8, 43609},
	{"POPULATED", 9, 43610},
	{"HLIK", 4, 43611},
	{"SEETHER", 7, 43612},
	{"RENEE", 5, 43613},
	{"BOILING", 7, 43614},
	{"JOURNEYS", 8, 43615},
	{"EADJ", 4, 43616},
	{"MILESTONES", 10, 43617},
	{"PARKINSON", 9, 43618},
	{"ALFW", 4, 43619},
	{"OLAU", 4, 43620},
	{"PARSING", 7, 43621},
	{"EARU", 4, 43622},
	{"SPLITTING", 9, 43623},
	{"ORBL", 4, 43624},
	{"MCLEAN", 6, 43625},
	{"DERBYSHIRE", 10, 43626},
	{"RYMI", 4, 43627},
	{"CHECKBOXES", 10, 43628},
	{"LYRU", 4, 43629},
	{"HEUL", 4, 43630},
	{"YDUE", 4, 43631},
	{"DWEW", 4, 43632},
	{"LOBBYING", 8, 43633},
	{"DRAD", 4, 43634},
	{"RAVE", 4, 43635},
	{"HFRE", 4, 43636},
	{"MANJ", 4, 43637},
	{"MGM", 3, 43638},
	{"CIGARS", 6, 43639},
	{"CINEMAS", 7, 43640},
	{"SROB", 4, 43641},
	{"ISLANDER", 8, 43642},
	{"CHBI", 4, 43643},
	{"ENCODER", 7, 43644},
	{"NICOLAS", 7, 43645},
	{"APUR", 4, 43646},
	{"USME", 4, 43647},
	{"INFERENCE", 9, 43648},
	{"RECALLED", 8, 43649},
	{"CYIS", 4, 43650},
	{"LFRA", 4, 43651},
	{"IMPORTERS", 9, 43652},
	{"IMPRESSUM", 9, 43653},
	{"TRANSFORMER", 11, 43654},
	{"LLPU", 4, 43655},
	{"WEISS", 5, 43656},
	{"DECLARATIONS", 12, 43657},
	{"YWEE", 4, 43658},
	{"CHATTANOOGA", 11, 43659},
	{"GILES", 5, 43660},
	{"OWBA", 4, 43661},
	{"MAROON", 6, 43662},
	{"DRAFTS", 6, 43663},
	{"LNOW", 4, 43664},
	{"EXCURSIONS", 10, 43665},
	{"JERK", 4, 43666},
	{"KONTAKT", 7, 43667},
	{"FDEA", 4, 43668},
	{"SHACK", 5, 43669},
	{"MARROW", 6, 43670},
	{"KAWASAKI", 8, 43671},
	{"OPOW", 4, 43672},
	{"LICENCES", 8, 43673},
	{"TAVERN", 6, 43674},
	{"BATHING", 7, 43675},
	{"LAMBERT", 7, 43676},
	{"USWE", 4, 43677},
	{"EPILEPSY", 8, 43678},
	{"ALLOWANCES", 10, 43679},
	{"OCLI", 4, 43680},
	{"FOUNTAINS", 9, 43681},
	{"UNGW", 4, 43682},
	{"FPOW", 4, 43683},
	{"GOGGLES", 7, 43684},
	{"UVEN", 4, 43685},
	{"LEIG", 4, 43686},
	{"CLONES", 6, 43687},
	{"FOREGOING", 9, 43688},
	{"CROSSOVER", 9, 43689},
	{"SPECIFICITY", 11, 43690},
	{"ERMC", 4, 43691},
	{"CERTAINTY", 9, 43692},
	{"SLEEK", 5, 43693},
	{"GERARD", 6, 43694},
	{"UPLA", 4, 43695},
	{"RUNOFF", 6, 43696},
	{"YIDE", 4, 43697},
	{"OSTEOPOROSIS", 12, 43698},
	{"DUPB", 4, 43699},
	{"APPROVALS", 9, 43700},
	{"ANTARCTIC", 9, 43701},
	{"SUCCESSIVE", 10, 43702},
	{"NEGLECTED", 9, 43703},
	{"UEDE", 4, 43704},
	{"RISF", 4, 43705},
	{"ARIEL", 5, 43706},
	{"MEEV", 4, 43707},
	{"MONTY", 5, 43708},
	{"TYMO", 4, 43709},
	{"CAFES", 5, 43710},
	{"JUKEBOX", 7, 43711},
	{"URYO", 4, 43712},
	{"CLASSMATES", 10, 43713},
	{"HITCH", 5, 43714},
	{"LDTE", 4, 43715},
	{"DMEE", 4, 43716},
	{"FRACTURE", 8, 43717},
	{"NEXUS", 5, 43718},
	{"WELV", 4, 43719},
	{"CANCERS", 7, 43720},
	{"VEDC", 4, 43721},
	{"DBEO", 4, 43722},
	{"FOREMOST", 8, 43723},
	{"TYYE", 4, 43724},
	{"NINETEENTH", 10, 43725},
	{"MAPR", 4, 43726},
	{"FCEN", 4, 43727},
	{"AIDJ", 4, 43728},
	{"CHESAPEAKE", 10, 43729},
	{"TANGO", 5, 43730},
	{"LICR", 4, 43731},
	{"MELTING", 7, 43732},
	{"MAHOGANY", 8, 43733},
	{"DSEP", 4, 43734},
	{"ACTRESSES", 9, 43735},
	{"CLARENCE", 8, 43736},
	{"ERNST", 5, 43737},
	{"NEGL", 4, 43738},
	{"GARNER", 6, 43739},
	{"BUSTER", 6, 43740},
	{"ELAX", 4, 43741},
	{"MODERATED", 9, 43742},
	{"NASSAU", 6, 43743},
	{"FLAP", 4, 43744},
	{"AKOF", 4, 43745},
	{"EYLA", 4, 43746},
	{"IGNORANT", 8, 43747},
	{"ALLOWABLE", 9, 43748},
	{"KARATE", 6, 43749},
	{"NMOU", 4, 43750},
	{"COMPOSITIONS", 12, 43751},
	{"CEPE", 4, 43752},
	{"SINGS", 5, 43753},
	{"AYAC", 4, 43754},
	{"MARCOS", 6, 43755},
	{"SORROW", 6, 43756},
	{"ETLY", 4, 43757},
	{"CWIT", 4, 43758},
	{"ORDM", 4, 43759},
	{"CARTE", 5, 43760},
	{"UPTC", 4, 43761},
	{"AYAP", 4, 43762},
	{"HCLA", 4, 43763},
	{"CANNED", 6, 43764},
	{"COLLECTS", 8, 43765},
	{"TREATIES", 8, 43766},
	{"ENDURANCE", 9, 43767},
	{"GETU", 4, 43768},
	{"OPTIMIZING", 10, 43769},
	{"LLGI", 4, 43770},
	{"SWITCHFOOT", 10, 43771},
	{"DMER", 4, 43772},
	{"COLDPLAY", 8, 43773},
	{"INSULATED", 9, 43774},
	{"CKFI", 4, 43775},
	{"UTTR", 4, 43776},
	{"DUPONT", 6, 43777},
	{"GSPO", 4, 43778},
	{"HARRIET", 7, 43779},
	{"PHILOSOPHER", 11, 43780},
	{"RECTANGLE", 9, 43781},
	{"PEDC", 4, 43782},
	{"QUEER", 5, 43783},
	{"PAINS", 5, 43784},
	{"VIOXX", 5, 43785},
	{"HSUC", 4, 43786},
	{"DECATUR", 7, 43787},
	{"WRAPPER", 7, 43788},
	{"BECL", 4, 43789},
	{"AHMED", 5, 43790},
	{"BUCHANAN", 8, 43791},
	{"DRUMMER", 7, 43792},
	{"BYTR", 4, 43793},
	{"SOBRE", 5, 43794},
	{"CELEXA", 6, 43795},
	{"GESB", 4, 43796},
	{"NOGR", 4, 43797},
	{"GUITARIST", 9, 43798},
	{"CKBO", 4, 43799},
	{"FHAV", 4, 43800},
	{"SYMMETRIC", 9, 43801},
	{"CEREMONIES", 10, 43802},
	{"TORL", 4, 43803},
	{"YQUE", 4, 43804},
	{"SATISFIES", 9, 43805},
	{"KUALA", 5, 43806},
	{"CILM", 4, 43807},
	{"APPELLATE", 9, 43808},
	{"COMMA", 5, 43809},
	{"LUXU", 4, 43810},
	{"NOFU", 4, 43811},
	{"BBB", 3, 43812},
	{"GEEKS", 5, 43813},
	{"CONFORMITY", 10, 43814},
	{"AVANT", 5, 43815},
	{"GBOT", 4, 43816},
	{"REPEC", 5, 43817},
	{"INSIGHTFUL", 10, 43818},
	{"SUPPER", 6, 43819},
	{"FULFILLING", 10, 43820},
	{"NBYS", 4, 43821},
	{"IRFR", 4, 43822},
	{"HOODED", 6, 43823},
	{"UTGE", 4, 43824},
	{"LBRE", 4, 43825},
	{"UNRATED", 7, 43826},
	{"RESR", 4, 43827},
	{"COUV", 4, 43828},
	{"DIVA", 4, 43829},
	{"ADSENSE", 7, 43830},
	{"YSFI", 4, 43831},
	{"BYUS", 4, 43832},
	{"INSTABILITY", 11, 43833},
	{"LEFE", 4, 43834},
	{"SEMINARY", 8, 43835},
	{"EXEMPTIONS", 10, 43836},
	{"INTEGRATES", 10, 43837},
	{"LSKI", 4, 43838},
	{"PRESENTER", 9, 43839},
	{"ADCH", 4, 43840},
	{"KSAG", 4, 43841},
	{"YDIR", 4, 43842},
	{"NDNU", 4, 43843},
	{"LGIV", 4, 43844},
	{"UMIG", 4, 43845},
	{"CEAF", 4, 43846},
	{"OFFENSES", 8, 43847},
	{"HGRO", 4, 43848},
	{"EMULATION", 9, 43849},
	{"LENGTHY", 7, 43850},
	{"SONATA", 6, 43851},
	{"WYV", 3, 43852},
	{"FORTRESS", 8, 43853},
	{"CONTIGUOUS", 10, 43854},
	{"DBLU", 4, 43855},
	{"BOOKSTORES", 10, 43856},
	{"LSEL", 4, 43857},
	{"NIPU", 4, 43858},
	{"PEREZ", 5, 43859},
	{"CIMEL", 5, 43860},
	{"LOPA", 4, 43861},
	{"INACCURATE", 10, 43862},
	{"MNOR", 4, 43863},
	{"YACH", 4, 43864},
	{"HORU", 4, 43865},
	{"HVAC", 4, 43866},
	{"EXPLANATORY", 11, 43867},
	{"LEICA", 5, 43868},
	{"ADDT", 4, 43869},
	{"DCOV", 4, 43870},
	{"SETTLERS", 8, 43871},
	{"OMEK", 4, 43872},
	{"STOOLS", 6, 43873},
	{"MINISTERIAL", 11, 43874},
	{"XAVIER", 6, 43875},
	{"AGENDAS", 7, 43876},
	{"YNIC", 4, 43877},
	{"TORAH", 5, 43878},
	{"HBRI", 4, 43879},
	{"AMAB", 4, 43880},
	{"PUBLISHES", 9, 43881},
	{"STACKS", 6, 43882},
	{"VECR", 4, 43883},
	{"RRYH", 4, 43884},
	{"OWNING", 6, 43885},
	{"HBAC", 4, 43886},
	{"ANDERSEN", 8, 43887},
	{"UWU", 3, 43888},
	{"OVAR", 4, 43889},
	{"BUSCH", 5, 43890},
	{"TGAR", 4, 43891},
	{"TOGU", 4, 43892},
	{"MYCA", 4, 43893},
	{"ARMANI", 6, 43894},
	{"BEIJ", 4, 43895},
	{"HOFW", 4, 43896},
	{"BIPOLAR", 7, 43897},
	{"SERMON", 6, 43898},
	{"HCAM", 4, 43899},
	{"LEXE", 4, 43900},
	{"DSDE", 4, 43901},
	{"JORP", 4, 43902},
	{"EEKB", 4, 43903},
	{"MWHA", 4, 43904},
	{"YMAI", 4, 43905},
	{"FACILITATING", 12, 43906},
	{"COMPLAINED", 10, 43907},
	{"URYW", 4, 43908},
	{"UNTF", 4, 43909},
	{"FERDINAND", 9, 43910},
	{"ORCU", 4, 43911},
	{"HEDL", 4, 43912},
	{"LUET", 4, 43913},
	{"WEDU", 4, 43914},
	{"ULIE", 4, 43915},
	{"BADG", 4, 43916},
	{"DNTK", 4, 43917},
	{"ALOB", 4, 43918},
	{"THRILL", 6, 43919},
	{"LTYA", 4, 43920},
	{"LAGOON", 6, 43921},
	{"UNDOUBTEDLY", 11, 43922},
	{"MENOPAUSE", 9, 43923},
	{"UKRA", 4, 43924},
	{"ONDG", 4, 43925},
	{"RCHH", 4, 43926},
	{"INBOUND", 7, 43927},
	{"WITHHELD", 8, 43928},
	{"INSISTED", 8, 43929},
	{"RESY", 4, 43930},
	{"SHORTLIST", 9, 43931},
	{"UTUA", 4, 43932},
	{"SJUN", 4, 43933},
	{"GAINESVILLE", 11, 43934},
	{"TIAVA", 5, 43935},
	{"RDHE", 4, 43936},
	{"ECLECTIC", 8, 43937},
	{"HEADPHONE", 9, 43938},
	{"GSFR", 4, 43939},
	{"REGIMES", 7, 43940},
	{"GRIE", 4, 43941},
	{"HEADACHES", 9, 43942},
	{"RUGB", 4, 43943},
	{"RAMSEY", 6, 43944},
	{"NKAR", 4, 43945},
	{"KERC", 4, 43946},
	{"RDEB", 4, 43947},
	{"README", 6, 43948},
	{"ALJO", 4, 43949},
	{"PIGEON", 6, 43950},
	{"RIVALS", 6, 43951},
	{"FREED", 5, 43952},
	{"BINDER", 6, 43953},
	{"TSDU", 4, 43954},
	{"XEMACS", 6, 43955},
	{"CONSTRAINED", 11, 43956},
	{"PARROT", 6, 43957},
	{"MAGNUM", 6, 43958},
	{"YWEI", 4, 43959},
	{"INVOKED", 7, 43960},
	{"YNEV", 4, 43961},
	{"INVALUABLE", 10, 43962},
	{"HELICOPTERS", 11, 43963},
	{"EBED", 4, 43964},
	{"YSCR", 4, 43965},
	{"NCEU", 4, 43966},
	{"KEYSTONE", 8, 43967},
	{"INCLINED", 8, 43968},
	{"UBMA", 4, 43969},
	{"GALA", 4, 43970},
	{"YCOO", 4, 43971},
	{"INTERCONTINENTAL", 16, 43972},
	{"MSCH", 4, 43973},
	{"TRACTION", 8, 43974},
	{"UTTERLY", 7, 43975},
	{"WORKSPACE", 9, 43976},
	{"NYBE", 4, 43977},
	{"CUSTOMIZABLE", 12, 43978},
	{"SOFTCOVER", 9, 43979},
	{"GAVIN", 5, 43980},
	{"ILLUMINATED", 11, 43981},
	{"REALTIME", 8, 43982},
	{"LASTS", 5, 43983},
	{"PTHR", 4, 43984},
	{"GLOUCESTERSHIRE", 15, 43985},
	{"ELECTRONS", 9, 43986},
	{"STFL", 4, 43987},
	{"OUSY", 4, 43988},
	{"NAFG", 4, 43989},
	{"CLAUDIA", 7, 43990},
	{"PERPETUAL", 9, 43991},
	{"YEDS", 4, 43992},
	{"SUBSYSTEM", 9, 43993},
	{"APPL", 4, 43994},
	{"YHOP", 4, 43995},
	{"EUSC", 4, 43996},
	{"KINETIC", 7, 43997},
	{"CAFFEINE", 8, 43998},
	{"LSWO", 4, 43999},
	{"DDOU", 4, 44000},
	{"SOLICITOR", 9, 44001},
	{"CLUSTERING", 10, 44002},
	{"LEBL", 4, 44003},
	{"GSUR", 4, 44004},
	{"RNFR", 4, 44005},
	{"GONC", 4, 44006},
	{"TBOR", 4, 44007},
	{"KFAS", 4, 44008},
	{"MWOU", 4, 44009},
	{"VUJ", 3, 44010},
	{"UMOU", 4, 44011},
	{"GONW", 4, 44012},
	{"WLER", 4, 44013},
	{"VERBATIM", 8, 44014},
	{"LDGI", 4, 44015},
	{"INNOCENCE", 9, 44016},
	{"ODCA", 4, 44017},
	{"CHBR", 4, 44018},
	{"HTTPD", 5, 44019},
	{"QUICKER", 7, 44020},
	{"RMEL", 4, 44021},
	{"GRANDPARENTS", 12, 44022},
	{"RTHM", 4, 44023},
	{"DEAW", 4, 44024},
	{"RADL", 4, 44025},
	{"RDHI", 4, 44026},
	{"AYRO", 4, 44027},
	{"CARDBOARD", 9, 44028},
	{"ATTRIBUTABLE", 12, 44029},
	{"EORB", 4, 44030},
	{"SKETCHES", 8, 44031},
	{"YERC", 4, 44032},
	{"RFAV", 4, 44033},
	{"UYTH", 4, 44034},
	{"KEDC", 4, 44035},
	{"ANGELO", 6, 44036},
	{"TERTIARY", 8, 44037},
	{"RDBU", 4, 44038},
	{"LICW", 4, 44039},
	{"EXHAUSTED", 9, 44040},
	{"SMARTER", 7, 44041},
	{"GNUM", 4, 44042},
	{"RPIE", 4, 44043},
	{"GBAS", 4, 44044},
	{"SLAC", 4, 44045},
	{"SHELTERS", 8, 44046},
	{"GYTH", 4, 44047},
	{"ATTAIN", 6, 44048},
	{"DORA", 4, 44049},
	{"CALORIE", 7, 44050},
	{"INCONVENIENCE", 13, 44051},
	{"IRBU", 4, 44052},
	{"EGUE", 4, 44053},
	{"GRAPHITE", 8, 44054},
	{"NTYW", 4, 44055},
	{"VACCINATION", 11, 44056},
	{"STROLLER", 8, 44057},
	{"FARTHER", 7, 44058},
	{"BOWEL", 5, 44059},
	{"SWEATERS", 8, 44060},
	{"CHATS", 5, 44061},
	{"MAFIA", 5, 44062},
	{"LSUC", 4, 44063},
	{"AYAG", 4, 44064},
	{"FUTUNA", 6, 44065},
	{"MANDARIN", 8, 44066},
	{"IMFR", 4, 44067},
	{"DUNGEON", 7, 44068},
	{"PREDICTABLE", 11, 44069},
	{"UTFA", 4, 44070},
	{"GERMANS", 7, 44071},
	{"LILLY", 5, 44072},
	{"SHIRE", 5, 44073},
	{"KEAM", 4, 44074},
	{"SUSCEPTIBLE", 11, 44075},
	{"MOSQUITO", 8, 44076},
	{"GLEG", 4, 44077},
	{"RRYW", 4, 44078},
	{"MSFR", 4, 44079},
	{"FEWP", 4, 44080},
	{"KASHMIR", 7, 44081},
	{"TOML", 4, 44082},
	{"INSEST", 6, 44083},
	{"LYONS", 5, 44084},
	{"SKYLINE", 7, 44085},
	{"SULFUR", 6, 44086},
	{"UMUL", 4, 44087},
	{"SCAMS", 5, 44088},
	{"LIPID", 5, 44089},
	{"PUTNAM", 6, 44090},
	{"CORPSE", 6, 44091},
	{"MING", 4, 44092},
	{"NROM", 4, 44093},
	{"EDCU", 4, 44094},
	{"QUOT", 4, 44095},
	{"YSDE", 4, 44096},
	{"BYIS", 4, 44097},
	{"RITZ", 4, 44098},
	{"NETWORKED", 9, 44099},
	{"NEYG", 4, 44100},
	{"LOCALHOST", 9, 44101},
	{"LUSH", 4, 44102},
	{"BARRELS", 7, 44103},
	{"TRANSFORMATIONS", 15, 44104},
	{"UNGC", 4, 44105},
	{"BEFA", 4, 44106},
	{"UELT", 4, 44107},
	{"CABLING", 7, 44108},
	{"ANALOGUE", 8, 44109},
	{"EDSL", 4, 44110},
	{"CROA", 4, 44111},
	{"WERNER", 6, 44112},
	{"CLYDE", 5, 44113},
	{"STILLS", 6, 44114},
	{"PERIMETER", 9, 44115},
	{"BIASED", 6, 44116},
	{"CARDIOLOGY", 10, 44117},
	{"HONORARY", 8, 44118},
	{"PEDD", 4, 44119},
	{"IRWIN", 5, 44120},
	{"BREWER", 6, 44121},
	{"CHIANG", 6, 44122},
	{"EXCHANGED", 9, 44123},
	{"SUPO", 4, 44124},
	{"FCHE", 4, 44125},
	{"PAYLOAD", 7, 44126},
	{"UGEE", 4, 44127},
	{"OUPR", 4, 44128},
	{"ADHERE", 6, 44129},
	{"RSMU", 4, 44130},
	{"RBEG", 4, 44131},
	{"DWEE", 4, 44132},
	{"FRAN", 4, 44133},
	{"LYSM", 4, 44134},
	{"MERRILL", 7, 44135},
	{"RCHP", 4, 44136},
	{"OLDSMOBILE", 10, 44137},
	{"GRILLED", 7, 44138},
	{"RORD", 4, 44139},
	{"OKYO", 4, 44140},
	{"OMOB", 4, 44141},
	{"LBUR", 4, 44142},
	{"RAFAEL", 6, 44143},
	{"UMMO", 4, 44144},
	{"CCC", 3, 44145},
	{"ENQUIRE", 7, 44146},
	{"HWAL", 4, 44147},
	{"TOILETS", 7, 44148},
	{"MAINS", 5, 44149},
	{"WHALES", 6, 44150},
	{"ENRU", 4, 44151},
	{"MISTY", 5, 44152},
	{"LINDSEY", 7, 44153},
	{"PARITY", 6, 44154},
	{"PARTITIONS", 10, 44155},
	{"ELRO", 4, 44156},
	{"KZU", 3, 44157},
	{"GRIM", 4, 44158},
	{"LEOU", 4, 44159},
	{"CONSERVED", 9, 44160},
	{"SEARCHSEARCH", 12, 44161},
	{"GDON", 4, 44162},
	{"HUBBARD", 7, 44163},
	{"REGG", 4, 44164},
	{"UEDB", 4, 44165},
	{"REWRITE", 7, 44166},
	{"UPAG", 4, 44167},
	{"HJUS", 4, 44168},
	{"VENDING", 7, 44169},
	{"PRISM", 5, 44170},
	{"DSME", 4, 44171},
	{"DGIR", 4, 44172},
	{"CHASING", 7, 44173},
	{"KEYGEN", 6, 44174},
	{"INDF", 4, 44175},
	{"JANEIRO", 7, 44176},
	{"FLOP", 4, 44177},
	{"OLWA", 4, 44178},
	{"UXUR", 4, 44179},
	{"AGGREGATION", 11, 44180},
	{"SHELLEY", 7, 44181},
	{"RKTI", 4, 44182},
	{"BATTING", 7, 44183},
	{"BORROWED", 8, 44184},
	{"EMSF", 4, 44185},
	{"URFR", 4, 44186},
	{"NERP", 4, 44187},
	{"RBOY", 4, 44188},
	{"RESTS", 5, 44189},
	{"RARC", 4, 44190},
	{"LDEX", 4, 44191},
	{"RBYA", 4, 44192},
	{"PRENTICE", 8, 44193},
	{"DEPICTED", 8, 44194},
	{"PROPOSING", 9, 44195},
	{"MSAL", 4, 44196},
	{"CKSP", 4, 44197},
	{"LDRO", 4, 44198},
	{"WINDING", 7, 44199},
	{"DIAZ", 4, 44200},
	{"RIPPED", 6, 44201},
	{"LFIG", 4, 44202},
	{"VEGAN", 5, 44203},
	{"CONGRESSMAN", 11, 44204},
	{"COBALT", 6, 44205},
	{"PITY", 4, 44206},
	{"LTOC", 4, 44207},
	{"RECOMBINANT", 11, 44208},
	{"UBUNTU", 6, 44209},
	{"DOWNWARD", 8, 44210},
	{"SUPERSTAR", 9, 44211},
	{"EYOR", 4, 44212},
	{"REHU", 4, 44213},
	{"TTYM", 4, 44214},
	{"CLOSEOUT", 8, 44215},
	{"COREL", 5, 44216},
	{"RIAR", 4, 44217},
	{"KAYAKING", 8, 44218},
	{"SYNERGY", 7, 44219},
	{"EIRJ", 4, 44220},
	{"CATALOGUES", 10, 44221},
	{"ASPIRE", 6, 44222},
	{"EELC", 4, 44223},
	{"NCEJ", 4, 44224},
	{"YOCC", 4, 44225},
	{"HARVESTING", 10, 44226},
	{"GARFIELD", 8, 44227},
	{"MPSH", 4, 44228},
	{"GROOM", 5, 44229},
	{"JEWELS", 6, 44230},
	{"SATURATED", 9, 44231},
	{"GEORGES", 7, 44232},
	{"DBOA", 4, 44233},
	{"BACKPACKING", 11, 44234},
	{"WASQ", 4, 44235},
	{"QUINCY", 6, 44236},
	{"WWHO", 4, 44237},
	{"ACCIDENTALLY", 12, 44238},
	{"DOUGHTY", 7, 44239},
	{"ARFU", 4, 44240},
	{"BONDED", 6, 44241},
	{"DDEB", 4, 44242},
	{"STICKING", 8, 44243},
	{"DUDLEY", 6, 44244},
	{"OSAMA", 5, 44245},
	{"ILDW", 4, 44246},
	{"WEEDS", 5, 44247},
	{"STRIPPED", 8, 44248},
	{"OPRAH", 5, 44249},
	{"PKIN", 4, 44250},
	{"INFLATABLE", 10, 44251},
	{"BEERS", 5, 44252},
	{"CLIVE", 5, 44253},
	{"FIXTURE", 7, 44254},
	{"YEDH", 4, 44255},
	{"GLASSWARE", 9, 44256},
	{"UUZ", 3, 44257},
	{"WFUL", 4, 44258},
	{"CANARY", 6, 44259},
	{"IMAGINED", 8, 44260},
	{"DEAV", 4, 44261},
	{"DARBY", 5, 44262},
	{"HOWR", 4, 44263},
	{"WOKE", 4, 44264},
	{"FILLS", 5, 44265},
	{"GWRI", 4, 44266},
	{"PROPORTIONS", 11, 44267},
	{"IDOU", 4, 44268},
	{"GRIPS", 5, 44269},
	{"CLERGY", 6, 44270},
	{"NGSK", 4, 44271},
	{"COURSEWORK", 10, 44272},
	{"SOLICITORS", 10, 44273},
	{"KAYAK", 5, 44274},
	{"MODERATELY", 10, 44275},
	{"ELAL", 4, 44276},
	{"NLYU", 4, 44277},
	{"DVOL", 4, 44278},
	{"CKSU", 4, 44279},
	{"YCLU", 4, 44280},
	{"MAYOTTE", 7, 44281},
	{"ALTAR", 5, 44282},
	{"WNPR", 4, 44283},
	{"SALVAGE", 7, 44284},
	{"RTDE", 4, 44285},
	{"REPETITIVE", 10, 44286},
	{"STANTON", 7, 44287},
	{"CREATORS", 8, 44288},
	{"GEARS", 5, 44289},
	{"ORBITAL", 7, 44290},
	{"MUSICALS", 8, 44291},
	{"GOFC", 4, 44292},
	{"RFEL", 4, 44293},
	{"TYBO", 4, 44294},
	{"KILOMETRES", 10, 44295},
	{"SLEV", 4, 44296},
	{"UDOF", 4, 44297},
	{"BYFI", 4, 44298},
	{"CUFF", 4, 44299},
	{"LTOD", 4, 44300},
	{"LITHUANIAN", 10, 44301},
	{"NCHW", 4, 44302},
	{"REPEATING", 9, 44303},
	{"EMPIRES", 7, 44304},
	{"NCUS", 4, 44305},
	{"FFSH", 4, 44306},
	{"GGOO", 4, 44307},
	{"DSSU", 4, 44308},
	{"AYDO", 4, 44309},
	{"PROFILING", 9, 44310},
	{"ELYG", 4, 44311},
	{"LFIE", 4, 44312},
	{"REPS", 4, 44313},
	{"NAUD", 4, 44314},
	{"LLUT", 4, 44315},
	{"EXIB", 4, 44316},
	{"YMPH", 4, 44317},
	{"EWWA", 4, 44318},
	{"DASF", 4, 44319},
	{"ALDW", 4, 44320},
	{"RTEM", 4, 44321},
	{"MABL", 4, 44322},
	{"LDBR", 4, 44323},
	{"NLOW", 4, 44324},
	{"OYSTER", 6, 44325},
	{"STURDY", 6, 44326},
	{"SEQUENCING", 10, 44327},
	{"ADAW", 4, 44328},
	{"DFAN", 4, 44329},
	{"TEMC", 4, 44330},
	{"MASSACRE", 8, 44331},
	{"NTDR", 4, 44332},
	{"BYDI", 4, 44333},
	{"PANORAMIC", 9, 44334},
	{"RISEN", 5, 44335},
	{"BLENDED", 7, 44336},
	{"DESKJET", 7, 44337},
	{"WPLA", 4, 44338},
	{"EWFR", 4, 44339},
	{"RHINO", 5, 44340},
	{"POLYNOMIAL", 10, 44341},
	{"OMLE", 4, 44342},
	{"NIFY", 4, 44343},
	{"IMPERATIVE", 10, 44344},
	{"STAKEHOLDER", 11, 44345},
	{"FWAY", 4, 44346},
	{"ILMO", 4, 44347},
	{"DIGGING", 7, 44348},
	{"RMTO", 4, 44349},
	{"LANTERN", 7, 44350},
	{"CATCHES", 7, 44351},
	{"OFLU", 4, 44352},
	{"EVANGELICAL", 11, 44353},
	{"RULER", 5, 44354},
	{"SIGNIFIES", 9, 44355},
	{"HENRI", 5, 44356},
	{"LYGI", 4, 44357},
	{"DJAN", 4, 44358},
	{"STOCHASTIC", 10, 44359},
	{"MIDF", 4, 44360},
	{"RTWE", 4, 44361},
	{"DITD", 4, 44362},
	{"EDTU", 4, 44363},
	{"TBOU", 4, 44364},
	{"TACU", 4, 44365},
	{"TOKENS", 6, 44366},
	{"SANTANA", 7, 44367},
	{"LDUN", 4, 44368},
	{"KIDDING", 7, 44369},
	{"NBOU", 4, 44370},
	{"FMEM", 4, 44371},
	{"ULTW", 4, 44372},
	{"PIPING", 6, 44373},
	{"GETD", 4, 44374},
	{"FFIT", 4, 44375},
	{"EJAM", 4, 44376},
	{"SWEPT", 5, 44377},
	{"OORW", 4, 44378},
	{"SWANSEA", 7, 44379},
	{"AIRMAIL", 7, 44380},
	{"STARING", 7, 44381},
	{"ICKR", 4, 44382},
	{"SEVENTY", 7, 44383},
	{"EDSK", 4, 44384},
	{"OAPR", 4, 44385},
	{"GDIR", 4, 44386},
	{"RYTA", 4, 44387},
	{"UNTL", 4, 44388},
	{"PROBLEMATIC", 11, 44389},
	{"YATP", 4, 44390},
	{"TUME", 4, 44391},
	{"GATR", 4, 44392},
	{"CTFR", 4, 44393},
	{"RKAR", 4, 44394},
	{"AROSE", 5, 44395},
	{"GHMO", 4, 44396},
	{"DECOMPOSITION", 13, 44397},
	{"NDLU", 4, 44398},
	{"GDJ", 3, 44399},
	{"RDFI", 4, 44400},
	{"CHATHAM", 7, 44401},
	{"IRJO", 4, 44402},
	{"ODYE", 4, 44403},
	{"ROADMAP", 7, 44404},
	{"RONZ", 4, 44405},
	{"TCHM", 4, 44406},
	{"RCUT", 4, 44407},
	{"BECKY", 5, 44408},
	{"LSIG", 4, 44409},
	{"FARRELL", 7, 44410},
	{"CSER", 4, 44411},
	{"ELDERS", 6, 44412},
	{"EFAV", 4, 44413},
	{"INTERPRETERS", 12, 44414},
	{"USDO", 4, 44415},
	{"YJM", 3, 44416},
	{"ACKNOWLEDGEMENTS", 16, 44417},
	{"GOWH", 4, 44418},
	{"KLAUS", 5, 44419},
	{"LDOG", 4, 44420},
	{"RSSP", 4, 44421},
	{"WOPE", 4, 44422},
	{"TYBA", 4, 44423},
	{"SKINCARE", 8, 44424},
	{"CONQUEST", 8, 44425},
	{"EIFY", 4, 44426},
	{"DLEV", 4, 44427},
	{"ZYJ", 3, 44428},
	{"YSMI", 4, 44429},
	{"HEROIN", 6, 44430},
	{"RMES", 4, 44431},
	{"RNIC", 4, 44432},
	{"RDTI", 4, 44433},
	{"REPAIRING", 9, 44434},
	{"MANDATED", 8, 44435},
	{"WORKBOOK", 8, 44436},
	{"XSLT", 4, 44437},
	{"THBY", 4, 44438},
	{"HOGAN", 5, 44439},
	{"NGIL", 4, 44440},
	{"GEAB", 4, 44441},
	{"XTMO", 4, 44442},
	{"WHISTLE", 7, 44443},
	{"SULFATE", 7, 44444},
	{"ALSD", 4, 44445},
	{"LPRA", 4, 44446},
	{"DRESDEN", 7, 44447},
	{"RRYB", 4, 44448},
	{"TIMESHARE", 9, 44449},
	{"DIVERSIFIED", 11, 44450},
	{"RZM", 3, 44451},
	{"RCHU", 4, 44452},
	{"DROI", 4, 44453},
	{"ALHU", 4, 44454},
	{"OLDIES", 6, 44455},
	{"DGEM", 4, 44456},
	{"LERP", 4, 44457},
	{"UCKT", 4, 44458},
	{"IRDW", 4, 44459},
	{"FERTILIZER", 10, 44460},
	{"HOFM", 4, 44461},
	{"GMIN", 4, 44462},
	{"COMPLAINING", 11, 44463},
	{"FTFO", 4, 44464},
	{"ANALYTIC", 8, 44465},
	{"MYHA", 4, 44466},
	{"RLIT", 4, 44467},
	{"GHWI", 4, 44468},
	{"PREDOMINANTLY", 13, 44469},
	{"AMETHYST", 8, 44470},
	{"DEBRA", 5, 44471},
	{"WOODWARD", 8, 44472},
	{"REWRITTEN", 9, 44473},
	{"CDROM", 5, 44474},
	{"URNF", 4, 44475},
	{"SAUC", 4, 44476},
	{"CONCERTO", 8, 44477},
	{"IRDQ", 4, 44478},
	{"HEFF", 4, 44479},
	{"AFFL", 4, 44480},
	{"GUEL", 4, 44481},
	{"ADORABLE", 8, 44482},
	{"TLOW", 4, 44483},
	{"TORRES", 6, 44484},
	{"TBEP", 4, 44485},
	{"KEBE", 4, 44486},
	{"DMID", 4, 44487},
	{"CILA", 4, 44488},
	{"URYB", 4, 44489},
	{"AILC", 4, 44490},
	{"RESTRAINT", 9, 44491},
	{"OLWH", 4, 44492},
	{"GYOF", 4, 44493},
	{"YPET", 4, 44494},
	{"PEFO", 4, 44495},
	{"THRILLERS", 9, 44496},
	{"OMYI", 4, 44497},
	{"GOWI", 4, 44498},
	{"FLIV", 4, 44499},
	{"EORP", 4, 44500},
	{"FORTRAN", 7, 44501},
	{"EDDY", 4, 44502},
	{"ILYL", 4, 44503},
	{"HOWY", 4, 44504},
	{"CONDEMNED", 9, 44505},
	{"BERGER", 6, 44506},
	{"TIMELESS", 8, 44507},
	{"PAROLE", 6, 44508},
	{"COREY", 5, 44509},
	{"KENDALL", 7, 44510},
	{"QUL", 3, 44511},
	{"SPOUSES", 7, 44512},
	{"SLIPS", 5, 44513},
	{"RYBR", 4, 44514},
	{"NINETY", 6, 44515},
	{"DDRU", 4, 44516},
	{"IDAC", 4, 44517},
	{"TRAYS", 5, 44518},
	{"STEWARDSHIP", 11, 44519},
	{"CUES", 4, 44520},
	{"BIOINFORMATICS", 14, 44521},
	{"HGAM", 4, 44522},
	{"RTHL", 4, 44523},
	{"KISSES", 6, 44524},
	{"LYFU", 4, 44525},
	{"CALY", 4, 44526},
	{"KERR", 4, 44527},
	{"REGULATING", 10, 44528},
	{"RSCI", 4, 44529},
	{"FLOCK", 5, 44530},
	{"EXPORTING", 9, 44531},
	{"PUTH", 4, 44532},
	{"ARABIAN", 7, 44533},
	{"CHUNG", 5, 44534},
	{"SUBPART", 7, 44535},
	{"EERR", 4, 44536},
	{"DEAB", 4, 44537},
	{"SCHEDULER", 9, 44538},
	{"BENDING", 7, 44539},
	{"LIMM", 4, 44540},
	{"RNWA", 4, 44541},
	{"MONF", 4, 44542},
	{"BORIS", 5, 44543},
	{"LMAS", 4, 44544},
	{"HYPNOSIS", 8, 44545},
	{"AMPR", 4, 44546},
	{"ALAV", 4, 44547},
	{"GMET", 4, 44548},
	{"AMMUNITION", 10, 44549},
	{"VEGA", 4, 44550},
	{"RVOT", 4, 44551},
	{"RCOO", 4, 44552},
	{"PLEASURES", 9, 44553},
	{"SHORTEST", 8, 44554},
	{"DENYING", 7, 44555},
	{"SYRI", 4, 44556},
	{"ONBL", 4, 44557},
	{"RBAG", 4, 44558},
	{"CKOR", 4, 44559},
	{"CORNERSTONE", 11, 44560},
	{"TSBR", 4, 44561},
	{"RSDU", 4, 44562},
	{"RECYCLE", 7, 44563},
	{"FFAC", 4, 44564},
	{"SHAVE", 5, 44565},
	{"ICPE", 4, 44566},
	{"HYBR", 4, 44567},
	{"UGAL", 4, 44568},
	{"HTBY", 4, 44569},
	{"XEMP", 4, 44570},
	{"SMUR", 4, 44571},
	{"NTQU", 4, 44572},
	{"DISRUPTION", 10, 44573},
	{"GALWAY", 6, 44574},
	{"KHAD", 4, 44575},
	{"COLT", 4, 44576},
	{"ARTILLERY", 9, 44577},
	{"MEKI", 4, 44578},
	{"PRECEDENCE", 10, 44579},
	{"ODWH", 4, 44580},
	{"WSOM", 4, 44581},
	{"OLSW", 4, 44582},
	{"APPLICABILITY", 13, 44583},
	{"RYBY", 4, 44584},
	{"VOLATILITY", 10, 44585},
	{"GRINDING", 8, 44586},
	{"RUBBISH", 7, 44587},
	{"ELFB", 4, 44588},
	{"OWME", 4, 44589},
	{"KNOCKED", 7, 44590},
	{"SWAMP", 5, 44591},
	{"PITCHING", 8, 44592},
	{"NROC", 4, 44593},
	{"HOTELES", 7, 44594},
	{"BEDB", 4, 44595},
	{"NJEC", 4, 44596},
	{"BORDEAUX", 8, 44597},
	{"MANIFOLD", 8, 44598},
	{"TORNADO", 7, 44599},
	{"DISNEYLAND", 10, 44600},
	{"UMD", 3, 44601},
	{"GDB", 3, 44602},
	{"POSSESSED", 9, 44603},
	{"EAMR", 4, 44604},
	{"CTAL", 4, 44605},
	{"GDES", 4, 44606},
	{"TURTLES", 7, 44607},
	{"OFFS", 4, 44608},
	{"LISTSERV", 8, 44609},
	{"YROO", 4, 44610},
	{"CTME", 4, 44611},
	{"VAUXHALL", 8, 44612},
	{"COND", 4, 44613},
	{"DMAL", 4, 44614},
	{"WELCOMING", 9, 44615},
	{"MDOW", 4, 44616},
	{"LEARNS", 6, 44617},
	{"HIMD", 4, 44618},
	{"DNTM", 4, 44619},
	{"WEJU", 4, 44620},
	{"RTPR", 4, 44621},
	{"DIVIDING", 8, 44622},
	{"HICKORY", 7, 44623},
	{"RENOVATED", 9, 44624},
	{"INMATES", 7, 44625},
	{"TOKELAU", 7, 44626},
	{"CONFORMANCE", 11, 44627},
	{"SLICES", 6, 44628},
	{"DIECAST", 7, 44629},
	{"MONP", 4, 44630},
	{"TSFU", 4, 44631},
	{"BITTORRENT", 10, 44632},
	{"LBEB", 4, 44633},
	{"CODY", 4, 44634},
	{"FRANKIE", 7, 44635},
	{"WHYH", 4, 44636},
	{"LAWSON", 6, 44637},
	{"YPAI", 4, 44638},
	{"OMDI", 4, 44639},
	{"RPAY", 4, 44640},
	{"FEWT", 4, 44641},
	{"ALPRAZOLAM", 10, 44642},
	{"DAMNED", 6, 44643},
	{"YOUJ", 4, 44644},
	{"LBAT", 4, 44645},
	{"UADE", 4, 44646},
	{"LDUP", 4, 44647},
	{"BEETHOVEN", 9, 44648},
	{"UTMY", 4, 44649},
	{"ARMT", 4, 44650},
	{"LEXC", 4, 44651},
	{"EERB", 4, 44652},
	{"FTAL", 4, 44653},
	{"ECOW", 4, 44654},
	{"REBUILT", 7, 44655},
	{"UTEW", 4, 44656},
	{"PROCEEDED", 9, 44657},
	{"TMER", 4, 44658},
	{"GHSP", 4, 44659},
	{"COLLABORATE", 11, 44660},
	{"LETU", 4, 44661},
	{"KSAB", 4, 44662},
	{"GCOR", 4, 44663},
	{"REDV", 4, 44664},
	{"OFEC", 4, 44665},
	{"TENTATIVE", 9, 44666},
	{"FDIF", 4, 44667},
	{"PETERBOROUGH", 12, 44668},
	{"EGOP", 4, 44669},
	{"JARS", 4, 44670},
	{"AUTHENTICITY", 12, 44671},
	{"RTYR", 4, 44672},
	{"LPUR", 4, 44673},
	{"ADGO", 4, 44674},
	{"LSOV", 4, 44675},
	{"RYDO", 4, 44676},
	{"GLAND", 5, 44677},
	{"CTBE", 4, 44678},
	{"POSITIVES", 9, 44679},
	{"WIGS", 4, 44680},
	{"FDOL", 4, 44681},
	{"RESIGNATION", 11, 44682},
	{"STRIPED", 7, 44683},
	{"DQW", 3, 44684},
	{"BLENDS", 6, 44685},
	{"GARMENTS", 8, 44686},
	{"FRATERNITY", 10, 44687},
	{"HUNK", 4, 44688},
	{"ALLOCATIONS", 11, 44689},
	{"LYMPHOMA", 8, 44690},
	{"TAPESTRY", 8, 44691},
	{"LDDI", 4, 44692},
	{"ORIGINATING", 11, 44693},
	{"GLEM", 4, 44694},
	{"LUBI", 4, 44695},
	{"AKFA", 4, 44696},
	{"CHAP", 4, 44697},
	{"UNGR", 4, 44698},
	{"VLU", 3, 44699},
	{"BLOWS", 5, 44700},
	{"RPC", 3, 44701},
	{"ROCL", 4, 44702},
	{"FREEBIES", 8, 44703},
	{"IGMA", 4, 44704},
	{"UNDN", 4, 44705},
	{"FBIL", 4, 44706},
	{"CONVERSE", 8, 44707},
	{"CUTA", 4, 44708},
	{"FRONTLINE", 9, 44709},
	{"YROA", 4, 44710},
	{"GARDENER", 8, 44711},
	{"EXPI", 4, 44712},
	{"IMAP", 4, 44713},
	{"WINAMP", 6, 44714},
	{"WINNIE", 6, 44715},
	{"NERM", 4, 44716},
	{"XCUS", 4, 44717},
	{"UDSO", 4, 44718},
	{"HIGGINS", 7, 44719},
	{"STOKE", 5, 44720},
	{"GDEV", 4, 44721},
	{"MBOT", 4, 44722},
	{"DITR", 4, 44723},
	{"ITMU", 4, 44724},
	{"IDBU", 4, 44725},
	{"HMAK", 4, 44726},
	{"ENQU", 4, 44727},
	{"RSEB", 4, 44728},
	{"WARWICKSHIRE", 12, 44729},
	{"POLYMERS", 8, 44730},
	{"PENGUINS", 8, 44731},
	{"LAYC", 4, 44732},
	{"ATTRACTING", 10, 44733},
	{"GRILLS", 6, 44734},
	{"JEEVES", 6, 44735},
	{"HARP", 4, 44736},
	{"USWO", 4, 44737},
	{"THCR", 4, 44738},
	{"ESCROW", 6, 44739},
	{"LAWO", 4, 44740},
	{"LUMPUR", 6, 44741},
	{"CREL", 4, 44742},
	{"DENTON", 6, 44743},
	{"ANTHEM", 6, 44744},
	{"TACK", 4, 44745},
	{"WHITMAN", 7, 44746},
	{"NOWADAYS", 8, 44747},
	{"WOODSTOCK", 9, 44748},
	{"USFI", 4, 44749},
	{"INFOSPACE", 9, 44750},
	{"FVIE", 4, 44751},
	{"AJUN", 4, 44752},
	{"LROU", 4, 44753},
	{"INFERIOR", 8, 44754},
	{"SURFERS", 7, 44755},
	{"EORF", 4, 44756},
	{"EHUG", 4, 44757},
	{"ABUSES", 6, 44758},
	{"INSPECTED", 9, 44759},
	{"RWEI", 4, 44760},
	{"NREQ", 4, 44761},
	{"ILYN", 4, 44762},
	{"LAWT", 4, 44763},
	{"YLOV", 4, 44764},
	{"WARH", 4, 44765},
	{"NKSW", 4, 44766},
	{"JOCKEY", 6, 44767},
	{"KAUAI", 5, 44768},
	{"LICENSORS", 9, 44769},
	{"YWES", 4, 44770},
	{"AWLE", 4, 44771},
	{"EORL", 4, 44772},
	{"INDICATIVE", 10, 44773},
	{"CPC", 3, 44774},
	{"STRESSES", 8, 44775},
	{"ITHACA", 6, 44776},
	{"WEBHOSTING", 10, 44777},
	{"LOWU", 4, 44778},
	{"EDMUND", 6, 44779},
	{"PEORIA", 6, 44780},
	{"UPHOLSTERY", 10, 44781},
	{"PEEK", 4, 44782},
	{"HRUS", 4, 44783},
	{"GSBE", 4, 44784},
	{"PRACTICED", 9, 44785},
	{"ELLA", 4, 44786},
	{"RROA", 4, 44787},
	{"CASUALTIES", 10, 44788},
	{"IPSEC", 5, 44789},
	{"GFOO", 4, 44790},
	{"GCRE", 4, 44791},
	{"BOURNEMOUTH", 11, 44792},
	{"SUDOKU", 6, 44793},
	{"MONARCH", 7, 44794},
	{"VEJU", 4, 44795},
	{"UNDEF", 5, 44796},
	{"HOUSED", 6, 44797},
	{"ADMINISTERING", 13, 44798},
	{"TLAU", 4, 44799},
	{"HUMI", 4, 44800},
	{"TEMPTATION", 10, 44801},
	{"HAVANA", 6, 44802},
	{"ROWO", 4, 44803},
	{"CAMPGROUND", 10, 44804},
	{"NASAL", 5, 44805},
	{"UPZ", 3, 44806},
	{"NVAD", 4, 44807},
	{"BYGE", 4, 44808},
	{"RESTRICTIVE", 11, 44809},
	{"BWAS", 4, 44810},
	{"COSTING", 7, 44811},
	{"RANGED", 6, 44812},
	{"PREDICTIVE", 10, 44813},
	{"DGME", 4, 44814},
	{"VLAN", 4, 44815},
	{"ODIR", 4, 44816},
	{"AQUACULTURE", 11, 44817},
	{"EXTB", 4, 44818},
	{"SPRUCE", 6, 44819},
	{"NSGR", 4, 44820},
	{"PARADOX", 7, 44821},
	{"ESFU", 4, 44822},
	{"SENDMAIL", 8, 44823},
	{"REDESIGN", 8, 44824},
	{"URSW", 4, 44825},
	{"BILLINGS", 8, 44826},
	{"JEANNE", 6, 44827},
	{"NITRO", 5, 44828},
	{"OXIDATION", 9, 44829},
	{"JACKPOT", 7, 44830},
	{"MARIN", 5, 44831},
	{"BYGO", 4, 44832},
	{"DWIC", 4, 44833},
	{"UGBY", 4, 44834},
	{"CORTEX", 6, 44835},
	{"ENTITLEMENT", 11, 44836},
	{"AMENDING", 8, 44837},
	{"CONFLICTING", 11, 44838},
	{"GEORGIAN", 8, 44839},
	{"IELL", 4, 44840},
	{"COMPENSATE", 10, 44841},
	{"RECHERCHE", 9, 44842},
	{"IPBE", 4, 44843},
	{"LOSER", 5, 44844},
	{"HTBU", 4, 44845},
	{"MIXERS", 6, 44846},
	{"EWEC", 4, 44847},
	{"ACCOUNTANCY", 11, 44848},
	{"CLAUS", 5, 44849},
	{"POLICING", 8, 44850},
	{"BRAVES", 6, 44851},
	{"CRACKING", 8, 44852},
	{"WENF", 4, 44853},
	{"SUED", 4, 44854},
	{"SHOOTS", 6, 44855},
	{"MICHAELS", 8, 44856},
	{"INTERRUPTED", 11, 44857},
	{"HEMISPHERE", 10, 44858},
	{"MIRANDA", 7, 44859},
	{"KEYP", 4, 44860},
	{"CLOVER", 6, 44861},
	{"MAYF", 4, 44862},
	{"KINDNESS", 8, 44863},
	{"SIMILARITIES", 12, 44864},
	{"BEOF", 4, 44865},
	{"YFIG", 4, 44866},
	{"LYQU", 4, 44867},
	{"HIPAA", 5, 44868},
	{"PORTO", 5, 44869},
	{"EWBO", 4, 44870},
	{"NEUTRON", 7, 44871},
	{"ATQU", 4, 44872},
	{"DULUTH", 6, 44873},
	{"DIRECTS", 7, 44874},
	{"RKIL", 4, 44875},
	{"JOLLY", 5, 44876},
	{"SNAKES", 6, 44877},
	{"SWELLING", 8, 44878},
	{"SPANNING", 8, 44879},
	{"FEMME", 5, 44880},
	{"UNANIMOUS", 9, 44881},
	{"LEXT", 4, 44882},
	{"RAILWAYS", 8, 44883},
	{"APPROVES", 8, 44884},
	{"SCRIPTURES", 10, 44885},
	{"MISCONDUCT", 10, 44886},
	{"LESTER", 6, 44887},
	{"DOGG", 4, 44888},
	{"WBUS", 4, 44889},
	{"FOLKLORE", 8, 44890},
	{"RESIDES", 7, 44891},
	{"WORDING", 7, 44892},
	{"OBLIGED", 7, 44893},
	{"EDPH", 4, 44894},
	{"DDHI", 4, 44895},
	{"HFIR", 4, 44896},
	{"EUPF", 4, 44897},
	{"ROCKIES", 7, 44898},
	{"SIEGE", 5, 44899},
	{"TEBR", 4, 44900},
	{"DIMM", 4, 44901},
	{"WWEE", 4, 44902},
	{"EXERCISING", 10, 44903},
	{"ACOUSTICS", 9, 44904},
	{"VOLUNTARILY", 11, 44905},
	{"GVER", 4, 44906},
	{"PENSACOLA", 9, 44907},
	{"UESF", 4, 44908},
	{"ATKINSON", 8, 44909},
	{"YINR", 4, 44910},
	{"OULS", 4, 44911},
	{"YMPA", 4, 44912},
	{"CONDOMINIUM", 11, 44913},
	{"WILDCATS", 8, 44914},
	{"RDNE", 4, 44915},
	{"NORD", 4, 44916},
	{"EXHIBITORS", 10, 44917},
	{"TRUTHS", 6, 44918},
	{"AYPE", 4, 44919},
	{"UNAW", 4, 44920},
	{"GPOW", 4, 44921},
	{"EDSM", 4, 44922},
	{"FCRI", 4, 44923},
	{"LEDN", 4, 44924},
	{"YSEP", 4, 44925},
	{"GFUL", 4, 44926},
	{"GROUPING", 8, 44927},
	{"YFAV", 4, 44928},
	{"EERU", 4, 44929},
	{"DBEU", 4, 44930},
	{"YISR", 4, 44931},
	{"ISMW", 4, 44932},
	{"WOLFE", 5, 44933},
	{"OTFR", 4, 44934},
	{"REDWOOD", 7, 44935},
	{"THERETO", 7, 44936},
	{"CKRO", 4, 44937},
	{"INVOICES", 8, 44938},
	{"LANF", 4, 44939},
	{"OCEL", 4, 44940},
	{"NYSU", 4, 44941},
	{"NYME", 4, 44942},
	{"PLIA", 4, 44943},
	{"TYRES", 5, 44944},
	{"FERF", 4, 44945},
	{"WESTWOOD", 8, 44946},
	{"AUTHORIZING", 11, 44947},
	{"YBUR", 4, 44948},
	{"WNBE", 4, 44949},
	{"ENAMEL", 6, 44950},
	{"KSFR", 4, 44951},
	{"DLYI", 4, 44952},
	{"WERR", 4, 44953},
	{"DIGN", 4, 44954},
	{"LFEE", 4, 44955},
	{"TOBY", 4, 44956},
	{"GLY", 3, 44957},
	{"GHOL", 4, 44958},
	{"VEPU", 4, 44959},
	{"LWAT", 4, 44960},
	{"UGUE", 4, 44961},
	{"RADIANT", 7, 44962},
	{"ESTONIAN", 8, 44963},
	{"VIRGINS", 7, 44964},
	{"FIRSTLY", 7, 44965},
	{"LPOI", 4, 44966},
	{"GLEO", 4, 44967},
	{"MARTINI", 7, 44968},
	{"UNGT", 4, 44969},
	{"BUTTE", 5, 44970},
	{"BOMBER", 6, 44971},
	{"REEVES", 6, 44972},
	{"SONGWRITER", 10, 44973},
	{"YMPT", 4, 44974},
	{"OLDU", 4, 44975},
	{"DISADVANTAGE", 12, 44976},
	{"BASTARD", 7, 44977},
	{"SHANIA", 6, 44978},
	{"TORJ", 4, 44979},
	{"GLOT", 4, 44980},
	{"BEAW", 4, 44981},
	{"COASTER", 7, 44982},
	{"SPENDS", 6, 44983},
	{"HICKS", 5, 44984},
	{"TYPEDEF", 7, 44985},
	{"YEXT", 4, 44986},
	{"PRATT", 5, 44987},
	{"PEDIGREE", 8, 44988},
	{"STRIPPERS", 9, 44989},
	{"MACMILLAN", 9, 44990},
	{"FRAUDULENT", 10, 44991},
	{"WOODWORKING", 11, 44992},
	{"SHERWOOD", 8, 44993},
	{"GEGR", 4, 44994},
	{"FORGIVENESS", 11, 44995},
	{"QBW", 3, 44996},
	{"OORG", 4, 44997},
	{"WNBU", 4, 44998},
	{"CBD", 3, 44999},
	{"ALMOND", 6, 45000},
	{"PRICERUNNER", 11, 45001},
	{"ADIM", 4, 45002},
	{"MBAN", 4, 45003},
	{"CATALYTIC", 9, 45004},
	{"DITM", 4, 45005},
	{"LLJU", 4, 45006},
	{"PETITIONS", 9, 45007},
	{"RTMO", 4, 45008},
	{"FRANCAIS", 8, 45009},
	{"UERT", 4, 45010},
	{"ECUB", 4, 45011},
	{"TRENTON", 7, 45012},
	{"CHALK", 5, 45013},
	{"OMAR", 4, 45014},
	{"IERF", 4, 45015},
	{"ALEXIS", 6, 45016},
	{"NTGU", 4, 45017},
	{"BETHESDA", 8, 45018},
	{"UNGB", 4, 45019},
	{"OBAD", 4, 45020},
	{"PRIVATIZATION", 13, 45021},
	{"SOURCEFORGE", 11, 45022},
	{"SANFORD", 7, 45023},
	{"WOGA", 4, 45024},
	{"RROS", 4, 45025},
	{"AXLE", 4, 45026},
	{"MEMBRANES", 9, 45027},
	{"EGAP", 4, 45028},
	{"ECKT", 4, 45029},
	{"PUPPET", 6, 45030},
	{"EYBU", 4, 45031},
	{"TESTOSTERONE", 12, 45032},
	{"WELO", 4, 45033},
	{"CULTIVATION", 11, 45034},
	{"NUNAVUT", 7, 45035},
	{"SURVEYING", 9, 45036},
	{"QBY", 3, 45037},
	{"UPIS", 4, 45038},
	{"ISBY", 4, 45039},
	{"LOFB", 4, 45040},
	{"GRAZING", 7, 45041},
	{"BIOCHEMICAL", 11, 45042},
	{"RSAV", 4, 45043},
	{"PILLAR", 6, 45044},
	{"MIRAGE", 6, 45045},
	{"GUYW", 4, 45046},
	{"LENNON", 6, 45047},
	{"FCAM", 4, 45048},
	{"QUESTIONABLE", 12, 45049},
	{"KSAL", 4, 45050},
	{"SEASIDE", 7, 45051},
	{"WWHI", 4, 45052},
	{"HOWP", 4, 45053},
	{"ACHL", 4, 45054},
	{"SUITABILITY", 11, 45055},
	{"PRECINCT", 8, 45056},
	{"RENAMED", 7, 45057},
	{"COBB", 4, 45058},
	{"LARA", 4, 45059},
	{"PEWI", 4, 45060},
	{"UNBELIEVABLE", 12, 45061},
	{"SOLUBLE", 7, 45062},
	{"PIRACY", 6, 45063},
	{"OLFE", 4, 45064},
	{"KLYA", 4, 45065},
	{"ROWING", 6, 45066},
	{"SIDING", 6, 45067},
	{"HARDEST", 7, 45068},
	{"FORREST", 7, 45069},
	{"INVITATIONAL", 12, 45070},
	{"REMINDERS", 9, 45071},
	{"GYAR", 4, 45072},
	{"BLYH", 4, 45073},
	{"BLANCA", 6, 45074},
	{"DYEL", 4, 45075},
	{"LYKI", 4, 45076},
	{"RSOV", 4, 45077},
	{"LSDE", 4, 45078},
	{"EQUIVALENTS", 11, 45079},
	{"FULM", 4, 45080},
	{"DHOR", 4, 45081},
	{"AORD", 4, 45082},
	{"ADFI", 4, 45083},
	{"JOHANN", 6, 45084},
	{"HANDCRAFTED", 11, 45085},
	{"AFTERMARKET", 11, 45086},
	{"PINEAPPLE", 9, 45087},
	{"FELLOWSHIPS", 11, 45088},
	{"OWWO", 4, 45089},
	{"YPW", 3, 45090},
	{"TPUR", 4, 45091},
	{"AGUN", 4, 45092},
	{"EURS", 4, 45093},
	{"EJUL", 4, 45094},
	{"FREEWAY", 7, 45095},
	{"OWSC", 4, 45096},
	{"WRATH", 5, 45097},
	{"RTSU", 4, 45098},
	{"OPAL", 4, 45099},
	{"NDUM", 4, 45100},
	{"SIMPLEST", 8, 45101},
	{"PATRONS", 7, 45102},
	{"PECULIAR", 8, 45103},
	{"RPRA", 4, 45104},
	{"EUROPEANS", 9, 45105},
	{"COMMENCE", 8, 45106},
	{"MYFR", 4, 45107},
	{"DESCENDANTS", 11, 45108},
	{"ICWH", 4, 45109},
	{"REDMOND", 7, 45110},
	{"RNPA", 4, 45111},
	{"SAFEGUARD", 9, 45112},
	{"DIGITALLY", 9, 45113},
	{"LARS", 4, 45114},
	{"HATCHBACK", 9, 45115},
	{"RASU", 4, 45116},
	{"RFP", 3, 45117},
	{"OBSESSION", 9, 45118},
	{"GRIND", 5, 45119},
	{"ALBEIT", 6, 45120},
	{"BILLIARDS", 9, 45121},
	{"TARW", 4, 45122},
	{"CLINT", 5, 45123},
	{"BANKERS", 7, 45124},
	{"RIGHTEOUS", 9, 45125},
	{"NLED", 4, 45126},
	{"VEVI", 4, 45127},
	{"RMYO", 4, 45128},
	{"REDISTRIBUTION", 14, 45129},
	{"RKSF", 4, 45130},
	{"WWIL", 4, 45131},
	{"FREAKS", 6, 45132},
	{"UTEM", 4, 45133},
	{"KECH", 4, 45134},
	{"ESRU", 4, 45135},
	{"LDBO", 4, 45136},
	{"SUBCLASS", 8, 45137},
	{"RDIT", 4, 45138},
	{"KSRE", 4, 45139},
	{"EEDY", 4, 45140},
	{"DMYS", 4, 45141},
	{"RUTGERS", 7, 45142},
	{"GEWO", 4, 45143},
	{"SAMPLED", 7, 45144},
	{"SINCERE", 7, 45145},
	{"AMEV", 4, 45146},
	{"DEPLOYING", 9, 45147},
	{"INTERACTING", 11, 45148},
	{"ROANOKE", 7, 45149},
	{"INTENTIONALLY", 13, 45150},
	{"BLITZ", 5, 45151},
	{"TENDED", 6, 45152},
	{"CENSORSHIP", 10, 45153},
	{"MOFC", 4, 45154},
	{"CACTUS", 6, 45155},
	{"VIVA", 4, 45156},
	{"TREADMILL", 9, 45157},
	{"ANYU", 4, 45158},
	{"LITW", 4, 45159},
	{"HSUP", 4, 45160},
	{"EBUN", 4, 45161},
	{"FIBERGLASS", 10, 45162},
	{"ATTAINED", 8, 45163},
	{"LDSW", 4, 45164},
	{"RFJ", 3, 45165},
	{"BLEW", 4, 45166},
	{"OSAKA", 5, 45167},
	{"SPLENDID", 8, 45168},
	{"MNOW", 4, 45169},
	{"JANICE", 6, 45170},
	{"IFEF", 4, 45171},
	{"PERSONALIZE", 11, 45172},
	{"LAVA", 4, 45173},
	{"LEONARDO", 8, 45174},
	{"SUCKED", 6, 45175},
	{"YSBU", 4, 45176},
	{"RTYF", 4, 45177},
	{"SCISSORS", 8, 45178},
	{"BRONCOS", 7, 45179},
	{"JORGE", 5, 45180},
	{"UTOP", 4, 45181},
	{"COOKS", 5, 45182},
	{"RNAB", 4, 45183},
	{"OUGA", 4, 45184},
	{"GRANADA", 7, 45185},
	{"LAURENCE", 8, 45186},
	{"WIFT", 4, 45187},
	{"RGON", 4, 45188},
	{"NPAL", 4, 45189},
	{"SAQU", 4, 45190},
	{"REBELLION", 9, 45191},
	{"RAINY", 5, 45192},
	{"REGENT", 6, 45193},
	{"ALYZ", 4, 45194},
	{"YPUR", 4, 45195},
	{"EVELYN", 6, 45196},
	{"VINEGAR", 7, 45197},
	{"CLASSIFICATIONS", 15, 45198},
	{"FFMA", 4, 45199},
	{"NECR", 4, 45200},
	{"CKAL", 4, 45201},
	{"DIGGS", 5, 45202},
	{"RAFTING", 7, 45203},
	{"PLUTO", 5, 45204},
	{"NOFJ", 4, 45205},
	{"VAIL", 4, 45206},
	{"SUNF", 4, 45207},
	{"GHLE", 4, 45208},
	{"MISERY", 6, 45209},
	{"UNDERGOING", 10, 45210},
	{"LIMERICK", 8, 45211},
	{"YSOR", 4, 45212},
	{"YLEG", 4, 45213},
	{"SAFARIS", 7, 45214},
	{"CONTAMINANTS", 12, 45215},
	{"ENVY", 4, 45216},
	{"GSPA", 4, 45217},
	{"MITCH", 5, 45218},
	{"OYLE", 4, 45219},
	{"SWEEPING", 8, 45220},
	{"ELFC", 4, 45221},
	{"HEALTHIER", 9, 45222},
	{"CKIT", 4, 45223},
	{"RTHF", 4, 45224},
	{"USSR", 4, 45225},
	{"MAILER", 6, 45226},
	{"PREFACE", 7, 45227},
	{"JAMESON", 7, 45228},
	{"GRIEVANCE", 9, 45229},
	{"ELLN", 4, 45230},
	{"LINERS", 6, 45231},
	{"ASHEVILLE", 9, 45232},
	{"SFIX", 4, 45233},
	{"UTBO", 4, 45234},
	{"UNREAD", 6, 45235},
	{"MVER", 4, 45236},
	{"TLYN", 4, 45237},
	{"LDPL", 4, 45238},
	{"PENCILS", 7, 45239},
	{"WUY", 3, 45240},
	{"RKX", 3, 45241},
	{"TDUE", 4, 45242},
	{"GALLOWAY", 8, 45243},
	{"QUINTA", 6, 45244},
	{"EJUM", 4, 45245},
	{"DATC", 4, 45246},
	{"KRISTIN", 7, 45247},
	{"FORGED", 6, 45248},
	{"BISTRO", 6, 45249},
	{"VIOLA", 5, 45250},
	{"DGEF", 4, 45251},
	{"RSGR", 4, 45252},
	{"TYMI", 4, 45253},
	{"VOODOO", 6, 45254},
	{"AIDG", 4, 45255},
	{"OWSM", 4, 45256},
	{"WHYA", 4, 45257},
	{"DISCLOSURES", 11, 45258},
	{"RRON", 4, 45259},
	{"LKOF", 4, 45260},
	{"PROVENCE", 8, 45261},
	{"ITRU", 4, 45262},
	{"UJJ", 3, 45263},
	{"CACHING", 7, 45264},
	{"COMPUTERIZED", 12, 45265},
	{"DBIG", 4, 45266},
	{"RUSTIC", 6, 45267},
	{"EEPW", 4, 45268},
	{"CYPR", 4, 45269},
	{"DJUL", 4, 45270},
	{"AMAK", 4, 45271},
	{"DILLON", 6, 45272},
	{"RJAC", 4, 45273},
	{"DPEA", 4, 45274},
	{"ELEANOR", 7, 45275},
	{"LAYH", 4, 45276},
	{"ERMY", 4, 45277},
	{"DECEPTION", 9, 45278},
	{"VOLTS", 5, 45279},
	{"CONDUCTS", 8, 45280},
	{"DIVORCED", 8, 45281},
	{"RUSHED", 6, 45282},
	{"EXCALIBUR", 9, 45283},
	{"YADM", 4, 45284},
	{"AUCE", 4, 45285},
	{"WEIGHS", 6, 45286},
	{"ARWO", 4, 45287},
	{"SINATRA", 7, 45288},
	{"AYBO", 4, 45289},
	{"DSOX", 4, 45290},
	{"MAGNOLIA", 8, 45291},
	{"DIVER", 5, 45292},
	{"CASTLES", 7, 45293},
	{"NBEP", 4, 45294},
	{"NOTIONS", 7, 45295},
	{"PLATEAU", 7, 45296},
	{"INTERPERSONAL", 13, 45297},
	{"DEXTER", 6, 45298},
	{"SFUT", 4, 45299},
	{"TRAUMATIC", 9, 45300},
	{"RINGER", 6, 45301},
	{"ORCY", 4, 45302},
	{"AMDE", 4, 45303},
	{"MONR", 4, 45304},
	{"ZIPPER", 6, 45305},
	{"MEDS", 4, 45306},
	{"RYIM", 4, 45307},
	{"YKD", 3, 45308},
	{"GANU", 4, 45309},
	{"CKHI", 4, 45310},
	{"ACTB", 4, 45311},
	{"PALETTE", 7, 45312},
	{"BLAZE", 5, 45313},
	{"ELSB", 4, 45314},
	{"WRECK", 5, 45315},
	{"NGOB", 4, 45316},
	{"THREATENS", 9, 45317},
	{"STRENGTHENED", 12, 45318},
	{"SAMMY", 5, 45319},
	{"ELSF", 4, 45320},
	{"BRIEFINGS", 9, 45321},
	{"SIBLINGS", 8, 45322},
	{"YOPP", 4, 45323},
	{"WAKEFIELD", 9, 45324},
	{"LTYT", 4, 45325},
	{"ADVERSELY", 9, 45326},
	{"PITCAIRN", 8, 45327},
	{"CENTRO", 6, 45328},
	{"YZW", 3, 45329},
	{"UGHG", 4, 45330},
	{"PDB", 3, 45331},
	{"BEPE", 4, 45332},
	{"ARABS", 5, 45333},
	{"RSBR", 4, 45334},
	{"YPOW", 4, 45335},
	{"MONM", 4, 45336},
	{"GEDM", 4, 45337},
	{"BILD", 4, 45338},
	{"WSRE", 4, 45339},
	{"OFLY", 4, 45340},
	{"ONBOARD", 7, 45341},
	{"ROBBERY", 7, 45342},
	{"EFEM", 4, 45343},
	{"NUCLEIC", 7, 45344},
	{"TELECOMS", 8, 45345},
	{"YPAY", 4, 45346},
	{"UZP", 3, 45347},
	{"PEDM", 4, 45348},
	{"JASMINE", 7, 45349},
	{"YCUT", 4, 45350},
	{"CROCHET", 7, 45351},
	{"BROCK", 5, 45352},
	{"FTOP", 4, 45353},
	{"LBLA", 4, 45354},
	{"GAGR", 4, 45355},
	{"MSOR", 4, 45356},
	{"RPIC", 4, 45357},
	{"DAPL", 4, 45358},
	{"CROWDS", 6, 45359},
	{"DXW", 3, 45360},
	{"DYST", 4, 45361},
	{"HOOPS", 5, 45362},
	{"LRAT", 4, 45363},
	{"WSWI", 4, 45364},
	{"MACON", 5, 45365},
	{"CELERON", 7, 45366},
	{"SGIR", 4, 45367},
	{"MEVI", 4, 45368},
	{"LYNNE", 5, 45369},
	{"LDAM", 4, 45370},
	{"INVARIANT", 9, 45371},
	{"TOFK", 4, 45372},
	{"YTHM", 4, 45373},
	{"STAMPED", 7, 45374},
	{"MLIK", 4, 45375},
	{"EKOR", 4, 45376},
	{"CHALLENGER", 10, 45377},
	{"INCREMENT", 9, 45378},
	{"REDISTRIBUTED", 13, 45379},
	{"NYWO", 4, 45380},
	{"UPTAKE", 6, 45381},
	{"NEWSWEEK", 8, 45382},
	{"GEARED", 6, 45383},
	{"IDEALS", 6, 45384},
	{"CHLOE", 5, 45385},
	{"NPAY", 4, 45386},
	{"OADR", 4, 45387},
	{"FMET", 4, 45388},
	{"UEWA", 4, 45389},
	{"APOLOGIES", 9, 45390},
	{"PRADA", 5, 45391},
	{"TYCOON", 6, 45392},
	{"NGTU", 4, 45393},
	{"URNH", 4, 45394},
	{"MALIGNANT", 9, 45395},
	{"ZGL", 3, 45396},
	{"RXX", 3, 45397},
	{"MYWA", 4, 45398},
	{"RKMA", 4, 45399},
	{"MAXTOR", 6, 45400},
	{"PLONE", 5, 45401},
	{"DCP", 3, 45402},
	{"ORGU", 4, 45403},
	{"LGRE", 4, 45404},
	{"RRYF", 4, 45405},
	{"YJUN", 4, 45406},
	{"MENF", 4, 45407},
	{"PRECEDED", 8, 45408},
	{"LAWFUL", 6, 45409},
	{"RMUC", 4, 45410},
	{"CROSBY", 6, 45411},
	{"BIOCHEM", 7, 45412},
	{"KTOM", 4, 45413},
	{"BYHO", 4, 45414},
	{"FEUR", 4, 45415},
	{"GATEWAYS", 8, 45416},
	{"COMPACTFLASH", 12, 45417},
	{"COLLAPSED", 9, 45418},
	{"ANTIBIOTIC", 10, 45419},
	{"RPHA", 4, 45420},
	{"HORNS", 5, 45421},
	{"VANDERBILT", 10, 45422},
	{"DIVERSION", 9, 45423},
	{"GDIF", 4, 45424},
	{"OVERWEIGHT", 10, 45425},
	{"RNAD", 4, 45426},
	{"FANTASIES", 9, 45427},
	{"METASEARCH", 10, 45428},
	{"OBOR", 4, 45429},
	{"TALIBAN", 7, 45430},
	{"MAUREEN", 7, 45431},
	{"AYWO", 4, 45432},
	{"TREKKING", 8, 45433},
	{"COORDINATORS", 12, 45434},
	{"LERF", 4, 45435},
	{"BEGINNINGS", 10, 45436},
	{"REVERSAL", 8, 45437},
	{"DIGI", 4, 45438},
	{"NMER", 4, 45439},
	{"AYFI", 4, 45440},
	{"OMOD", 4, 45441},
	{"RICP", 4, 45442},
	{"ASFL", 4, 45443},
	{"SHORELINE", 9, 45444},
	{"PRESSES", 7, 45445},
	{"RORN", 4, 45446},
	{"ORDINATION", 10, 45447},
	{"WESTIN", 6, 45448},
	{"OXFORDSHIRE", 11, 45449},
	{"YVES", 4, 45450},
	{"TANDEM", 6, 45451},
	{"DPLE", 4, 45452},
	{"MIDDLEWARE", 10, 45453},
	{"DCHU", 4, 45454},
	{"MIPS", 4, 45455},
	{"DELIBERATE", 10, 45456},
	{"FHOM", 4, 45457},
	{"GAGGED", 6, 45458},
	{"LMAY", 4, 45459},
	{"ROUNDTABLE", 10, 45460},
	{"PSED", 4, 45461},
	{"SURPRISES", 9, 45462},
	{"SOBV", 4, 45463},
	{"FREG", 4, 45464},
	{"AGAL", 4, 45465},
	{"YLJ", 3, 45466},
	{"QUD", 3, 45467},
	{"JJU", 3, 45468},
	{"USEG", 4, 45469},
	{"RYPT", 4, 45470},
	{"TBUY", 4, 45471},
	{"SBUD", 4, 45472},
	{"DEMENTIA", 8, 45473},
	{"BARLEY", 6, 45474},
	{"RSIF", 4, 45475},
	{"ODSW", 4, 45476},
	{"BYJA", 4, 45477},
	{"POTENT", 6, 45478},
	{"AMUSING", 7, 45479},
	{"BLYD", 4, 45480},
	{"MASTERING", 9, 45481},
	{"WAYM", 4, 45482},
	{"CKBY", 4, 45483},
	{"BYAF", 4, 45484},
	{"LEVINE", 6, 45485},
	{"DELH", 4, 45486},
	{"NERVES", 6, 45487},
	{"RIPENCC", 7, 45488},
	{"SHOPPY", 6, 45489},
	{"ONDQ", 4, 45490},
	{"FILESYSTEM", 10, 45491},
	{"RETAINS", 7, 45492},
	{"LSWA", 4, 45493},
	{"TDRO", 4, 45494},
	{"URDO", 4, 45495},
	{"DOCKING", 7, 45496},
	{"GUIDEBOOK", 9, 45497},
	{"ATREYU", 6, 45498},
	{"KYLIE", 5, 45499},
	{"MUEL", 4, 45500},
	{"LTRY", 4, 45501},
	{"PILATES", 7, 45502},
	{"CHIMNEY", 7, 45503},
	{"OOLY", 4, 45504},
	{"LDEL", 4, 45505},
	{"YFD", 3, 45506},
	{"BACKSTREET", 10, 45507},
	{"FSAL", 4, 45508},
	{"PACKERS", 7, 45509},
	{"LOCALIZED", 9, 45510},
	{"ORKR", 4, 45511},
	{"NAOMI", 5, 45512},
	{"PROVERBS", 8, 45513},
	{"ORYR", 4, 45514},
	{"IBUN", 4, 45515},
	{"DCEL", 4, 45516},
	{"MISTAKEN", 8, 45517},
	{"CARVING", 7, 45518},
	{"RCEW", 4, 45519},
	{"MIRACLES", 8, 45520},
	{"OCRO", 4, 45521},
	{"DOCC", 4, 45522},
	{"FKIN", 4, 45523},
	{"CLAIR", 5, 45524},
	{"SLIPPED", 7, 45525},
	{"FWEA", 4, 45526},
	{"REALISM", 7, 45527},
	{"MAFT", 4, 45528},
	{"DBOU", 4, 45529},
	{"PSWH", 4, 45530},
	{"TJUD", 4, 45531},
	{"CRETE", 5, 45532},
	{"RDSL", 4, 45533},
	{"FRACTIONS", 9, 45534},
	{"EYSU", 4, 45535},
	{"URTW", 4, 45536},
	{"DYWH", 4, 45537},
	{"ULLC", 4, 45538},
	{"TRIU", 4, 45539},
	{"ARCHIVING", 9, 45540},
	{"ERYU", 4, 45541},
	{"DISCONNECT", 10, 45542},
	{"GUEO", 4, 45543},
	{"BLOODHOUND", 10, 45544},
	{"MULTILINGUAL", 12, 45545},
	{"OPOU", 4, 45546},
	{"SHERRY", 6, 45547},
	{"BESP", 4, 45548},
	{"INDIES", 6, 45549},
	{"TULIP", 5, 45550},
	{"NDGL", 4, 45551},
	{"ARLS", 4, 45552},
	{"MADAME", 6, 45553},
	{"REMEDIAL", 8, 45554},
	{"GINL", 4, 45555},
	{"BERT", 4, 45556},
	{"IMMUNIZATION", 12, 45557},
	{"DALTON", 6, 45558},
	{"ELLG", 4, 45559},
	{"WINB", 4, 45560},
	{"BOLOGNA", 7, 45561},
	{"WERM", 4, 45562},
	{"OMSU", 4, 45563},
	{"DEPARTING", 9, 45564},
	{"LMOD", 4, 45565},
	{"CIARA", 5, 45566},
	{"MAZE", 4, 45567},
	{"ODAL", 4, 45568},
	{"WSWE", 4, 45569},
	{"RNEU", 4, 45570},
	{"ABUR", 4, 45571},
	{"ICSB", 4, 45572},
	{"LQUA", 4, 45573},
	{"OBUR", 4, 45574},
	{"BAREFOOT", 8, 45575},
	{"LERK", 4, 45576},
	{"REMUNERATION", 12, 45577},
	{"OWPA", 4, 45578},
	{"BOHEMIAN", 8, 45579},
	{"INTERVIEWING", 12, 45580},
	{"CATEGORIZED", 11, 45581},
	{"IFTY", 4, 45582},
	{"DWEH", 4, 45583},
	{"IMPOSING", 8, 45584},
	{"DAMON", 5, 45585},
	{"TECL", 4, 45586},
	{"TIVOLI", 6, 45587},
	{"CMOS", 4, 45588},
	{"TRANSMISSIONS", 13, 45589},
	{"YAUT", 4, 45590},
	{"LVAR", 4, 45591},
	{"AGOB", 4, 45592},
	{"RECEIVABLE", 10, 45593},
	{"RODE", 4, 45594},
	{"MARCHING", 8, 45595},
	{"FINV", 4, 45596},
	{"RONNIE", 6, 45597},
	{"ECUP", 4, 45598},
	{"OWING", 5, 45599},
	{"WARP", 4, 45600},
	{"ARKR", 4, 45601},
	{"IMPLANT", 7, 45602},
	{"LACR", 4, 45603},
	{"PLAYLISTS", 9, 45604},
	{"THEMATIC", 8, 45605},
	{"BRENTWOOD", 9, 45606},
	{"CATHOLICS", 9, 45607},
	{"UNLO", 4, 45608},
	{"NBOW", 4, 45609},
	{"RILI", 4, 45610},
	{"CORRECTIONAL", 12, 45611},
	{"LYBI", 4, 45612},
	{"BLYC", 4, 45613},
	{"FACULTIES", 9, 45614},
	{"KATZ", 4, 45615},
	{"DENIES", 6, 45616},
	{"JOJO", 4, 45617},
	{"BUFFERS", 7, 45618},
	{"RDMO", 4, 45619},
	{"TALKBACK", 8, 45620},
	{"NGSG", 4, 45621},
	{"ACTM", 4, 45622},
	{"SERVINGS", 8, 45623},
	{"OOLR", 4, 45624},
	{"LYBL", 4, 45625},
	{"LLRU", 4, 45626},
	{"RYGR", 4, 45627},
	{"KOBE", 4, 45628},
	{"INCEPTION", 9, 45629},
	{"BAYLOR", 6, 45630},
	{"BOWMAN", 6, 45631},
	{"FRUSTRATING", 11, 45632},
	{"SUBVERSION", 10, 45633},
	{"BENNY", 5, 45634},
	{"SPIRES", 6, 45635},
	{"UNBY", 4, 45636},
	{"BARNEY", 6, 45637},
	{"DINNERWARE", 10, 45638},
	{"FYK", 3, 45639},
	{"BYFR", 4, 45640},
	{"BYRA", 4, 45641},
	{"SCLEROSIS", 9, 45642},
	{"RLYN", 4, 45643},
	{"PTCY", 4, 45644},
	{"RUET", 4, 45645},
	{"DECLARES", 8, 45646},
	{"ACYO", 4, 45647},
	{"MASONRY", 7, 45648},
	{"RONB", 4, 45649},
	{"DEOU", 4, 45650},
	{"MEDICINAL", 9, 45651},
	{"ESTROGEN", 8, 45652},
	{"ODBC", 4, 45653},
	{"IPODS", 5, 45654},
	{"FMEN", 4, 45655},
	{"OPSW", 4, 45656},
	{"ACCRUED", 7, 45657},
	{"TEMPLES", 7, 45658},
	{"REALIZING", 9, 45659},
	{"ANNUM", 5, 45660},
	{"TOPB", 4, 45661},
	{"OPENBSD", 7, 45662},
	{"CEMETERIES", 10, 45663},
	{"INDOORS", 7, 45664},
	{"MBIG", 4, 45665},
	{"TELESCOPES", 10, 45666},
	{"AVOL", 4, 45667},
	{"DMOU", 4, 45668},
	{"RDOM", 4, 45669},
	{"LFWI", 4, 45670},
	{"OLDN", 4, 45671},
	{"MAGELLAN", 8, 45672},
	{"NCYR", 4, 45673},
	{"CHAMPS", 6, 45674},
	{"DVIE", 4, 45675},
	{"OGYO", 4, 45676},
	{"AWRI", 4, 45677},
	{"ISFL", 4, 45678},
	{"FEDERATED", 9, 45679},
	{"YILL", 4, 45680},
	{"AVERAGING", 9, 45681},
	{"RAGM", 4, 45682},
	{"SALADS", 6, 45683},
	{"IDOW", 4, 45684},
	{"CBOO", 4, 45685},
	{"ADDICTED", 8, 45686},
	{"FLASHLIGHT", 10, 45687},
	{"DISAPPOINTING", 13, 45688},
	{"ROCKFORD", 8, 45689},
	{"EIGHTY", 6, 45690},
	{"STAGING", 7, 45691},
	{"UNLOCKED", 8, 45692},
	{"SCARCE", 6, 45693},
	{"RDAI", 4, 45694},
	{"XHAU", 4, 45695},
	{"AMSB", 4, 45696},
	{"STATISTIC", 9, 45697},
	{"CKWO", 4, 45698},
	{"ROCHE", 5, 45699},
	{"ROPES", 5, 45700},
	{"TORINO", 6, 45701},
	{"SPIDERS", 7, 45702},
	{"OBEDIENCE", 9, 45703},
	{"YSKI", 4, 45704},
	{"YMEE", 4, 45705},
	{"GHAP", 4, 45706},
	{"PLAGUE", 6, 45707},
	{"DILUTED", 7, 45708},
	{"CANINE", 6, 45709},
	{"GLADLY", 6, 45710},
	{"SCHIZOPHRENIA", 13, 45711},
	{"BREWERY", 7, 45712},
	{"ULLF", 4, 45713},
	{"LINEAGE", 7, 45714},
	{"MEHR", 4, 45715},
	{"BREW", 4, 45716},
	{"VAUGHAN", 7, 45717},
	{"KERN", 4, 45718},
	{"CERW", 4, 45719},
	{"JULIUS", 6, 45720},
	{"CANNES", 6, 45721},
	{"AFED", 4, 45722},
	{"MORSE", 5, 45723},
	{"UTFE", 4, 45724},
	{"CTRU", 4, 45725},
	{"USGO", 4, 45726},
	{"DOMINANCE", 9, 45727},
	{"PREDATORS", 9, 45728},
	{"PISTON", 6, 45729},
	{"ULSO", 4, 45730},
	{"CORDS", 5, 45731},
	{"GWOM", 4, 45732},
	{"REVISITED", 9, 45733},
	{"UBSA", 4, 45734},
	{"AYTR", 4, 45735},
	{"EWPA", 4, 45736},
	{"SEALING", 7, 45737},
	{"TOPPED", 6, 45738},
	{"ADHESIVES", 9, 45739},
	{"DESPAIR", 7, 45740},
	{"ILLV", 4, 45741},
	{"OTBU", 4, 45742},
	{"BUYT", 4, 45743},
	{"INVENTORIES", 11, 45744},
	{"FORE", 4, 45745},
	{"FTBA", 4, 45746},
	{"BROKEBACK", 9, 45747},
	{"INJECTED", 8, 45748},
	{"NDEU", 4, 45749},
	{"IEDU", 4, 45750},
	{"USKI", 4, 45751},
	{"ALPS", 4, 45752},
	{"BYDO", 4, 45753},
	{"COMMODORE", 9, 45754},
	{"DUMPING", 7, 45755},
	{"ENLISTED", 8, 45756},
	{"PROPHETS", 8, 45757},
	{"RCLU", 4, 45758},
	{"LLDR", 4, 45759},
	{"AFIV", 4, 45760},
	{"WAREZ", 5, 45761},
	{"DBEW", 4, 45762},
	{"KSBU", 4, 45763},
	{"UNGI", 4, 45764},
	{"FFRI", 4, 45765},
	{"XPIR", 4, 45766},
	{"SUPERNATURAL", 12, 45767},
	{"OVERLOOKED", 10, 45768},
	{"MAGENTA", 7, 45769},
	{"TAGGING", 7, 45770},
	{"ANKW", 4, 45771},
	{"DITCH", 5, 45772},
	{"GEVI", 4, 45773},
	{"FEARED", 6, 45774},
	{"PRELUDE", 7, 45775},
	{"YCOA", 4, 45776},
	{"UZZL", 4, 45777},
	{"EEPU", 4, 45778},
	{"WYU", 3, 45779},
	{"VKL", 3, 45780},
	{"GCZ", 3, 45781},
	{"SMOF", 4, 45782},
	{"ROWE", 4, 45783},
	{"SLICK", 5, 45784},
	{"UEWH", 4, 45785},
	{"OVERLY", 6, 45786},
	{"LIMESTONE", 9, 45787},
	{"ODIV", 4, 45788},
	{"LKSW", 4, 45789},
	{"TRIGGERS", 8, 45790},
	{"COMMENTARIES", 12, 45791},
	{"CONSTRUCTS", 10, 45792},
	{"IMPEDANCE", 9, 45793},
	{"ULEO", 4, 45794},
	{"DRAGONFLY", 9, 45795},
	{"MANPOWER", 8, 45796},
	{"UNDEROATH", 9, 45797},
	{"EAKD", 4, 45798},
	{"WCOU", 4, 45799},
	{"ELSP", 4, 45800},
	{"REELS", 5, 45801},
	{"ALSR", 4, 45802},
	{"SLEPT", 5, 45803},
	{"RGAS", 4, 45804},
	{"UPRO", 4, 45805},
	{"GREGG", 5, 45806},
	{"REFUNDABLE", 10, 45807},
	{"RTSD", 4, 45808},
	{"EJUR", 4, 45809},
	{"BILLBOARD", 9, 45810},
	{"DLIM", 4, 45811},
	{"DRAFTED", 7, 45812},
	{"CHALET", 6, 45813},
	{"HUANG", 5, 45814},
	{"DSIL", 4, 45815},
	{"SPORTSBOOK", 10, 45816},
	{"LAYERED", 7, 45817},
	{"NTYR", 4, 45818},
	{"HOPPER", 6, 45819},
	{"LLVI", 4, 45820},
	{"NEUROLOGICAL", 12, 45821},
	{"DBYK", 4, 45822},
	{"SUBS", 4, 45823},
	{"SPECIALIZATION", 14, 45824},
	{"NTDU", 4, 45825},
	{"LETC", 4, 45826},
	{"ABSTRACTION", 11, 45827},
	{"YPRA", 4, 45828},
	{"RCHY", 4, 45829},
	{"LUDWIG", 6, 45830},
	{"WATCHDOG", 8, 45831},
	{"RPLU", 4, 45832},
	{"ENBL", 4, 45833},
	{"SCANDINAVIAN", 12, 45834},
	{"RRAD", 4, 45835},
	{"STARBUCKS", 9, 45836},
	{"IBOOK", 5, 45837},
	{"MYDA", 4, 45838},
	{"VIABILITY", 9, 45839},
	{"DETAINED", 8, 45840},
	{"LUNCHEON", 8, 45841},
	{"DUPF", 4, 45842},
	{"FILLER", 6, 45843},
	{"SMILEY", 6, 45844},
	{"ZENITH", 6, 45845},
	{"GENOMICS", 8, 45846},
	{"OUFO", 4, 45847},
	{"YUM", 3, 45848},
	{"BROWNS", 6, 45849},
	{"RDCH", 4, 45850},
	{"RESEARCHED", 10, 45851},
	{"WAITS", 5, 45852},
	{"WOMI", 4, 45853},
	{"TENOR", 5, 45854},
	{"HADV", 4, 45855},
	{"COPIERS", 7, 45856},
	{"OVARIAN", 7, 45857},
	{"PLENARY", 7, 45858},
	{"SCRUB", 5, 45859},
	{"IFOU", 4, 45860},
	{"BOYF", 4, 45861},
	{"BLAI", 4, 45862},
	{"RPAI", 4, 45863},
	{"AIRPLANES", 9, 45864},
	{"WILKINSON", 9, 45865},
	{"LYEL", 4, 45866},
	{"INTESTINAL", 10, 45867},
	{"WCZ", 3, 45868},
	{"CELLO", 5, 45869},
	{"WLAN", 4, 45870},
	{"GCLO", 4, 45871},
	{"MMUT", 4, 45872},
	{"REFUSING", 8, 45873},
	{"SUFFERS", 7, 45874},
	{"RMEE", 4, 45875},
	{"SWEEPSTAKES", 11, 45876},
	{"UPSH", 4, 45877},
	{"ANFL", 4, 45878},
	{"EAMD", 4, 45879},
	{"ANTIGENS", 8, 45880},
	{"MIDTOWN", 7, 45881},
	{"BETHLEHEM", 9, 45882},
	{"XXM", 3, 45883},
	{"STABILIZATION", 13, 45884},
	{"CAVES", 5, 45885},
	{"ACHG", 4, 45886},
	{"AUTHORITATIVE", 13, 45887},
	{"CELESTIAL", 9, 45888},
	{"UTHP", 4, 45889},
	{"ERCY", 4, 45890},
	{"IMMENSE", 7, 45891},
	{"AUDREY", 6, 45892},
	{"MERLIN", 6, 45893},
	{"IROP", 4, 45894},
	{"KINETICS", 8, 45895},
	{"COCOS", 5, 45896},
	{"SORL", 4, 45897},
	{"AIMING", 6, 45898},
	{"SEIZURE", 7, 45899},
	{"STUTTGART", 9, 45900},
	{"SDAR", 4, 45901},
	{"DIPLOMACY", 9, 45902},
	{"MPEL", 4, 45903},
	{"BADT", 4, 45904},
	{"DIFFERING", 9, 45905},
	{"IMPACTED", 8, 45906},
	{"YPK", 3, 45907},
	{"DDZ", 3, 45908},
	{"BLYO", 4, 45909},
	{"FOREIGNERS", 10, 45910},
	{"LIMP", 4, 45911},
	{"NTUP", 4, 45912},
	{"ETPL", 4, 45913},
	{"CAPITALIST", 10, 45914},
	{"UHAD", 4, 45915},
	{"EMOB", 4, 45916},
	{"ADWE", 4, 45917},
	{"RUMSFELD", 8, 45918},
	{"MUTE", 4, 45919},
	{"BEANIE", 6, 45920},
	{"PRESCOTT", 8, 45921},
	{"PROTESTANT", 10, 45922},
	{"METRE", 5, 45923},
	{"TRICKY", 6, 45924},
	{"ORDINANCES", 10, 45925},
	{"IUMT", 4, 45926},
	{"FFON", 4, 45927},
	{"THURS", 5, 45928},
	{"SPACED", 6, 45929},
	{"RKRE", 4, 45930},
	{"KEYI", 4, 45931},
	{"BUTJ", 4, 45932},
	{"KOCH", 4, 45933},
	{"TOPAZ", 5, 45934},
	{"TFLA", 4, 45935},
	{"SEGMENTATION", 12, 45936},
	{"IMAGINARY", 9, 45937},
	{"AWFU", 4, 45938},
	{"ALBION", 6, 45939},
	{"SOAPS", 5, 45940},
	{"EWAG", 4, 45941},
	{"KSOU", 4, 45942},
	{"COURTHOUSE", 10, 45943},
	{"ERYV", 4, 45944},
	{"GWOU", 4, 45945},
	{"SUTHERLAND", 10, 45946},
	{"YTRY", 4, 45947},
	{"ENTREPRENEURIAL", 15, 45948},
	{"DNTL", 4, 45949},
	{"VESD", 4, 45950},
	{"BYBA", 4, 45951},
	{"DART", 4, 45952},
	{"LEBANESE", 8, 45953},
	{"PSYCHO", 6, 45954},
	{"MAHARASHTRA", 11, 45955},
	{"RICOH", 5, 45956},
	{"WROUGHT", 7, 45957},
	{"ROBE", 4, 45958},
	{"RALV", 4, 45959},
	{"LYEM", 4, 45960},
	{"THERESA", 7, 45961},
	{"HEIDELBERG", 10, 45962},
	{"MULTITUDE", 9, 45963},
	{"ORKD", 4, 45964},
	{"EMYT", 4, 45965},
	{"TUTORS", 6, 45966},
	{"PSBE", 4, 45967},
	{"EZRA", 4, 45968},
	{"HOUSEKEEPING", 12, 45969},
	{"UDGM", 4, 45970},
	{"CAPTIVE", 7, 45971},
	{"LLSL", 4, 45972},
	{"KETTLE", 6, 45973},
	{"VISITATION", 10, 45974},
	{"DATB", 4, 45975},
	{"FTOW", 4, 45976},
	{"GIBBS", 5, 45977},
	{"RYRA", 4, 45978},
	{"RCOV", 4, 45979},
	{"BAGGAGE", 7, 45980},
	{"CHAVEZ", 6, 45981},
	{"DUSTY", 5, 45982},
	{"FSOF", 4, 45983},
	{"PATTY", 5, 45984},
	{"SERENA", 6, 45985},
	{"RYSM", 4, 45986},
	{"SATIRE", 6, 45987},
	{"OVERLOAD", 8, 45988},
	{"UGAN", 4, 45989},
	{"TORTURED", 8, 45990},
	{"PIONEERS", 8, 45991},
	{"RBEH", 4, 45992},
	{"ENJU", 4, 45993},
	{"VIKINGS", 7, 45994},
	{"CRATE", 5, 45995},
	{"KANYE", 5, 45996},
	{"BOOTSTRAP", 9, 45997},
	{"LMAD", 4, 45998},
	{"EPISCOPAL", 9, 45999},
	{"HUMANE", 6, 46000},
	{"ULDV", 4, 46001},
	{"SPIK", 4, 46002},
	{"EYUS", 4, 46003},
	{"RPOP", 4, 46004},
	{"MOONLIGHT", 9, 46005},
	{"TRAVELOCITY", 11, 46006},
	{"NCYW", 4, 46007},
	{"BYNE", 4, 46008},
	{"UNFINISHED", 10, 46009},
	{"CARED", 5, 46010},
	{"IRWE", 4, 46011},
	{"TCHP", 4, 46012},
	{"AFFECTION", 9, 46013},
	{"SWORN", 5, 46014},
	{"TWINK", 5, 46015},
	{"BOWEN", 5, 46016},
	{"EFUE", 4, 46017},
	{"VICIOUS", 7, 46018},
	{"OLRE", 4, 46019},
	{"ODOX", 4, 46020},
	{"EDUCATING", 9, 46021},
	{"YLIG", 4, 46022},
	{"KERH", 4, 46023},
	{"NORTEL", 6, 46024},
	{"AFFILIATIONS", 12, 46025},
	{"COZY", 4, 46026},
	{"APPROPRIATED", 12, 46027},
	{"ESCHERICHIA", 11, 46028},
	{"WARB", 4, 46029},
	{"MALLORCA", 8, 46030},
	{"UTTL", 4, 46031},
	{"MACKENZIE", 9, 46032},
	{"REVERSIBLE", 10, 46033},
	{"OFNU", 4, 46034},
	{"VELW", 4, 46035},
	{"RENB", 4, 46036},
	{"SLIPPERS", 8, 46037},
	{"LDSL", 4, 46038},
	{"UNCLASSIFIED", 12, 46039},
	{"EARTHQUAKES", 11, 46040},
	{"LDEB", 4, 46041},
	{"BOOKSHELF", 9, 46042},
	{"URSP", 4, 46043},
	{"HAYWARD", 7, 46044},
	{"WANDERING", 9, 46045},
	{"EKAR", 4, 46046},
	{"COMB", 4, 46047},
	{"CEDD", 4, 46048},
	{"WODI", 4, 46049},
	{"RVOU", 4, 46050},
	{"NFUR", 4, 46051},
	{"LIQUIDS", 7, 46052},
	{"HTDOCS", 6, 46053},
	{"BEECH", 5, 46054},
	{"VINEYARDS", 9, 46055},
	{"LSPI", 4, 46056},
	{"IEDL", 4, 46057},
	{"AMER", 4, 46058},
	{"WODE", 4, 46059},
	{"RLDH", 4, 46060},
	{"ZUR", 3, 46061},
	{"FROGS", 5, 46062},
	{"KEDP", 4, 46063},
	{"FROS", 4, 46064},
	{"CONSEQUENTIAL", 13, 46065},
	{"INITIALIZATION", 14, 46066},
	{"UNREASONABLE", 12, 46067},
	{"EXPAT", 5, 46068},
	{"OSBORNE", 7, 46069},
	{"LYFL", 4, 46070},
	{"LDOC", 4, 46071},
	{"TPAU", 4, 46072},
	{"RAIDER", 6, 46073},
	{"FARMINGTON", 10, 46074},
	{"BITR", 4, 46075},
	{"LEOV", 4, 46076},
	{"TIMERS", 6, 46077},
	{"ECONOMISTS", 10, 46078},
	{"MINERS", 6, 46079},
	{"AGNES", 5, 46080},
	{"CONSTITUENCY", 12, 46081},
	{"ROCKER", 6, 46082},
	{"RSGE", 4, 46083},
	{"DTOY", 4, 46084},
	{"ACKNOWLEDGES", 12, 46085},
	{"RGOL", 4, 46086},
	{"ENROLMENT", 9, 46087},
	{"UILL", 4, 46088},
	{"BYLI", 4, 46089},
	{"GLIBC", 5, 46090},
	{"SAWYER", 6, 46091},
	{"MAORI", 5, 46092},
	{"LAWMAKERS", 9, 46093},
	{"COWA", 4, 46094},
	{"PREDICTING", 10, 46095},
	{"ICKP", 4, 46096},
	{"FILIPINO", 8, 46097},
	{"GUEB", 4, 46098},
	{"RYPL", 4, 46099},
	{"COOLED", 6, 46100},
	{"PRUDENTIAL", 10, 46101},
	{"BASEL", 5, 46102},
	{"OEFF", 4, 46103},
	{"MIGRANT", 7, 46104},
	{"DEVOTION", 8, 46105},
	{"RLDB", 4, 46106},
	{"WLON", 4, 46107},
	{"LARSON", 6, 46108},
	{"PHOTOSMART", 10, 46109},
	{"INVOKE", 6, 46110},
	{"LEANING", 7, 46111},
	{"EBYP", 4, 46112},
	{"CENTRALLY", 9, 46113},
	{"SBYP", 4, 46114},
	{"PFIN", 4, 46115},
	{"CEEX", 4, 46116},
	{"MEMP", 4, 46117},
	{"LUV", 3, 46118},
	{"PADDLE", 6, 46119},
	{"WATKINS", 7, 46120},
	{"OXLEY", 5, 46121},
	{"ANTERIOR", 8, 46122},
	{"DEALERSHIP", 10, 46123},
	{"EYEWEAR", 7, 46124},
	{"LASG", 4, 46125},
	{"ROOTED", 6, 46126},
	{"ONYX", 4, 46127},
	{"BENCHES", 7, 46128},
	{"ILLUMINATION", 12, 46129},
	{"LOFO", 4, 46130},
	{"RLDR", 4, 46131},
	{"FREEDOMS", 8, 46132},
	{"URGR", 4, 46133},
	{"BAKERSFIELD", 11, 46134},
	{"RRIL", 4, 46135},
	{"FOOLISH", 7, 46136},
	{"RWON", 4, 46137},
	{"FINALE", 6, 46138},
	{"WEAKER", 6, 46139},
	{"FOLEY", 5, 46140},
	{"EWSR", 4, 46141},
	{"RIPO", 4, 46142},
	{"YJD", 3, 46143},
	{"KERM", 4, 46144},
	{"MECR", 4, 46145},
	{"STIRLING", 8, 46146},
	{"PENF", 4, 46147},
	{"MORAN", 5, 46148},
	{"DPAN", 4, 46149},
	{"DECAL", 5, 46150},
	{"SIXP", 4, 46151},
	{"GFUN", 4, 46152},
	{"DIAP", 4, 46153},
	{"NAUSEA", 6, 46154},
	{"ZEDS", 4, 46155},
	{"DGAV", 4, 46156},
	{"YERM", 4, 46157},
	{"YGC", 3, 46158},
	{"COMFORTABLY", 11, 46159},
	{"ADDICTIVE", 9, 46160},
	{"CLARINET", 8, 46161},
	{"TEMPS", 5, 46162},
	{"FIONA", 5, 46163},
	{"CLEARER", 7, 46164},
	{"FLOODS", 6, 46165},
	{"GIGABYTE", 8, 46166},
	{"OUJU", 4, 46167},
	{"FRITZ", 5, 46168},
	{"MOVER", 5, 46169},
	{"VEDD", 4, 46170},
	{"DBZ", 3, 46171},
	{"CULU", 4, 46172},
	{"RSFE", 4, 46173},
	{"NBAY", 4, 46174},
	{"YMER", 4, 46175},
	{"MODELED", 7, 46176},
	{"ERICA", 5, 46177},
	{"YMJ", 3, 46178},
	{"MALAGA", 6, 46179},
	{"EYME", 4, 46180},
	{"NCHP", 4, 46181},
	{"WAUK", 4, 46182},
	{"RAINFOREST", 10, 46183},
	{"WOPO", 4, 46184},
	{"MPST", 4, 46185},
	{"FEDERALLY", 9, 46186},
	{"SUSTAINING", 10, 46187},
	{"MACOS", 5, 46188},
	{"OORC", 4, 46189},
	{"GEDY", 4, 46190},
	{"REPAIRED", 8, 46191},
	{"DIOCESE", 7, 46192},
	{"FRANCOIS", 8, 46193},
	{"OBITUARY", 8, 46194},
	{"WINW", 4, 46195},
	{"MULTINATIONAL", 13, 46196},
	{"AOFF", 4, 46197},
	{"PAINTERS", 8, 46198},
	{"THISTLE", 7, 46199},
	{"ANUR", 4, 46200},
	{"CKPR", 4, 46201},
	{"SLEEPY", 6, 46202},
	{"QBK", 3, 46203},
	{"GAUG", 4, 46204},
	{"FOOTNOTES", 9, 46205},
	{"RUPERT", 6, 46206},
	{"SHRINE", 6, 46207},
	{"LTSW", 4, 46208},
	{"ASPIRIN", 7, 46209},
	{"ORYD", 4, 46210},
	{"PURIFIED", 8, 46211},
	{"STRIVING", 8, 46212},
	{"RRYM", 4, 46213},
	{"DIRE", 4, 46214},
	{"IERL", 4, 46215},
	{"ATTENDANT", 9, 46216},
	{"CTSB", 4, 46217},
	{"GULL", 4, 46218},
	{"JOUR", 4, 46219},
	{"EWAB", 4, 46220},
	{"SDER", 4, 46221},
	{"EYFA", 4, 46222},
	{"SPOILERS", 8, 46223},
	{"NORTHUMBERLAND", 14, 46224},
	{"RHYT", 4, 46225},
	{"MACHINING", 9, 46226},
	{"MALIBU", 6, 46227},
	{"MEMOIR", 6, 46228},
	{"BRUI", 4, 46229},
	{"BETSY", 5, 46230},
	{"RRAR", 4, 46231},
	{"GATWICK", 7, 46232},
	{"SHAUN", 5, 46233},
	{"REDUNDANCY", 10, 46234},
	{"MEREDITH", 8, 46235},
	{"FAUNA", 5, 46236},
	{"CLIFFS", 6, 46237},
	{"HAYDEN", 6, 46238},
	{"REEQ", 4, 46239},
	{"ROADSIDE", 8, 46240},
	{"VEFE", 4, 46241},
	{"SMELLS", 6, 46242},
	{"DISPOSE", 7, 46243},
	{"VECL", 4, 46244},
	{"UCKW", 4, 46245},
	{"LYAW", 4, 46246},
	{"DETOX", 5, 46247},
	{"WAKING", 6, 46248},
	{"FEATHERS", 8, 46249},
	{"SKATEBOARD", 10, 46250},
	{"ACEU", 4, 46251},
	{"REFLEX", 6, 46252},
	{"EYFE", 4, 46253},
	{"FALCONS", 7, 46254},
	{"SGLO", 4, 46255},
	{"AUTOMATE", 8, 46256},
	{"YROU", 4, 46257},
	{"NYOR", 4, 46258},
	{"DROSOPHILA", 10, 46259},
	{"MYIS", 4, 46260},
	{"DNTD", 4, 46261},
	{"OFGI", 4, 46262},
	{"BRANSON", 7, 46263},
	{"SPURS", 5, 46264},
	{"ORTHO", 5, 46265},
	{"UCHR", 4, 46266},
	{"CRASHED", 7, 46267},
	{"YROB", 4, 46268},
	{"APPRAISALS", 10, 46269},
	{"TRAVELLED", 9, 46270},
	{"XIMI", 4, 46271},
	{"URGENCY", 7, 46272},
	{"RAOF", 4, 46273},
	{"FLASHES", 7, 46274},
	{"LEYF", 4, 46275},
	{"ATDU", 4, 46276},
	{"LAKEWOOD", 8, 46277},
	{"GOULD", 5, 46278},
	{"BRIT", 4, 46279},
	{"DRUPAL", 6, 46280},
	{"PRAC", 4, 46281},
	{"ELIZA", 5, 46282},
	{"CARERS", 6, 46283},
	{"LDIV", 4, 46284},
	{"KRAMER", 6, 46285},
	{"UWAS", 4, 46286},
	{"EWLI", 4, 46287},
	{"LERU", 4, 46288},
	{"GRADUATING", 10, 46289},
	{"RIMS", 4, 46290},
	{"HARMONIC", 8, 46291},
	{"USAID", 5, 46292},
	{"DARTS", 5, 46293},
	{"RACR", 4, 46294},
	{"WHAV", 4, 46295},
	{"RNMO", 4, 46296},
	{"INKB", 4, 46297},
	{"YVC", 3, 46298},
	{"MTOL", 4, 46299},
	{"UNFI", 4, 46300},
	{"INTRIGUING", 10, 46301},
	{"KEYPAD", 6, 46302},
	{"LDJU", 4, 46303},
	{"ROVO", 4, 46304},
	{"YISP", 4, 46305},
	{"AMIX", 4, 46306},
	{"FLAW", 4, 46307},
	{"UELL", 4, 46308},
	{"RICHLAND", 8, 46309},
	{"TAILS", 5, 46310},
	{"EMULATOR", 8, 46311},
	{"MICROBIAL", 9, 46312},
	{"DISCARDED", 9, 46313},
	{"BIBLES", 6, 46314},
	{"HANGS", 5, 46315},
	{"HLEF", 4, 46316},
	{"CAREGIVERS", 10, 46317},
	{"JOANNA", 6, 46318},
	{"QUARK", 5, 46319},
	{"ODAR", 4, 46320},
	{"ZYBAN", 5, 46321},
	{"ORNW", 4, 46322},
	{"WUJ", 3, 46323},
	{"SYNONYMS", 8, 46324},
	{"ELECTRONICA", 11, 46325},
	{"MURP", 4, 46326},
	{"HLEV", 4, 46327},
	{"WELE", 4, 46328},
	{"MITOCHONDRIAL", 13, 46329},
	{"HORTON", 6, 46330},
	{"WNPE", 4, 46331},
	{"DOLCE", 5, 46332},
	{"HERCULES", 8, 46333},
	{"HVIL", 4, 46334},
	{"OALW", 4, 46335},
	{"LAWF", 4, 46336},
	{"BROWNING", 8, 46337},
	{"ZEDC", 4, 46338},
	{"ARIU", 4, 46339},
	{"ANGULAR", 7, 46340},
	{"VEINS", 5, 46341},
	{"FOLDS", 5, 46342},
	{"HAPL", 4, 46343},
	{"EUMO", 4, 46344},
	{"GRINDER", 7, 46345},
	{"YISB", 4, 46346},
	{"ANGIE", 5, 46347},
	{"ALBL", 4, 46348},
	{"RYAG", 4, 46349},
	{"OCTET", 5, 46350},
	{"INCORRECTLY", 11, 46351},
	{"AVOIDANCE", 9, 46352},
	{"SDAV", 4, 46353},
	{"STGU", 4, 46354},
	{"IFEM", 4, 46355},
	{"DINOSAURS", 9, 46356},
	{"ARBR", 4, 46357},
	{"EMWE", 4, 46358},
	{"SAUCES", 6, 46359},
	{"CONQUER", 7, 46360},
	{"YMV", 3, 46361},
	{"SLYS", 4, 46362},
	{"MMIL", 4, 46363},
	{"LAYG", 4, 46364},
	{"MCCOY", 5, 46365},
	{"PROBABILITIES", 13, 46366},
	{"VIBE", 4, 46367},
	{"YPEA", 4, 46368},
	{"OWFR", 4, 46369},
	{"MBRE", 4, 46370},
	{"IRGR", 4, 46371},
	{"IMMORTAL", 8, 46372},
	{"MARINERS", 8, 46373},
	{"LMOT", 4, 46374},
	{"SNAPSHOTS", 9, 46375},
	{"UTUS", 4, 46376},
	{"URWE", 4, 46377},
	{"ICEG", 4, 46378},
	{"UBC", 3, 46379},
	{"ENDEAVOR", 8, 46380},
	{"CREOLE", 6, 46381},
	{"FDIR", 4, 46382},
	{"MATEO", 5, 46383},
	{"SDAL", 4, 46384},
	{"TRENDY", 6, 46385},
	{"RATW", 4, 46386},
	{"SETTLING", 8, 46387},
	{"KCHA", 4, 46388},
	{"GEAM", 4, 46389},
	{"CEAM", 4, 46390},
	{"DECH", 4, 46391},
	{"INPATIENT", 9, 46392},
	{"FILMING", 7, 46393},
	{"BADGER", 6, 46394},
	{"MOHAMMED", 8, 46395},
	{"HMED", 4, 46396},
	{"SATURDAYS", 9, 46397},
	{"NOPL", 4, 46398},
	{"GTRE", 4, 46399},
	{"PARTISAN", 8, 46400},
	{"FREAD", 5, 46401},
	{"BACKEND", 7, 46402},
	{"WEDF", 4, 46403},
	{"EWLA", 4, 46404},
	{"GRATITUDE", 9, 46405},
	{"JOBT", 4, 46406},
	{"BYTA", 4, 46407},
	{"HOWU", 4, 46408},
	{"WILLY", 5, 46409},
	{"EMINENT", 7, 46410},
	{"RIBS", 4, 46411},
	{"COMMUNICATED", 12, 46412},
	{"ILMT", 4, 46413},
	{"EXCEPTIONALLY", 13, 46414},
	{"QUILTS", 6, 46415},
	{"CARTIER", 7, 46416},
	{"AGEING", 6, 46417},
	{"OMFR", 4, 46418},
	{"SPLITS", 6, 46419},
	{"SUBSCRIBING", 11, 46420},
	{"COMPANIONS", 10, 46421},
	{"CHEQUES", 7, 46422},
	{"CONTAINMENT", 11, 46423},
	{"VYK", 3, 46424},
	{"KEYNES", 6, 46425},
	{"PROTECTIONS", 11, 46426},
	{"EDITH", 5, 46427},
	{"ALIASES", 7, 46428},
	{"MAXIMIZING", 10, 46429},
	{"KEAG", 4, 46430},
	{"SCREWED", 7, 46431},
	{"HANDSFREE", 9, 46432},
	{"TOMCAT", 6, 46433},
	{"MAGNA", 5, 46434},
	{"WALMART", 7, 46435},
	{"EACQ", 4, 46436},
	{"SECTIONAL", 9, 46437},
	{"LEYR", 4, 46438},
	{"UPCA", 4, 46439},
	{"INTERESTINGLY", 13, 46440},
	{"FASHIONABLE", 11, 46441},
	{"POLLY", 5, 46442},
	{"FKC", 3, 46443},
	{"HEML", 4, 46444},
	{"TIDAL", 5, 46445},
	{"JULES", 5, 46446},
	{"BALLOTS", 7, 46447},
	{"LICD", 4, 46448},
	{"CWHI", 4, 46449},
	{"ERNIE", 5, 46450},
	{"POOLE", 5, 46451},
	{"BOYCOTT", 7, 46452},
	{"FBRA", 4, 46453},
	{"ELEM", 4, 46454},
	{"VITALITY", 8, 46455},
	{"CLERKS", 6, 46456},
	{"VEFU", 4, 46457},
	{"CRUST", 5, 46458},
	{"BOTHERED", 8, 46459},
	{"MSBE", 4, 46460},
	{"DEMN", 4, 46461},
	{"TRAVERSE", 8, 46462},
	{"DGEC", 4, 46463},
	{"VENGEANCE", 9, 46464},
	{"ODOL", 4, 46465},
	{"ORGANISERS", 10, 46466},
	{"DOLLY", 5, 46467},
	{"PISSED", 6, 46468},
	{"UCRA", 4, 46469},
	{"GARRISON", 8, 46470},
	{"BARB", 4, 46471},
	{"KENW", 4, 46472},
	{"MCKENZIE", 8, 46473},
	{"LENOX", 5, 46474},
	{"MINER", 5, 46475},
	{"USLA", 4, 46476},
	{"OURU", 4, 46477},
	{"FASHIONS", 8, 46478},
	{"DARUSSALAM", 10, 46479},
	{"GENITAL", 7, 46480},
	{"LLKI", 4, 46481},
	{"SICW", 4, 46482},
	{"MCSE", 4, 46483},
	{"ARKM", 4, 46484},
	{"BARR", 4, 46485},
	{"VEIM", 4, 46486},
	{"KEBA", 4, 46487},
	{"ANALOGY", 7, 46488},
	{"INSOMNIA", 8, 46489},
	{"CONSTITUENT", 11, 46490},
	{"LYSL", 4, 46491},
	{"FGRO", 4, 46492},
	{"AURA", 4, 46493},
	{"PWIL", 4, 46494},
	{"CECIL", 5, 46495},
	{"SPONGE", 6, 46496},
	{"CAJUN", 5, 46497},
	{"HREL", 4, 46498},
	{"RCHM", 4, 46499},
	{"ALGEBRAIC", 9, 46500},
	{"DINER", 5, 46501},
	{"FTRU", 4, 46502},
	{"ANTICIPATION", 12, 46503},
	{"ATBY", 4, 46504},
	{"ENDURING", 8, 46505},
	{"SCARBOROUGH", 11, 46506},
	{"KRISTEN", 7, 46507},
	{"REGIS", 5, 46508},
	{"WINTERS", 7, 46509},
	{"LESG", 4, 46510},
	{"EXPLOSIVES", 10, 46511},
	{"MOUND", 5, 46512},
	{"BACKGAMMON", 10, 46513},
	{"CQUE", 4, 46514},
	{"WSAR", 4, 46515},
	{"CHROMATOGRAPHY", 14, 46516},
	{"OVERDOSE", 8, 46517},
	{"OORP", 4, 46518},
	{"OTPL", 4, 46519},
	{"YFLO", 4, 46520},
	{"ABYS", 4, 46521},
	{"GALLAGHER", 9, 46522},
	{"BEWA", 4, 46523},
	{"ODEW", 4, 46524},
	{"ACHJ", 4, 46525},
	{"BIGF", 4, 46526},
	{"UMTO", 4, 46527},
	{"GLOC", 4, 46528},
	{"EALD", 4, 46529},
	{"MUELLER", 7, 46530},
	{"GUPO", 4, 46531},
	{"MOLE", 4, 46532},
	{"OWED", 4, 46533},
	{"WOCH", 4, 46534},
	{"LADYBOYS", 8, 46535},
	{"RMFO", 4, 46536},
	{"HOCC", 4, 46537},
	{"ADPA", 4, 46538},
	{"YFEW", 4, 46539},
	{"GACR", 4, 46540},
	{"PLANTRONICS", 11, 46541},
	{"KISSED", 6, 46542},
	{"JOYI", 4, 46543},
	{"ORKN", 4, 46544},
	{"BUFF", 4, 46545},
	{"ADPL", 4, 46546},
	{"FREEZERS", 8, 46547},
	{"BUTCHER", 7, 46548},
	{"PSALMS", 6, 46549},
	{"RNMA", 4, 46550},
	{"RUM", 3, 46551},
	{"TTYG", 4, 46552},
	{"YSWO", 4, 46553},
	{"IBIZA", 5, 46554},
	{"REESE", 5, 46555},
	{"CHEFS", 5, 46556},
	{"RSOP", 4, 46557},
	{"DPOO", 4, 46558},
	{"GOFR", 4, 46559},
	{"ENGRAVING", 9, 46560},
	{"DIGIMON", 7, 46561},
	{"CONSTITUTED", 11, 46562},
	{"GASTROINTESTINAL", 16, 46563},
	{"EYSC", 4, 46564},
	{"HAMLET", 6, 46565},
	{"INSPIRON", 8, 46566},
	{"ARKF", 4, 46567},
	{"LBRA", 4, 46568},
	{"PAGERANK", 8, 46569},
	{"PLUN", 4, 46570},
	{"OKAL", 4, 46571},
	{"AGLO", 4, 46572},
	{"YSUS", 4, 46573},
	{"CONTRIB", 7, 46574},
	{"UJUS", 4, 46575},
	{"OULT", 4, 46576},
	{"GYTO", 4, 46577},
	{"CLAD", 4, 46578},
	{"EXCURSION", 9, 46579},
	{"BLU", 3, 46580},
	{"MATLAB", 6, 46581},
	{"INVERNESS", 9, 46582},
	{"GRANGE", 6, 46583},
	{"NETWARE", 7, 46584},
	{"HEYJ", 4, 46585},
	{"LGOR", 4, 46586},
	{"BEPO", 4, 46587},
	{"MEGAPIXELS", 10, 46588},
	{"DSUG", 4, 46589},
	{"RESIGNED", 8, 46590},
	{"RETRIEVER", 9, 46591},
	{"FLED", 4, 46592},
	{"SVALBARD", 8, 46593},
	{"ENRICHED", 8, 46594},
	{"HARRINGTON", 10, 46595},
	{"BRANDY", 6, 46596},
	{"SWINGS", 6, 46597},
	{"PIXAR", 5, 46598},
	{"SCION", 5, 46599},
	{"ELLE", 4, 46600},
	{"REPTILES", 8, 46601},
	{"DHTML", 5, 46602},
	{"VORTEX", 6, 46603},
	{"SWALLOWING", 10, 46604},
	{"WINME", 5, 46605},
	{"PURSES", 6, 46606},
	{"GBYT", 4, 46607},
	{"BODILY", 6, 46608},
	{"DPAL", 4, 46609},
	{"LYER", 4, 46610},
	{"FUNC", 4, 46611},
	{"LYWR", 4, 46612},
	{"LBOR", 4, 46613},
	{"HUTD", 4, 46614},
	{"WPEO", 4, 46615},
	{"OLBU", 4, 46616},
	{"GAMESPY", 7, 46617},
	{"YTOK", 4, 46618},
	{"YFAL", 4, 46619},
	{"PYTO", 4, 46620},
	{"BEAUMONT", 8, 46621},
	{"STANDALONE", 10, 46622},
	{"AUSTRALASIA", 11, 46623},
	{"PENW", 4, 46624},
	{"MANDY", 5, 46625},
	{"HOODS", 5, 46626},
	{"ANTITRUST", 9, 46627},
	{"EQUINE", 6, 46628},
	{"BROS", 4, 46629},
	{"FIREPLACES", 10, 46630},
	{"PROTO", 5, 46631},
	{"JARED", 5, 46632},
	{"FBAS", 4, 46633},
	{"REQUISITE", 9, 46634},
	{"RETROSPECTIVE", 13, 46635},
	{"BYNA", 4, 46636},
	{"EFRU", 4, 46637},
	{"EMPHASIZES", 10, 46638},
	{"LIZARD", 6, 46639},
	{"HAWTHORNE", 9, 46640},
	{"TEHRAN", 6, 46641},
	{"RYVE", 4, 46642},
	{"RLSA", 4, 46643},
	{"BOUQUETS", 8, 46644},
	{"LBOO", 4, 46645},
	{"IDAF", 4, 46646},
	{"FLAR", 4, 46647},
	{"WEARS", 5, 46648},
	{"ANESTHESIA", 10, 46649},
	{"SHROPSHIRE", 10, 46650},
	{"BAJA", 4, 46651},
	{"FILEMAKER", 9, 46652},
	{"REGAL", 5, 46653},
	{"OYFR", 4, 46654},
	{"YDOI", 4, 46655},
	{"LBLO", 4, 46656},
	{"SAFEGUARDS", 10, 46657},
	{"CABBAGE", 7, 46658},
	{"CUB", 3, 46659},
	{"LIBTOOL", 7, 46660},
	{"WRONGFUL", 8, 46661},
	{"SPECTATOR", 9, 46662},
	{"ARRESTS", 7, 46663},
	{"SIGNAGE", 7, 46664},
	{"LLBL", 4, 46665},
	{"LCLU", 4, 46666},
	{"NUMBERING", 9, 46667},
	{"RTDI", 4, 46668},
	{"ENCODE", 6, 46669},
	{"ADMINS", 6, 46670},
	{"ODBU", 4, 46671},
	{"MALP", 4, 46672},
	{"ALVIN", 5, 46673},
	{"ORNB", 4, 46674},
	{"URSC", 4, 46675},
	{"KITW", 4, 46676},
	{"EWWH", 4, 46677},
	{"ACCOLADES", 9, 46678},
	{"YNUM", 4, 46679},
	{"RATON", 5, 46680},
	{"SLICED", 6, 46681},
	{"EYJU", 4, 46682},
	{"REPRODUCTIONS", 13, 46683},
	{"STEFANI", 7, 46684},
	{"INFERTILITY", 11, 46685},
	{"BYRD", 4, 46686},
	{"TLOV", 4, 46687},
	{"RWEB", 4, 46688},
	{"PROB", 4, 46689},
	{"BREAKER", 7, 46690},
	{"IDSU", 4, 46691},
	{"CURLY", 5, 46692},
	{"BIGU", 4, 46693},
	{"SERVLET", 7, 46694},
	{"ALBERTO", 7, 46695},
	{"COLLAGE", 7, 46696},
	{"ASSERTED", 8, 46697},
	{"LPOP", 4, 46698},
	{"TADM", 4, 46699},
	{"DEPECHE", 7, 46700},
	{"KEAF", 4, 46701},
	{"BENCHMARKING", 12, 46702},
	{"MAYP", 4, 46703},
	{"JEALOUS", 7, 46704},
	{"REFINEMENT", 10, 46705},
	{"REUR", 4, 46706},
	{"FIXT", 4, 46707},
	{"DURBAN", 6, 46708},
	{"LEARNT", 6, 46709},
	{"XXL", 3, 46710},
	{"HOUND", 5, 46711},
	{"SQUIRREL", 8, 46712},
	{"TELEFLORA", 9, 46713},
	{"CONCEALED", 9, 46714},
	{"URFE", 4, 46715},
	{"BANKRUPTCIES", 12, 46716},
	{"GAUGES", 6, 46717},
	{"BLUEPRINT", 9, 46718},
	{"RBYS", 4, 46719},
	{"MCCAIN", 6, 46720},
	{"AILF", 4, 46721},
	{"KEDR", 4, 46722},
	{"SPIDERMAN", 9, 46723},
	{"BRIDGING", 8, 46724},
	{"SFLE", 4, 46725},
	{"WHARF", 5, 46726},
	{"RHYTHMS", 7, 46727},
	{"DEPARTURES", 10, 46728},
	{"FLICK", 5, 46729},
	{"DATUM", 5, 46730},
	{"OFSL", 4, 46731},
	{"EGGI", 4, 46732},
	{"TGAV", 4, 46733},
	{"GOFM", 4, 46734},
	{"SHOTGUN", 7, 46735},
	{"STIMULATED", 10, 46736},
	{"CHICKENS", 8, 46737},
	{"UVEG", 4, 46738},
	{"HIMU", 4, 46739},
	{"RDOG", 4, 46740},
	{"CANCELED", 8, 46741},
	{"LANGLEY", 7, 46742},
	{"BRIGGS", 6, 46743},
	{"CHEYENNE", 8, 46744},
	{"EMPOWERING", 10, 46745},
	{"LFLO", 4, 46746},
	{"SRUP", 4, 46747},
	{"BEGR", 4, 46748},
	{"LUG", 3, 46749},
	{"YMCA", 4, 46750},
	{"CEEV", 4, 46751},
	{"UDEC", 4, 46752},
	{"SURVEYOR", 8, 46753},
	{"FACILITATOR", 11, 46754},
	{"ELDM", 4, 46755},
	{"MACWORLD", 8, 46756},
	{"WWF", 3, 46757},
	{"MAIZE", 5, 46758},
	{"GALVESTON", 9, 46759},
	{"EXTINCTION", 10, 46760},
	{"RGIR", 4, 46761},
	{"UNAWARE", 7, 46762},
	{"ROCKVILLE", 9, 46763},
	{"TMOU", 4, 46764},
	{"BANFF", 5, 46765},
	{"DISCRETIONARY", 13, 46766},
	{"ICFR", 4, 46767},
	{"FMOS", 4, 46768},
	{"PSALM", 5, 46769},
	{"IGLE", 4, 46770},
	{"SERV", 4, 46771},
	{"BLYM", 4, 46772},
	{"LROL", 4, 46773},
	{"LDCL", 4, 46774},
	{"BEBR", 4, 46775},
	{"MYSO", 4, 46776},
	{"SCENTED", 7, 46777},
	{"WAYD", 4, 46778},
	{"GDEC", 4, 46779},
	{"TIMESTAMP", 9, 46780},
	{"MUSICA", 6, 46781},
	{"GOWNS", 5, 46782},
	{"PPIE", 4, 46783},
	{"KSMA", 4, 46784},
	{"STEVIE", 6, 46785},
	{"SPYING", 6, 46786},
	{"NICHOLSON", 9, 46787},
	{"NBEM", 4, 46788},
	{"RIVERA", 6, 46789},
	{"DERMATOLOGY", 11, 46790},
	{"LIED", 4, 46791},
	{"WOOR", 4, 46792},
	{"SANDBOX", 7, 46793},
	{"YIFT", 4, 46794},
	{"YBED", 4, 46795},
	{"BLOC", 4, 46796},
	{"PINKWORLD", 9, 46797},
	{"CAMBRIDGESHIRE", 14, 46798},
	{"VEBI", 4, 46799},
	{"GHWH", 4, 46800},
	{"BYAG", 4, 46801},
	{"PREMIERSHIP", 11, 46802},
	{"LUTON", 5, 46803},
	{"RECURRENT", 9, 46804},
	{"TALBOT", 6, 46805},
	{"CONFTEST", 8, 46806},
	{"OBIG", 4, 46807},
	{"LEAKS", 5, 46808},
	{"RECURSIVE", 9, 46809},
	{"VILLE", 5, 46810},
	{"YWM", 3, 46811},
	{"SHBU", 4, 46812},
	{"REGISTERREGISTER", 16, 46813},
	{"DSAW", 4, 46814},
	{"ABAY", 4, 46815},
	{"FLUORESCENCE", 12, 46816},
	{"KOSHER", 6, 46817},
	{"MANTLE", 6, 46818},
	{"ADDITIVES", 9, 46819},
	{"CHICO", 5, 46820},
	{"TBYS", 4, 46821},
	{"YSOC", 4, 46822},
	{"OLWI", 4, 46823},
	{"FAPO", 4, 46824},
	{"FAIRBANKS", 9, 46825},
	{"PARFUM", 6, 46826},
	{"EDSY", 4, 46827},
	{"MARKETED", 8, 46828},
	{"ARMIES", 6, 46829},
	{"RCEB", 4, 46830},
	{"LIUS", 4, 46831},
	{"GANP", 4, 46832},
	{"DISF", 4, 46833},
	{"HUGS", 4, 46834},
	{"JUQ", 3, 46835},
	{"LOFR", 4, 46836},
	{"KLED", 4, 46837},
	{"GREENFIELD", 10, 46838},
	{"SANTOS", 6, 46839},
	{"AFUR", 4, 46840},
	{"LFOL", 4, 46841},
	{"OWLS", 4, 46842},
	{"MANDRAKE", 8, 46843},
	{"CUTTERS", 7, 46844},
	{"GYIS", 4, 46845},
	{"OMEX", 4, 46846},
	{"CTSP", 4, 46847},
	{"CAMPER", 6, 46848},
	{"MHIG", 4, 46849},
	{"GEDC", 4, 46850},
	{"ELDP", 4, 46851},
	{"ACQUIRES", 8, 46852},
	{"CPR", 3, 46853},
	{"CEASED", 6, 46854},
	{"EUPC", 4, 46855},
	{"DBOY", 4, 46856},
	{"MERGING", 7, 46857},
	{"PLAQUES", 7, 46858},
	{"BREADTH", 7, 46859},
	{"GSOL", 4, 46860},
	{"MAMMOTH", 7, 46861},
	{"LIQUIDITY", 9, 46862},
	{"UTRO", 4, 46863},
	{"OLEB", 4, 46864},
	{"UYSA", 4, 46865},
	{"CONVICTIONS", 11, 46866},
	{"ULDK", 4, 46867},
	{"LASIK", 5, 46868},
	{"INTENTIONAL", 11, 46869},
	{"GALACTIC", 8, 46870},
	{"SOPHIA", 6, 46871},
	{"MERCHANDISING", 13, 46872},
	{"ALSK", 4, 46873},
	{"YBIG", 4, 46874},
	{"PROHIBITS", 9, 46875},
	{"NALJ", 4, 46876},
	{"OMBUDSMAN", 9, 46877},
	{"INNINGS", 7, 46878},
	{"RDSD", 4, 46879},
	{"REGISTRANT", 10, 46880},
	{"HGOV", 4, 46881},
	{"REORGANIZATION", 14, 46882},
	{"PRONUNCIATION", 13, 46883},
	{"ORFL", 4, 46884},
	{"FIREFIGHTERS", 12, 46885},
	{"XILE", 4, 46886},
	{"SELD", 4, 46887},
	{"PLACEMENTS", 10, 46888},
	{"CONCESSION", 10, 46889},
	{"ERLU", 4, 46890},
	{"MEASURABLE", 10, 46891},
	{"ELEC", 4, 46892},
	{"NYMI", 4, 46893},
	{"PARCELS", 7, 46894},
	{"PASTRY", 6, 46895},
	{"AYUP", 4, 46896},
	{"CCOL", 4, 46897},
	{"MANNERS", 7, 46898},
	{"LEVIN", 5, 46899},
	{"ACADEMIA", 8, 46900},
	{"DISU", 4, 46901},
	{"EWPE", 4, 46902},
	{"AMIGA", 5, 46903},
	{"PHOSPHORUS", 10, 46904},
	{"VIPER", 5, 46905},
	{"DESCRIPTOR", 10, 46906},
	{"VOLCANIC", 8, 46907},
	{"GYPSY", 5, 46908},
	{"THIEVES", 7, 46909},
	{"USTK", 4, 46910},
	{"LEJU", 4, 46911},
	{"PREACHING", 9, 46912},
	{"PIMP", 4, 46913},
	{"REPEAL", 6, 46914},
	{"OUTJ", 4, 46915},
	{"EMPR", 4, 46916},
	{"GIMP", 4, 46917},
	{"EWWO", 4, 46918},
	{"UNCOVERED", 9, 46919},
	{"HEMP", 4, 46920},
	{"STJU", 4, 46921},
	{"EILEEN", 6, 46922},
	{"GJOB", 4, 46923},
	{"KUPA", 4, 46924},
	{"DBOR", 4, 46925},
	{"NYLO", 4, 46926},
	{"PROFICIENT", 10, 46927},
	{"GEDR", 4, 46928},
	{"RAFR", 4, 46929},
	{"PELICAN", 7, 46930},
	{"CYCLIC", 6, 46931},
	{"SWIMSUIT", 8, 46932},
	{"LUBW", 4, 46933},
	{"APOCALYPSE", 10, 46934},
	{"MORPHOLOGY", 10, 46935},
	{"RESK", 4, 46936},
	{"TUPW", 4, 46937},
	{"DENF", 4, 46938},
	{"VERSACE", 7, 46939},
	{"PRINTPRINTER", 12, 46940},
	{"COUSINS", 7, 46941},
	{"RLOR", 4, 46942},
	{"DISCHARGES", 10, 46943},
	{"CYLI", 4, 46944},
	{"GIORGIO", 7, 46945},
	{"MBAL", 4, 46946},
	{"CONDOM", 6, 46947},
	{"WESTERNS", 8, 46948},
	{"OPYO", 4, 46949},
	{"FAGA", 4, 46950},
	{"DODGERS", 7, 46951},
	{"SGAV", 4, 46952},
	{"KOFH", 4, 46953},
	{"LITRE", 5, 46954},
	{"POURED", 6, 46955},
	{"DAWH", 4, 46956},
	{"USEFULNESS", 10, 46957},
	{"UNSOLICITED", 11, 46958},
	{"ITYU", 4, 46959},
	{"OILP", 4, 46960},
	{"LFON", 4, 46961},
	{"AVYW", 4, 46962},
	{"LDDA", 4, 46963},
	{"BINDS", 5, 46964},
	{"UNMA", 4, 46965},
	{"UNVEILED", 8, 46966},
	{"DMUL", 4, 46967},
	{"ANBY", 4, 46968},
	{"CORRELATIONS", 12, 46969},
	{"BURT", 4, 46970},
	{"TITUS", 5, 46971},
	{"TEXTUAL", 7, 46972},
	{"SUFFIX", 6, 46973},
	{"AVEK", 4, 46974},
	{"HANDSETS", 8, 46975},
	{"INSTALLMENT", 11, 46976},
	{"EWHY", 4, 46977},
	{"DLYD", 4, 46978},
	{"GANDHI", 6, 46979},
	{"SPINDLE", 7, 46980},
	{"LTWO", 4, 46981},
	{"HEAVENS", 7, 46982},
	{"GQUA", 4, 46983},
	{"OUPH", 4, 46984},
	{"OGOB", 4, 46985},
	{"WINK", 4, 46986},
	{"LICF", 4, 46987},
	{"DIARRHEA", 8, 46988},
	{"SEAHAWKS", 8, 46989},
	{"MISTER", 6, 46990},
	{"ROUNDING", 8, 46991},
	{"DGEH", 4, 46992},
	{"TRYD", 4, 46993},
	{"INORGANIC", 9, 46994},
	{"DNOV", 4, 46995},
	{"FLARE", 5, 46996},
	{"SCHOLASTIC", 10, 46997},
	{"WIGHT", 5, 46998},
	{"WAYL", 4, 46999},
	{"MONDAYS", 7, 47000},
	{"IBBE", 4, 47001},
	{"EUMA", 4, 47002},
	{"WITHHOLDING", 11, 47003},
	{"NSUG", 4, 47004},
	{"BIGM", 4, 47005},
	{"XMY", 3, 47006},
	{"INSERTIONS", 10, 47007},
	{"AYDI", 4, 47008},
	{"COUTURE", 7, 47009},
	{"CBUT", 4, 47010},
	{"FOLIAGE", 7, 47011},
	{"RFUR", 4, 47012},
	{"YOFU", 4, 47013},
	{"SPUL", 4, 47014},
	{"ATIVAN", 6, 47015},
	{"DARG", 4, 47016},
	{"DERJ", 4, 47017},
	{"FIFE", 4, 47018},
	{"GENERALS", 8, 47019},
	{"RSGA", 4, 47020},
	{"PENL", 4, 47021},
	{"KEAW", 4, 47022},
	{"RDHO", 4, 47023},
	{"CRANK", 5, 47024},
	{"WOPA", 4, 47025},
	{"GOATS", 5, 47026},
	{"AUTOGRAPHS", 10, 47027},
	{"SUMMARIZE", 9, 47028},
	{"STUB", 4, 47029},
	{"DYWI", 4, 47030},
	{"TYAC", 4, 47031},
	{"OMRA", 4, 47032},
	{"FUNDAMENTALLY", 13, 47033},
	{"ILMM", 4, 47034},
	{"CREAMY", 6, 47035},
	{"EXPOSITION", 10, 47036},
	{"GEQU", 4, 47037},
	{"SAVESAVE", 8, 47038},
	{"RAINS", 5, 47039},
	{"BUCKLEY", 7, 47040},
	{"MIDDLETON", 9, 47041},
	{"LAMINATED", 9, 47042},
	{"ORGANISE", 8, 47043},
	{"CITRIX", 6, 47044},
	{"BRACE", 5, 47045},
	{"NRUL", 4, 47046},
	{"OEMP", 4, 47047},
	{"ODEB", 4, 47048},
	{"BACKUPS", 7, 47049},
	{"HIPG", 4, 47050},
	{"NOVELTIES", 9, 47051},
	{"TURISMO", 7, 47052},
	{"GIGANTIC", 8, 47053},
	{"LARV", 4, 47054},
	{"LZR", 3, 47055},
	{"ABDUL", 5, 47056},
	{"ILTB", 4, 47057},
	{"SHELDON", 7, 47058},
	{"RYDER", 5, 47059},
	{"OWPE", 4, 47060},
	{"MAYHEM", 6, 47061},
	{"WASHERS", 7, 47062},
	{"GREP", 4, 47063},
	{"POLYMERASE", 10, 47064},
	{"OPTIMISATION", 12, 47065},
	{"OCTAVE", 6, 47066},
	{"STRUTS", 6, 47067},
	{"RTYM", 4, 47068},
	{"EASYSHARE", 9, 47069},
	{"CVSROOT", 7, 47070},
	{"ASMY", 4, 47071},
	{"MYPA", 4, 47072},
	{"HLEY", 4, 47073},
	{"SUPPRESS", 8, 47074},
	{"HARDING", 7, 47075},
	{"OKUP", 4, 47076},
	{"DAMS", 4, 47077},
	{"VIOLATES", 8, 47078},
	{"JOPLIN", 6, 47079},
	{"DOFN", 4, 47080},
	{"WONB", 4, 47081},
	{"DIALUP", 6, 47082},
	{"RUTHERFORD", 10, 47083},
	{"AFRO", 4, 47084},
	{"SEPARATES", 9, 47085},
	{"PROOFS", 6, 47086},
	{"PRECEDENT", 9, 47087},
	{"BIOSYNTHESIS", 12, 47088},
	{"PROSECUTORS", 11, 47089},
	{"LTYP", 4, 47090},
	{"CONFIRMING", 10, 47091},
	{"GARTH", 5, 47092},
	{"NCIV", 4, 47093},
	{"NOLAN", 5, 47094},
	{"ILMW", 4, 47095},
	{"ALLOYS", 6, 47096},
	{"GEDD", 4, 47097},
	{"BKU", 3, 47098},
	{"FBAN", 4, 47099},
	{"NSBR", 4, 47100},
	{"MACH", 4, 47101},
	{"OUPC", 4, 47102},
	{"GETAWAYS", 8, 47103},
	{"ODBE", 4, 47104},
	{"FACILITATED", 11, 47105},
	{"MIQUELON", 8, 47106},
	{"PAOLO", 5, 47107},
	{"BRIDGET", 7, 47108},
	{"WONDERLAND", 10, 47109},
	{"INFUSION", 8, 47110},
	{"JESSIE", 6, 47111},
	{"RGEH", 4, 47112},
	{"ORGANISING", 10, 47113},
	{"MSBU", 4, 47114},
	{"FVER", 4, 47115},
	{"DLOR", 4, 47116},
	{"TRUMAN", 6, 47117},
	{"ARGUS", 5, 47118},
	{"WUPI", 4, 47119},
	{"LDPU", 4, 47120},
	{"MANGO", 5, 47121},
	{"TOPW", 4, 47122},
	{"SPUR", 4, 47123},
	{"JUBILEE", 7, 47124},
	{"WUX", 3, 47125},
	{"RZD", 3, 47126},
	{"TUPS", 4, 47127},
	{"SMUL", 4, 47128},
	{"LANDMARKS", 9, 47129},
	{"VERJ", 4, 47130},
	{"POLITE", 6, 47131},
	{"OILL", 4, 47132},
	{"RDBO", 4, 47133},
	{"FHEL", 4, 47134},
	{"AMWE", 4, 47135},
	{"ASYNCHRONOUS", 12, 47136},
	{"PAVING", 6, 47137},
	{"CYCLONE", 7, 47138},
	{"PERENNIAL", 9, 47139},
	{"CARLA", 5, 47140},
	{"JACQUELINE", 10, 47141},
	{"LLID", 4, 47142},
	{"RSEF", 4, 47143},
	{"OPFO", 4, 47144},
	{"BYTW", 4, 47145},
	{"MESSAGESLOG", 11, 47146},
	{"GSPR", 4, 47147},
	{"MEATS", 5, 47148},
	{"CLEARINGHOUSE", 13, 47149},
	{"GOFP", 4, 47150},
	{"NMIG", 4, 47151},
	{"LSMO", 4, 47152},
	{"IVAC", 4, 47153},
	{"RMWA", 4, 47154},
	{"YDAV", 4, 47155},
	{"BULLDOG", 7, 47156},
	{"NBIG", 4, 47157},
	{"YMIC", 4, 47158},
	{"CHFE", 4, 47159},
	{"CLEAVAGE", 8, 47160},
	{"ANALYSED", 8, 47161},
	{"GRADUAL", 7, 47162},
	{"WNMA", 4, 47163},
	{"LHAL", 4, 47164},
	{"ERNL", 4, 47165},
	{"BRETHREN", 8, 47166},
	{"FACILITATES", 11, 47167},
	{"EMBODIMENT", 10, 47168},
	{"SPECIALISED", 11, 47169},
	{"RAMONES", 7, 47170},
	{"EVERQUEST", 9, 47171},
	{"VIOLATING", 9, 47172},
	{"YBOY", 4, 47173},
	{"RRYC", 4, 47174},
	{"RECRUITED", 9, 47175},
	{"BERNSTEIN", 9, 47176},
	{"CALC", 4, 47177},
	{"MARKETERS", 9, 47178},
	{"TOILETTE", 8, 47179},
	{"TRAILING", 8, 47180},
	{"MISU", 4, 47181},
	{"EEDR", 4, 47182},
	{"PACT", 4, 47183},
	{"BBYI", 4, 47184},
	{"FTEC", 4, 47185},
	{"EWLE", 4, 47186},
	{"LIPSTICK", 8, 47187},
	{"HONOURABLE", 10, 47188},
	{"LESY", 4, 47189},
	{"ENWR", 4, 47190},
	{"LULU", 4, 47191},
	{"WINDY", 5, 47192},
	{"BRENNAN", 7, 47193},
	{"ELUS", 4, 47194},
	{"KPX", 3, 47195},
	{"PUNISHED", 8, 47196},
	{"SATURATION", 10, 47197},
	{"STAMFORD", 8, 47198},
	{"ALAMO", 5, 47199},
	{"RJAM", 4, 47200},
	{"ZILI", 4, 47201},
	{"CHRONOLOGY", 10, 47202},
	{"FFSO", 4, 47203},
	{"RAWF", 4, 47204},
	{"MASTERY", 7, 47205},
	{"AGOF", 4, 47206},
	{"UERI", 4, 47207},
	{"ALIL", 4, 47208},
	{"THERMOMETER", 11, 47209},
	{"RLED", 4, 47210},
	{"IGHF", 4, 47211},
	{"YDAM", 4, 47212},
	{"CRANBERRY", 9, 47213},
	{"DOWNHILL", 8, 47214},
	{"COMCAST", 7, 47215},
	{"RPED", 4, 47216},
	{"HYDERABAD", 9, 47217},
	{"NSDU", 4, 47218},
	{"NESTING", 7, 47219},
	{"VOGUE", 5, 47220},
	{"RNAC", 4, 47221},
	{"AIRED", 5, 47222},
	{"POFS", 4, 47223},
	{"SPAGHETTI", 9, 47224},
	{"HIPR", 4, 47225},
	{"OUTWARD", 7, 47226},
	{"OLEV", 4, 47227},
	{"IPSWICH", 7, 47228},
	{"PMON", 4, 47229},
	{"UFFL", 4, 47230},
	{"BOOGIE", 6, 47231},
	{"DESL", 4, 47232},
	{"YZY", 3, 47233},
	{"WKV", 3, 47234},
	{"ABRAMOFF", 8, 47235},
	{"COMPROMISED", 11, 47236},
	{"UTILIZES", 8, 47237},
	{"LLYV", 4, 47238},
	{"DEPRIVED", 8, 47239},
	{"BENEDICT", 8, 47240},
	{"VODKA", 5, 47241},
	{"ESFL", 4, 47242},
	{"DDOM", 4, 47243},
	{"IMEG", 4, 47244},
	{"MOLDING", 7, 47245},
	{"ZAIRE", 5, 47246},
	{"NMUC", 4, 47247},
	{"GBLO", 4, 47248},
	{"CZEC", 4, 47249},
	{"RZF", 3, 47250},
	{"FASTENERS", 9, 47251},
	{"OFSW", 4, 47252},
	{"DZON", 4, 47253},
	{"BRICKS", 6, 47254},
	{"GSRE", 4, 47255},
	{"COMMUNISM", 9, 47256},
	{"LEOPARD", 7, 47257},
	{"UESC", 4, 47258},
	{"JOYT", 4, 47259},
	{"DBYV", 4, 47260},
	{"URYC", 4, 47261},
	{"SAKAI", 5, 47262},
	{"DDOI", 4, 47263},
	{"FLOWERING", 9, 47264},
	{"JINGLE", 6, 47265},
	{"BOUNTY", 6, 47266},
	{"ARCADIA", 7, 47267},
	{"GOSP", 4, 47268},
	{"FISHES", 6, 47269},
	{"KTOC", 4, 47270},
	{"RINGING", 7, 47271},
	{"DTEX", 4, 47272},
	{"ANYV", 4, 47273},
	{"KNOBS", 5, 47274},
	{"MEKN", 4, 47275},
	{"BYBU", 4, 47276},
	{"TAURUS", 6, 47277},
	{"RAJASTHAN", 9, 47278},
	{"YFAT", 4, 47279},
	{"RSVI", 4, 47280},
	{"DTAX", 4, 47281},
	{"DLUC", 4, 47282},
	{"BATM", 4, 47283},
	{"WHISKEY", 7, 47284},
	{"LPOF", 4, 47285},
	{"ABSURD", 6, 47286},
	{"YSIX", 4, 47287},
	{"COMMITTING", 10, 47288},
	{"UTHK", 4, 47289},
	{"EWAV", 4, 47290},
	{"AVEV", 4, 47291},
	{"RSRO", 4, 47292},
	{"DLEW", 4, 47293},
	{"NGOD", 4, 47294},
	{"TOLERANT", 8, 47295},
	{"NKSF", 4, 47296},
	{"AGUY", 4, 47297},
	{"GOFI", 4, 47298},
	{"ERGL", 4, 47299},
	{"STOVES", 6, 47300},
	{"OKCO", 4, 47301},
	{"INLOG", 5, 47302},
	{"RPIN", 4, 47303},
	{"OLYE", 4, 47304},
	{"JORR", 4, 47305},
	{"ENACTMENT", 9, 47306},
	{"LAMINATE", 8, 47307},
	{"FMAS", 4, 47308},
	{"EARRING", 7, 47309},
	{"AGGREGATOR", 10, 47310},
	{"DATATYPE", 8, 47311},
	{"EMBRYO", 6, 47312},
	{"URWO", 4, 47313},
	{"POSTNUKE", 8, 47314},
	{"KOFM", 4, 47315},
	{"EFIX", 4, 47316},
	{"LDSM", 4, 47317},
	{"TPOU", 4, 47318},
	{"REIC", 4, 47319},
	{"SALTS", 5, 47320},
	{"TJAC", 4, 47321},
	{"MARIETTA", 8, 47322},
	{"DKEN", 4, 47323},
	{"ERGONOMIC", 9, 47324},
	{"FURIOUS", 7, 47325},
	{"DYLA", 4, 47326},
	{"ITERATION", 9, 47327},
	{"TEPU", 4, 47328},
	{"FJF", 3, 47329},
	{"TMOM", 4, 47330},
	{"VIDA", 4, 47331},
	{"CEILINGS", 8, 47332},
	{"DISPENSER", 9, 47333},
	{"RESPECTING", 10, 47334},
	{"KLYN", 4, 47335},
	{"RLYY", 4, 47336},
	{"DLYB", 4, 47337},
	{"APPROVING", 9, 47338},
	{"UNSAFE", 6, 47339},
	{"REWM", 4, 47340},
	{"RHOR", 4, 47341},
	{"REFILLS", 7, 47342},
	{"YYYY", 4, 47343},
	{"SEPARATING", 10, 47344},
	{"TYBY", 4, 47345},
	{"IUMO", 4, 47346},
	{"SOUPS", 5, 47347},
	{"RESIDING", 8, 47348},
	{"SAPU", 4, 47349},
	{"UNIDENTIFIED", 12, 47350},
	{"RICHIE", 6, 47351},
	{"WOFA", 4, 47352},
	{"MARKINGS", 8, 47353},
	{"MOIST", 5, 47354},
	{"TRACTORS", 8, 47355},
	{"FSEL", 4, 47356},
	{"YXB", 3, 47357},
	{"VPV", 3, 47358},
	{"TRINA", 5, 47359},
	{"ADLA", 4, 47360},
	{"DRAINED", 7, 47361},
	{"EALG", 4, 47362},
	{"COED", 4, 47363},
	{"EMLI", 4, 47364},
	{"AUDIOBOOKS", 10, 47365},
	{"UNAR", 4, 47366},
	{"MULE", 4, 47367},
	{"SHEIKH", 6, 47368},
	{"EDIL", 4, 47369},
	{"NGEP", 4, 47370},
	{"ACUA", 4, 47371},
	{"HERNANDEZ", 9, 47372},
	{"KIWI", 4, 47373},
	{"CESSATION", 9, 47374},
	{"TRUSTE", 6, 47375},
	{"MCOL", 4, 47376},
	{"APPEND", 6, 47377},
	{"PESTS", 5, 47378},
	{"LEPU", 4, 47379},
	{"WDER", 4, 47380},
	{"ACREAGE", 7, 47381},
	{"SEASONED", 8, 47382},
	{"SUNFLOWER", 9, 47383},
	{"DUEL", 4, 47384},
	{"MFC", 3, 47385},
	{"FINGERPRINT", 11, 47386},
	{"OMYS", 4, 47387},
	{"BERNARDINO", 10, 47388},
	{"STOCKED", 7, 47389},
	{"SBYC", 4, 47390},
	{"HDEF", 4, 47391},
	{"SORORITY", 8, 47392},
	{"CIAR", 4, 47393},
	{"FLUI", 4, 47394},
	{"BETHEL", 6, 47395},
	{"OFTB", 4, 47396},
	{"ENTRE", 5, 47397},
	{"AUDITION", 8, 47398},
	{"TDOY", 4, 47399},
	{"PLANO", 5, 47400},
	{"YDIE", 4, 47401},
	{"SUNDERLAND", 10, 47402},
	{"VETW", 4, 47403},
	{"DORIS", 5, 47404},
	{"EBIB", 4, 47405},
	{"MOTIVES", 7, 47406},
	{"REINFORCEMENT", 13, 47407},
	{"DWIGHT", 6, 47408},
	{"OLMA", 4, 47409},
	{"ROWH", 4, 47410},
	{"LORTAB", 6, 47411},
	{"LEVERAGING", 10, 47412},
	{"PSYCHOTHERAPY", 13, 47413},
	{"PROVOST", 7, 47414},
	{"RCHD", 4, 47415},
	{"GUESSING", 8, 47416},
	{"STOKES", 6, 47417},
	{"LAKERS", 6, 47418},
	{"DSQU", 4, 47419},
	{"EAUG", 4, 47420},
	{"OPOP", 4, 47421},
	{"SAXOPHONE", 9, 47422},
	{"COCKTAILS", 9, 47423},
	{"PCHA", 4, 47424},
	{"ESKM", 4, 47425},
	{"MEAD", 4, 47426},
	{"HARLEM", 6, 47427},
	{"THROTTLE", 8, 47428},
	{"YTEC", 4, 47429},
	{"STEROID", 7, 47430},
	{"GONG", 4, 47431},
	{"ILYE", 4, 47432},
	{"COMMUNICATOR", 12, 47433},
	{"HNMC", 4, 47434},
	{"HORTICULTURE", 12, 47435},
	{"RESETS", 6, 47436},
	{"UTIL", 4, 47437},
	{"YLEW", 4, 47438},
	{"EOBV", 4, 47439},
	{"EDGL", 4, 47440},
	{"EBOL", 4, 47441},
	{"SYMPATHETIC", 11, 47442},
	{"FRIDAYS", 7, 47443},
	{"ORDINATOR", 9, 47444},
	{"UNCONSCIOUS", 11, 47445},
	{"BAYS", 4, 47446},
	{"GLYT", 4, 47447},
	{"FJOH", 4, 47448},
	{"TABR", 4, 47449},
	{"NSUF", 4, 47450},
	{"ACRONYM", 7, 47451},
	{"MYOW", 4, 47452},
	{"VERITAS", 7, 47453},
	{"FAULTY", 6, 47454},
	{"AFFIDAVIT", 9, 47455},
	{"ATBL", 4, 47456},
	{"ICDO", 4, 47457},
	{"BREATHTAKING", 12, 47458},
	{"STREAMLINE", 10, 47459},
	{"CROWNE", 6, 47460},
	{"MESSIAH", 7, 47461},
	{"BRUNCH", 6, 47462},
	{"UMCO", 4, 47463},
	{"INFAMOUS", 8, 47464},
	{"PUNDIT", 6, 47465},
	{"PLEASING", 8, 47466},
	{"SEIZURES", 8, 47467},
	{"APPEALED", 8, 47468},
	{"FIGURINE", 8, 47469},
	{"SURVEYORS", 9, 47470},
	{"MUTANTS", 7, 47471},
	{"CYBERSPACE", 10, 47472},
	{"FDEV", 4, 47473},
	{"TENACIOUS", 9, 47474},
	{"IMWA", 4, 47475},
	{"EXPIRY", 6, 47476},
	{"LYNC", 4, 47477},
	{"EXIF", 4, 47478},
	{"WATERFALL", 9, 47479},
	{"SENSUAL", 7, 47480},
	{"PERSECUTION", 11, 47481},
	{"RCAU", 4, 47482},
	{"GOLDMAN", 7, 47483},
	{"UTIW", 4, 47484},
	{"PETIT", 5, 47485},
	{"BURGESS", 7, 47486},
	{"EDOB", 4, 47487},
	{"UIDI", 4, 47488},
	{"EGEF", 4, 47489},
	{"ISMY", 4, 47490},
	{"INNING", 6, 47491},
	{"HFRI", 4, 47492},
	{"FRIES", 5, 47493},
	{"FXW", 3, 47494},
	{"DXY", 3, 47495},
	{"CHLORINE", 8, 47496},
	{"FRESHLY", 7, 47497},
	{"USGR", 4, 47498},
	{"INITIALIZE", 10, 47499},
	{"GWER", 4, 47500},
	{"USSP", 4, 47501},
	{"SAXON", 5, 47502},
	{"CABO", 4, 47503},
	{"SYBASE", 6, 47504},
	{"NBUL", 4, 47505},
	{"DBEY", 4, 47506},
	{"ISABELLA", 8, 47507},
	{"FOUNDRY", 7, 47508},
	{"TOXICOLOGY", 10, 47509},
	{"MPLS", 4, 47510},
	{"MONIES", 6, 47511},
	{"BODYBUILDING", 12, 47512},
	{"LLBY", 4, 47513},
	{"GLYC", 4, 47514},
	{"ASSASSINATION", 13, 47515},
	{"SWEW", 4, 47516},
	{"GBEH", 4, 47517},
	{"NOSTALGIA", 9, 47518},
	{"OMEY", 4, 47519},
	{"PPYW", 4, 47520},
	{"REMARKABLY", 10, 47521},
	{"ACETATE", 7, 47522},
	{"CKWE", 4, 47523},
	{"DHIL", 4, 47524},
	{"POINTE", 6, 47525},
	{"LOFL", 4, 47526},
	{"STALL", 5, 47527},
	{"DEERE", 5, 47528},
	{"DAWO", 4, 47529},
	{"BMX", 3, 47530},
	{"DYSA", 4, 47531},
	{"SARATOGA", 8, 47532},
	{"ENTIRETY", 8, 47533},
	{"SWEC", 4, 47534},
	{"DESTINED", 8, 47535},
	{"IPWA", 4, 47536},
	{"MARCEL", 6, 47537},
	{"ORIU", 4, 47538},
	{"TERMINATOR", 10, 47539},
	{"TUSU", 4, 47540},
	{"HULK", 4, 47541},
	{"TPMA", 4, 47542},
	{"EMEX", 4, 47543},
	{"ELFH", 4, 47544},
	{"WITW", 4, 47545},
	{"BADMINTON", 9, 47546},
	{"IORW", 4, 47547},
	{"CYAN", 4, 47548},
	{"CORY", 4, 47549},
	{"RKSE", 4, 47550},
	{"ERIP", 4, 47551},
	{"CKCH", 4, 47552},
	{"GMEA", 4, 47553},
	{"FLORES", 6, 47554},
	{"DSAB", 4, 47555},
	{"OLIVIER", 7, 47556},
	{"GEFI", 4, 47557},
	{"RNOL", 4, 47558},
	{"PORTAGE", 7, 47559},
	{"PHOL", 4, 47560},
	{"STACEY", 6, 47561},
	{"LLSD", 4, 47562},
	{"SERIF", 5, 47563},
	{"DWELLINGS", 9, 47564},
	{"OKPA", 4, 47565},
	{"FVAR", 4, 47566},
	{"CEOV", 4, 47567},
	{"INFORMING", 9, 47568},
	{"YELLOWSTONE", 11, 47569},
	{"YPOR", 4, 47570},
	{"IZEW", 4, 47571},
	{"RINR", 4, 47572},
	{"EKOF", 4, 47573},
	{"PORTABILITY", 11, 47574},
	{"RICARDO", 7, 47575},
	{"YOURSELVES", 10, 47576},
	{"YEARBOOK", 8, 47577},
	{"LLUM", 4, 47578},
	{"ROTTERDAM", 9, 47579},
	{"LUBRICANTS", 10, 47580},
	{"LSUN", 4, 47581},
	{"SDRU", 4, 47582},
	{"NBYM", 4, 47583},
	{"GSIG", 4, 47584},
	{"ALAMEDA", 7, 47585},
	{"YAPA", 4, 47586},
	{"AEROSOL", 7, 47587},
	{"MLM", 3, 47588},
	{"EVIK", 4, 47589},
	{"CLEMSON", 7, 47590},
	{"YCRA", 4, 47591},
	{"LDUR", 4, 47592},
	{"CRACKER", 7, 47593},
	{"ANGLICAN", 8, 47594},
	{"XURY", 4, 47595},
	{"MONKS", 5, 47596},
	{"COMPLIMENT", 10, 47597},
	{"OLBE", 4, 47598},
	{"CAMINO", 6, 47599},
	{"TODU", 4, 47600},
	{"STOREY", 6, 47601},
	{"SCOTCH", 6, 47602},
	{"ONGG", 4, 47603},
	{"SERMONS", 7, 47604},
	{"RUGA", 4, 47605},
	{"KBAC", 4, 47606},
	{"PHILLY", 6, 47607},
	{"OFOB", 4, 47608},
	{"YXR", 3, 47609},
	{"REMEMBERS", 9, 47610},
	{"COOLERS", 7, 47611},
	{"MULTILATERAL", 12, 47612},
	{"FREDDIE", 7, 47613},
	{"CONTENTION", 10, 47614},
	{"COSTELLO", 8, 47615},
	{"ELPP", 4, 47616},
	{"AUDITED", 7, 47617},
	{"JULIET", 6, 47618},
	{"YQUA", 4, 47619},
	{"ADJUNCT", 7, 47620},
	{"GUERNSEY", 8, 47621},
	{"IDRO", 4, 47622},
	{"OMDA", 4, 47623},
	{"AVIR", 4, 47624},
	{"GALORE", 6, 47625},
	{"ALOHA", 5, 47626},
	{"QUU", 3, 47627},
	{"FYJ", 3, 47628},
	{"DEHYDROGENASE", 13, 47629},
	{"BANGOR", 6, 47630},
	{"UFFY", 4, 47631},
	{"FWAL", 4, 47632},
	{"PERSIA", 6, 47633},
	{"YPEN", 4, 47634},
	{"POSTFIX", 7, 47635},
	{"STIRRING", 8, 47636},
	{"ALTAVISTA", 9, 47637},
	{"ROYI", 4, 47638},
	{"NDUT", 4, 47639},
	{"EXPONENTIAL", 11, 47640},
	{"UTTER", 5, 47641},
	{"NLAB", 4, 47642},
	{"BOTTLED", 7, 47643},
	{"GYCO", 4, 47644},
	{"BEME", 4, 47645},
	{"VELC", 4, 47646},
	{"GASTRIC", 7, 47647},
	{"JVU", 3, 47648},
	{"SECRETARIAL", 11, 47649},
	{"INFLUENCING", 11, 47650},
	{"RSYO", 4, 47651},
	{"RENTS", 5, 47652},
	{"CHRISTY", 7, 47653},
	{"THEIRS", 6, 47654},
	{"URWH", 4, 47655},
	{"BEMI", 4, 47656},
	{"MATTRESSES", 10, 47657},
	{"OWAC", 4, 47658},
	{"EWSB", 4, 47659},
	{"TODAYS", 6, 47660},
	{"DONOVAN", 7, 47661},
	{"KOFP", 4, 47662},
	{"TOASTER", 7, 47663},
	{"GINJ", 4, 47664},
	{"CATER", 5, 47665},
	{"COLTS", 5, 47666},
	{"UPIL", 4, 47667},
	{"REHEARSAL", 9, 47668},
	{"STRAUSS", 7, 47669},
	{"REPUTABLE", 9, 47670},
	{"KSUP", 4, 47671},
	{"ULCO", 4, 47672},
	{"AVRE", 4, 47673},
	{"SLAB", 4, 47674},
	{"LLAU", 4, 47675},
	{"UTCR", 4, 47676},
	{"LURE", 4, 47677},
	{"KART", 4, 47678},
	{"CHGA", 4, 47679},
	{"CPL", 3, 47680},
	{"ARCHBISHOP", 10, 47681},
	{"BYJU", 4, 47682},
	{"PUTIN", 5, 47683},
	{"QUESTIONNAIRES", 14, 47684},
	{"LING", 4, 47685},
	{"INCOMPATIBLE", 12, 47686},
	{"ADBO", 4, 47687},
	{"EMBLEM", 6, 47688},
	{"LYUP", 4, 47689},
	{"LWAU", 4, 47690},
	{"UPIT", 4, 47691},
	{"SBLU", 4, 47692},
	{"DLEI", 4, 47693},
	{"REKE", 4, 47694},
	{"PROFILEPROFILE", 14, 47695},
	{"ROADWAY", 7, 47696},
	{"OVERLAPPING", 11, 47697},
	{"SERIALS", 7, 47698},
	{"YZB", 3, 47699},
	{"WALTERS", 7, 47700},
	{"DUNES", 5, 47701},
	{"EQUIVALENCE", 11, 47702},
	{"MURDERS", 7, 47703},
	{"VAUGHN", 6, 47704},
	{"AVIV", 4, 47705},
	{"MISERABLE", 9, 47706},
	{"UNSUCCESSFUL", 12, 47707},
	{"CONDOMINIUMS", 12, 47708},
	{"MEAW", 4, 47709},
	{"APPLETON", 8, 47710},
	{"DDEE", 4, 47711},
	{"GCIT", 4, 47712},
	{"BOTTOMS", 7, 47713},
	{"RMCO", 4, 47714},
	{"REVOCATION", 10, 47715},
	{"APOF", 4, 47716},
	{"VOMITING", 8, 47717},
	{"MSWA", 4, 47718},
	{"TOUP", 4, 47719},
	{"EEKF", 4, 47720},
	{"CHESTERFIELD", 12, 47721},
	{"EXPOSING", 8, 47722},
	{"TUBS", 4, 47723},
	{"SIMULATE", 8, 47724},
	{"SCHEMATIC", 9, 47725},
	{"TEMF", 4, 47726},
	{"FSPO", 4, 47727},
	{"LIPOSUCTION", 11, 47728},
	{"ARGR", 4, 47729},
	{"MEDINA", 6, 47730},
	{"LTLI", 4, 47731},
	{"APOPTOSIS", 9, 47732},
	{"THANKFUL", 8, 47733},
	{"PNEUMATIC", 9, 47734},
	{"ALASKAN", 7, 47735},
	{"FRIEDRICH", 9, 47736},
	{"SNIPER", 6, 47737},
	{"MEBR", 4, 47738},
	{"EBYC", 4, 47739},
	{"XWAS", 4, 47740},
	{"UTYE", 4, 47741},
	{"VERTICES", 8, 47742},
	{"ELEPHANTS", 9, 47743},
	{"PINCH", 5, 47744},
	{"ICYA", 4, 47745},
	{"TICV", 4, 47746},
	{"ILTR", 4, 47747},
	{"DYCA", 4, 47748},
	{"YACA", 4, 47749},
	{"ADDITIVE", 8, 47750},
	{"MEIM", 4, 47751},
	{"ARIJ", 4, 47752},
	{"PROFESSIONALISM", 15, 47753},
	{"LIBERTARIAN", 11, 47754},
	{"GGEN", 4, 47755},
	{"FLYNN", 5, 47756},
	{"WASHABLE", 8, 47757},
	{"NORMALIZED", 10, 47758},
	{"UNINSTALL", 9, 47759},
	{"ACUT", 4, 47760},
	{"SCOPES", 6, 47761},
	{"FUNDRAISER", 10, 47762},
	{"BRACES", 6, 47763},
	{"TROLL", 5, 47764},
	{"ICLO", 4, 47765},
	{"CALHOUN", 7, 47766},
	{"EWBA", 4, 47767},
	{"TEAMWORK", 8, 47768},
	{"DENJ", 4, 47769},
	{"DEFICIENT", 9, 47770},
	{"DLYC", 4, 47771},
	{"CCRE", 4, 47772},
	{"AUDITIONS", 9, 47773},
	{"REFRIGERATORS", 13, 47774},
	{"ODYC", 4, 47775},
	{"REDIRECTED", 10, 47776},
	{"YGUA", 4, 47777},
	{"ANNOTATIONS", 11, 47778},
	{"MIDDLETOWN", 10, 47779},
	{"FILTH", 5, 47780},
	{"MMAY", 4, 47781},
	{"EDKE", 4, 47782},
	{"KTOR", 4, 47783},
	{"TGUN", 4, 47784},
	{"MODERATION", 10, 47785},
	{"WIDGETS", 7, 47786},
	{"WORRYING", 8, 47787},
	{"ONTOLOGY", 8, 47788},
	{"TIMBERLAND", 10, 47789},
	{"MAGS", 4, 47790},
	{"OUTRAGEOUS", 10, 47791},
	{"KRAFT", 5, 47792},
	{"VIDEOGAMES", 10, 47793},
	{"CONCLUDING", 10, 47794},
	{"ILLJ", 4, 47795},
	{"FEWC", 4, 47796},
	{"STMU", 4, 47797},
	{"VALLARTA", 8, 47798},
	{"BLACKBOARD", 10, 47799},
	{"CHOPPER", 7, 47800},
	{"RKBE", 4, 47801},
	{"NITRATE", 7, 47802},
	{"WNCA", 4, 47803},
	{"PINBALL", 7, 47804},
	{"EWBR", 4, 47805},
	{"PHARMACISTS", 11, 47806},
	{"AMFR", 4, 47807},
	{"OOLM", 4, 47808},
	{"SKATES", 6, 47809},
	{"ACYI", 4, 47810},
	{"SURCHARGE", 9, 47811},
	{"NTCU", 4, 47812},
	{"YJAN", 4, 47813},
	{"COMSTOCK", 8, 47814},
	{"FGEO", 4, 47815},
	{"YFLA", 4, 47816},
	{"LATVIAN", 7, 47817},
	{"GLYA", 4, 47818},
	{"FOOTPRINT", 9, 47819},
	{"RPIT", 4, 47820},
	{"IORP", 4, 47821},
	{"INSTALLS", 8, 47822},
	{"LTOL", 4, 47823},
	{"WPAR", 4, 47824},
	{"MALWARE", 7, 47825},
	{"TUNNELS", 7, 47826},
	{"LUBH", 4, 47827},
	{"CRISES", 6, 47828},
	{"WNDE", 4, 47829},
	{"TRILLION", 8, 47830},
	{"GBOA", 4, 47831},
	{"RENF", 4, 47832},
	{"PHEL", 4, 47833},
	{"EAGG", 4, 47834},
	{"COMFORTER", 9, 47835},
	{"CASHMERE", 8, 47836},
	{"HEAVIER", 7, 47837},
	{"NGUYEN", 6, 47838},
	{"METEOROLOGICAL", 14, 47839},
	{"DUNL", 4, 47840},
	{"LABELLED", 8, 47841},
	{"EEPP", 4, 47842},
	{"DARKER", 6, 47843},
	{"LEMU", 4, 47844},
	{"RBIR", 4, 47845},
	{"GLIT", 4, 47846},
	{"SALOMON", 7, 47847},
	{"UDIA", 4, 47848},
	{"LICB", 4, 47849},
	{"HORSEPOWER", 10, 47850},
	{"GLOBES", 6, 47851},
	{"ALGAE", 5, 47852},
	{"LDMI", 4, 47853},
	{"SARBANES", 8, 47854},
	{"RPUT", 4, 47855},
	{"ALCOHOLISM", 10, 47856},
	{"RETY", 4, 47857},
	{"DISSENT", 7, 47858},
	{"BDD", 3, 47859},
	{"MAXIMAL", 7, 47860},
	{"DALY", 4, 47861},
	{"RTYH", 4, 47862},
	{"GECH", 4, 47863},
	{"PRENATAL", 8, 47864},
	{"DEXI", 4, 47865},
	{"SCOOBY", 6, 47866},
	{"CHORAL", 6, 47867},
	{"UNRESTRICTED", 12, 47868},
	{"HAPPENINGS", 10, 47869},
	{"ULOO", 4, 47870},
	{"NEGU", 4, 47871},
	{"MOBY", 4, 47872},
	{"OFSY", 4, 47873},
	{"LEICESTERSHIRE", 14, 47874},
	{"CONTEMPT", 8, 47875},
	{"SOCIALISM", 9, 47876},
	{"UMPA", 4, 47877},
	{"IPEL", 4, 47878},
	{"ADOZ", 4, 47879},
	{"TMAL", 4, 47880},
	{"ELTR", 4, 47881},
	{"LEDS", 4, 47882},
	{"MCBRIDE", 7, 47883},
	{"EDIBLE", 6, 47884},
	{"ANARCHY", 7, 47885},
	{"ARDEN", 5, 47886},
	{"VESY", 4, 47887},
	{"IEDD", 4, 47888},
	{"GADV", 4, 47889},
	{"ALDU", 4, 47890},
	{"CLICKED", 7, 47891},
	{"INEFFECTIVE", 11, 47892},
	{"CEGR", 4, 47893},
	{"SCORECARD", 9, 47894},
	{"IUMW", 4, 47895},
	{"BEIRUT", 6, 47896},
	{"YCUR", 4, 47897},
	{"FTRI", 4, 47898},
	{"WIDO", 4, 47899},
	{"HAML", 4, 47900},
	{"GHUN", 4, 47901},
	{"DRAWERS", 7, 47902},
	{"BYRNE", 5, 47903},
	{"EDOD", 4, 47904},
	{"CONDITIONERS", 12, 47905},
	{"USCI", 4, 47906},
	{"ACME", 4, 47907},
	{"LEAKAGE", 7, 47908},
	{"CULTURALLY", 10, 47909},
	{"ILUG", 4, 47910},
	{"ADYW", 4, 47911},
	{"SHADY", 5, 47912},
	{"CHEMIST", 7, 47913},
	{"ELDU", 4, 47914},
	{"AXRE", 4, 47915},
	{"EVENLY", 6, 47916},
	{"JANITORIAL", 10, 47917},
	{"LWEE", 4, 47918},
	{"RECLAMATION", 11, 47919},
	{"ROVE", 4, 47920},
	{"PROPANE", 7, 47921},
	{"APPENDICES", 10, 47922},
	{"DMUR", 4, 47923},
	{"COLLAGEN", 8, 47924},
	{"LIONEL", 6, 47925},
	{"PRAISED", 7, 47926},
	{"ADAU", 4, 47927},
	{"ABUI", 4, 47928},
	{"LTIV", 4, 47929},
	{"RHYMES", 6, 47930},
	{"BLIZZARD", 8, 47931},
	{"AMUE", 4, 47932},
	{"ERECT", 5, 47933},
	{"NIGERIAN", 8, 47934},
	{"REFINING", 8, 47935},
	{"YRSQ", 4, 47936},
	{"CONCESSIONS", 11, 47937},
	{"RTYB", 4, 47938},
	{"COMMANDMENTS", 12, 47939},
	{"MALONE", 6, 47940},
	{"TYUN", 4, 47941},
	{"VESTS", 5, 47942},
	{"LRAN", 4, 47943},
	{"LARH", 4, 47944},
	{"ARBL", 4, 47945},
	{"GEWE", 4, 47946},
	{"YERH", 4, 47947},
	{"THBL", 4, 47948},
	{"LYDIA", 5, 47949},
	{"COYOTE", 6, 47950},
	{"MAKEOVER", 8, 47951},
	{"BREEDER", 7, 47952},
	{"CHCR", 4, 47953},
	{"ELECTRODE", 9, 47954},
	{"OUDS", 4, 47955},
	{"DRAGONBALL", 10, 47956},
	{"PGAM", 4, 47957},
	{"LFDE", 4, 47958},
	{"EUSD", 4, 47959},
	{"ATFU", 4, 47960},
	{"CHOW", 4, 47961},
	{"RYGA", 4, 47962},
	{"LYID", 4, 47963},
	{"COOKBOOKS", 9, 47964},
	{"POLLEN", 6, 47965},
	{"FFIE", 4, 47966},
	{"CKSM", 4, 47967},
	{"DRUNKEN", 7, 47968},
	{"SHRU", 4, 47969},
	{"ZERL", 4, 47970},
	{"RDPE", 4, 47971},
	{"MEQU", 4, 47972},
	{"VALET", 5, 47973},
	{"SPOILER", 7, 47974},
	{"TFLI", 4, 47975},
	{"CHENG", 5, 47976},
	{"IMAB", 4, 47977},
	{"TRYR", 4, 47978},
	{"MYCH", 4, 47979},
	{"IALV", 4, 47980},
	{"LAMBORGHINI", 11, 47981},
	{"LASF", 4, 47982},
	{"POLARIZED", 9, 47983},
	{"ECOF", 4, 47984},
	{"SHRUBS", 6, 47985},
	{"RZC", 3, 47986},
	{"WATERING", 8, 47987},
	{"BAROQUE", 7, 47988},
	{"NECL", 4, 47989},
	{"BARROW", 6, 47990},
	{"AWFO", 4, 47991},
	{"LTRO", 4, 47992},
	{"ELIOT", 5, 47993},
	{"JUNG", 4, 47994},
	{"JIHAD", 5, 47995},
	{"IWOR", 4, 47996},
	{"TRANSPORTING", 12, 47997},
	{"SHAREPOINT", 10, 47998},
	{"AVEJ", 4, 47999},
	{"RIFLES", 6, 48000},
	{"IALU", 4, 48001},
	{"NEMU", 4, 48002},
	{"POSTERIOR", 9, 48003},
	{"ELGIN", 5, 48004},
	{"PTOB", 4, 48005},
	{"EPIR", 4, 48006},
	{"EBLI", 4, 48007},
	{"EXCISE", 6, 48008},
	{"POETIC", 6, 48009},
	{"ABNORMALITIES", 13, 48010},
	{"ATGU", 4, 48011},
	{"MORTAR", 6, 48012},
	{"BLAMED", 6, 48013},
	{"RECOMMENDING", 12, 48014},
	{"ARMU", 4, 48015},
	{"OMSP", 4, 48016},
	{"LYTU", 4, 48017},
	{"IDFR", 4, 48018},
	{"DIRK", 4, 48019},
	{"DBOD", 4, 48020},
	{"POSTURE", 7, 48021},
	{"THEREON", 7, 48022},
	{"VALLEYS", 7, 48023},
	{"SCHM", 4, 48024},
	{"LLSR", 4, 48025},
	{"DECLARING", 9, 48026},
	{"TYGR", 4, 48027},
	{"HRYS", 4, 48028},
	{"BLOGSHARES", 10, 48029},
	{"OORM", 4, 48030},
	{"MOTORSPORT", 10, 48031},
	{"SEPTIC", 6, 48032},
	{"COMMENCING", 10, 48033},
	{"ARMADA", 6, 48034},
	{"WRENCH", 6, 48035},
	{"THANKED", 7, 48036},
	{"RTBR", 4, 48037},
	{"CITROEN", 7, 48038},
	{"TYTR", 4, 48039},
	{"USRO", 4, 48040},
	{"EELY", 4, 48041},
	{"ARRANGING", 9, 48042},
	{"THRILLED", 8, 48043},
	{"YWB", 3, 48044},
	{"OOLL", 4, 48045},
	{"PREDICTS", 8, 48046},
	{"AMELIA", 6, 48047},
	{"PALMONE", 7, 48048},
	{"JONAH", 5, 48049},
	{"EXPEDITED", 9, 48050},
	{"DISCOMFORT", 10, 48051},
	{"RAYT", 4, 48052},
	{"CURRICULA", 9, 48053},
	{"SCAR", 4, 48054},
	{"EEDC", 4, 48055},
	{"INDICTMENT", 10, 48056},
	{"WMD", 3, 48057},
	{"ILWI", 4, 48058},
	{"WNOR", 4, 48059},
	{"IDBA", 4, 48060},
	{"GIZE", 4, 48061},
	{"COLLARS", 7, 48062},
	{"PMTH", 4, 48063},
	{"CONFIGURABLE", 12, 48064},
	{"ANDOVER", 7, 48065},
	{"DENON", 5, 48066},
	{"SLOAN", 5, 48067},
	{"PUDDING", 7, 48068},
	{"SJAC", 4, 48069},
	{"FLAWED", 6, 48070},
	{"CHECKPOINT", 10, 48071},
	{"ZUF", 3, 48072},
	{"ROSENBERG", 9, 48073},
	{"PLATO", 5, 48074},
	{"RKSC", 4, 48075},
	{"EXAMINERS", 9, 48076},
	{"KHOM", 4, 48077},
	{"SALZBURG", 8, 48078},
	{"GDRI", 4, 48079},
	{"IRIVER", 6, 48080},
	{"CALLAWAY", 8, 48081},
	{"URTL", 4, 48082},
	{"POSSESSES", 9, 48083},
	{"EYMU", 4, 48084},
	{"DJUD", 4, 48085},
	{"DORM", 4, 48086},
	{"LTWA", 4, 48087},
	{"SQUARED", 7, 48088},
	{"KSOM", 4, 48089},
	{"YDOC", 4, 48090},
	{"NEEDLESS", 8, 48091},
	{"EROG", 4, 48092},
	{"ELPL", 4, 48093},
	{"LAKESIDE", 8, 48094},
	{"MARQUETTE", 9, 48095},
	{"AMAM", 4, 48096},
	{"KEPR", 4, 48097},
	{"YSPL", 4, 48098},
	{"UMFO", 4, 48099},
	{"IVEJ", 4, 48100},
	{"NTBL", 4, 48101},
	{"PALMA", 5, 48102},
	{"BARNETT", 7, 48103},
	{"INTERCONNECTION", 15, 48104},
	{"GILMORE", 7, 48105},
	{"PRC", 3, 48106},
	{"GSBU", 4, 48107},
	{"EWSM", 4, 48108},
	{"HETEROGENEOUS", 13, 48109},
	{"TAXIS", 5, 48110},
	{"ASPIRATIONS", 11, 48111},
	{"GAMEFAQS", 8, 48112},
	{"NDYS", 4, 48113},
	{"FENCES", 6, 48114},
	{"HMEM", 4, 48115},
	{"PLYW", 4, 48116},
	{"EXCAVATION", 10, 48117},
	{"COOKERS", 7, 48118},
	{"MSAY", 4, 48119},
	{"OFUP", 4, 48120},
	{"LUCKILY", 7, 48121},
	{"ULTRAVIOLET", 11, 48122},
	{"ADYP", 4, 48123},
	{"RUTLAND", 7, 48124},
	{"LIGHTED", 7, 48125},
	{"PNEUMONIA", 9, 48126},
	{"MONASTERY", 9, 48127},
	{"RYAF", 4, 48128},
	{"SLYW", 4, 48129},
	{"CEFA", 4, 48130},
	{"ERECTED", 7, 48131},
	{"EXPRESSES", 9, 48132},
	{"HAITIAN", 7, 48133},
	{"PEVE", 4, 48134},
	{"DIALING", 7, 48135},
	{"YSPI", 4, 48136},
	{"RDGA", 4, 48137},
	{"MIGRATE", 7, 48138},
	{"PYTH", 4, 48139},
	{"GDEM", 4, 48140},
	{"RFLA", 4, 48141},
	{"UNICEF", 6, 48142},
	{"DSPL", 4, 48143},
	{"CARTON", 6, 48144},
	{"LORRAINE", 8, 48145},
	{"EAKW", 4, 48146},
	{"COUNCILLORS", 11, 48147},
	{"IDENTIFIERS", 11, 48148},
	{"RCAD", 4, 48149},
	{"HAGUE", 5, 48150},
	{"MENTORS", 7, 48151},
	{"LHEW", 4, 48152},
	{"TRANSFORMS", 10, 48153},
	{"AMMONIA", 7, 48154},
	{"STEINER", 7, 48155},
	{"LICENSURE", 9, 48156},
	{"ROXY", 4, 48157},
	{"OUTLAW", 6, 48158},
	{"RXG", 3, 48159},
	{"TAMMY", 5, 48160},
	{"MCHI", 4, 48161},
	{"BOVINE", 6, 48162},
	{"YTIC", 4, 48163},
	{"NCHB", 4, 48164},
	{"DISLIKE", 7, 48165},
	{"SYSTEMATICALLY", 14, 48166},
	{"OGDEN", 5, 48167},
	{"FFHI", 4, 48168},
	{"INTERRUPTION", 12, 48169},
	{"DEMI", 4, 48170},
	{"LFER", 4, 48171},
	{"IMMINENT", 8, 48172},
	{"MADAM", 5, 48173},
	{"TIGHTS", 6, 48174},
	{"COMPELLED", 9, 48175},
	{"CRITICIZED", 10, 48176},
	{"SDAM", 4, 48177},
	{"HYPERTEXT", 9, 48178},
	{"YCJ", 3, 48179},
	{"UPHA", 4, 48180},
	{"ULLM", 4, 48181},
	{"SOYBEAN", 7, 48182},
	{"ELECTRA", 7, 48183},
	{"MFIN", 4, 48184},
	{"AFFIRMED", 8, 48185},
	{"VALV", 4, 48186},
	{"ULCA", 4, 48187},
	{"POSIX", 5, 48188},
	{"FBRE", 4, 48189},
	{"TDAV", 4, 48190},
	{"COMMUNAL", 8, 48191},
	{"LANDLORDS", 9, 48192},
	{"BREWERS", 7, 48193},
	{"VEAV", 4, 48194},
	{"LIBBY", 5, 48195},
	{"RDDI", 4, 48196},
	{"AMOM", 4, 48197},
	{"DYNAMITE", 8, 48198},
	{"ODCH", 4, 48199},
	{"NLAK", 4, 48200},
	{"MOTLEY", 6, 48201},
	{"ERKS", 4, 48202},
	{"AYPO", 4, 48203},
	{"MMES", 4, 48204},
	{"AROMA", 5, 48205},
	{"PIERCED", 7, 48206},
	{"TRANSLATES", 10, 48207},
	{"USPL", 4, 48208},
	{"UYAN", 4, 48209},
	{"RETRACTABLE", 11, 48210},
	{"LAWH", 4, 48211},
	{"IJUA", 4, 48212},
	{"COGNITION", 9, 48213},
	{"QUICKBOOKS", 10, 48214},
	{"TOWNHOUSE", 9, 48215},
	{"YBYA", 4, 48216},
	{"VERONA", 6, 48217},
	{"MBLA", 4, 48218},
	{"STORMWATER", 10, 48219},
	{"DELEGATED", 9, 48220},
	{"EWIR", 4, 48221},
	{"VEDN", 4, 48222},
	{"LGRI", 4, 48223},
	{"LPTU", 4, 48224},
	{"LINR", 4, 48225},
	{"LEJO", 4, 48226},
	{"COCO", 4, 48227},
	{"CHATTING", 8, 48228},
	{"YFIE", 4, 48229},
	{"GPUB", 4, 48230},
	{"NOFV", 4, 48231},
	{"FAFR", 4, 48232},
	{"FISHERMEN", 9, 48233},
	{"USOP", 4, 48234},
	{"KERP", 4, 48235},
	{"PIPELINES", 9, 48236},
	{"SGUY", 4, 48237},
	{"NCUT", 4, 48238},
	{"CONFORMING", 10, 48239},
	{"FKF", 3, 48240},
	{"CAUSAL", 6, 48241},
	{"SUNR", 4, 48242},
	{"KBEC", 4, 48243},
	{"RUDY", 4, 48244},
	{"STRINGENT", 9, 48245},
	{"ROWAN", 5, 48246},
	{"SEUR", 4, 48247},
	{"ASSIGNING", 9, 48248},
	{"DWELL", 5, 48249},
	{"EXTP", 4, 48250},
	{"UGES", 4, 48251},
	{"CEDL", 4, 48252},
	{"HACKED", 6, 48253},
	{"INAUGURAL", 9, 48254},
	{"AWKWARD", 7, 48255},
	{"MSDS", 4, 48256},
	{"WEAVING", 7, 48257},
	{"METROPOLIS", 10, 48258},
	{"PLYC", 4, 48259},
	{"ARAFAT", 6, 48260},
	{"NADR", 4, 48261},
	{"PSYCHOLOGISTS", 13, 48262},
	{"DILIGENCE", 9, 48263},
	{"NSMU", 4, 48264},
	{"GBOO", 4, 48265},
	{"SPLITTER", 8, 48266},
	{"PMOR", 4, 48267},
	{"ADFR", 4, 48268},
	{"HRED", 4, 48269},
	{"UTSW", 4, 48270},
	{"STANDARDIZATION", 15, 48271},
	{"ENFORCING", 9, 48272},
	{"YATL", 4, 48273},
	{"LAKELAND", 8, 48274},
	{"THISCATEGORY", 12, 48275},
	{"CLASSY", 6, 48276},
	{"STRUGGLED", 9, 48277},
	{"LOOKOUT", 7, 48278},
	{"ARTERIAL", 8, 48279},
	{"INJUSTICE", 9, 48280},
	{"MYSTICAL", 8, 48281},
	{"ACXIOM", 6, 48282},
	{"YGAV", 4, 48283},
	{"TRIATHLON", 9, 48284},
	{"IRONING", 7, 48285},
	{"FWOM", 4, 48286},
	{"DBYU", 4, 48287},
	{"OLIG", 4, 48288},
	{"KBYTES", 6, 48289},
	{"LYCE", 4, 48290},
	{"ERUM", 4, 48291},
	{"TDOU", 4, 48292},
	{"LLPI", 4, 48293},
	{"COMMANDED", 9, 48294},
	{"LDOM", 4, 48295},
	{"LASB", 4, 48296},
	{"OLLM", 4, 48297},
	{"WOODLANDS", 9, 48298},
	{"GUARDIANS", 9, 48299},
	{"MANIFESTO", 9, 48300},
	{"JAWS", 4, 48301},
	{"TEXTURED", 8, 48302},
	{"LERD", 4, 48303},
	{"ELSL", 4, 48304},
	{"DOPPLER", 7, 48305},
	{"RAWO", 4, 48306},
	{"PEDESTAL", 8, 48307},
	{"ENTROPY", 7, 48308},
	{"WIDENING", 8, 48309},
	{"ORMF", 4, 48310},
	{"RGYS", 4, 48311},
	{"YREI", 4, 48312},
	{"SNOOKER", 7, 48313},
	{"UNLEASHED", 9, 48314},
	{"UNDERWOOD", 9, 48315},
	{"SALINE", 6, 48316},
	{"FFFO", 4, 48317},
	{"SONNY", 5, 48318},
	{"NPLE", 4, 48319},
	{"LONGEVITY", 9, 48320},
	{"LUX", 3, 48321},
	{"LGOT", 4, 48322},
	{"ISABEL", 6, 48323},
	{"RDPO", 4, 48324},
	{"PLEY", 4, 48325},
	{"KEFR", 4, 48326},
	{"CTLI", 4, 48327},
	{"NAIROBI", 7, 48328},
	{"STERILE", 7, 48329},
	{"ENFU", 4, 48330},
	{"KTRA", 4, 48331},
	{"FFAR", 4, 48332},
	{"IMPORTER", 8, 48333},
	{"ORIOLES", 7, 48334},
	{"BOTANY", 6, 48335},
	{"DISSOLUTION", 11, 48336},
	{"ROTOR", 5, 48337},
	{"PAULINE", 7, 48338},
	{"ICTL", 4, 48339},
	{"ITCR", 4, 48340},
	{"FTEX", 4, 48341},
	{"SACQ", 4, 48342},
	{"RAYM", 4, 48343},
	{"OCTR", 4, 48344},
	{"ORKL", 4, 48345},
	{"QUART", 5, 48346},
	{"THERES", 6, 48347},
	{"BISON", 5, 48348},
	{"SUPPRESSED", 10, 48349},
	{"LFAT", 4, 48350},
	{"FRIN", 4, 48351},
	{"ALLEGRO", 7, 48352},
	{"WSOU", 4, 48353},
	{"CKAD", 4, 48354},
	{"TCEL", 4, 48355},
	{"MATERIALLY", 10, 48356},
	{"AMOR", 4, 48357},
	{"FUNGI", 5, 48358},
	{"PHYLLIS", 7, 48359},
	{"DREAMY", 6, 48360},
	{"NYWE", 4, 48361},
	{"ALAK", 4, 48362},
	{"BENGAL", 6, 48363},
	{"BACKSTAGE", 9, 48364},
	{"SCROLLS", 7, 48365},
	{"HTCL", 4, 48366},
	{"AWAKENING", 9, 48367},
	{"RKSB", 4, 48368},
	{"CQUA", 4, 48369},
	{"RIJU", 4, 48370},
	{"FAIRIES", 7, 48371},
	{"RLIC", 4, 48372},
	{"PRESCRIBE", 9, 48373},
	{"EEKC", 4, 48374},
	{"LUBBOCK", 7, 48375},
	{"YBOU", 4, 48376},
	{"LLCE", 4, 48377},
	{"GREED", 5, 48378},
	{"TBEM", 4, 48379},
	{"GINR", 4, 48380},
	{"NOMINATE", 8, 48381},
	{"SPARKLE", 7, 48382},
	{"AUTOGRAPH", 9, 48383},
	{"SUVS", 4, 48384},
	{"YDRE", 4, 48385},
	{"BMP", 3, 48386},
	{"NBYP", 4, 48387},
	{"FTBE", 4, 48388},
	{"YRUS", 4, 48389},
	{"MIGRATING", 9, 48390},
	{"GASKET", 6, 48391},
	{"REFRAIN", 7, 48392},
	{"LASTLY", 6, 48393},
	{"OVERCOMING", 10, 48394},
	{"MOFM", 4, 48395},
	{"DFLE", 4, 48396},
	{"GESM", 4, 48397},
	{"RELIEVED", 8, 48398},
	{"STBL", 4, 48399},
	{"ERTB", 4, 48400},
	{"FIREARM", 7, 48401},
	{"DLIB", 4, 48402},
	{"LEYP", 4, 48403},
	{"LUC", 3, 48404},
	{"DNTF", 4, 48405},
	{"ELENA", 5, 48406},
	{"LPAY", 4, 48407},
	{"CLOSURES", 8, 48408},
	{"DWEI", 4, 48409},
	{"IGHD", 4, 48410},
	{"ADAV", 4, 48411},
	{"PARTICIPATORY", 13, 48412},
	{"INTERMITTENT", 12, 48413},
	{"MICRON", 6, 48414},
	{"BUDGETARY", 9, 48415},
	{"GHAB", 4, 48416},
	{"PCOS", 4, 48417},
	{"VOLS", 4, 48418},
	{"REVOLVING", 9, 48419},
	{"AMAF", 4, 48420},
	{"LLOA", 4, 48421},
	{"YGOA", 4, 48422},
	{"BUNDLED", 7, 48423},
	{"FDAY", 4, 48424},
	{"PANTIE", 6, 48425},
	{"UTDA", 4, 48426},
	{"PPEL", 4, 48427},
	{"ACCL", 4, 48428},
	{"BOMBERS", 7, 48429},
	{"FBAL", 4, 48430},
	{"COVERT", 6, 48431},
	{"UTYA", 4, 48432},
	{"CRATER", 6, 48433},
	{"GNCO", 4, 48434},
	{"GGET", 4, 48435},
	{"FAVORED", 7, 48436},
	{"BRED", 4, 48437},
	{"SPONGEBOB", 9, 48438},
	{"FRACTIONAL", 10, 48439},
	{"MARKUS", 6, 48440},
	{"FOSTERING", 9, 48441},
	{"DOWO", 4, 48442},
	{"OLAW", 4, 48443},
	{"WELLBUTRIN", 10, 48444},
	{"UPFI", 4, 48445},
	{"RHEUMATOID", 10, 48446},
	{"THENCE", 6, 48447},
	{"BIRTHPLACE", 10, 48448},
	{"BLEED", 5, 48449},
	{"REVEREND", 8, 48450},
	{"ONDY", 4, 48451},
	{"ANYK", 4, 48452},
	{"TRANSMITTING", 12, 48453},
	{"KINW", 4, 48454},
	{"SWINDON", 7, 48455},
	{"CABERNET", 8, 48456},
	{"DHEB", 4, 48457},
	{"SERIE", 5, 48458},
	{"YSAV", 4, 48459},
	{"NEPTUNE", 7, 48460},
	{"EPTU", 4, 48461},
	{"CAUCASIAN", 9, 48462},
	{"UNDERSTANDABLE", 14, 48463},
	{"OEUR", 4, 48464},
	{"GOBLET", 6, 48465},
	{"DOCTORATE", 9, 48466},
	{"BINARIES", 8, 48467},
	{"OMDO", 4, 48468},
	{"INVENTIONS", 10, 48469},
	{"SLOVENIAN", 9, 48470},
	{"REWF", 4, 48471},
	{"LOUG", 4, 48472},
	{"PRACTICABLE", 11, 48473},
	{"IERB", 4, 48474},
	{"SHOWDOWN", 8, 48475},
	{"SIMONE", 6, 48476},
	{"EXTG", 4, 48477},
	{"FRONTS", 6, 48478},
	{"RUSSIANS", 8, 48479},
	{"RORF", 4, 48480},
	{"SERW", 4, 48481},
	{"POTENTIALS", 10, 48482},
	{"ALGI", 4, 48483},
	{"UZG", 3, 48484},
	{"JRY", 3, 48485},
	{"CZP", 3, 48486},
	{"INCUR", 5, 48487},
	{"TEMPE", 5, 48488},
	{"WSUP", 4, 48489},
	{"HKLM", 4, 48490},
	{"TLIM", 4, 48491},
	{"CORES", 5, 48492},
	{"LRAC", 4, 48493},
	{"LLYJ", 4, 48494},
	{"BORROWERS", 9, 48495},
	{"DGLO", 4, 48496},
	{"HTFU", 4, 48497},
	{"EELB", 4, 48498},
	{"MEFE", 4, 48499},
	{"CANONICAL", 9, 48500},
	{"MYBE", 4, 48501},
	{"NODDED", 6, 48502},
	{"CONFRONTED", 10, 48503},
	{"DGLA", 4, 48504},
	{"BELIEVER", 8, 48505},
	{"BOUVET", 6, 48506},
	{"MULTIFUNCTION", 13, 48507},
	{"AUSTRALIANS", 11, 48508},
	{"UTPL", 4, 48509},
	{"NIFTY", 5, 48510},
	{"AFTW", 4, 48511},
	{"DECLINES", 8, 48512},
	{"UNVEILS", 7, 48513},
	{"CECL", 4, 48514},
	{"PEACOCK", 7, 48515},
	{"UTMOST", 6, 48516},
	{"SKELETAL", 8, 48517},
	{"KSWA", 4, 48518},
	{"DEMS", 4, 48519},
	{"LWAL", 4, 48520},
	{"ACUP", 4, 48521},
	{"YATES", 5, 48522},
	{"LEROY", 5, 48523},
	{"ROLLOVER", 8, 48524},
	{"LSCR", 4, 48525},
	{"INFOS", 5, 48526},
	{"HELPERS", 7, 48527},
	{"DLYR", 4, 48528},
	{"ELAPSED", 7, 48529},
	{"THANX", 5, 48530},
	{"ANTHRAX", 7, 48531},
	{"ACADEMIES", 9, 48532},
	{"SMOM", 4, 48533},
	{"SHOCKWAVE", 9, 48534},
	{"IMITATION", 9, 48535},
	{"HARVESTED", 9, 48536},
	{"LDET", 4, 48537},
	{"HOPEFUL", 7, 48538},
	{"YORC", 4, 48539},
	{"FURNISHING", 10, 48540},
	{"GASU", 4, 48541},
	{"NEGATIVELY", 10, 48542},
	{"WESTLIFE", 8, 48543},
	{"RESIDENCES", 10, 48544},
	{"SPINACH", 7, 48545},
	{"BPM", 3, 48546},
	{"TICG", 4, 48547},
	{"LIQUIDATION", 11, 48548},
	{"BEOU", 4, 48549},
	{"LFAL", 4, 48550},
	{"PREDECESSOR", 11, 48551},
	{"TAMIFLU", 7, 48552},
	{"CHEEKS", 6, 48553},
	{"GMIS", 4, 48554},
	{"GSKI", 4, 48555},
	{"ATFL", 4, 48556},
	{"PLANAR", 6, 48557},
	{"PHILANTHROPY", 12, 48558},
	{"ADEQUACY", 8, 48559},
	{"KSCH", 4, 48560},
	{"LCHU", 4, 48561},
	{"IOMEGA", 6, 48562},
	{"NRID", 4, 48563},
	{"YSGO", 4, 48564},
	{"FETISCH", 7, 48565},
	{"PEANUTS", 7, 48566},
	{"DISCOVERS", 9, 48567},
	{"EASTMAN", 7, 48568},
	{"FRANCHISING", 11, 48569},
	{"COPPERMINE", 10, 48570},
	{"DISCARD", 7, 48571},
	{"CAVALRY", 7, 48572},
	{"YCG", 3, 48573},
	{"BREAKERS", 8, 48574},
	{"QUORUM", 6, 48575},
	{"FORWARDS", 8, 48576},
	{"ECRY", 4, 48577},
	{"EYAC", 4, 48578},
	{"LBAL", 4, 48579},
	{"ECARD", 5, 48580},
	{"PREVALENT", 9, 48581},
	{"INDP", 4, 48582},
	{"PLAT", 4, 48583},
	{"EXPLOITS", 8, 48584},
	{"FULN", 4, 48585},
	{"MOFP", 4, 48586},
	{"ANGW", 4, 48587},
	{"DUKES", 5, 48588},
	{"YOLD", 4, 48589},
	{"DIEV", 4, 48590},
	{"OFFENDED", 8, 48591},
	{"LYMU", 4, 48592},
	{"TRIMMED", 7, 48593},
	{"KYAR", 4, 48594},
	{"FERRIES", 7, 48595},
	{"WORCESTERSHIRE", 14, 48596},
	{"KESB", 4, 48597},
	{"ZFM", 3, 48598},
	{"PQB", 3, 48599},
	{"AGIV", 4, 48600},
	{"FAQFAQ", 6, 48601},
	{"MULLER", 6, 48602},
	{"PROSTITUTION", 12, 48603},
	{"MOSQUE", 6, 48604},
	{"CKMO", 4, 48605},
	{"RAMF", 4, 48606},
	{"FUDGE", 5, 48607},
	{"EXTRACTOR", 9, 48608},
	{"HORSEBACK", 9, 48609},
	{"VESTED", 6, 48610},
	{"REOB", 4, 48611},
	{"EPAU", 4, 48612},
	{"HDIF", 4, 48613},
	{"EARNEST", 7, 48614},
	{"USERGROUPSUSERGROUPS", 20, 48615},
	{"SVENSKA", 7, 48616},
	{"PCG", 3, 48617},
	{"YOFV", 4, 48618},
	{"MYOCARDIAL", 10, 48619},
	{"HOMME", 5, 48620},
	{"CLANCY", 6, 48621},
	{"EVERYTIME", 9, 48622},
	{"YLEN", 4, 48623},
	{"CALLBACK", 8, 48624},
	{"TORY", 4, 48625},
	{"ENCOMPASSES", 11, 48626},
	{"NCHF", 4, 48627},
	{"YXX", 3, 48628},
	{"LJF", 3, 48629},
	{"ROSSI", 5, 48630},
	{"SANDER", 6, 48631},
	{"ABLU", 4, 48632},
	{"OLDHAM", 6, 48633},
	{"GONZALES", 8, 48634},
	{"HLOC", 4, 48635},
	{"CONDUCTIVITY", 12, 48636},
	{"CONFEDERATE", 11, 48637},
	{"PRESUMED", 8, 48638},
	{"ANNETTE", 7, 48639},
	{"MPUL", 4, 48640},
	{"CLIMAX", 6, 48641},
	{"BLENDING", 8, 48642},
	{"ULST", 4, 48643},
	{"VICKI", 5, 48644},
	{"ARCL", 4, 48645},
	{"POSTPONED", 9, 48646},
	{"EYBR", 4, 48647},
	{"DANVILLE", 8, 48648},
	{"PHILOSOPHERS", 12, 48649},
	{"UPHO", 4, 48650},
	{"SPEEDING", 8, 48651},
	{"XPLI", 4, 48652},
	{"ERTM", 4, 48653},
	{"CREDITOR", 8, 48654},
	{"MXW", 3, 48655},
	{"NZAL", 4, 48656},
	{"OVEP", 4, 48657},
	{"EDYS", 4, 48658},
	{"PARDON", 6, 48659},
	{"SEDONA", 6, 48660},
	{"ODER", 4, 48661},
	{"SKATEBOARDING", 13, 48662},
	{"LMMA", 4, 48663},
	{"LEXISNEXIS", 10, 48664},
	{"ABBY", 4, 48665},
	{"OUTBACK", 7, 48666},
	{"TELLER", 6, 48667},
	{"MANDATES", 8, 48668},
	{"REIKI", 5, 48669},
	{"BIOPSY", 6, 48670},
	{"PEPTIDES", 8, 48671},
	{"VEIL", 4, 48672},
	{"UGSA", 4, 48673},
	{"PECK", 4, 48674},
	{"EEPC", 4, 48675},
	{"CUSTODIAN", 9, 48676},
	{"DANTE", 5, 48677},
	{"LANGE", 5, 48678},
	{"SJOU", 4, 48679},
	{"VESR", 4, 48680},
	{"UNEV", 4, 48681},
	{"MENB", 4, 48682},
	{"UEPR", 4, 48683},
	{"OGAR", 4, 48684},
	{"QUARRY", 6, 48685},
	{"SENECA", 6, 48686},
	{"OCEANIC", 7, 48687},
	{"LETW", 4, 48688},
	{"RDWE", 4, 48689},
	{"HELM", 4, 48690},
	{"BURBANK", 7, 48691},
	{"FESTIVE", 7, 48692},
	{"TPLE", 4, 48693},
	{"TGOL", 4, 48694},
	{"ROSEN", 5, 48695},
	{"AWAKENINGS", 10, 48696},
	{"OLPR", 4, 48697},
	{"ODBY", 4, 48698},
	{"IMEY", 4, 48699},
	{"AILM", 4, 48700},
	{"ADIG", 4, 48701},
	{"ALLA", 4, 48702},
	{"PRESERVES", 9, 48703},
	{"UTEB", 4, 48704},
	{"MWAR", 4, 48705},
	{"SEBR", 4, 48706},
	{"SEDIMENTS", 9, 48707},
	{"DPHY", 4, 48708},
	{"APPRAISER", 9, 48709},
	{"DBUY", 4, 48710},
	{"INGRAM", 6, 48711},
	{"GAUSSIAN", 8, 48712},
	{"HUSTLER", 7, 48713},
	{"TENSIONS", 8, 48714},
	{"YVP", 3, 48715},
	{"SECRETION", 9, 48716},
	{"LINKAGES", 8, 48717},
	{"SEPARATOR", 9, 48718},
	{"ULEI", 4, 48719},
	{"INSULT", 6, 48720},
	{"BYEL", 4, 48721},
	{"SCRAPS", 6, 48722},
	{"WAIVED", 6, 48723},
	{"TWID", 4, 48724},
	{"CURED", 5, 48725},
	{"SCHULTZ", 7, 48726},
	{"FGER", 4, 48727},
	{"BUGGY", 5, 48728},
	{"NPAU", 4, 48729},
	{"LLAA", 4, 48730},
	{"CONCORDIA", 9, 48731},
	{"OODJ", 4, 48732},
	{"UREV", 4, 48733},
	{"RVOL", 4, 48734},
	{"RECON", 5, 48735},
	{"IRDC", 4, 48736},
	{"EAFU", 4, 48737},
	{"KENNEL", 6, 48738},
	{"DRILLED", 7, 48739},
	{"FILEPLANET", 10, 48740},
	{"UECH", 4, 48741},
	{"BEWE", 4, 48742},
	{"SOUVENIRS", 9, 48743},
	{"YSAM", 4, 48744},
	{"ROYALS", 6, 48745},
	{"HEMR", 4, 48746},
	{"PRESCRIBING", 11, 48747},
	{"SLACK", 5, 48748},
	{"GLOBALISATION", 13, 48749},
	{"BORLAND", 7, 48750},
	{"PASTEL", 6, 48751},
	{"FMAL", 4, 48752},
	{"FDEM", 4, 48753},
	{"NOTTINGHAMSHIRE", 15, 48754},
	{"EWLO", 4, 48755},
	{"RNRE", 4, 48756},
	{"DIFFERENTIATE", 13, 48757},
	{"UNTW", 4, 48758},
	{"STROLLERS", 9, 48759},
	{"CPER", 4, 48760},
	{"JAYS", 4, 48761},
	{"UNINSURED", 9, 48762},
	{"PICASSO", 7, 48763},
	{"PILGRIM", 7, 48764},
	{"RSPU", 4, 48765},
	{"VINES", 5, 48766},
	{"CANJ", 4, 48767},
	{"SUSCEPTIBILITY", 14, 48768},
	{"AMBIGUOUS", 9, 48769},
	{"MCGILL", 6, 48770},
	{"ADYC", 4, 48771},
	{"YMAS", 4, 48772},
	{"TOMC", 4, 48773},
	{"ULOS", 4, 48774},
	{"DSDO", 4, 48775},
	{"DISPUTED", 8, 48776},
	{"LTAG", 4, 48777},
	{"SCOUTING", 8, 48778},
	{"ROYALE", 6, 48779},
	{"GORGE", 5, 48780},
	{"RRYP", 4, 48781},
	{"RIGHTEOUSNESS", 13, 48782},
	{"YHUM", 4, 48783},
	{"GMAD", 4, 48784},
	{"EGEC", 4, 48785},
	{"LXB", 3, 48786},
	{"DERV", 4, 48787},
	{"AMSM", 4, 48788},
	{"DISCRIMINATORY", 14, 48789},
	{"TEBY", 4, 48790},
	{"WEDW", 4, 48791},
	{"OPAQUE", 6, 48792},
	{"HEADQUARTERED", 13, 48793},
	{"FUMB", 4, 48794},
	{"FMAK", 4, 48795},
	{"BULLYING", 8, 48796},
	{"SAUL", 4, 48797},
	{"FLAMING", 7, 48798},
	{"LMST", 4, 48799},
	{"GONM", 4, 48800},
	{"ARKP", 4, 48801},
	{"TRAVELODGE", 10, 48802},
	{"KNIF", 4, 48803},
	{"EMPOWER", 7, 48804},
	{"MARIAN", 6, 48805},
	{"COFO", 4, 48806},
	{"ORMB", 4, 48807},
	{"LIENS", 5, 48808},
	{"LSQU", 4, 48809},
	{"FSIX", 4, 48810},
	{"ZWAS", 4, 48811},
	{"CATERPILLAR", 11, 48812},
	{"HURLEY", 6, 48813},
	{"RFLI", 4, 48814},
	{"GWEE", 4, 48815},
	{"MBIE", 4, 48816},
	{"IFFO", 4, 48817},
	{"LGER", 4, 48818},
	{"REMINGTON", 9, 48819},
	{"YBEM", 4, 48820},
	{"PEDALS", 6, 48821},
	{"ICYO", 4, 48822},
	{"BENEFITED", 9, 48823},
	{"BITMAP", 6, 48824},
	{"MIGRAINE", 8, 48825},
	{"MUSIK", 5, 48826},
	{"YSAC", 4, 48827},
	{"ENUM", 4, 48828},
	{"OMISSION", 8, 48829},
	{"LTBY", 4, 48830},
	{"BUMW", 4, 48831},
	{"YADO", 4, 48832},
	{"BOYLE", 5, 48833},
	{"LAMAR", 5, 48834},
	{"ACYT", 4, 48835},
	{"LSLA", 4, 48836},
	{"DIMINISHED", 10, 48837},
	{"AIDY", 4, 48838},
	{"JONAS", 5, 48839},
	{"LTCO", 4, 48840},
	{"LOCKE", 5, 48841},
	{"CAGES", 5, 48842},
	{"METHANE", 7, 48843},
	{"PAGER", 5, 48844},
	{"ATCU", 4, 48845},
	{"RBQ", 3, 48846},
	{"KYQ", 3, 48847},
	{"JOLLA", 5, 48848},
	{"ACLU", 4, 48849},
	{"REXE", 4, 48850},
	{"NKFU", 4, 48851},
	{"CAPITALS", 8, 48852},
	{"CORRECTNESS", 11, 48853},
	{"HBUR", 4, 48854},
	{"WESTCHESTER", 11, 48855},
	{"YJOB", 4, 48856},
	{"SPUS", 4, 48857},
	{"DGOI", 4, 48858},
	{"AREX", 4, 48859},
	{"NYLI", 4, 48860},
	{"RLIG", 4, 48861},
	{"UMUS", 4, 48862},
	{"BANJO", 5, 48863},
	{"SHAKER", 6, 48864},
	{"LANY", 4, 48865},
	{"RPEA", 4, 48866},
	{"NATIVES", 7, 48867},
	{"QUILTING", 8, 48868},
	{"CAMPGROUNDS", 11, 48869},
	{"USYE", 4, 48870},
	{"FGOL", 4, 48871},
	{"CKTA", 4, 48872},
	{"STOUT", 5, 48873},
	{"REWARDED", 8, 48874},
	{"DENSITIES", 9, 48875},
	{"UCTT", 4, 48876},
	{"EXTU", 4, 48877},
	{"ATHENA", 6, 48878},
	{"DEEPEST", 7, 48879},
	{"ENCU", 4, 48880},
	{"MATTHIAS", 8, 48881},
	{"YZG", 3, 48882},
	{"TIONAL", 6, 48883},
	{"DUANE", 5, 48884},
	{"RSDR", 4, 48885},
	{"OWIM", 4, 48886},
	{"LSBA", 4, 48887},
	{"TURNAROUND", 10, 48888},
	{"TYPL", 4, 48889},
	{"OWDS", 4, 48890},
	{"ELBU", 4, 48891},
	{"CLIMBED", 7, 48892},
	{"MBUL", 4, 48893},
	{"CORRUPTED", 9, 48894},
	{"RELAYS", 6, 48895},
	{"NAVIGATIONAL", 12, 48896},
	{"STARGATE", 8, 48897},
	{"GBRI", 4, 48898},
	{"HUSBANDS", 8, 48899},
	{"SASKATOON", 9, 48900},
	{"YNOL", 4, 48901},
	{"PLYB", 4, 48902},
	{"YADE", 4, 48903},
	{"DWEB", 4, 48904},
	{"FADING", 6, 48905},
	{"GPAT", 4, 48906},
	{"BYGR", 4, 48907},
	{"ODYH", 4, 48908},
	{"COLCHESTER", 10, 48909},
	{"FINGERTIPS", 10, 48910},
	{"CCHU", 4, 48911},
	{"ABRU", 4, 48912},
	{"ROCKWELL", 8, 48913},
	{"ULTC", 4, 48914},
	{"ABOY", 4, 48915},
	{"SBEY", 4, 48916},
	{"CEBR", 4, 48917},
	{"HDEC", 4, 48918},
	{"YVAR", 4, 48919},
	{"LEFL", 4, 48920},
	{"GSOR", 4, 48921},
	{"PEPSI", 5, 48922},
	{"BYVI", 4, 48923},
	{"NYBU", 4, 48924},
	{"ROAMING", 7, 48925},
	{"OVERSIZED", 9, 48926},
	{"ORDD", 4, 48927},
	{"ENDD", 4, 48928},
	{"DETERMINATIONS", 14, 48929},
	{"BURBERRY", 8, 48930},
	{"LINJ", 4, 48931},
	{"WEIGHED", 7, 48932},
	{"ASHAMED", 7, 48933},
	{"CONCIERGE", 9, 48934},
	{"IMDO", 4, 48935},
	{"MSER", 4, 48936},
	{"ELPB", 4, 48937},
	{"GORILLA", 7, 48938},
	{"TDOM", 4, 48939},
	{"WEMU", 4, 48940},
	{"USCE", 4, 48941},
	{"GATHERINGS", 10, 48942},
	{"RJUN", 4, 48943},
	{"LYCU", 4, 48944},
	{"DLIE", 4, 48945},
	{"INHIBIT", 7, 48946},
	{"LLKE", 4, 48947},
	{"CHELTENHAM", 10, 48948},
	{"YDOU", 4, 48949},
	{"SCREENPLAY", 10, 48950},
	{"UNABRIDGED", 10, 48951},
	{"IGNB", 4, 48952},
	{"FFST", 4, 48953},
	{"DICKENS", 7, 48954},
	{"YCEL", 4, 48955},
	{"IMID", 4, 48956},
	{"ENDPOINT", 8, 48957},
	{"WELI", 4, 48958},
	{"JUNIPER", 7, 48959},
	{"SBYM", 4, 48960},
	{"REPETITION", 10, 48961},
	{"FSUR", 4, 48962},
	{"LABELLING", 9, 48963},
	{"SIBERIAN", 8, 48964},
	{"OUFE", 4, 48965},
	{"SYNCHRONOUS", 11, 48966},
	{"SVIR", 4, 48967},
	{"NMAG", 4, 48968},
	{"HEARTLAND", 9, 48969},
	{"RASL", 4, 48970},
	{"PREPARATORY", 11, 48971},
	{"CAFETERIA", 9, 48972},
	{"OUTFITTERS", 10, 48973},
	{"FIELDING", 8, 48974},
	{"EYRO", 4, 48975},
	{"DUNE", 4, 48976},
	{"KANY", 4, 48977},
	{"ULDJ", 4, 48978},
	{"ADLER", 5, 48979},
	{"HOMELESSNESS", 12, 48980},
	{"YOSEMITE", 8, 48981},
	{"CURSED", 6, 48982},
	{"OPENGL", 6, 48983},
	{"LBOW", 4, 48984},
	{"EFFICIENCIES", 12, 48985},
	{"BLOWOUT", 7, 48986},
	{"YOUTHS", 6, 48987},
	{"COFT", 4, 48988},
	{"TICKBOXES", 9, 48989},
	{"MIGRANTS", 8, 48990},
	{"MPOL", 4, 48991},
	{"MASSEY", 6, 48992},
	{"TUMBLE", 6, 48993},
	{"THRESHOLDS", 10, 48994},
	{"UNLOCKING", 9, 48995},
	{"MISSY", 5, 48996},
	{"USAY", 4, 48997},
	{"FCOA", 4, 48998},
	{"WAVEFORM", 8, 48999},
	{"DEFICITS", 8, 49000},
	{"MEADE", 5, 49001},
	{"CONTRADICTION", 13, 49002},
	{"FLAIR", 5, 49003},
	{"HELIUM", 6, 49004},
	{"APPLEGATE", 9, 49005},
	{"UTHL", 4, 49006},
	{"WONDERFULLY", 11, 49007},
	{"WHITEWATER", 10, 49008},
	{"TABLEWARE", 9, 49009},
	{"BERNIE", 6, 49010},
	{"EMCA", 4, 49011},
	{"DUG", 3, 49012},
	{"WORKGROUP", 9, 49013},
	{"CONGENITAL", 10, 49014},
	{"TDRE", 4, 49015},
	{"ILFR", 4, 49016},
	{"TROJANS", 7, 49017},
	{"INSANITY", 8, 49018},
	{"CLEMENT", 7, 49019},
	{"CTDE", 4, 49020},
	{"EMBRACED", 8, 49021},
	{"FINELY", 6, 49022},
	{"AUTHENTICATED", 13, 49023},
	{"LVOT", 4, 49024},
	{"REFORMED", 8, 49025},
	{"XXF", 3, 49026},
	{"ROBOTIC", 7, 49027},
	{"YISM", 4, 49028},
	{"RGAT", 4, 49029},
	{"KWER", 4, 49030},
	{"ADHESION", 8, 49031},
	{"EWRA", 4, 49032},
	{"MISSISSAUGA", 11, 49033},
	{"DIALYSIS", 8, 49034},
	{"UTHR", 4, 49035},
	{"LUEC", 4, 49036},
	{"FILMED", 6, 49037},
	{"STATEN", 6, 49038},
	{"CAROLE", 6, 49039},
	{"NOTICEABLE", 10, 49040},
	{"CETTE", 5, 49041},
	{"AESTHETICS", 10, 49042},
	{"SCHWARZENEGGER", 14, 49043},
	{"TORV", 4, 49044},
	{"GDUR", 4, 49045},
	{"YKF", 3, 49046},
	{"SMOKER", 6, 49047},
	{"YHIL", 4, 49048},
	{"RYVI", 4, 49049},
	{"RYEL", 4, 49050},
	{"BENIGN", 6, 49051},
	{"HYPOTHESES", 10, 49052},
	{"AFFORDED", 8, 49053},
	{"DUNNO", 5, 49054},
	{"BLUR", 4, 49055},
	{"IDDA", 4, 49056},
	{"EVIDENTLY", 9, 49057},
	{"SUMMARIZES", 10, 49058},
	{"IEFR", 4, 49059},
	{"LIMBS", 5, 49060},
	{"YAVE", 4, 49061},
	{"ADYE", 4, 49062},
	{"UNFORGETTABLE", 13, 49063},
	{"PUNT", 4, 49064},
	{"SLUDGE", 6, 49065},
	{"CRYPTO", 6, 49066},
	{"FTRO", 4, 49067},
	{"CHRISTENSEN", 11, 49068},
	{"RBLE", 4, 49069},
	{"TANNED", 6, 49070},
	{"ALTERING", 8, 49071},
	{"INKM", 4, 49072},
	{"CALU", 4, 49073},
	{"BUNKER", 6, 49074},
	{"MPTA", 4, 49075},
	{"MULTIPLICATION", 14, 49076},
	{"FUNA", 4, 49077},
	{"PAVED", 5, 49078},
	{"HEAVYWEIGHT", 11, 49079},
	{"KCAN", 4, 49080},
	{"FABRICATED", 10, 49081},
	{"ZACH", 4, 49082},
	{"UTGR", 4, 49083},
	{"PDP", 3, 49084},
	{"ILDU", 4, 49085},
	{"PASTURE", 7, 49086},
	{"WNLI", 4, 49087},
	{"OCOP", 4, 49088},
	{"GLIG", 4, 49089},
	{"RTUE", 4, 49090},
	{"EAQU", 4, 49091},
	{"PHANTOMNODE", 11, 49092},
	{"KSPR", 4, 49093},
	{"RICHEST", 7, 49094},
	{"RSTV", 4, 49095},
	{"CRUELTY", 7, 49096},
	{"UBCO", 4, 49097},
	{"COMPTROLLER", 11, 49098},
	{"OFFP", 4, 49099},
	{"SCALABILITY", 11, 49100},
	{"CREATINE", 8, 49101},
	{"MORMON", 6, 49102},
	{"EMBL", 4, 49103},
	{"MINIMIZING", 10, 49104},
	{"LZL", 3, 49105},
	{"JYU", 3, 49106},
	{"SCOTS", 5, 49107},
	{"YLAU", 4, 49108},
	{"GENUINELY", 9, 49109},
	{"NCYP", 4, 49110},
	{"EAFL", 4, 49111},
	{"PHYO", 4, 49112},
	{"OOLG", 4, 49113},
	{"NEIGHBOURING", 12, 49114},
	{"PLUGGED", 7, 49115},
	{"TYSON", 5, 49116},
	{"SOUVENIR", 8, 49117},
	{"MIFFLIN", 7, 49118},
	{"RELATIVITY", 10, 49119},
	{"WNFA", 4, 49120},
	{"RGEE", 4, 49121},
	{"AFEM", 4, 49122},
	{"MOJO", 4, 49123},
	{"ECONO", 5, 49124},
	{"YBAT", 4, 49125},
	{"OCCURRENCES", 11, 49126},
	{"SHAPIRO", 7, 49127},
	{"MARSHAL", 7, 49128},
	{"RITUALS", 7, 49129},
	{"ANDERS", 6, 49130},
	{"DECISIVE", 8, 49131},
	{"SPAWN", 5, 49132},
	{"SHFR", 4, 49133},
	{"IRSQ", 4, 49134},
	{"EBYM", 4, 49135},
	{"BLANKS", 6, 49136},
	{"DUNGEONS", 8, 49137},
	{"UGGI", 4, 49138},
	{"EPOXY", 5, 49139},
	{"WATERCOLOR", 10, 49140},
	{"RGUN", 4, 49141},
	{"UNCENSORED", 10, 49142},
	{"SAILORS", 7, 49143},
	{"STONY", 5, 49144},
	{"UREU", 4, 49145},
	{"FAYETTE", 7, 49146},
	{"TRAINEES", 8, 49147},
	{"SHELVING", 8, 49148},
	{"EFFLUENT", 8, 49149},
	{"ANKB", 4, 49150},
	{"INFOUSA", 7, 49151},
	{"NSKY", 4, 49152},
	{"ANNALS", 6, 49153},
	{"STORYTELLING", 12, 49154},
	{"SADNESS", 7, 49155},
	{"HOFP", 4, 49156},
	{"PERIODICAL", 10, 49157},
	{"MPOW", 4, 49158},
	{"LRAI", 4, 49159},
	{"POLARIZATION", 12, 49160},
	{"KESF", 4, 49161},
	{"DIME", 4, 49162},
	{"LOSERS", 6, 49163},
	{"RDSU", 4, 49164},
	{"BOMBINGS", 8, 49165},
	{"PUNTA", 5, 49166},
	{"FLAVOUR", 7, 49167},
	{"IONAMIN", 7, 49168},
	{"CRYPT", 5, 49169},
	{"CHARLOTTESVILLE", 15, 49170},
	{"ONWARDS", 7, 49171},
	{"NOFK", 4, 49172},
	{"BOGUS", 5, 49173},
	{"CARP", 4, 49174},
	{"ANISTON", 7, 49175},
	{"PROMPTS", 7, 49176},
	{"LEEC", 4, 49177},
	{"WITCHES", 7, 49178},
	{"VELB", 4, 49179},
	{"BARRED", 6, 49180},
	{"SKINNER", 7, 49181},
	{"EQUITIES", 8, 49182},
	{"DUSK", 4, 49183},
	{"NOUVEAU", 7, 49184},
	{"CUSTOMARY", 9, 49185},
	{"VERTICALLY", 10, 49186},
	{"CRASHING", 8, 49187},
	{"RLAC", 4, 49188},
	{"CAUTIOUS", 8, 49189},
	{"POSSESSIONS", 11, 49190},
	{"FEEDERS", 7, 49191},
	{"ROFU", 4, 49192},
	{"KTOD", 4, 49193},
	{"CKDE", 4, 49194},
	{"URGING", 6, 49195},
	{"JBOSS", 5, 49196},
	{"LMTH", 4, 49197},
	{"MESY", 4, 49198},
	{"PASSIONS", 8, 49199},
	{"LREQ", 4, 49200},
	{"FADED", 5, 49201},
	{"LITU", 4, 49202},
	{"MOBIL", 5, 49203},
	{"LKST", 4, 49204},
	{"SCROLLING", 9, 49205},
	{"UTENSILS", 8, 49206},
	{"SECRETLY", 8, 49207},
	{"UTJU", 4, 49208},
	{"TYING", 5, 49209},
	{"RNEG", 4, 49210},
	{"CEOU", 4, 49211},
	{"DIODE", 5, 49212},
	{"KAUFMAN", 7, 49213},
	{"DGEB", 4, 49214},
	{"ELSU", 4, 49215},
	{"QDU", 3, 49216},
	{"MAGICIAN", 8, 49217},
	{"INDULGENCE", 10, 49218},
	{"IERP", 4, 49219},
	{"DBON", 4, 49220},
	{"CEVI", 4, 49221},
	{"JOHAN", 5, 49222},
	{"BUCKINGHAMSHIRE", 15, 49223},
	{"FASU", 4, 49224},
	{"MELTED", 6, 49225},
	{"LUND", 4, 49226},
	{"MEDFORD", 7, 49227},
	{"USAM", 4, 49228},
	{"EYRA", 4, 49229},
	{"LDID", 4, 49230},
	{"EXTREMES", 8, 49231},
	{"PUFF", 4, 49232},
	{"UNDERLINED", 10, 49233},
	{"WHORES", 6, 49234},
	{"GALILEO", 7, 49235},
	{"BLOOMFIELD", 10, 49236},
	{"PLEU", 4, 49237},
	{"OBSESSED", 8, 49238},
	{"FLAVORED", 8, 49239},
	{"FULR", 4, 49240},
	{"DIZE", 4, 49241},
	{"GEMSTONES", 9, 49242},
	{"VIEWPOINTS", 10, 49243},
	{"FPAT", 4, 49244},
	{"GHAV", 4, 49245},
	{"DGAI", 4, 49246},
	{"GROCERIES", 9, 49247},
	{"MOTTO", 5, 49248},
	{"OCKR", 4, 49249},
	{"EXIM", 4, 49250},
	{"SINGLED", 7, 49251},
	{"ALTON", 5, 49252},
	{"APPALACHIAN", 11, 49253},
	{"STAPLE", 6, 49254},
	{"NKEL", 4, 49255},
	{"CTBU", 4, 49256},
	{"PYRI", 4, 49257},
	{"DEALINGS", 8, 49258},
	{"MYHO", 4, 49259},
	{"PHILLIES", 8, 49260},
	{"UGIN", 4, 49261},
	{"PATHETIC", 8, 49262},
	{"RAMBLINGS", 9, 49263},
	{"CTPR", 4, 49264},
	{"EUSM", 4, 49265},
	{"WKIN", 4, 49266},
	{"JANIS", 5, 49267},
	{"CRAFTSMAN", 9, 49268},
	{"IRRITATION", 10, 49269},
	{"RULERS", 6, 49270},
	{"CENTRIC", 7, 49271},
	{"COLLISIONS", 10, 49272},
	{"GHEW", 4, 49273},
	{"ATUP", 4, 49274},
	{"MILITIA", 7, 49275},
	{"OPTIONALLY", 10, 49276},
	{"YISD", 4, 49277},
	{"GCOA", 4, 49278},
	{"AYGR", 4, 49279},
	{"CONSERVATORY", 12, 49280},
	{"LCHO", 4, 49281},
	{"LAWW", 4, 49282},
	{"NIGHTCLUB", 9, 49283},
	{"CROO", 4, 49284},
	{"BANANAS", 7, 49285},
	{"GEOPHYSICAL", 11, 49286},
	{"FICTIONAL", 9, 49287},
	{"ADHERENCE", 9, 49288},
	{"GOLFING", 7, 49289},
	{"DEFENDED", 8, 49290},
	{"RUBIN", 5, 49291},
	{"WOFO", 4, 49292},
	{"GONB", 4, 49293},
	{"HANDLERS", 8, 49294},
	{"NGID", 4, 49295},
	{"GRILLE", 6, 49296},
	{"ELISABETH", 9, 49297},
	{"CLAW", 4, 49298},
	{"PUSHES", 6, 49299},
	{"ALAIN", 5, 49300},
	{"FLAGSHIP", 8, 49301},
	{"KITTENS", 7, 49302},
	{"TOPEKA", 6, 49303},
	{"OPENOFFICE", 10, 49304},
	{"LUID", 4, 49305},
	{"IRLW", 4, 49306},
	{"ILLEGALLY", 9, 49307},
	{"POFC", 4, 49308},
	{"BUGZILLA", 8, 49309},
	{"DETER", 5, 49310},
	{"YFAN", 4, 49311},
	{"TYRE", 4, 49312},
	{"FURRY", 5, 49313},
	{"CUBES", 5, 49314},
	{"TRANSCRIBED", 11, 49315},
	{"URNB", 4, 49316},
	{"BOUNCING", 8, 49317},
	{"WAND", 4, 49318},
	{"LINUS", 5, 49319},
	{"KSOR", 4, 49320},
	{"MCSG", 4, 49321},
	{"HUMBOLDT", 8, 49322},
	{"SCARVES", 7, 49323},
	{"CAVALIER", 8, 49324},
	{"RIOL", 4, 49325},
	{"PSOM", 4, 49326},
	{"LPST", 4, 49327},
	{"EVEW", 4, 49328},
	{"RINSE", 5, 49329},
	{"OUTFITS", 7, 49330},
	{"CHARLTON", 8, 49331},
	{"REPERTOIRE", 10, 49332},
	{"RESPECTFULLY", 12, 49333},
	{"EMERITUS", 8, 49334},
	{"UORE", 4, 49335},
	{"ULSTER", 6, 49336},
	{"MACROECONOMIC", 13, 49337},
	{"TIDES", 5, 49338},
	{"TYFA", 4, 49339},
	{"NCHL", 4, 49340},
	{"LONC", 4, 49341},
	{"URGU", 4, 49342},
	{"WELD", 4, 49343},
	{"OBOF", 4, 49344},
	{"VENOM", 5, 49345},
	{"GUNDAM", 6, 49346},
	{"ADAPTEC", 7, 49347},
	{"WRIT", 4, 49348},
	{"PATAGONIA", 9, 49349},
	{"NCOD", 4, 49350},
	{"DISPENSING", 10, 49351},
	{"LORP", 4, 49352},
	{"TAILED", 6, 49353},
	{"PUPPETS", 7, 49354},
	{"ICFE", 4, 49355},
	{"VOYER", 5, 49356},
	{"WHYN", 4, 49357},
	{"KATR", 4, 49358},
	{"TAPPING", 7, 49359},
	{"HOSTNAME", 8, 49360},
	{"OPMA", 4, 49361},
	{"DDIA", 4, 49362},
	{"BYPL", 4, 49363},
	{"EXCL", 4, 49364},
	{"DGUN", 4, 49365},
	{"TYPO", 4, 49366},
	{"REXI", 4, 49367},
	{"GQUE", 4, 49368},
	{"RYGE", 4, 49369},
	{"MBOD", 4, 49370},
	{"ILEV", 4, 49371},
	{"IMMERSION", 9, 49372},
	{"TOULOUSE", 8, 49373},
	{"FQUE", 4, 49374},
	{"ROFJ", 4, 49375},
	{"DSUI", 4, 49376},
	{"ESCAPES", 7, 49377},
	{"BERRIES", 7, 49378},
	{"RKSS", 4, 49379},
	{"EPHR", 4, 49380},
	{"MERCHANTABILITY", 15, 49381},
	{"DPAU", 4, 49382},
	{"HAPPIER", 7, 49383},
	{"AUTODESK", 8, 49384},
	{"NBYH", 4, 49385},
	{"MUMMY", 5, 49386},
	{"UANG", 4, 49387},
	{"PUNJAB", 6, 49388},
	{"OTGU", 4, 49389},
	{"OMGO", 4, 49390},
	{"STACKED", 7, 49391},
	{"OBEV", 4, 49392},
	{"WINGED", 6, 49393},
	{"YONM", 4, 49394},
	{"IEFF", 4, 49395},
	{"BRIGHTER", 8, 49396},
	{"CRIES", 5, 49397},
	{"SPECIALITY", 10, 49398},
	{"WARRANTED", 9, 49399},
	{"ATTACKER", 8, 49400},
	{"PINM", 4, 49401},
	{"RUINED", 6, 49402},
	{"WNAR", 4, 49403},
	{"CATCHER", 7, 49404},
	{"DAMP", 4, 49405},
	{"SANITY", 6, 49406},
	{"LVEN", 4, 49407},
	{"LWAN", 4, 49408},
	{"YWOM", 4, 49409},
	{"ETHER", 5, 49410},
	{"SUCTION", 7, 49411},
	{"HAYNES", 6, 49412},
	{"OMGE", 4, 49413},
	{"CRUSADE", 7, 49414},
	{"SIYABONA", 8, 49415},
	{"RUMBLE", 6, 49416},
	{"INVERTER", 8, 49417},
	{"CORRECTING", 10, 49418},
	{"SHATTERED", 9, 49419},
	{"HEROIC", 6, 49420},
	{"SCIR", 4, 49421},
	{"RETREATS", 8, 49422},
	{"MACKAY", 6, 49423},
	{"FORMULATE", 9, 49424},
	{"PCAN", 4, 49425},
	{"BRIDGEPORT", 10, 49426},
	{"ASSESSOR", 8, 49427},
	{"FULLERTON", 9, 49428},
	{"UMAB", 4, 49429},
	{"CPP", 3, 49430},
	{"SHEDS", 5, 49431},
	{"BLOCKBUSTER", 11, 49432},
	{"FAVR", 4, 49433},
	{"AMARILLO", 8, 49434},
	{"PIXMANIA", 8, 49435},
	{"PATHFINDER", 10, 49436},
	{"ANOMALIES", 9, 49437},
	{"LLFU", 4, 49438},
	{"ONYW", 4, 49439},
	{"BONSAI", 6, 49440},
	{"WINDSHIELD", 10, 49441},
	{"IFYA", 4, 49442},
	{"GONF", 4, 49443},
	{"ELFP", 4, 49444},
	{"HUMPHREY", 8, 49445},
	{"SPHERES", 7, 49446},
	{"BELONGED", 8, 49447},
	{"TOMTOM", 6, 49448},
	{"ASSIGNS", 7, 49449},
	{"CROYDON", 7, 49450},
	{"SOFAS", 5, 49451},
	{"CROIX", 5, 49452},
	{"VEJO", 4, 49453},
	{"FSPR", 4, 49454},
	{"CUSHIONS", 8, 49455},
	{"FERN", 4, 49456},
	{"RORW", 4, 49457},
	{"DLYW", 4, 49458},
	{"CONVECTION", 10, 49459},
	{"JDBC", 4, 49460},
	{"YEQU", 4, 49461},
	{"OFIV", 4, 49462},
	{"DEFENDERS", 9, 49463},
	{"DEBUGGER", 8, 49464},
	{"LPOR", 4, 49465},
	{"BOING", 5, 49466},
	{"EWIF", 4, 49467},
	{"ODESSA", 6, 49468},
	{"CFRO", 4, 49469},
	{"OTPU", 4, 49470},
	{"LCLO", 4, 49471},
	{"ERTC", 4, 49472},
	{"LORE", 4, 49473},
	{"RUNH", 4, 49474},
	{"YACR", 4, 49475},
	{"ANCILLARY", 9, 49476},
	{"POINTLESS", 9, 49477},
	{"WHIPPED", 7, 49478},
	{"ALAX", 4, 49479},
	{"ALIBRIS", 7, 49480},
	{"ALLJ", 4, 49481},
	{"DINNERS", 7, 49482},
	{"VOLC", 4, 49483},
	{"USQU", 4, 49484},
	{"ROSIE", 5, 49485},
	{"FACTORING", 9, 49486},
	{"GENEALOGICAL", 12, 49487},
	{"UTAW", 4, 49488},
	{"RMSH", 4, 49489},
	{"OOKR", 4, 49490},
	{"GYMS", 4, 49491},
	{"INHALATION", 10, 49492},
	{"TERRE", 5, 49493},
	{"SELFISH", 7, 49494},
	{"MALW", 4, 49495},
	{"EVENTUAL", 8, 49496},
	{"FROZ", 4, 49497},
	{"KEFI", 4, 49498},
	{"FAUCET", 6, 49499},
	{"RLDF", 4, 49500},
	{"ILIG", 4, 49501},
	{"CKDR", 4, 49502},
	{"MITIGATE", 8, 49503},
	{"ARSY", 4, 49504},
	{"BITPIPE", 7, 49505},
	{"JAMESTOWN", 9, 49506},
	{"ARGUABLY", 8, 49507},
	{"TECHS", 5, 49508},
	{"ELECTIVES", 9, 49509},
	{"WALKMAN", 7, 49510},
	{"UEBA", 4, 49511},
	{"MLON", 4, 49512},
	{"USLO", 4, 49513},
	{"MHOM", 4, 49514},
	{"MIDGET", 6, 49515},
	{"ELISA", 5, 49516},
	{"SHELTON", 7, 49517},
	{"IWER", 4, 49518},
	{"QUAN", 4, 49519},
	{"BOILED", 6, 49520},
	{"COMMISSIONING", 13, 49521},
	{"CERY", 4, 49522},
	{"NEVILLE", 7, 49523},
	{"DSUF", 4, 49524},
	{"EXPERIMENTATION", 15, 49525},
	{"YFOC", 4, 49526},
	{"WPRE", 4, 49527},
	{"SALTWATER", 9, 49528},
	{"NATASHA", 7, 49529},
	{"AZED", 4, 49530},
	{"ENDEAVOUR", 9, 49531},
	{"RGAL", 4, 49532},
	{"ROSWELL", 7, 49533},
	{"HAUTE", 5, 49534},
	{"ODLA", 4, 49535},
	{"FKV", 3, 49536},
	{"ULYI", 4, 49537},
	{"HERRING", 7, 49538},
	{"TDEB", 4, 49539},
	{"YORM", 4, 49540},
	{"UNFAMILIAR", 10, 49541},
	{"WACKY", 5, 49542},
	{"EXPECTANCY", 10, 49543},
	{"RLOA", 4, 49544},
	{"DETERIORATION", 13, 49545},
	{"SGML", 4, 49546},
	{"NMUL", 4, 49547},
	{"POFP", 4, 49548},
	{"PROCLAIMED", 10, 49549},
	{"ARID", 4, 49550},
	{"ANEMIA", 6, 49551},
	{"LDVE", 4, 49552},
	{"BITING", 6, 49553},
	{"PYWI", 4, 49554},
	{"COINCIDENCE", 11, 49555},
	{"IDIOTS", 6, 49556},
	{"IDPE", 4, 49557},
	{"REITS", 5, 49558},
	{"MUDDY", 5, 49559},
	{"OWPO", 4, 49560},
	{"NUEVO", 5, 49561},
	{"OMJA", 4, 49562},
	{"SAVANNA", 7, 49563},
	{"GNOW", 4, 49564},
	{"HITCHCOCK", 9, 49565},
	{"DBUL", 4, 49566},
	{"TRAVESTIS", 9, 49567},
	{"CYRE", 4, 49568},
	{"IROR", 4, 49569},
	{"TGOM", 4, 49570},
	{"OMTR", 4, 49571},
	{"NEIGHBOUR", 9, 49572},
	{"NMEX", 4, 49573},
	{"MMF", 3, 49574},
	{"OFKM", 4, 49575},
	{"RASPBERRY", 9, 49576},
	{"CANCELLATIONS", 13, 49577},
	{"PAGING", 6, 49578},
	{"BBIT", 4, 49579},
	{"VEBY", 4, 49580},
	{"OMAJ", 4, 49581},
	{"NUDISTS", 7, 49582},
	{"ILLUSIONS", 9, 49583},
	{"SPIKES", 6, 49584},
	{"ULIK", 4, 49585},
	{"AIRSOFT", 7, 49586},
	{"RDNO", 4, 49587},
	{"GHDA", 4, 49588},
	{"BONTRIL", 7, 49589},
	{"RDEE", 4, 49590},
	{"GLYS", 4, 49591},
	{"ENUMERATION", 11, 49592},
	{"PROLIANT", 8, 49593},
	{"KEELING", 7, 49594},
	{"DORW", 4, 49595},
	{"ACCESSES", 8, 49596},
	{"SUCHE", 5, 49597},
	{"PERMISSIBLE", 11, 49598},
	{"EXTC", 4, 49599},
	{"YIELDED", 7, 49600},
	{"WNMO", 4, 49601},
	{"NUISANCE", 8, 49602},
	{"JIVE", 4, 49603},
	{"LATENT", 6, 49604},
	{"DAFU", 4, 49605},
	{"YEDM", 4, 49606},
	{"MARCIA", 6, 49607},
	{"MOGR", 4, 49608},
	{"DROWNING", 8, 49609},
	{"CASPER", 6, 49610},
	{"SPUN", 4, 49611},
	{"SHALT", 5, 49612},
	{"USBO", 4, 49613},
	{"LIBSTDC", 7, 49614},
	{"LOCH", 4, 49615},
	{"LEEL", 4, 49616},
	{"COMMANDING", 10, 49617},
	{"NCEV", 4, 49618},
	{"SPARROW", 7, 49619},
	{"POOREST", 7, 49620},
	{"BLYF", 4, 49621},
	{"HECTOR", 6, 49622},
	{"XPRESS", 6, 49623},
	{"DATASETS", 8, 49624},
	{"WEBDESIGN", 9, 49625},
	{"NICOTINE", 8, 49626},
	{"OFIC", 4, 49627},
	{"YKEE", 4, 49628},
	{"COMEBACK", 8, 49629},
	{"BROTHERHOOD", 11, 49630},
	{"HDRE", 4, 49631},
	{"GANNETT", 7, 49632},
	{"MILLING", 7, 49633},
	{"HOWG", 4, 49634},
	{"SINKING", 7, 49635},
	{"SULPHUR", 7, 49636},
	{"CURRICULAR", 10, 49637},
	{"DOWNTIME", 8, 49638},
	{"TAKEOVER", 8, 49639},
	{"EEKD", 4, 49640},
	{"ANKC", 4, 49641},
	{"WICKER", 6, 49642},
	{"ORUP", 4, 49643},
	{"BALM", 4, 49644},
	{"UEMA", 4, 49645},
	{"THESSALONIANS", 13, 49646},
	{"FIGS", 4, 49647},
	{"UPTO", 4, 49648},
	{"BROWNE", 6, 49649},
	{"NEPHEW", 6, 49650},
	{"JOAQUIN", 7, 49651},
	{"UESB", 4, 49652},
	{"HDEP", 4, 49653},
	{"CHAOTIC", 7, 49654},
	{"ALEXANDRE", 9, 49655},
	{"LAYS", 4, 49656},
	{"PRINCIPALLY", 11, 49657},
	{"ELGR", 4, 49658},
	{"VISOR", 5, 49659},
	{"MUNDO", 5, 49660},
	{"TRANSISTOR", 10, 49661},
	{"BYEX", 4, 49662},
	{"OCKD", 4, 49663},
	{"JARVIS", 6, 49664},
	{"DRIP", 4, 49665},
	{"RNWI", 4, 49666},
	{"TRACED", 6, 49667},
	{"OUTRIGHT", 8, 49668},
	{"LSDO", 4, 49669},
	{"LYOW", 4, 49670},
	{"ICKD", 4, 49671},
	{"MELODIES", 8, 49672},
	{"SPOTTING", 8, 49673},
	{"YWV", 3, 49674},
	{"VRW", 3, 49675},
	{"UUJ", 3, 49676},
	{"DXV", 3, 49677},
	{"MYRIAD", 6, 49678},
	{"STAINS", 6, 49679},
	{"WEAV", 4, 49680},
	{"SANDAL", 6, 49681},
	{"RUBBING", 7, 49682},
	{"NAIVE", 5, 49683},
	{"NCIR", 4, 49684},
	{"SKEPTICAL", 9, 49685},
	{"WAGERING", 8, 49686},
	{"REMEMBRANCE", 11, 49687},
	{"KENY", 4, 49688},
	{"DETECTS", 7, 49689},
	{"CKBR", 4, 49690},
	{"EVEREST", 7, 49691},
	{"DISREGARD", 9, 49692},
	{"HANGER", 6, 49693},
	{"OUTKAST", 7, 49694},
	{"DPUL", 4, 49695},
	{"DRAGGED", 7, 49696},
	{"PITBULL", 7, 49697},
	{"LQUE", 4, 49698},
	{"FOREMAN", 7, 49699},
	{"ALLEGIANCE", 10, 49700},
	{"UZK", 3, 49701},
	{"GUPI", 4, 49702},
	{"FAIRVIEW", 8, 49703},
	{"HIRES", 5, 49704},
	{"CONDUIT", 7, 49705},
	{"ALIENWARE", 9, 49706},
	{"DEPENDABLE", 10, 49707},
	{"MAINFRAME", 9, 49708},
	{"ECHOES", 6, 49709},
	{"COMPILERS", 9, 49710},
	{"LADDERS", 7, 49711},
	{"PRUDENT", 7, 49712},
	{"GLOWING", 7, 49713},
	{"GUINNESS", 8, 49714},
	{"HEARTBEAT", 9, 49715},
	{"IGUA", 4, 49716},
	{"BLAZER", 6, 49717},
	{"ALCHEMY", 7, 49718},
	{"VIBR", 4, 49719},
	{"UMPO", 4, 49720},
	{"LINDEN", 6, 49721},
	{"GCRI", 4, 49722},
	{"TIMEZONE", 8, 49723},
	{"MERCK", 5, 49724},
	{"LALW", 4, 49725},
	{"TANYA", 5, 49726},
	{"GEOGRAPHICALLY", 14, 49727},
	{"ODYB", 4, 49728},
	{"BMC", 3, 49729},
	{"ALTERNATING", 11, 49730},
	{"TRISTAN", 7, 49731},
	{"AUDIBLE", 7, 49732},
	{"KEYC", 4, 49733},
	{"FOLIO", 5, 49734},
	{"PRESIDING", 9, 49735},
	{"NEFL", 4, 49736},
	{"COLLEEN", 7, 49737},
	{"UDID", 4, 49738},
	{"BBBONLINE", 9, 49739},
	{"GFAM", 4, 49740},
	{"PARTICIPATES", 12, 49741},
	{"WATERWAYS", 9, 49742},
	{"SYNDICATED", 10, 49743},
	{"LEXICON", 7, 49744},
	{"RNSW", 4, 49745},
	{"LOUN", 4, 49746},
	{"LPTO", 4, 49747},
	{"FRACTURES", 9, 49748},
	{"APPRENTICESHIP", 14, 49749},
	{"ACTP", 4, 49750},
	{"CHILDBIRTH", 10, 49751},
	{"KBAN", 4, 49752},
	{"INWR", 4, 49753},
	{"DUMPED", 6, 49754},
	{"INTEGERS", 8, 49755},
	{"ARYJ", 4, 49756},
	{"ZIRCONIA", 8, 49757},
	{"BARRE", 5, 49758},
	{"ADYD", 4, 49759},
	{"SHORTAGES", 9, 49760},
	{"FREV", 4, 49761},
	{"ARKD", 4, 49762},
	{"PLUMBERS", 8, 49763},
	{"RAMA", 4, 49764},
	{"YFUL", 4, 49765},
	{"ORIV", 4, 49766},
	{"JOHANNES", 8, 49767},
	{"FIERY", 5, 49768},
	{"CONVEX", 6, 49769},
	{"UWJ", 3, 49770},
	{"JFK", 3, 49771},
	{"RICHER", 6, 49772},
	{"IGOR", 4, 49773},
	{"CEFE", 4, 49774},
	{"RGUS", 4, 49775},
	{"YGAR", 4, 49776},
	{"SOLEIL", 6, 49777},
	{"PATTON", 6, 49778},
	{"SURFER", 6, 49779},
	{"DIAPERS", 7, 49780},
	{"HTPR", 4, 49781},
	{"WACO", 4, 49782},
	{"PHYSIOL", 7, 49783},
	{"CONNOR", 6, 49784},
	{"HLYS", 4, 49785},
	{"EUSW", 4, 49786},
	{"NORTHAMPTONSHIRE", 16, 49787},
	{"YRAM", 4, 49788},
	{"TMAG", 4, 49789},
	{"BISCUITS", 8, 49790},
	{"TJAM", 4, 49791},
	{"DISCLAIMS", 9, 49792},
	{"GALC", 4, 49793},
	{"GGAR", 4, 49794},
	{"OUTBOUND", 8, 49795},
	{"EEPY", 4, 49796},
	{"BREAKOUT", 8, 49797},
	{"RESTLESS", 8, 49798},
	{"SKIC", 4, 49799},
	{"OMJU", 4, 49800},
	{"IDSP", 4, 49801},
	{"UNANSWERED", 10, 49802},
	{"PAIRED", 6, 49803},
	{"UARI", 4, 49804},
	{"LADM", 4, 49805},
	{"EUNF", 4, 49806},
	{"FAKES", 5, 49807},
	{"STDERR", 6, 49808},
	{"EFFR", 4, 49809},
	{"FOMIT", 5, 49810},
	{"VAULTS", 6, 49811},
	{"LDAG", 4, 49812},
	{"TECR", 4, 49813},
	{"INJECTIONS", 10, 49814},
	{"AHMAD", 5, 49815},
	{"REMORTGAGE", 10, 49816},
	{"RROT", 4, 49817},
	{"RGUY", 4, 49818},
	{"STDU", 4, 49819},
	{"YOGURT", 6, 49820},
	{"COMPLIES", 8, 49821},
	{"TOSSED", 6, 49822},
	{"CAUCUS", 6, 49823},
	{"WORKAROUND", 10, 49824},
	{"MAVE", 4, 49825},
	{"BOXO", 4, 49826},
	{"LGIA", 4, 49827},
	{"MHIM", 4, 49828},
	{"MERN", 4, 49829},
	{"MBEA", 4, 49830},
	{"LVIC", 4, 49831},
	{"COOKE", 5, 49832},
	{"POLYTECHNIC", 11, 49833},
	{"PILLARS", 7, 49834},
	{"KATY", 4, 49835},
	{"EERP", 4, 49836},
	{"UBER", 4, 49837},
	{"OVERWHELMED", 11, 49838},
	{"ACKJ", 4, 49839},
	{"SALUTE", 6, 49840},
	{"SHOPPE", 6, 49841},
	{"OOKD", 4, 49842},
	{"PARODY", 6, 49843},
	{"BEVI", 4, 49844},
	{"BERLIOS", 7, 49845},
	{"LOFU", 4, 49846},
	{"UEDO", 4, 49847},
	{"NEMB", 4, 49848},
	{"UALH", 4, 49849},
	{"RYCR", 4, 49850},
	{"RIAM", 4, 49851},
	{"ILMF", 4, 49852},
	{"PENTHOUSE", 9, 49853},
	{"COMPENSATED", 11, 49854},
	{"SYNTHASE", 8, 49855},
	{"CTSM", 4, 49856},
	{"GEFA", 4, 49857},
	{"SGUA", 4, 49858},
	{"LACKED", 6, 49859},
	{"CIRCULATED", 10, 49860},
	{"URGL", 4, 49861},
	{"CCHI", 4, 49862},
	{"NICM", 4, 49863},
	{"PISTONS", 7, 49864},
	{"BYOT", 4, 49865},
	{"TVOL", 4, 49866},
	{"CKAB", 4, 49867},
	{"EMULE", 5, 49868},
	{"MALTESE", 7, 49869},
	{"SAUVIGNON", 9, 49870},
	{"LARU", 4, 49871},
	{"UMBR", 4, 49872},
	{"URUN", 4, 49873},
	{"RTFI", 4, 49874},
	{"ACORN", 5, 49875},
	{"BOSSES", 6, 49876},
	{"ASCENSION", 9, 49877},
	{"BAYER", 5, 49878},
	{"SGRI", 4, 49879},
	{"CARRERA", 7, 49880},
	{"PLY", 3, 49881},
	{"RTSR", 4, 49882},
	{"YXW", 3, 49883},
	{"XYU", 3, 49884},
	{"XXB", 3, 49885},
	{"MORNINGS", 8, 49886},
	{"SFED", 4, 49887},
	{"OUWH", 4, 49888},
	{"XWIT", 4, 49889},
	{"DVB", 3, 49890},
	{"YASC", 4, 49891},
	{"LSMI", 4, 49892},
	{"CATION", 6, 49893},
	{"MENTIONING", 10, 49894},
	{"YPAC", 4, 49895},
	{"SCIENTOLOGY", 11, 49896},
	{"CDMA", 4, 49897},
	{"SLYC", 4, 49898},
	{"FLAGSTAFF", 9, 49899},
	{"MAXI", 4, 49900},
	{"OUSV", 4, 49901},
	{"PRETORIA", 8, 49902},
	{"MARB", 4, 49903},
	{"FEMINISM", 8, 49904},
	{"RIGHTLY", 7, 49905},
	{"PARAGON", 7, 49906},
	{"OWGO", 4, 49907},
	{"OVAK", 4, 49908},
	{"BASAL", 5, 49909},
	{"TOPPS", 5, 49910},
	{"WEBINAR", 7, 49911},
	{"FEDI", 4, 49912},
	{"ARIM", 4, 49913},
	{"DEWALT", 6, 49914},
	{"TURNOUT", 7, 49915},
	{"BRUINS", 6, 49916},
	{"ARDJ", 4, 49917},
	{"WILDE", 5, 49918},
	{"INDISPENSABLE", 13, 49919},
	{"SRAR", 4, 49920},
	{"CLAMPS", 6, 49921},
	{"TWHY", 4, 49922},
	{"ILLICIT", 7, 49923},
	{"FIREFLY", 7, 49924},
	{"LIAR", 4, 49925},
	{"DMUN", 4, 49926},
	{"OWHY", 4, 49927},
	{"NUPA", 4, 49928},
	{"MBEL", 4, 49929},
	{"TABLETOP", 8, 49930},
	{"VEVE", 4, 49931},
	{"PLEDGED", 7, 49932},
	{"MONOCLONAL", 10, 49933},
	{"PICTORIAL", 9, 49934},
	{"CURLING", 7, 49935},
	{"DMAJ", 4, 49936},
	{"TYEX", 4, 49937},
	{"MINW", 4, 49938},
	{"WHOLESALER", 10, 49939},
	{"SMOKY", 5, 49940},
	{"OPUS", 4, 49941},
	{"IERD", 4, 49942},
	{"FEFO", 4, 49943},
	{"DPIN", 4, 49944},
	{"BYRI", 4, 49945},
	{"TYPEKEY", 7, 49946},
	{"AROMATIC", 8, 49947},
	{"FLIRT", 5, 49948},
	{"SLANG", 5, 49949},
	{"EMPORIUM", 8, 49950},
	{"PRINCES", 7, 49951},
	{"RESTRICTING", 11, 49952},
	{"MALF", 4, 49953},
	{"PARTNERING", 10, 49954},
	{"PROMOTERS", 9, 49955},
	{"SOOTHING", 8, 49956},
	{"FRESHMEN", 8, 49957},
	{"MAGE", 4, 49958},
	{"DEPARTED", 8, 49959},
	{"SQRT", 4, 49960},
	{"EXCA", 4, 49961},
	{"ARISTOTLE", 9, 49962},
	{"ISRAELIS", 8, 49963},
	{"FINCH", 5, 49964},
	{"FIBE", 4, 49965},
	{"INHERENTLY", 10, 49966},
	{"UNKS", 4, 49967},
	{"CDP", 3, 49968},
	{"KRISHNA", 7, 49969},
	{"FOREFRONT", 9, 49970},
	{"HEADLIGHTS", 10, 49971},
	{"YESP", 4, 49972},
	{"MONOPHONIC", 10, 49973},
	{"LARGO", 5, 49974},
	{"PROQUEST", 8, 49975},
	{"AMAZINGLY", 9, 49976},
	{"PLURAL", 6, 49977},
	{"EPTW", 4, 49978},
	{"RTOK", 4, 49979},
	{"DOMINIC", 7, 49980},
	{"SERGIO", 6, 49981},
	{"SWAPPING", 8, 49982},
	{"SKIPPED", 7, 49983},
	{"HEREINAFTER", 11, 49984},
	{"NBYC", 4, 49985},
	{"YWRO", 4, 49986},
	{"EXTRACTING", 10, 49987},
	{"ANALOGOUS", 9, 49988},
	{"HEBREWS", 7, 49989},
	{"PARTICULATE", 11, 49990},
	{"TALLY", 5, 49991},
	{"UNPLEASANT", 10, 49992},
	{"DTEM", 4, 49993},
	{"TEMPTED", 7, 49994},
	{"BEDFORDSHIRE", 12, 49995},
	{"BLINDNESS", 9, 49996},
	{"CREEP", 5, 49997},
	{"STAINING", 8, 49998},
	{"ROCKPORT", 8, 49999},
	{"NPAP", 4, 50000},
	{"SHADED", 6, 50001},
	{"UBTE", 4, 50002},
	{"PLASTER", 7, 50003},
	{"UPSW", 4, 50004},
	{"NEGOTIABLE", 10, 50005},
	{"SUBCATEGORIES", 13, 50006},
	{"HEARTED", 7, 50007},
	{"YEXI", 4, 50008},
	{"OBSTRUCTION", 11, 50009},
	{"AGILITY", 7, 50010},
	{"COMPLYING", 9, 50011},
	{"ERMR", 4, 50012},
	{"SUDBURY", 7, 50013},
	{"OVERTURE", 8, 50014},
	{"NEWCOMERS", 9, 50015},
	{"HECTARES", 8, 50016},
	{"GBRE", 4, 50017},
	{"UPSCALE", 7, 50018},
	{"TEMM", 4, 50019},
	{"SCRABBLE", 8, 50020},
	{"NOTEWORTHY", 10, 50021},
	{"AGILE", 5, 50022},
	{"WMIN", 4, 50023},
	{"DFED", 4, 50024},
	{"SACKS", 5, 50025},
	{"DOCBOOK", 7, 50026},
	{"DEOC", 4, 50027},
	{"KIOSK", 5, 50028},
	{"IONIC", 5, 50029},
	{"ALFB", 4, 50030},
	{"URYP", 4, 50031},
	{"NMYS", 4, 50032},
	{"STRAY", 5, 50033},
	{"RUNAWAY", 7, 50034},
	{"SLOWING", 7, 50035},
	{"FIRSTGOV", 8, 50036},
	{"OMYT", 4, 50037},
	{"AKDO", 4, 50038},
	{"HOODIE", 6, 50039},
	{"LEMT", 4, 50040},
	{"MGRE", 4, 50041},
	{"HOODIA", 6, 50042},
	{"PAYOUT", 6, 50043},
	{"RKHE", 4, 50044},
	{"LMSA", 4, 50045},
	{"CLINICALLY", 10, 50046},
	{"WATCHERS", 8, 50047},
	{"SLYD", 4, 50048},
	{"DCUS", 4, 50049},
	{"SUPPLEMENTED", 12, 50050},
	{"POPPY", 5, 50051},
	{"GHPE", 4, 50052},
	{"MONMOUTH", 8, 50053},
	{"METACRITIC", 10, 50054},
	{"OBLIGATED", 9, 50055},
	{"FRENZY", 6, 50056},
	{"DECODING", 8, 50057},
	{"PLYS", 4, 50058},
	{"JARGON", 6, 50059},
	{"IFED", 4, 50060},
	{"KANGAROO", 8, 50061},
	{"SLEEPER", 7, 50062},
	{"ELEMENTAL", 9, 50063},
	{"PRESENTERS", 10, 50064},
	{"TSDR", 4, 50065},
	{"OMFA", 4, 50066},
	{"UNNAMED", 7, 50067},
	{"EPSTEIN", 7, 50068},
	{"LYSW", 4, 50069},
	{"DONCASTER", 9, 50070},
	{"PARTICULARS", 11, 50071},
	{"JERKING", 7, 50072},
	{"WEBLOGIC", 8, 50073},
	{"BUNGALOW", 8, 50074},
	{"COVINGTON", 9, 50075},
	{"BAZAAR", 6, 50076},
	{"INTERCONNECT", 12, 50077},
	{"PREDICATE", 9, 50078},
	{"RECURRENCE", 10, 50079},
	{"CHINATOWN", 9, 50080},
	{"MINDLESS", 8, 50081},
	{"PURIFIER", 8, 50082},
	{"RECRUITS", 8, 50083},
	{"SHARPER", 7, 50084},
	{"RGIC", 4, 50085},
	{"AROB", 4, 50086},
	{"TABLESPOONS", 11, 50087},
	{"EBOB", 4, 50088},
	{"ADGR", 4, 50089},
	{"GREEDY", 6, 50090},
	{"RODGERS", 7, 50091},
	{"VISC", 4, 50092},
	{"NKOR", 4, 50093},
	{"DADR", 4, 50094},
	{"PCZ", 3, 50095},
	{"DZB", 3, 50096},
	{"GLORYHOLE", 9, 50097},
	{"ARMW", 4, 50098},
	{"SUPERVISE", 9, 50099},
	{"BYCR", 4, 50100},
	{"OGOF", 4, 50101},
	{"TERMED", 6, 50102},
	{"FRAUEN", 6, 50103},
	{"SUPPL", 5, 50104},
	{"UMWH", 4, 50105},
	{"STAMPING", 8, 50106},
	{"COOLEST", 7, 50107},
	{"MYPR", 4, 50108},
	{"REILLY", 6, 50109},
	{"HOTJOBS", 7, 50110},
	{"DOWNING", 7, 50111},
	{"LIBC", 4, 50112},
	{"BASQUE", 6, 50113},
	{"SOCIETAL", 8, 50114},
	{"ASTROS", 6, 50115},
	{"HALOGEN", 7, 50116},
	{"UUW", 3, 50117},
	{"QMY", 3, 50118},
	{"KLYT", 4, 50119},
	{"PEGASUS", 7, 50120},
	{"DUBL", 4, 50121},
	{"SILHOUETTE", 10, 50122},
	{"WYNDHAM", 7, 50123},
	{"TUESDAYS", 8, 50124},
	{"DORADO", 6, 50125},
	{"DARING", 6, 50126},
	{"REALMS", 6, 50127},
	{"TLYG", 4, 50128},
	{"RSCE", 4, 50129},
	{"MAESTRO", 7, 50130},
	{"TURIN", 5, 50131},
	{"NELW", 4, 50132},
	{"BYDR", 4, 50133},
	{"SUPERPAGES", 10, 50134},
	{"FORTE", 5, 50135},
	{"COAXIAL", 7, 50136},
	{"TIPPING", 7, 50137},
	{"JPY", 3, 50138},
	{"IDEG", 4, 50139},
	{"HOLSTER", 7, 50140},
	{"FIDDLE", 6, 50141},
	{"DGON", 4, 50142},
	{"CRUNCH", 6, 50143},
	{"UGOT", 4, 50144},
	{"LEIPZIG", 7, 50145},
	{"LIAM", 4, 50146},
	{"SLYB", 4, 50147},
	{"DYSH", 4, 50148},
	{"BARD", 4, 50149},
	{"KELLOGG", 7, 50150},
	{"ARABIDOPSIS", 11, 50151},
	{"REAP", 4, 50152},
	{"URYH", 4, 50153},
	{"ARGV", 4, 50154},
	{"OMYW", 4, 50155},
	{"WEGI", 4, 50156},
	{"BEEV", 4, 50157},
	{"CCM", 3, 50158},
	{"OGOV", 4, 50159},
	{"FAUCETS", 7, 50160},
	{"BALLISTIC", 9, 50161},
	{"CKYO", 4, 50162},
	{"EXEMPLARY", 9, 50163},
	{"PAYOUTS", 7, 50164},
	{"ROCKIN", 6, 50165},
	{"CALIBER", 7, 50166},
	{"ILAF", 4, 50167},
	{"DISW", 4, 50168},
	{"APOSTLE", 7, 50169},
	{"PLAYFUL", 7, 50170},
	{"EPIP", 4, 50171},
	{"SUPERMARKETS", 12, 50172},
	{"BMG", 3, 50173},
	{"DWAI", 4, 50174},
	{"ICELANDIC", 9, 50175},
	{"LNOR", 4, 50176},
	{"MULTIPLIED", 10, 50177},
	{"ENCHANTED", 9, 50178},
	{"BELGRADE", 8, 50179},
	{"KLET", 4, 50180},
	{"STYLED", 6, 50181},
	{"NACIONAL", 8, 50182},
	{"COMMANDERS", 10, 50183},
	{"TELSTRA", 7, 50184},
	{"WAIVE", 5, 50185},
	{"CONTRACEPTION", 13, 50186},
	{"BETHANY", 7, 50187},
	{"POLAROID", 8, 50188},
	{"VANCE", 5, 50189},
	{"SOPRANO", 7, 50190},
	{"POLISHING", 9, 50191},
	{"URAI", 4, 50192},
	{"MARQUIS", 7, 50193},
	{"NVOY", 4, 50194},
	{"UDYA", 4, 50195},
	{"UNDERAGE", 8, 50196},
	{"CARDIO", 6, 50197},
	{"LDOE", 4, 50198},
	{"TRANSLATING", 11, 50199},
	{"URBR", 4, 50200},
	{"KMON", 4, 50201},
	{"TBAD", 4, 50202},
	{"LLMY", 4, 50203},
	{"OMGR", 4, 50204},
	{"IORG", 4, 50205},
	{"AUBU", 4, 50206},
	{"OUDA", 4, 50207},
	{"FRONTIERS", 9, 50208},
	{"ELPM", 4, 50209},
	{"TIMESHARES", 10, 50210},
	{"FATR", 4, 50211},
	{"LUEB", 4, 50212},
	{"DSAG", 4, 50213},
	{"YNOM", 4, 50214},
	{"RDLO", 4, 50215},
	{"LOGGER", 6, 50216},
	{"WNPO", 4, 50217},
	{"ADJOINING", 9, 50218},
	{"RALU", 4, 50219},
	{"VEDL", 4, 50220},
	{"ACCLAIM", 7, 50221},
	{"IORF", 4, 50222},
	{"KOOL", 4, 50223},
	{"VALC", 4, 50224},
	{"IARW", 4, 50225},
	{"BIRDING", 7, 50226},
	{"PTOW", 4, 50227},
	{"HARDSHIP", 8, 50228},
	{"DETAINEES", 9, 50229},
	{"SIXW", 4, 50230},
	{"LYMPH", 5, 50231},
	{"DNEX", 4, 50232},
	{"BARRIE", 6, 50233},
	{"POLLUTANT", 9, 50234},
	{"KOFE", 4, 50235},
	{"CLOSEOUTS", 9, 50236},
	{"YISF", 4, 50237},
	{"MIRIAM", 6, 50238},
	{"ORIL", 4, 50239},
	{"OPYR", 4, 50240},
	{"CAVALIERS", 9, 50241},
	{"ROLLERS", 7, 50242},
	{"CARLETON", 8, 50243},
	{"PUMPED", 6, 50244},
	{"WOCA", 4, 50245},
	{"UYWH", 4, 50246},
	{"EWBE", 4, 50247},
	{"TOLKIEN", 7, 50248},
	{"DIFFERENTIATED", 14, 50249},
	{"NJOU", 4, 50250},
	{"UNDP", 4, 50251},
	{"VERIFYING", 9, 50252},
	{"JBL", 3, 50253},
	{"ALMIGHTY", 8, 50254},
	{"LHOW", 4, 50255},
	{"YSBA", 4, 50256},
	{"WEEKDAY", 7, 50257},
	{"YXP", 3, 50258},
	{"GXR", 3, 50259},
	{"HOMECOMING", 10, 50260},
	{"EWTR", 4, 50261},
	{"INCREMENTS", 10, 50262},
	{"KURDISH", 7, 50263},
	{"INTUITION", 9, 50264},
	{"TUGA", 4, 50265},
	{"REVOKED", 7, 50266},
	{"WAYR", 4, 50267},
	{"NGKE", 4, 50268},
	{"OPENNESS", 8, 50269},
	{"CHROMIUM", 8, 50270},
	{"CIRCULATING", 11, 50271},
	{"EWFA", 4, 50272},
	{"YEME", 4, 50273},
	{"BRYCE", 5, 50274},
	{"GNAM", 4, 50275},
	{"LATCH", 5, 50276},
	{"MCCORMICK", 9, 50277},
	{"CIER", 4, 50278},
	{"VERBS", 5, 50279},
	{"ISUR", 4, 50280},
	{"DRANK", 5, 50281},
	{"NEYL", 4, 50282},
	{"EFOX", 4, 50283},
	{"BCON", 4, 50284},
	{"PCM", 3, 50285},
	{"SHREVEPORT", 10, 50286},
	{"GROWER", 6, 50287},
	{"SOCR", 4, 50288},
	{"DEOP", 4, 50289},
	{"FREDERIC", 8, 50290},
	{"LYVA", 4, 50291},
	{"ELSM", 4, 50292},
	{"DARLINGTON", 10, 50293},
	{"RYBI", 4, 50294},
	{"RONP", 4, 50295},
	{"LEYM", 4, 50296},
	{"FULH", 4, 50297},
	{"BYSC", 4, 50298},
	{"SLIPPERY", 8, 50299},
	{"OMWO", 4, 50300},
	{"UNPREDICTABLE", 13, 50301},
	{"GALERIE", 7, 50302},
	{"YWED", 4, 50303},
	{"CHOV", 4, 50304},
	{"PTOC", 4, 50305},
	{"HCRE", 4, 50306},
	{"CAPACITOR", 9, 50307},
	{"ULLH", 4, 50308},
	{"OUTPOST", 7, 50309},
	{"BURNETT", 7, 50310},
	{"RHEC", 4, 50311},
	{"HILFIGER", 8, 50312},
	{"LITRES", 6, 50313},
	{"MOROCCAN", 8, 50314},
	{"SEVILLE", 7, 50315},
	{"LVIL", 4, 50316},
	{"ORSK", 4, 50317},
	{"MIRA", 4, 50318},
	{"KWOR", 4, 50319},
	{"NIGHTWISH", 9, 50320},
	{"CHATTER", 7, 50321},
	{"WHEATON", 7, 50322},
	{"MPTH", 4, 50323},
	{"ZZV", 3, 50324},
	{"NLAU", 4, 50325},
	{"GFRI", 4, 50326},
	{"LETTUCE", 7, 50327},
	{"RAGING", 6, 50328},
	{"POTL", 4, 50329},
	{"LCEL", 4, 50330},
	{"TIDY", 4, 50331},
	{"MOTORIZED", 9, 50332},
	{"JONG", 4, 50333},
	{"KUPS", 4, 50334},
	{"FICP", 4, 50335},
	{"SUBGROUP", 8, 50336},
	{"XISU", 4, 50337},
	{"EGEW", 4, 50338},
	{"OPPRESSION", 10, 50339},
	{"CHEVELLE", 8, 50340},
	{"HADU", 4, 50341},
	{"YVOL", 4, 50342},
	{"GLEH", 4, 50343},
	{"YJUL", 4, 50344},
	{"YNOV", 4, 50345},
	{"RKSP", 4, 50346},
	{"BOWS", 4, 50347},
	{"OOCC", 4, 50348},
	{"EYPO", 4, 50349},
	{"YIELDING", 8, 50350},
	{"ASSAYS", 6, 50351},
	{"TORSO", 5, 50352},
	{"OCCULT", 6, 50353},
	{"MYMI", 4, 50354},
	{"EXPEDITIONS", 11, 50355},
	{"AFOL", 4, 50356},
	{"RAMON", 5, 50357},
	{"ODSC", 4, 50358},
	{"DTUE", 4, 50359},
	{"LONGHORN", 8, 50360},
	{"LORENZO", 7, 50361},
	{"BEAU", 4, 50362},
	{"BACKDROP", 8, 50363},
	{"SUBORDINATE", 11, 50364},
	{"LILIES", 6, 50365},
	{"AEROBIC", 7, 50366},
	{"OWDA", 4, 50367},
	{"NDZO", 4, 50368},
	{"DBIR", 4, 50369},
	{"VGROUP", 6, 50370},
	{"ECSTASY", 7, 50371},
	{"SWEETHEART", 10, 50372},
	{"FULFIL", 6, 50373},
	{"CALCUTTA", 8, 50374},
	{"IPFO", 4, 50375},
	{"THURSDAYS", 9, 50376},
	{"DANSK", 5, 50377},
	{"POFM", 4, 50378},
	{"BEWH", 4, 50379},
	{"ALKW", 4, 50380},
	{"TENERIFE", 8, 50381},
	{"HOBBS", 5, 50382},
	{"NUEF", 4, 50383},
	{"MAYEN", 5, 50384},
	{"XIDE", 4, 50385},
	{"MEDIATOR", 8, 50386},
	{"OLDMEDLINE", 10, 50387},
	{"DUNLOP", 6, 50388},
	{"MODERNIZATION", 13, 50389},
	{"UERR", 4, 50390},
	{"LTHP", 4, 50391},
	{"DEUN", 4, 50392},
	{"BEQU", 4, 50393},
	{"CULTIVATED", 10, 50394},
	{"RANG", 4, 50395},
	{"DISCONNECTED", 12, 50396},
	{"CONSULATE", 9, 50397},
	{"EYPU", 4, 50398},
	{"DVIL", 4, 50399},
	{"FOURIER", 7, 50400},
	{"WATERSPORTS", 11, 50401},
	{"LUCENT", 6, 50402},
	{"NMAJ", 4, 50403},
	{"WILKES", 6, 50404},
	{"COMMUTER", 8, 50405},
	{"OLSC", 4, 50406},
	{"WOPR", 4, 50407},
	{"ORTHOPEDIC", 10, 50408},
	{"DISAGREEMENT", 12, 50409},
	{"STRANDS", 7, 50410},
	{"TYROSINE", 8, 50411},
	{"SICILY", 6, 50412},
	{"TWOV", 4, 50413},
	{"COMPOST", 7, 50414},
	{"EWAK", 4, 50415},
	{"SHENZHEN", 8, 50416},
	{"ADJOURNED", 9, 50417},
	{"FAMILIARITY", 11, 50418},
	{"RTYD", 4, 50419},
	{"INITIATING", 10, 50420},
	{"ERRONEOUS", 9, 50421},
	{"GRABS", 5, 50422},
	{"ACOV", 4, 50423},
	{"ERICKSON", 8, 50424},
	{"UBES", 4, 50425},
	{"MARLIN", 6, 50426},
	{"PULSES", 6, 50427},
	{"THESES", 6, 50428},
	{"YERB", 4, 50429},
	{"STUFFING", 8, 50430},
	{"FPOI", 4, 50431},
	{"CASSEROLE", 9, 50432},
	{"RZK", 3, 50433},
	{"PSRE", 4, 50434},
	{"LSEV", 4, 50435},
	{"CANOEING", 8, 50436},
	{"YOFK", 4, 50437},
	{"PTOD", 4, 50438},
	{"AYBR", 4, 50439},
	{"JEUX", 4, 50440},
	{"WILTON", 6, 50441},
	{"OPHTHALMOLOGY", 13, 50442},
	{"YKNE", 4, 50443},
	{"IDMI", 4, 50444},
	{"YBEP", 4, 50445},
	{"FLOODED", 7, 50446},
	{"GEILE", 5, 50447},
	{"NAQU", 4, 50448},
	{"LSLO", 4, 50449},
	{"REWW", 4, 50450},
	{"CLUBHOUSE", 9, 50451},
	{"REVERTED", 8, 50452},
	{"CRACKERS", 8, 50453},
	{"RRUS", 4, 50454},
	{"GREYHOUND", 9, 50455},
	{"CORSAIR", 7, 50456},
	{"SFIF", 4, 50457},
	{"SEDV", 4, 50458},
	{"IRONIC", 6, 50459},
	{"LICENSEES", 9, 50460},
	{"WARDS", 5, 50461},
	{"GMOV", 4, 50462},
	{"UNSUPPORTED", 11, 50463},
	{"ALYT", 4, 50464},
	{"EVALUATES", 9, 50465},
	{"HINGE", 5, 50466},
	{"UPUN", 4, 50467},
	{"UXJ", 3, 50468},
	{"INLU", 4, 50469},
	{"FFFR", 4, 50470},
	{"ULTIMA", 6, 50471},
	{"COCKPIT", 7, 50472},
	{"PROTESTERS", 10, 50473},
	{"OURJ", 4, 50474},
	{"FBLO", 4, 50475},
	{"SUEW", 4, 50476},
	{"BYSP", 4, 50477},
	{"BEFU", 4, 50478},
	{"FERNANDEZ", 9, 50479},
	{"OILC", 4, 50480},
	{"PAYR", 4, 50481},
	{"VENETIAN", 8, 50482},
	{"MVC", 3, 50483},
	{"GOPP", 4, 50484},
	{"SLEAZYDREAM", 11, 50485},
	{"PATTI", 5, 50486},
	{"RBUD", 4, 50487},
	{"ULMI", 4, 50488},
	{"TYCL", 4, 50489},
	{"CARROTS", 7, 50490},
	{"FAIRE", 5, 50491},
	{"BLYL", 4, 50492},
	{"LAPS", 4, 50493},
	{"MEMORIALS", 9, 50494},
	{"SENNHEISER", 10, 50495},
	{"UBWA", 4, 50496},
	{"EWSU", 4, 50497},
	{"LDGR", 4, 50498},
	{"KEEV", 4, 50499},
	{"TGUI", 4, 50500},
	{"RESUMED", 7, 50501},
	{"NTYM", 4, 50502},
	{"SHEEHAN", 7, 50503},
	{"CONVERSELY", 10, 50504},
	{"DOFJ", 4, 50505},
	{"MYTO", 4, 50506},
	{"EMORY", 5, 50507},
	{"STUNT", 5, 50508},
	{"MAVEN", 5, 50509},
	{"EXCUSES", 7, 50510},
	{"COMMUTE", 7, 50511},
	{"STAGED", 6, 50512},
	{"VITAE", 5, 50513},
	{"TFUR", 4, 50514},
	{"LBEW", 4, 50515},
	{"FSUB", 4, 50516},
	{"TRANSGENDER", 11, 50517},
	{"RRER", 4, 50518},
	{"HUSTLE", 6, 50519},
	{"STIMULI", 7, 50520},
	{"CUSTOMIZING", 11, 50521},
	{"KMOR", 4, 50522},
	{"SUBROUTINE", 10, 50523},
	{"UPWARDS", 7, 50524},
	{"CUTB", 4, 50525},
	{"WITTY", 5, 50526},
	{"AYFE", 4, 50527},
	{"PONG", 4, 50528},
	{"YBAD", 4, 50529},
	{"ONDV", 4, 50530},
	{"TRANSCEND", 9, 50531},
	{"LOOSELY", 7, 50532},
	{"ANCHORS", 7, 50533},
	{"ILEK", 4, 50534},
	{"GEYO", 4, 50535},
	{"YPLE", 4, 50536},
	{"DAMU", 4, 50537},
	{"HERTZ", 5, 50538},
	{"ATHEIST", 7, 50539},
	{"IDLO", 4, 50540},
	{"CAPPED", 6, 50541},
	{"MBEF", 4, 50542},
	{"LGAT", 4, 50543},
	{"MYR", 3, 50544},
	{"DKJ", 3, 50545},
	{"BRIDGEWATER", 11, 50546},
	{"OWRA", 4, 50547},
	{"EERL", 4, 50548},
	{"FIREFIGHTER", 11, 50549},
	{"LIKING", 6, 50550},
	{"AWSC", 4, 50551},
	{"PREACHER", 8, 50552},
	{"PROPULSION", 10, 50553},
	{"YVIE", 4, 50554},
	{"LSAF", 4, 50555},
	{"RAPL", 4, 50556},
	{"COMPLIED", 8, 50557},
	{"OWSB", 4, 50558},
	{"INTANGIBLE", 10, 50559},
	{"WESTFIELD", 9, 50560},
	{"HLYP", 4, 50561},
	{"AFFW", 4, 50562},
	{"COMPASSIONATE", 13, 50563},
	{"ZEDW", 4, 50564},
	{"CATASTROPHIC", 12, 50565},
	{"YSFR", 4, 50566},
	{"MOFH", 4, 50567},
	{"BLOWER", 6, 50568},
	{"SUBSTITUTES", 11, 50569},
	{"ETCL", 4, 50570},
	{"FLOWN", 5, 50571},
	{"FRAU", 4, 50572},
	{"DUBBED", 6, 50573},
	{"SILKY", 5, 50574},
	{"PAFT", 4, 50575},
	{"GICLEE", 6, 50576},
	{"GROOVY", 6, 50577},
	{"EORW", 4, 50578},
	{"VOWS", 4, 50579},
	{"REUSABLE", 8, 50580},
	{"MACY", 4, 50581},
	{"ACTUARIAL", 9, 50582},
	{"EWDI", 4, 50583},
	{"DISTORTED", 9, 50584},
	{"NATHANIEL", 9, 50585},
	{"ATTRACTS", 8, 50586},
	{"BERN", 4, 50587},
	{"QUALIFIES", 9, 50588},
	{"GRIZZLY", 7, 50589},
	{"DEYE", 4, 50590},
	{"HELPLINE", 8, 50591},
	{"MICAH", 5, 50592},
	{"ZEDH", 4, 50593},
	{"ERECTILE", 8, 50594},
	{"TIMELINESS", 10, 50595},
	{"OBSTETRICS", 10, 50596},
	{"CHAIRED", 7, 50597},
	{"AGRI", 4, 50598},
	{"REPAY", 5, 50599},
	{"HURTING", 7, 50600},
	{"HOMICIDE", 8, 50601},
	{"URCI", 4, 50602},
	{"PROGNOSIS", 9, 50603},
	{"FPEN", 4, 50604},
	{"COLOMBIAN", 9, 50605},
	{"PANDEMIC", 8, 50606},
	{"MPC", 3, 50607},
	{"BIGL", 4, 50608},
	{"SPARSE", 6, 50609},
	{"RBUL", 4, 50610},
	{"CORRIDORS", 9, 50611},
	{"MCDOWELL", 8, 50612},
	{"DEWO", 4, 50613},
	{"ODIG", 4, 50614},
	{"FOSSILS", 7, 50615},
	{"LENV", 4, 50616},
	{"VICTORIES", 9, 50617},
	{"WHOV", 4, 50618},
	{"DIMAGE", 6, 50619},
	{"CHEMICALLY", 10, 50620},
	{"EYEX", 4, 50621},
	{"FETUS", 5, 50622},
	{"SUPW", 4, 50623},
	{"DETERMINANTS", 12, 50624},
	{"COMPLIMENTS", 11, 50625},
	{"DURANGO", 7, 50626},
	{"OGIZ", 4, 50627},
	{"MHAR", 4, 50628},
	{"RGYI", 4, 50629},
	{"EAKU", 4, 50630},
	{"CIDER", 5, 50631},
	{"NONCOMMERCIAL", 13, 50632},
	{"OPTERON", 7, 50633},
	{"CROOKED", 7, 50634},
	{"GANGS", 5, 50635},
	{"SEGREGATION", 11, 50636},
	{"SUPERANNUATION", 14, 50637},
	{"RNAU", 4, 50638},
	{"KEDN", 4, 50639},
	{"DHEM", 4, 50640},
	{"OVERCAST", 8, 50641},
	{"WDOY", 4, 50642},
	{"DRYA", 4, 50643},
	{"INVERTED", 8, 50644},
	{"LENNY", 5, 50645},
	{"ACHIEVES", 8, 50646},
	{"OADF", 4, 50647},
	{"HCOR", 4, 50648},
	{"TMYS", 4, 50649},
	{"LDSF", 4, 50650},
	{"WIMBLEDON", 9, 50651},
	{"MLOO", 4, 50652},
	{"YWID", 4, 50653},
	{"REMAKE", 6, 50654},
	{"BRAILLE", 7, 50655},
	{"IZEF", 4, 50656},
	{"RNBA", 4, 50657},
	{"LTAX", 4, 50658},
	{"WNTU", 4, 50659},
	{"DPUN", 4, 50660},
	{"UMSI", 4, 50661},
	{"OUFI", 4, 50662},
	{"PHYSIOPATHOLOGY", 15, 50663},
	{"SKYE", 4, 50664},
	{"SEPERATE", 8, 50665},
	{"GMAY", 4, 50666},
	{"ECONPAPERS", 10, 50667},
	{"ARXIV", 5, 50668},
	{"OORB", 4, 50669},
	{"CHBY", 4, 50670},
	{"KALAMAZOO", 9, 50671},
	{"PERCY", 5, 50672},
	{"SCRATCHES", 9, 50673},
	{"CONAN", 5, 50674},
	{"LILAC", 5, 50675},
	{"SINUS", 5, 50676},
	{"RYOP", 4, 50677},
	{"OFIX", 4, 50678},
	{"WNAL", 4, 50679},
	{"UTBI", 4, 50680},
	{"FHOL", 4, 50681},
	{"EMOG", 4, 50682},
	{"MAVERICK", 8, 50683},
	{"MEGE", 4, 50684},
	{"MZC", 3, 50685},
	{"LJW", 3, 50686},
	{"GLYI", 4, 50687},
	{"YMAJ", 4, 50688},
	{"INTELLECT", 9, 50689},
	{"OTMU", 4, 50690},
	{"CHARMED", 7, 50691},
	{"DENNY", 5, 50692},
	{"KPER", 4, 50693},
	{"HARMAN", 6, 50694},
	{"HEARS", 5, 50695},
	{"DORB", 4, 50696},
	{"WILHELM", 7, 50697},
	{"NATIONALISM", 11, 50698},
	{"OWNV", 4, 50699},
	{"DBUD", 4, 50700},
	{"PERVASIVE", 9, 50701},
	{"UEVE", 4, 50702},
	{"PSFR", 4, 50703},
	{"ECIM", 4, 50704},
	{"AUCH", 4, 50705},
	{"ZEDO", 4, 50706},
	{"RMIG", 4, 50707},
	{"HAMC", 4, 50708},
	{"GICI", 4, 50709},
	{"ENFIELD", 7, 50710},
	{"GSUN", 4, 50711},
	{"ANABOLIC", 8, 50712},
	{"FTFR", 4, 50713},
	{"DGRI", 4, 50714},
	{"ALLEGRA", 7, 50715},
	{"LEXAR", 5, 50716},
	{"CLEARS", 6, 50717},
	{"VIDEOTAPE", 9, 50718},
	{"EDUC", 4, 50719},
	{"PYOF", 4, 50720},
	{"OKEW", 4, 50721},
	{"KNOWINGLY", 9, 50722},
	{"REDJ", 4, 50723},
	{"LZG", 3, 50724},
	{"PIVOT", 5, 50725},
	{"AMPLIFICATION", 13, 50726},
	{"OKOU", 4, 50727},
	{"LARSEN", 6, 50728},
	{"HURON", 5, 50729},
	{"OFKN", 4, 50730},
	{"BDUL", 4, 50731},
	{"ILWE", 4, 50732},
	{"SNIPPETS", 8, 50733},
	{"DMIK", 4, 50734},
	{"UNDERGRADUATES", 14, 50735},
	{"CONSERV", 7, 50736},
	{"DIGESTION", 9, 50737},
	{"DUSTIN", 6, 50738},
	{"WSOP", 4, 50739},
	{"WNUP", 4, 50740},
	{"RMYC", 4, 50741},
	{"IMOV", 4, 50742},
	{"MIXTURES", 8, 50743},
	{"COMPOSITES", 10, 50744},
	{"WOLVERHAMPTON", 13, 50745},
	{"SOARING", 7, 50746},
	{"YLEI", 4, 50747},
	{"WIDT", 4, 50748},
	{"DRAGGING", 8, 50749},
	{"LFAI", 4, 50750},
	{"VIRTUES", 7, 50751},
	{"BANNING", 7, 50752},
	{"FLUSHING", 8, 50753},
	{"DEPRIVATION", 11, 50754},
	{"ELPW", 4, 50755},
	{"DELIGHTS", 8, 50756},
	{"GAUTENG", 7, 50757},
	{"FOREWORD", 8, 50758},
	{"GLIDE", 5, 50759},
	{"TRANSVERSE", 10, 50760},
	{"FTAR", 4, 50761},
	{"KENC", 4, 50762},
	{"LYJO", 4, 50763},
	{"WATERTOWN", 9, 50764},
	{"PATHOGENS", 9, 50765},
	{"GMED", 4, 50766},
	{"ENGAGEMENTS", 11, 50767},
	{"DOAL", 4, 50768},
	{"ADBY", 4, 50769},
	{"WITHSTAND", 9, 50770},
	{"UEFA", 4, 50771},
	{"CCLE", 4, 50772},
	{"NEWBURY", 7, 50773},
	{"AUTHORIZES", 10, 50774},
	{"BLOOMS", 6, 50775},
	{"EMMO", 4, 50776},
	{"EHYP", 4, 50777},
	{"JACKING", 7, 50778},
	{"LCRO", 4, 50779},
	{"RADIOHEAD", 9, 50780},
	{"UNIFORMLY", 9, 50781},
	{"KINP", 4, 50782},
	{"AJUD", 4, 50783},
	{"NWEB", 4, 50784},
	{"AKID", 4, 50785},
	{"SUBSECTIONS", 11, 50786},
	{"TSUG", 4, 50787},
	{"OULA", 4, 50788},
	{"TODOS", 5, 50789},
	{"DEFINATELY", 10, 50790},
	{"YISG", 4, 50791},
	{"PIEDMONT", 8, 50792},
	{"OPFI", 4, 50793},
	{"EMPOWERED", 9, 50794},
	{"HOMEPAGES", 9, 50795},
	{"OUTLYING", 8, 50796},
	{"HOFL", 4, 50797},
	{"SLOGAN", 6, 50798},
	{"CAWA", 4, 50799},
	{"SUBDIVISIONS", 12, 50800},
	{"HANDOUTS", 8, 50801},
	{"DEDUCTED", 8, 50802},
	{"DSUM", 4, 50803},
	{"EZEKIEL", 7, 50804},
	{"ODDA", 4, 50805},
	{"TOTALING", 8, 50806},
	{"UFFS", 4, 50807},
	{"ELIJAH", 6, 50808},
	{"CPM", 3, 50809},
	{"MARVELOUS", 9, 50810},
	{"ACAU", 4, 50811},
	{"ASNBLOCK", 8, 50812},
	{"MSUP", 4, 50813},
	{"WEDG", 4, 50814},
	{"COMPTON", 7, 50815},
	{"YEXE", 4, 50816},
	{"STRETCHES", 9, 50817},
	{"VIGOROUS", 8, 50818},
	{"GCHE", 4, 50819},
	{"KWEL", 4, 50820},
	{"BILOXI", 6, 50821},
	{"BISCUIT", 7, 50822},
	{"LDIM", 4, 50823},
	{"EUMS", 4, 50824},
	{"CREME", 5, 50825},
	{"MPSE", 4, 50826},
	{"SUBMITS", 7, 50827},
	{"AGOD", 4, 50828},
	{"WALTZ", 5, 50829},
	{"MENACE", 6, 50830},
	{"LWRI", 4, 50831},
	{"LPHE", 4, 50832},
	{"OKLY", 4, 50833},
	{"EMERGES", 7, 50834},
	{"PAIGE", 5, 50835},
	{"DOWNSTAIRS", 10, 50836},
	{"STATESMAN", 9, 50837},
	{"INDYMEDIA", 9, 50838},
	{"ELWE", 4, 50839},
	{"CLAPTON", 7, 50840},
	{"CHEERFUL", 8, 50841},
	{"BLUSH", 5, 50842},
	{"DSBA", 4, 50843},
	{"BEYONCE", 7, 50844},
	{"LEAFLET", 7, 50845},
	{"MONDE", 5, 50846},
	{"WEYMOUTH", 8, 50847},
	{"NABBLE", 6, 50848},
	{"PFUL", 4, 50849},
	{"DNOM", 4, 50850},
	{"ALQA", 4, 50851},
	{"IDTY", 4, 50852},
	{"BYCL", 4, 50853},
	{"NGKA", 4, 50854},
	{"SPHERICAL", 9, 50855},
	{"INTRACELLULAR", 13, 50856},
	{"ICUN", 4, 50857},
	{"FFLA", 4, 50858},
	{"EEBU", 4, 50859},
	{"UFEE", 4, 50860},
	{"INFOWORLD", 9, 50861},
	{"RYAP", 4, 50862},
	{"LYHU", 4, 50863},
	{"FAVOURABLE", 10, 50864},
	{"UDEI", 4, 50865},
	{"INFORMS", 7, 50866},
	{"BOYZ", 4, 50867},
	{"DOMT", 4, 50868},
	{"DRAMAS", 6, 50869},
	{"UITC", 4, 50870},
	{"RNEC", 4, 50871},
	{"ADBR", 4, 50872},
	{"GEBY", 4, 50873},
	{"EWPL", 4, 50874},
	{"KERD", 4, 50875},
	{"HOFB", 4, 50876},
	{"CHER", 4, 50877},
	{"WALTHAM", 7, 50878},
	{"WSMA", 4, 50879},
	{"GEISHA", 6, 50880},
	{"BILLIARD", 8, 50881},
	{"DBLP", 4, 50882},
	{"BRIEFCASE", 9, 50883},
	{"DGEP", 4, 50884},
	{"MALAY", 5, 50885},
	{"UNSEEN", 6, 50886},
	{"GALB", 4, 50887},
	{"MCMAHON", 7, 50888},
	{"RASB", 4, 50889},
	{"OPTIMISM", 8, 50890},
	{"SILICA", 6, 50891},
	{"KARA", 4, 50892},
	{"MCGREGOR", 8, 50893},
	{"MODAL", 5, 50894},
	{"MARLBORO", 8, 50895},
	{"GRAFTON", 7, 50896},
	{"ICEU", 4, 50897},
	{"HBLA", 4, 50898},
	{"UNUSUALLY", 9, 50899},
	{"PHISHING", 8, 50900},
	{"ADDENDUM", 8, 50901},
	{"WIDEST", 6, 50902},
	{"SJUD", 4, 50903},
	{"IMPOTENCE", 9, 50904},
	{"XTOF", 4, 50905},
	{"MEDLEY", 6, 50906},
	{"YSGA", 4, 50907},
	{"CADET", 5, 50908},
	{"YFAS", 4, 50909},
	{"REDSKINS", 8, 50910},
	{"KIRSTEN", 7, 50911},
	{"TEMPER", 6, 50912},
	{"YORKER", 6, 50913},
	{"MEMBERLISTMEMBERLIST", 20, 50914},
	{"GBLA", 4, 50915},
	{"INTRAVENOUS", 11, 50916},
	{"YVY", 3, 50917},
	{"BITM", 4, 50918},
	{"RLAP", 4, 50919},
	{"LPFU", 4, 50920},
	{"ILBU", 4, 50921},
	{"ASHCROFT", 8, 50922},
	{"ASSERTS", 7, 50923},
	{"AYRA", 4, 50924},
	{"LOREN", 5, 50925},
	{"NEWSFEED", 8, 50926},
	{"YHUN", 4, 50927},
	{"CKPE", 4, 50928},
	{"HEREAFTER", 9, 50929},
	{"OLEU", 4, 50930},
	{"CARBS", 5, 50931},
	{"RETIRING", 8, 50932},
	{"BIGH", 4, 50933},
	{"SMASHING", 8, 50934},
	{"YAKIMA", 6, 50935},
	{"GSWO", 4, 50936},
	{"UEFR", 4, 50937},
	{"OFSK", 4, 50938},
	{"REALTONES", 9, 50939},
	{"VDATA", 5, 50940},
	{"INTERPRO", 8, 50941},
	{"TAHITI", 6, 50942},
	{"ENGADGET", 8, 50943},
	{"YMAG", 4, 50944},
	{"TRACEY", 6, 50945},
	{"LUBT", 4, 50946},
	{"UBTT", 4, 50947},
	{"MARINER", 7, 50948},
	{"COLLIER", 7, 50949},
	{"DARFUR", 6, 50950},
	{"AMSD", 4, 50951},
	{"YECO", 4, 50952},
	{"FRAGMENTATION", 13, 50953},
	{"BEHAVIOURAL", 11, 50954},
	{"YWP", 3, 50955},
	{"KIEV", 4, 50956},
	{"DAMB", 4, 50957},
	{"PARANORMAL", 10, 50958},
	{"TOMP", 4, 50959},
	{"MSPO", 4, 50960},
	{"HFIV", 4, 50961},
	{"WHISPERED", 9, 50962},
	{"GENEROSITY", 10, 50963},
	{"VIBRATING", 9, 50964},
	{"GLOSSARIES", 10, 50965},
	{"SONYERICSSON", 12, 50966},
	{"LAMA", 4, 50967},
	{"ARTISAN", 7, 50968},
	{"RAPHAEL", 7, 50969},
	{"LLEH", 4, 50970},
	{"KBEF", 4, 50971},
	{"LOLA", 4, 50972},
	{"EMBARRASSING", 12, 50973},
	{"TCRU", 4, 50974},
	{"YAPO", 4, 50975},
	{"NBOY", 4, 50976},
	{"EMOTICONS", 9, 50977},
	{"CARBOHYDRATES", 13, 50978},
	{"DCIV", 4, 50979},
	{"AQUEOUS", 7, 50980},
	{"PEMBROKE", 8, 50981},
	{"NORWOOD", 7, 50982},
	{"APPETIZERS", 10, 50983},
	{"STOCKHOLDERS", 12, 50984},
	{"WEBMIN", 6, 50985},
	{"OTBY", 4, 50986},
	{"EWSL", 4, 50987},
	{"LILLIAN", 7, 50988},
	{"STYLESHEET", 10, 50989},
	{"LSFA", 4, 50990},
	{"LSTY", 4, 50991},
	{"GOLDSTEIN", 9, 50992},
	{"SPLINTER", 8, 50993},
	{"WNBA", 4, 50994},
	{"YMOM", 4, 50995},
	{"YESW", 4, 50996},
	{"PREFERABLE", 10, 50997},
	{"LZQ", 3, 50998},
	{"DATF", 4, 50999},
	{"ENGLEWOOD", 9, 51000},
	{"JUICES", 6, 51001},
	{"ERNG", 4, 51002},
	{"LSAB", 4, 51003},
	{"MORALE", 6, 51004},
	{"MORALES", 7, 51005},
	{"SOLDER", 6, 51006},
	{"TRENCH", 6, 51007},
	{"ORMH", 4, 51008},
	{"PERSUASION", 10, 51009},
	{"HOTTIE", 6, 51010},
	{"STRIPPER", 8, 51011},
	{"CKSL", 4, 51012},
	{"PRACTISE", 8, 51013},
	{"YRON", 4, 51014},
	{"HAMW", 4, 51015},
	{"PFC", 3, 51016},
	{"ADRENALINE", 10, 51017},
	{"OGUA", 4, 51018},
	{"PLYF", 4, 51019},
	{"IMLE", 4, 51020},
	{"FFSI", 4, 51021},
	{"MAMMALIAN", 9, 51022},
	{"OPTED", 5, 51023},
	{"LODGED", 6, 51024},
	{"REVOLT", 6, 51025},
	{"LYOB", 4, 51026},
	{"ILGR", 4, 51027},
	{"ARAV", 4, 51028},
	{"METEOROLOGY", 11, 51029},
	{"ANALYZES", 8, 51030},
	{"RENDERS", 7, 51031},
	{"BWIT", 4, 51032},
	{"PIONEERING", 10, 51033},
	{"NKAL", 4, 51034},
	{"FFCO", 4, 51035},
	{"PRISTINE", 8, 51036},
	{"FRANCAISE", 9, 51037},
	{"MDES", 4, 51038},
	{"ELWO", 4, 51039},
	{"SHINES", 6, 51040},
	{"DJON", 4, 51041},
	{"VLJ", 3, 51042},
	{"VALW", 4, 51043},
	{"RIPH", 4, 51044},
	{"CATALAN", 7, 51045},
	{"TPAL", 4, 51046},
	{"RANW", 4, 51047},
	{"DWIG", 4, 51048},
	{"SPREADSHEETS", 12, 51049},
	{"CKME", 4, 51050},
	{"RESIZE", 6, 51051},
	{"RPAL", 4, 51052},
	{"AUDITORY", 8, 51053},
	{"SSBY", 4, 51054},
	{"ADOV", 4, 51055},
	{"APPLAUSE", 8, 51056},
	{"MEDICALLY", 9, 51057},
	{"TWEAK", 5, 51058},
	{"MMM", 3, 51059},
	{"POPPED", 6, 51060},
	{"RFED", 4, 51061},
	{"DSAD", 4, 51062},
	{"FFOL", 4, 51063},
	{"CWIL", 4, 51064},
	{"UYSW", 4, 51065},
	{"BUSTED", 6, 51066},
	{"NYEX", 4, 51067},
	{"UDEF", 4, 51068},
	{"RTGR", 4, 51069},
	{"RMIE", 4, 51070},
	{"ALICANTE", 8, 51071},
	{"BASINS", 6, 51072},
	{"OLLT", 4, 51073},
	{"FARMHOUSE", 9, 51074},
	{"DESD", 4, 51075},
	{"POUNDING", 8, 51076},
	{"PICTURESQUE", 11, 51077},
	{"UICE", 4, 51078},
	{"MIXO", 4, 51079},
	{"EPEL", 4, 51080},
	{"OTTOMAN", 7, 51081},
	{"GRADERS", 7, 51082},
	{"SHREK", 5, 51083},
	{"TBUL", 4, 51084},
	{"POUS", 4, 51085},
	{"BEDH", 4, 51086},
	{"EATER", 5, 51087},
	{"GOND", 4, 51088},
	{"ERTF", 4, 51089},
	{"UNIVERSIDAD", 11, 51090},
	{"ICSL", 4, 51091},
	{"TUNERS", 6, 51092},
	{"UTOPIA", 6, 51093},
	{"SLIDER", 6, 51094},
	{"INSISTS", 7, 51095},
	{"HBRE", 4, 51096},
	{"CYMRU", 5, 51097},
	{"FPRINTF", 7, 51098},
	{"WILLARD", 7, 51099},
	{"TGOD", 4, 51100},
	{"LETTERING", 9, 51101},
	{"DADS", 4, 51102},
	{"VALF", 4, 51103},
	{"MARLBOROUGH", 11, 51104},
	{"EBUSINESS", 9, 51105},
	{"POURING", 7, 51106},
	{"LMAL", 4, 51107},
	{"CYRUS", 5, 51108},
	{"CONCENTRATING", 13, 51109},
	{"BUCKINGHAM", 10, 51110},
	{"OORF", 4, 51111},
	{"HIDES", 5, 51112},
	{"GOODWIN", 7, 51113},
	{"YMNA", 4, 51114},
	{"SDED", 4, 51115},
	{"ISMF", 4, 51116},
	{"MANURE", 6, 51117},
	{"SAVIOR", 6, 51118},
	{"DADE", 4, 51119},
	{"WPER", 4, 51120},
	{"OLSF", 4, 51121},
	{"SECRECY", 7, 51122},
	{"EDKA", 4, 51123},
	{"RCTI", 4, 51124},
	{"GORS", 4, 51125},
	{"ELOB", 4, 51126},
	{"DVIO", 4, 51127},
	{"WESLEYAN", 8, 51128},
	{"DUPLICATED", 10, 51129},
	{"PONC", 4, 51130},
	{"DLEB", 4, 51131},
	{"MCCL", 4, 51132},
	{"UCKB", 4, 51133},
	{"DREAMED", 7, 51134},
	{"DSBY", 4, 51135},
	{"RELOCATING", 10, 51136},
	{"FCIT", 4, 51137},
	{"TGUY", 4, 51138},
	{"RONR", 4, 51139},
	{"FERTILE", 7, 51140},
	{"OGOD", 4, 51141},
	{"HINGES", 6, 51142},
	{"PLAUSIBLE", 9, 51143},
	{"CREEPY", 6, 51144},
	{"ISMC", 4, 51145},
	{"DCRU", 4, 51146},
	{"SYNTH", 5, 51147},
	{"FILTHY", 6, 51148},
	{"SUBCHAPTER", 10, 51149},
	{"NARRATOR", 8, 51150},
	{"OPTIMIZATIONS", 13, 51151},
	{"LSME", 4, 51152},
	{"INFOCUS", 7, 51153},
	{"YCOV", 4, 51154},
	{"YJJ", 3, 51155},
	{"YEAC", 4, 51156},
	{"WEDM", 4, 51157},
	{"BELLSOUTH", 9, 51158},
	{"SWEENEY", 7, 51159},
	{"AUGUSTUS", 8, 51160},
	{"FAHRENHEIT", 10, 51161},
	{"HILLSIDE", 8, 51162},
	{"FROC", 4, 51163},
	{"DPIE", 4, 51164},
	{"STANDPOINT", 10, 51165},
	{"LAYUP", 5, 51166},
	{"LAUNDERING", 10, 51167},
	{"ROFV", 4, 51168},
	{"RMYT", 4, 51169},
	{"POWD", 4, 51170},
	{"NATIONALIST", 11, 51171},
	{"PIAZZA", 6, 51172},
	{"DENOTED", 7, 51173},
	{"NAZIS", 5, 51174},
	{"GSIM", 4, 51175},
	{"ONESELF", 7, 51176},
	{"ROYALTIES", 9, 51177},
	{"NEWBIES", 7, 51178},
	{"YATR", 4, 51179},
	{"AUGA", 4, 51180},
	{"AFAV", 4, 51181},
	{"PILES", 5, 51182},
	{"MWEL", 4, 51183},
	{"ABBREVIATION", 12, 51184},
	{"ALEU", 4, 51185},
	{"BLANCO", 6, 51186},
	{"URDL", 4, 51187},
	{"UESP", 4, 51188},
	{"ROBU", 4, 51189},
	{"CRITIQUES", 9, 51190},
	{"STROLL", 6, 51191},
	{"ANOMALY", 7, 51192},
	{"THIGHS", 6, 51193},
	{"EJER", 4, 51194},
	{"AKEG", 4, 51195},
	{"EXPRESSIVE", 10, 51196},
	{"INFECT", 6, 51197},
	{"BEZEL", 5, 51198},
	{"AVATARS", 7, 51199},
	{"PERS", 4, 51200},
	{"TWIZTID", 7, 51201},
	{"DOTTED", 6, 51202},
	{"FRONTAL", 7, 51203},
	{"HAVOC", 5, 51204},
	{"UBIQUITOUS", 10, 51205},
	{"LFLA", 4, 51206},
	{"ARSENIC", 7, 51207},
	{"SYNONYM", 7, 51208},
	{"FACILITATION", 12, 51209},
	{"IEWP", 4, 51210},
	{"RIAW", 4, 51211},
	{"HREV", 4, 51212},
	{"LLFL", 4, 51213},
	{"UTUB", 4, 51214},
	{"RICB", 4, 51215},
	{"OPKI", 4, 51216},
	{"DOOMED", 6, 51217},
	{"PAVI", 4, 51218},
	{"LMAC", 4, 51219},
	{"GATL", 4, 51220},
	{"APPLETS", 7, 51221},
	{"MUMB", 4, 51222},
	{"FRANCS", 6, 51223},
	{"BALLAD", 6, 51224},
	{"NGGL", 4, 51225},
	{"KEGO", 4, 51226},
	{"PDFS", 4, 51227},
	{"SLING", 5, 51228},
	{"CONTRACTION", 11, 51229},
	{"YVIL", 4, 51230},
	{"PYIN", 4, 51231},
	{"IDRI", 4, 51232},
	{"DEVISED", 7, 51233},
	{"FTUR", 4, 51234},
	{"SOBR", 4, 51235},
	{"EXPLORERS", 9, 51236},
	{"BILLIE", 6, 51237},
	{"UNDERCOVER", 10, 51238},
	{"SUBSTRATES", 10, 51239},
	{"EVANSVILLE", 10, 51240},
	{"JOYSTICK", 8, 51241},
	{"LEYD", 4, 51242},
	{"KNOWLEDGEBASE", 13, 51243},
	{"FORRESTER", 9, 51244},
	{"NDIP", 4, 51245},
	{"RAVENS", 6, 51246},
	{"TUMN", 4, 51247},
	{"BEJU", 4, 51248},
	{"XOOPS", 5, 51249},
	{"RICAN", 5, 51250},
	{"UNDERLINE", 9, 51251},
	{"OBSCENE", 7, 51252},
	{"LUEI", 4, 51253},
	{"BBOT", 4, 51254},
	{"UPTIME", 6, 51255},
	{"MENR", 4, 51256},
	{"DOOYOO", 6, 51257},
	{"GLON", 4, 51258},
	{"SPAMMERS", 8, 51259},
	{"RDDR", 4, 51260},
	{"KENL", 4, 51261},
	{"MITW", 4, 51262},
	{"KINB", 4, 51263},
	{"LKTH", 4, 51264},
	{"GMUC", 4, 51265},
	{"HYMN", 4, 51266},
	{"FEXT", 4, 51267},
	{"CONTINUAL", 9, 51268},
	{"NUCLEI", 6, 51269},
	{"GUPTA", 5, 51270},
	{"TUMMY", 5, 51271},
	{"AXIAL", 5, 51272},
	{"SLOWED", 6, 51273},
	{"ALADDIN", 7, 51274},
	{"WSPE", 4, 51275},
	{"TOLERATED", 9, 51276},
	{"QUAY", 4, 51277},
	{"YALC", 4, 51278},
	{"SEMU", 4, 51279},
	{"OUTING", 6, 51280},
	{"FCHO", 4, 51281},
	{"WILCOX", 6, 51282},
	{"TOPOGRAPHIC", 11, 51283},
	{"WESTPORT", 8, 51284},
	{"OVERHAUL", 8, 51285},
	{"TILM", 4, 51286},
	{"PTLY", 4, 51287},
	{"FBEC", 4, 51288},
	{"MAJORDOMO", 9, 51289},
	{"PERUVIAN", 8, 51290},
	{"INDEMNITY", 9, 51291},
	{"IMAGINATIVE", 11, 51292},
	{"WEIR", 4, 51293},
	{"ASGU", 4, 51294},
	{"WEDNESDAYS", 10, 51295},
	{"BURGERS", 7, 51296},
	{"REMARKED", 8, 51297},
	{"YSDO", 4, 51298},
	{"PWAR", 4, 51299},
	{"DENP", 4, 51300},
	{"PORTRAYED", 9, 51301},
	{"LDCR", 4, 51302},
	{"IFFA", 4, 51303},
	{"WATCHLIST", 9, 51304},
	{"KSPA", 4, 51305},
	{"LOFG", 4, 51306},
	{"LEFU", 4, 51307},
	{"NYDA", 4, 51308},
	{"GERJ", 4, 51309},
	{"CLARENDON", 9, 51310},
	{"CAMPERS", 7, 51311},
	{"PHENOTYPE", 9, 51312},
	{"UALG", 4, 51313},
	{"VENK", 4, 51314},
	{"COUNTRYWIDE", 11, 51315},
	{"FERRIS", 6, 51316},
	{"JULIO", 5, 51317},
	{"SUPF", 4, 51318},
	{"AFFIRM", 6, 51319},
	{"URCU", 4, 51320},
	{"DIRECTX", 7, 51321},
	{"SPELLED", 7, 51322},
	{"EPOCH", 5, 51323},
	{"PDOW", 4, 51324},
	{"MOURNING", 8, 51325},
	{"RESISTOR", 8, 51326},
	{"PHELPS", 6, 51327},
	{"OGYW", 4, 51328},
	{"DBAD", 4, 51329},
	{"WFOU", 4, 51330},
	{"TOPD", 4, 51331},
	{"PLAID", 5, 51332},
	{"YDZ", 3, 51333},
	{"YBF", 3, 51334},
	{"HPAL", 4, 51335},
	{"AUDUBON", 7, 51336},
	{"FABLE", 5, 51337},
	{"BUTK", 4, 51338},
	{"RESCUED", 7, 51339},
	{"COMMENTSBLOG", 12, 51340},
	{"RKLE", 4, 51341},
	{"SNOWMOBILE", 10, 51342},
	{"EXPLODED", 8, 51343},
	{"CEAW", 4, 51344},
	{"PUBL", 4, 51345},
	{"CPG", 3, 51346},
	{"IABU", 4, 51347},
	{"WABL", 4, 51348},
	{"GAFI", 4, 51349},
	{"PADRES", 6, 51350},
	{"YTYP", 4, 51351},
	{"CESY", 4, 51352},
	{"FBEL", 4, 51353},
	{"SCARS", 5, 51354},
	{"WHISKY", 6, 51355},
	{"UPTOWN", 6, 51356},
	{"HBRA", 4, 51357},
	{"SUSIE", 5, 51358},
	{"MBAB", 4, 51359},
	{"SUBPARAGRAPH", 12, 51360},
	{"BATTER", 6, 51361},
	{"WEIGHTING", 9, 51362},
	{"REYES", 5, 51363},
	{"RECTAL", 6, 51364},
	{"VIVIAN", 6, 51365},
	{"NUGGETS", 7, 51366},
	{"SILENTLY", 8, 51367},
	{"PESOS", 5, 51368},
	{"SHAKES", 6, 51369},
	{"DRAM", 4, 51370},
	{"MCKINNEY", 8, 51371},
	{"IMPARTIAL", 9, 51372},
	{"HERSHEY", 7, 51373},
	{"RLAK", 4, 51374},
	{"EMBRYOS", 7, 51375},
	{"PUNCTUATION", 11, 51376},
	{"INITIALS", 8, 51377},
	{"NBUD", 4, 51378},
	{"SPANS", 5, 51379},
	{"WMIL", 4, 51380},
	{"LAYP", 4, 51381},
	{"PALLET", 6, 51382},
	{"OYAG", 4, 51383},
	{"PISTOLS", 7, 51384},
	{"LAPR", 4, 51385},
	{"MARA", 4, 51386},
	{"GARAGES", 7, 51387},
	{"TANNER", 6, 51388},
	{"GLOO", 4, 51389},
	{"CKPI", 4, 51390},
	{"AVENUES", 7, 51391},
	{"UROLOGY", 7, 51392},
	{"ARAJ", 4, 51393},
	{"FARG", 4, 51394},
	{"LSDI", 4, 51395},
	{"ELYK", 4, 51396},
	{"AFOREMENTIONED", 14, 51397},
	{"RIHANNA", 7, 51398},
	{"ORMP", 4, 51399},
	{"TACKLING", 8, 51400},
	{"OBESE", 5, 51401},
	{"TGAL", 4, 51402},
	{"GUEP", 4, 51403},
	{"COMPRESS", 8, 51404},
	{"APOSTLES", 8, 51405},
	{"MELVIN", 6, 51406},
	{"OALF", 4, 51407},
	{"SOBER", 5, 51408},
	{"COLLABORATIONS", 14, 51409},
	{"LSFI", 4, 51410},
	{"TREAD", 5, 51411},
	{"LEGITIMACY", 10, 51412},
	{"ZOOLOGY", 7, 51413},
	{"IKEJ", 4, 51414},
	{"CEFL", 4, 51415},
	{"WRIS", 4, 51416},
	{"FXU", 3, 51417},
	{"LBEU", 4, 51418},
	{"HOPK", 4, 51419},
	{"STEALS", 6, 51420},
	{"UNWILLING", 9, 51421},
	{"ISOLATES", 8, 51422},
	{"UTMU", 4, 51423},
	{"RORM", 4, 51424},
	{"RMIK", 4, 51425},
	{"YTRO", 4, 51426},
	{"NYBA", 4, 51427},
	{"VELCRO", 6, 51428},
	{"WORKSHEETS", 10, 51429},
	{"AVAYA", 5, 51430},
	{"ITBR", 4, 51431},
	{"WIGAN", 5, 51432},
	{"ABBA", 4, 51433},
	{"RPAU", 4, 51434},
	{"IGRO", 4, 51435},
	{"ELTL", 4, 51436},
	{"ORIG", 4, 51437},
	{"RWIC", 4, 51438},
	{"YROS", 4, 51439},
	{"BBEA", 4, 51440},
	{"PADDY", 5, 51441},
	{"ERTP", 4, 51442},
	{"HUSKIES", 7, 51443},
	{"FREY", 4, 51444},
	{"RSJO", 4, 51445},
	{"LOYOLA", 6, 51446},
	{"EGEB", 4, 51447},
	{"PEARCE", 6, 51448},
	{"OKAR", 4, 51449},
	{"GANR", 4, 51450},
	{"GARTNER", 7, 51451},
	{"ODJO", 4, 51452},
	{"FMAY", 4, 51453},
	{"ROWW", 4, 51454},
	{"RHED", 4, 51455},
	{"NREB", 4, 51456},
	{"PLEV", 4, 51457},
	{"ILMC", 4, 51458},
	{"SINISTER", 8, 51459},
	{"RBYC", 4, 51460},
	{"BURR", 4, 51461},
	{"UMSO", 4, 51462},
	{"ARTERIES", 8, 51463},
	{"IDIF", 4, 51464},
	{"GUPW", 4, 51465},
	{"EIRK", 4, 51466},
	{"CHASER", 6, 51467},
	{"PETU", 4, 51468},
	{"FORMATIONS", 10, 51469},
	{"CEJU", 4, 51470},
	{"VANTAGE", 7, 51471},
	{"TEXANS", 6, 51472},
	{"DIFFUSE", 7, 51473},
	{"NEYP", 4, 51474},
	{"BOREDOM", 7, 51475},
	{"NORMA", 5, 51476},
	{"ASTRA", 5, 51477},
	{"MSEV", 4, 51478},
	{"EXPASY", 6, 51479},
	{"CROSSE", 6, 51480},
	{"OVERDRIVE", 9, 51481},
	{"MONDO", 5, 51482},
	{"RIPLEY", 6, 51483},
	{"DMIG", 4, 51484},
	{"OUTV", 4, 51485},
	{"PHOSPHORYLATION", 15, 51486},
	{"HELPLESS", 8, 51487},
	{"LGUA", 4, 51488},
	{"DEPLETION", 9, 51489},
	{"NEONATAL", 8, 51490},
	{"RWEG", 4, 51491},
	{"MCLAREN", 7, 51492},
	{"WYATT", 5, 51493},
	{"ROWLING", 7, 51494},
	{"UMEO", 4, 51495},
	{"BIGR", 4, 51496},
	{"GABU", 4, 51497},
	{"GROA", 4, 51498},
	{"PINF", 4, 51499},
	{"LOTB", 4, 51500},
	{"LLEO", 4, 51501},
	{"FLATBED", 7, 51502},
	{"SPADES", 6, 51503},
	{"RGYC", 4, 51504},
	{"SLUG", 4, 51505},
	{"VISIONARY", 9, 51506},
	{"COFFIN", 6, 51507},
	{"OTTER", 5, 51508},
	{"RUNL", 4, 51509},
	{"NBAD", 4, 51510},
	{"DKID", 4, 51511},
	{"GOLFERS", 7, 51512},
	{"LIRA", 4, 51513},
	{"NAVAJO", 6, 51514},
	{"EARNS", 5, 51515},
	{"YANU", 4, 51516},
	{"TILY", 4, 51517},
	{"ARML", 4, 51518},
	{"AMPLIFIED", 9, 51519},
	{"RECESS", 6, 51520},
	{"DISPERSED", 9, 51521},
	{"TECHNICS", 8, 51522},
	{"SHOUTED", 7, 51523},
	{"DAMIEN", 6, 51524},
	{"EWIC", 4, 51525},
	{"PSER", 4, 51526},
	{"DMES", 4, 51527},
	{"CLIPPERS", 8, 51528},
	{"SHILLING", 8, 51529},
	{"ZEDP", 4, 51530},
	{"ILDP", 4, 51531},
	{"LAFO", 4, 51532},
	{"GDEP", 4, 51533},
	{"YREB", 4, 51534},
	{"SPIRITED", 8, 51535},
	{"WOFI", 4, 51536},
	{"CARBONATE", 9, 51537},
	{"MIMI", 4, 51538},
	{"YWIF", 4, 51539},
	{"MFRI", 4, 51540},
	{"DISCRIMINATE", 12, 51541},
	{"YDAT", 4, 51542},
	{"STARED", 6, 51543},
	{"RECHARGE", 8, 51544},
	{"YPIN", 4, 51545},
	{"CROCODILE", 9, 51546},
	{"RLAU", 4, 51547},
	{"YJW", 3, 51548},
	{"BJW", 3, 51549},
	{"OPENID", 6, 51550},
	{"UBTL", 4, 51551},
	{"ROWB", 4, 51552},
	{"SASSY", 5, 51553},
	{"DEMUX", 5, 51554},
	{"RATIFICATION", 12, 51555},
	{"RIBOSOMAL", 9, 51556},
	{"TSRU", 4, 51557},
	{"PHYT", 4, 51558},
	{"KSPE", 4, 51559},
	{"VASES", 5, 51560},
	{"FILMMAKERS", 10, 51561},
	{"TRANSNATIONAL", 13, 51562},
	{"ADVISES", 7, 51563},
	{"COWARD", 6, 51564},
	{"PARALEGAL", 9, 51565},
	{"SPOKESPERSON", 12, 51566},
	{"WTRA", 4, 51567},
	{"DHEP", 4, 51568},
	{"TEAMED", 6, 51569},
	{"SCOC", 4, 51570},
	{"NICP", 4, 51571},
	{"PRESET", 6, 51572},
	{"INEQUALITIES", 12, 51573},
	{"IPTABLES", 8, 51574},
	{"ETYW", 4, 51575},
	{"POCKETPC", 8, 51576},
	{"GARDE", 5, 51577},
	{"JAMS", 4, 51578},
	{"MWIN", 4, 51579},
	{"PANCREATIC", 10, 51580},
	{"GEAG", 4, 51581},
	{"GSAB", 4, 51582},
	{"OPSP", 4, 51583},
	{"DASR", 4, 51584},
	{"MANICURES", 9, 51585},
	{"GCER", 4, 51586},
	{"EDUM", 4, 51587},
	{"DYES", 4, 51588},
	{"EDUK", 4, 51589},
	{"KZD", 3, 51590},
	{"OADL", 4, 51591},
	{"IEXP", 4, 51592},
	{"NUPS", 4, 51593},
	{"PRWEB", 5, 51594},
	{"HOLLOWAY", 8, 51595},
	{"TURBULENCE", 10, 51596},
	{"CDRW", 4, 51597},
	{"DFLI", 4, 51598},
	{"UPMA", 4, 51599},
	{"RKOR", 4, 51600},
	{"PLZ", 3, 51601},
	{"LYPI", 4, 51602},
	{"NADU", 4, 51603},
	{"RITCHIE", 7, 51604},
	{"UNDERWRITING", 12, 51605},
	{"DRESSER", 7, 51606},
	{"RULEMAKING", 10, 51607},
	{"RDOI", 4, 51608},
	{"RAKE", 4, 51609},
	{"VALENTINO", 9, 51610},
	{"IAMC", 4, 51611},
	{"IDCH", 4, 51612},
	{"SCOD", 4, 51613},
	{"ORNAMENTAL", 10, 51614},
	{"ULYW", 4, 51615},
	{"RICHES", 6, 51616},
	{"PROLYTE", 7, 51617},
	{"MILLENIUM", 9, 51618},
	{"RTSL", 4, 51619},
	{"COLLECTABLE", 11, 51620},
	{"MFRE", 4, 51621},
	{"STEPHAN", 7, 51622},
	{"UNGG", 4, 51623},
	{"EUPI", 4, 51624},
	{"ARIES", 5, 51625},
	{"GGJ", 3, 51626},
	{"DZM", 3, 51627},
	{"RAMPS", 5, 51628},
	{"TACKLES", 7, 51629},
	{"INJUNCTION", 10, 51630},
	{"YAUG", 4, 51631},
	{"INTERVENE", 9, 51632},
	{"POISED", 6, 51633},
	{"YSAD", 4, 51634},
	{"OCAC", 4, 51635},
	{"LEMB", 4, 51636},
	{"BARKING", 7, 51637},
	{"WALDEN", 6, 51638},
	{"RHAU", 4, 51639},
	{"JOSEPHINE", 9, 51640},
	{"MDUR", 4, 51641},
	{"GPIT", 4, 51642},
	{"DREAD", 5, 51643},
	{"NTFL", 4, 51644},
	{"EYCU", 4, 51645},
	{"CATCHMENT", 9, 51646},
	{"TARGUS", 6, 51647},
	{"RREI", 4, 51648},
	{"PARTITIONING", 12, 51649},
	{"VOICEMAIL", 9, 51650},
	{"ACCT", 4, 51651},
	{"HANDWRITING", 11, 51652},
	{"SHIMANO", 7, 51653},
	{"RIWA", 4, 51654},
	{"SERPENT", 7, 51655},
	{"LINGERE", 7, 51656},
	{"NOWG", 4, 51657},
	{"TAPPED", 6, 51658},
	{"ONYB", 4, 51659},
	{"ARTICULATED", 11, 51660},
	{"PITCHED", 7, 51661},
	{"PARENTHESES", 11, 51662},
	{"CONTEXTUAL", 10, 51663},
	{"DWIF", 4, 51664},
	{"EYEV", 4, 51665},
	{"ILSW", 4, 51666},
	{"UBQ", 3, 51667},
	{"JBY", 3, 51668},
	{"FRUN", 4, 51669},
	{"EMYF", 4, 51670},
	{"OUPD", 4, 51671},
	{"QWEST", 5, 51672},
	{"JIRA", 4, 51673},
	{"CEREVISIAE", 10, 51674},
	{"WISELY", 6, 51675},
	{"ACCUSTOMED", 10, 51676},
	{"EODD", 4, 51677},
	{"BREMEN", 6, 51678},
	{"XINC", 4, 51679},
	{"OWEX", 4, 51680},
	{"FDAN", 4, 51681},
	{"STEAKS", 6, 51682},
	{"DYSON", 5, 51683},
	{"PLAYHOUSE", 9, 51684},
	{"SUPERFICIAL", 11, 51685},
	{"TOXINS", 6, 51686},
	{"CAMARO", 6, 51687},
	{"EEPD", 4, 51688},
	{"JOSEF", 5, 51689},
	{"CASTS", 5, 51690},
	{"BUNK", 4, 51691},
	{"CRYPTOGRAPHY", 12, 51692},
	{"DYER", 4, 51693},
	{"OUPF", 4, 51694},
	{"EFFECTED", 8, 51695},
	{"SIGNALLING", 10, 51696},
	{"DAYCARE", 7, 51697},
	{"MURAKAMI", 8, 51698},
	{"FBEA", 4, 51699},
	{"TUBULAR", 7, 51700},
	{"ORSY", 4, 51701},
	{"MERRIAM", 7, 51702},
	{"GOTR", 4, 51703},
	{"SCORPIO", 7, 51704},
	{"ILDF", 4, 51705},
	{"AVOIDS", 6, 51706},
	{"RRYR", 4, 51707},
	{"USCU", 4, 51708},
	{"RICHTER", 7, 51709},
	{"UNKI", 4, 51710},
	{"ULTRASONIC", 10, 51711},
	{"IBBO", 4, 51712},
	{"HMID", 4, 51713},
	{"EVIDENCED", 9, 51714},
	{"HEINZ", 5, 51715},
	{"ARGOS", 5, 51716},
	{"NKSG", 4, 51717},
	{"LARVAE", 6, 51718},
	{"DYKE", 4, 51719},
	{"ITGR", 4, 51720},
	{"ASHFORD", 7, 51721},
	{"INTERGOVERNMENTAL", 17, 51722},
	{"VEMY", 4, 51723},
	{"HFUN", 4, 51724},
	{"UMSE", 4, 51725},
	{"CASSIDY", 7, 51726},
	{"NTYB", 4, 51727},
	{"PARANOID", 8, 51728},
	{"KERNELS", 7, 51729},
	{"SLUC", 4, 51730},
	{"NBRU", 4, 51731},
	{"MOBILIZATION", 12, 51732},
	{"XVID", 4, 51733},
	{"DMOZ", 4, 51734},
	{"TBOD", 4, 51735},
	{"OVEY", 4, 51736},
	{"IVTOOLS", 7, 51737},
	{"RMYW", 4, 51738},
	{"BARRON", 6, 51739},
	{"ARYU", 4, 51740},
	{"WILKINS", 7, 51741},
	{"SBOY", 4, 51742},
	{"SNORKELING", 10, 51743},
	{"DKAR", 4, 51744},
	{"CHILEAN", 7, 51745},
	{"GOFW", 4, 51746},
	{"BBON", 4, 51747},
	{"SUNY", 4, 51748},
	{"FVIC", 4, 51749},
	{"GIFS", 4, 51750},
	{"QUALIFIER", 9, 51751},
	{"MANIPULATED", 11, 51752},
	{"HANNOVER", 8, 51753},
	{"ALLEVIATE", 9, 51754},
	{"GOFB", 4, 51755},
	{"FUNGAL", 6, 51756},
	{"LIGAND", 6, 51757},
	{"PEOPLESOFT", 10, 51758},
	{"FREELISTS", 9, 51759},
	{"USHW", 4, 51760},
	{"UMWI", 4, 51761},
	{"WMEM", 4, 51762},
	{"RIDDLE", 6, 51763},
	{"COASTLINE", 9, 51764},
	{"NDMR", 4, 51765},
	{"GANB", 4, 51766},
	{"ENUC", 4, 51767},
	{"COMEDIES", 8, 51768},
	{"AKUP", 4, 51769},
	{"FAINTER", 7, 51770},
	{"URTC", 4, 51771},
	{"RESPECTFUL", 10, 51772},
	{"FLAMINGO", 8, 51773},
	{"CABARET", 7, 51774},
	{"ADOG", 4, 51775},
	{"DEFORMATION", 11, 51776},
	{"LTYI", 4, 51777},
	{"AUTU", 4, 51778},
	{"RGOD", 4, 51779},
	{"HOFR", 4, 51780},
	{"KSER", 4, 51781},
	{"RQW", 3, 51782},
	{"BOYC", 4, 51783},
	{"PFIZER", 6, 51784},
	{"ASSEMBLER", 9, 51785},
	{"AWAITED", 7, 51786},
	{"RENOVATIONS", 11, 51787},
	{"LDSB", 4, 51788},
	{"NOZZLE", 6, 51789},
	{"RBAD", 4, 51790},
	{"MUHA", 4, 51791},
	{"EXTERNALLY", 10, 51792},
	{"NEEDY", 5, 51793},
	{"GENBANK", 7, 51794},
	{"NCYM", 4, 51795},
	{"BROADCASTERS", 12, 51796},
	{"GLAC", 4, 51797},
	{"RYNI", 4, 51798},
	{"EMPLOYABILITY", 13, 51799},
	{"WHEELED", 7, 51800},
	{"ILKI", 4, 51801},
	{"GTAK", 4, 51802},
	{"FTOD", 4, 51803},
	{"BOOKSELLERS", 11, 51804},
	{"ULYS", 4, 51805},
	{"NOODLES", 7, 51806},
	{"DARN", 4, 51807},
	{"UPAF", 4, 51808},
	{"EHYD", 4, 51809},
	{"DSOP", 4, 51810},
	{"RENR", 4, 51811},
	{"YUPT", 4, 51812},
	{"MLOC", 4, 51813},
	{"DINERS", 6, 51814},
	{"OGYC", 4, 51815},
	{"GREEKS", 6, 51816},
	{"AULE", 4, 51817},
	{"YZM", 3, 51818},
	{"YRJ", 3, 51819},
	{"RETARDATION", 11, 51820},
	{"SUPERVISING", 11, 51821},
	{"FREEPORT", 8, 51822},
	{"LYME", 4, 51823},
	{"CORNING", 7, 51824},
	{"PROV", 4, 51825},
	{"REICH", 5, 51826},
	{"GHCA", 4, 51827},
	{"CKLO", 4, 51828},
	{"AIDK", 4, 51829},
	{"DISHNETWORK", 11, 51830},
	{"ARMORED", 7, 51831},
	{"WEARY", 5, 51832},
	{"SIXC", 4, 51833},
	{"MYFO", 4, 51834},
	{"OWTR", 4, 51835},
	{"HLOW", 4, 51836},
	{"SOLITARY", 8, 51837},
	{"YCER", 4, 51838},
	{"CLAREMONT", 9, 51839},
	{"OMSW", 4, 51840},
	{"PHOTOGRAPHED", 12, 51841},
	{"TWEED", 5, 51842},
	{"AYSY", 4, 51843},
	{"SNOWY", 5, 51844},
	{"TDRU", 4, 51845},
	{"LLAV", 4, 51846},
	{"PIANIST", 7, 51847},
	{"YMID", 4, 51848},
	{"RTIV", 4, 51849},
	{"SLOU", 4, 51850},
	{"SSYM", 4, 51851},
	{"EMMANUEL", 8, 51852},
	{"ACAPULCO", 8, 51853},
	{"SURROUNDS", 9, 51854},
	{"KNOCKING", 8, 51855},
	{"COSMOPOLITAN", 12, 51856},
	{"MAGISTRATE", 10, 51857},
	{"EVERLASTING", 11, 51858},
	{"CHILDS", 6, 51859},
	{"PIGMENT", 7, 51860},
	{"URHI", 4, 51861},
	{"FACTION", 7, 51862},
	{"FICR", 4, 51863},
	{"BIZKIT", 6, 51864},
	{"ALJA", 4, 51865},
	{"YESC", 4, 51866},
	{"ARGENTINE", 9, 51867},
	{"BLOGOSPHERE", 11, 51868},
	{"ENDOCRINE", 9, 51869},
	{"SCANDINAVIA", 11, 51870},
	{"MINNIE", 6, 51871},
	{"RTBA", 4, 51872},
	{"RESP", 4, 51873},
	{"WDID", 4, 51874},
	{"GENIE", 5, 51875},
	{"ORDN", 4, 51876},
	{"LSEM", 4, 51877},
	{"CARLSBAD", 8, 51878},
	{"AMMO", 4, 51879},
	{"BLING", 5, 51880},
	{"CHARS", 5, 51881},
	{"MCGUIRE", 7, 51882},
	{"IMEV", 4, 51883},
	{"VUF", 3, 51884},
	{"FELY", 4, 51885},
	{"UTILISATION", 11, 51886},
	{"RULINGS", 7, 51887},
	{"LVIE", 4, 51888},
	{"IPSF", 4, 51889},
	{"GLEY", 4, 51890},
	{"HANDEL", 6, 51891},
	{"GEOPHYSICS", 10, 51892},
	{"LUSP", 4, 51893},
	{"DIWO", 4, 51894},
	{"REWB", 4, 51895},
	{"MCNA", 4, 51896},
	{"YJOI", 4, 51897},
	{"IORY", 4, 51898},
	{"MICROSCOPIC", 11, 51899},
	{"NCOC", 4, 51900},
	{"ADUN", 4, 51901},
	{"CLARIFIED", 9, 51902},
	{"COHERENCE", 9, 51903},
	{"SLATER", 6, 51904},
	{"BROCCOLI", 8, 51905},
	{"FOREACH", 7, 51906},
	{"DAYG", 4, 51907},
	{"LMAI", 4, 51908},
	{"GAFO", 4, 51909},
	{"OAKWOOD", 7, 51910},
	{"URSB", 4, 51911},
	{"LFLI", 4, 51912},
	{"SENSATIONS", 10, 51913},
	{"YROC", 4, 51914},
	{"DYSE", 4, 51915},
	{"ORPHAN", 6, 51916},
	{"CONFERRED", 9, 51917},
	{"ODWO", 4, 51918},
	{"MCGEE", 5, 51919},
	{"ELFL", 4, 51920},
	{"KISSIMMEE", 9, 51921},
	{"VEOP", 4, 51922},
	{"DISTURBANCES", 12, 51923},
	{"RSCU", 4, 51924},
	{"CHANDELIER", 10, 51925},
	{"LINKER", 6, 51926},
	{"EMBRYONIC", 9, 51927},
	{"UTCL", 4, 51928},
	{"PALC", 4, 51929},
	{"TETRIS", 6, 51930},
	{"NWRO", 4, 51931},
	{"CARVER", 6, 51932},
	{"WYZ", 3, 51933},
	{"MGRA", 4, 51934},
	{"PATERSON", 8, 51935},
	{"IPGA", 4, 51936},
	{"RGYT", 4, 51937},
	{"ADJO", 4, 51938},
	{"DELLE", 5, 51939},
	{"GRACEFUL", 8, 51940},
	{"SYNCHRONIZED", 12, 51941},
	{"CKTR", 4, 51942},
	{"INTERCEPT", 9, 51943},
	{"NEYR", 4, 51944},
	{"MREL", 4, 51945},
	{"TYDO", 4, 51946},
	{"HSBC", 4, 51947},
	{"SHELLFISH", 9, 51948},
	{"SHOUTS", 6, 51949},
	{"ASCERTAIN", 9, 51950},
	{"NCYB", 4, 51951},
	{"ASTORIA", 7, 51952},
	{"OYCE", 4, 51953},
	{"JORT", 4, 51954},
	{"TRAJECTORY", 10, 51955},
	{"PLYO", 4, 51956},
	{"EPSILON", 7, 51957},
	{"OGOW", 4, 51958},
	{"EXHAUSTIVE", 10, 51959},
	{"SLYR", 4, 51960},
	{"OKMO", 4, 51961},
	{"UBDI", 4, 51962},
	{"ANNOYED", 7, 51963},
	{"BUREAUCRACY", 11, 51964},
	{"URNW", 4, 51965},
	{"KNOWLES", 7, 51966},
	{"ASTROPHYSICS", 12, 51967},
	{"STALLS", 6, 51968},
	{"FINED", 5, 51969},
	{"RONJ", 4, 51970},
	{"OLAB", 4, 51971},
	{"HANSARD", 7, 51972},
	{"INWARD", 6, 51973},
	{"REFLECTOR", 9, 51974},
	{"GREETED", 7, 51975},
	{"OFID", 4, 51976},
	{"HARTLEY", 7, 51977},
	{"CKSD", 4, 51978},
	{"DEFENSES", 8, 51979},
	{"KOFR", 4, 51980},
	{"MEANINGLESS", 11, 51981},
	{"UTUM", 4, 51982},
	{"AUTHORISATION", 13, 51983},
	{"RBOS", 4, 51984},
	{"CRUN", 4, 51985},
	{"YSFA", 4, 51986},
	{"CLAM", 4, 51987},
	{"VAMPIRES", 8, 51988},
	{"LMOU", 4, 51989},
	{"RELOCATE", 8, 51990},
	{"NERD", 4, 51991},
	{"FRANCESCO", 9, 51992},
	{"FFHA", 4, 51993},
	{"GEORG", 5, 51994},
	{"UNSF", 4, 51995},
	{"NEGLIGIBLE", 10, 51996},
	{"STARCH", 6, 51997},
	{"MELINDA", 7, 51998},
	{"GODFATHER", 9, 51999},
	{"DJOS", 4, 52000},
	{"APRON", 5, 52001},
	{"RORB", 4, 52002},
	{"GLAZING", 7, 52003},
	{"GUTS", 4, 52004},
	{"PRAGMATIC", 9, 52005},
	{"TYRANNY", 7, 52006},
	{"PROVISIONING", 12, 52007},
	{"WAREHOUSES", 10, 52008},
	{"REGIMEN", 7, 52009},
	{"IPOL", 4, 52010},
	{"AXEL", 4, 52011},
	{"WNRI", 4, 52012},
	{"MPAG", 4, 52013},
	{"EXPANDABLE", 10, 52014},
	{"ANTONY", 6, 52015},
	{"MASERATI", 8, 52016},
	{"ALFH", 4, 52017},
	{"FLUFFY", 6, 52018},
	{"MARIANNE", 8, 52019},
	{"HFAM", 4, 52020},
	{"ERUB", 4, 52021},
	{"DGUY", 4, 52022},
	{"SLENDER", 7, 52023},
	{"ULGE", 4, 52024},
	{"SCOF", 4, 52025},
	{"HEREFORD", 8, 52026},
	{"BENDER", 6, 52027},
	{"DVEH", 4, 52028},
	{"RELIABLY", 8, 52029},
	{"AIDES", 5, 52030},
	{"FORMA", 5, 52031},
	{"BUMT", 4, 52032},
	{"AVYS", 4, 52033},
	{"YSSU", 4, 52034},
	{"WMAR", 4, 52035},
	{"SBYH", 4, 52036},
	{"LPIT", 4, 52037},
	{"RGRI", 4, 52038},
	{"SENDO", 5, 52039},
	{"RCHL", 4, 52040},
	{"KEBU", 4, 52041},
	{"ABSORBING", 9, 52042},
	{"RMWI", 4, 52043},
	{"GAGI", 4, 52044},
	{"CHERRIES", 8, 52045},
	{"HASBRO", 6, 52046},
	{"GAELIC", 6, 52047},
	{"GOMEZ", 5, 52048},
	{"ALEC", 4, 52049},
	{"CORBA", 5, 52050},
	{"MEFU", 4, 52051},
	{"POLSKI", 6, 52052},
	{"SDOL", 4, 52053},
	{"DISTINGUISHING", 14, 52054},
	{"MULTIDISCIPLINARY", 17, 52055},
	{"SORU", 4, 52056},
	{"OOPP", 4, 52057},
	{"VENTRICULAR", 11, 52058},
	{"GLAZED", 6, 52059},
	{"RDAD", 4, 52060},
	{"JUDD", 4, 52061},
	{"FAWO", 4, 52062},
	{"DASHED", 6, 52063},
	{"SBYF", 4, 52064},
	{"PETERSEN", 8, 52065},
	{"LIBYAN", 6, 52066},
	{"NEYD", 4, 52067},
	{"DICKSON", 7, 52068},
	{"DISTRESSED", 10, 52069},
	{"NYFR", 4, 52070},
	{"OUMU", 4, 52071},
	{"MACQUARIE", 9, 52072},
	{"MYSP", 4, 52073},
	{"SHOUTING", 8, 52074},
	{"PSPE", 4, 52075},
	{"BULLOCK", 7, 52076},
	{"OFFG", 4, 52077},
	{"VILLAGERS", 9, 52078},
	{"TRANSFERABLE", 12, 52079},
	{"ANGK", 4, 52080},
	{"YUMMY", 5, 52081},
	{"BLYN", 4, 52082},
	{"ACKNOWLEDGMENTS", 15, 52083},
	{"NDEG", 4, 52084},
	{"AVYA", 4, 52085},
	{"ETHIOPIAN", 9, 52086},
	{"MOMMA", 5, 52087},
	{"LEHIGH", 6, 52088},
	{"MERMAID", 7, 52089},
	{"BUDS", 4, 52090},
	{"CONCORDANCE", 11, 52091},
	{"GREENBERG", 9, 52092},
	{"DSDI", 4, 52093},
	{"TRISH", 5, 52094},
	{"ILKE", 4, 52095},
	{"WILDER", 6, 52096},
	{"ANKM", 4, 52097},
	{"CENTRED", 7, 52098},
	{"CONFINEMENT", 11, 52099},
	{"ISLANDERS", 9, 52100},
	{"DING", 4, 52101},
	{"ITYV", 4, 52102},
	{"CONTESTED", 9, 52103},
	{"COMA", 4, 52104},
	{"HUSKY", 5, 52105},
	{"CONSERVE", 8, 52106},
	{"TCHD", 4, 52107},
	{"YRIS", 4, 52108},
	{"THDU", 4, 52109},
	{"BLAND", 5, 52110},
	{"ELECTRODES", 10, 52111},
	{"GUEF", 4, 52112},
	{"SVCD", 4, 52113},
	{"CRON", 4, 52114},
	{"DARTH", 5, 52115},
	{"WTOD", 4, 52116},
	{"ABATEMENT", 9, 52117},
	{"CRAMER", 6, 52118},
	{"YUP", 3, 52119},
	{"ESLU", 4, 52120},
	{"ORIGINATOR", 10, 52121},
	{"CHING", 5, 52122},
	{"ALTU", 4, 52123},
	{"WHIPPING", 8, 52124},
	{"SKIPPING", 8, 52125},
	{"MELANOMA", 8, 52126},
	{"ILPA", 4, 52127},
	{"SBYR", 4, 52128},
	{"THUG", 4, 52129},
	{"ROUTED", 6, 52130},
	{"HLYR", 4, 52131},
	{"RUDOLPH", 7, 52132},
	{"ABIGAIL", 7, 52133},
	{"MISSIONARIES", 12, 52134},
	{"YUGOSLAV", 8, 52135},
	{"OFFD", 4, 52136},
	{"ICGO", 4, 52137},
	{"HOUSEHOLDER", 11, 52138},
	{"MEMU", 4, 52139},
	{"AFTP", 4, 52140},
	{"CPAN", 4, 52141},
	{"PLOTTING", 8, 52142},
	{"MEJU", 4, 52143},
	{"ELIP", 4, 52144},
	{"WEPL", 4, 52145},
	{"NMEL", 4, 52146},
	{"SUCCEEDING", 10, 52147},
	{"BIZJOURNALSHIRE", 15, 52148},
	{"SHAVER", 6, 52149},
	{"GRAMMY", 6, 52150},
	{"EADG", 4, 52151},
	{"ELMER", 5, 52152},
	{"FIBROSIS", 8, 52153},
	{"MREP", 4, 52154},
	{"MCAM", 4, 52155},
	{"ORKU", 4, 52156},
	{"SAILS", 5, 52157},
	{"OPEL", 4, 52158},
	{"LHAP", 4, 52159},
	{"SCHUSTER", 8, 52160},
	{"HUMMINGBIRD", 11, 52161},
	{"SUNB", 4, 52162},
	{"ARSG", 4, 52163},
	{"PORTED", 6, 52164},
	{"ACIV", 4, 52165},
	{"MEOV", 4, 52166},
	{"FHED", 4, 52167},
	{"ROBES", 5, 52168},
	{"MYGR", 4, 52169},
	{"FUNGUS", 6, 52170},
	{"ASTONISHING", 11, 52171},
	{"POLYETHYLENE", 12, 52172},
	{"GRAVEYARD", 9, 52173},
	{"CHUNKS", 6, 52174},
	{"BOURNE", 6, 52175},
	{"REVERT", 6, 52176},
	{"OXYG", 4, 52177},
	{"IGNORES", 7, 52178},
	{"MASD", 4, 52179},
	{"EUSB", 4, 52180},
	{"PARAMETRIC", 10, 52181},
	{"POPPING", 7, 52182},
	{"CAPTAINS", 8, 52183},
	{"LOAF", 4, 52184},
	{"AWARDING", 8, 52185},
	{"RJOS", 4, 52186},
	{"WSFR", 4, 52187},
	{"DKK", 3, 52188},
	{"KCZ", 3, 52189},
	{"SUPERBOWL", 9, 52190},
	{"PANDORA", 7, 52191},
	{"HASKELL", 7, 52192},
	{"DALC", 4, 52193},
	{"FLATWARE", 8, 52194},
	{"SKID", 4, 52195},
	{"EYEGLASSES", 10, 52196},
	{"OFWR", 4, 52197},
	{"ESUD", 4, 52198},
	{"FENTON", 6, 52199},
	{"POLARIS", 7, 52200},
	{"GABRIELLE", 9, 52201},
	{"FORMULATIONS", 12, 52202},
	{"ABEL", 4, 52203},
	{"BGP", 3, 52204},
	{"UREX", 4, 52205},
	{"ENIGMA", 6, 52206},
	{"PINP", 4, 52207},
	{"LRUL", 4, 52208},
	{"GLANDS", 6, 52209},
	{"PARENTHOOD", 10, 52210},
	{"NUEW", 4, 52211},
	{"TAXB", 4, 52212},
	{"SJAM", 4, 52213},
	{"RSIZ", 4, 52214},
	{"MILITANT", 8, 52215},
	{"ODBA", 4, 52216},
	{"ICHY", 4, 52217},
	{"LATINOS", 7, 52218},
	{"ARTWORKS", 8, 52219},
	{"RJOI", 4, 52220},
	{"RICM", 4, 52221},
	{"DOHERTY", 7, 52222},
	{"JUG", 3, 52223},
	{"INFERNO", 7, 52224},
	{"NBLU", 4, 52225},
	{"GOWA", 4, 52226},
	{"RKPL", 4, 52227},
	{"NDPM", 4, 52228},
	{"DNOC", 4, 52229},
	{"ALLEGHENY", 9, 52230},
	{"ARENAS", 6, 52231},
	{"LABU", 4, 52232},
	{"ERMT", 4, 52233},
	{"ARYV", 4, 52234},
	{"TORRENTS", 8, 52235},
	{"COMPRESSORS", 11, 52236},
	{"OUTSET", 6, 52237},
	{"MINB", 4, 52238},
	{"EXCLUSIVES", 10, 52239},
	{"YVONNE", 6, 52240},
	{"APUN", 4, 52241},
	{"ATTACHING", 9, 52242},
	{"RTUP", 4, 52243},
	{"ADEPT", 5, 52244},
	{"LOUNGES", 7, 52245},
	{"TBYP", 4, 52246},
	{"DOUBTFUL", 8, 52247},
	{"INKP", 4, 52248},
	{"HBEF", 4, 52249},
	{"RIGE", 4, 52250},
	{"FCLO", 4, 52251},
	{"CTWO", 4, 52252},
	{"CONSULTATIVE", 12, 52253},
	{"RATIFIED", 8, 52254},
	{"UECA", 4, 52255},
	{"SGER", 4, 52256},
	{"NDSG", 4, 52257},
	{"CTYO", 4, 52258},
	{"AMDI", 4, 52259},
	{"INSECURE", 8, 52260},
	{"AILP", 4, 52261},
	{"EXPLOSIONS", 10, 52262},
	{"AYDA", 4, 52263},
	{"EYGA", 4, 52264},
	{"DDHA", 4, 52265},
	{"UCHG", 4, 52266},
	{"ODIU", 4, 52267},
	{"VYWE", 4, 52268},
	{"CONVEYOR", 8, 52269},
	{"GNFO", 4, 52270},
	{"FWEL", 4, 52271},
	{"NORMATIVE", 9, 52272},
	{"TRUNKS", 6, 52273},
	{"RZP", 3, 52274},
	{"GARETH", 6, 52275},
	{"SURG", 4, 52276},
	{"GESD", 4, 52277},
	{"OXOF", 4, 52278},
	{"OWAP", 4, 52279},
	{"OMAU", 4, 52280},
	{"VERSATILITY", 11, 52281},
	{"RDDO", 4, 52282},
	{"BEDF", 4, 52283},
	{"MBAI", 4, 52284},
	{"DPOU", 4, 52285},
	{"HIML", 4, 52286},
	{"ORJE", 4, 52287},
	{"MCKAY", 5, 52288},
	{"LOTHIAN", 7, 52289},
	{"CYFO", 4, 52290},
	{"NYGO", 4, 52291},
	{"INTRICATE", 9, 52292},
	{"STRATA", 6, 52293},
	{"SOLVER", 6, 52294},
	{"OTQU", 4, 52295},
	{"LACIE", 5, 52296},
	{"SOLVENTS", 8, 52297},
	{"DEPOSITORY", 10, 52298},
	{"HUBERT", 6, 52299},
	{"PROCLAMATION", 12, 52300},
	{"WNSP", 4, 52301},
	{"BEAUTIES", 8, 52302},
	{"HYBRIDS", 7, 52303},
	{"KUDOS", 5, 52304},
	{"GILLIAN", 7, 52305},
	{"DARRELL", 7, 52306},
	{"EMUT", 4, 52307},
	{"TVIL", 4, 52308},
	{"LFWH", 4, 52309},
	{"DFOC", 4, 52310},
	{"CREAMS", 6, 52311},
	{"IRRESPECTIVE", 12, 52312},
	{"LBOT", 4, 52313},
	{"KWOU", 4, 52314},
	{"HANDBOOKS", 9, 52315},
	{"YELI", 4, 52316},
	{"QUEC", 4, 52317},
	{"IMPOSITION", 10, 52318},
	{"TARF", 4, 52319},
	{"SHAWNEE", 7, 52320},
	{"CROWLEY", 7, 52321},
	{"OCKL", 4, 52322},
	{"BYWO", 4, 52323},
	{"ENSURED", 7, 52324},
	{"BUTALBITAL", 10, 52325},
	{"KIDNAPPED", 9, 52326},
	{"CEREALS", 7, 52327},
	{"GFIL", 4, 52328},
	{"REPH", 4, 52329},
	{"ADYM", 4, 52330},
	{"OUTRAGE", 7, 52331},
	{"POOP", 4, 52332},
	{"UMIL", 4, 52333},
	{"SCRUBS", 6, 52334},
	{"UCHN", 4, 52335},
	{"ORCHESTRAL", 10, 52336},
	{"IERM", 4, 52337},
	{"MDOT", 4, 52338},
	{"COLDWELL", 8, 52339},
	{"DEPTS", 5, 52340},
	{"GWAL", 4, 52341},
	{"BELLINGHAM", 10, 52342},
	{"VETERINARIAN", 12, 52343},
	{"DRIPPING", 8, 52344},
	{"TYAD", 4, 52345},
	{"GFAN", 4, 52346},
	{"MERSEYSIDE", 10, 52347},
	{"KRONA", 5, 52348},
	{"DYON", 4, 52349},
	{"DISSEMINATE", 11, 52350},
	{"FACETS", 6, 52351},
	{"MUSIQUE", 7, 52352},
	{"HYWE", 4, 52353},
	{"FRIGHTENED", 10, 52354},
	{"NOISES", 6, 52355},
	{"NBUY", 4, 52356},
	{"AMBIGUITY", 9, 52357},
	{"ENMY", 4, 52358},
	{"BOOTHS", 6, 52359},
	{"ELUSIVE", 7, 52360},
	{"GNPO", 4, 52361},
	{"SPECULATIVE", 11, 52362},
	{"PUGET", 5, 52363},
	{"NKFO", 4, 52364},
	{"MADEIRA", 7, 52365},
	{"COASTERS", 8, 52366},
	{"XYGE", 4, 52367},
	{"LBYT", 4, 52368},
	{"OWAV", 4, 52369},
	{"EWAD", 4, 52370},
	{"INTIMACY", 8, 52371},
	{"NAGG", 4, 52372},
	{"GEOLOGIC", 8, 52373},
	{"FLEETWOOD", 9, 52374},
	{"GECR", 4, 52375},
	{"ODMO", 4, 52376},
	{"FELDMAN", 7, 52377},
	{"NKWH", 4, 52378},
	{"WHEY", 4, 52379},
	{"RIPPING", 7, 52380},
	{"ENDOCRINOLOGY", 13, 52381},
	{"YRID", 4, 52382},
	{"EFTC", 4, 52383},
	{"REPLICAS", 8, 52384},
	{"HPOW", 4, 52385},
	{"ABOD", 4, 52386},
	{"POLYGON", 7, 52387},
	{"MCG", 3, 52388},
	{"RELOADED", 8, 52389},
	{"GARRY", 5, 52390},
	{"VKU", 3, 52391},
	{"RYDU", 4, 52392},
	{"ESTER", 5, 52393},
	{"EELW", 4, 52394},
	{"KWAZULU", 7, 52395},
	{"SERVO", 5, 52396},
	{"NOBJ", 4, 52397},
	{"RIPARIAN", 8, 52398},
	{"OMCL", 4, 52399},
	{"THRIVING", 8, 52400},
	{"HAMPERS", 7, 52401},
	{"BRAGG", 5, 52402},
	{"RKIT", 4, 52403},
	{"FADV", 4, 52404},
	{"GRACIOUS", 8, 52405},
	{"DIFH", 4, 52406},
	{"GUELPH", 6, 52407},
	{"TENUATE", 7, 52408},
	{"SNAIL", 5, 52409},
	{"MBEH", 4, 52410},
	{"CTOU", 4, 52411},
	{"CURATOR", 7, 52412},
	{"UTOV", 4, 52413},
	{"CURT", 4, 52414},
	{"JAIME", 5, 52415},
	{"DEMISE", 6, 52416},
	{"THEORETICALLY", 13, 52417},
	{"EEPB", 4, 52418},
	{"GROOVES", 7, 52419},
	{"SUTRA", 5, 52420},
	{"RROC", 4, 52421},
	{"TSUF", 4, 52422},
	{"NSPU", 4, 52423},
	{"MOWER", 5, 52424},
	{"RETL", 4, 52425},
	{"RESG", 4, 52426},
	{"CONVEYED", 8, 52427},
	{"VILR", 4, 52428},
	{"TIGU", 4, 52429},
	{"KLYB", 4, 52430},
	{"RYRI", 4, 52431},
	{"LLEB", 4, 52432},
	{"GAMESTATS", 9, 52433},
	{"LVL", 3, 52434},
	{"OFKO", 4, 52435},
	{"SWINE", 5, 52436},
	{"FAXING", 6, 52437},
	{"ELDD", 4, 52438},
	{"ELPC", 4, 52439},
	{"MEYERS", 6, 52440},
	{"LSLE", 4, 52441},
	{"KEYF", 4, 52442},
	{"TYPOGRAPHICAL", 13, 52443},
	{"ELLISON", 7, 52444},
	{"KFUL", 4, 52445},
	{"TESTSUITE", 9, 52446},
	{"YBEO", 4, 52447},
	{"TROPHIES", 8, 52448},
	{"QUICKEN", 7, 52449},
	{"YONW", 4, 52450},
	{"DYBU", 4, 52451},
	{"HABR", 4, 52452},
	{"STRESSFUL", 9, 52453},
	{"WERDEN", 6, 52454},
	{"HERON", 5, 52455},
	{"EXTRANET", 8, 52456},
	{"REMASTERED", 10, 52457},
	{"UFFO", 4, 52458},
	{"NPOU", 4, 52459},
	{"LICM", 4, 52460},
	{"GRAFT", 5, 52461},
	{"LPAL", 4, 52462},
	{"LANB", 4, 52463},
	{"SRAP", 4, 52464},
	{"NLYK", 4, 52465},
	{"CROSSINGS", 9, 52466},
	{"DERRICK", 7, 52467},
	{"LLEP", 4, 52468},
	{"EASTWOOD", 8, 52469},
	{"HANDSPRING", 10, 52470},
	{"GERM", 4, 52471},
	{"ENVOY", 5, 52472},
	{"WWER", 4, 52473},
	{"HORG", 4, 52474},
	{"GERBER", 6, 52475},
	{"BRECKENRIDGE", 12, 52476},
	{"DURAN", 5, 52477},
	{"PUG", 3, 52478},
	{"SUSB", 4, 52479},
	{"ANTOINE", 7, 52480},
	{"AQUARIUS", 8, 52481},
	{"DOMINGO", 7, 52482},
	{"NGJE", 4, 52483},
	{"MMAL", 4, 52484},
	{"RESEMBLES", 9, 52485},
	{"STENCIL", 7, 52486},
	{"IFAL", 4, 52487},
	{"AKOU", 4, 52488},
	{"SCIFI", 5, 52489},
	{"MINM", 4, 52490},
	{"GRANDSON", 8, 52491},
	{"IRDD", 4, 52492},
	{"CATALINA", 8, 52493},
	{"REDDING", 7, 52494},
	{"REDIRECTION", 11, 52495},
	{"ACCOMPANIMENT", 13, 52496},
	{"RAMH", 4, 52497},
	{"BYEA", 4, 52498},
	{"DERIVATION", 10, 52499},
	{"RPOT", 4, 52500},
	{"ABYT", 4, 52501},
	{"SHOWCASES", 9, 52502},
	{"WARDEN", 6, 52503},
	{"RDAG", 4, 52504},
	{"VOIR", 4, 52505},
	{"OGYS", 4, 52506},
	{"KPRE", 4, 52507},
	{"HYDI", 4, 52508},
	{"MSWO", 4, 52509},
	{"IMJU", 4, 52510},
	{"LYVO", 4, 52511},
	{"RRYL", 4, 52512},
	{"REFINERY", 8, 52513},
	{"MYMA", 4, 52514},
	{"MARGARITA", 9, 52515},
	{"LSIM", 4, 52516},
	{"CLANS", 5, 52517},
	{"INSTITUTED", 10, 52518},
	{"NOTARY", 6, 52519},
	{"SLAK", 4, 52520},
	{"DHEF", 4, 52521},
	{"ORMR", 4, 52522},
	{"IMPU", 4, 52523},
	{"ABORT", 5, 52524},
	{"RDBR", 4, 52525},
	{"SCHROEDER", 9, 52526},
	{"XTTW", 4, 52527},
	{"INDENT", 6, 52528},
	{"SOCIOLOGICAL", 12, 52529},
	{"ROSB", 4, 52530},
	{"EVEC", 4, 52531},
	{"CHARDONNAY", 10, 52532},
	{"REMOVALS", 8, 52533},
	{"UPBU", 4, 52534},
	{"MICG", 4, 52535},
	{"ANTRIM", 6, 52536},
	{"OFFENDING", 9, 52537},
	{"FORGETTING", 10, 52538},
	{"IRGO", 4, 52539},
	{"IDAP", 4, 52540},
	{"MACEDONIAN", 10, 52541},
	{"IMAF", 4, 52542},
	{"ACCELERATING", 12, 52543},
	{"VOTRE", 5, 52544},
	{"IAFR", 4, 52545},
	{"GUESTHOUSE", 10, 52546},
	{"RESERVOIRS", 10, 52547},
	{"MYBA", 4, 52548},
	{"BARLOW", 6, 52549},
	{"TYRONE", 6, 52550},
	{"HALLE", 5, 52551},
	{"GYQ", 3, 52552},
	{"CZC", 3, 52553},
	{"CYZ", 3, 52554},
	{"EDGED", 5, 52555},
	{"INSIDERS", 8, 52556},
	{"TBYM", 4, 52557},
	{"ENCOMPASS", 9, 52558},
	{"DUVET", 5, 52559},
	{"ULMA", 4, 52560},
	{"ICSY", 4, 52561},
	{"SPADE", 5, 52562},
	{"HERMES", 6, 52563},
	{"TBLU", 4, 52564},
	{"GLARE", 5, 52565},
	{"METAPHYSICAL", 12, 52566},
	{"SFLI", 4, 52567},
	{"DESR", 4, 52568},
	{"DECODE", 6, 52569},
	{"LOONEY", 6, 52570},
	{"INSIGNIFICANT", 13, 52571},
	{"LCIR", 4, 52572},
	{"KSBY", 4, 52573},
	{"FKEN", 4, 52574},
	{"EXCHANGING", 10, 52575},
	{"YPEC", 4, 52576},
	{"RYAM", 4, 52577},
	{"ILBA", 4, 52578},
	{"PLEDGES", 7, 52579},
	{"WANY", 4, 52580},
	{"CTMO", 4, 52581},
	{"MENTALITY", 9, 52582},
	{"BRIGHAM", 7, 52583},
	{"OALM", 4, 52584},
	{"TURBULENT", 9, 52585},
	{"UTDU", 4, 52586},
	{"NPAG", 4, 52587},
	{"LCAU", 4, 52588},
	{"OPUN", 4, 52589},
	{"JEWELERS", 8, 52590},
	{"LENW", 4, 52591},
	{"KRES", 4, 52592},
	{"HSPR", 4, 52593},
	{"PUP", 3, 52594},
	{"JUNEAU", 6, 52595},
	{"ICWE", 4, 52596},
	{"DILUTION", 8, 52597},
	{"FKNO", 4, 52598},
	{"GHRA", 4, 52599},
	{"FORTUNES", 8, 52600},
	{"SULTAN", 6, 52601},
	{"MASKED", 6, 52602},
	{"CASING", 6, 52603},
	{"WNCH", 4, 52604},
	{"EURB", 4, 52605},
	{"VETERINARIANS", 13, 52606},
	{"LEYL", 4, 52607},
	{"BALW", 4, 52608},
	{"RSUM", 4, 52609},
	{"PLOTTED", 7, 52610},
	{"COLOURFUL", 9, 52611},
	{"YSQU", 4, 52612},
	{"GRIDS", 5, 52613},
	{"SIGHTINGS", 9, 52614},
	{"BINUTILS", 8, 52615},
	{"HCRI", 4, 52616},
	{"SPACER", 6, 52617},
	{"MICROPROCESSOR", 14, 52618},
	{"HALEY", 5, 52619},
	{"DELOITTE", 8, 52620},
	{"CLAIBORNE", 9, 52621},
	{"CLIE", 4, 52622},
	{"CDM", 3, 52623},
	{"GENEROUSLY", 10, 52624},
	{"SPILLS", 6, 52625},
	{"MISF", 4, 52626},
	{"ASSISTIVE", 9, 52627},
	{"AMOUNTED", 8, 52628},
	{"CGAM", 4, 52629},
	{"WWEL", 4, 52630},
	{"EMSB", 4, 52631},
	{"DGUA", 4, 52632},
	{"YNEX", 4, 52633},
	{"UWON", 4, 52634},
	{"CHRONOGRAPH", 11, 52635},
	{"LEGU", 4, 52636},
	{"REFUNDED", 8, 52637},
	{"SUNNYVALE", 9, 52638},
	{"REPRESSION", 10, 52639},
	{"DWRO", 4, 52640},
	{"REAPER", 6, 52641},
	{"DLYP", 4, 52642},
	{"HONORING", 8, 52643},
	{"SPAMCOP", 7, 52644},
	{"FACTO", 5, 52645},
	{"ULTB", 4, 52646},
	{"YBEW", 4, 52647},
	{"HLYC", 4, 52648},
	{"BYFE", 4, 52649},
	{"LOVIN", 5, 52650},
	{"EMBRACING", 9, 52651},
	{"FMER", 4, 52652},
	{"WOWA", 4, 52653},
	{"CLIMATIC", 8, 52654},
	{"NKWI", 4, 52655},
	{"MINIMISE", 8, 52656},
	{"BROADEN", 7, 52657},
	{"TARL", 4, 52658},
	{"SALINITY", 8, 52659},
	{"OLSY", 4, 52660},
	{"NBSP", 4, 52661},
	{"BEGGING", 7, 52662},
	{"UHAM", 4, 52663},
	{"OUDT", 4, 52664},
	{"SPECIALISING", 12, 52665},
	{"RGHA", 4, 52666},
	{"HANDOUT", 7, 52667},
	{"YOFJ", 4, 52668},
	{"WHARTON", 7, 52669},
	{"ROUTLEDGE", 9, 52670},
	{"IEBR", 4, 52671},
	{"RAMIREZ", 7, 52672},
	{"IGNU", 4, 52673},
	{"FREDDY", 6, 52674},
	{"AWLI", 4, 52675},
	{"BUSHES", 6, 52676},
	{"AMCH", 4, 52677},
	{"REMB", 4, 52678},
	{"HAIKU", 5, 52679},
	{"YRUL", 4, 52680},
	{"YZP", 3, 52681},
	{"WMEX", 4, 52682},
	{"RESTRAINTS", 10, 52683},
	{"PAISLEY", 7, 52684},
	{"ECKW", 4, 52685},
	{"TELEMARKETING", 13, 52686},
	{"IDPO", 4, 52687},
	{"CUTOFF", 6, 52688},
	{"TRUNCATED", 9, 52689},
	{"GIBBONS", 7, 52690},
	{"IFEP", 4, 52691},
	{"NITRIC", 6, 52692},
	{"VISUALS", 7, 52693},
	{"BREADS", 6, 52694},
	{"SPAU", 4, 52695},
	{"SMDA", 4, 52696},
	{"LDDR", 4, 52697},
	{"GLOVER", 6, 52698},
	{"YALB", 4, 52699},
	{"FPEA", 4, 52700},
	{"ASLU", 4, 52701},
	{"RAILROADS", 9, 52702},
	{"UNICORN", 7, 52703},
	{"NORMANDY", 8, 52704},
	{"MARTINA", 7, 52705},
	{"MCLAUGHLIN", 10, 52706},
	{"ORSG", 4, 52707},
	{"QUEZ", 4, 52708},
	{"LPAI", 4, 52709},
	{"HLYA", 4, 52710},
	{"CEMU", 4, 52711},
	{"FLOATS", 6, 52712},
	{"HEADLIGHT", 9, 52713},
	{"KEMP", 4, 52714},
	{"RKHO", 4, 52715},
	{"JUSTICES", 8, 52716},
	{"ORDERLY", 7, 52717},
	{"REWC", 4, 52718},
	{"AMIG", 4, 52719},
	{"FEXC", 4, 52720},
	{"PIPERMAIL", 9, 52721},
	{"RMOM", 4, 52722},
	{"SONNERIES", 9, 52723},
	{"WAFER", 5, 52724},
	{"ODLI", 4, 52725},
	{"NELD", 4, 52726},
	{"CLINICIANS", 10, 52727},
	{"LSBO", 4, 52728},
	{"GHRI", 4, 52729},
	{"PUCK", 4, 52730},
	{"SICR", 4, 52731},
	{"ENTERTAINERS", 12, 52732},
	{"TRIPP", 5, 52733},
	{"PETERTHOENY", 11, 52734},
	{"BLOCKERS", 8, 52735},
	{"ROOFS", 5, 52736},
	{"REEFS", 5, 52737},
	{"JAMAICAN", 8, 52738},
	{"CTEX", 4, 52739},
	{"DACI", 4, 52740},
	{"HOVER", 5, 52741},
	{"ENDOGENOUS", 10, 52742},
	{"QUARANTINE", 10, 52743},
	{"TWEV", 4, 52744},
	{"MEMOREX", 7, 52745},
	{"SHOWTIME", 8, 52746},
	{"NARCOTICS", 9, 52747},
	{"EBYH", 4, 52748},
	{"DETRIMENTAL", 11, 52749},
	{"OCEANFRONT", 10, 52750},
	{"NYFI", 4, 52751},
	{"MTIM", 4, 52752},
	{"MOLDS", 5, 52753},
	{"IDAM", 4, 52754},
	{"ELIAS", 5, 52755},
	{"FLANGE", 6, 52756},
	{"REALPLAYER", 10, 52757},
	{"MCC", 3, 52758},
	{"SUBSISTENCE", 11, 52759},
	{"CHILLED", 7, 52760},
	{"CITADEL", 7, 52761},
	{"WSTU", 4, 52762},
	{"DEFU", 4, 52763},
	{"MPAA", 4, 52764},
	{"GOGH", 4, 52765},
	{"TOPOGRAPHY", 10, 52766},
	{"ALLENTOWN", 9, 52767},
	{"LEAFLETS", 8, 52768},
	{"ROMERO", 6, 52769},
	{"BNWT", 4, 52770},
	{"GSCR", 4, 52771},
	{"WRINKLE", 7, 52772},
	{"CONTEMPLATED", 12, 52773},
	{"FPOP", 4, 52774},
	{"TBIR", 4, 52775},
	{"NEUV", 4, 52776},
	{"PREDEFINED", 10, 52777},
	{"LQW", 3, 52778},
	{"ADOLESCENCE", 11, 52779},
	{"FOFA", 4, 52780},
	{"HARMON", 6, 52781},
	{"NCYF", 4, 52782},
	{"NBYR", 4, 52783},
	{"INDULGE", 7, 52784},
	{"BERNHARD", 8, 52785},
	{"BYOU", 4, 52786},
	{"HEARTH", 6, 52787},
	{"SADU", 4, 52788},
	{"BUZZNET", 7, 52789},
	{"EEDP", 4, 52790},
	{"GBAL", 4, 52791},
	{"AGGRESSIVELY", 12, 52792},
	{"MELODIC", 7, 52793},
	{"KDAY", 4, 52794},
	{"COINCIDE", 8, 52795},
	{"GHWE", 4, 52796},
	{"NAICS", 5, 52797},
	{"TRANSGENIC", 10, 52798},
	{"AXIM", 4, 52799},
	{"MAYNARD", 7, 52800},
	{"BROOKFIELD", 10, 52801},
	{"EQUO", 4, 52802},
	{"EEKM", 4, 52803},
	{"AYFA", 4, 52804},
	{"GENOA", 5, 52805},
	{"DRUL", 4, 52806},
	{"FHEC", 4, 52807},
	{"ENLIGHTENED", 11, 52808},
	{"FTCO", 4, 52809},
	{"VISCOSITY", 9, 52810},
	{"CLIPPINGS", 9, 52811},
	{"UTAK", 4, 52812},
	{"RADICALS", 8, 52813},
	{"BENGALS", 7, 52814},
	{"ESTIMATOR", 9, 52815},
	{"CONCURRENTLY", 12, 52816},
	{"PENETRATE", 9, 52817},
	{"STRIDE", 6, 52818},
	{"CATASTROPHE", 11, 52819},
	{"EMSU", 4, 52820},
	{"LEAFS", 5, 52821},
	{"GREATNESS", 9, 52822},
	{"ELECTRICIAN", 11, 52823},
	{"MAYFIELD", 8, 52824},
	{"MONB", 4, 52825},
	{"IRDL", 4, 52826},
	{"ARCHIE", 6, 52827},
	{"SAMUI", 5, 52828},
	{"PARASITES", 9, 52829},
	{"BLEACH", 6, 52830},
	{"ENTERTAINED", 11, 52831},
	{"IRBR", 4, 52832},
	{"SGAL", 4, 52833},
	{"INVENTORS", 9, 52834},
	{"ODPL", 4, 52835},
	{"ZMY", 3, 52836},
	{"ZMC", 3, 52837},
	{"YJK", 3, 52838},
	{"UNAUTHORISED", 12, 52839},
	{"FERRET", 6, 52840},
	{"YENJ", 4, 52841},
	{"LOUISA", 6, 52842},
	{"ERUR", 4, 52843},
	{"AGONY", 5, 52844},
	{"WOLVERINE", 9, 52845},
	{"KESY", 4, 52846},
	{"BLYP", 4, 52847},
	{"MARSEILLE", 9, 52848},
	{"TALLER", 6, 52849},
	{"DOUBLING", 8, 52850},
	{"STUPIDITY", 9, 52851},
	{"MOOR", 4, 52852},
	{"INDIVIDUALIZED", 14, 52853},
	{"KTOL", 4, 52854},
	{"STEPHENSON", 10, 52855},
	{"ENRICH", 6, 52856},
	{"FOREGROUND", 10, 52857},
	{"REVELATIONS", 11, 52858},
	{"UEBU", 4, 52859},
	{"REPLYING", 8, 52860},
	{"RAFFLE", 6, 52861},
	{"ERKO", 4, 52862},
	{"SHREDDER", 8, 52863},
	{"YHED", 4, 52864},
	{"ODPA", 4, 52865},
	{"INCAPABLE", 9, 52866},
	{"PARTE", 5, 52867},
	{"CRYI", 4, 52868},
	{"SBUL", 4, 52869},
	{"ACKNOWLEDGMENT", 14, 52870},
	{"EMBEDDING", 9, 52871},
	{"PENM", 4, 52872},
	{"MSCR", 4, 52873},
	{"HYDROLOGY", 9, 52874},
	{"MASCOT", 6, 52875},
	{"BIGW", 4, 52876},
	{"SAFL", 4, 52877},
	{"MHOU", 4, 52878},
	{"UNVE", 4, 52879},
	{"LUBE", 4, 52880},
	{"LAUNCHER", 8, 52881},
	{"MECH", 4, 52882},
	{"LABYRINTH", 9, 52883},
	{"TBEB", 4, 52884},
	{"AFRICANS", 8, 52885},
	{"SWAY", 4, 52886},
	{"DHUR", 4, 52887},
	{"PRIMERS", 7, 52888},
	{"TRYL", 4, 52889},
	{"UNDERGONE", 9, 52890},
	{"LACEY", 5, 52891},
	{"ONWR", 4, 52892},
	{"YKID", 4, 52893},
	{"NYKI", 4, 52894},
	{"MOFI", 4, 52895},
	{"CAREGIVER", 9, 52896},
	{"TRIANGULAR", 10, 52897},
	{"DISABLING", 9, 52898},
	{"CONES", 5, 52899},
	{"LUPUS", 5, 52900},
	{"TFAV", 4, 52901},
	{"EURG", 4, 52902},
	{"RNEV", 4, 52903},
	{"SACHS", 5, 52904},
	{"INVERSION", 9, 52905},
	{"THANKFULLY", 10, 52906},
	{"QTEK", 4, 52907},
	{"TAXED", 5, 52908},
	{"UYST", 4, 52909},
	{"XTFE", 4, 52910},
	{"NUNL", 4, 52911},
	{"AELB", 4, 52912},
	{"PRESUMPTION", 11, 52913},
	{"EXCITATION", 10, 52914},
	{"SALESMAN", 8, 52915},
	{"HATFIELD", 8, 52916},
	{"CONSTANTINE", 11, 52917},
	{"CONFEDERATION", 13, 52918},
	{"KEANE", 5, 52919},
	{"FQB", 3, 52920},
	{"PETALS", 6, 52921},
	{"KWAY", 4, 52922},
	{"GTAL", 4, 52923},
	{"GATOR", 5, 52924},
	{"IMPRISONED", 10, 52925},
	{"THCU", 4, 52926},
	{"MEMBERLIST", 10, 52927},
	{"KEUS", 4, 52928},
	{"INKF", 4, 52929},
	{"NORDSTROM", 9, 52930},
	{"USKE", 4, 52931},
	{"UNPA", 4, 52932},
	{"NMYO", 4, 52933},
	{"MEIF", 4, 52934},
	{"ROSEVILLE", 9, 52935},
	{"HELLER", 6, 52936},
	{"DISHWASHERS", 11, 52937},
	{"WALLA", 5, 52938},
	{"REMIXES", 7, 52939},
	{"RMRE", 4, 52940},
	{"GUAB", 4, 52941},
	{"LISR", 4, 52942},
	{"LDFE", 4, 52943},
	{"COZUMEL", 7, 52944},
	{"REPLICATE", 9, 52945},
	{"VEQU", 4, 52946},
	{"TAPED", 5, 52947},
	{"HSUB", 4, 52948},
	{"EUSF", 4, 52949},
	{"MCGRATH", 7, 52950},
	{"RKAL", 4, 52951},
	{"WERG", 4, 52952},
	{"DLYF", 4, 52953},
	{"DOCKS", 5, 52954},
	{"BIOMETRIC", 9, 52955},
	{"THPU", 4, 52956},
	{"LANDOWNERS", 10, 52957},
	{"INCUBATION", 10, 52958},
	{"AGGREGATES", 10, 52959},
	{"WRANGLER", 8, 52960},
	{"YVM", 3, 52961},
	{"ERUT", 4, 52962},
	{"JUNO", 4, 52963},
	{"DEUX", 4, 52964},
	{"DEFIANCE", 8, 52965},
	{"ASYMMETRIC", 10, 52966},
	{"BULLY", 5, 52967},
	{"CYTOCHROME", 10, 52968},
	{"VALIANT", 7, 52969},
	{"GEXT", 4, 52970},
	{"XFM", 3, 52971},
	{"CONSTRUCTIONS", 13, 52972},
	{"RSJU", 4, 52973},
	{"RAWB", 4, 52974},
	{"YALM", 4, 52975},
	{"YOUNGSTERS", 10, 52976},
	{"SHURE", 5, 52977},
	{"VIDB", 4, 52978},
	{"FQUA", 4, 52979},
	{"BREASTED", 8, 52980},
	{"BANGING", 7, 52981},
	{"OBOW", 4, 52982},
	{"OAFF", 4, 52983},
	{"VERTIGO", 7, 52984},
	{"MYBO", 4, 52985},
	{"BEOP", 4, 52986},
	{"UNSATISFACTORY", 14, 52987},
	{"FLUENT", 6, 52988},
	{"FFEA", 4, 52989},
	{"RHYME", 5, 52990},
	{"RUSC", 4, 52991},
	{"RMWH", 4, 52992},
	{"DONATING", 8, 52993},
	{"ANTEC", 5, 52994},
	{"GIVEAWAY", 8, 52995},
	{"APOU", 4, 52996},
	{"CMC", 3, 52997},
	{"WTOB", 4, 52998},
	{"ALYSSA", 6, 52999},
	{"OREK", 4, 53000},
	{"NFOC", 4, 53001},
	{"RENTER", 6, 53002},
	{"VMWARE", 6, 53003},
	{"EMEW", 4, 53004},
	{"PATEL", 5, 53005},
	{"HONEYWELL", 9, 53006},
	{"RYQU", 4, 53007},
	{"ILAL", 4, 53008},
	{"MCINTOSH", 8, 53009},
	{"SUFFICE", 7, 53010},
	{"NIGHTCLUBS", 10, 53011},
	{"BARRINGTON", 10, 53012},
	{"LUXOR", 5, 53013},
	{"TSFL", 4, 53014},
	{"CATERERS", 8, 53015},
	{"MPSI", 4, 53016},
	{"LKSO", 4, 53017},
	{"CAPACITORS", 10, 53018},
	{"ROCKEFELLER", 11, 53019},
	{"CONVENED", 8, 53020},
	{"CHECKBOX", 8, 53021},
	{"GHQU", 4, 53022},
	{"YSUG", 4, 53023},
	{"NOWK", 4, 53024},
	{"ACCUSATIONS", 11, 53025},
	{"YTHC", 4, 53026},
	{"DEBATED", 7, 53027},
	{"UBIS", 4, 53028},
	{"YGOD", 4, 53029},
	{"RTCH", 4, 53030},
	{"CHJO", 4, 53031},
	{"ITINERARIES", 11, 53032},
	{"DEAU", 4, 53033},
	{"STALLION", 8, 53034},
	{"REAGENTS", 8, 53035},
	{"CHRISTOPH", 9, 53036},
	{"WALKERS", 7, 53037},
	{"WOBA", 4, 53038},
	{"DJER", 4, 53039},
	{"EQUIPMENTS", 10, 53040},
	{"NECESSITIES", 11, 53041},
	{"PUTM", 4, 53042},
	{"ENSEMBL", 7, 53043},
	{"WEEKDAYS", 8, 53044},
	{"CAMELOT", 7, 53045},
	{"COMPUTATIONS", 12, 53046},
	{"WINERIES", 8, 53047},
	{"VDC", 3, 53048},
	{"BOOKER", 6, 53049},
	{"AWKI", 4, 53050},
	{"OUDL", 4, 53051},
	{"MATTEL", 6, 53052},
	{"DESERTED", 8, 53053},
	{"DIVERSIFICATION", 15, 53054},
	{"WSDL", 4, 53055},
	{"RLOU", 4, 53056},
	{"HIPD", 4, 53057},
	{"MATIC", 5, 53058},
	{"XYZ", 3, 53059},
	{"KEEPERS", 7, 53060},
	{"POFH", 4, 53061},
	{"DDTO", 4, 53062},
	{"ANTIOXIDANT", 11, 53063},
	{"TDAM", 4, 53064},
	{"PPYA", 4, 53065},
	{"DIDM", 4, 53066},
	{"LOGICALLY", 9, 53067},
	{"CARAVANS", 8, 53068},
	{"ESRB", 4, 53069},
	{"DDTH", 4, 53070},
	{"CSWI", 4, 53071},
	{"ARCHOS", 6, 53072},
	{"ORANGES", 7, 53073},
	{"BUM", 3, 53074},
	{"PRESSE", 6, 53075},
	{"PLYD", 4, 53076},
	{"OLGA", 4, 53077},
	{"RYYO", 4, 53078},
	{"SEMESTERS", 9, 53079},
	{"PTWO", 4, 53080},
	{"AMTR", 4, 53081},
	{"NARUTO", 6, 53082},
	{"CONTENDS", 8, 53083},
	{"SNORT", 5, 53084},
	{"OCCUPANTS", 9, 53085},
	{"STORYLINE", 9, 53086},
	{"EBYR", 4, 53087},
	{"MELROSE", 7, 53088},
	{"STREAMLINED", 11, 53089},
	{"NMYL", 4, 53090},
	{"ANALYSING", 9, 53091},
	{"AIRWAY", 6, 53092},
	{"ICONV", 5, 53093},
	{"GPOP", 4, 53094},
	{"ORGANISER", 9, 53095},
	{"COMMAS", 6, 53096},
	{"VICKY", 5, 53097},
	{"LUMINOUS", 8, 53098},
	{"CROWE", 5, 53099},
	{"FBER", 4, 53100},
	{"HELVETICA", 9, 53101},
	{"PYAN", 4, 53102},
	{"SUBMITTER", 9, 53103},
	{"UNPARALLELED", 12, 53104},
	{"ANYHOW", 6, 53105},
	{"RALJ", 4, 53106},
	{"CAMBRIA", 7, 53107},
	{"SUPI", 4, 53108},
	{"WATERFALLS", 10, 53109},
	{"OBTAINS", 7, 53110},
	{"ILAP", 4, 53111},
	{"ANTWERP", 7, 53112},
	{"GESR", 4, 53113},
	{"ULRICH", 6, 53114},
	{"LATL", 4, 53115},
	{"HECD", 4, 53116},
	{"HARDENED", 8, 53117},
	{"PRIMAL", 6, 53118},
	{"NGKN", 4, 53119},
	{"LUBO", 4, 53120},
	{"GOTB", 4, 53121},
	{"WOGO", 4, 53122},
	{"SRIL", 4, 53123},
	{"GEXC", 4, 53124},
	{"STRAITS", 7, 53125},
	{"UPHELD", 6, 53126},
	{"MANIFESTATION", 13, 53127},
	{"MALT", 4, 53128},
	{"SUBSETS", 7, 53129},
	{"BLAZERS", 7, 53130},
	{"JUPITERMEDIA", 12, 53131},
	{"TJUN", 4, 53132},
	{"MERRITT", 7, 53133},
	{"TRIAD", 5, 53134},
	{"WEBPAGES", 8, 53135},
	{"YPV", 3, 53136},
	{"KCJ", 3, 53137},
	{"ORWR", 4, 53138},
	{"CLINIQUE", 8, 53139},
	{"LYNI", 4, 53140},
	{"HBIL", 4, 53141},
	{"GIUM", 4, 53142},
	{"FITCH", 5, 53143},
	{"CHFU", 4, 53144},
	{"RJOE", 4, 53145},
	{"CHARTING", 8, 53146},
	{"UGM", 3, 53147},
	{"FIXATION", 8, 53148},
	{"LENOVO", 6, 53149},
	{"ENDOWED", 7, 53150},
	{"DBRU", 4, 53151},
	{"ALAMOS", 6, 53152},
	{"CAMEO", 5, 53153},
	{"YGEO", 4, 53154},
	{"WEFI", 4, 53155},
	{"OAFR", 4, 53156},
	{"ATTIRE", 6, 53157},
	{"LCUR", 4, 53158},
	{"BLAINE", 6, 53159},
	{"LEACH", 5, 53160},
	{"YETB", 4, 53161},
	{"OLAD", 4, 53162},
	{"LSAV", 4, 53163},
	{"GRAVITATIONAL", 13, 53164},
	{"BYWE", 4, 53165},
	{"TYPEWRITER", 10, 53166},
	{"CYRILLIC", 8, 53167},
	{"DLAC", 4, 53168},
	{"PREVACID", 8, 53169},
	{"POMONA", 6, 53170},
	{"GODDARD", 7, 53171},
	{"DESIGNEE", 8, 53172},
	{"FANNY", 5, 53173},
	{"SUNNI", 5, 53174},
	{"RGZ", 3, 53175},
	{"KPY", 3, 53176},
	{"PUSI", 4, 53177},
	{"ABEG", 4, 53178},
	{"PLAGIARISM", 10, 53179},
	{"MILKY", 5, 53180},
	{"LORM", 4, 53181},
	{"NETFLIX", 7, 53182},
	{"AJAP", 4, 53183},
	{"COMBS", 5, 53184},
	{"FPHI", 4, 53185},
	{"MONOXIDE", 8, 53186},
	{"UPLAND", 6, 53187},
	{"OLSP", 4, 53188},
	{"GROUPEE", 7, 53189},
	{"EEKP", 4, 53190},
	{"HARDIN", 6, 53191},
	{"COLORECTAL", 10, 53192},
	{"OUTAGE", 6, 53193},
	{"UNCONSTITUTIONAL", 16, 53194},
	{"DKAT", 4, 53195},
	{"CHUNKY", 6, 53196},
	{"ADOPTS", 6, 53197},
	{"RTHG", 4, 53198},
	{"WWOU", 4, 53199},
	{"RAPTOR", 6, 53200},
	{"OMIZ", 4, 53201},
	{"FISR", 4, 53202},
	{"UPTA", 4, 53203},
	{"UTOC", 4, 53204},
	{"USHF", 4, 53205},
	{"COULTER", 7, 53206},
	{"FJAP", 4, 53207},
	{"OPPL", 4, 53208},
	{"MACAO", 5, 53209},
	{"IUND", 4, 53210},
	{"BYBI", 4, 53211},
	{"ULRE", 4, 53212},
	{"EPED", 4, 53213},
	{"SNAPS", 5, 53214},
	{"DEFENDS", 7, 53215},
	{"DEPICTS", 7, 53216},
	{"PBX", 3, 53217},
	{"AYEX", 4, 53218},
	{"PILGRIMAGE", 10, 53219},
	{"QUANTIFY", 8, 53220},
	{"ORVO", 4, 53221},
	{"DMESG", 5, 53222},
	{"ELEVATORS", 9, 53223},
	{"ELFWOOD", 7, 53224},
	{"BOYW", 4, 53225},
	{"SUBSTITUTIONS", 13, 53226},
	{"LANCOME", 7, 53227},
	{"LSCE", 4, 53228},
	{"LWEB", 4, 53229},
	{"GALLERIA", 8, 53230},
	{"HILLSBOROUGH", 12, 53231},
	{"ABWE", 4, 53232},
	{"BOOKLETS", 8, 53233},
	{"FBOO", 4, 53234},
	{"ATWW", 4, 53235},
	{"GLUTEN", 6, 53236},
	{"NARROWED", 8, 53237},
	{"IRGA", 4, 53238},
	{"SPANKED", 7, 53239},
	{"UGHY", 4, 53240},
	{"ORTHOPAEDIC", 11, 53241},
	{"MYAR", 4, 53242},
	{"GHTV", 4, 53243},
	{"MEDI", 4, 53244},
	{"UELC", 4, 53245},
	{"MMAG", 4, 53246},
	{"HYWO", 4, 53247},
	{"DVIA", 4, 53248},
	{"EIGHTEENTH", 10, 53249},
	{"HURST", 5, 53250},
	{"INSCRIPTION", 11, 53251},
	{"ASCENT", 6, 53252},
	{"OBISPO", 6, 53253},
	{"EEPF", 4, 53254},
	{"BTLE", 4, 53255},
	{"ULLL", 4, 53256},
	{"MINOGUE", 7, 53257},
	{"LDAV", 4, 53258},
	{"LADT", 4, 53259},
	{"PENB", 4, 53260},
	{"TURBINES", 8, 53261},
	{"SICM", 4, 53262},
	{"NOTEPAD", 7, 53263},
	{"TEDIOUS", 7, 53264},
	{"PODS", 4, 53265},
	{"UMBO", 4, 53266},
	{"HFRA", 4, 53267},
	{"HDID", 4, 53268},
	{"EARV", 4, 53269},
	{"UNIVERSALLY", 11, 53270},
	{"CRAPPY", 6, 53271},
	{"WBAC", 4, 53272},
	{"GOLFER", 6, 53273},
	{"DJAP", 4, 53274},
	{"AOFK", 4, 53275},
	{"DEDV", 4, 53276},
	{"UNGF", 4, 53277},
	{"LOYS", 4, 53278},
	{"LCHR", 4, 53279},
	{"TUMO", 4, 53280},
	{"CHMU", 4, 53281},
	{"RECEIVABLES", 11, 53282},
	{"WTOM", 4, 53283},
	{"MOFR", 4, 53284},
	{"FMAI", 4, 53285},
	{"CHEWING", 7, 53286},
	{"SCRIPPS", 7, 53287},
	{"YSAG", 4, 53288},
	{"CILW", 4, 53289},
	{"ACCOMMODATED", 12, 53290},
	{"TENDENCIES", 10, 53291},
	{"LIVERMORE", 9, 53292},
	{"IGNL", 4, 53293},
	{"ROWLAND", 7, 53294},
	{"CEJO", 4, 53295},
	{"EUSG", 4, 53296},
	{"DCIR", 4, 53297},
	{"WELDED", 6, 53298},
	{"PGRO", 4, 53299},
	{"CONFORMS", 8, 53300},
	{"SGUS", 4, 53301},
	{"YVF", 3, 53302},
	{"CIRQUE", 6, 53303},
	{"DSHU", 4, 53304},
	{"MARXISM", 7, 53305},
	{"REGGIE", 6, 53306},
	{"ESCONDIDO", 9, 53307},
	{"DIFFRACTION", 11, 53308},
	{"ODSU", 4, 53309},
	{"OUTLINING", 9, 53310},
	{"RAUG", 4, 53311},
	{"GGOA", 4, 53312},
	{"SUBTRACT", 8, 53313},
	{"BOSNIAN", 7, 53314},
	{"NCRU", 4, 53315},
	{"FPRA", 4, 53316},
	{"REFRESHMENTS", 12, 53317},
	{"COILS", 5, 53318},
	{"CALLERS", 7, 53319},
	{"HYDRATION", 9, 53320},
	{"IORL", 4, 53321},
	{"CCOA", 4, 53322},
	{"MYOP", 4, 53323},
	{"HAVENT", 6, 53324},
	{"PREFERENTIAL", 12, 53325},
	{"EYCL", 4, 53326},
	{"NAVEL", 5, 53327},
	{"ARBITRATOR", 10, 53328},
	{"INTERNS", 7, 53329},
	{"QUOTAS", 6, 53330},
	{"PROLIFIC", 8, 53331},
	{"NURSERIES", 9, 53332},
	{"KINM", 4, 53333},
	{"FFET", 4, 53334},
	{"YCHU", 4, 53335},
	{"MPAB", 4, 53336},
	{"METHODOLOGICAL", 14, 53337},
	{"WDOE", 4, 53338},
	{"AARP", 4, 53339},
	{"GETTYSBURG", 10, 53340},
	{"WLQ", 3, 53341},
	{"ISERIES", 7, 53342},
	{"GALP", 4, 53343},
	{"AFTC", 4, 53344},
	{"MENLO", 5, 53345},
	{"UGHJ", 4, 53346},
	{"WALKTHROUGH", 11, 53347},
	{"EEKR", 4, 53348},
	{"FOOTSTEPS", 9, 53349},
	{"RYJO", 4, 53350},
	{"MEBI", 4, 53351},
	{"LEUP", 4, 53352},
	{"KOFW", 4, 53353},
	{"INDEFINITELY", 12, 53354},
	{"LLUL", 4, 53355},
	{"SUCKER", 6, 53356},
	{"SADL", 4, 53357},
	{"BUMPS", 5, 53358},
	{"BIKINIS", 7, 53359},
	{"FRIGHTENING", 11, 53360},
	{"MYDE", 4, 53361},
	{"MTWO", 4, 53362},
	{"HLOR", 4, 53363},
	{"WILDLY", 6, 53364},
	{"LENF", 4, 53365},
	{"SABLE", 5, 53366},
	{"AOPEN", 5, 53367},
	{"LEXS", 4, 53368},
	{"RETARDED", 8, 53369},
	{"DLOA", 4, 53370},
	{"BOOKCROSSING", 12, 53371},
	{"ADDICTS", 7, 53372},
	{"EPITHELIAL", 10, 53373},
	{"DRASTICALLY", 11, 53374},
	{"NACU", 4, 53375},
	{"NEATLY", 6, 53376},
	{"SINGLETON", 9, 53377},
	{"RNWH", 4, 53378},
	{"WNWO", 4, 53379},
	{"FFWH", 4, 53380},
	{"SPANIEL", 7, 53381},
	{"FLYA", 4, 53382},
	{"SOMERVILLE", 10, 53383},
	{"WORTHLESS", 9, 53384},
	{"CLARKS", 6, 53385},
	{"TBYC", 4, 53386},
	{"SPOOL", 5, 53387},
	{"OPWI", 4, 53388},
	{"WETR", 4, 53389},
	{"ONGY", 4, 53390},
	{"GROUPWARE", 9, 53391},
	{"MATCHMAKING", 11, 53392},
	{"DICT", 4, 53393},
	{"NOWU", 4, 53394},
	{"JEOPARDY", 8, 53395},
	{"DESCRIPTORS", 11, 53396},
	{"ROVERS", 6, 53397},
	{"VOICED", 6, 53398},
	{"HLED", 4, 53399},
	{"AERONAUTICS", 11, 53400},
	{"RADIOGRAPHY", 11, 53401},
	{"NORSK", 5, 53402},
	{"ANNOY", 5, 53403},
	{"EXPR", 4, 53404},
	{"CLAP", 4, 53405},
	{"YGOL", 4, 53406},
	{"IEFC", 4, 53407},
	{"ASPIRING", 8, 53408},
	{"REFEREED", 8, 53409},
	{"EGIF", 4, 53410},
	{"EARK", 4, 53411},
	{"DAZZLING", 8, 53412},
	{"CORNELIUS", 9, 53413},
	{"BYPU", 4, 53414},
	{"ARDK", 4, 53415},
	{"RMYI", 4, 53416},
	{"SCIENTIFICALLY", 14, 53417},
	{"GRANDPA", 7, 53418},
	{"YNDI", 4, 53419},
	{"CORNISH", 7, 53420},
	{"GUESSED", 7, 53421},
	{"KENNELS", 7, 53422},
	{"RNDA", 4, 53423},
	{"TOXIN", 5, 53424},
	{"URTB", 4, 53425},
	{"UKEO", 4, 53426},
	{"ADYR", 4, 53427},
	{"KSAF", 4, 53428},
	{"AXIOM", 5, 53429},
	{"STAMINA", 7, 53430},
	{"RGEG", 4, 53431},
	{"HARDNESS", 8, 53432},
	{"YWIS", 4, 53433},
	{"NLOU", 4, 53434},
	{"CEIF", 4, 53435},
	{"QQU", 3, 53436},
	{"JUY", 3, 53437},
	{"GJP", 3, 53438},
	{"RJAN", 4, 53439},
	{"ABOUND", 6, 53440},
	{"POYNTER", 7, 53441},
	{"MNED", 4, 53442},
	{"CSWH", 4, 53443},
	{"CURING", 6, 53444},
	{"SOCRATES", 8, 53445},
	{"AZTEC", 5, 53446},
	{"CONFER", 6, 53447},
	{"KOFD", 4, 53448},
	{"OWUN", 4, 53449},
	{"ONYC", 4, 53450},
	{"VENTS", 5, 53451},
	{"EVOR", 4, 53452},
	{"MATER", 5, 53453},
	{"ONEIDA", 6, 53454},
	{"FILMMAKER", 9, 53455},
	{"AIKEN", 5, 53456},
	{"CROWNED", 7, 53457},
	{"SANDSTONE", 9, 53458},
	{"ADAPTING", 8, 53459},
	{"NEJU", 4, 53460},
	{"GROUNDING", 9, 53461},
	{"SMARTPHONES", 11, 53462},
	{"DCLU", 4, 53463},
	{"CALVERT", 7, 53464},
	{"OKSW", 4, 53465},
	{"FIDUCIARY", 9, 53466},
	{"CRANES", 6, 53467},
	{"OVOL", 4, 53468},
	{"ROOSTER", 7, 53469},
	{"BAYESIAN", 8, 53470},
	{"GERU", 4, 53471},
	{"SACCHAROMYCES", 13, 53472},
	{"CFP", 3, 53473},
	{"PROCTOR", 7, 53474},
	{"PREHISTORIC", 11, 53475},
	{"USBI", 4, 53476},
	{"ILEU", 4, 53477},
	{"HUMPS", 5, 53478},
	{"BALKANS", 7, 53479},
	{"LATR", 4, 53480},
	{"YISW", 4, 53481},
	{"JOKER", 5, 53482},
	{"ZIMMERMAN", 9, 53483},
	{"JAVIER", 6, 53484},
	{"ROMANTICS", 9, 53485},
	{"TRIMMER", 7, 53486},
	{"BOOKKEEPING", 11, 53487},
	{"RMLY", 4, 53488},
	{"HIKES", 5, 53489},
	{"KICKOFF", 7, 53490},
	{"WIPED", 5, 53491},
	{"GEDG", 4, 53492},
	{"WTOW", 4, 53493},
	{"UBAI", 4, 53494},
	{"CONTOURS", 8, 53495},
	{"MAGICK", 6, 53496},
	{"GBAT", 4, 53497},
	{"ABDOMEN", 7, 53498},
	{"HILLSBORO", 9, 53499},
	{"BADEN", 5, 53500},
	{"IRBI", 4, 53501},
	{"UCUS", 4, 53502},
	{"IGAM", 4, 53503},
	{"EDYI", 4, 53504},
	{"BLM", 3, 53505},
	{"TUDOR", 5, 53506},
	{"FRACTAL", 7, 53507},
	{"AMLO", 4, 53508},
	{"PAWS", 4, 53509},
	{"VILLAINS", 8, 53510},
	{"PRAYED", 6, 53511},
	{"INEFFICIENT", 11, 53512},
	{"SBYW", 4, 53513},
	{"HEIRS", 5, 53514},
	{"PAYC", 4, 53515},
	{"PARASITE", 8, 53516},
	{"RDIO", 4, 53517},
	{"NKBE", 4, 53518},
	{"CHRU", 4, 53519},
	{"GUILDFORD", 9, 53520},
	{"TWILL", 5, 53521},
	{"THGU", 4, 53522},
	{"CHGE", 4, 53523},
	{"EDYN", 4, 53524},
	{"SHORTCOMINGS", 12, 53525},
	{"CURES", 5, 53526},
	{"PTOG", 4, 53527},
	{"OMIG", 4, 53528},
	{"IBRI", 4, 53529},
	{"DISRUPTIVE", 10, 53530},
	{"OCHU", 4, 53531},
	{"KICKER", 6, 53532},
	{"PROTEASE", 8, 53533},
	{"CONCENTRATES", 12, 53534},
	{"YOPT", 4, 53535},
	{"PRECLUDE", 8, 53536},
	{"GHTJ", 4, 53537},
	{"ABRAMS", 6, 53538},
	{"WNAB", 4, 53539},
	{"MORENO", 6, 53540},
	{"NEWSFORGE", 9, 53541},
	{"FASTING", 7, 53542},
	{"TIMEX", 5, 53543},
	{"SEPU", 4, 53544},
	{"DUFFY", 5, 53545},
	{"LOUDLY", 6, 53546},
	{"RACERS", 6, 53547},
	{"HORSESHOE", 9, 53548},
	{"MAFR", 4, 53549},
	{"URSL", 4, 53550},
	{"ZEUS", 4, 53551},
	{"CONSTELLATION", 13, 53552},
	{"OLCH", 4, 53553},
	{"RECITAL", 7, 53554},
	{"DNEG", 4, 53555},
	{"USAW", 4, 53556},
	{"PAIRING", 7, 53557},
	{"UMRE", 4, 53558},
	{"RPIL", 4, 53559},
	{"UTRECHT", 7, 53560},
	{"OARG", 4, 53561},
	{"KIRKLAND", 8, 53562},
	{"FREUD", 5, 53563},
	{"BEDTIME", 7, 53564},
	{"GHAC", 4, 53565},
	{"THINKERS", 8, 53566},
	{"ELPY", 4, 53567},
	{"KEMY", 4, 53568},
	{"GUJARAT", 7, 53569},
	{"IRKI", 4, 53570},
	{"FTWE", 4, 53571},
	{"HUME", 4, 53572},
	{"DKNY", 4, 53573},
	{"REMINISCENT", 11, 53574},
	{"URYF", 4, 53575},
	{"RAPPORT", 7, 53576},
	{"EPHESIANS", 9, 53577},
	{"CATFISH", 7, 53578},
	{"DOPE", 4, 53579},
	{"MINP", 4, 53580},
	{"DOUBLETREE", 10, 53581},
	{"WNUN", 4, 53582},
	{"FERW", 4, 53583},
	{"BRINK", 5, 53584},
	{"RGOR", 4, 53585},
	{"OBBL", 4, 53586},
	{"ADOB", 4, 53587},
	{"EWEV", 4, 53588},
	{"HOTPOINT", 8, 53589},
	{"TRUSS", 5, 53590},
	{"OYCO", 4, 53591},
	{"GEPL", 4, 53592},
	{"KILN", 4, 53593},
	{"ANTHOLOGIES", 11, 53594},
	{"RETIREES", 8, 53595},
	{"GUSO", 4, 53596},
	{"AFLE", 4, 53597},
	{"PEACHES", 7, 53598},
	{"RDBY", 4, 53599},
	{"BAYL", 4, 53600},
	{"DEPRESSING", 10, 53601},
	{"DCC", 3, 53602},
	{"INVESTIGATES", 12, 53603},
	{"SIXG", 4, 53604},
	{"CSFO", 4, 53605},
	{"MAYL", 4, 53606},
	{"HBEG", 4, 53607},
	{"CERU", 4, 53608},
	{"STRANGELY", 9, 53609},
	{"LLMU", 4, 53610},
	{"CHELMSFORD", 10, 53611},
	{"NARRATIVES", 10, 53612},
	{"SKIPPER", 7, 53613},
	{"DRAINS", 6, 53614},
	{"ANONYMITY", 9, 53615},
	{"RIMO", 4, 53616},
	{"LDOV", 4, 53617},
	{"GOTHAM", 6, 53618},
	{"LYLE", 4, 53619},
	{"MAXIMA", 6, 53620},
	{"UNIFICATION", 11, 53621},
	{"MCKE", 4, 53622},
	{"PINOT", 5, 53623},
	{"RESPONSIVENESS", 14, 53624},
	{"OSUF", 4, 53625},
	{"FFSP", 4, 53626},
	{"NAPU", 4, 53627},
	{"TESTIMONIAL", 11, 53628},
	{"RNUN", 4, 53629},
	{"PEDL", 4, 53630},
	{"KHAKI", 5, 53631},
	{"SLYH", 4, 53632},
	{"ANUC", 4, 53633},
	{"GAZETTEER", 9, 53634},
	{"DISTRIBUTES", 11, 53635},
	{"JACOBSON", 8, 53636},
	{"UISV", 4, 53637},
	{"NAVIGATING", 10, 53638},
	{"IMITREX", 7, 53639},
	{"DSOW", 4, 53640},
	{"MONASH", 6, 53641},
	{"BINGHAMTON", 10, 53642},
	{"CONNOLLY", 8, 53643},
	{"YMAL", 4, 53644},
	{"SLOUGH", 6, 53645},
	{"GBIL", 4, 53646},
	{"PRODIGY", 7, 53647},
	{"EMBOSSED", 8, 53648},
	{"OWGR", 4, 53649},
	{"INUP", 4, 53650},
	{"MOULD", 5, 53651},
	{"WBEC", 4, 53652},
	{"JOCK", 4, 53653},
	{"RPMS", 4, 53654},
	{"BSAR", 4, 53655},
	{"SICD", 4, 53656},
	{"TFOC", 4, 53657},
	{"HEMG", 4, 53658},
	{"PSYCHEDELIC", 11, 53659},
	{"BLASTS", 6, 53660},
	{"ULAC", 4, 53661},
	{"OLYN", 4, 53662},
	{"GSWA", 4, 53663},
	{"RHINESTONE", 10, 53664},
	{"POORER", 6, 53665},
	{"AGEU", 4, 53666},
	{"ANGLIA", 6, 53667},
	{"RKCA", 4, 53668},
	{"DYED", 4, 53669},
	{"QUADRATIC", 9, 53670},
	{"YFIS", 4, 53671},
	{"LSBY", 4, 53672},
	{"DISSATISFIED", 12, 53673},
	{"PHILHARMONIC", 12, 53674},
	{"YELS", 4, 53675},
	{"DYNAMICAL", 9, 53676},
	{"CANTONESE", 9, 53677},
	{"OADP", 4, 53678},
	{"KNIC", 4, 53679},
	{"QURAN", 5, 53680},
	{"TURNOVR", 7, 53681},
	{"KEYCHAIN", 8, 53682},
	{"SMYS", 4, 53683},
	{"SHAKERS", 7, 53684},
	{"FVOT", 4, 53685},
	{"BOURBON", 7, 53686},
	{"STAGGERING", 10, 53687},
	{"BISMARCK", 8, 53688},
	{"LEKN", 4, 53689},
	{"RUBBED", 6, 53690},
	{"AKEV", 4, 53691},
	{"WASP", 4, 53692},
	{"MSMO", 4, 53693},
	{"LYAU", 4, 53694},
	{"GOFE", 4, 53695},
	{"INHIBITED", 9, 53696},
	{"ICIM", 4, 53697},
	{"BOOKSELLER", 10, 53698},
	{"UEDH", 4, 53699},
	{"LEXICAL", 7, 53700},
	{"EXWI", 4, 53701},
	{"AYMI", 4, 53702},
	{"OPENSSL", 7, 53703},
	{"UGG", 3, 53704},
	{"MATHEMATICA", 11, 53705},
	{"IRFE", 4, 53706},
	{"KARACHI", 7, 53707},
	{"MISSOULA", 8, 53708},
	{"ABILENE", 7, 53709},
	{"FDID", 4, 53710},
	{"FUSS", 4, 53711},
	{"GAFA", 4, 53712},
	{"MUIR", 4, 53713},
	{"UTERUS", 6, 53714},
	{"PUNE", 4, 53715},
	{"RKBU", 4, 53716},
	{"OUPP", 4, 53717},
	{"ANMC", 4, 53718},
	{"TRASHY", 6, 53719},
	{"GPAI", 4, 53720},
	{"FLOV", 4, 53721},
	{"CHIMES", 6, 53722},
	{"DSTY", 4, 53723},
	{"LVEA", 4, 53724},
	{"EXPENDED", 8, 53725},
	{"WEBCT", 5, 53726},
	{"CTOP", 4, 53727},
	{"WEBBER", 6, 53728},
	{"TPAG", 4, 53729},
	{"PVR", 3, 53730},
	{"HANDYCAM", 8, 53731},
	{"SRSQ", 4, 53732},
	{"ITWW", 4, 53733},
	{"UDYT", 4, 53734},
	{"GNEX", 4, 53735},
	{"FBUR", 4, 53736},
	{"DUPH", 4, 53737},
	{"AGGREGATED", 10, 53738},
	{"LRED", 4, 53739},
	{"KMUS", 4, 53740},
	{"STRATEGICALLY", 13, 53741},
	{"EMDO", 4, 53742},
	{"RGLO", 4, 53743},
	{"AROV", 4, 53744},
	{"DAQU", 4, 53745},
	{"PICO", 4, 53746},
	{"HBIR", 4, 53747},
	{"TURT", 4, 53748},
	{"RILS", 4, 53749},
	{"OWAG", 4, 53750},
	{"RNBE", 4, 53751},
	{"ORND", 4, 53752},
	{"EXHIBITING", 10, 53753},
	{"HCHR", 4, 53754},
	{"RYEV", 4, 53755},
	{"GIMME", 5, 53756},
	{"DEPUTIES", 8, 53757},
	{"UPOR", 4, 53758},
	{"FBAC", 4, 53759},
	{"TDAR", 4, 53760},
	{"EMERGENT", 8, 53761},
	{"OMAW", 4, 53762},
	{"GANM", 4, 53763},
	{"ERIKA", 5, 53764},
	{"AUTHENTICATE", 12, 53765},
	{"SICV", 4, 53766},
	{"HEBY", 4, 53767},
	{"ALIGNING", 8, 53768},
	{"GBUI", 4, 53769},
	{"SEUP", 4, 53770},
	{"RLYG", 4, 53771},
	{"DNRS", 4, 53772},
	{"BEAUFORT", 8, 53773},
	{"NAUTILUS", 8, 53774},
	{"RADICALLY", 9, 53775},
	{"LFLE", 4, 53776},
	{"DOULTON", 7, 53777},
	{"TERMINATING", 11, 53778},
	{"PLATTER", 7, 53779},
	{"NDJI", 4, 53780},
	{"GLIV", 4, 53781},
	{"EKRE", 4, 53782},
	{"IMBL", 4, 53783},
	{"DRACULA", 7, 53784},
	{"UMM", 3, 53785},
	{"MODDING", 7, 53786},
	{"CHAMBERLAIN", 11, 53787},
	{"UEDW", 4, 53788},
	{"NPLU", 4, 53789},
	{"RDOO", 4, 53790},
	{"STEAMBOAT", 9, 53791},
	{"BREWSTER", 8, 53792},
	{"OHUM", 4, 53793},
	{"INFERRED", 8, 53794},
	{"SHAMAN", 6, 53795},
	{"LETRA", 5, 53796},
	{"CROFT", 5, 53797},
	{"EORR", 4, 53798},
	{"MBET", 4, 53799},
	{"DSOV", 4, 53800},
	{"ARMF", 4, 53801},
	{"EYCR", 4, 53802},
	{"FJUL", 4, 53803},
	{"UPLIFTING", 9, 53804},
	{"MANDRIVA", 8, 53805},
	{"UTHD", 4, 53806},
	{"EXTRACELLULAR", 13, 53807},
	{"PENAL", 5, 53808},
	{"EXCLUSIONS", 10, 53809},
	{"SBYD", 4, 53810},
	{"ETYR", 4, 53811},
	{"JAIPUR", 6, 53812},
	{"PAGEANT", 7, 53813},
	{"PSUP", 4, 53814},
	{"LDLY", 4, 53815},
	{"EMYI", 4, 53816},
	{"HENLEY", 6, 53817},
	{"PURCHASERS", 10, 53818},
	{"WONF", 4, 53819},
	{"STOCKPORT", 9, 53820},
	{"EIFFEL", 6, 53821},
	{"ZIMB", 4, 53822},
	{"PLYWOOD", 7, 53823},
	{"EDAK", 4, 53824},
	{"MORBIDITY", 9, 53825},
	{"WIMAX", 5, 53826},
	{"EFFEXOR", 7, 53827},
	{"GDRA", 4, 53828},
	{"BINDERS", 7, 53829},
	{"DNOL", 4, 53830},
	{"PITCHERS", 8, 53831},
	{"CUSTODIAL", 9, 53832},
	{"COMBI", 5, 53833},
	{"INTEGRATOR", 10, 53834},
	{"SONNERIE", 8, 53835},
	{"LKSH", 4, 53836},
	{"LCER", 4, 53837},
	{"TRACTS", 6, 53838},
	{"WNOU", 4, 53839},
	{"SECTORAL", 8, 53840},
	{"TROMBONE", 8, 53841},
	{"UBTH", 4, 53842},
	{"TCIR", 4, 53843},
	{"POSTSECONDARY", 13, 53844},
	{"MORALLY", 7, 53845},
	{"IUMC", 4, 53846},
	{"GESL", 4, 53847},
	{"CTUS", 4, 53848},
	{"RBD", 3, 53849},
	{"UDEP", 4, 53850},
	{"LPYO", 4, 53851},
	{"HOSIERY", 7, 53852},
	{"AMBULATORY", 10, 53853},
	{"UVD", 3, 53854},
	{"LOOKIN", 6, 53855},
	{"REPTILE", 7, 53856},
	{"FTOB", 4, 53857},
	{"XFF", 3, 53858},
	{"RSRI", 4, 53859},
	{"RROY", 4, 53860},
	{"RKLA", 4, 53861},
	{"GANF", 4, 53862},
	{"CAMOUFLAGE", 10, 53863},
	{"BECKHAM", 7, 53864},
	{"PENU", 4, 53865},
	{"MAMT", 4, 53866},
	{"LLBI", 4, 53867},
	{"ARFE", 4, 53868},
	{"OVERDUE", 7, 53869},
	{"DISPENSERS", 10, 53870},
	{"COWAN", 5, 53871},
	{"FIREBIRD", 8, 53872},
	{"MOHAWK", 6, 53873},
	{"RIOTS", 5, 53874},
	{"ICSR", 4, 53875},
	{"SHOWBIZ", 7, 53876},
	{"HASSAN", 6, 53877},
	{"SCHWARZ", 7, 53878},
	{"HBOX", 4, 53879},
	{"WAIKIKI", 7, 53880},
	{"YARC", 4, 53881},
	{"WFIR", 4, 53882},
	{"YTHU", 4, 53883},
	{"GLIC", 4, 53884},
	{"UEDF", 4, 53885},
	{"BLYR", 4, 53886},
	{"PERSUADED", 9, 53887},
	{"TEASING", 7, 53888},
	{"REJECTING", 9, 53889},
	{"LYOC", 4, 53890},
	{"EYSW", 4, 53891},
	{"EMPHASIZING", 11, 53892},
	{"UNBOUND", 7, 53893},
	{"QUENTIN", 7, 53894},
	{"ANTIQUA", 7, 53895},
	{"SERY", 4, 53896},
	{"SHEPARD", 7, 53897},
	{"SACRIFICES", 10, 53898},
	{"URTD", 4, 53899},
	{"ANGM", 4, 53900},
	{"DELINQUENT", 10, 53901},
	{"HMER", 4, 53902},
	{"YEXA", 4, 53903},
	{"GAFE", 4, 53904},
	{"CONTRASTING", 11, 53905},
	{"NESTLE", 6, 53906},
	{"WTIM", 4, 53907},
	{"CORRESPONDENTS", 14, 53908},
	{"BOXERS", 6, 53909},
	{"GUTHRIE", 7, 53910},
	{"EDWR", 4, 53911},
	{"IMPERFECT", 9, 53912},
	{"GTRO", 4, 53913},
	{"DISGUISE", 8, 53914},
	{"ELEVENTH", 8, 53915},
	{"EMBASSIES", 9, 53916},
	{"IMSW", 4, 53917},
	{"ASICS", 5, 53918},
	{"BARBEQUE", 8, 53919},
	{"WORKOUTS", 8, 53920},
	{"OCCO", 4, 53921},
	{"LAPSE", 5, 53922},
	{"OPLI", 4, 53923},
	{"DFIF", 4, 53924},
	{"MRC", 3, 53925},
	{"SEAMLESSLY", 10, 53926},
	{"GFIG", 4, 53927},
	{"WALLY", 5, 53928},
	{"GIRLFRIENDS", 11, 53929},
	{"PHENOMENAL", 10, 53930},
	{"SONGBOOK", 8, 53931},
	{"NMUR", 4, 53932},
	{"CIVILIZATIONS", 13, 53933},
	{"HEPATIC", 7, 53934},
	{"FRIENDSHIPS", 11, 53935},
	{"WNME", 4, 53936},
	{"BSCU", 4, 53937},
	{"COPELAND", 8, 53938},
	{"MARJORIE", 8, 53939},
	{"NNYW", 4, 53940},
	{"SHRUB", 5, 53941},
	{"RWRO", 4, 53942},
	{"IRMT", 4, 53943},
	{"KINDRED", 7, 53944},
	{"RECONSIDER", 10, 53945},
	{"SANCTIONED", 10, 53946},
	{"AFFT", 4, 53947},
	{"SWANSON", 7, 53948},
	{"AQUIFER", 7, 53949},
	{"PARFUMS", 7, 53950},
	{"RENEGADE", 8, 53951},
	{"OKSF", 4, 53952},
	{"FISL", 4, 53953},
	{"LAYU", 4, 53954},
	{"LDL", 3, 53955},
	{"FCLI", 4, 53956},
	{"YXC", 3, 53957},
	{"WCV", 3, 53958},
	{"AWAITS", 6, 53959},
	{"WOFR", 4, 53960},
	{"CHKI", 4, 53961},
	{"IORR", 4, 53962},
	{"DDEG", 4, 53963},
	{"AUGMENTED", 9, 53964},
	{"AMENDS", 6, 53965},
	{"SVENSK", 6, 53966},
	{"FULLEST", 7, 53967},
	{"SHAFTS", 6, 53968},
	{"FINER", 5, 53969},
	{"GLEV", 4, 53970},
	{"GFEA", 4, 53971},
	{"STEREOTYPES", 11, 53972},
	{"MARLINS", 7, 53973},
	{"BURDENS", 7, 53974},
	{"INVOCATION", 10, 53975},
	{"SHELLY", 6, 53976},
	{"GILLESPIE", 9, 53977},
	{"EXITING", 7, 53978},
	{"EUPD", 4, 53979},
	{"BROOCH", 6, 53980},
	{"SAGINAW", 7, 53981},
	{"POLYURETHANE", 12, 53982},
	{"MOTIFS", 6, 53983},
	{"TEXTUS", 6, 53984},
	{"DLOU", 4, 53985},
	{"LGUI", 4, 53986},
	{"MEOP", 4, 53987},
	{"ONGJ", 4, 53988},
	{"JOHANSSON", 9, 53989},
	{"WLES", 4, 53990},
	{"SPRAYING", 8, 53991},
	{"GRIFFITHS", 9, 53992},
	{"HAMBURGER", 9, 53993},
	{"REACTIVITY", 10, 53994},
	{"XXR", 3, 53995},
	{"UMAK", 4, 53996},
	{"FEBA", 4, 53997},
	{"YJAC", 4, 53998},
	{"INVADERS", 8, 53999},
	{"EDMOND", 6, 54000},
	{"LIEBERMAN", 9, 54001},
	{"BOXA", 4, 54002},
	{"RMUR", 4, 54003},
	{"GCRO", 4, 54004},
	{"FFBE", 4, 54005},
	{"VOLUNTEERED", 11, 54006},
	{"WINDCHILL", 9, 54007},
	{"EEDD", 4, 54008},
	{"SWOLLEN", 7, 54009},
	{"LISTE", 5, 54010},
	{"OMOL", 4, 54011},
	{"UIRY", 4, 54012},
	{"STOREFRONT", 10, 54013},
	{"GRASSES", 7, 54014},
	{"FBAT", 4, 54015},
	{"STEWARD", 7, 54016},
	{"CHERISHED", 9, 54017},
	{"SMACK", 5, 54018},
	{"INCIDENTALLY", 12, 54019},
	{"RADF", 4, 54020},
	{"NPAK", 4, 54021},
	{"ABOW", 4, 54022},
	{"YMES", 4, 54023},
	{"CODEINE", 7, 54024},
	{"TETEX", 5, 54025},
	{"SBYB", 4, 54026},
	{"CHEERLEADING", 12, 54027},
	{"WELLBEING", 9, 54028},
	{"PKWY", 4, 54029},
	{"YAFR", 4, 54030},
	{"CYWA", 4, 54031},
	{"DEPLETED", 8, 54032},
	{"PAWA", 4, 54033},
	{"HOLINESS", 8, 54034},
	{"DIVINITY", 8, 54035},
	{"CAMPAIGNING", 11, 54036},
	{"HAIRDRYER", 9, 54037},
	{"IMBO", 4, 54038},
	{"TOUGHER", 7, 54039},
	{"SHERLOCK", 8, 54040},
	{"PUNITIVE", 8, 54041},
	{"USHR", 4, 54042},
	{"COMPREHEND", 10, 54043},
	{"MCOR", 4, 54044},
	{"XMF", 3, 54045},
	{"DZK", 3, 54046},
	{"CLOAK", 5, 54047},
	{"YPOO", 4, 54048},
	{"RDTR", 4, 54049},
	{"OUTSOURCE", 9, 54050},
	{"THIER", 5, 54051},
	{"SIEBEL", 6, 54052},
	{"CAPTIONS", 8, 54053},
	{"YNEC", 4, 54054},
	{"PAMPHLET", 8, 54055},
	{"RTOV", 4, 54056},
	{"ELPU", 4, 54057},
	{"KLYS", 4, 54058},
	{"KACC", 4, 54059},
	{"CLIPPER", 7, 54060},
	{"CROL", 4, 54061},
	{"UMBRELLAS", 9, 54062},
	{"CHROMOSOMES", 11, 54063},
	{"PRICELESS", 9, 54064},
	{"NRYA", 4, 54065},
	{"ASSASSIN", 8, 54066},
	{"LTSF", 4, 54067},
	{"EMAILING", 8, 54068},
	{"EXPLOITING", 10, 54069},
	{"YLEC", 4, 54070},
	{"TCUS", 4, 54071},
	{"EKAL", 4, 54072},
	{"CYNICAL", 7, 54073},
	{"MANIC", 5, 54074},
	{"ETCHED", 6, 54075},
	{"NYDO", 4, 54076},
	{"NOVOTEL", 7, 54077},
	{"BRAY", 4, 54078},
	{"CHOKE", 5, 54079},
	{"TRANSMITTERS", 12, 54080},
	{"NICOLA", 6, 54081},
	{"NJOB", 4, 54082},
	{"PPAL", 4, 54083},
	{"MINIDV", 6, 54084},
	{"UNDERWENT", 9, 54085},
	{"COLLABORATING", 13, 54086},
	{"TUXEDO", 6, 54087},
	{"YOPI", 4, 54088},
	{"DJOE", 4, 54089},
	{"SGLA", 4, 54090},
	{"RECEPTUS", 8, 54091},
	{"MICHELIN", 8, 54092},
	{"OWSL", 4, 54093},
	{"GEMP", 4, 54094},
	{"COMFORTS", 8, 54095},
	{"ULPR", 4, 54096},
	{"AWOF", 4, 54097},
	{"APPOINTS", 8, 54098},
	{"BICYCLING", 9, 54099},
	{"ULLW", 4, 54100},
	{"TURG", 4, 54101},
	{"KEENE", 5, 54102},
	{"RACHAEL", 7, 54103},
	{"SWALLOWED", 9, 54104},
	{"BLUEBERRY", 9, 54105},
	{"KPRI", 4, 54106},
	{"HWEL", 4, 54107},
	{"SCHUMACHER", 10, 54108},
	{"YIMA", 4, 54109},
	{"WOOU", 4, 54110},
	{"HLYT", 4, 54111},
	{"IMPERIALISM", 11, 54112},
	{"MOUTHS", 6, 54113},
	{"SOCIOECONOMIC", 13, 54114},
	{"OFAY", 4, 54115},
	{"NCUB", 4, 54116},
	{"HALTER", 6, 54117},
	{"HAMSTER", 7, 54118},
	{"BUSHNELL", 8, 54119},
	{"ERGONOMICS", 10, 54120},
	{"EWFI", 4, 54121},
	{"DBEV", 4, 54122},
	{"AMOB", 4, 54123},
	{"FINALIZE", 8, 54124},
	{"SKYA", 4, 54125},
	{"NKSC", 4, 54126},
	{"LSAM", 4, 54127},
	{"LUMENS", 6, 54128},
	{"PUMPKINS", 8, 54129},
	{"ONUP", 4, 54130},
	{"SUDANESE", 8, 54131},
	{"SOFTPEDIA", 9, 54132},
	{"YHEC", 4, 54133},
	{"ISKY", 4, 54134},
	{"SHRINKING", 9, 54135},
	{"EURI", 4, 54136},
	{"RDGR", 4, 54137},
	{"YBK", 3, 54138},
	{"ROAR", 4, 54139},
	{"NOVELIST", 8, 54140},
	{"URTU", 4, 54141},
	{"FACEPLATE", 9, 54142},
	{"MASF", 4, 54143},
	{"PACKER", 6, 54144},
	{"POTOMAC", 7, 54145},
	{"KENU", 4, 54146},
	{"ARROYO", 6, 54147},
	{"GFIV", 4, 54148},
	{"ERMP", 4, 54149},
	{"CEXP", 4, 54150},
	{"AFLI", 4, 54151},
	{"TIPPED", 6, 54152},
	{"AKAM", 4, 54153},
	{"LYPH", 4, 54154},
	{"LLNA", 4, 54155},
	{"ESWR", 4, 54156},
	{"AMIDST", 6, 54157},
	{"INSURGENTS", 10, 54158},
	{"LGIU", 4, 54159},
	{"WANDA", 5, 54160},
	{"ETCHING", 7, 54161},
	{"DISCOURAGED", 11, 54162},
	{"GALL", 4, 54163},
	{"BEMU", 4, 54164},
	{"OBLIVION", 8, 54165},
	{"ORNU", 4, 54166},
	{"RRSQ", 4, 54167},
	{"HEDV", 4, 54168},
	{"GRAVY", 5, 54169},
	{"BROWARD", 7, 54170},
	{"GLOBUS", 6, 54171},
	{"HBLO", 4, 54172},
	{"STITCHING", 9, 54173},
	{"RECO", 4, 54174},
	{"SOFTCORE", 8, 54175},
	{"MAWH", 4, 54176},
	{"ADVISABLE", 9, 54177},
	{"MEME", 4, 54178},
	{"YSME", 4, 54179},
	{"REFERENCING", 11, 54180},
	{"GLADSTONE", 9, 54181},
	{"GUANGZHOU", 9, 54182},
	{"JUGS", 4, 54183},
	{"KOFB", 4, 54184},
	{"CONGREGATIONS", 13, 54185},
	{"HANDING", 7, 54186},
	{"PAYER", 5, 54187},
	{"MRAN", 4, 54188},
	{"IFYF", 4, 54189},
	{"HERQ", 4, 54190},
	{"BEFOREHAND", 10, 54191},
	{"FATL", 4, 54192},
	{"NADER", 5, 54193},
	{"LABORER", 7, 54194},
	{"EYDA", 4, 54195},
	{"MILITANTS", 9, 54196},
	{"TBYH", 4, 54197},
	{"RESINS", 6, 54198},
	{"WATCHER", 7, 54199},
	{"FJUN", 4, 54200},
	{"VIBRATIONS", 10, 54201},
	{"LBIL", 4, 54202},
	{"STRAWBERRIES", 12, 54203},
	{"ABBAS", 5, 54204},
	{"MOODS", 5, 54205},
	{"COUGAR", 6, 54206},
	{"MONTROSE", 8, 54207},
	{"DOBSON", 6, 54208},
	{"SURREAL", 7, 54209},
	{"SOAKED", 6, 54210},
	{"IRRADIATION", 11, 54211},
	{"REDESIGNED", 10, 54212},
	{"UYOU", 4, 54213},
	{"SAJU", 4, 54214},
	{"RASTER", 6, 54215},
	{"MEDG", 4, 54216},
	{"LCUT", 4, 54217},
	{"CKRA", 4, 54218},
	{"ABRIDGED", 8, 54219},
	{"CREDENTIAL", 10, 54220},
	{"ELFU", 4, 54221},
	{"CHECKLISTS", 10, 54222},
	{"XUC", 3, 54223},
	{"MYBR", 4, 54224},
	{"QUIRKY", 6, 54225},
	{"OSCILLATOR", 10, 54226},
	{"PALATE", 6, 54227},
	{"FINALISTS", 9, 54228},
	{"DDOG", 4, 54229},
	{"ENCRYPT", 7, 54230},
	{"CANK", 4, 54231},
	{"VALB", 4, 54232},
	{"NVID", 4, 54233},
	{"THIERRY", 7, 54234},
	{"RENV", 4, 54235},
	{"SNEAKERS", 8, 54236},
	{"INCONTINENCE", 12, 54237},
	{"PAJAMAS", 7, 54238},
	{"MASCULINE", 9, 54239},
	{"MURDOCH", 7, 54240},
	{"DALI", 4, 54241},
	{"DUPP", 4, 54242},
	{"LUBRICANT", 9, 54243},
	{"RTAM", 4, 54244},
	{"RGAV", 4, 54245},
	{"ETYC", 4, 54246},
	{"REALIZES", 8, 54247},
	{"FOFS", 4, 54248},
	{"QUESTS", 6, 54249},
	{"TARV", 4, 54250},
	{"PETITIONERS", 11, 54251},
	{"OUTSOURCED", 10, 54252},
	{"CONSTABLE", 9, 54253},
	{"JODY", 4, 54254},
	{"NTYL", 4, 54255},
	{"SAYINGS", 7, 54256},
	{"UNCONDITIONAL", 13, 54257},
	{"EYGR", 4, 54258},
	{"PLASMID", 7, 54259},
	{"CKYT", 4, 54260},
	{"SCHIAVO", 7, 54261},
	{"GDAT", 4, 54262},
	{"EWEG", 4, 54263},
	{"UNBEATABLE", 10, 54264},
	{"PROGRESSIVELY", 13, 54265},
	{"UPSTATE", 7, 54266},
	{"LYMPHOCYTES", 11, 54267},
	{"TOPPING", 7, 54268},
	{"REPAYMENTS", 10, 54269},
	{"BAIRD", 5, 54270},
	{"CHILLING", 8, 54271},
	{"TRANSLUCENT", 11, 54272},
	{"FUELED", 6, 54273},
	{"GLAZE", 5, 54274},
	{"NEWCOMER", 8, 54275},
	{"APSY", 4, 54276},
	{"DGAT", 4, 54277},
	{"CTSL", 4, 54278},
	{"BRANCHING", 9, 54279},
	{"XANGA", 5, 54280},
	{"UNMARRIED", 9, 54281},
	{"SVERIGE", 7, 54282},
	{"EXTRAIT", 7, 54283},
	{"PELVIC", 6, 54284},
	{"MONOCHROME", 10, 54285},
	{"ACTIVATING", 10, 54286},
	{"ANTIOXIDANTS", 12, 54287},
	{"YLEB", 4, 54288},
	{"GYNECOLOGY", 10, 54289},
	{"TTYC", 4, 54290},
	{"KALS", 4, 54291},
	{"UNEXPECTEDLY", 12, 54292},
	{"MYTHTV", 6, 54293},
	{"FUNNIEST", 8, 54294},
	{"AIRR", 4, 54295},
	{"PROBABILISTIC", 13, 54296},
	{"OEDU", 4, 54297},
	{"HDIR", 4, 54298},
	{"SCORPION", 8, 54299},
	{"MIRRORED", 8, 54300},
	{"YGIR", 4, 54301},
	{"COOPERATING", 11, 54302},
	{"CALIBRATED", 10, 54303},
	{"TECU", 4, 54304},
	{"XVC", 3, 54305},
	{"DZR", 3, 54306},
	{"OYSW", 4, 54307},
	{"OWUS", 4, 54308},
	{"GBEL", 4, 54309},
	{"PHASED", 6, 54310},
	{"YGER", 4, 54311},
	{"MHEW", 4, 54312},
	{"ANATOMICAL", 10, 54313},
	{"PESW", 4, 54314},
	{"GODZILLA", 8, 54315},
	{"OFYA", 4, 54316},
	{"GBAR", 4, 54317},
	{"EWEEK", 5, 54318},
	{"AIRBUS", 6, 54319},
	{"SIMPLEX", 7, 54320},
	{"WEBHOME", 7, 54321},
	{"PBYT", 4, 54322},
	{"OPPA", 4, 54323},
	{"MISDEMEANOR", 11, 54324},
	{"FAFI", 4, 54325},
	{"AEROBICS", 8, 54326},
	{"SABRINA", 7, 54327},
	{"OKAB", 4, 54328},
	{"ATMC", 4, 54329},
	{"FAWA", 4, 54330},
	{"TOBIAS", 6, 54331},
	{"SALLE", 5, 54332},
	{"UPAB", 4, 54333},
	{"INFRA", 5, 54334},
	{"STRASBOURG", 10, 54335},
	{"COMMEMORATIVE", 13, 54336},
	{"ELSR", 4, 54337},
	{"CONDOR", 6, 54338},
	{"RKWE", 4, 54339},
	{"OPSF", 4, 54340},
	{"CUPF", 4, 54341},
	{"GATED", 5, 54342},
	{"GAAP", 4, 54343},
	{"IMPLICITLY", 10, 54344},
	{"DELM", 4, 54345},
	{"LERL", 4, 54346},
	{"HPUB", 4, 54347},
	{"JGU", 3, 54348},
	{"NBIR", 4, 54349},
	{"GWEA", 4, 54350},
	{"EBAYER", 6, 54351},
	{"EWING", 5, 54352},
	{"AUSTEN", 6, 54353},
	{"OVSK", 4, 54354},
	{"ASSURANCES", 10, 54355},
	{"GTOJ", 4, 54356},
	{"BITRATE", 7, 54357},
	{"KARNATAKA", 9, 54358},
	{"COMEDIAN", 8, 54359},
	{"APAG", 4, 54360},
	{"RASCAL", 6, 54361},
	{"BDIV", 4, 54362},
	{"AADM", 4, 54363},
	{"AMISH", 5, 54364},
	{"ROBERTA", 7, 54365},
	{"FFM", 3, 54366},
	{"HYPERLINKS", 10, 54367},
	{"DIZZY", 5, 54368},
	{"OUTBREAKS", 9, 54369},
	{"ANNUITIES", 9, 54370},
	{"WSAL", 4, 54371},
	{"AYAK", 4, 54372},
	{"CRIBS", 5, 54373},
	{"WHITENING", 9, 54374},
	{"OCCUPYING", 9, 54375},
	{"RELIANT", 7, 54376},
	{"NAFU", 4, 54377},
	{"GSMO", 4, 54378},
	{"FHUN", 4, 54379},
	{"EVAB", 4, 54380},
	{"SUBCONTRACTOR", 13, 54381},
	{"LEDV", 4, 54382},
	{"FENDI", 5, 54383},
	{"GIVEAWAYS", 9, 54384},
	{"RJIM", 4, 54385},
	{"HDUR", 4, 54386},
	{"DEPICTING", 9, 54387},
	{"ORDNANCE", 8, 54388},
	{"EFEB", 4, 54389},
	{"PSYCH", 5, 54390},
	{"HYDROCHLORIDE", 13, 54391},
	{"HMOV", 4, 54392},
	{"DOIL", 4, 54393},
	{"VERGE", 5, 54394},
	{"RANSOM", 6, 54395},
	{"DTHC", 4, 54396},
	{"MAGNIFICATION", 13, 54397},
	{"IVEK", 4, 54398},
	{"NOMAD", 5, 54399},
	{"TWELFTH", 7, 54400},
	{"DAGGER", 6, 54401},
	{"WALO", 4, 54402},
	{"THORN", 5, 54403},
	{"PREAMBLE", 8, 54404},
	{"PROPONENTS", 10, 54405},
	{"PRICELINE", 9, 54406},
	{"ICFL", 4, 54407},
	{"FWED", 4, 54408},
	{"ECCO", 4, 54409},
	{"SPINS", 5, 54410},
	{"SOLICIT", 7, 54411},
	{"IRDF", 4, 54412},
	{"MYAW", 4, 54413},
	{"PROVOKING", 9, 54414},
	{"BACKPACKERS", 11, 54415},
	{"ORCHIDS", 7, 54416},
	{"BUCKETS", 7, 54417},
	{"UEDU", 4, 54418},
	{"KOHLER", 6, 54419},
	{"RILW", 4, 54420},
	{"INITIALIZED", 11, 54421},
	{"DJOU", 4, 54422},
	{"YGOE", 4, 54423},
	{"SILVERADO", 9, 54424},
	{"SPOIL", 5, 54425},
	{"EELF", 4, 54426},
	{"PSYCHIATRIST", 12, 54427},
	{"LAUDER", 6, 54428},
	{"SOLDERING", 9, 54429},
	{"YSDI", 4, 54430},
	{"PHONO", 5, 54431},
	{"KVU", 3, 54432},
	{"TOMR", 4, 54433},
	{"CRD", 3, 54434},
	{"DARYL", 5, 54435},
	{"ODFI", 4, 54436},
	{"BLAZING", 7, 54437},
	{"ERIW", 4, 54438},
	{"PALERMO", 7, 54439},
	{"LEHMAN", 6, 54440},
	{"DAIHATSU", 8, 54441},
	{"GRANTEE", 7, 54442},
	{"ENHANCER", 8, 54443},
	{"UBOR", 4, 54444},
	{"OLYT", 4, 54445},
	{"SMOB", 4, 54446},
	{"APEF", 4, 54447},
	{"ANGLERS", 7, 54448},
	{"SNAPPED", 7, 54449},
	{"ALLIGATOR", 9, 54450},
	{"DETECTIVES", 10, 54451},
	{"ROCHELLE", 8, 54452},
	{"YEIG", 4, 54453},
	{"RSIL", 4, 54454},
	{"GEFU", 4, 54455},
	{"FITM", 4, 54456},
	{"TLAC", 4, 54457},
	{"ROTTWEILER", 10, 54458},
	{"NOMENCLATURE", 12, 54459},
	{"ABDULLAH", 8, 54460},
	{"FILEFRONT", 9, 54461},
	{"SIXD", 4, 54462},
	{"TUPF", 4, 54463},
	{"VISUALIZE", 9, 54464},
	{"YERR", 4, 54465},
	{"GSTY", 4, 54466},
	{"DJIM", 4, 54467},
	{"IDBR", 4, 54468},
	{"ICTM", 4, 54469},
	{"ELSD", 4, 54470},
	{"REGULATES", 9, 54471},
	{"YERD", 4, 54472},
	{"BIDPAY", 6, 54473},
	{"AYSK", 4, 54474},
	{"WINM", 4, 54475},
	{"RENDEZVOUS", 10, 54476},
	{"UGER", 4, 54477},
	{"RCEH", 4, 54478},
	{"MEJO", 4, 54479},
	{"ACYC", 4, 54480},
	{"STRIVES", 7, 54481},
	{"TRAPPING", 8, 54482},
	{"UEEZ", 4, 54483},
	{"GARDENERS", 9, 54484},
	{"RBAB", 4, 54485},
	{"CLEMENS", 7, 54486},
	{"TURNTABLE", 9, 54487},
	{"DEUTERONOMY", 11, 54488},
	{"GATP", 4, 54489},
	{"CLEL", 4, 54490},
	{"SCREENINGS", 10, 54491},
	{"BRITANNIA", 9, 54492},
	{"PIVOTAL", 7, 54493},
	{"RIZZ", 4, 54494},
	{"WNLA", 4, 54495},
	{"HEUER", 5, 54496},
	{"PHYI", 4, 54497},
	{"EEPM", 4, 54498},
	{"MANIFESTATIONS", 14, 54499},
	{"LHUN", 4, 54500},
	{"LINENO", 6, 54501},
	{"GLYP", 4, 54502},
	{"STITCHES", 8, 54503},
	{"LOFN", 4, 54504},
	{"PROMULGATED", 11, 54505},
	{"RBOX", 4, 54506},
	{"LDVI", 4, 54507},
	{"LDTI", 4, 54508},
	{"KSGI", 4, 54509},
	{"MEDIOCRE", 8, 54510},
	{"PROVO", 5, 54511},
	{"PASSPORTS", 9, 54512},
	{"LKIL", 4, 54513},
	{"KEBO", 4, 54514},
	{"NICW", 4, 54515},
	{"CHECKINS", 8, 54516},
	{"AYRSHIRE", 8, 54517},
	{"RFLY", 4, 54518},
	{"PLATING", 7, 54519},
	{"EAGERLY", 7, 54520},
	{"RANB", 4, 54521},
	{"UANC", 4, 54522},
	{"DFER", 4, 54523},
	{"LYCRA", 5, 54524},
	{"PLANCK", 6, 54525},
	{"DAMASCUS", 8, 54526},
	{"YUGIOH", 6, 54527},
	{"REACTORS", 8, 54528},
	{"REFORMATION", 11, 54529},
	{"KINGSLEY", 8, 54530},
	{"RAQU", 4, 54531},
	{"MORM", 4, 54532},
	{"GUNF", 4, 54533},
	{"CAREERBUILDER", 13, 54534},
	{"NDUB", 4, 54535},
	{"DWEC", 4, 54536},
	{"HYPOCRISY", 9, 54537},
	{"RNBU", 4, 54538},
	{"GILLETTE", 8, 54539},
	{"YBG", 3, 54540},
	{"JQU", 3, 54541},
	{"CZB", 3, 54542},
	{"BBAS", 4, 54543},
	{"AMPW", 4, 54544},
	{"FLUORIDE", 8, 54545},
	{"PARISHES", 8, 54546},
	{"STACKING", 8, 54547},
	{"COCHRAN", 7, 54548},
	{"FEWB", 4, 54549},
	{"NGEQ", 4, 54550},
	{"YDEB", 4, 54551},
	{"SUOMI", 5, 54552},
	{"SISSY", 5, 54553},
	{"TROOPER", 7, 54554},
	{"RCOP", 4, 54555},
	{"ICTB", 4, 54556},
	{"TRANG", 5, 54557},
	{"DOFU", 4, 54558},
	{"DIDL", 4, 54559},
	{"CALCULATES", 10, 54560},
	{"COMPENDIUM", 10, 54561},
	{"DIOW", 4, 54562},
	{"THUNDERSTORMS", 13, 54563},
	{"DISAPPEARS", 10, 54564},
	{"PSOU", 4, 54565},
	{"ADGA", 4, 54566},
	{"NVEY", 4, 54567},
	{"TRANSCRIPTIONAL", 15, 54568},
	{"HYMNS", 5, 54569},
	{"MONOTONE", 8, 54570},
	{"FINALIZED", 9, 54571},
	{"REFEREES", 8, 54572},
	{"TCUL", 4, 54573},
	{"PALSY", 5, 54574},
	{"ROFK", 4, 54575},
	{"MBOO", 4, 54576},
	{"HEFB", 4, 54577},
	{"OUME", 4, 54578},
	{"LLCI", 4, 54579},
	{"DEERFIELD", 9, 54580},
	{"RBAI", 4, 54581},
	{"PROPOSITIONS", 12, 54582},
	{"FMOU", 4, 54583},
	{"LOCOMOTIVE", 10, 54584},
	{"COCHRANE", 8, 54585},
	{"OWCH", 4, 54586},
	{"NSDR", 4, 54587},
	{"DEBATING", 8, 54588},
	{"ELDORADO", 8, 54589},
	{"LVAT", 4, 54590},
	{"EEMU", 4, 54591},
	{"ESMTP", 5, 54592},
	{"TWRO", 4, 54593},
	{"ELGO", 4, 54594},
	{"CUFFS", 5, 54595},
	{"CONSERVANCY", 11, 54596},
	{"OMIM", 4, 54597},
	{"YZC", 3, 54598},
	{"LZC", 3, 54599},
	{"LQB", 3, 54600},
	{"PROSPEROUS", 10, 54601},
	{"FAMINE", 6, 54602},
	{"DIELECTRIC", 10, 54603},
	{"FTFI", 4, 54604},
	{"ORALLY", 6, 54605},
	{"YGAI", 4, 54606},
	{"HELB", 4, 54607},
	{"ELLIPTICAL", 10, 54608},
	{"ANAND", 5, 54609},
	{"ELECTROPHORESIS", 15, 54610},
	{"VAUL", 4, 54611},
	{"UMPR", 4, 54612},
	{"GTAX", 4, 54613},
	{"UNGU", 4, 54614},
	{"HDIV", 4, 54615},
	{"GRABBING", 8, 54616},
	{"JOGGING", 7, 54617},
	{"SPRINKLER", 9, 54618},
	{"STIPULATED", 10, 54619},
	{"UERS", 4, 54620},
	{"IMBALANCE", 9, 54621},
	{"YBEU", 4, 54622},
	{"PERSUASIVE", 10, 54623},
	{"NICF", 4, 54624},
	{"IPWH", 4, 54625},
	{"EYAP", 4, 54626},
	{"TBEU", 4, 54627},
	{"LCOO", 4, 54628},
	{"HORRORS", 7, 54629},
	{"DYWO", 4, 54630},
	{"SCARLETT", 8, 54631},
	{"BEARER", 6, 54632},
	{"MMAS", 4, 54633},
	{"GSLE", 4, 54634},
	{"PASTORS", 7, 54635},
	{"NOVAK", 5, 54636},
	{"HIMR", 4, 54637},
	{"ACQUAINTED", 10, 54638},
	{"DEPENDENTS", 10, 54639},
	{"RSHU", 4, 54640},
	{"DNOB", 4, 54641},
	{"DIZZINESS", 9, 54642},
	{"BACKCOUNTRY", 11, 54643},
	{"ARTISTDIRECT", 12, 54644},
	{"OUTBOARD", 8, 54645},
	{"TURE", 4, 54646},
	{"DLAK", 4, 54647},
	{"BRILLIANCE", 10, 54648},
	{"NSCU", 4, 54649},
	{"NICKY", 5, 54650},
	{"ORIGINATE", 9, 54651},
	{"PITCHES", 7, 54652},
	{"RESPECTABLE", 11, 54653},
	{"UDDL", 4, 54654},
	{"ORNF", 4, 54655},
	{"LOCKHEED", 8, 54656},
	{"JORF", 4, 54657},
	{"YSAB", 4, 54658},
	{"HORACE", 6, 54659},
	{"PROHIBITING", 11, 54660},
	{"ULHA", 4, 54661},
	{"DISAPPEARANCE", 13, 54662},
	{"UTHM", 4, 54663},
	{"MORALS", 6, 54664},
	{"ELMO", 4, 54665},
	{"INVADED", 7, 54666},
	{"UKAN", 4, 54667},
	{"UNMATCHED", 9, 54668},
	{"SCRANTON", 8, 54669},
	{"SPOILED", 7, 54670},
	{"EGYM", 4, 54671},
	{"IXUS", 4, 54672},
	{"TYAF", 4, 54673},
	{"PINPOINT", 8, 54674},
	{"DWIS", 4, 54675},
	{"LWOM", 4, 54676},
	{"KSMO", 4, 54677},
	{"MONET", 5, 54678},
	{"GABBANA", 7, 54679},
	{"SOWR", 4, 54680},
	{"BLUN", 4, 54681},
	{"MAFO", 4, 54682},
	{"PICKLE", 6, 54683},
	{"NEUMANN", 7, 54684},
	{"OUTTA", 5, 54685},
	{"DIETING", 7, 54686},
	{"ANDHRA", 6, 54687},
	{"RALF", 4, 54688},
	{"OMFE", 4, 54689},
	{"QUAKER", 6, 54690},
	{"HAUNTING", 8, 54691},
	{"MANIPULATING", 12, 54692},
	{"EMUP", 4, 54693},
	{"GFEE", 4, 54694},
	{"TANGENT", 7, 54695},
	{"GSLO", 4, 54696},
	{"TEMPEST", 7, 54697},
	{"OPEZ", 4, 54698},
	{"APPRAISERS", 10, 54699},
	{"PETRA", 5, 54700},
	{"XENON", 5, 54701},
	{"MOFE", 4, 54702},
	{"DOMINIQUE", 9, 54703},
	{"HYBRIDIZATION", 13, 54704},
	{"WAVING", 6, 54705},
	{"ABERCROMBIE", 11, 54706},
	{"TRAX", 4, 54707},
	{"ODUS", 4, 54708},
	{"OTHEROSFS", 9, 54709},
	{"BABW", 4, 54710},
	{"YJAM", 4, 54711},
	{"KEDG", 4, 54712},
	{"HCAU", 4, 54713},
	{"GLIF", 4, 54714},
	{"UNEVEN", 6, 54715},
	{"DANBURY", 7, 54716},
	{"CONR", 4, 54717},
	{"PLATA", 5, 54718},
	{"PLURALITY", 9, 54719},
	{"NOFX", 4, 54720},
	{"WARRINGTON", 10, 54721},
	{"RTPH", 4, 54722},
	{"OWID", 4, 54723},
	{"SHARMA", 6, 54724},
	{"ADVENTUROUS", 11, 54725},
	{"ROCKERS", 7, 54726},
	{"PALLIATIVE", 10, 54727},
	{"SIRR", 4, 54728},
	{"LORB", 4, 54729},
	{"RECIEVE", 7, 54730},
	{"LUIGI", 5, 54731},
	{"LYIL", 4, 54732},
	{"YOFY", 4, 54733},
	{"BAYOU", 5, 54734},
	{"ACCUEIL", 7, 54735},
	{"CUFFLINKS", 9, 54736},
	{"QUEUES", 6, 54737},
	{"OUEV", 4, 54738},
	{"FSIG", 4, 54739},
	{"RELISTED", 8, 54740},
	{"BEEP", 4, 54741},
	{"YBYP", 4, 54742},
	{"DUNEDIN", 7, 54743},
	{"RATB", 4, 54744},
	{"LPIE", 4, 54745},
	{"YDAR", 4, 54746},
	{"REMANUFACTURED", 14, 54747},
	{"CONFLUENCE", 10, 54748},
	{"WSPR", 4, 54749},
	{"TCHL", 4, 54750},
	{"DLAY", 4, 54751},
	{"STAFFED", 7, 54752},
	{"RTTR", 4, 54753},
	{"OMVI", 4, 54754},
	{"ODAM", 4, 54755},
	{"BLOSSOMS", 8, 54756},
	{"SUCCEEDS", 8, 54757},
	{"ORPHANS", 7, 54758},
	{"LOUDER", 6, 54759},
	{"LIGHTSPEED", 10, 54760},
	{"MWAT", 4, 54761},
	{"GWRO", 4, 54762},
	{"GRILLING", 8, 54763},
	{"STALIN", 6, 54764},
	{"BOILERS", 7, 54765},
	{"KAYE", 4, 54766},
	{"LLJO", 4, 54767},
	{"DELW", 4, 54768},
	{"REUNIONS", 8, 54769},
	{"EBAK", 4, 54770},
	{"CAMO", 4, 54771},
	{"SHOUTBOX", 8, 54772},
	{"YELLING", 7, 54773},
	{"HOMESCHOOL", 10, 54774},
	{"CEGE", 4, 54775},
	{"CCG", 3, 54776},
	{"LIFEHOUSE", 9, 54777},
	{"UGEA", 4, 54778},
	{"WINDSURFING", 11, 54779},
	{"TROUGH", 6, 54780},
	{"MSFI", 4, 54781},
	{"ZUEL", 4, 54782},
	{"YLOA", 4, 54783},
	{"LEANED", 6, 54784},
	{"QUADRANT", 8, 54785},
	{"DISCREPANCY", 11, 54786},
	{"SLID", 4, 54787},
	{"PATTAYA", 7, 54788},
	{"NICG", 4, 54789},
	{"ANTIOCH", 7, 54790},
	{"UNTREATED", 9, 54791},
	{"RMAM", 4, 54792},
	{"COWO", 4, 54793},
	{"MKDIR", 5, 54794},
	{"OUGU", 4, 54795},
	{"OUPB", 4, 54796},
	{"DIVISIONAL", 10, 54797},
	{"RYUS", 4, 54798},
	{"CHIHUAHUA", 9, 54799},
	{"KINL", 4, 54800},
	{"MCCONNELL", 9, 54801},
	{"DPUS", 4, 54802},
	{"TONIC", 5, 54803},
	{"RESELL", 6, 54804},
	{"CHANDIGARH", 10, 54805},
	{"YLLA", 4, 54806},
	{"RTAU", 4, 54807},
	{"CENTRINO", 8, 54808},
	{"OSBOURNE", 8, 54809},
	{"MAGNUS", 6, 54810},
	{"IDJO", 4, 54811},
	{"CGRA", 4, 54812},
	{"BURNOUT", 7, 54813},
	{"RREB", 4, 54814},
	{"CLASSPATH", 9, 54815},
	{"DESIGNATIONS", 12, 54816},
	{"NPHY", 4, 54817},
	{"GASL", 4, 54818},
	{"DGOD", 4, 54819},
	{"HARROW", 6, 54820},
	{"RECKLESS", 8, 54821},
	{"MICROWAVES", 10, 54822},
	{"RAINING", 7, 54823},
	{"WCAL", 4, 54824},
	{"IDWO", 4, 54825},
	{"VADER", 5, 54826},
	{"FMAG", 4, 54827},
	{"COLISEUM", 8, 54828},
	{"EPHEDRA", 7, 54829},
	{"SPAWNING", 8, 54830},
	{"ENDOTHELIAL", 11, 54831},
	{"FIGURING", 8, 54832},
	{"CITRATE", 7, 54833},
	{"SLYP", 4, 54834},
	{"RRUL", 4, 54835},
	{"RDIG", 4, 54836},
	{"EDUARDO", 7, 54837},
	{"RLTO", 4, 54838},
	{"LWHA", 4, 54839},
	{"CRUSHING", 8, 54840},
	{"SNOWMAN", 7, 54841},
	{"RUQ", 3, 54842},
	{"UTJO", 4, 54843},
	{"THORPE", 6, 54844},
	{"RAQA", 4, 54845},
	{"ORDAINED", 8, 54846},
	{"EDMONDS", 7, 54847},
	{"HODGES", 6, 54848},
	{"SAUCER", 6, 54849},
	{"CHINOOK", 7, 54850},
	{"POTTY", 5, 54851},
	{"MICROBIOL", 9, 54852},
	{"EELM", 4, 54853},
	{"SHOOTERS", 8, 54854},
	{"AELC", 4, 54855},
	{"PASSOVER", 8, 54856},
	{"NORWALK", 7, 54857},
	{"BACILLUS", 8, 54858},
	{"ORUL", 4, 54859},
	{"GLAT", 4, 54860},
	{"RFLE", 4, 54861},
	{"FWER", 4, 54862},
	{"UGAT", 4, 54863},
	{"HEKU", 4, 54864},
	{"BYZANTINE", 9, 54865},
	{"TOMAS", 5, 54866},
	{"HDEV", 4, 54867},
	{"TRIANGLES", 9, 54868},
	{"URYM", 4, 54869},
	{"SPOOKY", 6, 54870},
	{"CURVATURE", 9, 54871},
	{"IMBY", 4, 54872},
	{"VIDC", 4, 54873},
	{"NDYI", 4, 54874},
	{"RITES", 5, 54875},
	{"LSIZ", 4, 54876},
	{"UNKA", 4, 54877},
	{"KSDO", 4, 54878},
	{"SIDEWAYS", 8, 54879},
	{"DEVIOUS", 7, 54880},
	{"BELLEVILLE", 10, 54881},
	{"VENEZUELAN", 10, 54882},
	{"DREAMER", 7, 54883},
	{"ETCR", 4, 54884},
	{"DITL", 4, 54885},
	{"ACKNOWLEDGING", 13, 54886},
	{"SLYO", 4, 54887},
	{"ESTUARY", 7, 54888},
	{"YBEB", 4, 54889},
	{"OKWA", 4, 54890},
	{"PSOR", 4, 54891},
	{"INKC", 4, 54892},
	{"BURGLARY", 8, 54893},
	{"BYAU", 4, 54894},
	{"CBR", 3, 54895},
	{"COLBY", 5, 54896},
	{"ILYG", 4, 54897},
	{"FTEL", 4, 54898},
	{"VECE", 4, 54899},
	{"LSEP", 4, 54900},
	{"LECI", 4, 54901},
	{"HSUR", 4, 54902},
	{"POUCHES", 7, 54903},
	{"TGLO", 4, 54904},
	{"FSIM", 4, 54905},
	{"OFAK", 4, 54906},
	{"LFFR", 4, 54907},
	{"SUBPOENA", 8, 54908},
	{"THRILLING", 9, 54909},
	{"SPECTACLE", 9, 54910},
	{"SENTIMENTS", 10, 54911},
	{"INTERPRETIVE", 12, 54912},
	{"DITTO", 5, 54913},
	{"EXTENDER", 8, 54914},
	{"WAITER", 6, 54915},
	{"PPRI", 4, 54916},
	{"GLUCOSAMINE", 11, 54917},
	{"PROJ", 4, 54918},
	{"ODDLY", 5, 54919},
	{"BEOV", 4, 54920},
	{"MODESTO", 7, 54921},
	{"IFRO", 4, 54922},
	{"DESIGNJET", 9, 54923},
	{"TYPHOON", 7, 54924},
	{"LAUNCHCAST", 10, 54925},
	{"NJER", 4, 54926},
	{"RJON", 4, 54927},
	{"REFERRER", 8, 54928},
	{"ZHEJIANG", 8, 54929},
	{"SUCHEN", 6, 54930},
	{"IGBR", 4, 54931},
	{"EMYC", 4, 54932},
	{"RAFT", 4, 54933},
	{"CUL", 3, 54934},
	{"GSAY", 4, 54935},
	{"AELW", 4, 54936},
	{"XXP", 3, 54937},
	{"NUTSHELL", 8, 54938},
	{"ARROGANT", 8, 54939},
	{"RICCI", 5, 54940},
	{"GSPI", 4, 54941},
	{"HERMANN", 7, 54942},
	{"SUPERHERO", 9, 54943},
	{"INDUCES", 7, 54944},
	{"TOOLING", 7, 54945},
	{"TOMOGRAPHY", 10, 54946},
	{"UMHA", 4, 54947},
	{"THRIFT", 6, 54948},
	{"OLFR", 4, 54949},
	{"BERMAN", 6, 54950},
	{"FLYT", 4, 54951},
	{"VOCALIST", 8, 54952},
	{"DFIT", 4, 54953},
	{"TIDBITS", 7, 54954},
	{"ADMIRED", 7, 54955},
	{"STUNTS", 6, 54956},
	{"RLOF", 4, 54957},
	{"CYSTIC", 6, 54958},
	{"SBRU", 4, 54959},
	{"PACIFICA", 8, 54960},
	{"THYP", 4, 54961},
	{"KOSTENLOS", 9, 54962},
	{"OGAV", 4, 54963},
	{"ANNIVERSARIES", 13, 54964},
	{"RNIR", 4, 54965},
	{"XEDA", 4, 54966},
	{"EUMI", 4, 54967},
	{"INFRASTRUCTURES", 15, 54968},
	{"LITTLETON", 9, 54969},
	{"LOWG", 4, 54970},
	{"YOUTHFUL", 8, 54971},
	{"COMMENTERS", 10, 54972},
	{"LECE", 4, 54973},
	{"CALI", 4, 54974},
	{"XOFT", 4, 54975},
	{"CABR", 4, 54976},
	{"FAIRWAY", 7, 54977},
	{"POSTDOCTORAL", 12, 54978},
	{"STUMBLED", 8, 54979},
	{"LHIL", 4, 54980},
	{"FAIRCHILD", 9, 54981},
	{"LUEF", 4, 54982},
	{"YBYS", 4, 54983},
	{"EMITTED", 7, 54984},
	{"GETL", 4, 54985},
	{"SPINNER", 7, 54986},
	{"MINV", 4, 54987},
	{"EVANSTON", 8, 54988},
	{"HOMEOPATHIC", 11, 54989},
	{"BTED", 4, 54990},
	{"ORDINARILY", 10, 54991},
	{"SUFFICIENCY", 11, 54992},
	{"TEMPERED", 8, 54993},
	{"SLIPPING", 8, 54994},
	{"SOLITUDE", 8, 54995},
	{"CYLINDRICAL", 11, 54996},
	{"CPD", 3, 54997},
	{"MYWH", 4, 54998},
	{"NEDV", 4, 54999},
	{"DESTROYER", 9, 55000},
	{"BRAKING", 7, 55001},
	{"RDDA", 4, 55002},
	{"FIDE", 4, 55003},
	{"UNDESIRABLE", 11, 55004},
	{"PLATELET", 8, 55005},
	{"EUDO", 4, 55006},
	{"MESSAGEBOARD", 12, 55007},
	{"LBUD", 4, 55008},
	{"XIBL", 4, 55009},
	{"PINB", 4, 55010},
	{"DYKN", 4, 55011},
	{"DSCE", 4, 55012},
	{"MONGOLIAN", 9, 55013},
	{"TALV", 4, 55014},
	{"WEAKLY", 6, 55015},
	{"PARSLEY", 7, 55016},
	{"UNDUE", 5, 55017},
	{"SETBACK", 7, 55018},
	{"STUNNED", 7, 55019},
	{"SMITHS", 6, 55020},
	{"MAGYAR", 6, 55021},
	{"RECIPEZAAR", 10, 55022},
	{"INSTALLERS", 10, 55023},
	{"CRIE", 4, 55024},
	{"YYR", 3, 55025},
	{"YFG", 3, 55026},
	{"PXX", 3, 55027},
	{"HOSTILITY", 9, 55028},
	{"GROVES", 6, 55029},
	{"SUBCATEGORY", 11, 55030},
	{"PURSUITS", 8, 55031},
	{"MARKOV", 6, 55032},
	{"RAFU", 4, 55033},
	{"NICR", 4, 55034},
	{"REFLUX", 6, 55035},
	{"FACTBOOK", 8, 55036},
	{"RLIB", 4, 55037},
	{"CKEX", 4, 55038},
	{"ALIP", 4, 55039},
	{"TUPLE", 5, 55040},
	{"FIBROMYALGIA", 12, 55041},
	{"EKSB", 4, 55042},
	{"ADAPTATIONS", 11, 55043},
	{"LLQU", 4, 55044},
	{"JURISPRUDENCE", 13, 55045},
	{"FSWI", 4, 55046},
	{"ROOTSWEB", 8, 55047},
	{"CULVER", 6, 55048},
	{"INVARIABLY", 10, 55049},
	{"LECTURERS", 9, 55050},
	{"PROGRESSED", 10, 55051},
	{"GHFR", 4, 55052},
	{"NTYD", 4, 55053},
	{"BROW", 4, 55054},
	{"ELVES", 5, 55055},
	{"BRATZ", 5, 55056},
	{"UARR", 4, 55057},
	{"TKID", 4, 55058},
	{"EMSM", 4, 55059},
	{"KEARNEY", 7, 55060},
	{"VELF", 4, 55061},
	{"LLEE", 4, 55062},
	{"GRAEME", 6, 55063},
	{"MEDN", 4, 55064},
	{"BUCHAREST", 9, 55065},
	{"KIMBALL", 7, 55066},
	{"EYDR", 4, 55067},
	{"CHANT", 5, 55068},
	{"LACOSTE", 7, 55069},
	{"TURNKEY", 7, 55070},
	{"SPRAYS", 6, 55071},
	{"RENTERS", 7, 55072},
	{"TIMBERLAKE", 10, 55073},
	{"LITC", 4, 55074},
	{"ZACK", 4, 55075},
	{"MARKHAM", 7, 55076},
	{"YROM", 4, 55077},
	{"PBEC", 4, 55078},
	{"GELS", 4, 55079},
	{"IFRAMES", 7, 55080},
	{"RKPR", 4, 55081},
	{"HEGY", 4, 55082},
	{"BERJ", 4, 55083},
	{"TAQU", 4, 55084},
	{"THINKGEEK", 9, 55085},
	{"NAFTA", 5, 55086},
	{"REVOLVER", 8, 55087},
	{"ADVERTISMENT", 12, 55088},
	{"MOUNTAINEERING", 14, 55089},
	{"SCREWDRIVER", 11, 55090},
	{"HUTCH", 5, 55091},
	{"RWHY", 4, 55092},
	{"KBET", 4, 55093},
	{"BECKETT", 7, 55094},
	{"NGEU", 4, 55095},
	{"ALEZ", 4, 55096},
	{"CROWNS", 6, 55097},
	{"INTERMEDIARY", 12, 55098},
	{"MATTED", 6, 55099},
	{"APRICOT", 7, 55100},
	{"TUFTS", 5, 55101},
	{"YDOM", 4, 55102},
	{"GYFO", 4, 55103},
	{"HOMESCHOOLING", 13, 55104},
	{"DEALERSHIPS", 11, 55105},
	{"LYAH", 4, 55106},
	{"DDOL", 4, 55107},
	{"CUCKOLD", 7, 55108},
	{"RNLE", 4, 55109},
	{"SAKURA", 6, 55110},
	{"BYU", 3, 55111},
	{"UNRELIABLE", 10, 55112},
	{"JUPITERWEB", 10, 55113},
	{"EKSL", 4, 55114},
	{"ROSEWOOD", 8, 55115},
	{"HTUR", 4, 55116},
	{"BESC", 4, 55117},
	{"PARRY", 5, 55118},
	{"EXISTENT", 8, 55119},
	{"WAYU", 4, 55120},
	{"MMYS", 4, 55121},
	{"NGIB", 4, 55122},
	{"PHOSPHATASE", 11, 55123},
	{"MAHAL", 5, 55124},
	{"PUTF", 4, 55125},
	{"LUBB", 4, 55126},
	{"KILLINGS", 8, 55127},
	{"TONGUES", 7, 55128},
	{"WOWO", 4, 55129},
	{"SBED", 4, 55130},
	{"DICTATOR", 8, 55131},
	{"ROBYN", 5, 55132},
	{"OYSC", 4, 55133},
	{"JEHOVAH", 7, 55134},
	{"JOBL", 4, 55135},
	{"ALWR", 4, 55136},
	{"LZP", 3, 55137},
	{"FANATICS", 8, 55138},
	{"YPHI", 4, 55139},
	{"ASYL", 4, 55140},
	{"ADIRONDACK", 10, 55141},
	{"CASABLANCA", 10, 55142},
	{"URTF", 4, 55143},
	{"RMSU", 4, 55144},
	{"COEUR", 5, 55145},
	{"LHUM", 4, 55146},
	{"PERPENDICULAR", 13, 55147},
	{"EWEX", 4, 55148},
	{"PULASKI", 7, 55149},
	{"DBOB", 4, 55150},
	{"MANTRA", 6, 55151},
	{"SOPU", 4, 55152},
	{"SOURCED", 7, 55153},
	{"TDEG", 4, 55154},
	{"CAROUSEL", 8, 55155},
	{"ROWF", 4, 55156},
	{"VEKI", 4, 55157},
	{"SHFL", 4, 55158},
	{"OBEK", 4, 55159},
	{"NYGR", 4, 55160},
	{"PEWA", 4, 55161},
	{"MPUMALANGA", 10, 55162},
	{"HEDGEHOG", 8, 55163},
	{"PLEJ", 4, 55164},
	{"FBEN", 4, 55165},
	{"RAVES", 5, 55166},
	{"MAMMA", 5, 55167},
	{"ENTAILS", 7, 55168},
	{"YALR", 4, 55169},
	{"MMEA", 4, 55170},
	{"YCUP", 4, 55171},
	{"DSIZ", 4, 55172},
	{"FOLLY", 5, 55173},
	{"THERMOSTAT", 10, 55174},
	{"WHEELING", 8, 55175},
	{"SHARPE", 6, 55176},
	{"LSAG", 4, 55177},
	{"INFARCTION", 10, 55178},
	{"HAWTHORN", 8, 55179},
	{"HDAD", 4, 55180},
	{"EGEM", 4, 55181},
	{"EMBY", 4, 55182},
	{"MURAL", 5, 55183},
	{"BANKRUPT", 8, 55184},
	{"MAYM", 4, 55185},
	{"POLYPROPYLENE", 13, 55186},
	{"MAILBOXES", 9, 55187},
	{"SOUTHEND", 8, 55188},
	{"MAXELL", 6, 55189},
	{"RGOS", 4, 55190},
	{"WAGER", 5, 55191},
	{"TUNDRA", 6, 55192},
	{"VARS", 4, 55193},
	{"EEBR", 4, 55194},
	{"YOUNGSTOWN", 10, 55195},
	{"FARMLAND", 8, 55196},
	{"HOGR", 4, 55197},
	{"EWAC", 4, 55198},
	{"PURGE", 5, 55199},
	{"SKATER", 6, 55200},
	{"INTERPOLATION", 13, 55201},
	{"WESL", 4, 55202},
	{"RYDR", 4, 55203},
	{"GHTK", 4, 55204},
	{"ADJOURNMENT", 11, 55205},
	{"PITFALLS", 8, 55206},
	{"DISRUPT", 7, 55207},
	{"YNER", 4, 55208},
	{"WTOR", 4, 55209},
	{"STATIONED", 9, 55210},
	{"AMBROSE", 7, 55211},
	{"NIGHTMARES", 10, 55212},
	{"RAMPAGE", 7, 55213},
	{"AGGRAVATED", 10, 55214},
	{"FINK", 4, 55215},
	{"IZZL", 4, 55216},
	{"HIMG", 4, 55217},
	{"APUL", 4, 55218},
	{"JURASSIC", 8, 55219},
	{"YISU", 4, 55220},
	{"VEBL", 4, 55221},
	{"BYGA", 4, 55222},
	{"GPG", 3, 55223},
	{"UWIT", 4, 55224},
	{"UERA", 4, 55225},
	{"KETM", 4, 55226},
	{"GNUPG", 5, 55227},
	{"MELVILLE", 8, 55228},
	{"FMEX", 4, 55229},
	{"OMVE", 4, 55230},
	{"CAVERN", 6, 55231},
	{"YIWA", 4, 55232},
	{"SFRU", 4, 55233},
	{"IRIC", 4, 55234},
	{"LWES", 4, 55235},
	{"SUMNER", 6, 55236},
	{"GDAN", 4, 55237},
	{"UROT", 4, 55238},
	{"AYGA", 4, 55239},
	{"DESCENDED", 9, 55240},
	{"DISGUSTING", 10, 55241},
	{"FLAX", 4, 55242},
	{"RLDP", 4, 55243},
	{"NYUN", 4, 55244},
	{"WEAKENED", 8, 55245},
	{"IMPOSES", 7, 55246},
	{"GGOV", 4, 55247},
	{"WITHDREW", 8, 55248},
	{"ALIASING", 8, 55249},
	{"COMIX", 5, 55250},
	{"GALM", 4, 55251},
	{"YATW", 4, 55252},
	{"GUERRILLA", 9, 55253},
	{"DEMB", 4, 55254},
	{"OALK", 4, 55255},
	{"SOLVES", 6, 55256},
	{"HIROSHIMA", 9, 55257},
	{"TDOG", 4, 55258},
	{"SPOONS", 6, 55259},
	{"JIANG", 5, 55260},
	{"PMTO", 4, 55261},
	{"FYFO", 4, 55262},
	{"PERSONA", 7, 55263},
	{"OSCARS", 6, 55264},
	{"IODW", 4, 55265},
	{"ECTG", 4, 55266},
	{"POSER", 5, 55267},
	{"BOOSTING", 8, 55268},
	{"KNOWNSITE", 9, 55269},
	{"MACARTHUR", 9, 55270},
	{"TRAM", 4, 55271},
	{"YFUR", 4, 55272},
	{"UPTR", 4, 55273},
	{"OILF", 4, 55274},
	{"DISTINCTIONS", 12, 55275},
	{"POWERHOUSE", 10, 55276},
	{"PEABODY", 7, 55277},
	{"TYAM", 4, 55278},
	{"DEODORANT", 9, 55279},
	{"YOURE", 5, 55280},
	{"RKEE", 4, 55281},
	{"COMPULSIVE", 10, 55282},
	{"ICED", 4, 55283},
	{"PERKY", 5, 55284},
	{"NUPO", 4, 55285},
	{"FAULKNER", 8, 55286},
	{"XYV", 3, 55287},
	{"UDGI", 4, 55288},
	{"REINFORCING", 11, 55289},
	{"SCARCELY", 8, 55290},
	{"EXTENSIBLE", 10, 55291},
	{"EXCUSED", 7, 55292},
	{"SROM", 4, 55293},
	{"IRWH", 4, 55294},
	{"ERTD", 4, 55295},
	{"FUSED", 5, 55296},
	{"MFIR", 4, 55297},
	{"MYEA", 4, 55298},
	{"CATHETER", 8, 55299},
	{"MADELEINE", 9, 55300},
	{"SGUN", 4, 55301},
	{"UNGH", 4, 55302},
	{"ROARING", 7, 55303},
	{"YLEE", 4, 55304},
	{"WITCHCRAFT", 10, 55305},
	{"WOPL", 4, 55306},
	{"STOPPER", 7, 55307},
	{"UELO", 4, 55308},
	{"SAUG", 4, 55309},
	{"FIBRES", 6, 55310},
	{"PHOTOCOPY", 9, 55311},
	{"CULLEN", 6, 55312},
	{"ZIPCODE", 7, 55313},
	{"MCPHERSON", 9, 55314},
	{"IDBY", 4, 55315},
	{"CKYS", 4, 55316},
	{"SAHARAN", 7, 55317},
	{"CRESTED", 7, 55318},
	{"PIXMA", 5, 55319},
	{"HUBBELL", 7, 55320},
	{"ZZAR", 4, 55321},
	{"TIMEFRAME", 9, 55322},
	{"ILEJ", 4, 55323},
	{"STUMP", 5, 55324},
	{"ROFY", 4, 55325},
	{"SCALP", 5, 55326},
	{"GUNN", 4, 55327},
	{"DISARMAMENT", 11, 55328},
	{"IBRE", 4, 55329},
	{"YLIB", 4, 55330},
	{"ACTIN", 5, 55331},
	{"TCHY", 4, 55332},
	{"JEAL", 4, 55333},
	{"ERWIN", 5, 55334},
	{"RZG", 3, 55335},
	{"INTERVIEWER", 11, 55336},
	{"CONDUCTORS", 10, 55337},
	{"CRITICISMS", 10, 55338},
	{"WAIKATO", 7, 55339},
	{"SYSLOG", 6, 55340},
	{"MALB", 4, 55341},
	{"ALYO", 4, 55342},
	{"GASTROENTEROLOGY", 16, 55343},
	{"FSEP", 4, 55344},
	{"EXOF", 4, 55345},
	{"HADLEY", 6, 55346},
	{"CUPY", 4, 55347},
	{"TRAVELMATE", 10, 55348},
	{"WAYY", 4, 55349},
	{"KEPO", 4, 55350},
	{"COMPOSTING", 10, 55351},
	{"MACKIE", 6, 55352},
	{"YOCT", 4, 55353},
	{"SYLVESTER", 9, 55354},
	{"MELON", 5, 55355},
	{"ALFM", 4, 55356},
	{"MANGANESE", 9, 55357},
	{"AEXP", 4, 55358},
	{"SIREN", 5, 55359},
	{"OCEANOGRAPHY", 12, 55360},
	{"IRSW", 4, 55361},
	{"CKSR", 4, 55362},
	{"VASTLY", 6, 55363},
	{"NDKO", 4, 55364},
	{"CLASP", 5, 55365},
	{"HBYT", 4, 55366},
	{"STARDUST", 8, 55367},
	{"IDGR", 4, 55368},
	{"OLIVES", 6, 55369},
	{"ORNM", 4, 55370},
	{"RADIOLOGICAL", 12, 55371},
	{"COMMANDO", 8, 55372},
	{"SUMMONS", 7, 55373},
	{"LUCRATIVE", 9, 55374},
	{"POROUS", 6, 55375},
	{"BATHTUB", 7, 55376},
	{"SHREWSBURY", 10, 55377},
	{"URDU", 4, 55378},
	{"AEDST", 5, 55379},
	{"GREER", 5, 55380},
	{"MOTORWAY", 8, 55381},
	{"CWHE", 4, 55382},
	{"URQU", 4, 55383},
	{"BILE", 4, 55384},
	{"SIXF", 4, 55385},
	{"SIEGEL", 6, 55386},
	{"ICYI", 4, 55387},
	{"CARA", 4, 55388},
	{"RBUC", 4, 55389},
	{"FWV", 3, 55390},
	{"WNGR", 4, 55391},
	{"HINDUISM", 8, 55392},
	{"MEVA", 4, 55393},
	{"LJAC", 4, 55394},
	{"ELEVATIONS", 10, 55395},
	{"OEMB", 4, 55396},
	{"REPOSITORIES", 12, 55397},
	{"FREAKY", 6, 55398},
	{"RBOB", 4, 55399},
	{"ACYS", 4, 55400},
	{"GUANGDONG", 9, 55401},
	{"MERLOT", 6, 55402},
	{"THIRST", 6, 55403},
	{"PWOR", 4, 55404},
	{"OWAF", 4, 55405},
	{"ENDEAVORS", 9, 55406},
	{"UBBI", 4, 55407},
	{"HACR", 4, 55408},
	{"SPORTSMAN", 9, 55409},
	{"TJOU", 4, 55410},
	{"SPIELBERG", 9, 55411},
	{"OWFI", 4, 55412},
	{"SCRATCHING", 10, 55413},
	{"LESLEY", 6, 55414},
	{"IODINE", 6, 55415},
	{"PHOEBE", 6, 55416},
	{"PHONEID", 7, 55417},
	{"SALINAS", 7, 55418},
	{"LEGGED", 6, 55419},
	{"UTGA", 4, 55420},
	{"UNILATERAL", 10, 55421},
	{"WIPES", 5, 55422},
	{"DLYM", 4, 55423},
	{"ODRU", 4, 55424},
	{"YEDP", 4, 55425},
	{"KRONE", 5, 55426},
	{"OOKG", 4, 55427},
	{"ANKG", 4, 55428},
	{"EXPOSES", 7, 55429},
	{"WKNO", 4, 55430},
	{"QUEO", 4, 55431},
	{"ERMF", 4, 55432},
	{"AEGIS", 5, 55433},
	{"NATURES", 7, 55434},
	{"COLLOQUIUM", 10, 55435},
	{"MATROX", 6, 55436},
	{"ODOC", 4, 55437},
	{"YFW", 3, 55438},
	{"LIBERALISM", 10, 55439},
	{"RMSF", 4, 55440},
	{"SPRINGSTEEN", 11, 55441},
	{"YDOT", 4, 55442},
	{"OUBU", 4, 55443},
	{"FATALITIES", 10, 55444},
	{"URNP", 4, 55445},
	{"LLOB", 4, 55446},
	{"SUPPLEMENTATION", 15, 55447},
	{"MEER", 4, 55448},
	{"DERRY", 5, 55449},
	{"NCEK", 4, 55450},
	{"RICD", 4, 55451},
	{"SUISSE", 6, 55452},
	{"EMBODIED", 8, 55453},
	{"ALTEC", 5, 55454},
	{"OGYF", 4, 55455},
	{"MOHAMMAD", 8, 55456},
	{"FRANKENSTEIN", 12, 55457},
	{"PARC", 4, 55458},
	{"VERBOSE", 7, 55459},
	{"LSPL", 4, 55460},
	{"SUCCESSORS", 10, 55461},
	{"ECCENTRIC", 9, 55462},
	{"YARMOUTH", 8, 55463},
	{"FEVI", 4, 55464},
	{"MARBELLA", 8, 55465},
	{"CYHA", 4, 55466},
	{"TRANSPORTS", 10, 55467},
	{"MUMO", 4, 55468},
	{"AMOUR", 5, 55469},
	{"ITERATOR", 8, 55470},
	{"ETYF", 4, 55471},
	{"APSB", 4, 55472},
	{"RECIEVED", 8, 55473},
	{"USFE", 4, 55474},
	{"CFL", 3, 55475},
	{"DETERMINISTIC", 13, 55476},
	{"NGLU", 4, 55477},
	{"UFY", 3, 55478},
	{"RLDE", 4, 55479},
	{"PREDICTOR", 9, 55480},
	{"WDED", 4, 55481},
	{"SALMONELLA", 10, 55482},
	{"NANTUCKET", 9, 55483},
	{"VIEWABLE", 8, 55484},
	{"SUBNET", 6, 55485},
	{"MAXIMISE", 8, 55486},
	{"ILLUSTRATIVE", 12, 55487},
	{"LOTR", 4, 55488},
	{"PROSECUTED", 10, 55489},
	{"SAILED", 6, 55490},
	{"PTOU", 4, 55491},
	{"LSAD", 4, 55492},
	{"CHALETS", 7, 55493},
	{"REIMBURSED", 10, 55494},
	{"IGND", 4, 55495},
	{"CRAVING", 7, 55496},
	{"YDIA", 4, 55497},
	{"RLYU", 4, 55498},
	{"ICIL", 4, 55499},
	{"ADVOCATING", 10, 55500},
	{"TITEL", 5, 55501},
	{"LEAKING", 7, 55502},
	{"WATERMARK", 9, 55503},
	{"ESCAPING", 8, 55504},
	{"POSSESSING", 10, 55505},
	{"SUICIDAL", 8, 55506},
	{"UNBA", 4, 55507},
	{"BYZA", 4, 55508},
	{"AUCR", 4, 55509},
	{"CRUISERS", 8, 55510},
	{"LFHA", 4, 55511},
	{"ZEDM", 4, 55512},
	{"MASONIC", 7, 55513},
	{"FORAGE", 6, 55514},
	{"KSWO", 4, 55515},
	{"SJUL", 4, 55516},
	{"RYFU", 4, 55517},
	{"MOHAMED", 7, 55518},
	{"HBEL", 4, 55519},
	{"GUYA", 4, 55520},
	{"DPLU", 4, 55521},
	{"DYSLEXIA", 8, 55522},
	{"HUBBLE", 6, 55523},
	{"THUGS", 5, 55524},
	{"LOCO", 4, 55525},
	{"TYCR", 4, 55526},
	{"ODUR", 4, 55527},
	{"HELLENIC", 8, 55528},
	{"ORGANICS", 8, 55529},
	{"DEARBORN", 8, 55530},
	{"FEDS", 4, 55531},
	{"ETHEL", 5, 55532},
	{"YIDDISH", 7, 55533},
	{"MMYA", 4, 55534},
	{"DOPAMINE", 8, 55535},
	{"URSM", 4, 55536},
	{"OKRE", 4, 55537},
	{"SEDJ", 4, 55538},
	{"DIBI", 4, 55539},
	{"AUCU", 4, 55540},
	{"MULTIPLIER", 10, 55541},
	{"WINZIP", 6, 55542},
	{"NBYD", 4, 55543},
	{"SACD", 4, 55544},
	{"PAYOFF", 6, 55545},
	{"DISTINCTLY", 10, 55546},
	{"SONAR", 5, 55547},
	{"ASSERTIONS", 10, 55548},
	{"BABA", 4, 55549},
	{"PEBBLE", 6, 55550},
	{"MONTICELLO", 10, 55551},
	{"SFLY", 4, 55552},
	{"FLASHER", 7, 55553},
	{"STAFFS", 6, 55554},
	{"SUBCONTRACTORS", 14, 55555},
	{"IEFP", 4, 55556},
	{"EFBI", 4, 55557},
	{"EVANGELISM", 10, 55558},
	{"DENOMINATION", 12, 55559},
	{"MENM", 4, 55560},
	{"FBET", 4, 55561},
	{"ABORTIONS", 9, 55562},
	{"PATCHED", 7, 55563},
	{"PATRIOTISM", 10, 55564},
	{"BATTLING", 8, 55565},
	{"LESION", 6, 55566},
	{"DGUE", 4, 55567},
	{"TICKLE", 6, 55568},
	{"SKYL", 4, 55569},
	{"NYAM", 4, 55570},
	{"BANDIT", 6, 55571},
	{"AKIRA", 5, 55572},
	{"PROGESTERONE", 12, 55573},
	{"LLOG", 4, 55574},
	{"ACQUAINTANCE", 12, 55575},
	{"ETHYL", 5, 55576},
	{"RLDM", 4, 55577},
	{"IUMF", 4, 55578},
	{"FDAR", 4, 55579},
	{"YJL", 3, 55580},
	{"LAMBS", 5, 55581},
	{"EARTHLINK", 9, 55582},
	{"CARAMEL", 7, 55583},
	{"IMMUNODEFICIENCY", 16, 55584},
	{"YNDR", 4, 55585},
	{"WASHBURN", 8, 55586},
	{"XTRA", 4, 55587},
	{"CAPITALIZED", 11, 55588},
	{"GUEH", 4, 55589},
	{"GHBU", 4, 55590},
	{"MAINT", 5, 55591},
	{"PANCREAS", 8, 55592},
	{"MYTE", 4, 55593},
	{"LOOM", 4, 55594},
	{"BLOUSE", 6, 55595},
	{"OCTOPUS", 7, 55596},
	{"BEKN", 4, 55597},
	{"AYIF", 4, 55598},
	{"NEURO", 5, 55599},
	{"DUSU", 4, 55600},
	{"RECEPTIONIST", 12, 55601},
	{"HEIGHTENED", 10, 55602},
	{"CHESTS", 6, 55603},
	{"CESSNA", 6, 55604},
	{"YVIC", 4, 55605},
	{"AMBITIONS", 9, 55606},
	{"FELINE", 6, 55607},
	{"ZOMBIES", 7, 55608},
	{"LFFO", 4, 55609},
	{"IDTR", 4, 55610},
	{"GRUB", 4, 55611},
	{"UDIS", 4, 55612},
	{"IEFM", 4, 55613},
	{"THYF", 4, 55614},
	{"UERO", 4, 55615},
	{"TLUC", 4, 55616},
	{"FGLO", 4, 55617},
	{"ULCER", 5, 55618},
	{"CAMBODIAN", 9, 55619},
	{"LFUL", 4, 55620},
	{"INTERAGENCY", 11, 55621},
	{"SLEW", 4, 55622},
	{"RYED", 4, 55623},
	{"ACTIVISION", 10, 55624},
	{"SYNCHRONIZE", 11, 55625},
	{"CROB", 4, 55626},
	{"JUEGOS", 6, 55627},
	{"HORNETS", 7, 55628},
	{"INGZ", 4, 55629},
	{"CROSSFIRE", 9, 55630},
	{"MENSTRUAL", 9, 55631},
	{"CANALS", 6, 55632},
	{"NEGATIVES", 9, 55633},
	{"ANKARA", 6, 55634},
	{"THREADING", 9, 55635},
	{"YWL", 3, 55636},
	{"DUET", 4, 55637},
	{"INTOLERANCE", 11, 55638},
	{"FPHO", 4, 55639},
	{"AMMONIUM", 8, 55640},
	{"SPANDEX", 7, 55641},
	{"ZEPHYR", 6, 55642},
	{"NBOD", 4, 55643},
	{"KWHA", 4, 55644},
	{"HDMI", 4, 55645},
	{"TAMARA", 6, 55646},
	{"CAPCOM", 6, 55647},
	{"TEARING", 7, 55648},
	{"MUFFINS", 7, 55649},
	{"PEACHTREE", 9, 55650},
	{"WFAC", 4, 55651},
	{"CHPU", 4, 55652},
	{"AUTOR", 5, 55653},
	{"ACEK", 4, 55654},
	{"FANNIE", 6, 55655},
	{"HANDYMAN", 8, 55656},
	{"FOOTHILLS", 9, 55657},
	{"ETHIC", 5, 55658},
	{"ERIB", 4, 55659},
	{"HARLAN", 6, 55660},
	{"TAXON", 5, 55661},
	{"RSKE", 4, 55662},
	{"INDEFINITE", 10, 55663},
	{"SLACKWARE", 9, 55664},
	{"NLUC", 4, 55665},
	{"COUGARS", 7, 55666},
	{"RKES", 4, 55667},
	{"ATRIUM", 6, 55668},
	{"RTDO", 4, 55669},
	{"WSBU", 4, 55670},
	{"LTMA", 4, 55671},
	{"SUPERIORITY", 11, 55672},
	{"GESTURES", 8, 55673},
	{"LGOA", 4, 55674},
	{"EARCH", 5, 55675},
	{"AMBIENCE", 8, 55676},
	{"GENET", 5, 55677},
	{"NEMESIS", 7, 55678},
	{"NUCK", 4, 55679},
	{"ENGEL", 5, 55680},
	{"CONFESSIONAL", 12, 55681},
	{"PHOTOPOST", 9, 55682},
	{"CARDIGAN", 8, 55683},
	{"YTAR", 4, 55684},
	{"INFOR", 5, 55685},
	{"NEURONAL", 8, 55686},
	{"GODW", 4, 55687},
	{"TAUNTON", 7, 55688},
	{"EVAPORATION", 11, 55689},
	{"DEVISE", 6, 55690},
	{"CARROLLTON", 10, 55691},
	{"LOGR", 4, 55692},
	{"AYRI", 4, 55693},
	{"ABOLISHED", 9, 55694},
	{"SORRENTO", 8, 55695},
	{"MNEY", 4, 55696},
	{"KESL", 4, 55697},
	{"BLANCHARD", 9, 55698},
	{"CHECKERS", 8, 55699},
	{"HOFJ", 4, 55700},
	{"TORRANCE", 8, 55701},
	{"TOYING", 6, 55702},
	{"SSGR", 4, 55703},
	{"FWOO", 4, 55704},
	{"KERY", 4, 55705},
	{"PARMA", 5, 55706},
	{"YUMA", 4, 55707},
	{"IKEK", 4, 55708},
	{"SPOKESWOMAN", 11, 55709},
	{"BACCALAUREATE", 13, 55710},
	{"TRIPODS", 7, 55711},
	{"WREATH", 6, 55712},
	{"PLIGHT", 6, 55713},
	{"OPIUM", 5, 55714},
	{"LOGISTIC", 8, 55715},
	{"RNSF", 4, 55716},
	{"PSBU", 4, 55717},
	{"OUPU", 4, 55718},
	{"IREV", 4, 55719},
	{"PERSONALIZATION", 15, 55720},
	{"KEBR", 4, 55721},
	{"DYAT", 4, 55722},
	{"BCAN", 4, 55723},
	{"ENEMA", 5, 55724},
	{"GOALIE", 6, 55725},
	{"DARKROOM", 8, 55726},
	{"IRRATIONAL", 10, 55727},
	{"RITB", 4, 55728},
	{"NERJ", 4, 55729},
	{"LPLE", 4, 55730},
	{"HYDROCARBONS", 12, 55731},
	{"ZKU", 3, 55732},
	{"JKW", 3, 55733},
	{"GPM", 3, 55734},
	{"OODU", 4, 55735},
	{"NKWA", 4, 55736},
	{"ARCHES", 6, 55737},
	{"IDBO", 4, 55738},
	{"NATURALIST", 10, 55739},
	{"IREZ", 4, 55740},
	{"WDIS", 4, 55741},
	{"ENCOMPASSING", 12, 55742},
	{"PENETRATING", 11, 55743},
	{"DESTROYS", 8, 55744},
	{"DONALDSON", 9, 55745},
	{"NUNF", 4, 55746},
	{"PRUSSIA", 7, 55747},
	{"RNCH", 4, 55748},
	{"GTUR", 4, 55749},
	{"LOWERS", 6, 55750},
	{"NMUN", 4, 55751},
	{"TISCOVER", 8, 55752},
	{"DYPA", 4, 55753},
	{"RECOR", 5, 55754},
	{"YSCI", 4, 55755},
	{"LNIG", 4, 55756},
	{"MORI", 4, 55757},
	{"ROCKLAND", 8, 55758},
	{"RATF", 4, 55759},
	{"KSPO", 4, 55760},
	{"COOKERY", 7, 55761},
	{"UNIQUENESS", 10, 55762},
	{"TSWR", 4, 55763},
	{"HEUM", 4, 55764},
	{"CASCADING", 9, 55765},
	{"METROS", 6, 55766},
	{"OPWA", 4, 55767},
	{"CKAF", 4, 55768},
	{"HANGERS", 7, 55769},
	{"THYL", 4, 55770},
	{"BEATRICE", 8, 55771},
	{"VEPI", 4, 55772},
	{"CARTILAGE", 9, 55773},
	{"DSGO", 4, 55774},
	{"BROADCASTER", 11, 55775},
	{"WXB", 3, 55776},
	{"LFZ", 3, 55777},
	{"BBEY", 4, 55778},
	{"TURNPIKE", 8, 55779},
	{"MDEC", 4, 55780},
	{"TYRI", 4, 55781},
	{"MIGRATORY", 9, 55782},
	{"WUPA", 4, 55783},
	{"JURORS", 6, 55784},
	{"ENUMERATED", 10, 55785},
	{"ROQU", 4, 55786},
	{"SHELTERED", 9, 55787},
	{"DLYH", 4, 55788},
	{"MUSCULUS", 8, 55789},
	{"DEGRADED", 8, 55790},
	{"DOCTRINES", 9, 55791},
	{"SEAMS", 5, 55792},
	{"MSLE", 4, 55793},
	{"PLEADED", 7, 55794},
	{"RDMI", 4, 55795},
	{"LLSN", 4, 55796},
	{"OMUL", 4, 55797},
	{"HFEL", 4, 55798},
	{"ELASTICITY", 10, 55799},
	{"MICF", 4, 55800},
	{"EBYE", 4, 55801},
	{"VIEWCVS", 7, 55802},
	{"LAFA", 4, 55803},
	{"IMAY", 4, 55804},
	{"GUPF", 4, 55805},
	{"EISENHOWER", 10, 55806},
	{"FLASHLIGHTS", 11, 55807},
	{"GUTTER", 6, 55808},
	{"ULCERS", 6, 55809},
	{"MYYAHOO", 7, 55810},
	{"ROSENTHAL", 9, 55811},
	{"FDRA", 4, 55812},
	{"AFFORDABILITY", 13, 55813},
	{"SLOPPY", 6, 55814},
	{"MEAV", 4, 55815},
	{"LATHAM", 6, 55816},
	{"FLANNEL", 7, 55817},
	{"FUSW", 4, 55818},
	{"VOLCANOES", 9, 55819},
	{"KLER", 4, 55820},
	{"JAILED", 6, 55821},
	{"KEWO", 4, 55822},
	{"RIDDEN", 6, 55823},
	{"YHUS", 4, 55824},
	{"DEDJ", 4, 55825},
	{"DEPP", 4, 55826},
	{"SREJ", 4, 55827},
	{"PODI", 4, 55828},
	{"CONTRADICTORY", 13, 55829},
	{"OWCL", 4, 55830},
	{"MOTORBIKES", 10, 55831},
	{"VERDANA", 7, 55832},
	{"YIFY", 4, 55833},
	{"KBRO", 4, 55834},
	{"DLOT", 4, 55835},
	{"BONITA", 6, 55836},
	{"URAM", 4, 55837},
	{"MISUNDERSTOOD", 13, 55838},
	{"NIPPON", 6, 55839},
	{"STEAMER", 7, 55840},
	{"CONG", 4, 55841},
	{"SJUM", 4, 55842},
	{"BAROMETER", 9, 55843},
	{"DECORATORS", 10, 55844},
	{"DWL", 3, 55845},
	{"WNFI", 4, 55846},
	{"TYAG", 4, 55847},
	{"RNDE", 4, 55848},
	{"EBYD", 4, 55849},
	{"JIZZ", 4, 55850},
	{"PENDLETON", 9, 55851},
	{"AVOC", 4, 55852},
	{"EXCLAIMED", 9, 55853},
	{"AGIF", 4, 55854},
	{"DIEM", 4, 55855},
	{"BARGE", 5, 55856},
	{"PSORIASIS", 9, 55857},
	{"IMIR", 4, 55858},
	{"SPARTAN", 7, 55859},
	{"MAVERICKS", 9, 55860},
	{"DIANNE", 6, 55861},
	{"KDRI", 4, 55862},
	{"CRYSTALLINE", 11, 55863},
	{"RUMOURS", 7, 55864},
	{"EARNHARDT", 9, 55865},
	{"FAMED", 5, 55866},
	{"BRANDT", 6, 55867},
	{"RIGA", 4, 55868},
	{"GDRU", 4, 55869},
	{"YUNC", 4, 55870},
	{"ODDL", 4, 55871},
	{"BENGALI", 7, 55872},
	{"AMTRAK", 6, 55873},
	{"RESID", 5, 55874},
	{"TOSTRING", 8, 55875},
	{"LESSEE", 6, 55876},
	{"RESPITE", 7, 55877},
	{"NBYB", 4, 55878},
	{"GOODYEAR", 8, 55879},
	{"YARG", 4, 55880},
	{"ILTU", 4, 55881},
	{"ZYY", 3, 55882},
	{"KYZ", 3, 55883},
	{"UTICA", 5, 55884},
	{"UFIN", 4, 55885},
	{"PCOU", 4, 55886},
	{"UTRU", 4, 55887},
	{"GRIMM", 5, 55888},
	{"OVERCLOCKING", 12, 55889},
	{"SHETLAND", 8, 55890},
	{"KITCHENAID", 10, 55891},
	{"BUYO", 4, 55892},
	{"PEACEKEEPING", 12, 55893},
	{"PROVOCATIVE", 11, 55894},
	{"GUIDO", 5, 55895},
	{"GECL", 4, 55896},
	{"INTERFERON", 10, 55897},
	{"AFUT", 4, 55898},
	{"ODYF", 4, 55899},
	{"SELECTABLE", 10, 55900},
	{"NNYC", 4, 55901},
	{"CHECHNYA", 8, 55902},
	{"RORY", 4, 55903},
	{"WOODBRIDGE", 10, 55904},
	{"TEPF", 4, 55905},
	{"INTERSECTIONS", 13, 55906},
	{"TASTED", 6, 55907},
	{"MTAK", 4, 55908},
	{"LICKED", 6, 55909},
	{"OBYT", 4, 55910},
	{"CAPITALIZATION", 14, 55911},
	{"BANGED", 6, 55912},
	{"RNPR", 4, 55913},
	{"XIOU", 4, 55914},
	{"NDTY", 4, 55915},
	{"IXWE", 4, 55916},
	{"FDET", 4, 55917},
	{"SAYY", 4, 55918},
	{"RESPONDER", 9, 55919},
	{"RUFUS", 5, 55920},
	{"THORACIC", 8, 55921},
	{"PHASER", 6, 55922},
	{"FORENSICS", 9, 55923},
	{"HOPELESS", 8, 55924},
	{"YSCE", 4, 55925},
	{"INFILTRATION", 12, 55926},
	{"HENRIK", 6, 55927},
	{"SAFEST", 6, 55928},
	{"DAPHNE", 6, 55929},
	{"SERINE", 6, 55930},
	{"DLYE", 4, 55931},
	{"BING", 4, 55932},
	{"LLNU", 4, 55933},
	{"GWES", 4, 55934},
	{"POLLOCK", 7, 55935},
	{"METEOR", 6, 55936},
	{"SCHEMAS", 7, 55937},
	{"LMAG", 4, 55938},
	{"GRANVILLE", 9, 55939},
	{"ORTHOGONAL", 10, 55940},
	{"YBEY", 4, 55941},
	{"BOOSTS", 6, 55942},
	{"DSEM", 4, 55943},
	{"STABILIZED", 10, 55944},
	{"VENEER", 6, 55945},
	{"LLVO", 4, 55946},
	{"ANONYMOUSLY", 11, 55947},
	{"MANAGEABLE", 10, 55948},
	{"AWKE", 4, 55949},
	{"DINY", 4, 55950},
	{"WORDPERFECT", 11, 55951},
	{"MSGS", 4, 55952},
	{"NCRY", 4, 55953},
	{"FDRI", 4, 55954},
	{"AYDU", 4, 55955},
	{"MSUC", 4, 55956},
	{"SLANT", 5, 55957},
	{"ZHOU", 4, 55958},
	{"DISCIPLINED", 11, 55959},
	{"HDEM", 4, 55960},
	{"AGHD", 4, 55961},
	{"SELENIUM", 8, 55962},
	{"GRINDERS", 8, 55963},
	{"POLLARD", 7, 55964},
	{"COMME", 5, 55965},
	{"CHOPS", 5, 55966},
	{"GALR", 4, 55967},
	{"FMOV", 4, 55968},
	{"EFAB", 4, 55969},
	{"TBEW", 4, 55970},
	{"LUEW", 4, 55971},
	{"BROOM", 5, 55972},
	{"PLAINLY", 7, 55973},
	{"IBRAHIM", 7, 55974},
	{"PUNCHES", 7, 55975},
	{"YALW", 4, 55976},
	{"URGS", 4, 55977},
	{"UNOU", 4, 55978},
	{"TBUD", 4, 55979},
	{"OACQ", 4, 55980},
	{"GUPS", 4, 55981},
	{"LISF", 4, 55982},
	{"SNARE", 5, 55983},
	{"GUYI", 4, 55984},
	{"SHANK", 5, 55985},
	{"AYCL", 4, 55986},
	{"PARACHUTE", 9, 55987},
	{"OLKA", 4, 55988},
	{"KBER", 4, 55989},
	{"YXF", 3, 55990},
	{"VGW", 3, 55991},
	{"UPHOLD", 6, 55992},
	{"GLIDER", 6, 55993},
	{"REVISING", 8, 55994},
	{"CHESNEY", 7, 55995},
	{"RKLI", 4, 55996},
	{"ERIR", 4, 55997},
	{"FPAL", 4, 55998},
	{"BADB", 4, 55999},
	{"GLYD", 4, 56000},
	{"INSIGNIA", 8, 56001},
	{"UGOS", 4, 56002},
	{"KSSU", 4, 56003},
	{"ECKH", 4, 56004},
	{"NURTURE", 7, 56005},
	{"YABI", 4, 56006},
	{"FVIR", 4, 56007},
	{"LOTIONS", 7, 56008},
	{"YBLU", 4, 56009},
	{"NUNP", 4, 56010},
	{"LEASH", 5, 56011},
	{"HUNTS", 5, 56012},
	{"FABER", 5, 56013},
	{"ADRENAL", 7, 56014},
	{"PLANTATIONS", 11, 56015},
	{"SIXTIES", 7, 56016},
	{"FACTIONS", 8, 56017},
	{"YEDG", 4, 56018},
	{"IAMG", 4, 56019},
	{"RCIR", 4, 56020},
	{"FALMOUTH", 8, 56021},
	{"SKYO", 4, 56022},
	{"HUMILITY", 8, 56023},
	{"COMMENTATORS", 12, 56024},
	{"IMPEACHMENT", 11, 56025},
	{"RBYP", 4, 56026},
	{"LDIA", 4, 56027},
	{"EBYO", 4, 56028},
	{"ACTON", 5, 56029},
	{"BOOTING", 7, 56030},
	{"ENGAGES", 7, 56031},
	{"YSUM", 4, 56032},
	{"CARBIDE", 7, 56033},
	{"ICBR", 4, 56034},
	{"CUNTS", 5, 56035},
	{"YNEG", 4, 56036},
	{"PULLMAN", 7, 56037},
	{"NKSB", 4, 56038},
	{"ELTD", 4, 56039},
	{"OZZY", 4, 56040},
	{"CHARACTERISED", 13, 56041},
	{"EBYB", 4, 56042},
	{"ALEQ", 4, 56043},
	{"ELEARNING", 9, 56044},
	{"KINDER", 6, 56045},
	{"DEEMS", 5, 56046},
	{"RROD", 4, 56047},
	{"HCRO", 4, 56048},
	{"GOBU", 4, 56049},
	{"OUTSIDERS", 9, 56050},
	{"TYDU", 4, 56051},
	{"OMCR", 4, 56052},
	{"IBBS", 4, 56053},
	{"FCLE", 4, 56054},
	{"VALUATIONS", 10, 56055},
	{"RTJU", 4, 56056},
	{"DODD", 4, 56057},
	{"UPMO", 4, 56058},
	{"ODEX", 4, 56059},
	{"KIDMAN", 6, 56060},
	{"RRAG", 4, 56061},
	{"IGDE", 4, 56062},
	{"ADRIENNE", 8, 56063},
	{"DEDUCT", 6, 56064},
	{"CRAWLING", 8, 56065},
	{"OUPM", 4, 56066},
	{"POSTOPERATIVE", 13, 56067},
	{"MODIFIER", 8, 56068},
	{"CYTOLOGY", 8, 56069},
	{"KEYR", 4, 56070},
	{"BIENNIAL", 8, 56071},
	{"IFNDEF", 6, 56072},
	{"CIRCUITRY", 9, 56073},
	{"GCAU", 4, 56074},
	{"CDW", 3, 56075},
	{"ROBB", 4, 56076},
	{"LESV", 4, 56077},
	{"MUCK", 4, 56078},
	{"UBTS", 4, 56079},
	{"KINJA", 5, 56080},
	{"YORB", 4, 56081},
	{"RVEO", 4, 56082},
	{"LPUS", 4, 56083},
	{"ILTF", 4, 56084},
	{"TWEAKS", 6, 56085},
	{"COLOMBO", 7, 56086},
	{"READERSHIP", 10, 56087},
	{"NORTHSTAR", 9, 56088},
	{"COHESION", 8, 56089},
	{"WORTHINGTON", 11, 56090},
	{"RECONNAISSANCE", 14, 56091},
	{"GROUNDBREAKING", 14, 56092},
	{"EPWA", 4, 56093},
	{"YPED", 4, 56094},
	{"ANTAGONISTS", 11, 56095},
	{"TRANSDUCER", 10, 56096},
	{"YJON", 4, 56097},
	{"RCAB", 4, 56098},
	{"BACHELORS", 9, 56099},
	{"SEROTONIN", 9, 56100},
	{"COMPLEMENTS", 11, 56101},
	{"YRAD", 4, 56102},
	{"ARMB", 4, 56103},
	{"OBSERVES", 8, 56104},
	{"PARAMS", 6, 56105},
	{"RADIATORS", 9, 56106},
	{"CORPORAL", 8, 56107},
	{"LIGNE", 5, 56108},
	{"BEAGLE", 6, 56109},
	{"TUPB", 4, 56110},
	{"WARY", 4, 56111},
	{"UALN", 4, 56112},
	{"RENM", 4, 56113},
	{"CADMIUM", 7, 56114},
	{"BODONI", 6, 56115},
	{"SPEEDO", 6, 56116},
	{"ORNC", 4, 56117},
	{"EACU", 4, 56118},
	{"LOCUST", 6, 56119},
	{"DETACHABLE", 10, 56120},
	{"CONDENSER", 9, 56121},
	{"NWIC", 4, 56122},
	{"ARTICULATION", 12, 56123},
	{"SIMPLIFIES", 10, 56124},
	{"JENK", 4, 56125},
	{"SLEEVELESS", 10, 56126},
	{"SBLE", 4, 56127},
	{"DBIT", 4, 56128},
	{"MOTORISTS", 9, 56129},
	{"BIGN", 4, 56130},
	{"VILLAIN", 7, 56131},
	{"TBSP", 4, 56132},
	{"WAIVERS", 7, 56133},
	{"FORSYTH", 7, 56134},
	{"FCRO", 4, 56135},
	{"RICERCA", 7, 56136},
	{"SECURES", 7, 56137},
	{"YATM", 4, 56138},
	{"ARDV", 4, 56139},
	{"AGILENT", 7, 56140},
	{"LEVITICUS", 9, 56141},
	{"IMPENDING", 9, 56142},
	{"REJOICE", 7, 56143},
	{"ELTW", 4, 56144},
	{"PICKERING", 9, 56145},
	{"PLUMPER", 7, 56146},
	{"RNIV", 4, 56147},
	{"POISSON", 7, 56148},
	{"ORML", 4, 56149},
	{"HOFD", 4, 56150},
	{"RTRY", 4, 56151},
	{"OMEJ", 4, 56152},
	{"GOIL", 4, 56153},
	{"UTERINE", 7, 56154},
	{"BURSTS", 6, 56155},
	{"KEOR", 4, 56156},
	{"ROCI", 4, 56157},
	{"ELAV", 4, 56158},
	{"APARTHEID", 9, 56159},
	{"GATW", 4, 56160},
	{"VERSAILLES", 10, 56161},
	{"BUSINESSWEEK", 12, 56162},
	{"MORPHOLOGICAL", 13, 56163},
	{"DASG", 4, 56164},
	{"HURDLES", 7, 56165},
	{"WINDHAM", 7, 56166},
	{"GPOO", 4, 56167},
	{"LUCIE", 5, 56168},
	{"HUSF", 4, 56169},
	{"RSRU", 4, 56170},
	{"ELLINGTON", 9, 56171},
	{"YHUR", 4, 56172},
	{"GEESE", 5, 56173},
	{"URYR", 4, 56174},
	{"EKFO", 4, 56175},
	{"CONDEMNATION", 12, 56176},
	{"CANDIES", 7, 56177},
	{"POLIO", 5, 56178},
	{"SIDEWALKS", 9, 56179},
	{"CLP", 3, 56180},
	{"FORMIDABLE", 10, 56181},
	{"RCIV", 4, 56182},
	{"SHARM", 5, 56183},
	{"UNTB", 4, 56184},
	{"AUTRES", 6, 56185},
	{"MECCA", 5, 56186},
	{"ALVAREZ", 7, 56187},
	{"UMAL", 4, 56188},
	{"REGATTA", 7, 56189},
	{"RSKN", 4, 56190},
	{"CYWI", 4, 56191},
	{"OLFI", 4, 56192},
	{"RESTED", 6, 56193},
	{"CHATROOM", 8, 56194},
	{"PAUSED", 6, 56195},
	{"MACBETH", 7, 56196},
	{"POLARITY", 8, 56197},
	{"NDOD", 4, 56198},
	{"OVERRIDES", 9, 56199},
	{"ABANDONMENT", 11, 56200},
	{"LGAI", 4, 56201},
	{"RIFF", 4, 56202},
	{"WIDTHS", 6, 56203},
	{"TGLA", 4, 56204},
	{"ATTENUATION", 11, 56205},
	{"MYHU", 4, 56206},
	{"BERTRAND", 8, 56207},
	{"EMYW", 4, 56208},
	{"BROTH", 5, 56209},
	{"SICL", 4, 56210},
	{"IDGO", 4, 56211},
	{"KLUWER", 6, 56212},
	{"MARTINS", 7, 56213},
	{"ITALIANA", 8, 56214},
	{"WENTWORTH", 9, 56215},
	{"TELFORD", 7, 56216},
	{"SEDUCTION", 9, 56217},
	{"YONF", 4, 56218},
	{"SDIG", 4, 56219},
	{"FERTILIZERS", 11, 56220},
	{"SHUMAN", 6, 56221},
	{"EUSP", 4, 56222},
	{"HMUC", 4, 56223},
	{"AMEJ", 4, 56224},
	{"MAISON", 6, 56225},
	{"MCRE", 4, 56226},
	{"CONTRASTS", 9, 56227},
	{"RUSSO", 5, 56228},
	{"UCHY", 4, 56229},
	{"DAUNTING", 8, 56230},
	{"TOPPLES", 7, 56231},
	{"LLTU", 4, 56232},
	{"IPBU", 4, 56233},
	{"GIUSEPPE", 8, 56234},
	{"IMPROPERLY", 10, 56235},
	{"FUTURISTIC", 10, 56236},
	{"NEBULA", 6, 56237},
	{"GFIS", 4, 56238},
	{"AUTOFOCUS", 9, 56239},
	{"OBSESSIVE", 9, 56240},
	{"GONP", 4, 56241},
	{"CROWS", 5, 56242},
	{"TRANSPLANTS", 11, 56243},
	{"REFERRERS", 9, 56244},
	{"JUNKIE", 6, 56245},
	{"ADMITTING", 9, 56246},
	{"GALACTICA", 9, 56247},
	{"ASUD", 4, 56248},
	{"BLOOMING", 8, 56249},
	{"OLDJ", 4, 56250},
	{"MACE", 4, 56251},
	{"YFEB", 4, 56252},
	{"SEMINOLE", 8, 56253},
	{"TAPER", 5, 56254},
	{"MHEL", 4, 56255},
	{"ORMM", 4, 56256},
	{"ROTATIONAL", 10, 56257},
	{"UINC", 4, 56258},
	{"SOGR", 4, 56259},
	{"ILIV", 4, 56260},
	{"WITHDRAWALS", 11, 56261},
	{"URFU", 4, 56262},
	{"PAGEVIEWS", 9, 56263},
	{"UBEL", 4, 56264},
	{"RJUD", 4, 56265},
	{"NDAK", 4, 56266},
	{"HARTMAN", 7, 56267},
	{"RTMU", 4, 56268},
	{"BYBL", 4, 56269},
	{"SYNAGOGUE", 9, 56270},
	{"FINALIST", 8, 56271},
	{"SUGARS", 6, 56272},
	{"BURNHAM", 7, 56273},
	{"ARMAGEDDON", 10, 56274},
	{"SMALLVILLE", 10, 56275},
	{"SELECTIVELY", 11, 56276},
	{"UTKM", 4, 56277},
	{"YMME", 4, 56278},
	{"ALBANS", 6, 56279},
	{"UBEC", 4, 56280},
	{"EJOK", 4, 56281},
	{"FALLOUT", 7, 56282},
	{"ALLURE", 6, 56283},
	{"BROWNSVILLE", 11, 56284},
	{"SCOB", 4, 56285},
	{"INTESTINE", 9, 56286},
	{"AMBASSADORS", 11, 56287},
	{"GALERIA", 7, 56288},
	{"STALKER", 7, 56289},
	{"IGBA", 4, 56290},
	{"ABEF", 4, 56291},
	{"RECLAIM", 7, 56292},
	{"KATHMANDU", 9, 56293},
	{"UITW", 4, 56294},
	{"WPRI", 4, 56295},
	{"KINGDOMS", 8, 56296},
	{"KRISTINA", 8, 56297},
	{"RICHNESS", 8, 56298},
	{"CONVERGE", 8, 56299},
	{"GUEM", 4, 56300},
	{"HEVR", 4, 56301},
	{"ARAY", 4, 56302},
	{"NADJ", 4, 56303},
	{"IZEM", 4, 56304},
	{"IUMB", 4, 56305},
	{"ICMP", 4, 56306},
	{"PIANOS", 6, 56307},
	{"TYDA", 4, 56308},
	{"ABOM", 4, 56309},
	{"WORKINGS", 8, 56310},
	{"PENELOPE", 8, 56311},
	{"SOPHISTICATION", 14, 56312},
	{"EXTINCT", 7, 56313},
	{"GBJ", 3, 56314},
	{"PONDER", 6, 56315},
	{"LHAM", 4, 56316},
	{"MESSED", 6, 56317},
	{"YEYE", 4, 56318},
	{"NPUL", 4, 56319},
	{"OCEANSIDE", 9, 56320},
	{"NVEL", 4, 56321},
	{"MYPO", 4, 56322},
	{"LUEP", 4, 56323},
	{"REVUE", 5, 56324},
	{"LUNCHES", 7, 56325},
	{"FOXPRO", 6, 56326},
	{"YZAN", 4, 56327},
	{"RYPU", 4, 56328},
	{"CHVI", 4, 56329},
	{"TAIWANESE", 9, 56330},
	{"OFFICEJET", 9, 56331},
	{"UBME", 4, 56332},
	{"FOOLED", 6, 56333},
	{"LFHO", 4, 56334},
	{"BEUP", 4, 56335},
	{"HELENS", 6, 56336},
	{"SMEAR", 5, 56337},
	{"RIGGING", 7, 56338},
	{"ILCH", 4, 56339},
	{"DERIVES", 7, 56340},
	{"PRAISES", 7, 56341},
	{"PPG", 3, 56342},
	{"RTAD", 4, 56343},
	{"GSDO", 4, 56344},
	{"DETACHMENT", 10, 56345},
	{"LUCA", 4, 56346},
	{"COMBOS", 6, 56347},
	{"CLONED", 6, 56348},
	{"FULHAM", 6, 56349},
	{"CARACAS", 7, 56350},
	{"DAHL", 4, 56351},
	{"MEPU", 4, 56352},
	{"GHPA", 4, 56353},
	{"MATHEWS", 7, 56354},
	{"LWOO", 4, 56355},
	{"YPAL", 4, 56356},
	{"WODO", 4, 56357},
	{"BESTSELLER", 10, 56358},
	{"OGOL", 4, 56359},
	{"LIDS", 4, 56360},
	{"GWOO", 4, 56361},
	{"ENRIQUE", 7, 56362},
	{"PORE", 4, 56363},
	{"GHFI", 4, 56364},
	{"MINIDISC", 8, 56365},
	{"RADIANCE", 8, 56366},
	{"DOWNSIDE", 8, 56367},
	{"HBUS", 4, 56368},
	{"MALVINAS", 8, 56369},
	{"HONCODE", 7, 56370},
	{"RYES", 4, 56371},
	{"URCL", 4, 56372},
	{"REISSUE", 7, 56373},
	{"RARG", 4, 56374},
	{"LDOT", 4, 56375},
	{"GSSU", 4, 56376},
	{"FJL", 3, 56377},
	{"OMYC", 4, 56378},
	{"OILY", 4, 56379},
	{"QUITTING", 8, 56380},
	{"STRIKER", 7, 56381},
	{"RLUN", 4, 56382},
	{"MEMOS", 5, 56383},
	{"GROVER", 6, 56384},
	{"SCREAMS", 7, 56385},
	{"OMYE", 4, 56386},
	{"MASKING", 7, 56387},
	{"TENSOR", 6, 56388},
	{"WHITEHEAD", 9, 56389},
	{"LRIV", 4, 56390},
	{"EKEL", 4, 56391},
	{"BROOKINGS", 9, 56392},
	{"UEPL", 4, 56393},
	{"ACCOMODATIONS", 13, 56394},
	{"INTEGRA", 7, 56395},
	{"PATCHWORK", 9, 56396},
	{"LCLE", 4, 56397},
	{"HEINRICH", 8, 56398},
	{"LAREDO", 6, 56399},
	{"LPOT", 4, 56400},
	{"GODF", 4, 56401},
	{"LOGICIEL", 8, 56402},
	{"BRETON", 6, 56403},
	{"JAGUARS", 7, 56404},
	{"ASSURES", 7, 56405},
	{"RGIE", 4, 56406},
	{"JOYS", 4, 56407},
	{"WAIV", 4, 56408},
	{"MFUL", 4, 56409},
	{"FFIG", 4, 56410},
	{"TRACER", 6, 56411},
	{"FRIST", 5, 56412},
	{"FTAK", 4, 56413},
	{"INVOLUNTARY", 11, 56414},
	{"ITRY", 4, 56415},
	{"INFINITELY", 10, 56416},
	{"SYNTHESIZER", 11, 56417},
	{"LPFR", 4, 56418},
	{"EJACULATING", 11, 56419},
	{"BIODIESEL", 9, 56420},
	{"IRVA", 4, 56421},
	{"DORCHESTER", 10, 56422},
	{"MCLEOD", 6, 56423},
	{"SERGE", 5, 56424},
	{"VEOV", 4, 56425},
	{"AJUS", 4, 56426},
	{"PSPO", 4, 56427},
	{"MORPHINE", 8, 56428},
	{"RGIL", 4, 56429},
	{"WALDORF", 7, 56430},
	{"GYMNASIUM", 9, 56431},
	{"MICROFILM", 9, 56432},
	{"HORP", 4, 56433},
	{"DJY", 3, 56434},
	{"WALDO", 5, 56435},
	{"DIESE", 5, 56436},
	{"LEAR", 4, 56437},
	{"SUBSIDIZED", 10, 56438},
	{"CHIEFLY", 7, 56439},
	{"ULBU", 4, 56440},
	{"JUDAH", 5, 56441},
	{"CONJECTURE", 10, 56442},
	{"MICH", 4, 56443},
	{"RAYW", 4, 56444},
	{"OJAP", 4, 56445},
	{"SIMONS", 6, 56446},
	{"OPTIMIZER", 9, 56447},
	{"RESTITUTION", 11, 56448},
	{"KBAS", 4, 56449},
	{"INDICTED", 8, 56450},
	{"BLASTING", 8, 56451},
	{"REDK", 4, 56452},
	{"CCUL", 4, 56453},
	{"ZIRE", 4, 56454},
	{"CONFRONTING", 11, 56455},
	{"PITUITARY", 9, 56456},
	{"REPEATER", 8, 56457},
	{"TEAMXBOX", 8, 56458},
	{"BYTECODE", 8, 56459},
	{"MCCALL", 6, 56460},
	{"AUTOPSY", 7, 56461},
	{"MASTERED", 8, 56462},
	{"POWDERS", 7, 56463},
	{"JOLTSEARCH", 10, 56464},
	{"DEBTORS", 7, 56465},
	{"GRIT", 4, 56466},
	{"URYD", 4, 56467},
	{"RDAC", 4, 56468},
	{"OTBR", 4, 56469},
	{"IRDG", 4, 56470},
	{"ASKY", 4, 56471},
	{"REIW", 4, 56472},
	{"RLAY", 4, 56473},
	{"SLAIN", 5, 56474},
	{"COLO", 4, 56475},
	{"GASF", 4, 56476},
	{"YING", 4, 56477},
	{"NCYH", 4, 56478},
	{"INODE", 5, 56479},
	{"GLENWOOD", 8, 56480},
	{"ALLSTATE", 8, 56481},
	{"HORTICULTURAL", 13, 56482},
	{"PPOL", 4, 56483},
	{"HAHAHA", 6, 56484},
	{"SPAMMING", 8, 56485},
	{"NEARER", 6, 56486},
	{"ANCESTRAL", 9, 56487},
	{"MWES", 4, 56488},
	{"MUJERES", 7, 56489},
	{"WMAT", 4, 56490},
	{"EUNP", 4, 56491},
	{"WARTIME", 7, 56492},
	{"RSBI", 4, 56493},
	{"FAITHFULLY", 10, 56494},
	{"REVOLUTIONS", 11, 56495},
	{"ELIU", 4, 56496},
	{"WLEY", 4, 56497},
	{"RORP", 4, 56498},
	{"GERIATRIC", 9, 56499},
	{"QUAIL", 5, 56500},
	{"TANKER", 6, 56501},
	{"MAYAN", 5, 56502},
	{"DATD", 4, 56503},
	{"MESK", 4, 56504},
	{"NAVMAN", 6, 56505},
	{"ADMINISTRATIONS", 15, 56506},
	{"FUTON", 5, 56507},
	{"LAQU", 4, 56508},
	{"USOU", 4, 56509},
	{"RNPO", 4, 56510},
	{"GRANNIES", 8, 56511},
	{"HAIRSTYLES", 10, 56512},
	{"MINL", 4, 56513},
	{"GHBE", 4, 56514},
	{"BEDW", 4, 56515},
	{"RECTOR", 6, 56516},
	{"BALLAST", 7, 56517},
	{"IMMATURE", 8, 56518},
	{"DTAB", 4, 56519},
	{"WEBSPACE", 8, 56520},
	{"RECOGNISES", 10, 56521},
	{"TAXING", 6, 56522},
	{"ICING", 5, 56523},
	{"OLLW", 4, 56524},
	{"SUBSTITUTING", 12, 56525},
	{"MELLITUS", 8, 56526},
	{"MULTIPLES", 9, 56527},
	{"EXECUTES", 8, 56528},
	{"RVIO", 4, 56529},
	{"ORIGINALITY", 11, 56530},
	{"CLEH", 4, 56531},
	{"PINNED", 6, 56532},
	{"RHOP", 4, 56533},
	{"CRYPTOGRAPHIC", 13, 56534},
	{"GABLES", 6, 56535},
	{"YJG", 3, 56536},
	{"QFY", 3, 56537},
	{"DISCONTINUE", 11, 56538},
	{"DISPARATE", 9, 56539},
	{"BANTAM", 6, 56540},
	{"BOARDWALK", 9, 56541},
	{"GQUI", 4, 56542},
	{"IAMW", 4, 56543},
	{"INELIGIBLE", 10, 56544},
	{"EMEG", 4, 56545},
	{"HOMEOPATHY", 10, 56546},
	{"ENTRANTS", 8, 56547},
	{"RALLIES", 7, 56548},
	{"SIMPLIFICATION", 14, 56549},
	{"FCIV", 4, 56550},
	{"OWKN", 4, 56551},
	{"GEYE", 4, 56552},
	{"DELC", 4, 56553},
	{"INSOLVENCY", 10, 56554},
	{"BIANCA", 6, 56555},
	{"ZIMMER", 6, 56556},
	{"EARTHLY", 7, 56557},
	{"PONW", 4, 56558},
	{"LVOL", 4, 56559},
	{"KMMI", 4, 56560},
	{"ROLEPLAYING", 11, 56561},
	{"AFFECTIVE", 9, 56562},
	{"WILMA", 5, 56563},
	{"COMPUSA", 7, 56564},
	{"HISTOGRAM", 9, 56565},
	{"LAXI", 4, 56566},
	{"WHEELCHAIRS", 11, 56567},
	{"USAF", 4, 56568},
	{"KSID", 4, 56569},
	{"CECU", 4, 56570},
	{"PENNINGTON", 10, 56571},
	{"LIBERALIZATION", 14, 56572},
	{"INSENSITIVE", 11, 56573},
	{"FORFEITURE", 10, 56574},
	{"GREENPEACE", 10, 56575},
	{"GENOTYPE", 8, 56576},
	{"LKAR", 4, 56577},
	{"CONTAMINANT", 11, 56578},
	{"INFORMA", 7, 56579},
	{"GBIG", 4, 56580},
	{"DISASTROUS", 10, 56581},
	{"COLLABORATORS", 13, 56582},
	{"MALVERN", 7, 56583},
	{"PROXIES", 7, 56584},
	{"ULTM", 4, 56585},
	{"LUTC", 4, 56586},
	{"IFIR", 4, 56587},
	{"REWIND", 6, 56588},
	{"GLADIATOR", 9, 56589},
	{"POPLAR", 6, 56590},
	{"ISSUERS", 7, 56591},
	{"CKFA", 4, 56592},
	{"ARNM", 4, 56593},
	{"SUNP", 4, 56594},
	{"LETP", 4, 56595},
	{"RECOURSE", 8, 56596},
	{"HFOL", 4, 56597},
	{"MARTIAN", 7, 56598},
	{"QMJ", 3, 56599},
	{"DDOO", 4, 56600},
	{"EQUINOX", 7, 56601},
	{"KERBEROS", 8, 56602},
	{"BYGI", 4, 56603},
	{"SCHOOLGIRLS", 11, 56604},
	{"HINDER", 6, 56605},
	{"FREDERICKSBURG", 14, 56606},
	{"NGIC", 4, 56607},
	{"PRESUME", 7, 56608},
	{"LEDJ", 4, 56609},
	{"EKWH", 4, 56610},
	{"MBIL", 4, 56611},
	{"HOFG", 4, 56612},
	{"AMGO", 4, 56613},
	{"STRATTON", 8, 56614},
	{"ASTRONAUT", 9, 56615},
	{"WEIL", 4, 56616},
	{"YEDC", 4, 56617},
	{"LGOL", 4, 56618},
	{"FFWA", 4, 56619},
	{"ARMCHAIR", 8, 56620},
	{"INSTITUTO", 9, 56621},
	{"REJA", 4, 56622},
	{"EYUN", 4, 56623},
	{"CECILIA", 7, 56624},
	{"LOWRY", 5, 56625},
	{"CONSTIPATION", 12, 56626},
	{"BYKE", 4, 56627},
	{"DFEW", 4, 56628},
	{"SHERYL", 6, 56629},
	{"FAFA", 4, 56630},
	{"NASHUA", 6, 56631},
	{"AIRG", 4, 56632},
	{"UNEC", 4, 56633},
	{"INKU", 4, 56634},
	{"CTFU", 4, 56635},
	{"VEVO", 4, 56636},
	{"LLCU", 4, 56637},
	{"STRUT", 5, 56638},
	{"MENL", 4, 56639},
	{"KARI", 4, 56640},
	{"DELB", 4, 56641},
	{"PAVEL", 5, 56642},
	{"YLAC", 4, 56643},
	{"EEGR", 4, 56644},
	{"OSWEGO", 6, 56645},
	{"GBR", 3, 56646},
	{"APPROPRIATENESS", 15, 56647},
	{"FCER", 4, 56648},
	{"HRAC", 4, 56649},
	{"IGHG", 4, 56650},
	{"SOLSTICE", 8, 56651},
	{"LLNI", 4, 56652},
	{"ITALIEN", 7, 56653},
	{"MCKENNA", 7, 56654},
	{"EUDORA", 6, 56655},
	{"CDOW", 4, 56656},
	{"FJG", 3, 56657},
	{"CANDIDA", 7, 56658},
	{"EMWO", 4, 56659},
	{"WOLFF", 5, 56660},
	{"FVIO", 4, 56661},
	{"FDRU", 4, 56662},
	{"SILDENAFIL", 10, 56663},
	{"ADJUSTS", 7, 56664},
	{"PLUME", 5, 56665},
	{"NOCL", 4, 56666},
	{"IGGS", 4, 56667},
	{"SQFT", 4, 56668},
	{"AYSJ", 4, 56669},
	{"PICKUPS", 7, 56670},
	{"SPARTA", 6, 56671},
	{"DIAF", 4, 56672},
	{"SQUARETRADE", 11, 56673},
	{"CHANDRA", 7, 56674},
	{"CALYPSO", 7, 56675},
	{"CHEESECAKE", 10, 56676},
	{"PANTRY", 6, 56677},
	{"ETIENNE", 7, 56678},
	{"ITALICS", 7, 56679},
	{"RREY", 4, 56680},
	{"REVERSING", 9, 56681},
	{"MURDERER", 8, 56682},
	{"COURTEOUS", 9, 56683},
	{"WILT", 4, 56684},
	{"SMOOTHING", 9, 56685},
	{"BILLET", 6, 56686},
	{"PORTING", 7, 56687},
	{"LUBRICATION", 11, 56688},
	{"LKSI", 4, 56689},
	{"PRETENDING", 10, 56690},
	{"HAMMOCK", 7, 56691},
	{"FSCR", 4, 56692},
	{"SHOOTOUT", 8, 56693},
	{"RECEPTIONS", 10, 56694},
	{"WLEA", 4, 56695},
	{"ENDG", 4, 56696},
	{"RACINE", 6, 56697},
	{"HDAV", 4, 56698},
	{"WEBSERVER", 9, 56699},
	{"YBIR", 4, 56700},
	{"EZUE", 4, 56701},
	{"RKUN", 4, 56702},
	{"RAHP", 4, 56703},
	{"FRAGMENTED", 10, 56704},
	{"REVOKE", 6, 56705},
	{"INTRUDER", 8, 56706},
	{"CHEVRON", 7, 56707},
	{"REINSURANCE", 11, 56708},
	{"MGLA", 4, 56709},
	{"SLATED", 6, 56710},
	{"WAGONS", 6, 56711},
	{"WEPR", 4, 56712},
	{"GXF", 3, 56713},
	{"SJER", 4, 56714},
	{"JENNIE", 6, 56715},
	{"GUANTANAMO", 10, 56716},
	{"REINA", 5, 56717},
	{"ENERGIZER", 9, 56718},
	{"PLATTE", 6, 56719},
	{"CLARKSVILLE", 11, 56720},
	{"VANDALISM", 9, 56721},
	{"UOVE", 4, 56722},
	{"ACPI", 4, 56723},
	{"SALC", 4, 56724},
	{"PLANK", 5, 56725},
	{"ACETAMINOPHEN", 13, 56726},
	{"YPIE", 4, 56727},
	{"RBLU", 4, 56728},
	{"PADDLING", 8, 56729},
	{"WOLFRAM", 7, 56730},
	{"BLYG", 4, 56731},
	{"OFTHE", 5, 56732},
	{"FABE", 4, 56733},
	{"CONTRACEPTIVE", 13, 56734},
	{"DMIX", 4, 56735},
	{"NECROSIS", 8, 56736},
	{"RNSC", 4, 56737},
	{"FEQU", 4, 56738},
	{"EDUB", 4, 56739},
	{"INTERROGATION", 13, 56740},
	{"ODOB", 4, 56741},
	{"BONANZA", 7, 56742},
	{"LUMBAR", 6, 56743},
	{"DISPARITIES", 11, 56744},
	{"OBOU", 4, 56745},
	{"NNYB", 4, 56746},
	{"NDYW", 4, 56747},
	{"UMASS", 5, 56748},
	{"ERDS", 4, 56749},
	{"LONGING", 7, 56750},
	{"IRRESISTIBLE", 12, 56751},
	{"PILGRIMS", 8, 56752},
	{"YPUL", 4, 56753},
	{"MPAL", 4, 56754},
	{"FLAMENCO", 8, 56755},
	{"OSPREY", 6, 56756},
	{"DISAPPEARING", 12, 56757},
	{"CROF", 4, 56758},
	{"BEGE", 4, 56759},
	{"NEBL", 4, 56760},
	{"SUBO", 4, 56761},
	{"SEMY", 4, 56762},
	{"VEKN", 4, 56763},
	{"EYPE", 4, 56764},
	{"BYRU", 4, 56765},
	{"FSPI", 4, 56766},
	{"FLAMMABLE", 9, 56767},
	{"WNPL", 4, 56768},
	{"BIOMETRICS", 10, 56769},
	{"BUSPAR", 6, 56770},
	{"PINW", 4, 56771},
	{"ORDG", 4, 56772},
	{"INERTIA", 7, 56773},
	{"YXV", 3, 56774},
	{"KBJ", 3, 56775},
	{"MISUNDERSTANDING", 16, 56776},
	{"WASNT", 5, 56777},
	{"SOFTWARES", 9, 56778},
	{"DEITY", 5, 56779},
	{"DBM", 3, 56780},
	{"PRUNING", 7, 56781},
	{"ALCHEMIST", 9, 56782},
	{"MARR", 4, 56783},
	{"YBON", 4, 56784},
	{"DLYO", 4, 56785},
	{"ADCR", 4, 56786},
	{"ULYB", 4, 56787},
	{"RMCA", 4, 56788},
	{"PEWH", 4, 56789},
	{"ODYG", 4, 56790},
	{"MCDONALDS", 9, 56791},
	{"HORMONAL", 8, 56792},
	{"UWHO", 4, 56793},
	{"AGRA", 4, 56794},
	{"XPEL", 4, 56795},
	{"MANDOLIN", 8, 56796},
	{"BAUG", 4, 56797},
	{"ROLF", 4, 56798},
	{"CALENDER", 8, 56799},
	{"FSWE", 4, 56800},
	{"SWIFTLY", 7, 56801},
	{"ELRY", 4, 56802},
	{"DISTRO", 6, 56803},
	{"CLAWS", 5, 56804},
	{"VECU", 4, 56805},
	{"BRIGHTLY", 8, 56806},
	{"HMOD", 4, 56807},
	{"VIRGO", 5, 56808},
	{"EMAB", 4, 56809},
	{"MANLY", 5, 56810},
	{"MCGR", 4, 56811},
	{"WINL", 4, 56812},
	{"PABO", 4, 56813},
	{"GLOU", 4, 56814},
	{"SHORTENED", 9, 56815},
	{"RINK", 4, 56816},
	{"JESOLO", 6, 56817},
	{"UNREALISTIC", 11, 56818},
	{"RHONDA", 6, 56819},
	{"PWIN", 4, 56820},
	{"FEARFUL", 7, 56821},
	{"POTENCY", 7, 56822},
	{"PILG", 4, 56823},
	{"NEPU", 4, 56824},
	{"AYOC", 4, 56825},
	{"PINGS", 5, 56826},
	{"FLAWLESS", 8, 56827},
	{"PCP", 3, 56828},
	{"PERIL", 5, 56829},
	{"NULT", 4, 56830},
	{"DESY", 4, 56831},
	{"ALESSANDRO", 10, 56832},
	{"TEASER", 6, 56833},
	{"WNAM", 4, 56834},
	{"BREACHES", 8, 56835},
	{"RESULTANT", 9, 56836},
	{"NESTLED", 7, 56837},
	{"HAIRS", 5, 56838},
	{"IMPAIRMENTS", 11, 56839},
	{"EERM", 4, 56840},
	{"DFEM", 4, 56841},
	{"DUMFRIES", 8, 56842},
	{"DRASTIC", 7, 56843},
	{"COURAGEOUS", 10, 56844},
	{"PROMOS", 6, 56845},
	{"YANM", 4, 56846},
	{"MSOL", 4, 56847},
	{"WARHAMMER", 9, 56848},
	{"ITERATIVE", 9, 56849},
	{"CATERED", 7, 56850},
	{"GUARDED", 7, 56851},
	{"CALLAHAN", 8, 56852},
	{"LLDU", 4, 56853},
	{"NEURON", 6, 56854},
	{"XLIBMESA", 8, 56855},
	{"ULLN", 4, 56856},
	{"HYFO", 4, 56857},
	{"DYPR", 4, 56858},
	{"PULSAR", 6, 56859},
	{"ENEWSLETTER", 11, 56860},
	{"LEHU", 4, 56861},
	{"YUNL", 4, 56862},
	{"ACKK", 4, 56863},
	{"MCEN", 4, 56864},
	{"LITB", 4, 56865},
	{"EABB", 4, 56866},
	{"CELERY", 6, 56867},
	{"PEDAGOGY", 8, 56868},
	{"FAFO", 4, 56869},
	{"RECONCILE", 9, 56870},
	{"BCC", 3, 56871},
	{"ADYL", 4, 56872},
	{"GRAMMATICAL", 11, 56873},
	{"COLLIN", 6, 56874},
	{"AFRIKAANS", 9, 56875},
	{"GCLU", 4, 56876},
	{"CINEMATIC", 9, 56877},
	{"FVY", 3, 56878},
	{"BYKI", 4, 56879},
	{"ADMIRATION", 10, 56880},
	{"OWAM", 4, 56881},
	{"EKWI", 4, 56882},
	{"MALIK", 5, 56883},
	{"IAMP", 4, 56884},
	{"RMSP", 4, 56885},
	{"ZANZIBAR", 8, 56886},
	{"LMWA", 4, 56887},
	{"ICDR", 4, 56888},
	{"TSHIRTS", 7, 56889},
	{"ODIL", 4, 56890},
	{"FELLOWES", 8, 56891},
	{"EGEP", 4, 56892},
	{"ILLUS", 5, 56893},
	{"LBON", 4, 56894},
	{"OFFEND", 6, 56895},
	{"TELEFON", 7, 56896},
	{"MAGUIRE", 7, 56897},
	{"SEVERANCE", 9, 56898},
	{"NUMERACY", 8, 56899},
	{"RRAM", 4, 56900},
	{"SOMALI", 6, 56901},
	{"CAVIAR", 6, 56902},
	{"MICM", 4, 56903},
	{"KPOI", 4, 56904},
	{"POPUPS", 6, 56905},
	{"FCUR", 4, 56906},
	{"SLEEPWEAR", 9, 56907},
	{"QUADS", 5, 56908},
	{"COMBATING", 9, 56909},
	{"RTIG", 4, 56910},
	{"NUMB", 4, 56911},
	{"KOFL", 4, 56912},
	{"RETINA", 6, 56913},
	{"GRADY", 5, 56914},
	{"NKRO", 4, 56915},
	{"UADA", 4, 56916},
	{"MAIDS", 5, 56917},
	{"TEMPTING", 8, 56918},
	{"OCAB", 4, 56919},
	{"IDEU", 4, 56920},
	{"FAFE", 4, 56921},
	{"YORW", 4, 56922},
	{"BUREAUS", 7, 56923},
	{"VOYAGES", 7, 56924},
	{"KELSEY", 6, 56925},
	{"GALATIANS", 9, 56926},
	{"ENFORCEABLE", 11, 56927},
	{"PLANTERS", 8, 56928},
	{"YUNS", 4, 56929},
	{"FROA", 4, 56930},
	{"BOUNCY", 6, 56931},
	{"VCRS", 4, 56932},
	{"RETINAL", 7, 56933},
	{"ROCCO", 5, 56934},
	{"SHEATH", 6, 56935},
	{"OKAD", 4, 56936},
	{"LOUIE", 5, 56937},
	{"CHAPLAIN", 8, 56938},
	{"IGID", 4, 56939},
	{"BENEFITING", 10, 56940},
	{"DUBIOUS", 7, 56941},
	{"ADCL", 4, 56942},
	{"SPONSORSHIPS", 12, 56943},
	{"YWD", 3, 56944},
	{"TEXTRM", 6, 56945},
	{"SCREENWRITER", 12, 56946},
	{"UTHU", 4, 56947},
	{"OKEU", 4, 56948},
	{"OCCUPIES", 8, 56949},
	{"IDME", 4, 56950},
	{"APEW", 4, 56951},
	{"MAMMAL", 6, 56952},
	{"ILSC", 4, 56953},
	{"SHIELDED", 8, 56954},
	{"DEGENERATION", 12, 56955},
	{"LISTENS", 7, 56956},
	{"CUTL", 4, 56957},
	{"SWIRL", 5, 56958},
	{"AWKW", 4, 56959},
	{"EMERY", 5, 56960},
	{"TWISTS", 6, 56961},
	{"SSCU", 4, 56962},
	{"ODYP", 4, 56963},
	{"GDEB", 4, 56964},
	{"ACYW", 4, 56965},
	{"VENDIO", 6, 56966},
	{"OTAGO", 5, 56967},
	{"DUCATI", 6, 56968},
	{"LTEX", 4, 56969},
	{"FMOT", 4, 56970},
	{"FAPL", 4, 56971},
	{"ALLELE", 6, 56972},
	{"SYLVANIA", 8, 56973},
	{"OPTIO", 5, 56974},
	{"PURIFIERS", 9, 56975},
	{"GRYA", 4, 56976},
	{"COMMUTING", 9, 56977},
	{"INTRIGUE", 8, 56978},
	{"HIPHOP", 6, 56979},
	{"DAPU", 4, 56980},
	{"KAMA", 4, 56981},
	{"REEU", 4, 56982},
	{"OMYH", 4, 56983},
	{"KEATING", 7, 56984},
	{"UESR", 4, 56985},
	{"HLEG", 4, 56986},
	{"GHSU", 4, 56987},
	{"BLANCHE", 7, 56988},
	{"CSTU", 4, 56989},
	{"ECZEMA", 6, 56990},
	{"NORTHLAND", 9, 56991},
	{"MSUS", 4, 56992},
	{"OMIR", 4, 56993},
	{"DITP", 4, 56994},
	{"ROADSTER", 8, 56995},
	{"RPLY", 4, 56996},
	{"REIR", 4, 56997},
	{"WOAR", 4, 56998},
	{"UGHU", 4, 56999},
	{"GMAL", 4, 57000},
	{"KBUR", 4, 57001},
	{"ZYV", 3, 57002},
	{"DIALECT", 7, 57003},
	{"NOMINATING", 10, 57004},
	{"FANATIC", 7, 57005},
	{"UPTON", 5, 57006},
	{"PAVE", 4, 57007},
	{"CONFETTI", 8, 57008},
	{"COVERINGS", 9, 57009},
	{"HLAW", 4, 57010},
	{"ANGD", 4, 57011},
	{"RAPTORS", 7, 57012},
	{"RORL", 4, 57013},
	{"MEDV", 4, 57014},
	{"DANCED", 6, 57015},
	{"SLIGHTEST", 9, 57016},
	{"LIBRE", 5, 57017},
	{"BROMLEY", 7, 57018},
	{"ORKY", 4, 57019},
	{"REVIVE", 6, 57020},
	{"WNSW", 4, 57021},
	{"IRDA", 4, 57022},
	{"YVEH", 4, 57023},
	{"COROLLA", 7, 57024},
	{"VEGGIE", 6, 57025},
	{"GSBY", 4, 57026},
	{"DHARMA", 6, 57027},
	{"CHAMELEON", 9, 57028},
	{"FHAD", 4, 57029},
	{"RGOE", 4, 57030},
	{"HOOPER", 6, 57031},
	{"TGRI", 4, 57032},
	{"PREDOMINANT", 11, 57033},
	{"LUCIANO", 7, 57034},
	{"YSBO", 4, 57035},
	{"ABODE", 5, 57036},
	{"SAVOY", 5, 57037},
	{"GRP", 3, 57038},
	{"RDOL", 4, 57039},
	{"ABRASIVE", 8, 57040},
	{"VOGEL", 5, 57041},
	{"INSECURITY", 10, 57042},
	{"KORUNA", 6, 57043},
	{"DYDE", 4, 57044},
	{"ENSEMBLES", 9, 57045},
	{"ORLU", 4, 57046},
	{"BACKPACKER", 10, 57047},
	{"TRUSTWORTHY", 11, 57048},
	{"ILIB", 4, 57049},
	{"BAINBRIDGE", 10, 57050},
	{"UNIFORMITY", 10, 57051},
	{"COMFY", 5, 57052},
	{"ASSURING", 8, 57053},
	{"YVW", 3, 57054},
	{"QJU", 3, 57055},
	{"CONQUERED", 9, 57056},
	{"ALARMING", 8, 57057},
	{"PSMO", 4, 57058},
	{"GETTEXT", 7, 57059},
	{"DUR", 3, 57060},
	{"YHOR", 4, 57061},
	{"REGISTRIES", 10, 57062},
	{"ERADICATION", 11, 57063},
	{"AMUSED", 6, 57064},
	{"HORIZONTALLY", 12, 57065},
	{"HEREFORDSHIRE", 13, 57066},
	{"LOTF", 4, 57067},
	{"ECTACO", 6, 57068},
	{"QUED", 4, 57069},
	{"KNITTED", 7, 57070},
	{"IMBS", 4, 57071},
	{"EXPLODING", 9, 57072},
	{"EAMG", 4, 57073},
	{"CMIL", 4, 57074},
	{"OFUT", 4, 57075},
	{"ACEG", 4, 57076},
	{"JODI", 4, 57077},
	{"RTYE", 4, 57078},
	{"CSRE", 4, 57079},
	{"NARROWLY", 8, 57080},
	{"CAMPO", 5, 57081},
	{"QUINTET", 7, 57082},
	{"RTOY", 4, 57083},
	{"MTAL", 4, 57084},
	{"KIMB", 4, 57085},
	{"GROUPWISE", 9, 57086},
	{"AMBIANCE", 8, 57087},
	{"RUGU", 4, 57088},
	{"CHUN", 4, 57089},
	{"RAMPANT", 7, 57090},
	{"OLYS", 4, 57091},
	{"SUITCASE", 8, 57092},
	{"DAMIAN", 6, 57093},
	{"BAKERIES", 8, 57094},
	{"DMR", 3, 57095},
	{"IEFW", 4, 57096},
	{"APAY", 4, 57097},
	{"POLKA", 5, 57098},
	{"EMBARRASSMENT", 13, 57099},
	{"WIPER", 5, 57100},
	{"AGOC", 4, 57101},
	{"WRAPPERS", 8, 57102},
	{"WIGH", 4, 57103},
	{"GIOCHI", 6, 57104},
	{"MLET", 4, 57105},
	{"SPECTATORS", 10, 57106},
	{"XLW", 3, 57107},
	{"OCKN", 4, 57108},
	{"NKMA", 4, 57109},
	{"LAXY", 4, 57110},
	{"ITERATIONS", 10, 57111},
	{"FAFT", 4, 57112},
	{"NAMESPACES", 10, 57113},
	{"MISMATCH", 8, 57114},
	{"FVIS", 4, 57115},
	{"FDIC", 4, 57116},
	{"CORONADO", 8, 57117},
	{"RETALIATION", 11, 57118},
	{"ULYO", 4, 57119},
	{"FPET", 4, 57120},
	{"XIBI", 4, 57121},
	{"OXIDES", 6, 57122},
	{"QUALIFIERS", 10, 57123},
	{"RLDL", 4, 57124},
	{"ALUP", 4, 57125},
	{"UNAV", 4, 57126},
	{"MDIR", 4, 57127},
	{"INQUIRER", 8, 57128},
	{"REYH", 4, 57129},
	{"BYHU", 4, 57130},
	{"BATTERED", 8, 57131},
	{"WELLESLEY", 9, 57132},
	{"MOFB", 4, 57133},
	{"IFEV", 4, 57134},
	{"FEBE", 4, 57135},
	{"DREADFUL", 8, 57136},
	{"SMOKEY", 6, 57137},
	{"CGUI", 4, 57138},
	{"PASSWD", 6, 57139},
	{"METAPHYSICS", 11, 57140},
	{"DRIFTING", 8, 57141},
	{"RITTER", 6, 57142},
	{"VACUUMS", 7, 57143},
	{"ATTENDS", 7, 57144},
	{"RKEV", 4, 57145},
	{"OLAL", 4, 57146},
	{"EGAU", 4, 57147},
	{"FALUN", 5, 57148},
	{"NICER", 5, 57149},
	{"SBUY", 4, 57150},
	{"FBIR", 4, 57151},
	{"MELLOW", 6, 57152},
	{"PRECIP", 6, 57153},
	{"LAGOS", 5, 57154},
	{"GENTS", 5, 57155},
	{"RESPIRATION", 11, 57156},
	{"RAPPER", 6, 57157},
	{"LPUT", 4, 57158},
	{"GAFR", 4, 57159},
	{"RLSW", 4, 57160},
	{"EDUA", 4, 57161},
	{"ABSENTEE", 8, 57162},
	{"DUPLICATES", 10, 57163},
	{"YSTY", 4, 57164},
	{"ORTV", 4, 57165},
	{"ADSF", 4, 57166},
	{"LZD", 3, 57167},
	{"GZW", 3, 57168},
	{"HOOTERS", 7, 57169},
	{"AYPL", 4, 57170},
	{"CALLIGRAPHY", 11, 57171},
	{"DUBOIS", 6, 57172},
	{"YRIV", 4, 57173},
	{"FSIL", 4, 57174},
	{"ADVANTAGEOUS", 12, 57175},
	{"MUSTEK", 6, 57176},
	{"RJER", 4, 57177},
	{"MYWO", 4, 57178},
	{"COROLLARY", 9, 57179},
	{"TIGHTER", 7, 57180},
	{"PREDETERMINED", 13, 57181},
	{"UGEL", 4, 57182},
	{"ASPARAGUS", 9, 57183},
	{"TERQ", 4, 57184},
	{"FMAD", 4, 57185},
	{"ATRY", 4, 57186},
	{"MONIQUE", 7, 57187},
	{"FEARLESS", 8, 57188},
	{"CEDN", 4, 57189},
	{"AIRY", 4, 57190},
	{"ORTIZ", 5, 57191},
	{"PREF", 4, 57192},
	{"SEUD", 4, 57193},
	{"PROGRESSES", 10, 57194},
	{"CANISTER", 8, 57195},
	{"ROCT", 4, 57196},
	{"MORNINGSTAR", 11, 57197},
	{"STIFFNESS", 9, 57198},
	{"RECESSED", 8, 57199},
	{"THRIFTY", 7, 57200},
	{"LJUN", 4, 57201},
	{"CANNING", 7, 57202},
	{"VSKY", 4, 57203},
	{"WORKMANSHIP", 11, 57204},
	{"RPUS", 4, 57205},
	{"PALLADIUM", 9, 57206},
	{"TOTALED", 7, 57207},
	{"LEVITT", 6, 57208},
	{"COMPLEXITIES", 12, 57209},
	{"KABU", 4, 57210},
	{"OVEG", 4, 57211},
	{"SHIPPER", 7, 57212},
	{"IREY", 4, 57213},
	{"DIDB", 4, 57214},
	{"OKBA", 4, 57215},
	{"KPEO", 4, 57216},
	{"CTSD", 4, 57217},
	{"DARRYL", 6, 57218},
	{"CTSR", 4, 57219},
	{"MERRELL", 7, 57220},
	{"WRINKLES", 8, 57221},
	{"ILLUSTRATING", 12, 57222},
	{"DGAL", 4, 57223},
	{"REDUCTASE", 9, 57224},
	{"RAUL", 4, 57225},
	{"XCAV", 4, 57226},
	{"IFRE", 4, 57227},
	{"DSBO", 4, 57228},
	{"SHENANDOAH", 10, 57229},
	{"HARNESSES", 9, 57230},
	{"LOMA", 4, 57231},
	{"OSHKOSH", 7, 57232},
	{"MULTIVARIATE", 12, 57233},
	{"PERCH", 5, 57234},
	{"ADPU", 4, 57235},
	{"IRML", 4, 57236},
	{"FPAI", 4, 57237},
	{"YGF", 3, 57238},
	{"XCUT", 4, 57239},
	{"GEIL", 4, 57240},
	{"CRAVEN", 6, 57241},
	{"DIVERGENCE", 10, 57242},
	{"KITCHENWARE", 11, 57243},
	{"HOMAGE", 6, 57244},
	{"RGYP", 4, 57245},
	{"ATROCITIES", 10, 57246},
	{"UNIGENE", 7, 57247},
	{"EAFG", 4, 57248},
	{"ILDM", 4, 57249},
	{"IMMUNOGLOBULIN", 14, 57250},
	{"RMHA", 4, 57251},
	{"LONDONDERRY", 11, 57252},
	{"SILVERSTONE", 11, 57253},
	{"UNIDEN", 6, 57254},
	{"TELECHARGEMENT", 14, 57255},
	{"NDOG", 4, 57256},
	{"AUOF", 4, 57257},
	{"GHUM", 4, 57258},
	{"ORKG", 4, 57259},
	{"GCUR", 4, 57260},
	{"REMSTATS", 8, 57261},
	{"UDEW", 4, 57262},
	{"UNITARY", 7, 57263},
	{"EMMY", 4, 57264},
	{"CUPT", 4, 57265},
	{"WOGR", 4, 57266},
	{"MTOU", 4, 57267},
	{"CHEZ", 4, 57268},
	{"ADMITTEDLY", 10, 57269},
	{"RUIZ", 4, 57270},
	{"GETNETWISE", 10, 57271},
	{"HOSPITALIZATION", 15, 57272},
	{"CLUBBING", 8, 57273},
	{"MICROELECTRONICS", 16, 57274},
	{"OBSERVATIONAL", 13, 57275},
	{"WAVERLY", 7, 57276},
	{"CRASHERS", 8, 57277},
	{"SCHWAB", 6, 57278},
	{"ANGST", 5, 57279},
	{"LITURGY", 7, 57280},
	{"NATIVITY", 8, 57281},
	{"SURETY", 6, 57282},
	{"MYSH", 4, 57283},
	{"IMEJ", 4, 57284},
	{"DEREGULATION", 12, 57285},
	{"MAGR", 4, 57286},
	{"FMAC", 4, 57287},
	{"TRANQUIL", 8, 57288},
	{"CARPENTRY", 9, 57289},
	{"OWBR", 4, 57290},
	{"EPYO", 4, 57291},
	{"DISSEMINATED", 12, 57292},
	{"STEINBERG", 9, 57293},
	{"STAIRCASE", 9, 57294},
	{"HEXC", 4, 57295},
	{"ELDL", 4, 57296},
	{"CUTLER", 6, 57297},
	{"SWEETIE", 7, 57298},
	{"ILSF", 4, 57299},
	{"CRADLES", 7, 57300},
	{"ELECTORATE", 10, 57301},
	{"MIDEAST", 7, 57302},
	{"RECONSTRUCTED", 13, 57303},
	{"EWGO", 4, 57304},
	{"CEQU", 4, 57305},
	{"RESENT", 6, 57306},
	{"HISPANICS", 9, 57307},
	{"PODIUM", 6, 57308},
	{"KCOL", 4, 57309},
	{"AKWI", 4, 57310},
	{"OPPOSES", 7, 57311},
	{"PARANOIA", 8, 57312},
	{"YORP", 4, 57313},
	{"FACETED", 7, 57314},
	{"GETG", 4, 57315},
	{"KEYL", 4, 57316},
	{"SILVIA", 6, 57317},
	{"DISTRACTION", 11, 57318},
	{"ARNF", 4, 57319},
	{"DOMINATES", 9, 57320},
	{"KIMBERLEY", 9, 57321},
	{"GECKO", 5, 57322},
	{"DESPATCH", 8, 57323},
	{"FULLSCREEN", 10, 57324},
	{"TUSW", 4, 57325},
	{"FMYF", 4, 57326},
	{"EWFE", 4, 57327},
	{"FUGITIVE", 8, 57328},
	{"TUCKED", 6, 57329},
	{"INTERCHANGEABLE", 15, 57330},
	{"ROLLINS", 7, 57331},
	{"JERICHO", 7, 57332},
	{"YPOC", 4, 57333},
	{"STARSHIP", 8, 57334},
	{"TURMOIL", 7, 57335},
	{"MIELE", 5, 57336},
	{"EAPU", 4, 57337},
	{"SEEDED", 6, 57338},
	{"PHAB", 4, 57339},
	{"GOFD", 4, 57340},
	{"GILLES", 6, 57341},
	{"DIETRICH", 8, 57342},
	{"ODWE", 4, 57343},
	{"HAINES", 6, 57344},
	{"UNJUST", 6, 57345},
	{"CYCLISTS", 8, 57346},
	{"MARKEDLY", 8, 57347},
	{"FASCINATED", 10, 57348},
	{"TERMINATES", 10, 57349},
	{"EXEMPTED", 8, 57350},
	{"BOUNCED", 7, 57351},
	{"RANKIN", 6, 57352},
	{"BRIGHTEST", 9, 57353},
	{"MYGO", 4, 57354},
	{"NURTURING", 9, 57355},
	{"SADDLES", 7, 57356},
	{"NDYM", 4, 57357},
	{"ENZYMOLOGY", 10, 57358},
	{"YCOT", 4, 57359},
	{"LTLA", 4, 57360},
	{"AMADEUS", 7, 57361},
	{"EEGG", 4, 57362},
	{"GALAPAGOS", 9, 57363},
	{"OKWH", 4, 57364},
	{"DAJO", 4, 57365},
	{"URJO", 4, 57366},
	{"OFTY", 4, 57367},
	{"UCONN", 5, 57368},
	{"SCOTSMAN", 8, 57369},
	{"FITZPATRICK", 11, 57370},
	{"GUSHING", 7, 57371},
	{"WNSC", 4, 57372},
	{"IEWF", 4, 57373},
	{"YGUI", 4, 57374},
	{"PICKER", 6, 57375},
	{"WEEX", 4, 57376},
	{"GFRA", 4, 57377},
	{"FMAJ", 4, 57378},
	{"DISTRACTED", 10, 57379},
	{"NKCO", 4, 57380},
	{"SECLUDED", 8, 57381},
	{"VEEF", 4, 57382},
	{"LMOF", 4, 57383},
	{"LIVELIHOOD", 10, 57384},
	{"RKME", 4, 57385},
	{"MULDER", 6, 57386},
	{"GODFREY", 7, 57387},
	{"DIALER", 6, 57388},
	{"WPOI", 4, 57389},
	{"HORW", 4, 57390},
	{"MINERVA", 7, 57391},
	{"SUPERSEDED", 10, 57392},
	{"ICEBERG", 7, 57393},
	{"PONL", 4, 57394},
	{"CALEB", 5, 57395},
	{"CHRISTENING", 11, 57396},
	{"JEALOUSY", 8, 57397},
	{"MOONEY", 6, 57398},
	{"TMEL", 4, 57399},
	{"SYNTACTIC", 9, 57400},
	{"PLUMBER", 7, 57401},
	{"MGRO", 4, 57402},
	{"MCLO", 4, 57403},
	{"JETTA", 5, 57404},
	{"DOWNEY", 6, 57405},
	{"HAGEN", 5, 57406},
	{"COWH", 4, 57407},
	{"CODEX", 5, 57408},
	{"SQUEEZED", 8, 57409},
	{"USERID", 6, 57410},
	{"EALU", 4, 57411},
	{"JUDAS", 5, 57412},
	{"SSBR", 4, 57413},
	{"VALLE", 5, 57414},
	{"COSMOLOGY", 9, 57415},
	{"DOLE", 4, 57416},
	{"WICK", 4, 57417},
	{"GERTRUDE", 8, 57418},
	{"COMMUNISTS", 10, 57419},
	{"EXED", 4, 57420},
	{"NOODLE", 6, 57421},
	{"ODPO", 4, 57422},
	{"GROMIT", 6, 57423},
	{"SCENTS", 6, 57424},
	{"GBOD", 4, 57425},
	{"SARGENT", 7, 57426},
	{"POFI", 4, 57427},
	{"BANGLE", 6, 57428},
	{"UBTI", 4, 57429},
	{"BURM", 4, 57430},
	{"NKID", 4, 57431},
	{"LATC", 4, 57432},
	{"EVEP", 4, 57433},
	{"BERTHA", 6, 57434},
	{"LEVIED", 6, 57435},
	{"BARNS", 5, 57436},
	{"COVENANTS", 9, 57437},
	{"EWCL", 4, 57438},
	{"DONNIE", 6, 57439},
	{"PRIVATISATION", 13, 57440},
	{"GVAL", 4, 57441},
	{"PROPRIETOR", 10, 57442},
	{"ALUT", 4, 57443},
	{"NJUD", 4, 57444},
	{"FFME", 4, 57445},
	{"TOFU", 4, 57446},
	{"UNHCR", 5, 57447},
	{"BATTLESTAR", 10, 57448},
	{"LIZZIE", 6, 57449},
	{"RYPI", 4, 57450},
	{"EUNR", 4, 57451},
	{"RAIDS", 5, 57452},
	{"INTUIT", 6, 57453},
	{"ADOPTIVE", 8, 57454},
	{"WPOR", 4, 57455},
	{"SOLOS", 5, 57456},
	{"COMPARTMENTS", 12, 57457},
	{"MINIMIZED", 9, 57458},
	{"BIZA", 4, 57459},
	{"PARTNERED", 9, 57460},
	{"FILIBUSTER", 10, 57461},
	{"OLBA", 4, 57462},
	{"IGCO", 4, 57463},
	{"GLAMORGAN", 9, 57464},
	{"ADWORDS", 7, 57465},
	{"TULANE", 6, 57466},
	{"LOTL", 4, 57467},
	{"PSPR", 4, 57468},
	{"ORYG", 4, 57469},
	{"NURB", 4, 57470},
	{"LDPI", 4, 57471},
	{"FACET", 5, 57472},
	{"OKMA", 4, 57473},
	{"GGK", 3, 57474},
	{"BEHAVIOURS", 10, 57475},
	{"IMPORTATION", 11, 57476},
	{"REDNECK", 7, 57477},
	{"RROM", 4, 57478},
	{"IMAX", 4, 57479},
	{"XPATH", 5, 57480},
	{"SYNTHESIZED", 11, 57481},
	{"LUEL", 4, 57482},
	{"FFHE", 4, 57483},
	{"ENCAPSULATION", 13, 57484},
	{"SAMSONITE", 9, 57485},
	{"LFBE", 4, 57486},
	{"GVIC", 4, 57487},
	{"ACCORDION", 9, 57488},
	{"FBIG", 4, 57489},
	{"PLANTER", 7, 57490},
	{"ROONEY", 6, 57491},
	{"EVRO", 4, 57492},
	{"MINIMALLY", 9, 57493},
	{"BSOF", 4, 57494},
	{"WEBPREFERENCES", 14, 57495},
	{"UGST", 4, 57496},
	{"SKODA", 5, 57497},
	{"PADR", 4, 57498},
	{"METZ", 4, 57499},
	{"MATCHUPS", 8, 57500},
	{"IMMACULATE", 10, 57501},
	{"YEDD", 4, 57502},
	{"FANB", 4, 57503},
	{"TYGA", 4, 57504},
	{"RSEG", 4, 57505},
	{"UCC", 3, 57506},
	{"PUR", 3, 57507},
	{"ZABL", 4, 57508},
	{"MAILINGS", 8, 57509},
	{"DDSA", 4, 57510},
	{"REINDEER", 8, 57511},
	{"OSPL", 4, 57512},
	{"ENZY", 4, 57513},
	{"BEACHFRONT", 10, 57514},
	{"TELEGRAM", 8, 57515},
	{"ROLC", 4, 57516},
	{"VEEM", 4, 57517},
	{"SHLY", 4, 57518},
	{"IDAW", 4, 57519},
	{"URTN", 4, 57520},
	{"RUBEN", 5, 57521},
	{"LALT", 4, 57522},
	{"GLYB", 4, 57523},
	{"SHAKEN", 6, 57524},
	{"CROSSWORDS", 10, 57525},
	{"WARES", 5, 57526},
	{"PUBCHEM", 7, 57527},
	{"INTEGRATIVE", 11, 57528},
	{"ICYT", 4, 57529},
	{"CKDI", 4, 57530},
	{"RIVALRY", 7, 57531},
	{"KELOWNA", 7, 57532},
	{"VERVE", 5, 57533},
	{"YERP", 4, 57534},
	{"CHARLEY", 7, 57535},
	{"CARPENTERS", 10, 57536},
	{"MBYT", 4, 57537},
	{"SPREE", 5, 57538},
	{"DASY", 4, 57539},
	{"ASKW", 4, 57540},
	{"EMBED", 5, 57541},
	{"GURUS", 5, 57542},
	{"SUNK", 4, 57543},
	{"YWEW", 4, 57544},
	{"TCOP", 4, 57545},
	{"MORLEY", 6, 57546},
	{"BESPOKE", 7, 57547},
	{"INFLICTED", 9, 57548},
	{"ABBREVIATED", 11, 57549},
	{"ALLOTTED", 8, 57550},
	{"DOFK", 4, 57551},
	{"SHUTTERFLY", 10, 57552},
	{"DROWNED", 7, 57553},
	{"GERHARD", 7, 57554},
	{"ESCORTED", 8, 57555},
	{"WATERSHEDS", 10, 57556},
	{"BRUTE", 5, 57557},
	{"XCRE", 4, 57558},
	{"FERB", 4, 57559},
	{"DSRA", 4, 57560},
	{"DIRO", 4, 57561},
	{"YBUY", 4, 57562},
	{"OODV", 4, 57563},
	{"TRIMESTER", 9, 57564},
	{"BARRACKS", 8, 57565},
	{"CLICKABLE", 9, 57566},
	{"KIDNEYS", 7, 57567},
	{"SPYDER", 6, 57568},
	{"ELECTRICIANS", 12, 57569},
	{"WARBLER", 7, 57570},
	{"YRAR", 4, 57571},
	{"DBAG", 4, 57572},
	{"NEXIUM", 6, 57573},
	{"ONWARD", 6, 57574},
	{"CAPRICORN", 9, 57575},
	{"OMVA", 4, 57576},
	{"AULO", 4, 57577},
	{"KIDNAPPING", 10, 57578},
	{"INDUCING", 8, 57579},
	{"DIPPED", 6, 57580},
	{"LANCET", 6, 57581},
	{"ANTELOPE", 8, 57582},
	{"TERMINUS", 8, 57583},
	{"CASTINGS", 8, 57584},
	{"NMYC", 4, 57585},
	{"FBUI", 4, 57586},
	{"YWEH", 4, 57587},
	{"FLANDERS", 8, 57588},
	{"KTOF", 4, 57589},
	{"FJAN", 4, 57590},
	{"PERM", 4, 57591},
	{"OKWI", 4, 57592},
	{"YSOP", 4, 57593},
	{"URRU", 4, 57594},
	{"SPECTROMETRY", 12, 57595},
	{"SNIPPET", 7, 57596},
	{"IALJ", 4, 57597},
	{"RRYD", 4, 57598},
	{"IMLO", 4, 57599},
	{"PELLETS", 7, 57600},
	{"DAHU", 4, 57601},
	{"GFLO", 4, 57602},
	{"EPAK", 4, 57603},
	{"CDAN", 4, 57604},
	{"AELJ", 4, 57605},
	{"PERMEABILITY", 12, 57606},
	{"SALF", 4, 57607},
	{"DFEB", 4, 57608},
	{"YATC", 4, 57609},
	{"OJUM", 4, 57610},
	{"ERMD", 4, 57611},
	{"ENCLOSING", 9, 57612},
	{"NBOX", 4, 57613},
	{"STARRED", 7, 57614},
	{"WAUKESHA", 8, 57615},
	{"YJF", 3, 57616},
	{"QUEW", 4, 57617},
	{"DEACON", 6, 57618},
	{"RIRA", 4, 57619},
	{"GNWA", 4, 57620},
	{"KABUL", 5, 57621},
	{"SWEEPS", 6, 57622},
	{"ZEFO", 4, 57623},
	{"BUTCH", 5, 57624},
	{"OOMM", 4, 57625},
	{"SCART", 5, 57626},
	{"MERCURE", 7, 57627},
	{"MCKI", 4, 57628},
	{"GMOT", 4, 57629},
	{"NORMALIZATION", 13, 57630},
	{"SOBJ", 4, 57631},
	{"DDST", 4, 57632},
	{"ARRU", 4, 57633},
	{"SKILLET", 7, 57634},
	{"VEFL", 4, 57635},
	{"GSIX", 4, 57636},
	{"GIMM", 4, 57637},
	{"BOOKCASE", 8, 57638},
	{"YREJ", 4, 57639},
	{"NEOPRENE", 8, 57640},
	{"HADK", 4, 57641},
	{"VLC", 3, 57642},
	{"OFFEROR", 7, 57643},
	{"GEEX", 4, 57644},
	{"ASSEMBLING", 10, 57645},
	{"LTAB", 4, 57646},
	{"EELG", 4, 57647},
	{"THERMO", 6, 57648},
	{"TTYW", 4, 57649},
	{"HRIG", 4, 57650},
	{"DIAPHRAGM", 9, 57651},
	{"WNSU", 4, 57652},
	{"SDOG", 4, 57653},
	{"QUESTO", 6, 57654},
	{"HUBER", 5, 57655},
	{"CHORES", 6, 57656},
	{"JARRETT", 7, 57657},
	{"CONSIGNMENT", 11, 57658},
	{"YARNS", 5, 57659},
	{"FARECHASE", 9, 57660},
	{"MAINTAINERS", 11, 57661},
	{"WNAC", 4, 57662},
	{"NFLS", 4, 57663},
	{"MAARTEN", 7, 57664},
	{"GINSENG", 7, 57665},
	{"LUEJ", 4, 57666},
	{"BLACKOUT", 8, 57667},
	{"DETERGENT", 9, 57668},
	{"SEEDLINGS", 9, 57669},
	{"ROSETTA", 7, 57670},
	{"QUOM", 4, 57671},
	{"MALG", 4, 57672},
	{"FORTIFIED", 9, 57673},
	{"RECONSIDERATION", 15, 57674},
	{"RICL", 4, 57675},
	{"INMC", 4, 57676},
	{"BARNARD", 7, 57677},
	{"XEDT", 4, 57678},
	{"URCR", 4, 57679},
	{"GRENADE", 7, 57680},
	{"OCCURED", 7, 57681},
	{"WSLE", 4, 57682},
	{"PROFOUNDLY", 10, 57683},
	{"KARIN", 5, 57684},
	{"FONTANA", 7, 57685},
	{"LYGU", 4, 57686},
	{"BARTENDER", 9, 57687},
	{"MAYFAIR", 7, 57688},
	{"ESMY", 4, 57689},
	{"MANEUVER", 8, 57690},
	{"RYSY", 4, 57691},
	{"RKSD", 4, 57692},
	{"KANG", 4, 57693},
	{"RIDDER", 6, 57694},
	{"VANISHED", 8, 57695},
	{"LQUI", 4, 57696},
	{"CRAFTING", 8, 57697},
	{"LAIR", 4, 57698},
	{"ENCLOSE", 7, 57699},
	{"YSUF", 4, 57700},
	{"IGUI", 4, 57701},
	{"FEWR", 4, 57702},
	{"IVILLAGE", 8, 57703},
	{"MOWERS", 6, 57704},
	{"BRATISLAVA", 10, 57705},
	{"PHYW", 4, 57706},
	{"SINNERS", 7, 57707},
	{"POLICYMAKERS", 12, 57708},
	{"LILLE", 5, 57709},
	{"NDYC", 4, 57710},
	{"IRTW", 4, 57711},
	{"SIENNA", 6, 57712},
	{"WATFORD", 7, 57713},
	{"NLAP", 4, 57714},
	{"CALVES", 6, 57715},
	{"MISCO", 5, 57716},
	{"DEFER", 5, 57717},
	{"GIVENCHY", 8, 57718},
	{"DESMOND", 7, 57719},
	{"LIARS", 5, 57720},
	{"LACY", 4, 57721},
	{"PHARAOH", 7, 57722},
	{"LXC", 3, 57723},
	{"FDEN", 4, 57724},
	{"ADVOCATED", 9, 57725},
	{"RDSN", 4, 57726},
	{"OROW", 4, 57727},
	{"ITCHING", 7, 57728},
	{"CSPO", 4, 57729},
	{"ALLES", 5, 57730},
	{"REIMBURSE", 9, 57731},
	{"DEVOTIONAL", 10, 57732},
	{"EVOU", 4, 57733},
	{"MPUR", 4, 57734},
	{"BYJE", 4, 57735},
	{"NGAK", 4, 57736},
	{"ESPERANTO", 9, 57737},
	{"MODALITIES", 10, 57738},
	{"PCC", 3, 57739},
	{"LBOD", 4, 57740},
	{"FERH", 4, 57741},
	{"BADF", 4, 57742},
	{"LIGHTERS", 8, 57743},
	{"COMPARATIVELY", 13, 57744},
	{"VWAS", 4, 57745},
	{"SHUTTING", 8, 57746},
	{"SPARTANS", 8, 57747},
	{"UMEI", 4, 57748},
	{"ENDEMIC", 7, 57749},
	{"TOURNEY", 7, 57750},
	{"REASONED", 8, 57751},
	{"LAWTON", 6, 57752},
	{"CARLY", 5, 57753},
	{"DEGLI", 5, 57754},
	{"HYDROLOGIC", 10, 57755},
	{"STANSTED", 8, 57756},
	{"ASTRAL", 6, 57757},
	{"EPTB", 4, 57758},
	{"HUDDERSFIELD", 12, 57759},
	{"PARALLELS", 9, 57760},
	{"AIMEE", 5, 57761},
	{"YELLED", 6, 57762},
	{"DAVEY", 5, 57763},
	{"YVEB", 4, 57764},
	{"WREN", 4, 57765},
	{"ELIQ", 4, 57766},
	{"RTLO", 4, 57767},
	{"ULEW", 4, 57768},
	{"RDIZ", 4, 57769},
	{"HELPSEARCHMEMBERSCALENDAR", 25, 57770},
	{"TERENCE", 7, 57771},
	{"HAMPER", 6, 57772},
	{"BALKAN", 6, 57773},
	{"YXU", 3, 57774},
	{"OWOM", 4, 57775},
	{"DFUT", 4, 57776},
	{"TRANSDUCTION", 12, 57777},
	{"SILVERMAN", 9, 57778},
	{"BLURRED", 7, 57779},
	{"CLARIFYING", 10, 57780},
	{"ODSF", 4, 57781},
	{"AORTIC", 6, 57782},
	{"DRC", 3, 57783},
	{"SMUGGLING", 9, 57784},
	{"ILTW", 4, 57785},
	{"EBIK", 4, 57786},
	{"STARCRAFT", 9, 57787},
	{"MARTENS", 7, 57788},
	{"INSTINCTS", 9, 57789},
	{"FICKEN", 6, 57790},
	{"HUTTON", 6, 57791},
	{"UCKH", 4, 57792},
	{"DGOE", 4, 57793},
	{"MASQUERADE", 10, 57794},
	{"DEANS", 5, 57795},
	{"STRUCTURING", 11, 57796},
	{"KONAMI", 6, 57797},
	{"DUALITY", 7, 57798},
	{"PRUD", 4, 57799},
	{"EDLU", 4, 57800},
	{"SENSATIONAL", 11, 57801},
	{"KITES", 5, 57802},
	{"LIPIDS", 6, 57803},
	{"UFFT", 4, 57804},
	{"PWHO", 4, 57805},
	{"JURISDICTIONAL", 14, 57806},
	{"IERG", 4, 57807},
	{"FNOV", 4, 57808},
	{"EWGR", 4, 57809},
	{"ESGU", 4, 57810},
	{"SMOOTHER", 8, 57811},
	{"RLAI", 4, 57812},
	{"CELLPHONES", 10, 57813},
	{"EXPULSION", 9, 57814},
	{"USBY", 4, 57815},
	{"CORDOBA", 7, 57816},
	{"AXCU", 4, 57817},
	{"WITHHOLD", 8, 57818},
	{"ROMANO", 6, 57819},
	{"SHEPPARD", 8, 57820},
	{"GRIEVANCES", 10, 57821},
	{"BETRAYED", 8, 57822},
	{"EVOK", 4, 57823},
	{"NLAY", 4, 57824},
	{"DPKG", 4, 57825},
	{"FOLSOM", 6, 57826},
	{"TRIGGERING", 10, 57827},
	{"XTBO", 4, 57828},
	{"EUKA", 4, 57829},
	{"DUMPS", 5, 57830},
	{"MAPA", 4, 57831},
	{"NYCL", 4, 57832},
	{"ICMU", 4, 57833},
	{"RACKMOUNT", 9, 57834},
	{"BINOCULAR", 9, 57835},
	{"BUCKLES", 7, 57836},
	{"JOYFUL", 6, 57837},
	{"GENERALIZATION", 14, 57838},
	{"SPECIALISE", 10, 57839},
	{"GVAR", 4, 57840},
	{"BANY", 4, 57841},
	{"REMORTGAGES", 11, 57842},
	{"MCKINLEY", 8, 57843},
	{"HANKS", 5, 57844},
	{"TYOV", 4, 57845},
	{"ICAU", 4, 57846},
	{"PANCAKES", 8, 57847},
	{"DOSING", 6, 57848},
	{"EFTY", 4, 57849},
	{"CRAVE", 5, 57850},
	{"TKEP", 4, 57851},
	{"RJUL", 4, 57852},
	{"CORDOVA", 7, 57853},
	{"JAGU", 4, 57854},
	{"EDRY", 4, 57855},
	{"STROBE", 6, 57856},
	{"FOCUSSED", 8, 57857},
	{"NYAD", 4, 57858},
	{"WAFFLE", 6, 57859},
	{"DETECTABLE", 10, 57860},
	{"ARROWHEAD", 9, 57861},
	{"MCFARLANE", 9, 57862},
	{"RIPPLE", 6, 57863},
	{"PAYCHECK", 8, 57864},
	{"SWEEPER", 7, 57865},
	{"NBYF", 4, 57866},
	{"LDTU", 4, 57867},
	{"RNMI", 4, 57868},
	{"CLAIMANTS", 9, 57869},
	{"FREELANCERS", 11, 57870},
	{"MFOU", 4, 57871},
	{"CONSOLIDATING", 13, 57872},
	{"SEINFELD", 8, 57873},
	{"RTOJ", 4, 57874},
	{"GOLDSMITH", 9, 57875},
	{"RESPONDERS", 10, 57876},
	{"INCLINATION", 11, 57877},
	{"RCRU", 4, 57878},
	{"KEEPSAKE", 8, 57879},
	{"YONB", 4, 57880},
	{"OKEF", 4, 57881},
	{"HBAL", 4, 57882},
	{"BIRTHDATE", 9, 57883},
	{"FABL", 4, 57884},
	{"GETTIN", 6, 57885},
	{"MEASLES", 7, 57886},
	{"EWJO", 4, 57887},
	{"ARCS", 4, 57888},
	{"YZD", 3, 57889},
	{"YYV", 3, 57890},
	{"UPBEAT", 6, 57891},
	{"KISL", 4, 57892},
	{"AWFI", 4, 57893},
	{"PORTMAN", 7, 57894},
	{"AMENITY", 7, 57895},
	{"DONUTS", 6, 57896},
	{"SALTY", 5, 57897},
	{"INTERACIAL", 10, 57898},
	{"NYCR", 4, 57899},
	{"BYMU", 4, 57900},
	{"CUISINART", 9, 57901},
	{"BAPTIZED", 8, 57902},
	{"YTOJ", 4, 57903},
	{"EXPELLED", 8, 57904},
	{"NAUTICA", 7, 57905},
	{"RVEB", 4, 57906},
	{"KSMI", 4, 57907},
	{"ESTRADIOL", 9, 57908},
	{"RUPEES", 6, 57909},
	{"LFBU", 4, 57910},
	{"FMYS", 4, 57911},
	{"TBAY", 4, 57912},
	{"DDAL", 4, 57913},
	{"NOTICIAS", 8, 57914},
	{"OADJ", 4, 57915},
	{"MROB", 4, 57916},
	{"CEUT", 4, 57917},
	{"BETRAYAL", 8, 57918},
	{"GMP", 3, 57919},
	{"SCHAEFER", 8, 57920},
	{"PROTOTYPING", 11, 57921},
	{"FTAX", 4, 57922},
	{"DIOF", 4, 57923},
	{"FLOURISH", 8, 57924},
	{"OMPM", 4, 57925},
	{"ZEROS", 5, 57926},
	{"CSPR", 4, 57927},
	{"SPORTY", 6, 57928},
	{"GRAF", 4, 57929},
	{"YAUS", 4, 57930},
	{"HAWKING", 7, 57931},
	{"NYBR", 4, 57932},
	{"TUMOUR", 6, 57933},
	{"FPIC", 4, 57934},
	{"CKTE", 4, 57935},
	{"PDC", 3, 57936},
	{"ATPASE", 6, 57937},
	{"POOLED", 6, 57938},
	{"BORA", 4, 57939},
	{"DIVIDES", 7, 57940},
	{"TYAB", 4, 57941},
	{"AELM", 4, 57942},
	{"STABILIZE", 9, 57943},
	{"NDIK", 4, 57944},
	{"SUBWOOFERS", 10, 57945},
	{"UMCA", 4, 57946},
	{"COMPOSING", 9, 57947},
	{"HANDICRAFTS", 11, 57948},
	{"HEALED", 6, 57949},
	{"VEHU", 4, 57950},
	{"MEGU", 4, 57951},
	{"BURMESE", 7, 57952},
	{"CLUELESS", 8, 57953},
	{"MYBU", 4, 57954},
	{"SOFITEL", 7, 57955},
	{"RIPI", 4, 57956},
	{"AYEL", 4, 57957},
	{"VALOR", 5, 57958},
	{"PEDESTRIANS", 11, 57959},
	{"WOODRUFF", 8, 57960},
	{"RMEI", 4, 57961},
	{"RKRA", 4, 57962},
	{"PTOL", 4, 57963},
	{"AMPF", 4, 57964},
	{"SOUTHPORT", 9, 57965},
	{"RTAF", 4, 57966},
	{"WALKTHROUGHS", 12, 57967},
	{"RADIOTHERAPY", 12, 57968},
	{"MCEL", 4, 57969},
	{"LFIT", 4, 57970},
	{"EWEM", 4, 57971},
	{"GATHERS", 7, 57972},
	{"PAWN", 4, 57973},
	{"STITCHED", 8, 57974},
	{"ICKG", 4, 57975},
	{"EMYB", 4, 57976},
	{"WELR", 4, 57977},
	{"RMPR", 4, 57978},
	{"CAMILLE", 7, 57979},
	{"MINIFIG", 7, 57980},
	{"CEASES", 6, 57981},
	{"DORSAL", 6, 57982},
	{"BYEM", 4, 57983},
	{"TRANSFUSION", 11, 57984},
	{"COLLIE", 6, 57985},
	{"ZEND", 4, 57986},
	{"NEWTOWN", 7, 57987},
	{"GSLA", 4, 57988},
	{"MCMILLAN", 8, 57989},
	{"LFES", 4, 57990},
	{"IMEU", 4, 57991},
	{"OMGA", 4, 57992},
	{"HEREDITARY", 10, 57993},
	{"EXAGGERATED", 11, 57994},
	{"OWSD", 4, 57995},
	{"GTHY", 4, 57996},
	{"BUCCANEERS", 10, 57997},
	{"MCD", 3, 57998},
	{"PFIV", 4, 57999},
	{"UNEP", 4, 58000},
	{"NEWSFLASH", 9, 58001},
	{"SPLEEN", 6, 58002},
	{"ALLOTMENT", 9, 58003},
	{"RECOMBINATION", 13, 58004},
	{"MESSING", 7, 58005},
	{"MULTIPLYING", 11, 58006},
	{"EMPRESS", 7, 58007},
	{"PRER", 4, 58008},
	{"ORBITS", 6, 58009},
	{"UPDE", 4, 58010},
	{"BUDGETED", 8, 58011},
	{"WHENCE", 6, 58012},
	{"OWIC", 4, 58013},
	{"SLOGANS", 7, 58014},
	{"LYCI", 4, 58015},
	{"ADYG", 4, 58016},
	{"FLASHBACK", 9, 58017},
	{"DKIC", 4, 58018},
	{"TRUSTING", 8, 58019},
	{"PHOTOMETRY", 10, 58020},
	{"SABRE", 5, 58021},
	{"STIGMA", 6, 58022},
	{"SUTTER", 6, 58023},
	{"EROK", 4, 58024},
	{"KNICKS", 6, 58025},
	{"HYWA", 4, 58026},
	{"USDR", 4, 58027},
	{"LIBU", 4, 58028},
	{"BYOF", 4, 58029},
	{"ABDUCTION", 9, 58030},
	{"KROA", 4, 58031},
	{"JARR", 4, 58032},
	{"INGESTION", 9, 58033},
	{"MINDSET", 7, 58034},
	{"DPHA", 4, 58035},
	{"LANM", 4, 58036},
	{"BANDA", 5, 58037},
	{"TFED", 4, 58038},
	{"ATTACHES", 8, 58039},
	{"ADULTHOOD", 9, 58040},
	{"INJECT", 6, 58041},
	{"TARTAN", 6, 58042},
	{"PROLOG", 6, 58043},
	{"TWISTING", 8, 58044},
	{"CPOW", 4, 58045},
	{"KREA", 4, 58046},
	{"DUNK", 4, 58047},
	{"GOOFY", 5, 58048},
	{"MIMIC", 5, 58049},
	{"ZWHO", 4, 58050},
	{"MCINTYRE", 8, 58051},
	{"CEUP", 4, 58052},
	{"GUILFORD", 8, 58053},
	{"DLEM", 4, 58054},
	{"OYWH", 4, 58055},
	{"SHIELDING", 9, 58056},
	{"STORMY", 6, 58057},
	{"RAGLAN", 6, 58058},
	{"PHOTONICS", 9, 58059},
	{"CDF", 3, 58060},
	{"WARL", 4, 58061},
	{"CELTICS", 7, 58062},
	{"XGAM", 4, 58063},
	{"BUTV", 4, 58064},
	{"VULGAR", 6, 58065},
	{"FVW", 3, 58066},
	{"PATHOLOGICAL", 12, 58067},
	{"IMUP", 4, 58068},
	{"MAPPINGS", 8, 58069},
	{"FIBR", 4, 58070},
	{"EBYF", 4, 58071},
	{"HODGE", 5, 58072},
	{"YIMM", 4, 58073},
	{"FASCISM", 7, 58074},
	{"CHSM", 4, 58075},
	{"GALERIAS", 8, 58076},
	{"TYAP", 4, 58077},
	{"OPAU", 4, 58078},
	{"FLIB", 4, 58079},
	{"FCUL", 4, 58080},
	{"AUDIOVISUAL", 11, 58081},
	{"ONMC", 4, 58082},
	{"DIAGNOSING", 10, 58083},
	{"EMANUEL", 7, 58084},
	{"RNDI", 4, 58085},
	{"SERENE", 6, 58086},
	{"LPWI", 4, 58087},
	{"KUPO", 4, 58088},
	{"NEUTRINO", 8, 58089},
	{"OBLIGATORY", 10, 58090},
	{"WNWE", 4, 58091},
	{"SKYW", 4, 58092},
	{"WOULDNT", 7, 58093},
	{"IGNR", 4, 58094},
	{"ERJI", 4, 58095},
	{"CODECS", 6, 58096},
	{"CORRUGATED", 10, 58097},
	{"QUEENSTOWN", 10, 58098},
	{"CERTIFYING", 10, 58099},
	{"AFFM", 4, 58100},
	{"DVP", 3, 58101},
	{"UNHEALTHY", 9, 58102},
	{"FELICITY", 8, 58103},
	{"TRADUZCA", 8, 58104},
	{"MAYG", 4, 58105},
	{"HOPW", 4, 58106},
	{"EMEF", 4, 58107},
	{"ULKO", 4, 58108},
	{"CTWE", 4, 58109},
	{"SUBJ", 4, 58110},
	{"ASYMPTOTIC", 10, 58111},
	{"TICKS", 5, 58112},
	{"UNBU", 4, 58113},
	{"GBIR", 4, 58114},
	{"ROWM", 4, 58115},
	{"FASCINATION", 11, 58116},
	{"SOBU", 4, 58117},
	{"ISOTOPE", 7, 58118},
	{"MOBLOG", 6, 58119},
	{"LOCALES", 7, 58120},
	{"EXPERIMENTING", 13, 58121},
	{"NBEV", 4, 58122},
	{"PREVENTATIVE", 12, 58123},
	{"SDAD", 4, 58124},
	{"OGOU", 4, 58125},
	{"SPLENDOR", 8, 58126},
	{"VIGIL", 5, 58127},
	{"ROBBED", 6, 58128},
	{"BRAMPTON", 8, 58129},
	{"TEMPERATE", 9, 58130},
	{"UGUY", 4, 58131},
	{"CHDR", 4, 58132},
	{"ICCU", 4, 58133},
	{"FURB", 4, 58134},
	{"RYET", 4, 58135},
	{"RENL", 4, 58136},
	{"FSUN", 4, 58137},
	{"EPFO", 4, 58138},
	{"MEIER", 5, 58139},
	{"CRORE", 5, 58140},
	{"REBIRTH", 7, 58141},
	{"RUGT", 4, 58142},
	{"WINONA", 6, 58143},
	{"LTYS", 4, 58144},
	{"CABU", 4, 58145},
	{"PROGRESSING", 11, 58146},
	{"FRAGRANT", 8, 58147},
	{"TPLU", 4, 58148},
	{"RKLO", 4, 58149},
	{"QUEF", 4, 58150},
	{"KEYM", 4, 58151},
	{"DALF", 4, 58152},
	{"DESERVING", 9, 58153},
	{"LSGO", 4, 58154},
	{"BANCO", 5, 58155},
	{"DIAGNOSES", 9, 58156},
	{"EWAP", 4, 58157},
	{"CHFL", 4, 58158},
	{"DEFEATING", 9, 58159},
	{"THERMALTAKE", 11, 58160},
	{"ULTRACET", 8, 58161},
	{"ANFU", 4, 58162},
	{"CORTICAL", 8, 58163},
	{"HOTTER", 6, 58164},
	{"ITCHY", 5, 58165},
	{"ECHW", 4, 58166},
	{"CITL", 4, 58167},
	{"INSTANTANEOUS", 13, 58168},
	{"OPERATIVES", 10, 58169},
	{"CARMICHAEL", 10, 58170},
	{"BULKY", 5, 58171},
	{"YDAD", 4, 58172},
	{"AROP", 4, 58173},
	{"EXPONENT", 8, 58174},
	{"DESPERATION", 11, 58175},
	{"GLAUCOMA", 8, 58176},
	{"UESM", 4, 58177},
	{"KYTO", 4, 58178},
	{"WYSIWYG", 7, 58179},
	{"OVERSEES", 8, 58180},
	{"PARLOR", 6, 58181},
	{"SETTER", 6, 58182},
	{"CATEGORISED", 11, 58183},
	{"THELIST", 7, 58184},
	{"YCIR", 4, 58185},
	{"MONUMENTAL", 10, 58186},
	{"OLAF", 4, 58187},
	{"YGON", 4, 58188},
	{"DIAMONDBACKS", 12, 58189},
	{"IGIL", 4, 58190},
	{"ARSQ", 4, 58191},
	{"SMFO", 4, 58192},
	{"MTHU", 4, 58193},
	{"GAWI", 4, 58194},
	{"STIRRED", 7, 58195},
	{"SBYI", 4, 58196},
	{"SUBTYPE", 7, 58197},
	{"OIMM", 4, 58198},
	{"TOUGHEST", 8, 58199},
	{"TOGL", 4, 58200},
	{"GFAS", 4, 58201},
	{"EECL", 4, 58202},
	{"FACADE", 6, 58203},
	{"ODEG", 4, 58204},
	{"FRANKFORT", 9, 58205},
	{"THESSALONIKI", 12, 58206},
	{"MONOGRAPH", 9, 58207},
	{"INKR", 4, 58208},
	{"DMV", 3, 58209},
	{"LEAFSTAFF", 9, 58210},
	{"LITERATE", 8, 58211},
	{"TRYN", 4, 58212},
	{"PMAR", 4, 58213},
	{"BOOZE", 5, 58214},
	{"KBYT", 4, 58215},
	{"LBOY", 4, 58216},
	{"WIDEN", 5, 58217},
	{"LEDK", 4, 58218},
	{"BIKERS", 6, 58219},
	{"HARCOURT", 8, 58220},
	{"KSFI", 4, 58221},
	{"BUBBA", 5, 58222},
	{"POFB", 4, 58223},
	{"CKDA", 4, 58224},
	{"MUTT", 4, 58225},
	{"ADJECTIVE", 9, 58226},
	{"NCYD", 4, 58227},
	{"DISCIPLE", 8, 58228},
	{"CIPHER", 6, 58229},
	{"ORWELL", 6, 58230},
	{"MIETWAGEN", 9, 58231},
	{"ARREARS", 7, 58232},
	{"IGHQ", 4, 58233},
	{"RHYTHMIC", 8, 58234},
	{"UNAFFECTED", 10, 58235},
	{"GLEL", 4, 58236},
	{"BAKEWARE", 8, 58237},
	{"STARVING", 8, 58238},
	{"LFPR", 4, 58239},
	{"VIDE", 4, 58240},
	{"ELLJ", 4, 58241},
	{"CLEANSER", 8, 58242},
	{"LENNOX", 6, 58243},
	{"HEARTY", 6, 58244},
	{"LONSDALE", 8, 58245},
	{"TRITON", 6, 58246},
	{"DEUS", 4, 58247},
	{"RSOW", 4, 58248},
	{"VELOCITIES", 10, 58249},
	{"DNAR", 4, 58250},
	{"DEVINE", 6, 58251},
	{"RENEWALS", 8, 58252},
	{"KONL", 4, 58253},
	{"ADORE", 5, 58254},
	{"ENTERTAINER", 11, 58255},
	{"RSFL", 4, 58256},
	{"ODPE", 4, 58257},
	{"UEAL", 4, 58258},
	{"KLYR", 4, 58259},
	{"RJV", 3, 58260},
	{"COLDS", 5, 58261},
	{"TBOY", 4, 58262},
	{"RLYK", 4, 58263},
	{"IXTY", 4, 58264},
	{"FVOL", 4, 58265},
	{"DEPENDANT", 9, 58266},
	{"ARKG", 4, 58267},
	{"THICKER", 7, 58268},
	{"YALF", 4, 58269},
	{"WEEPING", 7, 58270},
	{"OFMR", 4, 58271},
	{"SALFORD", 7, 58272},
	{"EPHEDRINE", 9, 58273},
	{"LONGVIEW", 8, 58274},
	{"FCOO", 4, 58275},
	{"CLOSEUP", 7, 58276},
	{"VSER", 4, 58277},
	{"NCHD", 4, 58278},
	{"CHVE", 4, 58279},
	{"VENOUS", 6, 58280},
	{"HAGU", 4, 58281},
	{"BRIB", 4, 58282},
	{"ROCU", 4, 58283},
	{"ENDJ", 4, 58284},
	{"HEREUNDER", 9, 58285},
	{"CHANDELIERS", 11, 58286},
	{"MONEYS", 6, 58287},
	{"RCOD", 4, 58288},
	{"FPIT", 4, 58289},
	{"OPWH", 4, 58290},
	{"FICF", 4, 58291},
	{"OUCH", 4, 58292},
	{"INFANCY", 7, 58293},
	{"TEFLON", 6, 58294},
	{"DEBADMIN", 8, 58295},
	{"CLEANS", 6, 58296},
	{"DIPS", 4, 58297},
	{"HONOURED", 8, 58298},
	{"YACHTING", 8, 58299},
	{"RLSO", 4, 58300},
	{"IDYE", 4, 58301},
	{"CLEANSE", 7, 58302},
	{"FPGA", 4, 58303},
	{"HYCA", 4, 58304},
	{"GGIR", 4, 58305},
	{"CUPO", 4, 58306},
	{"EDKN", 4, 58307},
	{"CHILLY", 6, 58308},
	{"EVERTON", 7, 58309},
	{"ROSTERS", 7, 58310},
	{"HERBICIDE", 9, 58311},
	{"FYAN", 4, 58312},
	{"DIGS", 4, 58313},
	{"BOLIVAR", 7, 58314},
	{"MARLENE", 7, 58315},
	{"WOMB", 4, 58316},
	{"ZEDE", 4, 58317},
	{"IRRITATING", 10, 58318},
	{"MONARCHY", 8, 58319},
	{"FUTURA", 6, 58320},
	{"MHOL", 4, 58321},
	{"PAYP", 4, 58322},
	{"GBYA", 4, 58323},
	{"CHEDDAR", 7, 58324},
	{"CORSET", 6, 58325},
	{"HINGED", 6, 58326},
	{"FPUR", 4, 58327},
	{"DURB", 4, 58328},
	{"TUCOWS", 6, 58329},
	{"GSEL", 4, 58330},
	{"GEAF", 4, 58331},
	{"HAMR", 4, 58332},
	{"REGEX", 5, 58333},
	{"BUKAKE", 6, 58334},
	{"TSBL", 4, 58335},
	{"MCHE", 4, 58336},
	{"LPEA", 4, 58337},
	{"MCCLELLAN", 9, 58338},
	{"NKIC", 4, 58339},
	{"CAWH", 4, 58340},
	{"ATTENDANTS", 10, 58341},
	{"FCLU", 4, 58342},
	{"GOPHER", 6, 58343},
	{"DISTAL", 6, 58344},
	{"FJES", 4, 58345},
	{"GCLI", 4, 58346},
	{"DLYN", 4, 58347},
	{"FROMMER", 7, 58348},
	{"ROBINS", 6, 58349},
	{"YABR", 4, 58350},
	{"OBAY", 4, 58351},
	{"BOOMING", 7, 58352},
	{"KEGR", 4, 58353},
	{"ARTIKEL", 7, 58354},
	{"RUEI", 4, 58355},
	{"SHORTFALL", 9, 58356},
	{"SCANDALS", 8, 58357},
	{"SCREAMED", 8, 58358},
	{"HARMONICA", 9, 58359},
	{"CRAMPS", 6, 58360},
	{"ADGU", 4, 58361},
	{"GEOTHERMAL", 10, 58362},
	{"TEXMF", 5, 58363},
	{"ATLASES", 7, 58364},
	{"KOHL", 4, 58365},
	{"BUMB", 4, 58366},
	{"HERRERA", 7, 58367},
	{"FDIV", 4, 58368},
	{"DIGGER", 6, 58369},
	{"LORAZEPAM", 9, 58370},
	{"LEWISTON", 8, 58371},
	{"YPIT", 4, 58372},
	{"STOWE", 5, 58373},
	{"LRK", 3, 58374},
	{"KCV", 3, 58375},
	{"WEDP", 4, 58376},
	{"GISR", 4, 58377},
	{"LSEY", 4, 58378},
	{"FLUKE", 5, 58379},
	{"XTME", 4, 58380},
	{"ESPIONAGE", 9, 58381},
	{"UTSF", 4, 58382},
	{"RIZI", 4, 58383},
	{"ERTG", 4, 58384},
	{"PUPS", 4, 58385},
	{"OGAL", 4, 58386},
	{"AVENGED", 7, 58387},
	{"CACHES", 6, 58388},
	{"UTQU", 4, 58389},
	{"STOMP", 5, 58390},
	{"NORTE", 5, 58391},
	{"GLADE", 5, 58392},
	{"ACIDIC", 6, 58393},
	{"ASYF", 4, 58394},
	{"PENDULUM", 8, 58395},
	{"GANGSTER", 8, 58396},
	{"DELIVERABLES", 12, 58397},
	{"BOUNCES", 7, 58398},
	{"URTY", 4, 58399},
	{"CENSORED", 8, 58400},
	{"FASCIST", 7, 58401},
	{"NEHEMIAH", 8, 58402},
	{"LIDO", 4, 58403},
	{"WINP", 4, 58404},
	{"MATCHBOX", 8, 58405},
	{"CONW", 4, 58406},
	{"LAWC", 4, 58407},
	{"THINNER", 7, 58408},
	{"VETU", 4, 58409},
	{"LICKS", 5, 58410},
	{"CASTE", 5, 58411},
	{"WEUS", 4, 58412},
	{"TEBL", 4, 58413},
	{"BUSINESSMEN", 11, 58414},
	{"RNSU", 4, 58415},
	{"UTOG", 4, 58416},
	{"IRDM", 4, 58417},
	{"DAFT", 4, 58418},
	{"SAMPSON", 7, 58419},
	{"INCUBATOR", 9, 58420},
	{"YREE", 4, 58421},
	{"EXPERIENTIAL", 12, 58422},
	{"PSYCHE", 6, 58423},
	{"HGAR", 4, 58424},
	{"FDOW", 4, 58425},
	{"ERASER", 6, 58426},
	{"RUDOLF", 6, 58427},
	{"NDIB", 4, 58428},
	{"ANGLING", 7, 58429},
	{"JORDANIAN", 9, 58430},
	{"NOQU", 4, 58431},
	{"JIWIRE", 6, 58432},
	{"LIBRA", 5, 58433},
	{"HFAR", 4, 58434},
	{"DCAB", 4, 58435},
	{"ZGM", 3, 58436},
	{"YWF", 3, 58437},
	{"YKV", 3, 58438},
	{"STUBBORN", 8, 58439},
	{"EKBE", 4, 58440},
	{"DIPLOMATS", 9, 58441},
	{"YMOO", 4, 58442},
	{"PHYSICIST", 9, 58443},
	{"TAGALOG", 7, 58444},
	{"LIPT", 4, 58445},
	{"UNIPROT", 7, 58446},
	{"REQUIEM", 7, 58447},
	{"TWOK", 4, 58448},
	{"MSLA", 4, 58449},
	{"EIMB", 4, 58450},
	{"STATYSTYKI", 10, 58451},
	{"URSF", 4, 58452},
	{"PKGSRC", 6, 58453},
	{"NONPROFITS", 10, 58454},
	{"DESNUDOS", 8, 58455},
	{"BLEU", 4, 58456},
	{"REDEEMED", 8, 58457},
	{"CZK", 3, 58458},
	{"CYWH", 4, 58459},
	{"SIGHED", 6, 58460},
	{"VALH", 4, 58461},
	{"SRAL", 4, 58462},
	{"LURES", 5, 58463},
	{"LWON", 4, 58464},
	{"AKAB", 4, 58465},
	{"ETHYLENE", 8, 58466},
	{"TYEV", 4, 58467},
	{"SLOWS", 5, 58468},
	{"FITD", 4, 58469},
	{"DIXO", 4, 58470},
	{"FUPT", 4, 58471},
	{"INHIBITS", 8, 58472},
	{"BAVARIA", 7, 58473},
	{"DEVASTATION", 11, 58474},
	{"EXPLORATORY", 11, 58475},
	{"RBYH", 4, 58476},
	{"NMYH", 4, 58477},
	{"EMIK", 4, 58478},
	{"SPECTROMETER", 12, 58479},
	{"HEROINE", 7, 58480},
	{"BINGHAM", 7, 58481},
	{"ULWA", 4, 58482},
	{"EDEU", 4, 58483},
	{"ACHILLES", 8, 58484},
	{"OUTSOLE", 7, 58485},
	{"LISTA", 5, 58486},
	{"FLAPS", 5, 58487},
	{"ADGI", 4, 58488},
	{"INDIFFERENT", 11, 58489},
	{"POLYNOMIALS", 11, 58490},
	{"CADENCE", 7, 58491},
	{"FROSTED", 7, 58492},
	{"SCHUBERT", 8, 58493},
	{"WANC", 4, 58494},
	{"MWAL", 4, 58495},
	{"RHINE", 5, 58496},
	{"MANIFESTED", 10, 58497},
	{"ELEGANS", 7, 58498},
	{"DENOMINATIONS", 13, 58499},
	{"INTERRUPTS", 10, 58500},
	{"DMOO", 4, 58501},
	{"TPUL", 4, 58502},
	{"OPENERS", 7, 58503},
	{"LORH", 4, 58504},
	{"RATTLE", 6, 58505},
	{"YPJ", 3, 58506},
	{"FJJ", 3, 58507},
	{"TOPG", 4, 58508},
	{"SHASTA", 6, 58509},
	{"ZZLI", 4, 58510},
	{"RBRU", 4, 58511},
	{"INSULTS", 7, 58512},
	{"OATMEAL", 7, 58513},
	{"YLIE", 4, 58514},
	{"NSRU", 4, 58515},
	{"ARLH", 4, 58516},
	{"FALLON", 6, 58517},
	{"MARTA", 5, 58518},
	{"HMIK", 4, 58519},
	{"FWEC", 4, 58520},
	{"DISTILLED", 9, 58521},
	{"STRICKEN", 8, 58522},
	{"SIDEKICK", 8, 58523},
	{"IRQU", 4, 58524},
	{"SSPU", 4, 58525},
	{"HAMU", 4, 58526},
	{"OTUP", 4, 58527},
	{"DMCA", 4, 58528},
	{"REWRITING", 9, 58529},
	{"BAHAMA", 6, 58530},
	{"UNREST", 6, 58531},
	{"MENP", 4, 58532},
	{"OWPL", 4, 58533},
	{"EXAG", 4, 58534},
	{"LORETTA", 7, 58535},
	{"CASCADES", 8, 58536},
	{"DRUID", 5, 58537},
	{"DUNBAR", 6, 58538},
	{"LINGVOSOFT", 10, 58539},
	{"ABSTINENCE", 10, 58540},
	{"ALLOCATING", 10, 58541},
	{"YPAN", 4, 58542},
	{"LOAL", 4, 58543},
	{"AKAW", 4, 58544},
	{"NEWELL", 6, 58545},
	{"JUVENILES", 9, 58546},
	{"GAMERMETRICS", 12, 58547},
	{"POODLE", 6, 58548},
	{"WEMI", 4, 58549},
	{"ULON", 4, 58550},
	{"WUNDER", 6, 58551},
	{"LUSC", 4, 58552},
	{"BEFE", 4, 58553},
	{"STEFANO", 7, 58554},
	{"PALT", 4, 58555},
	{"LCDS", 4, 58556},
	{"PICG", 4, 58557},
	{"HLER", 4, 58558},
	{"BYPH", 4, 58559},
	{"TPUN", 4, 58560},
	{"LJOH", 4, 58561},
	{"SITTER", 6, 58562},
	{"RHUR", 4, 58563},
	{"IEBU", 4, 58564},
	{"ORTHOLOG", 8, 58565},
	{"COLDER", 6, 58566},
	{"LABORERS", 8, 58567},
	{"TASMANIAN", 9, 58568},
	{"MOFL", 4, 58569},
	{"MBOR", 4, 58570},
	{"HYDROCARBON", 11, 58571},
	{"LOBBYIST", 8, 58572},
	{"ERHY", 4, 58573},
	{"ELFM", 4, 58574},
	{"CKCL", 4, 58575},
	{"KELVIN", 6, 58576},
	{"DZV", 3, 58577},
	{"DKEY", 4, 58578},
	{"WHISPERS", 8, 58579},
	{"FDEB", 4, 58580},
	{"SECONDHAND", 10, 58581},
	{"ETCU", 4, 58582},
	{"SWARM", 5, 58583},
	{"RNAG", 4, 58584},
	{"ELISE", 5, 58585},
	{"CHEATSCODESGUIDES", 17, 58586},
	{"KRAT", 4, 58587},
	{"CLEG", 4, 58588},
	{"MDL", 3, 58589},
	{"CLIENTELE", 9, 58590},
	{"VIDL", 4, 58591},
	{"REOL", 4, 58592},
	{"LEDGE", 5, 58593},
	{"WINTHROP", 8, 58594},
	{"TECHNICA", 8, 58595},
	{"GRATUITO", 8, 58596},
	{"IDJU", 4, 58597},
	{"ALKN", 4, 58598},
	{"HISTORIA", 8, 58599},
	{"PEASANTS", 8, 58600},
	{"NECTAR", 6, 58601},
	{"ARKON", 5, 58602},
	{"ANECDOTES", 9, 58603},
	{"KEMU", 4, 58604},
	{"WBER", 4, 58605},
	{"GHCH", 4, 58606},
	{"EKWA", 4, 58607},
	{"BUREAUCRATIC", 12, 58608},
	{"GILT", 4, 58609},
	{"TILJ", 4, 58610},
	{"RICF", 4, 58611},
	{"OFHY", 4, 58612},
	{"NEUM", 4, 58613},
	{"ACDO", 4, 58614},
	{"MASTERPIECES", 12, 58615},
	{"COOPERATIVES", 12, 58616},
	{"RACEWAY", 7, 58617},
	{"SOPRANOS", 8, 58618},
	{"CKRI", 4, 58619},
	{"SYMBOLISM", 9, 58620},
	{"MONSOON", 7, 58621},
	{"HOTTIES", 7, 58622},
	{"TERRELL", 7, 58623},
	{"XEDI", 4, 58624},
	{"KOWS", 4, 58625},
	{"CLOSINGS", 8, 58626},
	{"REGISTRARS", 10, 58627},
	{"FGAS", 4, 58628},
	{"STRLEN", 6, 58629},
	{"STRIFE", 6, 58630},
	{"ESPRIT", 6, 58631},
	{"FAYE", 4, 58632},
	{"ATTAINING", 9, 58633},
	{"UNTC", 4, 58634},
	{"LLYY", 4, 58635},
	{"LAKEVIEW", 8, 58636},
	{"ILSU", 4, 58637},
	{"CONSULAR", 8, 58638},
	{"OSPF", 4, 58639},
	{"TUNNELING", 9, 58640},
	{"YSHU", 4, 58641},
	{"TREASON", 7, 58642},
	{"RECKON", 6, 58643},
	{"GASTON", 6, 58644},
	{"PROSPER", 7, 58645},
	{"NAPIER", 6, 58646},
	{"TAFU", 4, 58647},
	{"MFES", 4, 58648},
	{"FINJ", 4, 58649},
	{"METHAMPHETAMINE", 15, 58650},
	{"SUPREMACY", 9, 58651},
	{"MURALS", 6, 58652},
	{"NWEC", 4, 58653},
	{"MAFA", 4, 58654},
	{"BBUT", 4, 58655},
	{"CAPILLARY", 9, 58656},
	{"GYPR", 4, 58657},
	{"GERMAIN", 7, 58658},
	{"ISLINGTON", 9, 58659},
	{"BANGS", 5, 58660},
	{"KNOCKOUT", 8, 58661},
	{"RADON", 5, 58662},
	{"RSAU", 4, 58663},
	{"MSFA", 4, 58664},
	{"AVANTGO", 7, 58665},
	{"UROU", 4, 58666},
	{"ANCHORED", 8, 58667},
	{"YONG", 4, 58668},
	{"VERS", 4, 58669},
	{"MULBERRY", 8, 58670},
	{"SINFUL", 6, 58671},
	{"USHC", 4, 58672},
	{"UEOR", 4, 58673},
	{"GPHO", 4, 58674},
	{"CHEESES", 7, 58675},
	{"FEWF", 4, 58676},
	{"BRADSHAW", 8, 58677},
	{"TIMELINES", 9, 58678},
	{"WEFE", 4, 58679},
	{"MYTHICAL", 8, 58680},
	{"ANKP", 4, 58681},
	{"ABYSS", 5, 58682},
	{"ROGET", 5, 58683},
	{"NRAM", 4, 58684},
	{"BOWI", 4, 58685},
	{"CRISTINA", 8, 58686},
	{"VISIO", 5, 58687},
	{"SYFO", 4, 58688},
	{"DORL", 4, 58689},
	{"WHITEHALL", 9, 58690},
	{"MALACHI", 7, 58691},
	{"TMUL", 4, 58692},
	{"AUTOIMMUNE", 10, 58693},
	{"CODER", 5, 58694},
	{"REPLICATED", 10, 58695},
	{"FULG", 4, 58696},
	{"EWVE", 4, 58697},
	{"TIMETABLES", 10, 58698},
	{"WUPT", 4, 58699},
	{"KLINE", 5, 58700},
	{"RCQ", 3, 58701},
	{"GXB", 3, 58702},
	{"ANOREXIA", 8, 58703},
	{"LSCL", 4, 58704},
	{"AKUR", 4, 58705},
	{"ERRNO", 5, 58706},
	{"TLEU", 4, 58707},
	{"RAWT", 4, 58708},
	{"GEPI", 4, 58709},
	{"ILFI", 4, 58710},
	{"GATM", 4, 58711},
	{"CLIPPING", 8, 58712},
	{"WORKPLACES", 10, 58713},
	{"YDEE", 4, 58714},
	{"NIECE", 5, 58715},
	{"IRRESPONSIBLE", 13, 58716},
	{"HARPERCOLLINS", 13, 58717},
	{"KEXC", 4, 58718},
	{"PLEAS", 5, 58719},
	{"SOFTER", 6, 58720},
	{"ULTP", 4, 58721},
	{"SGUE", 4, 58722},
	{"CLK", 3, 58723},
	{"PARALYSIS", 9, 58724},
	{"HEARTBURN", 9, 58725},
	{"DEVASTATED", 10, 58726},
	{"EMPATHY", 7, 58727},
	{"TARZAN", 6, 58728},
	{"MOTIVATING", 10, 58729},
	{"CLOCKWISE", 9, 58730},
	{"UNPL", 4, 58731},
	{"OMOP", 4, 58732},
	{"LFUR", 4, 58733},
	{"SHUTTERS", 8, 58734},
	{"OVEU", 4, 58735},
	{"CHIF", 4, 58736},
	{"FLASK", 5, 58737},
	{"ARISEN", 6, 58738},
	{"NKLY", 4, 58739},
	{"CALJ", 4, 58740},
	{"FEMMES", 6, 58741},
	{"XCOU", 4, 58742},
	{"RVID", 4, 58743},
	{"RELENTLESS", 10, 58744},
	{"RIBBED", 6, 58745},
	{"OMNIBUS", 7, 58746},
	{"STABLES", 7, 58747},
	{"FRISCO", 6, 58748},
	{"KLAT", 4, 58749},
	{"FDOI", 4, 58750},
	{"INHABITED", 9, 58751},
	{"HEREOF", 6, 58752},
	{"UNTOLD", 6, 58753},
	{"WNBO", 4, 58754},
	{"RLSC", 4, 58755},
	{"GOTC", 4, 58756},
	{"OBSERVABLE", 10, 58757},
	{"MITZVAH", 7, 58758},
	{"GRETCHEN", 8, 58759},
	{"CHONG", 5, 58760},
	{"LANTERNS", 8, 58761},
	{"BAMB", 4, 58762},
	{"ANGC", 4, 58763},
	{"TULIPS", 6, 58764},
	{"RSUG", 4, 58765},
	{"LEMF", 4, 58766},
	{"ECTY", 4, 58767},
	{"BASHING", 7, 58768},
	{"BOOSTERS", 8, 58769},
	{"NKRE", 4, 58770},
	{"GHYO", 4, 58771},
	{"CYL", 3, 58772},
	{"UGHV", 4, 58773},
	{"FPHY", 4, 58774},
	{"VIGOROUSLY", 10, 58775},
	{"INTERFERING", 11, 58776},
	{"KETD", 4, 58777},
	{"RASF", 4, 58778},
	{"QGR", 3, 58779},
	{"KVW", 3, 58780},
	{"GRUPO", 5, 58781},
	{"UESU", 4, 58782},
	{"HROB", 4, 58783},
	{"IDOLS", 5, 58784},
	{"DESIGNATING", 11, 58785},
	{"MIKHAIL", 7, 58786},
	{"UGEI", 4, 58787},
	{"KHAV", 4, 58788},
	{"DJEW", 4, 58789},
	{"DENOMINATOR", 11, 58790},
	{"BYOR", 4, 58791},
	{"KSUN", 4, 58792},
	{"ARSK", 4, 58793},
	{"MASR", 4, 58794},
	{"HVOL", 4, 58795},
	{"GORC", 4, 58796},
	{"NUGGET", 6, 58797},
	{"REMINDING", 9, 58798},
	{"GUSTS", 5, 58799},
	{"USRI", 4, 58800},
	{"CHANGESET", 9, 58801},
	{"XVIII", 5, 58802},
	{"JOVENCITAS", 10, 58803},
	{"TEXTTT", 6, 58804},
	{"ISLAMABAD", 9, 58805},
	{"MAGISTRATES", 11, 58806},
	{"DBOW", 4, 58807},
	{"FREESTANDING", 12, 58808},
	{"JOYC", 4, 58809},
	{"RESILIENT", 9, 58810},
	{"PROCESSION", 10, 58811},
	{"EYEWITNESS", 10, 58812},
	{"WGRO", 4, 58813},
	{"ULWI", 4, 58814},
	{"SPIRITUALLY", 11, 58815},
	{"RMUN", 4, 58816},
	{"SPARTANBURG", 11, 58817},
	{"ULPE", 4, 58818},
	{"HIPPO", 5, 58819},
	{"TRUNG", 5, 58820},
	{"TENANCY", 7, 58821},
	{"ATTENTIVE", 9, 58822},
	{"RUPTURE", 7, 58823},
	{"NOFY", 4, 58824},
	{"TRAD", 4, 58825},
	{"ASSIMILATION", 12, 58826},
	{"TFLE", 4, 58827},
	{"SDUT", 4, 58828},
	{"LYRICAL", 7, 58829},
	{"IMWO", 4, 58830},
	{"EWGE", 4, 58831},
	{"OFFSITE", 7, 58832},
	{"REALAUDIO", 9, 58833},
	{"CLEMENTS", 8, 58834},
	{"MOFG", 4, 58835},
	{"ICVE", 4, 58836},
	{"CONCORDE", 8, 58837},
	{"EERD", 4, 58838},
	{"ANGELICA", 8, 58839},
	{"BRAIDED", 7, 58840},
	{"TICKETING", 9, 58841},
	{"HETEROGENEITY", 13, 58842},
	{"GICT", 4, 58843},
	{"WOODED", 6, 58844},
	{"BODIED", 6, 58845},
	{"IBBL", 4, 58846},
	{"INTENSELY", 9, 58847},
	{"DUDES", 5, 58848},
	{"MAYTAG", 6, 58849},
	{"AIDU", 4, 58850},
	{"NORCO", 5, 58851},
	{"GHBA", 4, 58852},
	{"ALTOS", 5, 58853},
	{"RDEG", 4, 58854},
	{"HCER", 4, 58855},
	{"EFTM", 4, 58856},
	{"SLEEVED", 7, 58857},
	{"OVERS", 5, 58858},
	{"WATERCRAFT", 10, 58859},
	{"PROPELLED", 9, 58860},
	{"RIOW", 4, 58861},
	{"ARTISANS", 8, 58862},
	{"BASTARDS", 8, 58863},
	{"BASSETT", 7, 58864},
	{"GLID", 4, 58865},
	{"ASPIRATION", 10, 58866},
	{"APPENDED", 8, 58867},
	{"SCULLY", 6, 58868},
	{"CELLULOSE", 9, 58869},
	{"CATHODE", 7, 58870},
	{"MONOGRAPHS", 10, 58871},
	{"SDOR", 4, 58872},
	{"LUBC", 4, 58873},
	{"EBYL", 4, 58874},
	{"SLAMMED", 7, 58875},
	{"AVIATOR", 7, 58876},
	{"IMPLICATED", 10, 58877},
	{"SERIOUSNESS", 11, 58878},
	{"LEDY", 4, 58879},
	{"CONFORMATION", 12, 58880},
	{"GEWB", 4, 58881},
	{"UNLA", 4, 58882},
	{"TAYW", 4, 58883},
	{"INTIMIDATION", 12, 58884},
	{"NUPF", 4, 58885},
	{"UQUE", 4, 58886},
	{"PALADIN", 7, 58887},
	{"CIVILIZED", 9, 58888},
	{"MARCHED", 7, 58889},
	{"BYYO", 4, 58890},
	{"EKLA", 4, 58891},
	{"DORH", 4, 58892},
	{"AYJA", 4, 58893},
	{"DIGITIZED", 9, 58894},
	{"ROTATED", 7, 58895},
	{"TGIR", 4, 58896},
	{"IDEK", 4, 58897},
	{"MOTOWN", 6, 58898},
	{"MWON", 4, 58899},
	{"IPEG", 4, 58900},
	{"EGGA", 4, 58901},
	{"VZQ", 3, 58902},
	{"CASSANDRA", 9, 58903},
	{"PRYOR", 5, 58904},
	{"POCR", 4, 58905},
	{"LOFY", 4, 58906},
	{"SUSW", 4, 58907},
	{"OWSY", 4, 58908},
	{"GREELEY", 7, 58909},
	{"FOBA", 4, 58910},
	{"CCR", 3, 58911},
	{"UPAP", 4, 58912},
	{"AOFC", 4, 58913},
	{"SIGHTED", 7, 58914},
	{"LDKN", 4, 58915},
	{"IMUN", 4, 58916},
	{"PLYR", 4, 58917},
	{"AGRO", 4, 58918},
	{"HOPPING", 7, 58919},
	{"RAMOS", 5, 58920},
	{"QUIZILLA", 8, 58921},
	{"DESTIN", 6, 58922},
	{"CITIBANK", 8, 58923},
	{"TADR", 4, 58924},
	{"ROSARY", 6, 58925},
	{"SCOTTY", 6, 58926},
	{"VEWR", 4, 58927},
	{"IQUO", 4, 58928},
	{"PVP", 3, 58929},
	{"UNEB", 4, 58930},
	{"TAGU", 4, 58931},
	{"NBAG", 4, 58932},
	{"PLATOON", 7, 58933},
	{"MERIDIEN", 8, 58934},
	{"BRUNETTES", 9, 58935},
	{"CUNN", 4, 58936},
	{"ANDRES", 6, 58937},
	{"KENM", 4, 58938},
	{"LONELINESS", 10, 58939},
	{"PULLEY", 6, 58940},
	{"TPMO", 4, 58941},
	{"LDKE", 4, 58942},
	{"FFLU", 4, 58943},
	{"BSUR", 4, 58944},
	{"ALLEGING", 8, 58945},
	{"UNHELPFUL", 9, 58946},
	{"UNKO", 4, 58947},
	{"SYNONYMOUS", 10, 58948},
	{"CONFECTIONERY", 13, 58949},
	{"TYPH", 4, 58950},
	{"NELM", 4, 58951},
	{"REGRETS", 7, 58952},
	{"CONSCIOUSLY", 11, 58953},
	{"XITY", 4, 58954},
	{"RORH", 4, 58955},
	{"MICROORGANISMS", 14, 58956},
	{"COURS", 5, 58957},
	{"GMAK", 4, 58958},
	{"XMW", 3, 58959},
	{"KKF", 3, 58960},
	{"TWISTER", 7, 58961},
	{"FOOTPRINTS", 10, 58962},
	{"KRAKOW", 6, 58963},
	{"GEAD", 4, 58964},
	{"SEQUOIA", 7, 58965},
	{"ACTIVATOR", 9, 58966},
	{"VIDW", 4, 58967},
	{"PRISCILLA", 9, 58968},
	{"INCREDIBLES", 11, 58969},
	{"FAMILIAL", 8, 58970},
	{"STIMULATES", 10, 58971},
	{"MARQUEE", 7, 58972},
	{"DARKEST", 7, 58973},
	{"GDEL", 4, 58974},
	{"DTWE", 4, 58975},
	{"IMPLYING", 8, 58976},
	{"CONDUCIVE", 9, 58977},
	{"RESILIENCE", 10, 58978},
	{"RCUP", 4, 58979},
	{"THERMODYNAMICS", 14, 58980},
	{"UNCONTROLLED", 12, 58981},
	{"ULCH", 4, 58982},
	{"MYLE", 4, 58983},
	{"LKEN", 4, 58984},
	{"BALLADS", 7, 58985},
	{"MAKITA", 6, 58986},
	{"SUBGROUPS", 9, 58987},
	{"CATCHY", 6, 58988},
	{"MATHEW", 6, 58989},
	{"SYNAPTIC", 8, 58990},
	{"HUGELY", 6, 58991},
	{"BOBCATS", 7, 58992},
	{"SEVILLA", 7, 58993},
	{"ZAPPA", 5, 58994},
	{"OLSU", 4, 58995},
	{"MESJ", 4, 58996},
	{"HOSTAGES", 8, 58997},
	{"CHICAS", 6, 58998},
	{"ALYP", 4, 58999},
	{"SWAHILI", 7, 59000},
	{"CROU", 4, 59001},
	{"ROSARIO", 7, 59002},
	{"DZWONKI", 7, 59003},
	{"ENROLLING", 9, 59004},
	{"RFEM", 4, 59005},
	{"FRUITFUL", 8, 59006},
	{"FRANKS", 6, 59007},
	{"COMMERCIALIZATION", 17, 59008},
	{"KISC", 4, 59009},
	{"OFEQ", 4, 59010},
	{"FTUN", 4, 59011},
	{"INDEMNIFY", 9, 59012},
	{"SATISFACTORILY", 14, 59013},
	{"THINKER", 7, 59014},
	{"DOVA", 4, 59015},
	{"CONTESTANTS", 11, 59016},
	{"PTRE", 4, 59017},
	{"OWMI", 4, 59018},
	{"MPFO", 4, 59019},
	{"CATALOGING", 10, 59020},
	{"SNOWBOARDS", 10, 59021},
	{"INFLUX", 6, 59022},
	{"CONVOY", 6, 59023},
	{"AGOP", 4, 59024},
	{"TESLA", 5, 59025},
	{"SLED", 4, 59026},
	{"OGUI", 4, 59027},
	{"DNOP", 4, 59028},
	{"MZW", 3, 59029},
	{"YWEB", 4, 59030},
	{"PYRAMIDS", 8, 59031},
	{"INGRID", 6, 59032},
	{"LONGMAN", 7, 59033},
	{"DEPENDED", 8, 59034},
	{"UNLEADED", 8, 59035},
	{"PSWA", 4, 59036},
	{"CONVEYANCE", 10, 59037},
	{"RMSB", 4, 59038},
	{"FPOT", 4, 59039},
	{"DBOS", 4, 59040},
	{"MESQUITE", 8, 59041},
	{"KRONER", 6, 59042},
	{"BYAH", 4, 59043},
	{"TORTOISE", 8, 59044},
	{"MILO", 4, 59045},
	{"RANZ", 4, 59046},
	{"CULTIVATE", 9, 59047},
	{"FRM", 3, 59048},
	{"JAVADOC", 7, 59049},
	{"HOTBOT", 6, 59050},
	{"SROY", 4, 59051},
	{"AJOK", 4, 59052},
	{"DENALI", 6, 59053},
	{"INHIBITORY", 10, 59054},
	{"LONW", 4, 59055},
	{"PHONICS", 7, 59056},
	{"URNC", 4, 59057},
	{"UNOR", 4, 59058},
	{"TPAP", 4, 59059},
	{"SKRI", 4, 59060},
	{"ICFU", 4, 59061},
	{"CROCKER", 7, 59062},
	{"REFS", 4, 59063},
	{"WPOL", 4, 59064},
	{"GICO", 4, 59065},
	{"DIALOGUES", 9, 59066},
	{"THALIANA", 8, 59067},
	{"MENINGITIS", 10, 59068},
	{"MOTIVATIONS", 11, 59069},
	{"ASTEROID", 8, 59070},
	{"DONEGAL", 7, 59071},
	{"ABOLITION", 9, 59072},
	{"COAX", 4, 59073},
	{"PADRE", 5, 59074},
	{"ENDINGS", 7, 59075},
	{"UNFR", 4, 59076},
	{"MWF", 3, 59077},
	{"UBBA", 4, 59078},
	{"NGIW", 4, 59079},
	{"GHGR", 4, 59080},
	{"GHEC", 4, 59081},
	{"UNLISTED", 8, 59082},
	{"MLAT", 4, 59083},
	{"PHILIPPIANS", 11, 59084},
	{"CONDUCTIVE", 10, 59085},
	{"OWEC", 4, 59086},
	{"ORMD", 4, 59087},
	{"MARI", 4, 59088},
	{"LFIV", 4, 59089},
	{"GSGO", 4, 59090},
	{"QUATTRO", 7, 59091},
	{"MQB", 3, 59092},
	{"ECHOSTAR", 8, 59093},
	{"FORESIGHT", 9, 59094},
	{"RICR", 4, 59095},
	{"MDEN", 4, 59096},
	{"ROWU", 4, 59097},
	{"MICROSCOPES", 11, 59098},
	{"WGEN", 4, 59099},
	{"KENMORE", 7, 59100},
	{"WEBA", 4, 59101},
	{"PEPPERMINT", 10, 59102},
	{"REAGENT", 7, 59103},
	{"MSDO", 4, 59104},
	{"CASTILLO", 8, 59105},
	{"ACHIEVABLE", 10, 59106},
	{"GANL", 4, 59107},
	{"REMNANTS", 8, 59108},
	{"LAYR", 4, 59109},
	{"KSLO", 4, 59110},
	{"ODFA", 4, 59111},
	{"BYAW", 4, 59112},
	{"GLAMOROUS", 9, 59113},
	{"INTERACTS", 9, 59114},
	{"LITCHFIELD", 10, 59115},
	{"LAVORO", 6, 59116},
	{"ROLW", 4, 59117},
	{"NAILED", 6, 59118},
	{"VESG", 4, 59119},
	{"OPSY", 4, 59120},
	{"OPMO", 4, 59121},
	{"MANV", 4, 59122},
	{"DTIG", 4, 59123},
	{"ALUM", 4, 59124},
	{"HOBBYNUTTEN", 11, 59125},
	{"CHOMSKY", 7, 59126},
	{"FRANTIC", 7, 59127},
	{"TSMY", 4, 59128},
	{"NTWR", 4, 59129},
	{"ZACHARY", 7, 59130},
	{"VENEZIA", 7, 59131},
	{"DAGU", 4, 59132},
	{"KHOW", 4, 59133},
	{"COMRADES", 8, 59134},
	{"YAMAMOTO", 8, 59135},
	{"COCOON", 6, 59136},
	{"INTERLEUKIN", 11, 59137},
	{"RLAD", 4, 59138},
	{"FLASHCARDS", 10, 59139},
	{"GLADYS", 6, 59140},
	{"INTERCEPTION", 12, 59141},
	{"VOLTAGES", 8, 59142},
	{"ASSIGNEE", 8, 59143},
	{"DSYO", 4, 59144},
	{"BOWERS", 6, 59145},
	{"STRENGTHENS", 11, 59146},
	{"ALGARVE", 7, 59147},
	{"QUAL", 4, 59148},
	{"TYOW", 4, 59149},
	{"UEGR", 4, 59150},
	{"RKSM", 4, 59151},
	{"DFRU", 4, 59152},
	{"DICTATORSHIP", 12, 59153},
	{"VALANCE", 7, 59154},
	{"BREEZY", 6, 59155},
	{"PLOW", 4, 59156},
	{"GERV", 4, 59157},
	{"PISCES", 6, 59158},
	{"OBSW", 4, 59159},
	{"CKAC", 4, 59160},
	{"CPANEL", 6, 59161},
	{"LTBE", 4, 59162},
	{"FSCA", 4, 59163},
	{"EAKP", 4, 59164},
	{"HEMINGWAY", 9, 59165},
	{"MIGU", 4, 59166},
	{"GNMI", 4, 59167},
	{"GGAG", 4, 59168},
	{"MUNDANE", 7, 59169},
	{"IPRI", 4, 59170},
	{"ODAV", 4, 59171},
	{"BYVA", 4, 59172},
	{"YZL", 3, 59173},
	{"YFX", 3, 59174},
	{"RENDITION", 9, 59175},
	{"YEVI", 4, 59176},
	{"DANMARK", 7, 59177},
	{"DOUGLASS", 8, 59178},
	{"SOURCEBOOK", 10, 59179},
	{"BARCLAY", 7, 59180},
	{"GSAF", 4, 59181},
	{"MATADOR", 7, 59182},
	{"SMUT", 4, 59183},
	{"BCNE", 4, 59184},
	{"DANG", 4, 59185},
	{"BRADENTON", 9, 59186},
	{"NARB", 4, 59187},
	{"DDAI", 4, 59188},
	{"RERW", 4, 59189},
	{"NFUT", 4, 59190},
	{"HEKR", 4, 59191},
	{"BYPI", 4, 59192},
	{"MEETUPS", 7, 59193},
	{"BILBAO", 6, 59194},
	{"CLOTHS", 6, 59195},
	{"LTDO", 4, 59196},
	{"IGHM", 4, 59197},
	{"IEWC", 4, 59198},
	{"DELETES", 7, 59199},
	{"CLOWNS", 6, 59200},
	{"YLEP", 4, 59201},
	{"ELTY", 4, 59202},
	{"DPIL", 4, 59203},
	{"RLHA", 4, 59204},
	{"ADJUDICATION", 12, 59205},
	{"LOMBARD", 7, 59206},
	{"APLU", 4, 59207},
	{"BARREN", 6, 59208},
	{"TWEM", 4, 59209},
	{"PSEV", 4, 59210},
	{"AUTOCONF", 8, 59211},
	{"HISTOIRE", 8, 59212},
	{"RASMUSSEN", 9, 59213},
	{"FHOR", 4, 59214},
	{"MSMI", 4, 59215},
	{"EPUC", 4, 59216},
	{"BIBLIOGRAPHIES", 14, 59217},
	{"MILNE", 5, 59218},
	{"BEHAVED", 7, 59219},
	{"EMBARGO", 7, 59220},
	{"CONDENSATION", 12, 59221},
	{"RMLA", 4, 59222},
	{"YOKOHAMA", 8, 59223},
	{"UNPLUGGED", 9, 59224},
	{"ALFC", 4, 59225},
	{"WKWA", 4, 59226},
	{"CURRIE", 6, 59227},
	{"TORVALDS", 8, 59228},
	{"DIAD", 4, 59229},
	{"NEFF", 4, 59230},
	{"CLAUDIO", 7, 59231},
	{"TBYR", 4, 59232},
	{"RMYF", 4, 59233},
	{"BLOT", 4, 59234},
	{"PRIMERA", 7, 59235},
	{"COMMENTATOR", 11, 59236},
	{"TAILGATE", 8, 59237},
	{"PATTERNED", 9, 59238},
	{"EKSW", 4, 59239},
	{"HOLLIS", 6, 59240},
	{"OMYB", 4, 59241},
	{"WONL", 4, 59242},
	{"SPECTER", 7, 59243},
	{"IMAM", 4, 59244},
	{"YFLE", 4, 59245},
	{"RJOU", 4, 59246},
	{"LANIER", 6, 59247},
	{"OVERSEEING", 10, 59248},
	{"ESCALATION", 10, 59249},
	{"ASSENT", 6, 59250},
	{"EWDO", 4, 59251},
	{"UBAT", 4, 59252},
	{"RNBO", 4, 59253},
	{"RMBE", 4, 59254},
	{"USGE", 4, 59255},
	{"SHADING", 7, 59256},
	{"ECHC", 4, 59257},
	{"POLYMORPHISM", 12, 59258},
	{"SEMITISM", 8, 59259},
	{"SEVENFOLD", 9, 59260},
	{"COLOCATION", 10, 59261},
	{"MPRA", 4, 59262},
	{"WOODBURY", 8, 59263},
	{"SCRUBBED", 8, 59264},
	{"SIXR", 4, 59265},
	{"DOPI", 4, 59266},
	{"WARTS", 5, 59267},
	{"TSHIRT", 6, 59268},
	{"PBEI", 4, 59269},
	{"ORYN", 4, 59270},
	{"EPIDEMIOLOGICAL", 15, 59271},
	{"MEDIC", 5, 59272},
	{"ROUNDABOUT", 10, 59273},
	{"RPUN", 4, 59274},
	{"GNIG", 4, 59275},
	{"HARMED", 6, 59276},
	{"PATERNITY", 9, 59277},
	{"CONCEAL", 7, 59278},
	{"ORYU", 4, 59279},
	{"MBEG", 4, 59280},
	{"GRAIL", 5, 59281},
	{"STARVATION", 10, 59282},
	{"EPOD", 4, 59283},
	{"ESPANA", 6, 59284},
	{"HORNE", 5, 59285},
	{"NOSTALGIC", 9, 59286},
	{"DYSO", 4, 59287},
	{"RYKI", 4, 59288},
	{"APPOINTING", 10, 59289},
	{"ALDRICH", 7, 59290},
	{"TABLED", 6, 59291},
	{"FARSI", 5, 59292},
	{"LEAW", 4, 59293},
	{"SBYN", 4, 59294},
	{"EXCELSIOR", 9, 59295},
	{"RIAL", 4, 59296},
	{"IMDE", 4, 59297},
	{"FLOWED", 6, 59298},
	{"RNDO", 4, 59299},
	{"GREENSPAN", 9, 59300},
	{"DHABI", 5, 59301},
	{"CHOBE", 5, 59302},
	{"WESP", 4, 59303},
	{"HPOP", 4, 59304},
	{"ERUI", 4, 59305},
	{"UCEI", 4, 59306},
	{"RPSE", 4, 59307},
	{"IDSB", 4, 59308},
	{"OADU", 4, 59309},
	{"IGGA", 4, 59310},
	{"HMOU", 4, 59311},
	{"ANDREI", 6, 59312},
	{"FRAZIER", 7, 59313},
	{"ZULU", 4, 59314},
	{"CRIMINOLOGY", 11, 59315},
	{"BARNET", 6, 59316},
	{"JEANETTE", 8, 59317},
	{"YUSU", 4, 59318},
	{"RIFT", 4, 59319},
	{"SAVIOUR", 7, 59320},
	{"LAPEL", 5, 59321},
	{"CONSTEL", 7, 59322},
	{"RAYF", 4, 59323},
	{"GCHR", 4, 59324},
	{"TALKIN", 6, 59325},
	{"DUP", 3, 59326},
	{"RAMD", 4, 59327},
	{"PERMITTEE", 9, 59328},
	{"AYAU", 4, 59329},
	{"AKFO", 4, 59330},
	{"HANGOVER", 8, 59331},
	{"CAPITALIZE", 10, 59332},
	{"TURK", 4, 59333},
	{"RUEA", 4, 59334},
	{"MOTOCROSS", 9, 59335},
	{"PPIL", 4, 59336},
	{"BOOMERS", 7, 59337},
	{"WEDGWOOD", 8, 59338},
	{"CUPBOARD", 8, 59339},
	{"MCDERMOTT", 9, 59340},
	{"YOUNGS", 6, 59341},
	{"DAFL", 4, 59342},
	{"OMPH", 4, 59343},
	{"RAQW", 4, 59344},
	{"ARCHIPELAGO", 11, 59345},
	{"URID", 4, 59346},
	{"PEEP", 4, 59347},
	{"MSPL", 4, 59348},
	{"DECEPTIVE", 9, 59349},
	{"UNDERTAKINGS", 12, 59350},
	{"RAJO", 4, 59351},
	{"GROSSMAN", 8, 59352},
	{"PECAN", 5, 59353},
	{"ODIM", 4, 59354},
	{"TINTED", 6, 59355},
	{"FRESHMEAT", 9, 59356},
	{"FNAL", 4, 59357},
	{"GSDE", 4, 59358},
	{"CONGRATULATE", 12, 59359},
	{"BENZENE", 7, 59360},
	{"MCP", 3, 59361},
	{"TOPPER", 6, 59362},
	{"CONSTANCE", 9, 59363},
	{"ITTOOLBOX", 9, 59364},
	{"MANNY", 5, 59365},
	{"OSTEOARTHRITIS", 14, 59366},
	{"SCIV", 4, 59367},
	{"WESTLAKE", 8, 59368},
	{"CZECHOSLOVAKIA", 14, 59369},
	{"GYMA", 4, 59370},
	{"VANISHING", 9, 59371},
	{"YCRU", 4, 59372},
	{"UJD", 3, 59373},
	{"ADDICTIONS", 10, 59374},
	{"HCLI", 4, 59375},
	{"DYHE", 4, 59376},
	{"TAXONOMIC", 9, 59377},
	{"JUDO", 4, 59378},
	{"MIZUNO", 6, 59379},
	{"JORB", 4, 59380},
	{"IDIZ", 4, 59381},
	{"NOTIFYING", 9, 59382},
	{"ACHES", 5, 59383},
	{"PALMETTO", 8, 59384},
	{"KITCHENER", 9, 59385},
	{"WORO", 4, 59386},
	{"RICW", 4, 59387},
	{"SBYE", 4, 59388},
	{"LWEN", 4, 59389},
	{"GUEG", 4, 59390},
	{"TELCO", 5, 59391},
	{"LEAKED", 6, 59392},
	{"UPSP", 4, 59393},
	{"MICROARRAY", 10, 59394},
	{"ELECTROLUX", 10, 59395},
	{"GENERA", 6, 59396},
	{"ELEPHANTLIST", 12, 59397},
	{"SPARKED", 7, 59398},
	{"IDIOMS", 6, 59399},
	{"GARDINER", 8, 59400},
	{"NGEY", 4, 59401},
	{"BIDT", 4, 59402},
	{"AYMU", 4, 59403},
	{"QUALCOMM", 8, 59404},
	{"SADJ", 4, 59405},
	{"LAXE", 4, 59406},
	{"WHITAKER", 8, 59407},
	{"POISONOUS", 9, 59408},
	{"IDEY", 4, 59409},
	{"OMTW", 4, 59410},
	{"CONNELLY", 8, 59411},
	{"ADKI", 4, 59412},
	{"CHIME", 5, 59413},
	{"SPENCE", 6, 59414},
	{"UBHO", 4, 59415},
	{"CONNER", 6, 59416},
	{"HOSPITALIZED", 12, 59417},
	{"MISCHIEF", 8, 59418},
	{"ITFU", 4, 59419},
	{"HUTC", 4, 59420},
	{"ARGENT", 6, 59421},
	{"OPML", 4, 59422},
	{"WBOA", 4, 59423},
	{"DELINQUENCY", 11, 59424},
	{"TLAY", 4, 59425},
	{"KSAY", 4, 59426},
	{"ENTITLEMENTS", 12, 59427},
	{"WINGATE", 7, 59428},
	{"HEALEY", 6, 59429},
	{"SENTIMENTAL", 11, 59430},
	{"UNSUITABLE", 10, 59431},
	{"MILDLY", 6, 59432},
	{"KYWA", 4, 59433},
	{"DNAV", 4, 59434},
	{"JABRA", 5, 59435},
	{"MAJE", 4, 59436},
	{"ANGF", 4, 59437},
	{"QMAIL", 5, 59438},
	{"CERH", 4, 59439},
	{"ABYB", 4, 59440},
	{"SOYBEANS", 8, 59441},
	{"FORGING", 7, 59442},
	{"ELECTROSTATIC", 13, 59443},
	{"TOPOLOGICAL", 11, 59444},
	{"KETL", 4, 59445},
	{"GITF", 4, 59446},
	{"GISM", 4, 59447},
	{"GENV", 4, 59448},
	{"FKIL", 4, 59449},
	{"WAITRESS", 8, 59450},
	{"OVERSIZE", 8, 59451},
	{"SSDR", 4, 59452},
	{"CTPA", 4, 59453},
	{"WESTINGHOUSE", 12, 59454},
	{"CARIBOU", 7, 59455},
	{"GBEN", 4, 59456},
	{"MERCED", 6, 59457},
	{"OTGR", 4, 59458},
	{"EXPANSIVE", 9, 59459},
	{"FOOTING", 7, 59460},
	{"RBUY", 4, 59461},
	{"CRAFTSMANSHIP", 13, 59462},
	{"MANU", 4, 59463},
	{"PYLE", 4, 59464},
	{"EAKB", 4, 59465},
	{"IAMM", 4, 59466},
	{"SEUSS", 5, 59467},
	{"SLIGO", 5, 59468},
	{"EMYP", 4, 59469},
	{"RITR", 4, 59470},
	{"CHEETAH", 7, 59471},
	{"LDP", 3, 59472},
	{"REMIT", 5, 59473},
	{"BONNET", 6, 59474},
	{"COMPETED", 8, 59475},
	{"GPOR", 4, 59476},
	{"FRIDGES", 7, 59477},
	{"YONP", 4, 59478},
	{"TSKY", 4, 59479},
	{"MBON", 4, 59480},
	{"UNDERTOOK", 9, 59481},
	{"THYC", 4, 59482},
	{"HATCHERY", 8, 59483},
	{"JUDGEMENTS", 10, 59484},
	{"YFIT", 4, 59485},
	{"BADN", 4, 59486},
	{"DANW", 4, 59487},
	{"ATLU", 4, 59488},
	{"PROMENADE", 9, 59489},
	{"EXHAUSTION", 10, 59490},
	{"UNBORN", 6, 59491},
	{"FOFM", 4, 59492},
	{"FPAP", 4, 59493},
	{"DEMU", 4, 59494},
	{"WENDELL", 7, 59495},
	{"HLYM", 4, 59496},
	{"CORBETT", 7, 59497},
	{"CURR", 4, 59498},
	{"YDAU", 4, 59499},
	{"HAMMERS", 7, 59500},
	{"AMUT", 4, 59501},
	{"FINGERPRINTS", 12, 59502},
	{"SFEW", 4, 59503},
	{"CONV", 4, 59504},
	{"COASTS", 6, 59505},
	{"CHEESY", 6, 59506},
	{"EMITTING", 8, 59507},
	{"WCOS", 4, 59508},
	{"AHMEDABAD", 9, 59509},
	{"CONCUR", 6, 59510},
	{"UEJA", 4, 59511},
	{"UBRI", 4, 59512},
	{"RBOM", 4, 59513},
	{"ORIR", 4, 59514},
	{"MEGI", 4, 59515},
	{"MMOT", 4, 59516},
	{"AYVI", 4, 59517},
	{"EXERT", 5, 59518},
	{"GGAN", 4, 59519},
	{"CKIL", 4, 59520},
	{"ALSG", 4, 59521},
	{"MADELINE", 8, 59522},
	{"LONM", 4, 59523},
	{"SANSKRIT", 8, 59524},
	{"DIMLIST", 7, 59525},
	{"TORRE", 5, 59526},
	{"WINFIELD", 8, 59527},
	{"PINTO", 5, 59528},
	{"WORLDLY", 7, 59529},
	{"NYFU", 4, 59530},
	{"WEDGES", 6, 59531},
	{"CORDED", 6, 59532},
	{"HEIRLOOM", 8, 59533},
	{"PLEASANTLY", 10, 59534},
	{"EAMY", 4, 59535},
	{"GALLERYS", 8, 59536},
	{"MARTINDALE", 10, 59537},
	{"SOBL", 4, 59538},
	{"NALQ", 4, 59539},
	{"FJAM", 4, 59540},
	{"PERO", 4, 59541},
	{"TUSF", 4, 59542},
	{"WEBSTATISTICS", 13, 59543},
	{"ESOTERIC", 8, 59544},
	{"LUXE", 4, 59545},
	{"YSGR", 4, 59546},
	{"MESSENGERS", 10, 59547},
	{"MAYS", 4, 59548},
	{"RISC", 4, 59549},
	{"OILW", 4, 59550},
	{"YJUD", 4, 59551},
	{"MDID", 4, 59552},
	{"LANDINGS", 8, 59553},
	{"GRAPHICALLY", 11, 59554},
	{"NDAJ", 4, 59555},
	{"SHAMELESS", 9, 59556},
	{"XMD", 3, 59557},
	{"WVW", 3, 59558},
	{"LJOU", 4, 59559},
	{"IGGL", 4, 59560},
	{"AULM", 4, 59561},
	{"FAUG", 4, 59562},
	{"HURD", 4, 59563},
	{"GEOTRACK", 8, 59564},
	{"COMMUNICATES", 12, 59565},
	{"DJEF", 4, 59566},
	{"KOLKATA", 7, 59567},
	{"IMATION", 7, 59568},
	{"HEMATOLOGY", 10, 59569},
	{"BOURGEOIS", 9, 59570},
	{"OVOK", 4, 59571},
	{"ELBR", 4, 59572},
	{"OLSB", 4, 59573},
	{"RDUT", 4, 59574},
	{"BESW", 4, 59575},
	{"NAPKINS", 7, 59576},
	{"EXPRESSWAY", 10, 59577},
	{"UNLOADING", 9, 59578},
	{"STEELHEAD", 9, 59579},
	{"BAKERS", 6, 59580},
	{"SELMA", 5, 59581},
	{"PEARS", 5, 59582},
	{"TBOW", 4, 59583},
	{"MOFD", 4, 59584},
	{"UDEH", 4, 59585},
	{"LUCID", 5, 59586},
	{"TURNTABLES", 10, 59587},
	{"LINDHOLM", 8, 59588},
	{"LOBE", 4, 59589},
	{"CLOONEY", 7, 59590},
	{"FACILITATORS", 12, 59591},
	{"WTOG", 4, 59592},
	{"LAFR", 4, 59593},
	{"MCNAMARA", 8, 59594},
	{"SHIVA", 5, 59595},
	{"CANAAN", 6, 59596},
	{"TONERS", 6, 59597},
	{"MKNO", 4, 59598},
	{"KENYAN", 6, 59599},
	{"KDUR", 4, 59600},
	{"WYNN", 4, 59601},
	{"OPPRESSED", 9, 59602},
	{"VYIN", 4, 59603},
	{"INFER", 5, 59604},
	{"UBOF", 4, 59605},
	{"RKFR", 4, 59606},
	{"PROSECUTE", 9, 59607},
	{"MOTORBIKE", 9, 59608},
	{"DMEI", 4, 59609},
	{"ULBE", 4, 59610},
	{"COMW", 4, 59611},
	{"NILES", 5, 59612},
	{"THATCHER", 8, 59613},
	{"ZIPPO", 5, 59614},
	{"SERGEI", 6, 59615},
	{"BRET", 4, 59616},
	{"UPFRONT", 7, 59617},
	{"WHAD", 4, 59618},
	{"RLEM", 4, 59619},
	{"GLYR", 4, 59620},
	{"HAULING", 7, 59621},
	{"INCONSISTENCIES", 15, 59622},
	{"YSAP", 4, 59623},
	{"RSUF", 4, 59624},
	{"BATTLEFRONT", 11, 59625},
	{"INDEBTEDNESS", 12, 59626},
	{"LROS", 4, 59627},
	{"FANSITE", 7, 59628},
	{"SMIR", 4, 59629},
	{"DVOI", 4, 59630},
	{"ADVERSARY", 9, 59631},
	{"COLOSSIANS", 10, 59632},
	{"INBC", 4, 59633},
	{"LMFE", 4, 59634},
	{"QUAINT", 6, 59635},
	{"ADDICTING", 9, 59636},
	{"GERD", 4, 59637},
	{"OSWALD", 6, 59638},
	{"YPTO", 4, 59639},
	{"NYGI", 4, 59640},
	{"DIPPING", 7, 59641},
	{"IXEL", 4, 59642},
	{"UMNA", 4, 59643},
	{"PUPT", 4, 59644},
	{"COPA", 4, 59645},
	{"REVERE", 6, 59646},
	{"OGLO", 4, 59647},
	{"NGAJ", 4, 59648},
	{"TROOPERS", 8, 59649},
	{"ZLIB", 4, 59650},
	{"WHITESPACE", 10, 59651},
	{"TEKTRONIX", 9, 59652},
	{"DOESN", 5, 59653},
	{"UDTH", 4, 59654},
	{"NRBI", 4, 59655},
	{"LDNA", 4, 59656},
	{"MCCULLOUGH", 10, 59657},
	{"IMLI", 4, 59658},
	{"DOMAINE", 7, 59659},
	{"OLDE", 4, 59660},
	{"GUERRA", 6, 59661},
	{"TJUL", 4, 59662},
	{"URDR", 4, 59663},
	{"SOLEMN", 6, 59664},
	{"MICROFIBER", 10, 59665},
	{"ACOC", 4, 59666},
	{"MDC", 3, 59667},
	{"UPYO", 4, 59668},
	{"ORAK", 4, 59669},
	{"ERUPTION", 8, 59670},
	{"TYBR", 4, 59671},
	{"YYAR", 4, 59672},
	{"ECAF", 4, 59673},
	{"CELESTE", 7, 59674},
	{"DEPLOYMENTS", 11, 59675},
	{"NLAD", 4, 59676},
	{"FFBY", 4, 59677},
	{"STEARNS", 7, 59678},
	{"GENTRY", 6, 59679},
	{"INSURGENCY", 10, 59680},
	{"RNOM", 4, 59681},
	{"BOYER", 5, 59682},
	{"BEHRINGER", 9, 59683},
	{"ITPU", 4, 59684},
	{"MMOV", 4, 59685},
	{"PERCEPTUAL", 10, 59686},
	{"YGRI", 4, 59687},
	{"OROD", 4, 59688},
	{"OMJO", 4, 59689},
	{"HMAL", 4, 59690},
	{"ENCHANTING", 10, 59691},
	{"PREACHED", 8, 59692},
	{"MIDLOTHIAN", 10, 59693},
	{"MICA", 4, 59694},
	{"FOLLANDO", 8, 59695},
	{"PWU", 3, 59696},
	{"INSTR", 5, 59697},
	{"CADETS", 6, 59698},
	{"LADS", 4, 59699},
	{"RAMBLER", 7, 59700},
	{"NSFU", 4, 59701},
	{"LGEO", 4, 59702},
	{"DRYWALL", 7, 59703},
	{"ENDURED", 7, 59704},
	{"ENSUITE", 7, 59705},
	{"FERMENTATION", 12, 59706},
	{"SUZY", 4, 59707},
	{"MRIG", 4, 59708},
	{"OWNJ", 4, 59709},
	{"DEKALB", 6, 59710},
	{"SUMO", 4, 59711},
	{"DKEP", 4, 59712},
	{"CARELESS", 8, 59713},
	{"TOPSITES", 8, 59714},
	{"CHEMISTS", 8, 59715},
	{"SMIX", 4, 59716},
	{"FESP", 4, 59717},
	{"KOPE", 4, 59718},
	{"JULIEN", 6, 59719},
	{"DANDY", 5, 59720},
	{"REFURBISHMENT", 13, 59721},
	{"PFAM", 4, 59722},
	{"MEAU", 4, 59723},
	{"GRASSLAND", 9, 59724},
	{"TELW", 4, 59725},
	{"JEFFERY", 7, 59726},
	{"NARCOTIC", 8, 59727},
	{"UCEC", 4, 59728},
	{"UBRE", 4, 59729},
	{"COUNCILMAN", 10, 59730},
	{"SEYW", 4, 59731},
	{"MOULIN", 6, 59732},
	{"SWAPS", 5, 59733},
	{"UNBRANDED", 9, 59734},
	{"ASTRONAUTS", 10, 59735},
	{"AUXI", 4, 59736},
	{"LOCKERS", 7, 59737},
	{"LOOKUPS", 7, 59738},
	{"NNYD", 4, 59739},
	{"PAINE", 5, 59740},
	{"WVER", 4, 59741},
	{"LLSY", 4, 59742},
	{"HQUE", 4, 59743},
	{"HPOR", 4, 59744},
	{"EBBI", 4, 59745},
	{"INCOMPETENT", 11, 59746},
	{"ATTACKERS", 9, 59747},
	{"ACTUATOR", 8, 59748},
	{"LLHU", 4, 59749},
	{"RESTON", 6, 59750},
	{"SFTP", 4, 59751},
	{"SUSF", 4, 59752},
	{"SOQU", 4, 59753},
	{"NROY", 4, 59754},
	{"REINSTALL", 9, 59755},
	{"TBYB", 4, 59756},
	{"LANDER", 6, 59757},
	{"PREDECESSORS", 12, 59758},
	{"LANCER", 6, 59759},
	{"COBY", 4, 59760},
	{"SORCERER", 8, 59761},
	{"FISHERS", 7, 59762},
	{"XUZ", 3, 59763},
	{"INVOKING", 8, 59764},
	{"MUFFIN", 6, 59765},
	{"MOTHERHOOD", 10, 59766},
	{"WEXFORD", 7, 59767},
	{"LFST", 4, 59768},
	{"METHANOL", 8, 59769},
	{"MISCELLANY", 10, 59770},
	{"SIMPLIFYING", 11, 59771},
	{"SLOWDOWN", 8, 59772},
	{"DRESSINGS", 9, 59773},
	{"BRIDESMAID", 10, 59774},
	{"TYSM", 4, 59775},
	{"MABU", 4, 59776},
	{"TRANSISTORS", 11, 59777},
	{"NSJU", 4, 59778},
	{"NHUR", 4, 59779},
	{"MATW", 4, 59780},
	{"FGAR", 4, 59781},
	{"OTFU", 4, 59782},
	{"DOFV", 4, 59783},
	{"PARTRIDGE", 9, 59784},
	{"SYNOD", 5, 59785},
	{"NOTICING", 8, 59786},
	{"MARYS", 5, 59787},
	{"COLGATE", 7, 59788},
	{"LOUSY", 5, 59789},
	{"PHARM", 5, 59790},
	{"NBOL", 4, 59791},
	{"EIRY", 4, 59792},
	{"FORESEEABLE", 11, 59793},
	{"OUPG", 4, 59794},
	{"OPUP", 4, 59795},
	{"NPUN", 4, 59796},
	{"IEWB", 4, 59797},
	{"NUTRITIONISTS", 13, 59798},
	{"NEWMARKET", 9, 59799},
	{"EBYI", 4, 59800},
	{"AMIGO", 5, 59801},
	{"IREU", 4, 59802},
	{"DISCERNING", 10, 59803},
	{"TAUD", 4, 59804},
	{"SAWR", 4, 59805},
	{"TECHWEB", 7, 59806},
	{"IFAM", 4, 59807},
	{"FMUL", 4, 59808},
	{"CADDY", 5, 59809},
	{"BERKLEY", 7, 59810},
	{"ABYA", 4, 59811},
	{"RESISTORS", 9, 59812},
	{"CSUR", 4, 59813},
	{"BURROWS", 7, 59814},
	{"FURNACES", 8, 59815},
	{"RTPO", 4, 59816},
	{"MALH", 4, 59817},
	{"BLONDIE", 7, 59818},
	{"OCCUPANT", 8, 59819},
	{"RUNU", 4, 59820},
	{"OKSB", 4, 59821},
	{"IRMU", 4, 59822},
	{"HTPL", 4, 59823},
	{"DRWXR", 5, 59824},
	{"RONU", 4, 59825},
	{"LIVINGSTONE", 11, 59826},
	{"CFC", 3, 59827},
	{"RLYV", 4, 59828},
	{"GEAP", 4, 59829},
	{"WLEV", 4, 59830},
	{"NECU", 4, 59831},
	{"VILLANOVA", 9, 59832},
	{"JUGGLING", 8, 59833},
	{"WILDFIRE", 8, 59834},
	{"ODYM", 4, 59835},
	{"AFTB", 4, 59836},
	{"SEDUCTIVE", 9, 59837},
	{"SCALA", 5, 59838},
	{"ONGV", 4, 59839},
	{"ICHK", 4, 59840},
	{"PAMPHLETS", 9, 59841},
	{"RAMBLING", 8, 59842},
	{"RISJ", 4, 59843},
	{"KIDD", 4, 59844},
	{"BEDSIDE", 7, 59845},
	{"CESAR", 5, 59846},
	{"LAUSANNE", 8, 59847},
	{"CUUM", 4, 59848},
	{"HEURISTIC", 9, 59849},
	{"OMKI", 4, 59850},
	{"ARCHIVIST", 9, 59851},
	{"LEGALITY", 8, 59852},
	{"RFIF", 4, 59853},
	{"OPSB", 4, 59854},
	{"GALLUP", 6, 59855},
	{"ARBITRARILY", 11, 59856},
	{"VALTREX", 7, 59857},
	{"ANTIMICROBIAL", 13, 59858},
	{"BIOLOGIST", 9, 59859},
	{"COBOL", 5, 59860},
	{"AYIM", 4, 59861},
	{"HEPC", 4, 59862},
	{"EELP", 4, 59863},
	{"LUZ", 3, 59864},
	{"RBOL", 4, 59865},
	{"EPUM", 4, 59866},
	{"FRUITY", 6, 59867},
	{"REGULARS", 8, 59868},
	{"ROBSON", 6, 59869},
	{"STRATUS", 7, 59870},
	{"MYSTICISM", 9, 59871},
	{"UPCH", 4, 59872},
	{"FIPS", 4, 59873},
	{"WHYC", 4, 59874},
	{"SLYF", 4, 59875},
	{"UREA", 4, 59876},
	{"PICN", 4, 59877},
	{"BUMPERS", 7, 59878},
	{"ACCOMPANIES", 11, 59879},
	{"ACUU", 4, 59880},
	{"SUMMED", 6, 59881},
	{"CHOPIN", 6, 59882},
	{"TORCHES", 7, 59883},
	{"LUMIX", 5, 59884},
	{"DOMINATING", 10, 59885},
	{"JOINER", 6, 59886},
	{"WILDCARD", 8, 59887},
	{"VIEJO", 5, 59888},
	{"XWHI", 4, 59889},
	{"SWEV", 4, 59890},
	{"IOFF", 4, 59891},
	{"EXPLORATIONS", 12, 59892},
	{"GUARANTY", 8, 59893},
	{"DESNUDAS", 8, 59894},
	{"LSED", 4, 59895},
	{"PROCURE", 7, 59896},
	{"PLEXTOR", 7, 59897},
	{"DOAB", 4, 59898},
	{"OXIDATIVE", 9, 59899},
	{"EMAF", 4, 59900},
	{"BBIS", 4, 59901},
	{"STILLWATER", 10, 59902},
	{"SUNSETS", 7, 59903},
	{"YNAR", 4, 59904},
	{"BRITS", 5, 59905},
	{"CROPPING", 8, 59906},
	{"WOBE", 4, 59907},
	{"RYJU", 4, 59908},
	{"LGOI", 4, 59909},
	{"HEALY", 5, 59910},
	{"ZEME", 4, 59911},
	{"PLIERS", 6, 59912},
	{"KAYAKS", 6, 59913},
	{"IBANEZ", 6, 59914},
	{"ANASTASIA", 9, 59915},
	{"PUX", 3, 59916},
	{"VAKI", 4, 59917},
	{"ULAI", 4, 59918},
	{"OLIZ", 4, 59919},
	{"ARROGANCE", 9, 59920},
	{"MARXIST", 7, 59921},
	{"COULDNT", 7, 59922},
	{"NAPERVILLE", 10, 59923},
	{"DIVERTED", 8, 59924},
	{"SEFL", 4, 59925},
	{"NYGA", 4, 59926},
	{"ALFD", 4, 59927},
	{"FORGIVEN", 8, 59928},
	{"BOBC", 4, 59929},
	{"BLEAK", 5, 59930},
	{"DACU", 4, 59931},
	{"DIPLOMAS", 8, 59932},
	{"FIELDWORK", 9, 59933},
	{"CHRISTOPHE", 10, 59934},
	{"ERAJ", 4, 59935},
	{"DAMPING", 7, 59936},
	{"ROGU", 4, 59937},
	{"OUEX", 4, 59938},
	{"TEMD", 4, 59939},
	{"AYDR", 4, 59940},
	{"IMMUNOL", 7, 59941},
	{"DRUDGE", 6, 59942},
	{"BYNI", 4, 59943},
	{"DOLORES", 7, 59944},
	{"REGAN", 5, 59945},
	{"WWWROOT", 7, 59946},
	{"SMYF", 4, 59947},
	{"TRAMP", 5, 59948},
	{"SALIVA", 6, 59949},
	{"BOOTLEG", 7, 59950},
	{"CHICHESTER", 10, 59951},
	{"INTELLECTUALS", 13, 59952},
	{"WINSLOW", 7, 59953},
	{"YASL", 4, 59954},
	{"EUPG", 4, 59955},
	{"MINIS", 5, 59956},
	{"ARTEMIS", 7, 59957},
	{"LESSEN", 6, 59958},
	{"VEVA", 4, 59959},
	{"RANM", 4, 59960},
	{"WELLER", 6, 59961},
	{"SYRINGE", 7, 59962},
	{"LEFTIST", 7, 59963},
	{"DIVERSIONS", 10, 59964},
	{"RFEI", 4, 59965},
	{"TEQUILA", 7, 59966},
	{"ADMIRALTY", 9, 59967},
	{"POWDERED", 8, 59968},
	{"LPBU", 4, 59969},
	{"LIMOGES", 7, 59970},
	{"WILDWOOD", 8, 59971},
	{"GRANGER", 7, 59972},
	{"RDUS", 4, 59973},
	{"GERMANTOWN", 10, 59974},
	{"PREVAILED", 9, 59975},
	{"USHU", 4, 59976},
	{"MSLO", 4, 59977},
	{"GLACIAL", 7, 59978},
	{"BERGMAN", 7, 59979},
	{"XVW", 3, 59980},
	{"RJY", 3, 59981},
	{"DYX", 3, 59982},
	{"GMAC", 4, 59983},
	{"RTYY", 4, 59984},
	{"PULITZER", 8, 59985},
	{"TAPERED", 7, 59986},
	{"UNJA", 4, 59987},
	{"ALLEGES", 7, 59988},
	{"MOLLIGE", 7, 59989},
	{"URSQ", 4, 59990},
	{"AYUS", 4, 59991},
	{"TOOTHBRUSH", 10, 59992},
	{"LANP", 4, 59993},
	{"DELEGATIONS", 11, 59994},
	{"PLUTONIUM", 9, 59995},
	{"SHREDDED", 8, 59996},
	{"FACTSHEET", 9, 59997},
	{"SQUAREPANTS", 11, 59998},
	{"ANTIQUITY", 9, 59999},
	{"SUBSURFACE", 10, 60000},
	{"ZEAL", 4, 60001},
	{"HGIV", 4, 60002},
	{"VALPARAISO", 10, 60003},
	{"ANYJ", 4, 60004},
	{"BLAMING", 7, 60005},
	{"MSIM", 4, 60006},
	{"EMBARK", 6, 60007},
	{"OLLB", 4, 60008},
	{"MANNED", 6, 60009},
	{"PORTE", 5, 60010},
	{"GUADALUPE", 9, 60011},
	{"JOHANNA", 7, 60012},
	{"KOFO", 4, 60013},
	{"GNUP", 4, 60014},
	{"GRANULAR", 8, 60015},
	{"OWEW", 4, 60016},
	{"EYKE", 4, 60017},
	{"RDAP", 4, 60018},
	{"ORKNEY", 6, 60019},
	{"HALLIBURTON", 11, 60020},
	{"UNDERSCORE", 10, 60021},
	{"BORG", 4, 60022},
	{"ELAF", 4, 60023},
	{"DAGI", 4, 60024},
	{"GLUTAMINE", 9, 60025},
	{"ICEJ", 4, 60026},
	{"RHEB", 4, 60027},
	{"LNAV", 4, 60028},
	{"KWAT", 4, 60029},
	{"TUMP", 4, 60030},
	{"VERO", 4, 60031},
	{"OSCILLATIONS", 12, 60032},
	{"DEXH", 4, 60033},
	{"MCPHEE", 6, 60034},
	{"HERBICIDES", 10, 60035},
	{"USGENWEB", 8, 60036},
	{"YWAI", 4, 60037},
	{"NMYM", 4, 60038},
	{"INSCRIBED", 9, 60039},
	{"UBPR", 4, 60040},
	{"CHAINSAW", 8, 60041},
	{"GUNM", 4, 60042},
	{"SPHINX", 6, 60043},
	{"RXY", 3, 60044},
	{"CZD", 3, 60045},
	{"VIDM", 4, 60046},
	{"TABLATURE", 9, 60047},
	{"SPIEGEL", 7, 60048},
	{"FERTILIZATION", 13, 60049},
	{"UTVI", 4, 60050},
	{"MUJER", 5, 60051},
	{"GLITCH", 6, 60052},
	{"GEARBOX", 7, 60053},
	{"CEREMONIAL", 10, 60054},
	{"SONNET", 6, 60055},
	{"STANG", 5, 60056},
	{"ALEJANDRO", 9, 60057},
	{"CONSTITUENCIES", 14, 60058},
	{"SPRUNG", 6, 60059},
	{"VISW", 4, 60060},
	{"EDSB", 4, 60061},
	{"DNEC", 4, 60062},
	{"HEDGES", 6, 60063},
	{"TENSILE", 7, 60064},
	{"INFLATED", 8, 60065},
	{"VARCHAR", 7, 60066},
	{"INTERCOM", 8, 60067},
	{"MCKEE", 5, 60068},
	{"ENVISAGED", 9, 60069},
	{"SPLICE", 6, 60070},
	{"CROOKS", 6, 60071},
	{"SPLICING", 8, 60072},
	{"TELR", 4, 60073},
	{"CAMPFIRE", 8, 60074},
	{"CARDBUS", 7, 60075},
	{"RDIM", 4, 60076},
	{"PROSPECTING", 11, 60077},
	{"HUBBY", 5, 60078},
	{"QUILTED", 7, 60079},
	{"RDFA", 4, 60080},
	{"WALLED", 6, 60081},
	{"GRAPHING", 8, 60082},
	{"GOFG", 4, 60083},
	{"BIOLOGISTS", 10, 60084},
	{"ILYU", 4, 60085},
	{"FHAL", 4, 60086},
	{"IMPROV", 6, 60087},
	{"HEMPSTEAD", 9, 60088},
	{"IMMENSELY", 9, 60089},
	{"EXILIM", 6, 60090},
	{"BRAL", 4, 60091},
	{"TRAFALGAR", 9, 60092},
	{"ACEV", 4, 60093},
	{"RELAPSE", 7, 60094},
	{"XLR", 3, 60095},
	{"YEVA", 4, 60096},
	{"DEBUTS", 6, 60097},
	{"OLGR", 4, 60098},
	{"DISKETTE", 8, 60099},
	{"YSFU", 4, 60100},
	{"CUPC", 4, 60101},
	{"XWEE", 4, 60102},
	{"COMMEND", 7, 60103},
	{"CONTENDER", 9, 60104},
	{"JAKOB", 5, 60105},
	{"SOUTHLAND", 9, 60106},
	{"BOLSTER", 7, 60107},
	{"GLOBALS", 7, 60108},
	{"NIETZSCHE", 9, 60109},
	{"DIASPORA", 8, 60110},
	{"MORATORIUM", 10, 60111},
	{"SAFES", 5, 60112},
	{"TMUR", 4, 60113},
	{"RTSG", 4, 60114},
	{"YUQ", 3, 60115},
	{"LMZ", 3, 60116},
	{"DZC", 3, 60117},
	{"GOODNIGHT", 9, 60118},
	{"ALCOHOLICS", 10, 60119},
	{"ROCKED", 6, 60120},
	{"RANCID", 6, 60121},
	{"AVYC", 4, 60122},
	{"DISPARITY", 9, 60123},
	{"MALICE", 6, 60124},
	{"DVEG", 4, 60125},
	{"UTYC", 4, 60126},
	{"OLOP", 4, 60127},
	{"ECKP", 4, 60128},
	{"KNAPP", 5, 60129},
	{"HNUM", 4, 60130},
	{"SWIMMERS", 8, 60131},
	{"GATLINBURG", 10, 60132},
	{"SAWM", 4, 60133},
	{"SYLLABLE", 8, 60134},
	{"PAINFULLY", 9, 60135},
	{"PHARMACOL", 9, 60136},
	{"CROR", 4, 60137},
	{"HLYI", 4, 60138},
	{"EWSK", 4, 60139},
	{"SEJU", 4, 60140},
	{"OLYO", 4, 60141},
	{"MRUN", 4, 60142},
	{"ANLU", 4, 60143},
	{"XORG", 4, 60144},
	{"SWEATING", 8, 60145},
	{"VELH", 4, 60146},
	{"NUPP", 4, 60147},
	{"DEMOLISHED", 10, 60148},
	{"NEWSQUEST", 9, 60149},
	{"WAVELENGTHS", 11, 60150},
	{"TDER", 4, 60151},
	{"OURQ", 4, 60152},
	{"FHOP", 4, 60153},
	{"UNCLAIMED", 9, 60154},
	{"RACQUET", 7, 60155},
	{"COUT", 4, 60156},
	{"CYTOPLASMIC", 11, 60157},
	{"CATHOLICISM", 11, 60158},
	{"ULME", 4, 60159},
	{"TRIDENT", 7, 60160},
	{"QAIDA", 5, 60161},
	{"LEMC", 4, 60162},
	{"LEMONADE", 8, 60163},
	{"KPMG", 4, 60164},
	{"ABSENCES", 8, 60165},
	{"ANDES", 5, 60166},
	{"UBAS", 4, 60167},
	{"CIUDAD", 6, 60168},
	{"LANARKSHIRE", 11, 60169},
	{"STEAKHOUSE", 10, 60170},
	{"KENR", 4, 60171},
	{"GKIN", 4, 60172},
	{"STUBS", 5, 60173},
	{"LLWR", 4, 60174},
	{"JOSIE", 5, 60175},
	{"SOLARIUM", 8, 60176},
	{"PERSISTS", 8, 60177},
	{"MYJO", 4, 60178},
	{"BSCO", 4, 60179},
	{"FILLMORE", 8, 60180},
	{"WHOJ", 4, 60181},
	{"GREENHOUSES", 11, 60182},
	{"LGIR", 4, 60183},
	{"PROPELLER", 9, 60184},
	{"DENTS", 5, 60185},
	{"SPOTLIGHTS", 10, 60186},
	{"PERKS", 5, 60187},
	{"ANARCHIST", 9, 60188},
	{"HARLOW", 6, 60189},
	{"MORRISSEY", 9, 60190},
	{"HLYD", 4, 60191},
	{"SUBMERGED", 9, 60192},
	{"ENTRUSTED", 9, 60193},
	{"PLYP", 4, 60194},
	{"FCEL", 4, 60195},
	{"YATB", 4, 60196},
	{"RVIR", 4, 60197},
	{"ORGL", 4, 60198},
	{"LFHE", 4, 60199},
	{"CALMING", 7, 60200},
	{"LUSW", 4, 60201},
	{"INTENDING", 9, 60202},
	{"LUTZ", 4, 60203},
	{"WEDL", 4, 60204},
	{"CROMWELL", 8, 60205},
	{"DRUMMOND", 8, 60206},
	{"DISSERTATIONS", 13, 60207},
	{"HIGHLANDER", 10, 60208},
	{"UTDR", 4, 60209},
	{"SOLICITATIONS", 13, 60210},
	{"CAPACITANCE", 11, 60211},
	{"BIRTHSTONE", 10, 60212},
	{"PRIMITIVES", 10, 60213},
	{"BONG", 4, 60214},
	{"LINGUAL", 7, 60215},
	{"UNFRAMED", 8, 60216},
	{"YVIR", 4, 60217},
	{"TAMF", 4, 60218},
	{"FSAM", 4, 60219},
	{"MHAP", 4, 60220},
	{"PUNTO", 5, 60221},
	{"GGSA", 4, 60222},
	{"SURVIVES", 8, 60223},
	{"MYPE", 4, 60224},
	{"AGOM", 4, 60225},
	{"VIBES", 5, 60226},
	{"DARCY", 5, 60227},
	{"TMDL", 4, 60228},
	{"FUNNEL", 6, 60229},
	{"MOONS", 5, 60230},
	{"OMUR", 4, 60231},
	{"THIRSTY", 7, 60232},
	{"PROGRAMA", 8, 60233},
	{"REPUBLICATION", 13, 60234},
	{"FRESHNESS", 9, 60235},
	{"LATHE", 5, 60236},
	{"VENETO", 6, 60237},
	{"YCUL", 4, 60238},
	{"OLIB", 4, 60239},
	{"EBAP", 4, 60240},
	{"HIPPIE", 6, 60241},
	{"LFED", 4, 60242},
	{"UTSM", 4, 60243},
	{"LOID", 4, 60244},
	{"ACYCLOVIR", 9, 60245},
	{"SHABBY", 6, 60246},
	{"PUNCHED", 7, 60247},
	{"PETRI", 5, 60248},
	{"FSLA", 4, 60249},
	{"VIRGIL", 6, 60250},
	{"BENOIT", 6, 60251},
	{"ORGANIZES", 9, 60252},
	{"UNAUDITED", 9, 60253},
	{"SUMMERTIME", 10, 60254},
	{"MARBLES", 7, 60255},
	{"AIRBAG", 6, 60256},
	{"COTTONWOOD", 10, 60257},
	{"SAGG", 4, 60258},
	{"MILDRED", 7, 60259},
	{"SWEETWATER", 10, 60260},
	{"ZOMB", 4, 60261},
	{"DJUM", 4, 60262},
	{"DELETIONS", 9, 60263},
	{"HYME", 4, 60264},
	{"BJC", 3, 60265},
	{"ARLB", 4, 60266},
	{"CLEOPATRA", 9, 60267},
	{"UNDECIDED", 9, 60268},
	{"YREW", 4, 60269},
	{"STARTLING", 9, 60270},
	{"INTERNATIONALE", 14, 60271},
	{"INDUCTIVE", 9, 60272},
	{"KRYSTAL", 7, 60273},
	{"INADVERTENTLY", 13, 60274},
	{"EXPANSIONS", 10, 60275},
	{"ZEDR", 4, 60276},
	{"METY", 4, 60277},
	{"CHGI", 4, 60278},
	{"RGYE", 4, 60279},
	{"CORRELATE", 9, 60280},
	{"BURSTING", 8, 60281},
	{"RTSY", 4, 60282},
	{"LINKOUT", 7, 60283},
	{"UGEP", 4, 60284},
	{"LKON", 4, 60285},
	{"PITTSBURG", 9, 60286},
	{"WIRD", 4, 60287},
	{"BYLAW", 5, 60288},
	{"TLAD", 4, 60289},
	{"LPAP", 4, 60290},
	{"KENYON", 6, 60291},
	{"WFAR", 4, 60292},
	{"TRIMS", 5, 60293},
	{"EPIPHANY", 8, 60294},
	{"HALVES", 6, 60295},
	{"DEVIN", 5, 60296},
	{"MOULDING", 8, 60297},
	{"MELANCHOLY", 10, 60298},
	{"VIEWFINDER", 10, 60299},
	{"OBSERVANCE", 10, 60300},
	{"LEAPS", 5, 60301},
	{"HALEN", 5, 60302},
	{"HOMEWOOD", 8, 60303},
	{"MCRAE", 5, 60304},
	{"DOBU", 4, 60305},
	{"RENAMING", 8, 60306},
	{"GALVANIZED", 10, 60307},
	{"PWOU", 4, 60308},
	{"KPOS", 4, 60309},
	{"UEAR", 4, 60310},
	{"PLAINFIELD", 10, 60311},
	{"TEAPOT", 6, 60312},
	{"CONVEYS", 7, 60313},
	{"LENDS", 5, 60314},
	{"MAXON", 5, 60315},
	{"SQUIRE", 6, 60316},
	{"UCEM", 4, 60317},
	{"NORU", 4, 60318},
	{"NJAB", 4, 60319},
	{"SPRINTF", 7, 60320},
	{"ARMAGH", 6, 60321},
	{"LIVECHAT", 8, 60322},
	{"YPEI", 4, 60323},
	{"BYAV", 4, 60324},
	{"PDR", 3, 60325},
	{"UISM", 4, 60326},
	{"OLBY", 4, 60327},
	{"DEKI", 4, 60328},
	{"CKMI", 4, 60329},
	{"LYMAN", 5, 60330},
	{"NOTFOUND", 8, 60331},
	{"COUNTERFEIT", 11, 60332},
	{"ECAY", 4, 60333},
	{"WALLER", 6, 60334},
	{"PATHOGEN", 8, 60335},
	{"PURD", 4, 60336},
	{"ZAGREB", 6, 60337},
	{"GAYLE", 5, 60338},
	{"DUVAL", 5, 60339},
	{"OVERWRITE", 9, 60340},
	{"OWAW", 4, 60341},
	{"REVITALIZATION", 14, 60342},
	{"IRPU", 4, 60343},
	{"ATMR", 4, 60344},
	{"XTGE", 4, 60345},
	{"LBIO", 4, 60346},
	{"YOKE", 4, 60347},
	{"UTGI", 4, 60348},
	{"RESONANT", 8, 60349},
	{"CAMRY", 5, 60350},
	{"OUTSKIRTS", 9, 60351},
	{"POSTMODERN", 10, 60352},
	{"EXPEDITE", 8, 60353},
	{"LOYI", 4, 60354},
	{"IDDU", 4, 60355},
	{"FDUT", 4, 60356},
	{"NZER", 4, 60357},
	{"GRAYSON", 7, 60358},
	{"SWEETNESS", 9, 60359},
	{"TILR", 4, 60360},
	{"NCUP", 4, 60361},
	{"CROOK", 5, 60362},
	{"JAYNE", 5, 60363},
	{"REARING", 7, 60364},
	{"GHJU", 4, 60365},
	{"KUHN", 4, 60366},
	{"DAVISON", 7, 60367},
	{"ORSQ", 4, 60368},
	{"TYPOS", 5, 60369},
	{"YEMB", 4, 60370},
	{"DELIBERATIONS", 13, 60371},
	{"GLUTAMATE", 9, 60372},
	{"INDIFFERENCE", 12, 60373},
	{"INVADING", 8, 60374},
	{"TYFE", 4, 60375},
	{"SHCR", 4, 60376},
	{"MELTON", 6, 60377},
	{"DIVES", 5, 60378},
	{"UREK", 4, 60379},
	{"THYB", 4, 60380},
	{"KENZ", 4, 60381},
	{"AUSC", 4, 60382},
	{"ONEWORLD", 8, 60383},
	{"REALTONE", 8, 60384},
	{"EKAF", 4, 60385},
	{"WOBO", 4, 60386},
	{"DOFY", 4, 60387},
	{"MIKEY", 5, 60388},
	{"ELUD", 4, 60389},
	{"TELEPHOTO", 9, 60390},
	{"POOLING", 7, 60391},
	{"DRURY", 5, 60392},
	{"BHOU", 4, 60393},
	{"COYOTES", 7, 60394},
	{"STALE", 5, 60395},
	{"COSMO", 5, 60396},
	{"LUBM", 4, 60397},
	{"IMBR", 4, 60398},
	{"LEVERS", 6, 60399},
	{"CUSTER", 6, 60400},
	{"BORDERLINE", 10, 60401},
	{"SURGERIES", 9, 60402},
	{"MDOE", 4, 60403},
	{"LOBBYISTS", 9, 60404},
	{"INCARNATION", 11, 60405},
	{"STRAINED", 8, 60406},
	{"ZIONIST", 7, 60407},
	{"PUTTY", 5, 60408},
	{"REACTED", 7, 60409},
	{"ADMISSIBLE", 10, 60410},
	{"HTRU", 4, 60411},
	{"NYEL", 4, 60412},
	{"SUNLESS", 7, 60413},
	{"BITB", 4, 60414},
	{"PUZZLED", 7, 60415},
	{"UNEXPLAINED", 11, 60416},
	{"RDYE", 4, 60417},
	{"PATSY", 5, 60418},
	{"YLUM", 4, 60419},
	{"UNGD", 4, 60420},
	{"THERMOMETERS", 12, 60421},
	{"FOURTEENTH", 10, 60422},
	{"GASKETS", 7, 60423},
	{"COMPOUNDED", 10, 60424},
	{"PHOTOBLOG", 9, 60425},
	{"RERT", 4, 60426},
	{"CHIPPEWA", 8, 60427},
	{"ELDEST", 6, 60428},
	{"TERRIFYING", 10, 60429},
	{"CLIMBS", 6, 60430},
	{"CUSHING", 7, 60431},
	{"OUDR", 4, 60432},
	{"UPRISING", 8, 60433},
	{"IZEC", 4, 60434},
	{"DHUG", 4, 60435},
	{"GASP", 4, 60436},
	{"DIKN", 4, 60437},
	{"NONSTOP", 7, 60438},
	{"RNAF", 4, 60439},
	{"HUMMEL", 6, 60440},
	{"CORGI", 5, 60441},
	{"YTEM", 4, 60442},
	{"ODGI", 4, 60443},
	{"AWBE", 4, 60444},
	{"SWANS", 5, 60445},
	{"GBEG", 4, 60446},
	{"TORIES", 6, 60447},
	{"ELLIE", 5, 60448},
	{"CITIGROUP", 9, 60449},
	{"PPAN", 4, 60450},
	{"KFIE", 4, 60451},
	{"FFCA", 4, 60452},
	{"DIOB", 4, 60453},
	{"SEASONALLY", 10, 60454},
	{"BIZWOMEN", 8, 60455},
	{"RDTA", 4, 60456},
	{"REMNANT", 7, 60457},
	{"YDRU", 4, 60458},
	{"CKPL", 4, 60459},
	{"IMMORAL", 7, 60460},
	{"MALKIN", 6, 60461},
	{"SACRIFICED", 10, 60462},
	{"MYUN", 4, 60463},
	{"DSYM", 4, 60464},
	{"UNEQUAL", 7, 60465},
	{"ADBRITE", 7, 60466},
	{"STLU", 4, 60467},
	{"IEDG", 4, 60468},
	{"CEKE", 4, 60469},
	{"PSYCHOSOCIAL", 12, 60470},
	{"TYSB", 4, 60471},
	{"BEOB", 4, 60472},
	{"BRAXTON", 7, 60473},
	{"CATEGORICAL", 11, 60474},
	{"YBIT", 4, 60475},
	{"ETYB", 4, 60476},
	{"ELLSWORTH", 9, 60477},
	{"CUPID", 5, 60478},
	{"CLINE", 5, 60479},
	{"UGEC", 4, 60480},
	{"PMAK", 4, 60481},
	{"HBUI", 4, 60482},
	{"EYSF", 4, 60483},
	{"BACKLOG", 7, 60484},
	{"XUW", 3, 60485},
	{"KKP", 3, 60486},
	{"THEMA", 5, 60487},
	{"FILMMAKING", 10, 60488},
	{"STALKING", 8, 60489},
	{"UMID", 4, 60490},
	{"STURGEON", 8, 60491},
	{"TOWNHOMES", 9, 60492},
	{"PIERS", 5, 60493},
	{"ENSUING", 7, 60494},
	{"STWR", 4, 60495},
	{"LEOB", 4, 60496},
	{"MITIGATING", 10, 60497},
	{"EDMC", 4, 60498},
	{"INSTAPUNDIT", 11, 60499},
	{"MCMASTER", 8, 60500},
	{"DYKES", 5, 60501},
	{"REVIVED", 7, 60502},
	{"BAYSIDE", 7, 60503},
	{"JOACHIM", 7, 60504},
	{"THINKCENTRE", 11, 60505},
	{"CYON", 4, 60506},
	{"AEUR", 4, 60507},
	{"UPPA", 4, 60508},
	{"DUNF", 4, 60509},
	{"ANRB", 4, 60510},
	{"BIOPHYS", 7, 60511},
	{"NUGG", 4, 60512},
	{"DUPD", 4, 60513},
	{"HODGKIN", 7, 60514},
	{"EARLE", 5, 60515},
	{"VHOSTS", 6, 60516},
	{"LAUGHLIN", 8, 60517},
	{"NYSM", 4, 60518},
	{"OWNY", 4, 60519},
	{"ODYL", 4, 60520},
	{"ADSB", 4, 60521},
	{"FLAKES", 6, 60522},
	{"ALFALFA", 7, 60523},
	{"CORFU", 5, 60524},
	{"CUIS", 4, 60525},
	{"ARGYLL", 6, 60526},
	{"EMIL", 4, 60527},
	{"RMLE", 4, 60528},
	{"JOKING", 6, 60529},
	{"CONGRESSES", 10, 60530},
	{"ELECTRICALLY", 12, 60531},
	{"KESR", 4, 60532},
	{"CTFI", 4, 60533},
	{"OPHTHALMIC", 10, 60534},
	{"EEPG", 4, 60535},
	{"RHETORICAL", 10, 60536},
	{"PRONG", 5, 60537},
	{"UNRELEASED", 10, 60538},
	{"SIMMER", 6, 60539},
	{"UTKI", 4, 60540},
	{"AHUR", 4, 60541},
	{"CHAPLIN", 7, 60542},
	{"DFW", 3, 60543},
	{"SMALLPOX", 8, 60544},
	{"MFEE", 4, 60545},
	{"HISTOLOGY", 9, 60546},
	{"OVERWHELMINGLY", 14, 60547},
	{"WATERWAY", 8, 60548},
	{"GILMAN", 6, 60549},
	{"KLAMATH", 7, 60550},
	{"ATRIAL", 6, 60551},
	{"MIGRATED", 8, 60552},
	{"PSSU", 4, 60553},
	{"EQUALIZER", 9, 60554},
	{"VBSCRIPT", 8, 60555},
	{"HELMUT", 6, 60556},
	{"DATG", 4, 60557},
	{"REACTS", 6, 60558},
	{"OKCA", 4, 60559},
	{"MMAI", 4, 60560},
	{"NORBERT", 7, 60561},
	{"FJUD", 4, 60562},
	{"COMPLICATION", 12, 60563},
	{"LYNDA", 5, 60564},
	{"FJOB", 4, 60565},
	{"AUBREY", 6, 60566},
	{"GAPL", 4, 60567},
	{"ZAMB", 4, 60568},
	{"IDJA", 4, 60569},
	{"GKNO", 4, 60570},
	{"ADAPTABLE", 9, 60571},
	{"SAINTE", 6, 60572},
	{"BITTE", 5, 60573},
	{"FLEUR", 5, 60574},
	{"COUNCILMEMBER", 13, 60575},
	{"OWBI", 4, 60576},
	{"LUEG", 4, 60577},
	{"GTRU", 4, 60578},
	{"ENDORSES", 8, 60579},
	{"EXPOS", 5, 60580},
	{"MUY", 3, 60581},
	{"YHAW", 4, 60582},
	{"UBEN", 4, 60583},
	{"REWD", 4, 60584},
	{"ETMU", 4, 60585},
	{"CHERISH", 7, 60586},
	{"DHEG", 4, 60587},
	{"LUBR", 4, 60588},
	{"WBRI", 4, 60589},
	{"ACHK", 4, 60590},
	{"UNDEAD", 6, 60591},
	{"IXCO", 4, 60592},
	{"BERTH", 5, 60593},
	{"CRITTERS", 8, 60594},
	{"HODG", 4, 60595},
	{"YHEM", 4, 60596},
	{"UNINTERRUPTED", 13, 60597},
	{"BLOB", 4, 60598},
	{"CHALMERS", 8, 60599},
	{"CRABS", 5, 60600},
	{"KURDS", 5, 60601},
	{"PAGN", 4, 60602},
	{"TUSCAN", 6, 60603},
	{"LINGO", 5, 60604},
	{"UILI", 4, 60605},
	{"ANGP", 4, 60606},
	{"ICAL", 4, 60607},
	{"WNEX", 4, 60608},
	{"MACLEOD", 7, 60609},
	{"URNU", 4, 60610},
	{"DEVRY", 5, 60611},
	{"RAHMAN", 6, 60612},
	{"UOSC", 4, 60613},
	{"RKRI", 4, 60614},
	{"OMDR", 4, 60615},
	{"AWCO", 4, 60616},
	{"EINER", 5, 60617},
	{"FUNDAMENTALIST", 14, 60618},
	{"SUBTRACTION", 11, 60619},
	{"MJUN", 4, 60620},
	{"BUDDING", 7, 60621},
	{"SUPERSTARS", 10, 60622},
	{"GYAT", 4, 60623},
	{"ROAM", 4, 60624},
	{"LDOP", 4, 60625},
	{"RESEMBLANCE", 11, 60626},
	{"HACKNEY", 7, 60627},
	{"CHMOD", 5, 60628},
	{"LEVELING", 8, 60629},
	{"PIGGY", 5, 60630},
	{"STADIUMS", 8, 60631},
	{"ETMY", 4, 60632},
	{"HEBRON", 6, 60633},
	{"SABER", 5, 60634},
	{"DJES", 4, 60635},
	{"CATARACT", 8, 60636},
	{"PLAYABLE", 8, 60637},
	{"SUNOS", 5, 60638},
	{"MIDDAY", 6, 60639},
	{"DBIO", 4, 60640},
	{"INNATE", 6, 60641},
	{"RRYG", 4, 60642},
	{"KMIN", 4, 60643},
	{"LANCIA", 6, 60644},
	{"PERF", 4, 60645},
	{"RSGU", 4, 60646},
	{"OEQU", 4, 60647},
	{"INTERCONNECTED", 14, 60648},
	{"MEDALLION", 9, 60649},
	{"LIEC", 4, 60650},
	{"IGOV", 4, 60651},
	{"TUNNING", 7, 60652},
	{"WHITEPAPER", 10, 60653},
	{"PROMINENTLY", 11, 60654},
	{"NLYV", 4, 60655},
	{"PLATT", 5, 60656},
	{"LEXIS", 5, 60657},
	{"OABU", 4, 60658},
	{"VIROLOGY", 8, 60659},
	{"NAZARETH", 8, 60660},
	{"STGL", 4, 60661},
	{"NMYF", 4, 60662},
	{"NADIA", 5, 60663},
	{"ELYV", 4, 60664},
	{"GLANCED", 7, 60665},
	{"CALAIS", 6, 60666},
	{"RAPTURE", 7, 60667},
	{"PDIS", 4, 60668},
	{"HGER", 4, 60669},
	{"EPAV", 4, 60670},
	{"PURCELL", 7, 60671},
	{"SUNBEAM", 7, 60672},
	{"ABRUPTLY", 8, 60673},
	{"VIDAL", 5, 60674},
	{"SVCS", 4, 60675},
	{"QUOV", 4, 60676},
	{"BEETLES", 7, 60677},
	{"CASPIAN", 7, 60678},
	{"WERU", 4, 60679},
	{"NAMW", 4, 60680},
	{"IMPAIR", 6, 60681},
	{"FEME", 4, 60682},
	{"DBYY", 4, 60683},
	{"SHEPHERDS", 9, 60684},
	{"SUBSYSTEMS", 10, 60685},
	{"OXFAM", 5, 60686},
	{"JOHNSTOWN", 9, 60687},
	{"SUSANNA", 7, 60688},
	{"BEADING", 7, 60689},
	{"ROBUSTNESS", 10, 60690},
	{"KLYC", 4, 60691},
	{"FDOM", 4, 60692},
	{"INTERPLAY", 9, 60693},
	{"AYURVEDA", 8, 60694},
	{"MAINLINE", 8, 60695},
	{"TBYF", 4, 60696},
	{"FOLIC", 5, 60697},
	{"TBYD", 4, 60698},
	{"LLIR", 4, 60699},
	{"VALLEJO", 7, 60700},
	{"PHILOSOPHIES", 12, 60701},
	{"UNRA", 4, 60702},
	{"LAGER", 5, 60703},
	{"ILMD", 4, 60704},
	{"GPUR", 4, 60705},
	{"CMUS", 4, 60706},
	{"PROJECTING", 10, 60707},
	{"GOBLIN", 6, 60708},
	{"BLUFFS", 6, 60709},
	{"RATCHET", 7, 60710},
	{"PARROTS", 7, 60711},
	{"WOBR", 4, 60712},
	{"EGAZ", 4, 60713},
	{"WICCA", 5, 60714},
	{"ANTHEMS", 7, 60715},
	{"PFOU", 4, 60716},
	{"CYGNUS", 6, 60717},
	{"DEPICTION", 9, 60718},
	{"JPL", 3, 60719},
	{"TIERED", 6, 60720},
	{"OGYP", 4, 60721},
	{"KSEV", 4, 60722},
	{"OPTIMA", 6, 60723},
	{"GPEN", 4, 60724},
	{"TERRIFIED", 9, 60725},
	{"KSDI", 4, 60726},
	{"SEWARD", 6, 60727},
	{"NOCTURNAL", 9, 60728},
	{"PHOTONS", 7, 60729},
	{"TRANSACTIONAL", 13, 60730},
	{"EXMA", 4, 60731},
	{"OLFS", 4, 60732},
	{"NUEVA", 5, 60733},
	{"EMULATE", 7, 60734},
	{"DOGGY", 5, 60735},
	{"ANODIZED", 8, 60736},
	{"EXXON", 5, 60737},
	{"HUNTED", 6, 60738},
	{"HURDLE", 6, 60739},
	{"DIMINISHING", 11, 60740},
	{"DONNELLY", 8, 60741},
	{"METASTATIC", 10, 60742},
	{"ENCYCLOPAEDIA", 13, 60743},
	{"ERRATA", 6, 60744},
	{"APLO", 4, 60745},
	{"RIDLEY", 6, 60746},
	{"HLYE", 4, 60747},
	{"DIVAS", 5, 60748},
	{"PRODUITS", 8, 60749},
	{"GHDI", 4, 60750},
	{"TREY", 4, 60751},
	{"VPJ", 3, 60752},
	{"FJB", 3, 60753},
	{"ZIPPED", 6, 60754},
	{"INTREPID", 8, 60755},
	{"FICW", 4, 60756},
	{"BABEL", 5, 60757},
	{"CLUSTERED", 9, 60758},
	{"SBID", 4, 60759},
	{"THANKYOU", 8, 60760},
	{"YAVO", 4, 60761},
	{"GNAG", 4, 60762},
	{"ALERTING", 8, 60763},
	{"QAED", 4, 60764},
	{"INSOFAR", 7, 60765},
	{"SMILEYS", 7, 60766},
	{"PRIMATE", 7, 60767},
	{"GEXE", 4, 60768},
	{"SURROGATE", 9, 60769},
	{"BREATHABLE", 10, 60770},
	{"DIFFERED", 8, 60771},
	{"DICKIES", 7, 60772},
	{"ITZG", 4, 60773},
	{"GONZO", 5, 60774},
	{"GUNC", 4, 60775},
	{"DIBE", 4, 60776},
	{"BYVO", 4, 60777},
	{"EYEBROWS", 8, 60778},
	{"EFTL", 4, 60779},
	{"COMPROMISING", 12, 60780},
	{"PROGRAMMATIC", 12, 60781},
	{"WILLINGLY", 9, 60782},
	{"ORAJ", 4, 60783},
	{"ULYH", 4, 60784},
	{"LLVA", 4, 60785},
	{"LENU", 4, 60786},
	{"TEAMMATES", 9, 60787},
	{"HARLEQUIN", 9, 60788},
	{"NKEV", 4, 60789},
	{"BARRYMORE", 9, 60790},
	{"EMYH", 4, 60791},
	{"DDD", 3, 60792},
	{"BARRACUDA", 9, 60793},
	{"REVISIT", 7, 60794},
	{"LLSG", 4, 60795},
	{"KWOO", 4, 60796},
	{"RBYM", 4, 60797},
	{"ACCESSKEY", 9, 60798},
	{"ARFL", 4, 60799},
	{"APPELLANTS", 10, 60800},
	{"MBOU", 4, 60801},
	{"HDEL", 4, 60802},
	{"INSULTING", 9, 60803},
	{"RTBO", 4, 60804},
	{"PROMINENCE", 10, 60805},
	{"CUCKOO", 6, 60806},
	{"USERGROUPS", 10, 60807},
	{"EHUL", 4, 60808},
	{"IFEG", 4, 60809},
	{"PARRISH", 7, 60810},
	{"INSPIRES", 8, 60811},
	{"INITIATES", 9, 60812},
	{"ACACIA", 6, 60813},
	{"PWD", 3, 60814},
	{"WWEA", 4, 60815},
	{"LICU", 4, 60816},
	{"MATION", 6, 60817},
	{"WHITING", 7, 60818},
	{"FANG", 4, 60819},
	{"NETTING", 7, 60820},
	{"GRIZZLIES", 9, 60821},
	{"OKIDATA", 7, 60822},
	{"METHADONE", 9, 60823},
	{"CONTEMPLATING", 13, 60824},
	{"FSOR", 4, 60825},
	{"OFFSETS", 7, 60826},
	{"TRYIN", 5, 60827},
	{"ERASMUS", 7, 60828},
	{"JODIE", 5, 60829},
	{"JDK", 3, 60830},
	{"ZGER", 4, 60831},
	{"TMYF", 4, 60832},
	{"RECALLING", 9, 60833},
	{"TALLINN", 7, 60834},
	{"DESCARGA", 8, 60835},
	{"PRACTISING", 10, 60836},
	{"HRIM", 4, 60837},
	{"MONTERREY", 9, 60838},
	{"HERMITAGE", 9, 60839},
	{"STARLIGHT", 9, 60840},
	{"URTM", 4, 60841},
	{"HARROGATE", 9, 60842},
	{"LOTTERIES", 9, 60843},
	{"BOZEMAN", 7, 60844},
	{"EPOF", 4, 60845},
	{"DADJ", 4, 60846},
	{"COAUTHOR", 8, 60847},
	{"FOYER", 5, 60848},
	{"ULEF", 4, 60849},
	{"KLYI", 4, 60850},
	{"GONR", 4, 60851},
	{"PALACES", 7, 60852},
	{"LDGA", 4, 60853},
	{"BROOD", 5, 60854},
	{"YMUR", 4, 60855},
	{"RDSG", 4, 60856},
	{"AZURE", 5, 60857},
	{"TTYB", 4, 60858},
	{"CYBERSHOT", 9, 60859},
	{"AIRFLOW", 7, 60860},
	{"VIGI", 4, 60861},
	{"TZGE", 4, 60862},
	{"CONTRADICTIONS", 14, 60863},
	{"SERD", 4, 60864},
	{"AFTF", 4, 60865},
	{"THUR", 4, 60866},
	{"RCHG", 4, 60867},
	{"FESTIVITIES", 11, 60868},
	{"TRENCHES", 8, 60869},
	{"WEDR", 4, 60870},
	{"NBEB", 4, 60871},
	{"SABINE", 6, 60872},
	{"OPER", 4, 60873},
	{"SLYN", 4, 60874},
	{"RNOC", 4, 60875},
	{"DOORSTEP", 8, 60876},
	{"FIMM", 4, 60877},
	{"SNIFF", 5, 60878},
	{"DANGLING", 8, 60879},
	{"PGAT", 4, 60880},
	{"UNATTACHED", 10, 60881},
	{"UTYT", 4, 60882},
	{"MAHER", 5, 60883},
	{"AVYR", 4, 60884},
	{"NEGLIGENT", 9, 60885},
	{"KARLSRUHE", 9, 60886},
	{"GLIDING", 7, 60887},
	{"SLAD", 4, 60888},
	{"YURI", 4, 60889},
	{"OCLU", 4, 60890},
	{"BWHI", 4, 60891},
	{"CHEUNG", 6, 60892},
	{"HONEYMOONERS", 12, 60893},
	{"CHEAPTICKETS", 12, 60894},
	{"MEDITATIONS", 11, 60895},
	{"DFLY", 4, 60896},
	{"HOWIE", 5, 60897},
	{"DIETER", 6, 60898},
	{"CENTERPIECE", 11, 60899},
	{"UDWI", 4, 60900},
	{"MPLAYER", 7, 60901},
	{"NKIM", 4, 60902},
	{"TRANQUILITY", 11, 60903},
	{"UNWIND", 6, 60904},
	{"MJAN", 4, 60905},
	{"HALTED", 6, 60906},
	{"LIZA", 4, 60907},
	{"OUTINGS", 7, 60908},
	{"LKWI", 4, 60909},
	{"ELEW", 4, 60910},
	{"CROTCH", 6, 60911},
	{"LAWB", 4, 60912},
	{"WAVELET", 7, 60913},
	{"DRAWBACK", 8, 60914},
	{"NOTHIN", 6, 60915},
	{"YWEC", 4, 60916},
	{"SMYRNA", 6, 60917},
	{"TEMR", 4, 60918},
	{"PATHOGENESIS", 12, 60919},
	{"DIODES", 6, 60920},
	{"REALESTATE", 10, 60921},
	{"REINSTATEMENT", 13, 60922},
	{"BOTOX", 5, 60923},
	{"WCOL", 4, 60924},
	{"HOSTESS", 7, 60925},
	{"WEEP", 4, 60926},
	{"NROD", 4, 60927},
	{"CLEO", 4, 60928},
	{"POSSE", 5, 60929},
	{"MOSQUITOES", 10, 60930},
	{"FERP", 4, 60931},
	{"NORGE", 5, 60932},
	{"TANGLED", 7, 60933},
	{"GIGA", 4, 60934},
	{"WALSALL", 7, 60935},
	{"OLKI", 4, 60936},
	{"NKGO", 4, 60937},
	{"HDAK", 4, 60938},
	{"COMMUN", 6, 60939},
	{"BURNABY", 7, 60940},
	{"MPEO", 4, 60941},
	{"ASKM", 4, 60942},
	{"LILO", 4, 60943},
	{"MAJORCA", 7, 60944},
	{"RALK", 4, 60945},
	{"WELDON", 6, 60946},
	{"AGRIBUSINESS", 12, 60947},
	{"VALIDATOR", 9, 60948},
	{"FRYING", 6, 60949},
	{"SSUD", 4, 60950},
	{"HESITATION", 10, 60951},
	{"IMPRINTED", 9, 60952},
	{"PIXIE", 5, 60953},
	{"PROOFING", 8, 60954},
	{"CLITS", 5, 60955},
	{"GUNB", 4, 60956},
	{"KEYRING", 7, 60957},
	{"BEREAVEMENT", 11, 60958},
	{"SURRENDERED", 11, 60959},
	{"GUNP", 4, 60960},
	{"VEHICULAR", 9, 60961},
	{"HRID", 4, 60962},
	{"FICD", 4, 60963},
	{"BESTAND", 7, 60964},
	{"WORKBENCH", 9, 60965},
	{"EWSD", 4, 60966},
	{"SERL", 4, 60967},
	{"RAWM", 4, 60968},
	{"DEPH", 4, 60969},
	{"LANDSCAPED", 10, 60970},
	{"UNTP", 4, 60971},
	{"AZIZ", 4, 60972},
	{"LULA", 4, 60973},
	{"WESTWARD", 8, 60974},
	{"NUCL", 4, 60975},
	{"OOMC", 4, 60976},
	{"FARBER", 6, 60977},
	{"IMPALA", 6, 60978},
	{"COMMENTER", 9, 60979},
	{"CONVERGED", 9, 60980},
	{"FIWA", 4, 60981},
	{"CELSIUS", 7, 60982},
	{"FLICKS", 6, 60983},
	{"LEOPOLD", 7, 60984},
	{"RECOGNIZABLE", 12, 60985},
	{"NGOW", 4, 60986},
	{"LTDI", 4, 60987},
	{"HARDWEAR", 8, 60988},
	{"LUDLOW", 6, 60989},
	{"VIDH", 4, 60990},
	{"EUPB", 4, 60991},
	{"SPRAGUE", 7, 60992},
	{"PREFIXES", 8, 60993},
	{"RACQUETBALL", 11, 60994},
	{"ENDL", 4, 60995},
	{"SAYM", 4, 60996},
	{"CWHO", 4, 60997},
	{"EMBRACES", 8, 60998},
	{"FLAVOURS", 8, 60999},
	{"WNAF", 4, 61000},
	{"GUSTAV", 6, 61001},
	{"PUNDITS", 7, 61002},
	{"UNSET", 5, 61003},
	{"MURANO", 6, 61004},
	{"OPTIMISED", 9, 61005},
	{"WAXING", 6, 61006},
	{"BARIATRIC", 9, 61007},
	{"HITCHHIKER", 10, 61008},
	{"GAEL", 4, 61009},
	{"UEDS", 4, 61010},
	{"SINNER", 6, 61011},
	{"ISOTOPES", 8, 61012},
	{"ENTREZ", 6, 61013},
	{"ERICH", 5, 61014},
	{"AUSPICES", 8, 61015},
	{"COLES", 5, 61016},
	{"FFGA", 4, 61017},
	{"ERGO", 4, 61018},
	{"LUMM", 4, 61019},
	{"DGEL", 4, 61020},
	{"DISSENTING", 10, 61021},
	{"MELEE", 5, 61022},
	{"CHDU", 4, 61023},
	{"CONDUCTION", 10, 61024},
	{"FLYB", 4, 61025},
	{"RADCLIFFE", 9, 61026},
	{"COUNTESS", 8, 61027},
	{"QUEP", 4, 61028},
	{"PLEADING", 8, 61029},
	{"MSAB", 4, 61030},
	{"GSYO", 4, 61031},
	{"DVIN", 4, 61032},
	{"GRABBER", 7, 61033},
	{"CRAFTY", 6, 61034},
	{"URPI", 4, 61035},
	{"ORCH", 4, 61036},
	{"LLAMA", 5, 61037},
	{"YRIN", 4, 61038},
	{"MICW", 4, 61039},
	{"PERIDOT", 7, 61040},
	{"MONTAGUE", 8, 61041},
	{"PRODUC", 6, 61042},
	{"SKECHERS", 8, 61043},
	{"LOQU", 4, 61044},
	{"PACERS", 6, 61045},
	{"TROUBLING", 9, 61046},
	{"WWHY", 4, 61047},
	{"SALVATORE", 9, 61048},
	{"VOWEL", 5, 61049},
	{"REUBEN", 6, 61050},
	{"RBC", 3, 61051},
	{"NEUROSCI", 8, 61052},
	{"FEARING", 7, 61053},
	{"CORONATION", 10, 61054},
	{"PARTON", 6, 61055},
	{"LQAE", 4, 61056},
	{"IGBU", 4, 61057},
	{"ARMH", 4, 61058},
	{"APEC", 4, 61059},
	{"ISKM", 4, 61060},
	{"CENTERVILLE", 11, 61061},
	{"MCL", 3, 61062},
	{"ISABELLE", 8, 61063},
	{"IEFJ", 4, 61064},
	{"EBUYER", 6, 61065},
	{"YSCL", 4, 61066},
	{"RYJA", 4, 61067},
	{"LMAJ", 4, 61068},
	{"KONC", 4, 61069},
	{"GOFN", 4, 61070},
	{"DERMATITIS", 10, 61071},
	{"ROXIO", 5, 61072},
	{"NAGOYA", 6, 61073},
	{"UEFI", 4, 61074},
	{"IFTW", 4, 61075},
	{"RELUCTANCE", 10, 61076},
	{"SNOWFALL", 8, 61077},
	{"FUNDRAISERS", 11, 61078},
	{"INCONSISTENCY", 13, 61079},
	{"FECAL", 5, 61080},
	{"VORBIS", 6, 61081},
	{"HAZZARD", 7, 61082},
	{"LBP", 3, 61083},
	{"GORMAN", 6, 61084},
	{"BELM", 4, 61085},
	{"APOSTOLIC", 9, 61086},
	{"VALIDATING", 10, 61087},
	{"HEALTHDAY", 9, 61088},
	{"NEWSSTAND", 9, 61089},
	{"SUMMONED", 8, 61090},
	{"DOSSIER", 7, 61091},
	{"TREBLE", 6, 61092},
	{"GALLEY", 6, 61093},
	{"PSION", 5, 61094},
	{"SHOVEL", 6, 61095},
	{"ENTAIL", 6, 61096},
	{"CORBIN", 6, 61097},
	{"PONB", 4, 61098},
	{"MASHED", 6, 61099},
	{"SONGWRITING", 11, 61100},
	{"DACQ", 4, 61101},
	{"CKJO", 4, 61102},
	{"PACING", 6, 61103},
	{"HINTON", 6, 61104},
	{"NIGHTTIME", 9, 61105},
	{"SMUN", 4, 61106},
	{"DVET", 4, 61107},
	{"FLUXES", 6, 61108},
	{"KOMBAT", 6, 61109},
	{"FINDERS", 7, 61110},
	{"DICTATED", 8, 61111},
	{"DARLENE", 7, 61112},
	{"WESTCOTT", 8, 61113},
	{"LMIG", 4, 61114},
	{"ZLW", 3, 61115},
	{"YYK", 3, 61116},
	{"LPG", 3, 61117},
	{"SBYL", 4, 61118},
	{"OPEC", 4, 61119},
	{"PROXIMAL", 8, 61120},
	{"JIMMIE", 6, 61121},
	{"HENSON", 6, 61122},
	{"UNFOLDING", 9, 61123},
	{"TOTTENHAM", 9, 61124},
	{"DESERTS", 7, 61125},
	{"WGOO", 4, 61126},
	{"DSEY", 4, 61127},
	{"UPNE", 4, 61128},
	{"EUNK", 4, 61129},
	{"MILKING", 7, 61130},
	{"MSBY", 4, 61131},
	{"WILBUR", 6, 61132},
	{"DOMW", 4, 61133},
	{"SEYM", 4, 61134},
	{"SUITABLY", 8, 61135},
	{"CANCIONES", 9, 61136},
	{"DRAU", 4, 61137},
	{"IRIX", 4, 61138},
	{"KSBA", 4, 61139},
	{"DYWE", 4, 61140},
	{"ENORMOUSLY", 10, 61141},
	{"ABER", 4, 61142},
	{"YACQ", 4, 61143},
	{"NMYT", 4, 61144},
	{"DIDF", 4, 61145},
	{"PEROXIDE", 8, 61146},
	{"EJIM", 4, 61147},
	{"CICERO", 6, 61148},
	{"SCRIBE", 6, 61149},
	{"BRYN", 4, 61150},
	{"OGOR", 4, 61151},
	{"NELLIE", 6, 61152},
	{"WSOR", 4, 61153},
	{"OUTAGES", 7, 61154},
	{"SLEIGH", 6, 61155},
	{"COMPLEMENTED", 12, 61156},
	{"LNUT", 4, 61157},
	{"FORMULAE", 8, 61158},
	{"FINLEY", 6, 61159},
	{"KMAY", 4, 61160},
	{"IRIV", 4, 61161},
	{"RMOI", 4, 61162},
	{"RMBU", 4, 61163},
	{"ERGW", 4, 61164},
	{"DOBJ", 4, 61165},
	{"BACKLASH", 8, 61166},
	{"GALLO", 5, 61167},
	{"RYSS", 4, 61168},
	{"CEDG", 4, 61169},
	{"AGENCE", 6, 61170},
	{"VELM", 4, 61171},
	{"TAXD", 4, 61172},
	{"ONYP", 4, 61173},
	{"FRONTAGE", 8, 61174},
	{"BLISTER", 7, 61175},
	{"GVIE", 4, 61176},
	{"KJV", 3, 61177},
	{"EDYT", 4, 61178},
	{"JONNY", 5, 61179},
	{"NELB", 4, 61180},
	{"VDY", 3, 61181},
	{"BIBLIO", 6, 61182},
	{"OPACITY", 7, 61183},
	{"RATION", 6, 61184},
	{"USERLAND", 8, 61185},
	{"GCLE", 4, 61186},
	{"BITU", 4, 61187},
	{"TOWNSVILLE", 10, 61188},
	{"HUMID", 5, 61189},
	{"TURING", 6, 61190},
	{"OMCE", 4, 61191},
	{"IUMH", 4, 61192},
	{"PORTRAYAL", 9, 61193},
	{"VEGGIES", 7, 61194},
	{"CENTENARY", 9, 61195},
	{"MPEA", 4, 61196},
	{"LTWH", 4, 61197},
	{"GUILE", 5, 61198},
	{"LACQUER", 7, 61199},
	{"OBIC", 4, 61200},
	{"BARCLAYS", 8, 61201},
	{"HAMMERED", 8, 61202},
	{"YIGN", 4, 61203},
	{"YERN", 4, 61204},
	{"DREXEL", 6, 61205},
	{"PEDAGOGICAL", 11, 61206},
	{"LOCKHART", 8, 61207},
	{"TUTTI", 5, 61208},
	{"MINED", 5, 61209},
	{"CAUCASUS", 8, 61210},
	{"USAU", 4, 61211},
	{"ORNJ", 4, 61212},
	{"INTERVENING", 11, 61213},
	{"BALE", 4, 61214},
	{"ASTRONOMERS", 11, 61215},
	{"FISHNET", 7, 61216},
	{"COMBINATORIAL", 13, 61217},
	{"THRILLS", 7, 61218},
	{"THEREFOR", 8, 61219},
	{"RFEW", 4, 61220},
	{"HFLA", 4, 61221},
	{"ALCY", 4, 61222},
	{"UNINTENDED", 10, 61223},
	{"SORES", 5, 61224},
	{"SHUF", 4, 61225},
	{"RTDU", 4, 61226},
	{"ZERB", 4, 61227},
	{"RAMAN", 5, 61228},
	{"ROCHDALE", 8, 61229},
	{"PRNEWSWIRE", 10, 61230},
	{"YIDO", 4, 61231},
	{"UCKD", 4, 61232},
	{"ALTL", 4, 61233},
	{"PASTURES", 8, 61234},
	{"SMOG", 4, 61235},
	{"IPOR", 4, 61236},
	{"UNATTENDED", 10, 61237},
	{"UCL", 3, 61238},
	{"SJEW", 4, 61239},
	{"MSDI", 4, 61240},
	{"PLAYWRIGHT", 10, 61241},
	{"MICS", 4, 61242},
	{"PUNJABI", 7, 61243},
	{"PREM", 4, 61244},
	{"ICYM", 4, 61245},
	{"KATALOG", 7, 61246},
	{"CARTHAGE", 8, 61247},
	{"ZECHARIAH", 9, 61248},
	{"SKIW", 4, 61249},
	{"KETTERING", 9, 61250},
	{"HAYEK", 5, 61251},
	{"BROOKLINE", 9, 61252},
	{"MONTPELIER", 10, 61253},
	{"SELVES", 6, 61254},
	{"RDGO", 4, 61255},
	{"NATURALIZATION", 14, 61256},
	{"ARYK", 4, 61257},
	{"WHISPERING", 10, 61258},
	{"YGUY", 4, 61259},
	{"KMAT", 4, 61260},
	{"INDG", 4, 61261},
	{"DISSIPATION", 11, 61262},
	{"SPRITE", 6, 61263},
	{"OWJO", 4, 61264},
	{"ECIL", 4, 61265},
	{"KEEL", 4, 61266},
	{"FART", 4, 61267},
	{"RCHN", 4, 61268},
	{"OMRU", 4, 61269},
	{"NAGU", 4, 61270},
	{"OXIDASE", 7, 61271},
	{"LEIGHTON", 8, 61272},
	{"GCHO", 4, 61273},
	{"ILJU", 4, 61274},
	{"ONRY", 4, 61275},
	{"KCAM", 4, 61276},
	{"DUPC", 4, 61277},
	{"ATHEISM", 7, 61278},
	{"GRIPPING", 8, 61279},
	{"NKSP", 4, 61280},
	{"CELLARS", 7, 61281},
	{"CATERER", 7, 61282},
	{"PREGNANCIES", 11, 61283},
	{"FIORI", 5, 61284},
	{"AWWH", 4, 61285},
	{"TAINTED", 7, 61286},
	{"DATELINE", 8, 61287},
	{"REMISSION", 9, 61288},
	{"PRAXIS", 6, 61289},
	{"AFFIRMATION", 11, 61290},
	{"LYOT", 4, 61291},
	{"LUBF", 4, 61292},
	{"STDOUT", 6, 61293},
	{"PERTURBATION", 12, 61294},
	{"OBCA", 4, 61295},
	{"KGRE", 4, 61296},
	{"WANDERED", 8, 61297},
	{"UNASSIGNED", 10, 61298},
	{"ADRIANA", 7, 61299},
	{"REEDS", 5, 61300},
	{"NDHY", 4, 61301},
	{"LYNDON", 6, 61302},
	{"ILWO", 4, 61303},
	{"EBYW", 4, 61304},
	{"GROUPINGS", 9, 61305},
	{"MEMS", 4, 61306},
	{"ANGLER", 6, 61307},
	{"MIDTERM", 7, 61308},
	{"ASTOUNDING", 10, 61309},
	{"HCHU", 4, 61310},
	{"EMSR", 4, 61311},
	{"CHKE", 4, 61312},
	{"COSY", 4, 61313},
	{"CAMPSITE", 8, 61314},
	{"DROPDOWN", 8, 61315},
	{"MARKETER", 8, 61316},
	{"UELP", 4, 61317},
	{"RESEND", 6, 61318},
	{"BSWE", 4, 61319},
	{"NBUC", 4, 61320},
	{"AUGMENT", 7, 61321},
	{"FLARES", 6, 61322},
	{"DOWM", 4, 61323},
	{"UESL", 4, 61324},
	{"HUNTINGDON", 10, 61325},
	{"JCPENNEY", 8, 61326},
	{"MTRE", 4, 61327},
	{"GELATIN", 7, 61328},
	{"QVC", 3, 61329},
	{"SHEDDING", 8, 61330},
	{"ADENOSINE", 9, 61331},
	{"DCOC", 4, 61332},
	{"AFFR", 4, 61333},
	{"GLASTONBURY", 11, 61334},
	{"FUNERALS", 8, 61335},
	{"VYAN", 4, 61336},
	{"LMID", 4, 61337},
	{"FDAV", 4, 61338},
	{"MILLISECONDS", 12, 61339},
	{"SWATCH", 6, 61340},
	{"SBYO", 4, 61341},
	{"EUCALYPTUS", 10, 61342},
	{"REDEFINE", 8, 61343},
	{"GOWE", 4, 61344},
	{"LZY", 3, 61345},
	{"CONSERVATISM", 12, 61346},
	{"WTOU", 4, 61347},
	{"BSWI", 4, 61348},
	{"QUESTA", 6, 61349},
	{"BACKDOOR", 8, 61350},
	{"JAZEERA", 7, 61351},
	{"ENVISIONED", 10, 61352},
	{"NTYY", 4, 61353},
	{"KMEN", 4, 61354},
	{"RLWH", 4, 61355},
	{"GNWI", 4, 61356},
	{"EXTREM", 6, 61357},
	{"GOTP", 4, 61358},
	{"BUMPED", 6, 61359},
	{"BOYL", 4, 61360},
	{"AUTOMATING", 10, 61361},
	{"SEMPRON", 7, 61362},
	{"CURSORS", 7, 61363},
	{"FORTUNA", 7, 61364},
	{"CRIPPLE", 7, 61365},
	{"RPUL", 4, 61366},
	{"DIVERT", 6, 61367},
	{"MESV", 4, 61368},
	{"LOFTY", 5, 61369},
	{"PHNOM", 5, 61370},
	{"KECI", 4, 61371},
	{"IMWE", 4, 61372},
	{"KANJI", 5, 61373},
	{"YBUD", 4, 61374},
	{"RECREATE", 8, 61375},
	{"RCOT", 4, 61376},
	{"IPTU", 4, 61377},
	{"SMACKDOWN", 9, 61378},
	{"DROPOUT", 7, 61379},
	{"AYOV", 4, 61380},
	{"DSCU", 4, 61381},
	{"CROPPED", 7, 61382},
	{"JRST", 4, 61383},
	{"FALLUJAH", 8, 61384},
	{"YSIL", 4, 61385},
	{"TULS", 4, 61386},
	{"KADV", 4, 61387},
	{"CTIF", 4, 61388},
	{"LOCKOUT", 7, 61389},
	{"MMIE", 4, 61390},
	{"IGPL", 4, 61391},
	{"YBYC", 4, 61392},
	{"ULMO", 4, 61393},
	{"MORON", 5, 61394},
	{"TWAV", 4, 61395},
	{"CEIM", 4, 61396},
	{"TOWNHOUSES", 10, 61397},
	{"MERTON", 6, 61398},
	{"SWOL", 4, 61399},
	{"OJUN", 4, 61400},
	{"HORRIFIC", 8, 61401},
	{"ABACUS", 6, 61402},
	{"LIFELINE", 8, 61403},
	{"RICHLY", 6, 61404},
	{"RYCI", 4, 61405},
	{"DSAU", 4, 61406},
	{"TORQUAY", 7, 61407},
	{"CONJUGATE", 9, 61408},
	{"OMAV", 4, 61409},
	{"RAVI", 4, 61410},
	{"DOGMA", 5, 61411},
	{"PRIORI", 6, 61412},
	{"LURR", 4, 61413},
	{"VAGUELY", 7, 61414},
	{"QPU", 3, 61415},
	{"MFIE", 4, 61416},
	{"LUSM", 4, 61417},
	{"WINCH", 5, 61418},
	{"DGOR", 4, 61419},
	{"ELEKTRA", 7, 61420},
	{"SIBERIA", 7, 61421},
	{"KSLE", 4, 61422},
	{"WEBTRENDS", 9, 61423},
	{"MELONS", 6, 61424},
	{"FARLEY", 6, 61425},
	{"YSYO", 4, 61426},
	{"CKJA", 4, 61427},
	{"WSBE", 4, 61428},
	{"EKDA", 4, 61429},
	{"EVILS", 5, 61430},
	{"SPONTANEOUSLY", 13, 61431},
	{"SABOTAGE", 8, 61432},
	{"BLUEPRINTS", 10, 61433},
	{"LIMOS", 5, 61434},
	{"LFMA", 4, 61435},
	{"COCE", 4, 61436},
	{"MAWO", 4, 61437},
	{"AYSV", 4, 61438},
	{"MDAN", 4, 61439},
	{"UNAVOIDABLE", 11, 61440},
	{"ROLP", 4, 61441},
	{"FRAUNHOFER", 10, 61442},
	{"LCUS", 4, 61443},
	{"HTCR", 4, 61444},
	{"WARHOL", 6, 61445},
	{"SUPPRESSOR", 10, 61446},
	{"DOGPILE", 7, 61447},
	{"OYSB", 4, 61448},
	{"GMOM", 4, 61449},
	{"ERML", 4, 61450},
	{"RUTHLESS", 8, 61451},
	{"ALMONDS", 7, 61452},
	{"ECCLESIASTES", 12, 61453},
	{"WEBP", 4, 61454},
	{"EDMR", 4, 61455},
	{"APTITUDE", 8, 61456},
	{"BIRT", 4, 61457},
	{"VIAL", 4, 61458},
	{"RENSSELAER", 10, 61459},
	{"SHARPENING", 10, 61460},
	{"SENIORITY", 9, 61461},
	{"YVET", 4, 61462},
	{"JOCKS", 5, 61463},
	{"PROMPTING", 9, 61464},
	{"OBJECTED", 8, 61465},
	{"IPUR", 4, 61466},
	{"EQUATOR", 7, 61467},
	{"UNZIP", 5, 61468},
	{"GUILDS", 6, 61469},
	{"BLATANT", 7, 61470},
	{"YPAU", 4, 61471},
	{"RKDE", 4, 61472},
	{"FLOSS", 5, 61473},
	{"VEDG", 4, 61474},
	{"PSLI", 4, 61475},
	{"FAVOURED", 8, 61476},
	{"SARGE", 5, 61477},
	{"ENDNOTE", 7, 61478},
	{"OSUM", 4, 61479},
	{"EDAJ", 4, 61480},
	{"RIDGES", 6, 61481},
	{"LELAND", 6, 61482},
	{"OYSTERS", 7, 61483},
	{"TELUGU", 6, 61484},
	{"MIDWIFERY", 9, 61485},
	{"HUFF", 4, 61486},
	{"GSQU", 4, 61487},
	{"PRIMATES", 8, 61488},
	{"NMOB", 4, 61489},
	{"KXP", 3, 61490},
	{"GUST", 4, 61491},
	{"WREP", 4, 61492},
	{"NBYW", 4, 61493},
	{"DJUR", 4, 61494},
	{"RECEPTACLE", 10, 61495},
	{"COUC", 4, 61496},
	{"TANGERINE", 9, 61497},
	{"MENDOZA", 7, 61498},
	{"AMOXICILLIN", 11, 61499},
	{"GRAZ", 4, 61500},
	{"NNYP", 4, 61501},
	{"PUBERTY", 7, 61502},
	{"BASINGSTOKE", 11, 61503},
	{"CRAWLER", 7, 61504},
	{"ANGLED", 6, 61505},
	{"DYDO", 4, 61506},
	{"COMIN", 5, 61507},
	{"SHORTEN", 7, 61508},
	{"LONGHORNS", 9, 61509},
	{"UPWE", 4, 61510},
	{"MICL", 4, 61511},
	{"GVOT", 4, 61512},
	{"YLOU", 4, 61513},
	{"RLSB", 4, 61514},
	{"EBSCO", 5, 61515},
	{"EPTM", 4, 61516},
	{"SHAWL", 5, 61517},
	{"LYNCHBURG", 9, 61518},
	{"OVERRIDING", 10, 61519},
	{"GEMU", 4, 61520},
	{"NPUS", 4, 61521},
	{"SAMARITAN", 9, 61522},
	{"BENDS", 5, 61523},
	{"ERGH", 4, 61524},
	{"TUSB", 4, 61525},
	{"LYAI", 4, 61526},
	{"GRIMES", 6, 61527},
	{"WILSHIRE", 8, 61528},
	{"UNISON", 6, 61529},
	{"TABULAR", 7, 61530},
	{"NUPD", 4, 61531},
	{"GESY", 4, 61532},
	{"WACHOVIA", 8, 61533},
	{"VAGU", 4, 61534},
	{"FTPI", 4, 61535},
	{"GROFF", 5, 61536},
	{"AMIR", 4, 61537},
	{"APSM", 4, 61538},
	{"DORMANT", 7, 61539},
	{"OJUD", 4, 61540},
	{"CTPE", 4, 61541},
	{"NELL", 4, 61542},
	{"YSGE", 4, 61543},
	{"GGOL", 4, 61544},
	{"RESTRAINED", 10, 61545},
	{"WPOS", 4, 61546},
	{"RKSU", 4, 61547},
	{"ILMB", 4, 61548},
	{"GLOA", 4, 61549},
	{"TROPICS", 7, 61550},
	{"DIFA", 4, 61551},
	{"INVICTA", 7, 61552},
	{"CONCERTED", 9, 61553},
	{"DONGLE", 6, 61554},
	{"WILI", 4, 61555},
	{"TANAKA", 6, 61556},
	{"INTERNACIONAL", 13, 61557},
	{"TULT", 4, 61558},
	{"DWIR", 4, 61559},
	{"KWAN", 4, 61560},
	{"CDL", 3, 61561},
	{"YEDE", 4, 61562},
	{"AVENIR", 6, 61563},
	{"REFRIGERATED", 12, 61564},
	{"CROUCH", 6, 61565},
	{"UQB", 3, 61566},
	{"ARCHIV", 6, 61567},
	{"DEEX", 4, 61568},
	{"PENCE", 5, 61569},
	{"ITDR", 4, 61570},
	{"FORMULATING", 11, 61571},
	{"LAMENTATIONS", 12, 61572},
	{"PLACID", 6, 61573},
	{"NAPKIN", 6, 61574},
	{"UOSP", 4, 61575},
	{"RAYB", 4, 61576},
	{"EMILE", 5, 61577},
	{"CONTAGIOUS", 10, 61578},
	{"LENIN", 5, 61579},
	{"INACCESSIBLE", 12, 61580},
	{"ZEWI", 4, 61581},
	{"OMFL", 4, 61582},
	{"HECP", 4, 61583},
	{"MARSHA", 6, 61584},
	{"ADMINISTERS", 11, 61585},
	{"OTCR", 4, 61586},
	{"GRADIENTS", 9, 61587},
	{"CROCKETT", 8, 61588},
	{"OACL", 4, 61589},
	{"MECI", 4, 61590},
	{"CONSPICUOUS", 11, 61591},
	{"BARBARIAN", 9, 61592},
	{"RITALIN", 7, 61593},
	{"RETRIEVES", 9, 61594},
	{"SOAKING", 7, 61595},
	{"UBTO", 4, 61596},
	{"FERROUS", 7, 61597},
	{"NELF", 4, 61598},
	{"FDON", 4, 61599},
	{"DHAKA", 5, 61600},
	{"UUSE", 4, 61601},
	{"LMBE", 4, 61602},
	{"REFORMING", 9, 61603},
	{"RLEE", 4, 61604},
	{"JARE", 4, 61605},
	{"HEBC", 4, 61606},
	{"OKIC", 4, 61607},
	{"GBAD", 4, 61608},
	{"INTRUSIVE", 9, 61609},
	{"RNOG", 4, 61610},
	{"EDVD", 4, 61611},
	{"ICOB", 4, 61612},
	{"THYME", 5, 61613},
	{"PARASITIC", 9, 61614},
	{"ZILLION", 7, 61615},
	{"CHINO", 5, 61616},
	{"ABUSING", 7, 61617},
	{"LJOB", 4, 61618},
	{"GSMI", 4, 61619},
	{"CAVEAT", 6, 61620},
	{"RECEPTIVE", 9, 61621},
	{"NOLY", 4, 61622},
	{"IAMR", 4, 61623},
	{"TOILETRIES", 10, 61624},
	{"BEDROCK", 7, 61625},
	{"CAPT", 4, 61626},
	{"MDOI", 4, 61627},
	{"HCLE", 4, 61628},
	{"EARJ", 4, 61629},
	{"CHQU", 4, 61630},
	{"YKEN", 4, 61631},
	{"CLIO", 4, 61632},
	{"XVII", 4, 61633},
	{"YAFI", 4, 61634},
	{"HMIR", 4, 61635},
	{"ZINES", 5, 61636},
	{"MULTIPART", 9, 61637},
	{"VULCAN", 6, 61638},
	{"GALF", 4, 61639},
	{"MUSK", 4, 61640},
	{"LUCILLE", 7, 61641},
	{"EXECUTIONS", 10, 61642},
	{"RSBL", 4, 61643},
	{"FORKLIFT", 8, 61644},
	{"YXL", 3, 61645},
	{"MZY", 3, 61646},
	{"GFOL", 4, 61647},
	{"REFRESHED", 9, 61648},
	{"GUARDING", 8, 61649},
	{"NBYJ", 4, 61650},
	{"EEML", 4, 61651},
	{"HBER", 4, 61652},
	{"REPURCHASE", 10, 61653},
	{"ATWOOD", 6, 61654},
	{"YVEG", 4, 61655},
	{"URTJ", 4, 61656},
	{"WINDMILL", 8, 61657},
	{"ORTHOPEDICS", 11, 61658},
	{"LICE", 4, 61659},
	{"FGLA", 4, 61660},
	{"NFPA", 4, 61661},
	{"BADGERS", 7, 61662},
	{"NGAZ", 4, 61663},
	{"CERM", 4, 61664},
	{"GARTER", 6, 61665},
	{"APPETIZER", 9, 61666},
	{"OUCE", 4, 61667},
	{"WEBLINKS", 8, 61668},
	{"TVID", 4, 61669},
	{"FMYL", 4, 61670},
	{"TELEMETRY", 9, 61671},
	{"FOOTED", 6, 61672},
	{"XEDW", 4, 61673},
	{"SLYU", 4, 61674},
	{"IXGA", 4, 61675},
	{"YIFI", 4, 61676},
	{"QUEU", 4, 61677},
	{"EPDO", 4, 61678},
	{"LIBROS", 6, 61679},
	{"RENEWING", 8, 61680},
	{"BURROUGHS", 9, 61681},
	{"CONSUMABLE", 10, 61682},
	{"NRUR", 4, 61683},
	{"DEPRESSIVE", 10, 61684},
	{"SKWH", 4, 61685},
	{"NBYL", 4, 61686},
	{"STABILIZER", 10, 61687},
	{"HEFD", 4, 61688},
	{"RBIO", 4, 61689},
	{"SKIM", 4, 61690},
	{"TOUCHE", 6, 61691},
	{"ECZE", 4, 61692},
	{"OVARY", 5, 61693},
	{"RUNE", 4, 61694},
	{"SSRU", 4, 61695},
	{"OMOC", 4, 61696},
	{"MLOS", 4, 61697},
	{"WELT", 4, 61698},
	{"ACCRUAL", 7, 61699},
	{"LDBL", 4, 61700},
	{"VEAL", 4, 61701},
	{"PERPETRATORS", 12, 61702},
	{"USMU", 4, 61703},
	{"NMIK", 4, 61704},
	{"HWRI", 4, 61705},
	{"CREATIVELY", 10, 61706},
	{"URYL", 4, 61707},
	{"PSDE", 4, 61708},
	{"NMYB", 4, 61709},
	{"EMBARKED", 8, 61710},
	{"QUICKEST", 8, 61711},
	{"OVIL", 4, 61712},
	{"BCHA", 4, 61713},
	{"EUCLID", 6, 61714},
	{"TREMENDOUSLY", 12, 61715},
	{"ANGLAIS", 7, 61716},
	{"SMASHED", 7, 61717},
	{"UDLY", 4, 61718},
	{"OSCILLATION", 11, 61719},
	{"LVEH", 4, 61720},
	{"LSYO", 4, 61721},
	{"PTWI", 4, 61722},
	{"FFAB", 4, 61723},
	{"DIWI", 4, 61724},
	{"INTERFAITH", 10, 61725},
	{"AUTOMATA", 8, 61726},
	{"NORTHWOOD", 9, 61727},
	{"THUNDERSTORM", 12, 61728},
	{"PAYERS", 6, 61729},
	{"GRITTY", 6, 61730},
	{"XILI", 4, 61731},
	{"DUPR", 4, 61732},
	{"DMOM", 4, 61733},
	{"RETROSPECT", 10, 61734},
	{"GDIV", 4, 61735},
	{"DEWITT", 6, 61736},
	{"DWET", 4, 61737},
	{"HAILED", 6, 61738},
	{"BAHIA", 5, 61739},
	{"SLOR", 4, 61740},
	{"MIRACULOUS", 10, 61741},
	{"HOUNDS", 6, 61742},
	{"TIGHTENING", 10, 61743},
	{"SUEF", 4, 61744},
	{"DRAINING", 8, 61745},
	{"NGEG", 4, 61746},
	{"RECT", 4, 61747},
	{"PAROLES", 7, 61748},
	{"RSTJ", 4, 61749},
	{"SENSIBILITY", 11, 61750},
	{"PONM", 4, 61751},
	{"GGUI", 4, 61752},
	{"SEBRING", 7, 61753},
	{"RAGS", 4, 61754},
	{"REBORN", 6, 61755},
	{"UNRI", 4, 61756},
	{"PUNCHING", 8, 61757},
	{"USYO", 4, 61758},
	{"TUNF", 4, 61759},
	{"MKIN", 4, 61760},
	{"LENR", 4, 61761},
	{"HOPU", 4, 61762},
	{"LAGRANGE", 8, 61763},
	{"RODG", 4, 61764},
	{"PSYO", 4, 61765},
	{"IRVE", 4, 61766},
	{"DYSP", 4, 61767},
	{"DISTINGUISHES", 13, 61768},
	{"TREADMILLS", 10, 61769},
	{"BOFT", 4, 61770},
	{"FJAC", 4, 61771},
	{"EYJO", 4, 61772},
	{"BEBOP", 5, 61773},
	{"STREAMLINING", 12, 61774},
	{"RNWO", 4, 61775},
	{"AULK", 4, 61776},
	{"DAZZLE", 6, 61777},
	{"TRAININGS", 9, 61778},
	{"SEEDING", 7, 61779},
	{"YETC", 4, 61780},
	{"APHR", 4, 61781},
	{"ULYSSES", 7, 61782},
	{"INDUSTRIALIZED", 14, 61783},
	{"DANGLE", 6, 61784},
	{"EATERS", 6, 61785},
	{"BOTANIC", 7, 61786},
	{"BRONCO", 6, 61787},
	{"EXCEEDINGLY", 11, 61788},
	{"INAUGURATION", 12, 61789},
	{"RTYN", 4, 61790},
	{"INQUIRED", 8, 61791},
	{"MEOL", 4, 61792},
	{"DEEF", 4, 61793},
	{"REPENTANCE", 10, 61794},
	{"MOODLE", 6, 61795},
	{"CHASED", 6, 61796},
	{"UNPROTECTED", 11, 61797},
	{"MERLE", 5, 61798},
	{"KASW", 4, 61799},
	{"SAVORY", 6, 61800},
	{"INTERMEDIARIES", 14, 61801},
	{"RKIC", 4, 61802},
	{"ROTATIONS", 9, 61803},
	{"EVACUATED", 9, 61804},
	{"EMAU", 4, 61805},
	{"YPUS", 4, 61806},
	{"RECLAIMED", 9, 61807},
	{"PREFECTURE", 10, 61808},
	{"ACCENTED", 8, 61809},
	{"CRAWLEY", 7, 61810},
	{"UKIN", 4, 61811},
	{"HCUR", 4, 61812},
	{"DKAN", 4, 61813},
	{"KNOPPIX", 7, 61814},
	{"RTIZ", 4, 61815},
	{"MONTESSORI", 10, 61816},
	{"BIOMED", 6, 61817},
	{"MURINE", 6, 61818},
	{"ENTOMOLOGY", 10, 61819},
	{"BAUM", 4, 61820},
	{"RODENT", 6, 61821},
	{"PARADIGMS", 9, 61822},
	{"RSIB", 4, 61823},
	{"KOFN", 4, 61824},
	{"GGIV", 4, 61825},
	{"DDUN", 4, 61826},
	{"DWAG", 4, 61827},
	{"RACKET", 6, 61828},
	{"HANNIBAL", 8, 61829},
	{"PUTTER", 6, 61830},
	{"FONDA", 5, 61831},
	{"RECURSION", 9, 61832},
	{"FLOPS", 5, 61833},
	{"SICKLE", 6, 61834},
	{"VIOLENTLY", 9, 61835},
	{"CCOY", 4, 61836},
	{"ATTEST", 6, 61837},
	{"UNTOUCHED", 9, 61838},
	{"INITIATOR", 9, 61839},
	{"MYRI", 4, 61840},
	{"POBOX", 5, 61841},
	{"COMFORTING", 10, 61842},
	{"ZEISS", 5, 61843},
	{"CREEPING", 8, 61844},
	{"GNOM", 4, 61845},
	{"AYCE", 4, 61846},
	{"LSRO", 4, 61847},
	{"UCEW", 4, 61848},
	{"KEROSENE", 8, 61849},
	{"APPRAISED", 9, 61850},
	{"RMYH", 4, 61851},
	{"RESTORATIVE", 11, 61852},
	{"FERC", 4, 61853},
	{"EVAU", 4, 61854},
	{"SUNSCREEN", 9, 61855},
	{"HVIC", 4, 61856},
	{"LLVM", 4, 61857},
	{"KJUS", 4, 61858},
	{"PEACEFULLY", 10, 61859},
	{"ANTIDEPRESSANTS", 15, 61860},
	{"DECENTRALIZED", 13, 61861},
	{"FREAKING", 8, 61862},
	{"MFLO", 4, 61863},
	{"GFLA", 4, 61864},
	{"WHITTIER", 8, 61865},
	{"ELMIRA", 6, 61866},
	{"CUTC", 4, 61867},
	{"BASSIST", 7, 61868},
	{"OAKVILLE", 8, 61869},
	{"STATURE", 7, 61870},
	{"SKATERS", 7, 61871},
	{"SENTRY", 6, 61872},
	{"ASSAULTS", 8, 61873},
	{"KMEA", 4, 61874},
	{"KINR", 4, 61875},
	{"UPME", 4, 61876},
	{"LUMINOSITY", 10, 61877},
	{"BUV", 3, 61878},
	{"BERWICK", 7, 61879},
	{"EMULATORS", 9, 61880},
	{"TOEFL", 5, 61881},
	{"FFBU", 4, 61882},
	{"BDUC", 4, 61883},
	{"AILD", 4, 61884},
	{"VICES", 5, 61885},
	{"SFAU", 4, 61886},
	{"HAYW", 4, 61887},
	{"KEYCHAINS", 9, 61888},
	{"KARAT", 5, 61889},
	{"MODIS", 5, 61890},
	{"GINNY", 5, 61891},
	{"TOLLS", 5, 61892},
	{"DHUS", 4, 61893},
	{"DEGRADING", 9, 61894},
	{"RYBL", 4, 61895},
	{"BANGLES", 7, 61896},
	{"ACKV", 4, 61897},
	{"STEREOS", 7, 61898},
	{"SUBMITTAL", 9, 61899},
	{"BNIB", 4, 61900},
	{"RNBY", 4, 61901},
	{"FORSTER", 7, 61902},
	{"SUPD", 4, 61903},
	{"FIREMAN", 7, 61904},
	{"WSLI", 4, 61905},
	{"UEMO", 4, 61906},
	{"NKCA", 4, 61907},
	{"GTOY", 4, 61908},
	{"MINK", 4, 61909},
	{"SIMULATORS", 10, 61910},
	{"ULWH", 4, 61911},
	{"IMAW", 4, 61912},
	{"CSAL", 4, 61913},
	{"NAGAR", 5, 61914},
	{"BADW", 4, 61915},
	{"ZORRO", 5, 61916},
	{"MANIAC", 6, 61917},
	{"ECRAN", 5, 61918},
	{"TTPW", 4, 61919},
	{"TJUM", 4, 61920},
	{"KECR", 4, 61921},
	{"ANTICS", 6, 61922},
	{"YSDA", 4, 61923},
	{"REGL", 4, 61924},
	{"HUSC", 4, 61925},
	{"DEZE", 4, 61926},
	{"CHPI", 4, 61927},
	{"YVEN", 4, 61928},
	{"RMDE", 4, 61929},
	{"PPEO", 4, 61930},
	{"MREG", 4, 61931},
	{"EXTL", 4, 61932},
	{"EALING", 6, 61933},
	{"OZARK", 5, 61934},
	{"PFEIFFER", 8, 61935},
	{"RNSP", 4, 61936},
	{"DOYL", 4, 61937},
	{"COYO", 4, 61938},
	{"MIERS", 5, 61939},
	{"OACR", 4, 61940},
	{"LEXH", 4, 61941},
	{"GTOV", 4, 61942},
	{"ERMB", 4, 61943},
	{"FORMATIVE", 9, 61944},
	{"VICKERS", 7, 61945},
	{"RECOGNISING", 11, 61946},
	{"INTERACTIVITY", 13, 61947},
	{"DSMU", 4, 61948},
	{"CORSO", 5, 61949},
	{"WORDSWORTH", 10, 61950},
	{"CONSTRUCTORS", 12, 61951},
	{"WRONGLY", 7, 61952},
	{"BALP", 4, 61953},
	{"CREE", 4, 61954},
	{"USEK", 4, 61955},
	{"UNWH", 4, 61956},
	{"GEIG", 4, 61957},
	{"ARJU", 4, 61958},
	{"JAMA", 4, 61959},
	{"PHYSICISTS", 10, 61960},
	{"MALFUNCTION", 11, 61961},
	{"FALSELY", 7, 61962},
	{"ABBOT", 5, 61963},
	{"MAGMA", 5, 61964},
	{"LGEB", 4, 61965},
	{"HYCO", 4, 61966},
	{"SMITHFIELD", 10, 61967},
	{"BOYI", 4, 61968},
	{"AVYD", 4, 61969},
	{"CANUCKS", 7, 61970},
	{"QBG", 3, 61971},
	{"HAMMERSMITH", 11, 61972},
	{"CRICOS", 6, 61973},
	{"GOTW", 4, 61974},
	{"OFFICIO", 7, 61975},
	{"BLUM", 4, 61976},
	{"CONSUL", 6, 61977},
	{"ODDR", 4, 61978},
	{"MWEA", 4, 61979},
	{"NEDJ", 4, 61980},
	{"MEDJ", 4, 61981},
	{"PLAGUED", 7, 61982},
	{"PARKLAND", 8, 61983},
	{"LAHORE", 6, 61984},
	{"PCBS", 4, 61985},
	{"AIDING", 6, 61986},
	{"WEREWOLF", 8, 61987},
	{"GJOH", 4, 61988},
	{"ARIW", 4, 61989},
	{"NNYM", 4, 61990},
	{"FSKI", 4, 61991},
	{"KUNST", 5, 61992},
	{"SUCKERS", 7, 61993},
	{"MIDWESTERN", 10, 61994},
	{"WEXP", 4, 61995},
	{"HCLU", 4, 61996},
	{"EZBOARD", 7, 61997},
	{"ISLU", 4, 61998},
	{"CTPO", 4, 61999},
	{"SWALLOWS", 8, 62000},
	{"CHARISMA", 8, 62001},
	{"CHILLI", 6, 62002},
	{"UBUT", 4, 62003},
	{"ETUB", 4, 62004},
	{"SUSPENSIONS", 11, 62005},
	{"PATRONAGE", 9, 62006},
	{"UTKE", 4, 62007},
	{"GDEN", 4, 62008},
	{"CANOES", 6, 62009},
	{"UTAY", 4, 62010},
	{"MDEF", 4, 62011},
	{"EEBL", 4, 62012},
	{"MATILDA", 7, 62013},
	{"UITB", 4, 62014},
	{"FODDER", 6, 62015},
	{"IMPETUS", 7, 62016},
	{"PEELED", 6, 62017},
	{"MALNUTRITION", 12, 62018},
	{"LOGCHECK", 8, 62019},
	{"LAYTON", 6, 62020},
	{"GAINES", 6, 62021},
	{"INBRED", 6, 62022},
	{"LOUC", 4, 62023},
	{"INTERCULTURAL", 13, 62024},
	{"OMBL", 4, 62025},
	{"SKATEBOARDS", 11, 62026},
	{"MAINBOARD", 9, 62027},
	{"NKAC", 4, 62028},
	{"GOSHEN", 6, 62029},
	{"WHINING", 7, 62030},
	{"FUNCTIONALLY", 12, 62031},
	{"RABIES", 6, 62032},
	{"CATALYSTS", 9, 62033},
	{"DATETIME", 8, 62034},
	{"ARSON", 5, 62035},
	{"GHRO", 4, 62036},
	{"READABILITY", 11, 62037},
	{"EWUN", 4, 62038},
	{"DAKAR", 5, 62039},
	{"DSPACE", 6, 62040},
	{"HIRSCH", 6, 62041},
	{"CAPPUCCINO", 10, 62042},
	{"MODULUS", 7, 62043},
	{"KRAUSE", 6, 62044},
	{"SBAB", 4, 62045},
	{"CUISINES", 8, 62046},
	{"LHOP", 4, 62047},
	{"DNUR", 4, 62048},
	{"TAPESTRIES", 10, 62049},
	{"TRANSATLANTIC", 13, 62050},
	{"OFAJ", 4, 62051},
	{"YXD", 3, 62052},
	{"MACLEAN", 7, 62053},
	{"TMOB", 4, 62054},
	{"YAPE", 4, 62055},
	{"WSYO", 4, 62056},
	{"NBYE", 4, 62057},
	{"TUSCALOOSA", 10, 62058},
	{"BOOSTED", 7, 62059},
	{"SPRAYED", 7, 62060},
	{"GEARING", 7, 62061},
	{"GLUTATHIONE", 11, 62062},
	{"FREEING", 7, 62063},
	{"KILKENNY", 8, 62064},
	{"REDRESS", 7, 62065},
	{"ADOPTIONS", 9, 62066},
	{"SETTLES", 7, 62067},
	{"DFUE", 4, 62068},
	{"TWEAKING", 8, 62069},
	{"ANGINA", 6, 62070},
	{"GMIC", 4, 62071},
	{"GEEKY", 5, 62072},
	{"ROLB", 4, 62073},
	{"RMOB", 4, 62074},
	{"COUPLER", 7, 62075},
	{"LEXAPRO", 7, 62076},
	{"OGYB", 4, 62077},
	{"SEAMAN", 6, 62078},
	{"HWOM", 4, 62079},
	{"GICP", 4, 62080},
	{"PAISAPAY", 8, 62081},
	{"SKULLS", 6, 62082},
	{"ZANUSSI", 7, 62083},
	{"CAYENNE", 7, 62084},
	{"RUSW", 4, 62085},
	{"MINIMIZES", 9, 62086},
	{"UEXP", 4, 62087},
	{"LATP", 4, 62088},
	{"CKVI", 4, 62089},
	{"HILLSDALE", 9, 62090},
	{"KMET", 4, 62091},
	{"BALBOA", 6, 62092},
	{"TREATISE", 8, 62093},
	{"DEFEATS", 7, 62094},
	{"TESTIMONIES", 11, 62095},
	{"AMIF", 4, 62096},
	{"RMHE", 4, 62097},
	{"EVUL", 4, 62098},
	{"WAINWRIGHT", 10, 62099},
	{"GUADALAJARA", 11, 62100},
	{"PINELLAS", 8, 62101},
	{"KALI", 4, 62102},
	{"UMTS", 4, 62103},
	{"WEITERE", 7, 62104},
	{"TOMW", 4, 62105},
	{"IFFL", 4, 62106},
	{"HACL", 4, 62107},
	{"ZAPPOS", 6, 62108},
	{"WITHDRAWING", 11, 62109},
	{"TPUS", 4, 62110},
	{"MPTL", 4, 62111},
	{"KEFE", 4, 62112},
	{"SOLICITED", 9, 62113},
	{"URAY", 4, 62114},
	{"RMYB", 4, 62115},
	{"DAIMLER", 7, 62116},
	{"NEGY", 4, 62117},
	{"IDAV", 4, 62118},
	{"DPSY", 4, 62119},
	{"TADALAFIL", 9, 62120},
	{"GARD", 4, 62121},
	{"EVERGLADES", 10, 62122},
	{"CHIPPING", 8, 62123},
	{"UDHA", 4, 62124},
	{"MONTAGE", 7, 62125},
	{"BRILLIANTLY", 11, 62126},
	{"GEELONG", 7, 62127},
	{"IONIZATION", 10, 62128},
	{"BROOME", 6, 62129},
	{"DEJA", 4, 62130},
	{"BIASES", 6, 62131},
	{"MADM", 4, 62132},
	{"MCCANN", 6, 62133},
	{"SPALDING", 8, 62134},
	{"DILL", 4, 62135},
	{"SPRAWL", 6, 62136},
	{"REOPEN", 6, 62137},
	{"MARANTZ", 7, 62138},
	{"XDY", 3, 62139},
	{"POTTS", 5, 62140},
	{"RITM", 4, 62141},
	{"LDJO", 4, 62142},
	{"IPFR", 4, 62143},
	{"FLYO", 4, 62144},
	{"BEWR", 4, 62145},
	{"ALFREDO", 7, 62146},
	{"HAUNT", 5, 62147},
	{"HEDGING", 7, 62148},
	{"UTFL", 4, 62149},
	{"NDSQ", 4, 62150},
	{"ERASED", 6, 62151},
	{"INSULATING", 10, 62152},
	{"MCCLURE", 7, 62153},
	{"TJER", 4, 62154},
	{"VBR", 3, 62155},
	{"RESISTING", 9, 62156},
	{"WLYA", 4, 62157},
	{"CONGREGATIONAL", 14, 62158},
	{"WATERFOWL", 9, 62159},
	{"YEUR", 4, 62160},
	{"ANTIQUITIES", 11, 62161},
	{"DUNHAM", 6, 62162},
	{"MONSIEUR", 8, 62163},
	{"DJEN", 4, 62164},
	{"ADRESS", 6, 62165},
	{"REACTING", 8, 62166},
	{"INHALED", 7, 62167},
	{"FUSES", 5, 62168},
	{"VIRTUALIZATION", 14, 62169},
	{"IGHV", 4, 62170},
	{"BRITT", 5, 62171},
	{"COLLIDE", 7, 62172},
	{"UTFU", 4, 62173},
	{"MANKATO", 7, 62174},
	{"SEGREGATED", 10, 62175},
	{"BLINDED", 7, 62176},
	{"AVENGERS", 8, 62177},
	{"YMIT", 4, 62178},
	{"RPSA", 4, 62179},
	{"LALB", 4, 62180},
	{"TECHNOLOGIST", 12, 62181},
	{"MADRAS", 6, 62182},
	{"SACRIFICING", 11, 62183},
	{"PIGMENTS", 8, 62184},
	{"FAITHS", 6, 62185},
	{"IMPACTING", 9, 62186},
	{"GACL", 4, 62187},
	{"LAMONT", 6, 62188},
	{"AQUARIUMS", 9, 62189},
	{"TINKER", 6, 62190},
	{"SONORA", 6, 62191},
	{"ECHOED", 6, 62192},
	{"UNAF", 4, 62193},
	{"RYRU", 4, 62194},
	{"RIGS", 4, 62195},
	{"ELISHA", 6, 62196},
	{"GAZING", 6, 62197},
	{"ARGININE", 8, 62198},
	{"GMYS", 4, 62199},
	{"SKEPTICISM", 10, 62200},
	{"OKAF", 4, 62201},
	{"EIGHTIES", 8, 62202},
	{"PLEASANTON", 10, 62203},
	{"TELEVISED", 9, 62204},
	{"GIFTSHEALTH", 11, 62205},
	{"ANKD", 4, 62206},
	{"SIMPLISTIC", 10, 62207},
	{"EZWA", 4, 62208},
	{"GROUPE", 6, 62209},
	{"USPU", 4, 62210},
	{"HPRA", 4, 62211},
	{"AMPHIBIANS", 10, 62212},
	{"IKEU", 4, 62213},
	{"FSDE", 4, 62214},
	{"FREEHOLD", 8, 62215},
	{"IKAR", 4, 62216},
	{"BRAID", 5, 62217},
	{"AFLY", 4, 62218},
	{"MRAT", 4, 62219},
	{"LKAT", 4, 62220},
	{"RVK", 3, 62221},
	{"YETW", 4, 62222},
	{"CEAU", 4, 62223},
	{"APBE", 4, 62224},
	{"FORESTER", 8, 62225},
	{"RESISTED", 8, 62226},
	{"ENCAPSULATED", 12, 62227},
	{"INJECTOR", 8, 62228},
	{"MUNRO", 5, 62229},
	{"KESSLER", 7, 62230},
	{"GARDENJEWELRYKIDS", 17, 62231},
	{"AGAR", 4, 62232},
	{"LEUNG", 5, 62233},
	{"ARUNDEL", 7, 62234},
	{"IMPL", 4, 62235},
	{"GRAINED", 7, 62236},
	{"RELATOS", 7, 62237},
	{"SHIRAZ", 6, 62238},
	{"DOMF", 4, 62239},
	{"NEWSDAY", 7, 62240},
	{"TLEK", 4, 62241},
	{"GMAT", 4, 62242},
	{"MPIS", 4, 62243},
	{"EJAG", 4, 62244},
	{"ANNOUNCER", 9, 62245},
	{"MFRA", 4, 62246},
	{"KEFA", 4, 62247},
	{"BARNSLEY", 8, 62248},
	{"CYCLOBENZAPRINE", 15, 62249},
	{"POLYCARBONATE", 13, 62250},
	{"DVM", 3, 62251},
	{"MARLOW", 6, 62252},
	{"DROT", 4, 62253},
	{"DISGRACE", 8, 62254},
	{"DONV", 4, 62255},
	{"MEDIATE", 7, 62256},
	{"REALISATION", 11, 62257},
	{"IRRITABLE", 9, 62258},
	{"VEDV", 4, 62259},
	{"ICPU", 4, 62260},
	{"HACKETT", 7, 62261},
	{"CUNNING", 7, 62262},
	{"FISTS", 5, 62263},
	{"UCEP", 4, 62264},
	{"ATGL", 4, 62265},
	{"DIVIDER", 7, 62266},
	{"WCHI", 4, 62267},
	{"UPRA", 4, 62268},
	{"RBYR", 4, 62269},
	{"CORTEZ", 6, 62270},
	{"ASSOCIATIVE", 11, 62271},
	{"RSYNC", 5, 62272},
	{"PENNIES", 7, 62273},
	{"MINIVAN", 7, 62274},
	{"RYFL", 4, 62275},
	{"VICTORINOX", 10, 62276},
	{"CHIMP", 5, 62277},
	{"LVIA", 4, 62278},
	{"IDDR", 4, 62279},
	{"FLASHCODERS", 11, 62280},
	{"GIRAFFE", 7, 62281},
	{"HEMORRHAGE", 10, 62282},
	{"AWNING", 6, 62283},
	{"AWBA", 4, 62284},
	{"OINTMENT", 8, 62285},
	{"NDYB", 4, 62286},
	{"ECUE", 4, 62287},
	{"SPILLED", 7, 62288},
	{"STROUD", 6, 62289},
	{"LEFTY", 5, 62290},
	{"WGD", 3, 62291},
	{"KGG", 3, 62292},
	{"TRIPPING", 8, 62293},
	{"CMG", 3, 62294},
	{"WESTSIDE", 8, 62295},
	{"HERES", 5, 62296},
	{"AZIMUTH", 7, 62297},
	{"FPAN", 4, 62298},
	{"AJEW", 4, 62299},
	{"LOGISTICAL", 10, 62300},
	{"PWWW", 4, 62301},
	{"OCCIDENTAL", 10, 62302},
	{"VIGOR", 5, 62303},
	{"YAYE", 4, 62304},
	{"RFOC", 4, 62305},
	{"CHARIOT", 7, 62306},
	{"BUOY", 4, 62307},
	{"GERALDINE", 9, 62308},
	{"SNUC", 4, 62309},
	{"FIRENZE", 7, 62310},
	{"OKAVANGO", 8, 62311},
	{"JANSEN", 6, 62312},
	{"MATRIMONIAL", 11, 62313},
	{"SQUADS", 6, 62314},
	{"TWEEN", 5, 62315},
	{"PAYBACK", 7, 62316},
	{"DISCLOSING", 10, 62317},
	{"HYDRAULICS", 10, 62318},
	{"ENDPOINTS", 9, 62319},
	{"KHEW", 4, 62320},
	{"MASTHEAD", 8, 62321},
	{"URSULA", 6, 62322},
	{"PERRIN", 6, 62323},
	{"NYQU", 4, 62324},
	{"BOUCHER", 7, 62325},
	{"CHADWICK", 8, 62326},
	{"CANDIDACY", 9, 62327},
	{"YORR", 4, 62328},
	{"DHAB", 4, 62329},
	{"HYPNOTIC", 8, 62330},
	{"ADULTERY", 8, 62331},
	{"QUANTIFICATION", 14, 62332},
	{"COOLANT", 7, 62333},
	{"SEVENTEENTH", 11, 62334},
	{"NANAIMO", 7, 62335},
	{"YAHOOLIGANS", 11, 62336},
	{"WAYG", 4, 62337},
	{"NDYN", 4, 62338},
	{"FAVI", 4, 62339},
	{"PRILOSEC", 8, 62340},
	{"TEMPERAMENT", 11, 62341},
	{"PROSTITUTES", 11, 62342},
	{"GDOE", 4, 62343},
	{"HUTCHISON", 9, 62344},
	{"PARSED", 6, 62345},
	{"SHAMROCK", 8, 62346},
	{"ISMR", 4, 62347},
	{"HEALER", 6, 62348},
	{"TIFW", 4, 62349},
	{"RUNP", 4, 62350},
	{"SCHMITT", 7, 62351},
	{"REMN", 4, 62352},
	{"CIRCULATE", 9, 62353},
	{"KORG", 4, 62354},
	{"WARMERS", 7, 62355},
	{"GLUED", 5, 62356},
	{"OHUR", 4, 62357},
	{"SYCAMORE", 8, 62358},
	{"FRONTEND", 8, 62359},
	{"NUNK", 4, 62360},
	{"ITANIUM", 7, 62361},
	{"ALLELES", 7, 62362},
	{"LFEL", 4, 62363},
	{"WEINER", 6, 62364},
	{"GOPT", 4, 62365},
	{"HALFTIME", 8, 62366},
	{"FRYE", 4, 62367},
	{"RAYC", 4, 62368},
	{"KVER", 4, 62369},
	{"IRVO", 4, 62370},
	{"BELINDA", 7, 62371},
	{"YHAM", 4, 62372},
	{"GOAF", 4, 62373},
	{"ALBRIGHT", 8, 62374},
	{"OMYF", 4, 62375},
	{"ADYN", 4, 62376},
	{"WMF", 3, 62377},
	{"CLEMENTE", 8, 62378},
	{"UGED", 4, 62379},
	{"OMSM", 4, 62380},
	{"WESTMORELAND", 12, 62381},
	{"HANDWRITTEN", 11, 62382},
	{"WHSLE", 5, 62383},
	{"SLYM", 4, 62384},
	{"SHUTS", 5, 62385},
	{"AYFU", 4, 62386},
	{"MYAS", 4, 62387},
	{"LAUNCESTON", 10, 62388},
	{"TENDERNESS", 10, 62389},
	{"IRFL", 4, 62390},
	{"WEMBLEY", 7, 62391},
	{"TPHY", 4, 62392},
	{"RSVO", 4, 62393},
	{"OCULAR", 6, 62394},
	{"SANDMAN", 7, 62395},
	{"SMELLING", 8, 62396},
	{"MEJORES", 7, 62397},
	{"WAME", 4, 62398},
	{"IROL", 4, 62399},
	{"CIBL", 4, 62400},
	{"DUNG", 4, 62401},
	{"KEINE", 5, 62402},
	{"ALIR", 4, 62403},
	{"SCRATCHED", 9, 62404},
	{"CONCLUSIVE", 10, 62405},
	{"PMET", 4, 62406},
	{"CKES", 4, 62407},
	{"SCOOPS", 6, 62408},
	{"ICVA", 4, 62409},
	{"DWG", 3, 62410},
	{"OGSW", 4, 62411},
	{"TRUETYPE", 8, 62412},
	{"EIGENVALUES", 11, 62413},
	{"LVEI", 4, 62414},
	{"WSEC", 4, 62415},
	{"ALDER", 5, 62416},
	{"POLLUTED", 8, 62417},
	{"UNDERSIGNED", 11, 62418},
	{"MINJ", 4, 62419},
	{"ELRI", 4, 62420},
	{"LARK", 4, 62421},
	{"AIRBRUSH", 8, 62422},
	{"PPB", 3, 62423},
	{"CARLYLE", 7, 62424},
	{"COMMS", 5, 62425},
	{"RESTORES", 8, 62426},
	{"REGEXP", 6, 62427},
	{"RKBY", 4, 62428},
	{"LULLABY", 7, 62429},
	{"QUICKSTART", 10, 62430},
	{"BEAVERTON", 9, 62431},
	{"UEPA", 4, 62432},
	{"SANDERSON", 9, 62433},
	{"GTEL", 4, 62434},
	{"TRUCKER", 7, 62435},
	{"WILLAMETTE", 10, 62436},
	{"CHIROPRACTORS", 13, 62437},
	{"GRUD", 4, 62438},
	{"LAWNS", 5, 62439},
	{"YSBR", 4, 62440},
	{"SAYB", 4, 62441},
	{"OUUS", 4, 62442},
	{"TYCO", 4, 62443},
	{"MIDAS", 5, 62444},
	{"IFOL", 4, 62445},
	{"GOGU", 4, 62446},
	{"MIRRORING", 9, 62447},
	{"CHOKING", 7, 62448},
	{"URTP", 4, 62449},
	{"MWED", 4, 62450},
	{"MDON", 4, 62451},
	{"DAYU", 4, 62452},
	{"RIDL", 4, 62453},
	{"CASTOR", 6, 62454},
	{"PLENTIFUL", 9, 62455},
	{"RVEC", 4, 62456},
	{"BONNER", 6, 62457},
	{"MASSIVELY", 9, 62458},
	{"STATELY", 7, 62459},
	{"TFLY", 4, 62460},
	{"AERONAUTICAL", 12, 62461},
	{"LASALLE", 7, 62462},
	{"RACED", 5, 62463},
	{"DEUCE", 5, 62464},
	{"WORDLET", 7, 62465},
	{"HANFORD", 7, 62466},
	{"ADMU", 4, 62467},
	{"XRAT", 4, 62468},
	{"SQUIRRELS", 9, 62469},
	{"PLAC", 4, 62470},
	{"EXHIBITIONISM", 13, 62471},
	{"PADDINGTON", 10, 62472},
	{"RISER", 5, 62473},
	{"XTFI", 4, 62474},
	{"FEGU", 4, 62475},
	{"REDUX", 5, 62476},
	{"DRAWBACKS", 9, 62477},
	{"GAIM", 4, 62478},
	{"MLEF", 4, 62479},
	{"EJOY", 4, 62480},
	{"AUDIOBOOK", 9, 62481},
	{"COMPENSATORY", 12, 62482},
	{"EVOKED", 6, 62483},
	{"CSOU", 4, 62484},
	{"TPIL", 4, 62485},
	{"LUCR", 4, 62486},
	{"DICTATES", 8, 62487},
	{"COUPLINGS", 9, 62488},
	{"OOFC", 4, 62489},
	{"JEEZY", 5, 62490},
	{"STUDDED", 7, 62491},
	{"UDYS", 4, 62492},
	{"RUNR", 4, 62493},
	{"MONSANTO", 8, 62494},
	{"TYVI", 4, 62495},
	{"CLERIC", 6, 62496},
	{"RFQ", 3, 62497},
	{"PALB", 4, 62498},
	{"INDIVIDUALITY", 13, 62499},
	{"AYCU", 4, 62500},
	{"SPARED", 6, 62501},
	{"ANTICIPATING", 12, 62502},
	{"CONTACTOS", 9, 62503},
	{"OKEP", 4, 62504},
	{"OYAR", 4, 62505},
	{"CALIFORNIAN", 11, 62506},
	{"LONF", 4, 62507},
	{"BROWNIE", 7, 62508},
	{"ELPD", 4, 62509},
	{"EQUIV", 5, 62510},
	{"MACROPHAGES", 11, 62511},
	{"MYKI", 4, 62512},
	{"BYKA", 4, 62513},
	{"COMPUTES", 8, 62514},
	{"QUITS", 5, 62515},
	{"YSVI", 4, 62516},
	{"OUSJ", 4, 62517},
	{"OUMO", 4, 62518},
	{"UZV", 3, 62519},
	{"RZV", 3, 62520},
	{"ENSIGN", 6, 62521},
	{"PICKETT", 7, 62522},
	{"RESTRAINING", 11, 62523},
	{"TYGE", 4, 62524},
	{"CHARISMATIC", 11, 62525},
	{"ELID", 4, 62526},
	{"TELECONFERENCE", 14, 62527},
	{"ORDY", 4, 62528},
	{"WHITEPAPERS", 11, 62529},
	{"BLOCKADE", 8, 62530},
	{"GIRARD", 6, 62531},
	{"EPTP", 4, 62532},
	{"DARB", 4, 62533},
	{"DSBI", 4, 62534},
	{"NEARING", 7, 62535},
	{"POLYCOM", 7, 62536},
	{"XTDO", 4, 62537},
	{"CKMU", 4, 62538},
	{"RUFF", 4, 62539},
	{"BURGLAR", 7, 62540},
	{"ASYMMETRY", 9, 62541},
	{"XPASS", 5, 62542},
	{"WARPED", 6, 62543},
	{"USVE", 4, 62544},
	{"CFD", 3, 62545},
	{"WSME", 4, 62546},
	{"OLYC", 4, 62547},
	{"AWNF", 4, 62548},
	{"BARBOUR", 7, 62549},
	{"TIJUANA", 7, 62550},
	{"RASD", 4, 62551},
	{"NKRA", 4, 62552},
	{"HAMILTONIAN", 11, 62553},
	{"CDG", 3, 62554},
	{"DHOC", 4, 62555},
	{"BLEJ", 4, 62556},
	{"ALGEBRAS", 8, 62557},
	{"YGAT", 4, 62558},
	{"REYW", 4, 62559},
	{"QUOTIENT", 8, 62560},
	{"WNDI", 4, 62561},
	{"KESD", 4, 62562},
	{"TRIBUTES", 8, 62563},
	{"FREEZES", 7, 62564},
	{"YZED", 4, 62565},
	{"PILY", 4, 62566},
	{"KNOLL", 5, 62567},
	{"WILDCAT", 7, 62568},
	{"EUNU", 4, 62569},
	{"THINNING", 8, 62570},
	{"INLAY", 5, 62571},
	{"REDDY", 5, 62572},
	{"YITC", 4, 62573},
	{"VINM", 4, 62574},
	{"PRIMROSE", 8, 62575},
	{"PACO", 4, 62576},
	{"PARTING", 7, 62577},
	{"YLEH", 4, 62578},
	{"HUMBER", 6, 62579},
	{"MICHELANGELO", 12, 62580},
	{"ULTL", 4, 62581},
	{"CORDUROY", 8, 62582},
	{"CLOV", 4, 62583},
	{"AVOCADO", 7, 62584},
	{"TORPEDO", 7, 62585},
	{"OCTETS", 6, 62586},
	{"DUBUQUE", 7, 62587},
	{"EVALUATOR", 9, 62588},
	{"GFAI", 4, 62589},
	{"DCIN", 4, 62590},
	{"MUFFLER", 7, 62591},
	{"OLLC", 4, 62592},
	{"NPIL", 4, 62593},
	{"JUMPERS", 7, 62594},
	{"EDMUNDS", 7, 62595},
	{"LERNER", 6, 62596},
	{"LTHD", 4, 62597},
	{"DKEL", 4, 62598},
	{"TROUBLESOME", 11, 62599},
	{"MANIFOLDS", 9, 62600},
	{"NGSQ", 4, 62601},
	{"NAPOLI", 6, 62602},
	{"QUW", 3, 62603},
	{"EUCHARIST", 9, 62604},
	{"KRISTY", 6, 62605},
	{"VARIANCES", 9, 62606},
	{"OLDV", 4, 62607},
	{"GAWE", 4, 62608},
	{"OBJECTIVITY", 11, 62609},
	{"UMSW", 4, 62610},
	{"MACU", 4, 62611},
	{"DDOA", 4, 62612},
	{"SISTEMA", 7, 62613},
	{"MASSAGER", 8, 62614},
	{"INCUBATED", 9, 62615},
	{"OKSC", 4, 62616},
	{"FEEDSTER", 8, 62617},
	{"UYSI", 4, 62618},
	{"FEDERER", 7, 62619},
	{"WADSWORTH", 9, 62620},
	{"TURNOVERS", 9, 62621},
	{"OWFE", 4, 62622},
	{"HFIG", 4, 62623},
	{"CHANGERS", 8, 62624},
	{"FFUS", 4, 62625},
	{"HERETO", 6, 62626},
	{"PAYB", 4, 62627},
	{"CLYD", 4, 62628},
	{"MAGNETISM", 9, 62629},
	{"TYSL", 4, 62630},
	{"IARR", 4, 62631},
	{"HODGSON", 7, 62632},
	{"INVENTIVE", 9, 62633},
	{"ILAG", 4, 62634},
	{"ERYQ", 4, 62635},
	{"CLINICIAN", 9, 62636},
	{"UEWO", 4, 62637},
	{"ALLTEL", 6, 62638},
	{"CRAZE", 5, 62639},
	{"DISPATCHES", 10, 62640},
	{"YWHY", 4, 62641},
	{"UNTM", 4, 62642},
	{"CRAFTSMEN", 9, 62643},
	{"CURACAO", 7, 62644},
	{"CUTH", 4, 62645},
	{"WNCE", 4, 62646},
	{"TEPB", 4, 62647},
	{"RAPPORTEUR", 10, 62648},
	{"DESIRING", 8, 62649},
	{"ARCSERVE", 8, 62650},
	{"GUMP", 4, 62651},
	{"POWERLINE", 9, 62652},
	{"DBAB", 4, 62653},
	{"FELIPE", 6, 62654},
	{"ASPELL", 6, 62655},
	{"HOFFMANN", 8, 62656},
	{"TEXAN", 5, 62657},
	{"ULYF", 4, 62658},
	{"KOFG", 4, 62659},
	{"ETFL", 4, 62660},
	{"SAFEGUARDING", 12, 62661},
	{"NOMBRE", 6, 62662},
	{"PAXTON", 6, 62663},
	{"OPEP", 4, 62664},
	{"IKEV", 4, 62665},
	{"GRATED", 6, 62666},
	{"HERBIE", 6, 62667},
	{"WMUS", 4, 62668},
	{"WIMB", 4, 62669},
	{"CTBA", 4, 62670},
	{"SUBMARINES", 10, 62671},
	{"YABB", 4, 62672},
	{"CHROMOSOMAL", 11, 62673},
	{"HICKMAN", 7, 62674},
	{"RTPL", 4, 62675},
	{"QWHA", 4, 62676},
	{"KJP", 3, 62677},
	{"ROMANA", 6, 62678},
	{"RUNESCAPE", 9, 62679},
	{"SALESPERSON", 11, 62680},
	{"TPWW", 4, 62681},
	{"SUPERFAMILY", 11, 62682},
	{"RAMR", 4, 62683},
	{"CKTI", 4, 62684},
	{"THYW", 4, 62685},
	{"TUPAC", 5, 62686},
	{"YTEX", 4, 62687},
	{"PENP", 4, 62688},
	{"LAZI", 4, 62689},
	{"ACCOMMODATING", 13, 62690},
	{"GVIS", 4, 62691},
	{"CTEL", 4, 62692},
	{"GRENOBLE", 8, 62693},
	{"CALVARY", 7, 62694},
	{"CASSINI", 7, 62695},
	{"BANDED", 6, 62696},
	{"DEPORTATION", 11, 62697},
	{"HARALD", 6, 62698},
	{"TOBIN", 5, 62699},
	{"ACTIVATES", 9, 62700},
	{"CUTTINGS", 8, 62701},
	{"IOCR", 4, 62702},
	{"IFIG", 4, 62703},
	{"GMAJ", 4, 62704},
	{"HIBERNATE", 9, 62705},
	{"INVESTS", 7, 62706},
	{"OWSR", 4, 62707},
	{"DHAW", 4, 62708},
	{"EXTREMISTS", 10, 62709},
	{"MONTEGO", 7, 62710},
	{"SCULPTOR", 8, 62711},
	{"BSFO", 4, 62712},
	{"KILDARE", 7, 62713},
	{"COMMENDED", 9, 62714},
	{"ROPER", 5, 62715},
	{"NARROWING", 9, 62716},
	{"SERGEY", 6, 62717},
	{"CYCLICAL", 8, 62718},
	{"ENMC", 4, 62719},
	{"BARL", 4, 62720},
	{"MECHANICALLY", 12, 62721},
	{"ODSB", 4, 62722},
	{"CYTOKINES", 9, 62723},
	{"IMPROVISATION", 13, 62724},
	{"PROFANITY", 9, 62725},
	{"MMORPG", 6, 62726},
	{"TOURED", 6, 62727},
	{"FLATTS", 6, 62728},
	{"LTFR", 4, 62729},
	{"CMF", 3, 62730},
	{"VANW", 4, 62731},
	{"OAQU", 4, 62732},
	{"ARCHIVER", 8, 62733},
	{"RAINER", 6, 62734},
	{"PLAYMATE", 8, 62735},
	{"COVARIANCE", 10, 62736},
	{"WSAB", 4, 62737},
	{"MAOF", 4, 62738},
	{"LTHB", 4, 62739},
	{"OLFT", 4, 62740},
	{"KACO", 4, 62741},
	{"BOBBLE", 6, 62742},
	{"SEASONING", 9, 62743},
	{"VARGAS", 6, 62744},
	{"GULFPORT", 8, 62745},
	{"AIRFIELD", 8, 62746},
	{"FLIPPING", 8, 62747},
	{"OCOD", 4, 62748},
	{"DISRUPTED", 9, 62749},
	{"ADOLF", 5, 62750},
	{"ADJOURN", 7, 62751},
	{"YBRU", 4, 62752},
	{"ICBY", 4, 62753},
	{"RESTOCKING", 10, 62754},
	{"LGBT", 4, 62755},
	{"EXTREMETECH", 11, 62756},
	{"WIDOWS", 6, 62757},
	{"CONVEYING", 9, 62758},
	{"CITRINE", 7, 62759},
	{"NEOPLASM", 8, 62760},
	{"SLUN", 4, 62761},
	{"IORV", 4, 62762},
	{"BBRE", 4, 62763},
	{"VAUG", 4, 62764},
	{"RETHINKING", 10, 62765},
	{"GUPH", 4, 62766},
	{"PRECINCTS", 9, 62767},
	{"TYFU", 4, 62768},
	{"LSUM", 4, 62769},
	{"ORIENTATIONS", 12, 62770},
	{"VOLTA", 5, 62771},
	{"MEDIUMS", 7, 62772},
	{"CALUMET", 7, 62773},
	{"PELLET", 6, 62774},
	{"DISCERN", 7, 62775},
	{"BRAN", 4, 62776},
	{"DOGGIE", 6, 62777},
	{"PMUS", 4, 62778},
	{"INFLOW", 6, 62779},
	{"FLYN", 4, 62780},
	{"NUSD", 4, 62781},
	{"CTLE", 4, 62782},
	{"LYMPHOCYTE", 10, 62783},
	{"FUMES", 5, 62784},
	{"FUTILE", 6, 62785},
	{"UTOD", 4, 62786},
	{"FARW", 4, 62787},
	{"GASY", 4, 62788},
	{"WEINBERG", 8, 62789},
	{"DISQUALIFIED", 12, 62790},
	{"FENCED", 6, 62791},
	{"SAIGON", 6, 62792},
	{"WHITEBOARD", 10, 62793},
	{"UDRE", 4, 62794},
	{"ANIMATE", 7, 62795},
	{"VEGU", 4, 62796},
	{"BRODY", 5, 62797},
	{"LAGH", 4, 62798},
	{"IFID", 4, 62799},
	{"FARO", 4, 62800},
	{"RESEMBLING", 10, 62801},
	{"RPAG", 4, 62802},
	{"IVAB", 4, 62803},
	{"BUREN", 5, 62804},
	{"IMTR", 4, 62805},
	{"INVERTEBRATES", 13, 62806},
	{"TOTEM", 5, 62807},
	{"THYR", 4, 62808},
	{"ELLIPTIC", 8, 62809},
	{"AGONIST", 7, 62810},
	{"EXPERIMENTALLY", 14, 62811},
	{"SUNU", 4, 62812},
	{"ROBJ", 4, 62813},
	{"RKWO", 4, 62814},
	{"HYPERION", 8, 62815},
	{"DRINKERS", 8, 62816},
	{"ELJA", 4, 62817},
	{"UDBU", 4, 62818},
	{"UGEF", 4, 62819},
	{"OYAB", 4, 62820},
	{"DMOL", 4, 62821},
	{"PARTYPOKER", 10, 62822},
	{"ITFL", 4, 62823},
	{"IBEG", 4, 62824},
	{"ROCKINGHAM", 10, 62825},
	{"SANDLER", 7, 62826},
	{"HERMIONE", 8, 62827},
	{"OLYG", 4, 62828},
	{"LUTO", 4, 62829},
	{"LSSC", 4, 62830},
	{"INDUS", 5, 62831},
	{"HARMS", 5, 62832},
	{"ISGL", 4, 62833},
	{"GNLA", 4, 62834},
	{"BORC", 4, 62835},
	{"SCHWEIZ", 7, 62836},
	{"GRUNDIG", 7, 62837},
	{"RETHINK", 7, 62838},
	{"YTWI", 4, 62839},
	{"LTHU", 4, 62840},
	{"MUSCULOSKELETAL", 15, 62841},
	{"AGGIES", 6, 62842},
	{"PREREQ", 6, 62843},
	{"ASSERTING", 9, 62844},
	{"WLIV", 4, 62845},
	{"RGHS", 4, 62846},
	{"NIKITA", 6, 62847},
	{"SDAQ", 4, 62848},
	{"KBUS", 4, 62849},
	{"FRIV", 4, 62850},
	{"DELR", 4, 62851},
	{"GDOC", 4, 62852},
	{"DIDR", 4, 62853},
	{"AFFLUENT", 8, 62854},
	{"IROU", 4, 62855},
	{"SYLL", 4, 62856},
	{"TRUCKERS", 8, 62857},
	{"PROTESTING", 10, 62858},
	{"LONESOME", 8, 62859},
	{"LIBERATED", 9, 62860},
	{"GIRO", 4, 62861},
	{"OFMC", 4, 62862},
	{"LASERDISC", 9, 62863},
	{"UNCONVENTIONAL", 14, 62864},
	{"AMORE", 5, 62865},
	{"EPIG", 4, 62866},
	{"KASPERSKY", 9, 62867},
	{"EBUG", 4, 62868},
	{"DETERMINANT", 11, 62869},
	{"YSUI", 4, 62870},
	{"EERG", 4, 62871},
	{"RECKONING", 9, 62872},
	{"FABIAN", 6, 62873},
	{"CONCURRENCE", 11, 62874},
	{"CLOSETS", 7, 62875},
	{"MORPHEUS", 8, 62876},
	{"AYERS", 5, 62877},
	{"JUNKIES", 7, 62878},
	{"BITW", 4, 62879},
	{"CCNA", 4, 62880},
	{"METAPHORS", 9, 62881},
	{"JACQUARD", 8, 62882},
	{"ASSESSES", 8, 62883},
	{"DGEE", 4, 62884},
	{"OKINAWA", 7, 62885},
	{"ODME", 4, 62886},
	{"GOAW", 4, 62887},
	{"MUSTER", 6, 62888},
	{"LABOURER", 8, 62889},
	{"HEARTFELT", 9, 62890},
	{"XTFO", 4, 62891},
	{"WNAG", 4, 62892},
	{"AUTOSCAN", 8, 62893},
	{"PERTAIN", 7, 62894},
	{"QUANTIFIED", 10, 62895},
	{"YORF", 4, 62896},
	{"UGTH", 4, 62897},
	{"LTHF", 4, 62898},
	{"UPPSALA", 7, 62899},
	{"DISTORTIONS", 11, 62900},
	{"DEMOCRACIES", 11, 62901},
	{"SUBCLASSES", 10, 62902},
	{"RBYW", 4, 62903},
	{"UBEA", 4, 62904},
	{"MABR", 4, 62905},
	{"FJEW", 4, 62906},
	{"GIDEON", 6, 62907},
	{"MALLORY", 7, 62908},
	{"RIEC", 4, 62909},
	{"ICBI", 4, 62910},
	{"EDOY", 4, 62911},
	{"TYGU", 4, 62912},
	{"EUPR", 4, 62913},
	{"UDYW", 4, 62914},
	{"HTYP", 4, 62915},
	{"GAUNTLET", 8, 62916},
	{"CONDOLENCES", 11, 62917},
	{"IBOU", 4, 62918},
	{"MARTYRS", 7, 62919},
	{"FMYC", 4, 62920},
	{"HITTER", 6, 62921},
	{"LIVELIHOODS", 11, 62922},
	{"FVEN", 4, 62923},
	{"AZAK", 4, 62924},
	{"CALA", 4, 62925},
	{"TELLURIDE", 9, 62926},
	{"APNEA", 5, 62927},
	{"YYP", 3, 62928},
	{"CZL", 3, 62929},
	{"FLOODPLAIN", 10, 62930},
	{"VICTORIOUS", 10, 62931},
	{"LTYF", 4, 62932},
	{"UDTO", 4, 62933},
	{"SYLVAN", 6, 62934},
	{"BEVERLEY", 8, 62935},
	{"VALERA", 6, 62936},
	{"IGBE", 4, 62937},
	{"WENGER", 6, 62938},
	{"UISC", 4, 62939},
	{"CRUSADER", 8, 62940},
	{"BACKLINKS", 9, 62941},
	{"UNNATURAL", 9, 62942},
	{"UREJ", 4, 62943},
	{"IOPR", 4, 62944},
	{"EWMU", 4, 62945},
	{"ALPHABETIC", 10, 62946},
	{"YPHY", 4, 62947},
	{"OPEY", 4, 62948},
	{"LATM", 4, 62949},
	{"DELONGHI", 8, 62950},
	{"TAILORING", 9, 62951},
	{"SWISH", 5, 62952},
	{"SHAVERS", 7, 62953},
	{"MCDONNELL", 9, 62954},
	{"UEGA", 4, 62955},
	{"AURU", 4, 62956},
	{"UELY", 4, 62957},
	{"ABORTED", 7, 62958},
	{"BLENDERS", 8, 62959},
	{"NYVI", 4, 62960},
	{"CONFESSED", 9, 62961},
	{"DTOQ", 4, 62962},
	{"SYMPHONIC", 9, 62963},
	{"ASKER", 5, 62964},
	{"PSUN", 4, 62965},
	{"AJAC", 4, 62966},
	{"DRUMMING", 8, 62967},
	{"HUFFMAN", 7, 62968},
	{"ALISTAIR", 8, 62969},
	{"NAVARRO", 7, 62970},
	{"DMOB", 4, 62971},
	{"MODERNITY", 9, 62972},
	{"PATCHING", 8, 62973},
	{"FRET", 4, 62974},
	{"BUMO", 4, 62975},
	{"BBAT", 4, 62976},
	{"DYOR", 4, 62977},
	{"CEYE", 4, 62978},
	{"ETFU", 4, 62979},
	{"DIDC", 4, 62980},
	{"BOOTIES", 7, 62981},
	{"XTIL", 4, 62982},
	{"RMOO", 4, 62983},
	{"ABIDING", 7, 62984},
	{"CANCELS", 7, 62985},
	{"NEWSBLOG", 8, 62986},
	{"GANGSTA", 7, 62987},
	{"LUSCIOUS", 8, 62988},
	{"SIGHTING", 8, 62989},
	{"MGP", 3, 62990},
	{"RELIC", 5, 62991},
	{"NFLY", 4, 62992},
	{"FOODSERVICE", 11, 62993},
	{"TRYG", 4, 62994},
	{"UKZ", 3, 62995},
	{"JFU", 3, 62996},
	{"FKJ", 3, 62997},
	{"NEWLINE", 7, 62998},
	{"IMAK", 4, 62999},
	{"BTRA", 4, 63000},
	{"SLIPPER", 7, 63001},
	{"PRIORITIZE", 10, 63002},
	{"UCKF", 4, 63003},
	{"MPHE", 4, 63004},
	{"KEYH", 4, 63005},
	{"CLASHES", 7, 63006},
	{"CUSW", 4, 63007},
	{"AUGSBURG", 8, 63008},
	{"CROHN", 5, 63009},
	{"QUICKLINKS", 10, 63010},
	{"HAUPPAUGE", 9, 63011},
	{"ODLU", 4, 63012},
	{"KFUR", 4, 63013},
	{"SOLENOID", 8, 63014},
	{"ARGYLE", 6, 63015},
	{"EFTP", 4, 63016},
	{"UNDERDOG", 8, 63017},
	{"PROPHETIC", 9, 63018},
	{"FREDERICTON", 11, 63019},
	{"UBBO", 4, 63020},
	{"BEXTRA", 6, 63021},
	{"COMMUNE", 7, 63022},
	{"WBUI", 4, 63023},
	{"OKEL", 4, 63024},
	{"AGATHA", 6, 63025},
	{"COPYWRITING", 11, 63026},
	{"ROPL", 4, 63027},
	{"OABR", 4, 63028},
	{"DMYF", 4, 63029},
	{"TECHNOL", 7, 63030},
	{"MDR", 3, 63031},
	{"ASTEROIDS", 9, 63032},
	{"GESELLSCHAFT", 12, 63033},
	{"WNMI", 4, 63034},
	{"CONTINOUS", 9, 63035},
	{"ELIL", 4, 63036},
	{"NEUTRALITY", 10, 63037},
	{"HPLC", 4, 63038},
	{"OVULATION", 9, 63039},
	{"SJIM", 4, 63040},
	{"OILR", 4, 63041},
	{"GHAF", 4, 63042},
	{"AQUI", 4, 63043},
	{"SNORING", 7, 63044},
	{"QUASAR", 6, 63045},
	{"IGPA", 4, 63046},
	{"EUTHANASIA", 10, 63047},
	{"UOSB", 4, 63048},
	{"DURH", 4, 63049},
	{"TREMBLING", 9, 63050},
	{"SCHULZ", 6, 63051},
	{"OKANAGAN", 8, 63052},
	{"REPRODUCING", 11, 63053},
	{"LLSK", 4, 63054},
	{"LITERS", 6, 63055},
	{"COMETS", 6, 63056},
	{"RUEB", 4, 63057},
	{"OYWA", 4, 63058},
	{"TARRANT", 7, 63059},
	{"UNITARIAN", 9, 63060},
	{"BLACKLIST", 9, 63061},
	{"TYEL", 4, 63062},
	{"ISKF", 4, 63063},
	{"ABYL", 4, 63064},
	{"GOVERNS", 7, 63065},
	{"CLERMONT", 8, 63066},
	{"ROOFTOP", 7, 63067},
	{"EBERT", 5, 63068},
	{"PRAW", 4, 63069},
	{"FCOP", 4, 63070},
	{"GOLDFISH", 8, 63071},
	{"GUMS", 4, 63072},
	{"DELAYING", 8, 63073},
	{"WITHERSPOON", 11, 63074},
	{"YSRO", 4, 63075},
	{"ULAO", 4, 63076},
	{"SLIMLINE", 8, 63077},
	{"ELMU", 4, 63078},
	{"MAINZ", 5, 63079},
	{"RECONSTRUCT", 11, 63080},
	{"ANIMATOR", 8, 63081},
	{"BARBRA", 6, 63082},
	{"QUC", 3, 63083},
	{"PUV", 3, 63084},
	{"DQP", 3, 63085},
	{"TONED", 5, 63086},
	{"BIDF", 4, 63087},
	{"ERRED", 5, 63088},
	{"REOG", 4, 63089},
	{"CUTD", 4, 63090},
	{"KYLI", 4, 63091},
	{"HJAC", 4, 63092},
	{"MODELLED", 8, 63093},
	{"IRREVERSIBLE", 12, 63094},
	{"FLANAGAN", 8, 63095},
	{"EXPIRING", 8, 63096},
	{"ENCYCLOPEDIAS", 13, 63097},
	{"MABEL", 5, 63098},
	{"FALB", 4, 63099},
	{"CSIRO", 5, 63100},
	{"WHISTLES", 8, 63101},
	{"JEWELLERS", 9, 63102},
	{"DOWNTEMPO", 9, 63103},
	{"YDOG", 4, 63104},
	{"OKSP", 4, 63105},
	{"CARON", 5, 63106},
	{"UNDERSTANDINGS", 14, 63107},
	{"SHBR", 4, 63108},
	{"DARED", 5, 63109},
	{"HERNDON", 7, 63110},
	{"NUDGE", 5, 63111},
	{"SEEMING", 7, 63112},
	{"YAHU", 4, 63113},
	{"PUTD", 4, 63114},
	{"CAMPSITES", 9, 63115},
	{"GRACO", 5, 63116},
	{"LIGHTHOUSES", 11, 63117},
	{"ROSEBUD", 7, 63118},
	{"HEMOGLOBIN", 10, 63119},
	{"NSYD", 4, 63120},
	{"GORB", 4, 63121},
	{"GHFA", 4, 63122},
	{"ACCH", 4, 63123},
	{"HUPT", 4, 63124},
	{"MPKI", 4, 63125},
	{"DIOM", 4, 63126},
	{"TUNG", 4, 63127},
	{"GAWO", 4, 63128},
	{"ANDROMEDA", 9, 63129},
	{"SVGA", 4, 63130},
	{"POSTPARTUM", 10, 63131},
	{"CONDI", 5, 63132},
	{"YODA", 4, 63133},
	{"SIXTEENTH", 9, 63134},
	{"ORIGINATION", 11, 63135},
	{"DOVES", 5, 63136},
	{"LANDOWNER", 9, 63137},
	{"DALAI", 5, 63138},
	{"ERMW", 4, 63139},
	{"NYTIMES", 7, 63140},
	{"RBYB", 4, 63141},
	{"DDLI", 4, 63142},
	{"PREACHERS", 9, 63143},
	{"KENZO", 5, 63144},
	{"LEIDEN", 6, 63145},
	{"ALDEN", 5, 63146},
	{"KREP", 4, 63147},
	{"IAMD", 4, 63148},
	{"GADG", 4, 63149},
	{"WDOF", 4, 63150},
	{"TRAMPOLINE", 10, 63151},
	{"RAMONA", 6, 63152},
	{"GLIB", 4, 63153},
	{"CFIN", 4, 63154},
	{"GITB", 4, 63155},
	{"RESTRICTS", 9, 63156},
	{"BRUTALITY", 9, 63157},
	{"FICTITIOUS", 10, 63158},
	{"FRANCESCA", 9, 63159},
	{"RUMOUR", 6, 63160},
	{"UPSU", 4, 63161},
	{"RKPA", 4, 63162},
	{"IMMORTALITY", 11, 63163},
	{"INTAKES", 7, 63164},
	{"DOGFART", 7, 63165},
	{"IUSW", 4, 63166},
	{"ELJO", 4, 63167},
	{"UWD", 3, 63168},
	{"FZL", 3, 63169},
	{"SWEARING", 8, 63170},
	{"NBYG", 4, 63171},
	{"MOFW", 4, 63172},
	{"EOBL", 4, 63173},
	{"MONTEL", 6, 63174},
	{"SAFFRON", 7, 63175},
	{"OKOR", 4, 63176},
	{"LNOV", 4, 63177},
	{"UBBCODE", 7, 63178},
	{"NINEMSN", 7, 63179},
	{"UEME", 4, 63180},
	{"LCOD", 4, 63181},
	{"KYTH", 4, 63182},
	{"LGPL", 4, 63183},
	{"WGRA", 4, 63184},
	{"RAGGED", 6, 63185},
	{"PEERLESS", 8, 63186},
	{"CONSTITUTIONS", 13, 63187},
	{"PSYCHOTIC", 9, 63188},
	{"ALLYN", 5, 63189},
	{"PUNJ", 4, 63190},
	{"MYEX", 4, 63191},
	{"HIGGS", 5, 63192},
	{"CKUN", 4, 63193},
	{"IMPROBABLE", 10, 63194},
	{"PULSED", 6, 63195},
	{"IGNITE", 6, 63196},
	{"WYOM", 4, 63197},
	{"SYOF", 4, 63198},
	{"LSUI", 4, 63199},
	{"REITERATED", 10, 63200},
	{"LROB", 4, 63201},
	{"FFSD", 4, 63202},
	{"HORNET", 6, 63203},
	{"JESUIT", 6, 63204},
	{"THYD", 4, 63205},
	{"ATYPICAL", 8, 63206},
	{"EXCESSIVELY", 11, 63207},
	{"SEYC", 4, 63208},
	{"CONTRACEPTIVES", 14, 63209},
	{"MOUNDS", 6, 63210},
	{"RHEP", 4, 63211},
	{"OBWI", 4, 63212},
	{"WKEY", 4, 63213},
	{"SLIMMING", 8, 63214},
	{"DISPATCHER", 10, 63215},
	{"DEVOID", 6, 63216},
	{"EXTRAORDINARILY", 15, 63217},
	{"PARTED", 6, 63218},
	{"MARICOPA", 8, 63219},
	{"UMDE", 4, 63220},
	{"HLIF", 4, 63221},
	{"NORTHFIELD", 10, 63222},
	{"YEPI", 4, 63223},
	{"TMIK", 4, 63224},
	{"ELITES", 6, 63225},
	{"ZURE", 4, 63226},
	{"MUNSTER", 7, 63227},
	{"YGLA", 4, 63228},
	{"FIFO", 4, 63229},
	{"CORRELATES", 10, 63230},
	{"SUFFERERS", 9, 63231},
	{"ODYR", 4, 63232},
	{"LHOR", 4, 63233},
	{"SKUNK", 5, 63234},
	{"INTERRUPTIONS", 13, 63235},
	{"IRIM", 4, 63236},
	{"ERZE", 4, 63237},
	{"PLACER", 6, 63238},
	{"CASTERS", 7, 63239},
	{"HEISSE", 6, 63240},
	{"LINGERING", 9, 63241},
	{"FTWH", 4, 63242},
	{"DAMW", 4, 63243},
	{"BROOCHES", 8, 63244},
	{"HEAPS", 5, 63245},
	{"LDMU", 4, 63246},
	{"HYDRA", 5, 63247},
	{"EASYGALS", 8, 63248},
	{"ANVIL", 5, 63249},
	{"MANDALAY", 8, 63250},
	{"HAIRCARE", 8, 63251},
	{"CLIMBERS", 8, 63252},
	{"DQC", 3, 63253},
	{"BLINKING", 8, 63254},
	{"FTMA", 4, 63255},
	{"SWEETEST", 8, 63256},
	{"ROSL", 4, 63257},
	{"QUOL", 4, 63258},
	{"MADERA", 6, 63259},
	{"CALIBEX", 7, 63260},
	{"DISHONEST", 9, 63261},
	{"STALK", 5, 63262},
	{"MAILBAG", 7, 63263},
	{"INERT", 5, 63264},
	{"GOBL", 4, 63265},
	{"EGOC", 4, 63266},
	{"SMARTMEDIA", 10, 63267},
	{"VILNIUS", 7, 63268},
	{"DBL", 3, 63269},
	{"FAVORABLY", 9, 63270},
	{"VOCATION", 8, 63271},
	{"TRIBUNALS", 9, 63272},
	{"CEDRIC", 6, 63273},
	{"DOPING", 6, 63274},
	{"MDIF", 4, 63275},
	{"POSTWAR", 7, 63276},
	{"TFUT", 4, 63277},
	{"OFSQ", 4, 63278},
	{"STRAT", 5, 63279},
	{"BAREBONE", 8, 63280},
	{"THROMBOSIS", 10, 63281},
	{"FAVOURS", 7, 63282},
	{"SMARTY", 6, 63283},
	{"YLUC", 4, 63284},
	{"NCHG", 4, 63285},
	{"WONM", 4, 63286},
	{"AXCR", 4, 63287},
	{"WHITLEY", 7, 63288},
	{"WITNESSING", 10, 63289},
	{"EJECT", 5, 63290},
	{"UTYP", 4, 63291},
	{"FICM", 4, 63292},
	{"WINDERMERE", 10, 63293},
	{"SEVENTIES", 9, 63294},
	{"CURTIN", 6, 63295},
	{"DILEMMAS", 8, 63296},
	{"FICL", 4, 63297},
	{"RAYON", 5, 63298},
	{"HECZ", 4, 63299},
	{"LFUE", 4, 63300},
	{"GWYNEDD", 7, 63301},
	{"EDWARDIAN", 9, 63302},
	{"DRYDEN", 6, 63303},
	{"HPPA", 4, 63304},
	{"XESW", 4, 63305},
	{"NYOP", 4, 63306},
	{"GHAU", 4, 63307},
	{"SAUNAS", 6, 63308},
	{"POLICEMEN", 9, 63309},
	{"TILF", 4, 63310},
	{"OGYH", 4, 63311},
	{"HOROWITZ", 8, 63312},
	{"PUTP", 4, 63313},
	{"OPDO", 4, 63314},
	{"DLUN", 4, 63315},
	{"RMFU", 4, 63316},
	{"OFPS", 4, 63317},
	{"RTMI", 4, 63318},
	{"UNFAVORABLE", 11, 63319},
	{"UNDERGRAD", 9, 63320},
	{"MOCHA", 5, 63321},
	{"ANOMALOUS", 9, 63322},
	{"ESCADA", 6, 63323},
	{"KNOCKERS", 8, 63324},
	{"KATHARINE", 9, 63325},
	{"JITTER", 6, 63326},
	{"BARTER", 6, 63327},
	{"DCOD", 4, 63328},
	{"GJD", 3, 63329},
	{"SUPERNOVA", 9, 63330},
	{"ROWLEY", 6, 63331},
	{"LOUGHBOROUGH", 12, 63332},
	{"MODIFIES", 8, 63333},
	{"DIRECTTV", 8, 63334},
	{"FEMINIZATION", 12, 63335},
	{"FRUGAL", 6, 63336},
	{"EXTREMIST", 9, 63337},
	{"UYSH", 4, 63338},
	{"PERJ", 4, 63339},
	{"OWDR", 4, 63340},
	{"STARRY", 6, 63341},
	{"THANKING", 8, 63342},
	{"NOUNS", 5, 63343},
	{"TUTTLE", 6, 63344},
	{"YDOS", 4, 63345},
	{"MEDWAY", 6, 63346},
	{"HOBBIT", 6, 63347},
	{"CONSEQUENT", 10, 63348},
	{"HETATM", 6, 63349},
	{"ENTRANCES", 9, 63350},
	{"MTUE", 4, 63351},
	{"MULTIPURPOSE", 12, 63352},
	{"LONB", 4, 63353},
	{"GGEO", 4, 63354},
	{"AYOP", 4, 63355},
	{"DWORD", 5, 63356},
	{"DANUBE", 6, 63357},
	{"EVASION", 7, 63358},
	{"HERBALIFE", 9, 63359},
	{"GBUD", 4, 63360},
	{"OCALA", 5, 63361},
	{"COHESIVE", 8, 63362},
	{"VELR", 4, 63363},
	{"GERK", 4, 63364},
	{"BJORN", 5, 63365},
	{"FILENAMES", 9, 63366},
	{"DUTTON", 6, 63367},
	{"RDOV", 4, 63368},
	{"MAYORS", 6, 63369},
	{"LIFEBOOK", 8, 63370},
	{"CASTER", 6, 63371},
	{"MMYC", 4, 63372},
	{"GOSPELS", 7, 63373},
	{"CRITIQUER", 9, 63374},
	{"GMAG", 4, 63375},
	{"FARH", 4, 63376},
	{"WICKET", 6, 63377},
	{"GLYCOL", 6, 63378},
	{"MANICURE", 8, 63379},
	{"LDCE", 4, 63380},
	{"MEDIAL", 6, 63381},
	{"CORA", 4, 63382},
	{"NEOPETS", 7, 63383},
	{"LAZARUS", 7, 63384},
	{"ACCESORIES", 10, 63385},
	{"HEWW", 4, 63386},
	{"FAXED", 5, 63387},
	{"BLOOMSBURY", 10, 63388},
	{"MCCABE", 6, 63389},
	{"AVYM", 4, 63390},
	{"VILE", 4, 63391},
	{"MISGUIDED", 9, 63392},
	{"OIDC", 4, 63393},
	{"OKID", 4, 63394},
	{"GONY", 4, 63395},
	{"CHCU", 4, 63396},
	{"REUNITED", 8, 63397},
	{"ECKF", 4, 63398},
	{"COLOSSAL", 8, 63399},
	{"CONVERSATIONAL", 14, 63400},
	{"KARTING", 7, 63401},
	{"MCDANIEL", 8, 63402},
	{"INSPIRATIONS", 12, 63403},
	{"BRIO", 4, 63404},
	{"REWP", 4, 63405},
	{"IRGE", 4, 63406},
	{"GISW", 4, 63407},
	{"BLASTED", 7, 63408},
	{"BASKERVILLE", 11, 63409},
	{"NBYI", 4, 63410},
	{"IERY", 4, 63411},
	{"FIAB", 4, 63412},
	{"BELP", 4, 63413},
	{"SYNDROMES", 9, 63414},
	{"CONU", 4, 63415},
	{"KINNEY", 6, 63416},
	{"NORTHRIDGE", 10, 63417},
	{"ICHV", 4, 63418},
	{"TRIMBLE", 7, 63419},
	{"QLP", 3, 63420},
	{"WEBINARS", 8, 63421},
	{"TRIPLES", 7, 63422},
	{"GSUM", 4, 63423},
	{"USHM", 4, 63424},
	{"IBOR", 4, 63425},
	{"GOUN", 4, 63426},
	{"AULW", 4, 63427},
	{"BOUTIQUES", 9, 63428},
	{"FREEVIEW", 8, 63429},
	{"SHINGLES", 8, 63430},
	{"KASP", 4, 63431},
	{"GRESHAM", 7, 63432},
	{"SCREENER", 8, 63433},
	{"JANINE", 6, 63434},
	{"HANUKKAH", 8, 63435},
	{"ADSORPTION", 10, 63436},
	{"ISMM", 4, 63437},
	{"HLIV", 4, 63438},
	{"YBYM", 4, 63439},
	{"HHUM", 4, 63440},
	{"GEFE", 4, 63441},
	{"NSYM", 4, 63442},
	{"UNDERWRITERS", 12, 63443},
	{"FOXX", 4, 63444},
	{"NGJI", 4, 63445},
	{"HOBR", 4, 63446},
	{"BRUNTON", 7, 63447},
	{"MENDOCINO", 9, 63448},
	{"PIMA", 4, 63449},
	{"LRID", 4, 63450},
	{"ACTUATORS", 9, 63451},
	{"WUNI", 4, 63452},
	{"PEWE", 4, 63453},
	{"INTERNATIONALIZATION", 20, 63454},
	{"FTHC", 4, 63455},
	{"PIXIES", 6, 63456},
	{"IMMERSED", 8, 63457},
	{"RIPW", 4, 63458},
	{"PIDI", 4, 63459},
	{"LDKI", 4, 63460},
	{"EYVI", 4, 63461},
	{"PHILEMON", 8, 63462},
	{"URMU", 4, 63463},
	{"NNFL", 4, 63464},
	{"ROASTING", 8, 63465},
	{"DROY", 4, 63466},
	{"PANCAKE", 7, 63467},
	{"ACCRUE", 6, 63468},
	{"RDAF", 4, 63469},
	{"TRANSMEMBRANE", 13, 63470},
	{"PHOTOSTREAM", 11, 63471},
	{"LOIRE", 5, 63472},
	{"GUERRERO", 8, 63473},
	{"VENTED", 6, 63474},
	{"NKSM", 4, 63475},
	{"AYCR", 4, 63476},
	{"FIRTH", 5, 63477},
	{"HATHAWAY", 8, 63478},
	{"BEATTY", 6, 63479},
	{"ANDERSSON", 9, 63480},
	{"RNIZ", 4, 63481},
	{"NMYP", 4, 63482},
	{"UNSB", 4, 63483},
	{"LUNCHTIME", 9, 63484},
	{"MIRO", 4, 63485},
	{"CONSOLATION", 11, 63486},
	{"SLAMS", 5, 63487},
	{"ICYE", 4, 63488},
	{"AYGE", 4, 63489},
	{"STMY", 4, 63490},
	{"FRAZER", 6, 63491},
	{"OUTLAY", 6, 63492},
	{"DREADED", 7, 63493},
	{"AIRING", 6, 63494},
	{"RYPH", 4, 63495},
	{"LUTT", 4, 63496},
	{"LOOPING", 7, 63497},
	{"CRATES", 6, 63498},
	{"UNDATED", 7, 63499},
	{"YAWE", 4, 63500},
	{"FTSM", 4, 63501},
	{"TAKAHASHI", 9, 63502},
	{"RAMADAN", 7, 63503},
	{"LOWERCASE", 9, 63504},
	{"ALTERNATELY", 11, 63505},
	{"TECHNOLOGICALLY", 15, 63506},
	{"GRACEFULLY", 10, 63507},
	{"INTRIGUED", 9, 63508},
	{"ANAEROBIC", 9, 63509},
	{"VESK", 4, 63510},
	{"KLYD", 4, 63511},
	{"ANTAGONIST", 10, 63512},
	{"SATELITE", 8, 63513},
	{"PIONEERED", 9, 63514},
	{"EXALTED", 7, 63515},
	{"CADRE", 5, 63516},
	{"TABLOID", 7, 63517},
	{"CYAS", 4, 63518},
	{"SERB", 4, 63519},
	{"JAEGER", 6, 63520},
	{"PRED", 4, 63521},
	{"XTOR", 4, 63522},
	{"ORPT", 4, 63523},
	{"OBOL", 4, 63524},
	{"EYBY", 4, 63525},
	{"SOLUBILITY", 10, 63526},
	{"TROUBLESHOOT", 12, 63527},
	{"OVERTHROW", 9, 63528},
	{"PATIENTLY", 9, 63529},
	{"CABOT", 5, 63530},
	{"CONTROVERSIES", 13, 63531},
	{"ROOV", 4, 63532},
	{"HATCHER", 7, 63533},
	{"LTEM", 4, 63534},
	{"NARRATED", 8, 63535},
	{"CODERS", 6, 63536},
	{"SQUAT", 5, 63537},
	{"INSECTICIDES", 12, 63538},
	{"ELECTROLYTE", 11, 63539},
	{"WATANABE", 8, 63540},
	{"TCIV", 4, 63541},
	{"SNYD", 4, 63542},
	{"FIRESTONE", 9, 63543},
	{"MHAL", 4, 63544},
	{"WRITESHIELD", 11, 63545},
	{"DLIC", 4, 63546},
	{"OLSM", 4, 63547},
	{"DESCARGAR", 9, 63548},
	{"LETTERHEAD", 10, 63549},
	{"POLYPEPTIDE", 11, 63550},
	{"ILLUMINATING", 12, 63551},
	{"ARTIFICIALLY", 12, 63552},
	{"VELOUR", 6, 63553},
	{"UMMY", 4, 63554},
	{"MBUI", 4, 63555},
	{"DJAS", 4, 63556},
	{"CFIE", 4, 63557},
	{"BACHELORETTE", 12, 63558},
	{"RAYH", 4, 63559},
	{"EGOF", 4, 63560},
	{"SAUCEPAN", 8, 63561},
	{"FRESHEST", 8, 63562},
	{"NURS", 4, 63563},
	{"OKLE", 4, 63564},
	{"MARTYR", 6, 63565},
	{"GEOSPATIAL", 10, 63566},
	{"HACIENDA", 8, 63567},
	{"KORAN", 5, 63568},
	{"ZONED", 5, 63569},
	{"PUBIC", 5, 63570},
	{"PIZZERIA", 8, 63571},
	{"QUITO", 5, 63572},
	{"MIRC", 4, 63573},
	{"HENNING", 7, 63574},
	{"CHPH", 4, 63575},
	{"NITROUS", 7, 63576},
	{"UTSK", 4, 63577},
	{"LDFL", 4, 63578},
	{"TIARA", 5, 63579},
	{"ELEGANTLY", 9, 63580},
	{"YFLI", 4, 63581},
	{"DSRU", 4, 63582},
	{"AIRSPACE", 8, 63583},
	{"SANTORINI", 9, 63584},
	{"VDR", 3, 63585},
	{"TEMPTATIONS", 11, 63586},
	{"IZEP", 4, 63587},
	{"CONVERTOR", 9, 63588},
	{"BRAHMS", 6, 63589},
	{"GENOMES", 7, 63590},
	{"WORKABLE", 8, 63591},
	{"SKINNED", 7, 63592},
	{"IRRIGATED", 9, 63593},
	{"YSRA", 4, 63594},
	{"TBRU", 4, 63595},
	{"DIDP", 4, 63596},
	{"HIVES", 5, 63597},
	{"FEDW", 4, 63598},
	{"XPV", 3, 63599},
	{"XKU", 3, 63600},
	{"FZF", 3, 63601},
	{"ORDINATE", 8, 63602},
	{"GROUNDWORK", 10, 63603},
	{"YTOV", 4, 63604},
	{"RGYO", 4, 63605},
	{"CYRIL", 5, 63606},
	{"ODUN", 4, 63607},
	{"CKEA", 4, 63608},
	{"AKFR", 4, 63609},
	{"SEMINAL", 7, 63610},
	{"RODENTS", 7, 63611},
	{"DSDU", 4, 63612},
	{"PRECURSORS", 10, 63613},
	{"SUKE", 4, 63614},
	{"RESENTMENT", 10, 63615},
	{"RELEVANCY", 9, 63616},
	{"MEOB", 4, 63617},
	{"ILMP", 4, 63618},
	{"KOALA", 5, 63619},
	{"ISMD", 4, 63620},
	{"DISCUS", 6, 63621},
	{"GBUR", 4, 63622},
	{"GLACIERS", 8, 63623},
	{"DYLI", 4, 63624},
	{"GIFTWARE", 8, 63625},
	{"FEXI", 4, 63626},
	{"ALKB", 4, 63627},
	{"PERI", 4, 63628},
	{"MANFRED", 7, 63629},
	{"REALISTICALLY", 13, 63630},
	{"KEGA", 4, 63631},
	{"POLSKA", 6, 63632},
	{"LOCI", 4, 63633},
	{"NANOTECH", 8, 63634},
	{"RTCL", 4, 63635},
	{"RSKA", 4, 63636},
	{"ULAB", 4, 63637},
	{"SUBUNITS", 8, 63638},
	{"GAPING", 6, 63639},
	{"ETGR", 4, 63640},
	{"AWSOME", 6, 63641},
	{"ILBR", 4, 63642},
	{"INFRINGE", 8, 63643},
	{"YANW", 4, 63644},
	{"IDPL", 4, 63645},
	{"PORTA", 5, 63646},
	{"HULA", 4, 63647},
	{"INFERENCES", 10, 63648},
	{"LARAMIE", 7, 63649},
	{"IADU", 4, 63650},
	{"EMYM", 4, 63651},
	{"TOOTHPASTE", 10, 63652},
	{"FDOC", 4, 63653},
	{"MAXINE", 6, 63654},
	{"IWRO", 4, 63655},
	{"IFTC", 4, 63656},
	{"MENNONITE", 9, 63657},
	{"OKAW", 4, 63658},
	{"SUBTITLED", 9, 63659},
	{"MAIDSTONE", 9, 63660},
	{"ARKU", 4, 63661},
	{"ABRUPT", 6, 63662},
	{"RDEX", 4, 63663},
	{"LUGI", 4, 63664},
	{"JCB", 3, 63665},
	{"FASTENER", 8, 63666},
	{"PEDG", 4, 63667},
	{"FOXY", 4, 63668},
	{"JUPITERIMAGES", 13, 63669},
	{"GAMBLER", 7, 63670},
	{"AELP", 4, 63671},
	{"DISSECTION", 10, 63672},
	{"CATEGORIZATION", 14, 63673},
	{"NIGHTINGALE", 11, 63674},
	{"MTOK", 4, 63675},
	{"DESG", 4, 63676},
	{"INCLUSIONS", 10, 63677},
	{"FOSTERS", 7, 63678},
	{"CONC", 4, 63679},
	{"LANDAU", 6, 63680},
	{"LVAG", 4, 63681},
	{"DSHR", 4, 63682},
	{"SKMA", 4, 63683},
	{"GLYE", 4, 63684},
	{"DSBR", 4, 63685},
	{"YONJ", 4, 63686},
	{"LIMBAUGH", 8, 63687},
	{"UXY", 3, 63688},
	{"LFX", 3, 63689},
	{"CASSIE", 6, 63690},
	{"ALTMAN", 6, 63691},
	{"LETHBRIDGE", 10, 63692},
	{"PENG", 4, 63693},
	{"HAPM", 4, 63694},
	{"FILLERS", 7, 63695},
	{"AMIGOS", 6, 63696},
	{"TFER", 4, 63697},
	{"SYMPOSIA", 8, 63698},
	{"PUTT", 4, 63699},
	{"COLONIZATION", 12, 63700},
	{"RUEC", 4, 63701},
	{"DYBA", 4, 63702},
	{"OIFY", 4, 63703},
	{"CROCK", 5, 63704},
	{"AILMENTS", 8, 63705},
	{"TEMPLETON", 9, 63706},
	{"DISAGREED", 9, 63707},
	{"BOLDLY", 6, 63708},
	{"YMCC", 4, 63709},
	{"RPOU", 4, 63710},
	{"NARRATION", 9, 63711},
	{"YROD", 4, 63712},
	{"YUPS", 4, 63713},
	{"TYPOGRAPHY", 10, 63714},
	{"UNOPENED", 8, 63715},
	{"NLOR", 4, 63716},
	{"EUMP", 4, 63717},
	{"INSISTING", 9, 63718},
	{"NALK", 4, 63719},
	{"EBITDA", 6, 63720},
	{"BRUSHING", 8, 63721},
	{"YCUS", 4, 63722},
	{"REYC", 4, 63723},
	{"RESOLVES", 8, 63724},
	{"SACRAMENT", 9, 63725},
	{"CRAM", 4, 63726},
	{"ELIMINATOR", 10, 63727},
	{"ACCU", 4, 63728},
	{"MAXW", 4, 63729},
	{"GARDENJEWELRYKIDSMORE", 21, 63730},
	{"GAZEBO", 6, 63731},
	{"MEIW", 4, 63732},
	{"SHORTENING", 10, 63733},
	{"PREPRINT", 8, 63734},
	{"ONYF", 4, 63735},
	{"ACHV", 4, 63736},
	{"NAXOS", 5, 63737},
	{"BOBBI", 5, 63738},
	{"COCKER", 6, 63739},
	{"STEPH", 5, 63740},
	{"LJOI", 4, 63741},
	{"PROTONIX", 8, 63742},
	{"CLOVES", 6, 63743},
	{"SYSTEMAX", 8, 63744},
	{"TSUK", 4, 63745},
	{"MARKETABLE", 10, 63746},
	{"NUNR", 4, 63747},
	{"PRESTO", 6, 63748},
	{"FACL", 4, 63749},
	{"CHYA", 4, 63750},
	{"AKIC", 4, 63751},
	{"ADUP", 4, 63752},
	{"RETRY", 5, 63753},
	{"INYL", 4, 63754},
	{"HIRAM", 5, 63755},
	{"RADFORD", 7, 63756},
	{"USHB", 4, 63757},
	{"BROADENING", 10, 63758},
	{"IMPLANTATION", 12, 63759},
	{"TELEX", 5, 63760},
	{"HUMBERSIDE", 10, 63761},
	{"XEDB", 4, 63762},
	{"OMEQ", 4, 63763},
	{"LPUN", 4, 63764},
	{"GLOBALSPEC", 10, 63765},
	{"WJL", 3, 63766},
	{"FADM", 4, 63767},
	{"EYEB", 4, 63768},
	{"KOFI", 4, 63769},
	{"MUSHARRAF", 9, 63770},
	{"DETOXIFICATION", 14, 63771},
	{"BOWED", 5, 63772},
	{"WHIMSICAL", 9, 63773},
	{"KAVE", 4, 63774},
	{"GCUT", 4, 63775},
	{"BIOU", 4, 63776},
	{"HARDEN", 6, 63777},
	{"MOLTEN", 6, 63778},
	{"MCNALLY", 7, 63779},
	{"AUREUS", 6, 63780},
	{"INFORMATIONWEEK", 15, 63781},
	{"WCLO", 4, 63782},
	{"NRYS", 4, 63783},
	{"BULO", 4, 63784},
	{"REPAID", 6, 63785},
	{"BONNEVILLE", 10, 63786},
	{"TSYM", 4, 63787},
	{"ERPM", 4, 63788},
	{"RUPS", 4, 63789},
	{"BELTWAY", 7, 63790},
	{"EPICOR", 6, 63791},
	{"GSAM", 4, 63792},
	{"ERUG", 4, 63793},
	{"ISCSI", 5, 63794},
	{"WARMLY", 6, 63795},
	{"GROSSE", 6, 63796},
	{"PENANG", 6, 63797},
	{"SPORADIC", 8, 63798},
	{"ZIPPERED", 8, 63799},
	{"OOFW", 4, 63800},
	{"BROWNIES", 8, 63801},
	{"LESSOR", 6, 63802},
	{"PDUR", 4, 63803},
	{"DYLO", 4, 63804},
	{"STRICKLAND", 10, 63805},
	{"KINASES", 7, 63806},
	{"WSPO", 4, 63807},
	{"PANELISTS", 9, 63808},
	{"EKAM", 4, 63809},
	{"DWAV", 4, 63810},
	{"CHARLENE", 8, 63811},
	{"AUTISTIC", 8, 63812},
	{"UNNECESSARILY", 13, 63813},
	{"OBUL", 4, 63814},
	{"MCOA", 4, 63815},
	{"GSCE", 4, 63816},
	{"DYSS", 4, 63817},
	{"EQUALIZATION", 12, 63818},
	{"TAGL", 4, 63819},
	{"TROIS", 5, 63820},
	{"KSAC", 4, 63821},
	{"GHBR", 4, 63822},
	{"PAINLESS", 8, 63823},
	{"FCHU", 4, 63824},
	{"CORVALLIS", 9, 63825},
	{"DOSC", 4, 63826},
	{"SERBS", 5, 63827},
	{"CKNI", 4, 63828},
	{"AWPR", 4, 63829},
	{"REUSED", 6, 63830},
	{"OKEB", 4, 63831},
	{"HPUT", 4, 63832},
	{"URKS", 4, 63833},
	{"RMPA", 4, 63834},
	{"EWDR", 4, 63835},
	{"VOLOKH", 6, 63836},
	{"GFUR", 4, 63837},
	{"AXRA", 4, 63838},
	{"URNL", 4, 63839},
	{"CLEU", 4, 63840},
	{"VARI", 4, 63841},
	{"FORDHAM", 7, 63842},
	{"VERDI", 5, 63843},
	{"ANNEXATION", 10, 63844},
	{"TUOU", 4, 63845},
	{"IFPE", 4, 63846},
	{"HYDROXY", 7, 63847},
	{"DISSATISFACTION", 15, 63848},
	{"RRZ", 3, 63849},
	{"TFEM", 4, 63850},
	{"ALPES", 5, 63851},
	{"TECHNOLOGISTS", 13, 63852},
	{"APPLAUD", 7, 63853},
	{"ULLG", 4, 63854},
	{"HABEN", 5, 63855},
	{"DEMPSEY", 7, 63856},
	{"PRIMO", 5, 63857},
	{"ABOLISH", 7, 63858},
	{"CLIMATES", 8, 63859},
	{"MYRO", 4, 63860},
	{"CHJU", 4, 63861},
	{"IROB", 4, 63862},
	{"HTTPDOCS", 8, 63863},
	{"SPEAKERPHONE", 12, 63864},
	{"YESB", 4, 63865},
	{"RNRO", 4, 63866},
	{"GHLO", 4, 63867},
	{"UNEASY", 6, 63868},
	{"REISSUES", 8, 63869},
	{"SHALOM", 6, 63870},
	{"KHMER", 5, 63871},
	{"BUSIEST", 7, 63872},
	{"RECORDABLE", 10, 63873},
	{"DREDGING", 8, 63874},
	{"FRAY", 4, 63875},
	{"FLORIAN", 7, 63876},
	{"EXTRUSION", 9, 63877},
	{"GLYO", 4, 63878},
	{"PREGGO", 6, 63879},
	{"IDGA", 4, 63880},
	{"DEFAMATION", 10, 63881},
	{"CLOGS", 5, 63882},
	{"FLANK", 5, 63883},
	{"THERON", 6, 63884},
	{"PROTEOMICS", 10, 63885},
	{"SPAWNED", 7, 63886},
	{"CARTEL", 6, 63887},
	{"PHENDIMETRAZINE", 15, 63888},
	{"WIENER", 6, 63889},
	{"THEOREMS", 8, 63890},
	{"CIFY", 4, 63891},
	{"SAMPLERS", 8, 63892},
	{"MYTR", 4, 63893},
	{"NUMERICALLY", 11, 63894},
	{"PERFORATED", 10, 63895},
	{"INTENSIFIED", 11, 63896},
	{"SWEG", 4, 63897},
	{"PASCO", 5, 63898},
	{"KDES", 4, 63899},
	{"HILBERT", 7, 63900},
	{"TAMWORTH", 8, 63901},
	{"XEDR", 4, 63902},
	{"NKAM", 4, 63903},
	{"POSTMASTER", 10, 63904},
	{"WASHES", 6, 63905},
	{"ITMJ", 4, 63906},
	{"ECKB", 4, 63907},
	{"SHRUGGED", 8, 63908},
	{"ELECTORS", 8, 63909},
	{"DEPARTS", 7, 63910},
	{"YFED", 4, 63911},
	{"HAYD", 4, 63912},
	{"GBOR", 4, 63913},
	{"FBAD", 4, 63914},
	{"PRAHA", 5, 63915},
	{"LANDRY", 6, 63916},
	{"CRACKDOWN", 9, 63917},
	{"REYB", 4, 63918},
	{"OLAG", 4, 63919},
	{"LIFESPAN", 8, 63920},
	{"MAYBACH", 7, 63921},
	{"YSKE", 4, 63922},
	{"TYSF", 4, 63923},
	{"MINDFUL", 7, 63924},
	{"LURKING", 7, 63925},
	{"AELD", 4, 63926},
	{"HITHERTO", 8, 63927},
	{"CYSTEINE", 8, 63928},
	{"OUNL", 4, 63929},
	{"WKK", 3, 63930},
	{"EGYPTIANS", 9, 63931},
	{"RESPONSIBLY", 11, 63932},
	{"UNTU", 4, 63933},
	{"SLIDESHOWS", 10, 63934},
	{"LOOMS", 5, 63935},
	{"SPECTRE", 7, 63936},
	{"AYWR", 4, 63937},
	{"DOWNRIGHT", 9, 63938},
	{"TECHTARGET", 10, 63939},
	{"URGW", 4, 63940},
	{"GEOTECHNICAL", 12, 63941},
	{"FANTASIA", 8, 63942},
	{"EDUO", 4, 63943},
	{"CAMISOLE", 8, 63944},
	{"REFRACTORY", 10, 63945},
	{"ATOLL", 5, 63946},
	{"URBL", 4, 63947},
	{"HICC", 4, 63948},
	{"ATWR", 4, 63949},
	{"COUNSELLOR", 10, 63950},
	{"SHREDDERS", 9, 63951},
	{"INEXPERIENCED", 13, 63952},
	{"SHGR", 4, 63953},
	{"LPSY", 4, 63954},
	{"OUTRAGED", 8, 63955},
	{"GAGS", 4, 63956},
	{"BELGIQUE", 8, 63957},
	{"UGAB", 4, 63958},
	{"GBON", 4, 63959},
	{"RIPS", 4, 63960},
	{"FBEE", 4, 63961},
	{"FUTURAMA", 8, 63962},
	{"SMOTHER", 7, 63963},
	{"YBUL", 4, 63964},
	{"SHCL", 4, 63965},
	{"FFBA", 4, 63966},
	{"IRONMAN", 7, 63967},
	{"DUCTS", 5, 63968},
	{"FROSTY", 6, 63969},
	{"NLAC", 4, 63970},
	{"EPBA", 4, 63971},
	{"MARMOT", 6, 63972},
	{"NACQ", 4, 63973},
	{"REMAND", 6, 63974},
	{"MULES", 5, 63975},
	{"HAWKES", 6, 63976},
	{"SPOOF", 5, 63977},
	{"TRURO", 5, 63978},
	{"MOANING", 7, 63979},
	{"PONIES", 6, 63980},
	{"GRIV", 4, 63981},
	{"SPAMMER", 7, 63982},
	{"UEBL", 4, 63983},
	{"PRESETS", 7, 63984},
	{"SEPARATIONS", 11, 63985},
	{"ORIGINATES", 10, 63986},
	{"LATW", 4, 63987},
	{"KPAC", 4, 63988},
	{"PENICILLIN", 10, 63989},
	{"AMMAN", 5, 63990},
	{"DAVOS", 5, 63991},
	{"UBHA", 4, 63992},
	{"BLIGHT", 6, 63993},
	{"PHYSIQUE", 8, 63994},
	{"MATURATION", 10, 63995},
	{"INTERNALS", 9, 63996},
	{"BUNGALOWS", 9, 63997},
	{"TKAR", 4, 63998},
	{"KONM", 4, 63999},
	{"BECKINSALE", 10, 64000},
	{"REFRACTIVE", 10, 64001},
	{"INDEPENDENTS", 12, 64002},
	{"GMUL", 4, 64003},
	{"FEMO", 4, 64004},
	{"CRAV", 4, 64005},
	{"GRADER", 6, 64006},
	{"TRANSDUCERS", 11, 64007},
	{"CTXT", 4, 64008},
	{"CONTENTIOUS", 11, 64009},
	{"MEFL", 4, 64010},
	{"CHEERING", 8, 64011},
	{"DOXYGEN", 7, 64012},
	{"ULSH", 4, 64013},
	{"ELSG", 4, 64014},
	{"CGC", 3, 64015},
	{"UMSH", 4, 64016},
	{"HREQ", 4, 64017},
	{"INTERCOLLEGIATE", 15, 64018},
	{"ZITHROMAX", 9, 64019},
	{"ARCHIBALD", 9, 64020},
	{"MINR", 4, 64021},
	{"APEB", 4, 64022},
	{"DSCL", 4, 64023},
	{"ONKYO", 5, 64024},
	{"EMANCIPATION", 12, 64025},
	{"DUCHESS", 7, 64026},
	{"RNSB", 4, 64027},
	{"RAINIER", 7, 64028},
	{"RGEV", 4, 64029},
	{"FURMAN", 6, 64030},
	{"COMMEMORATE", 11, 64031},
	{"NEWSFEEDS", 9, 64032},
	{"SPOUT", 5, 64033},
	{"AUCA", 4, 64034},
	{"JCZ", 3, 64035},
	{"INUR", 4, 64036},
	{"LARKIN", 6, 64037},
	{"BIZTALK", 7, 64038},
	{"PERISH", 6, 64039},
	{"BADP", 4, 64040},
	{"SNAPPER", 7, 64041},
	{"HEFTY", 5, 64042},
	{"FLAI", 4, 64043},
	{"BOXT", 4, 64044},
	{"NARROWER", 8, 64045},
	{"CAPTIVITY", 9, 64046},
	{"WLOO", 4, 64047},
	{"PEYTON", 6, 64048},
	{"OVERLOADED", 10, 64049},
	{"LMSI", 4, 64050},
	{"AXCO", 4, 64051},
	{"SHORTHAND", 9, 64052},
	{"VALDOSTA", 8, 64053},
	{"GEEV", 4, 64054},
	{"CERES", 5, 64055},
	{"ULEAD", 5, 64056},
	{"EYSM", 4, 64057},
	{"DSVI", 4, 64058},
	{"BRAVERY", 7, 64059},
	{"DELANEY", 7, 64060},
	{"YASF", 4, 64061},
	{"UXIL", 4, 64062},
	{"URLY", 4, 64063},
	{"LIZARDS", 7, 64064},
	{"NYPU", 4, 64065},
	{"LEXW", 4, 64066},
	{"ULYC", 4, 64067},
	{"SFLU", 4, 64068},
	{"FERGUS", 6, 64069},
	{"SINCERITY", 9, 64070},
	{"RENP", 4, 64071},
	{"NYFE", 4, 64072},
	{"CALDER", 6, 64073},
	{"HAIRLESS", 8, 64074},
	{"MULLINS", 7, 64075},
	{"LACTATION", 9, 64076},
	{"FKAN", 4, 64077},
	{"INNSBRUCK", 9, 64078},
	{"FLAGGED", 7, 64079},
	{"NKIR", 4, 64080},
	{"WUSE", 4, 64081},
	{"UTYI", 4, 64082},
	{"UTCE", 4, 64083},
	{"OFFBEAT", 7, 64084},
	{"RELICS", 6, 64085},
	{"RELISH", 6, 64086},
	{"RSYM", 4, 64087},
	{"TEENIE", 6, 64088},
	{"EMCE", 4, 64089},
	{"PROTONS", 7, 64090},
	{"IMAGINING", 9, 64091},
	{"MACHINED", 8, 64092},
	{"CTPL", 4, 64093},
	{"BELONGINGS", 10, 64094},
	{"HOLMAN", 6, 64095},
	{"EVICTION", 8, 64096},
	{"LIRE", 4, 64097},
	{"LEGISLATURES", 12, 64098},
	{"TIMW", 4, 64099},
	{"OIDP", 4, 64100},
	{"CREV", 4, 64101},
	{"CASW", 4, 64102},
	{"UNCHECKED", 9, 64103},
	{"RLDD", 4, 64104},
	{"ODAB", 4, 64105},
	{"KNOCKS", 6, 64106},
	{"REGIONALLY", 10, 64107},
	{"ALFONSO", 7, 64108},
	{"OLDK", 4, 64109},
	{"LFDO", 4, 64110},
	{"THURMAN", 7, 64111},
	{"CANARIA", 7, 64112},
	{"SHOWCASING", 10, 64113},
	{"OVAC", 4, 64114},
	{"CONTRADICT", 10, 64115},
	{"CERTIFIES", 9, 64116},
	{"FLEURS", 6, 64117},
	{"SCARCITY", 8, 64118},
	{"ASHBY", 5, 64119},
	{"PRIMES", 6, 64120},
	{"EGRU", 4, 64121},
	{"FLEEING", 7, 64122},
	{"RENTON", 6, 64123},
	{"OPBE", 4, 64124},
	{"LAMBETH", 7, 64125},
	{"FILAMENT", 8, 64126},
	{"FRAPPR", 6, 64127},
	{"YEDL", 4, 64128},
	{"HTBR", 4, 64129},
	{"ERNV", 4, 64130},
	{"ABINGDON", 8, 64131},
	{"XYK", 3, 64132},
	{"THEORISTS", 9, 64133},
	{"MEXC", 4, 64134},
	{"EYEW", 4, 64135},
	{"LITURGICAL", 10, 64136},
	{"SOUTHWARK", 9, 64137},
	{"KINJ", 4, 64138},
	{"CELIA", 5, 64139},
	{"DISGUISED", 9, 64140},
	{"IMPLANTED", 9, 64141},
	{"OPENAFS", 7, 64142},
	{"GHUR", 4, 64143},
	{"ASSWORD", 7, 64144},
	{"RVING", 5, 64145},
	{"HODR", 4, 64146},
	{"EXOGENOUS", 9, 64147},
	{"FWEW", 4, 64148},
	{"DKNE", 4, 64149},
	{"SRAM", 4, 64150},
	{"SAULT", 5, 64151},
	{"THRASH", 6, 64152},
	{"TROLLS", 6, 64153},
	{"EFTU", 4, 64154},
	{"FLOR", 4, 64155},
	{"ANTIQUARIAN", 11, 64156},
	{"SHYP", 4, 64157},
	{"LDDU", 4, 64158},
	{"FLUENCY", 7, 64159},
	{"UNITING", 7, 64160},
	{"OLEG", 4, 64161},
	{"RTHV", 4, 64162},
	{"RLYJ", 4, 64163},
	{"BEHAVES", 7, 64164},
	{"SLABS", 5, 64165},
	{"CONCEIVABLE", 11, 64166},
	{"ICYW", 4, 64167},
	{"HYMA", 4, 64168},
	{"UYSO", 4, 64169},
	{"PAYH", 4, 64170},
	{"CUTF", 4, 64171},
	{"ANALYZERS", 9, 64172},
	{"AGATE", 5, 64173},
	{"YMUL", 4, 64174},
	{"CYDE", 4, 64175},
	{"INCLINE", 7, 64176},
	{"RSIV", 4, 64177},
	{"CKCR", 4, 64178},
	{"AELL", 4, 64179},
	{"HARTMANN", 8, 64180},
	{"LUNK", 4, 64181},
	{"LPOU", 4, 64182},
	{"SCORER", 6, 64183},
	{"SWAMI", 5, 64184},
	{"OILERS", 6, 64185},
	{"ERKM", 4, 64186},
	{"MANDELA", 7, 64187},
	{"LISTERS", 7, 64188},
	{"ORDINATED", 9, 64189},
	{"SOLICITING", 10, 64190},
	{"THOROUGHBRED", 12, 64191},
	{"ARLENE", 6, 64192},
	{"CALLE", 5, 64193},
	{"ONYR", 4, 64194},
	{"ONENESS", 7, 64195},
	{"DIVIDERS", 8, 64196},
	{"PSWO", 4, 64197},
	{"CLIMBER", 7, 64198},
	{"RECOVERABLE", 11, 64199},
	{"GATORS", 6, 64200},
	{"ODSM", 4, 64201},
	{"COMMONPLACE", 11, 64202},
	{"FLEI", 4, 64203},
	{"DOEV", 4, 64204},
	{"INTELLECTUALLY", 14, 64205},
	{"INTRADAY", 8, 64206},
	{"CRUCES", 6, 64207},
	{"CASANOVA", 8, 64208},
	{"UADO", 4, 64209},
	{"OUBA", 4, 64210},
	{"DSOD", 4, 64211},
	{"HIMALAYAN", 9, 64212},
	{"HOLLISTER", 9, 64213},
	{"ENEWS", 5, 64214},
	{"RYCU", 4, 64215},
	{"LACTOSE", 7, 64216},
	{"GIFFORD", 7, 64217},
	{"COMPETITIVELY", 13, 64218},
	{"ROCKSTAR", 8, 64219},
	{"WXW", 3, 64220},
	{"WWZ", 3, 64221},
	{"LJL", 3, 64222},
	{"DCOW", 4, 64223},
	{"DOWNFALL", 8, 64224},
	{"RGIO", 4, 64225},
	{"HAMPSTEAD", 9, 64226},
	{"CHRONO", 6, 64227},
	{"NAHUM", 5, 64228},
	{"RYAU", 4, 64229},
	{"RMMA", 4, 64230},
	{"OALC", 4, 64231},
	{"IRMW", 4, 64232},
	{"BOOKCASES", 9, 64233},
	{"STRIDES", 7, 64234},
	{"WFEA", 4, 64235},
	{"UPNO", 4, 64236},
	{"RAJA", 4, 64237},
	{"DETW", 4, 64238},
	{"NEXTLAST", 8, 64239},
	{"XINHUA", 6, 64240},
	{"WOFE", 4, 64241},
	{"LOFTS", 5, 64242},
	{"FERAL", 5, 64243},
	{"IXPO", 4, 64244},
	{"NEUROSURGERY", 12, 64245},
	{"TRANSMITS", 9, 64246},
	{"VEYI", 4, 64247},
	{"ADAIR", 5, 64248},
	{"RINGGIT", 7, 64249},
	{"IMPATIENT", 9, 64250},
	{"AFORESAID", 9, 64251},
	{"ELBOWS", 6, 64252},
	{"TRUCE", 5, 64253},
	{"UADS", 4, 64254},
	{"LBYA", 4, 64255},
	{"BETTE", 5, 64256},
	{"UKRANIAN", 8, 64257},
	{"LSGR", 4, 64258},
	{"PARMESAN", 8, 64259},
	{"WNLE", 4, 64260},
	{"KECL", 4, 64261},
	{"HCOV", 4, 64262},
	{"KIOSKS", 6, 64263},
	{"CVIO", 4, 64264},
	{"STAIRWAY", 8, 64265},
	{"YLEM", 4, 64266},
	{"LTUN", 4, 64267},
	{"HMUL", 4, 64268},
	{"WOODROW", 7, 64269},
	{"USJO", 4, 64270},
	{"BOAR", 4, 64271},
	{"VERTEBRATE", 10, 64272},
	{"RANP", 4, 64273},
	{"APUP", 4, 64274},
	{"HOOKING", 7, 64275},
	{"NODD", 4, 64276},
	{"DDYS", 4, 64277},
	{"RAWLINGS", 8, 64278},
	{"ESYR", 4, 64279},
	{"ERIU", 4, 64280},
	{"PHYSIOTHERAPY", 13, 64281},
	{"LAIRD", 5, 64282},
	{"MULTIPLICITY", 12, 64283},
	{"OBJECTIVELY", 11, 64284},
	{"WREXHAM", 7, 64285},
	{"RESIGNS", 7, 64286},
	{"BILLABONG", 9, 64287},
	{"PREPAYMENT", 10, 64288},
	{"ULIC", 4, 64289},
	{"JONESBORO", 9, 64290},
	{"ANGUISH", 7, 64291},
	{"PETAL", 5, 64292},
	{"PERFECTED", 9, 64293},
	{"SUPH", 4, 64294},
	{"BANGERS", 7, 64295},
	{"HANDGUN", 7, 64296},
	{"TOMLINSON", 9, 64297},
	{"GODH", 4, 64298},
	{"GAMU", 4, 64299},
	{"MISCATEGORIZED", 14, 64300},
	{"ODORS", 5, 64301},
	{"DESOTO", 6, 64302},
	{"PENR", 4, 64303},
	{"BLACKSTONE", 10, 64304},
	{"CLIPPED", 7, 64305},
	{"NUSW", 4, 64306},
	{"ETUM", 4, 64307},
	{"INNOVATOR", 9, 64308},
	{"MITOCHONDRIA", 12, 64309},
	{"MEWN", 4, 64310},
	{"SERNAME", 7, 64311},
	{"MCIN", 4, 64312},
	{"USMC", 4, 64313},
	{"AMICUS", 6, 64314},
	{"VIJAY", 5, 64315},
	{"REDIRECTING", 11, 64316},
	{"UTJA", 4, 64317},
	{"SMWA", 4, 64318},
	{"LEYG", 4, 64319},
	{"HORB", 4, 64320},
	{"CERVIX", 6, 64321},
	{"ULTD", 4, 64322},
	{"IEDJ", 4, 64323},
	{"BIBLIA", 6, 64324},
	{"LAGO", 4, 64325},
	{"COSBY", 5, 64326},
	{"DRIES", 5, 64327},
	{"FALM", 4, 64328},
	{"NVAC", 4, 64329},
	{"EACK", 4, 64330},
	{"MEJOR", 5, 64331},
	{"ANNOYANCE", 9, 64332},
	{"GRATING", 7, 64333},
	{"PROSTITUTE", 10, 64334},
	{"LUFTHANSA", 9, 64335},
	{"ODYD", 4, 64336},
	{"DDOR", 4, 64337},
	{"MSNSHOPPING", 11, 64338},
	{"LIPH", 4, 64339},
	{"ELIXIR", 6, 64340},
	{"SEWERAGE", 8, 64341},
	{"GUARDIANSHIP", 12, 64342},
	{"GAMBLERS", 8, 64343},
	{"RYVA", 4, 64344},
	{"ROSW", 4, 64345},
	{"AUTRE", 5, 64346},
	{"MANTIS", 6, 64347},
	{"APIR", 4, 64348},
	{"PEEPS", 5, 64349},
	{"ALERTED", 7, 64350},
	{"UNDK", 4, 64351},
	{"INTRON", 6, 64352},
	{"GFAT", 4, 64353},
	{"REVERENCE", 9, 64354},
	{"ICOW", 4, 64355},
	{"FAEL", 4, 64356},
	{"REMODEL", 7, 64357},
	{"SARDINIA", 8, 64358},
	{"CARPAL", 6, 64359},
	{"NATALIA", 7, 64360},
	{"FMUR", 4, 64361},
	{"CJK", 3, 64362},
	{"SPECIALISES", 11, 64363},
	{"OUTWEIGH", 8, 64364},
	{"UFRO", 4, 64365},
	{"TBYL", 4, 64366},
	{"VERNE", 5, 64367},
	{"CONDIMENTS", 10, 64368},
	{"EPWI", 4, 64369},
	{"DIDG", 4, 64370},
	{"ADYK", 4, 64371},
	{"ADVENTIST", 9, 64372},
	{"EGGPLANT", 8, 64373},
	{"GAYLORD", 7, 64374},
	{"BUNTING", 7, 64375},
	{"MPSW", 4, 64376},
	{"ARPH", 4, 64377},
	{"COUN", 4, 64378},
	{"AVENGER", 7, 64379},
	{"YVIO", 4, 64380},
	{"ACOW", 4, 64381},
	{"WYCOMBE", 7, 64382},
	{"MONAGHAN", 8, 64383},
	{"SPAR", 4, 64384},
	{"BLOGARAMA", 9, 64385},
	{"DEEV", 4, 64386},
	{"WAUGH", 5, 64387},
	{"CAPTIVATING", 11, 64388},
	{"VACCINATIONS", 12, 64389},
	{"TIERS", 5, 64390},
	{"WORA", 4, 64391},
	{"MBST", 4, 64392},
	{"IMFI", 4, 64393},
	{"GUTIERREZ", 9, 64394},
	{"BERND", 5, 64395},
	{"CENTURION", 9, 64396},
	{"LMSO", 4, 64397},
	{"PROPAGATE", 9, 64398},
	{"NEEDHAM", 7, 64399},
	{"ALJE", 4, 64400},
	{"PROSECUTING", 11, 64401},
	{"INUIT", 5, 64402},
	{"IZEB", 4, 64403},
	{"HEDJ", 4, 64404},
	{"MONTPELLIER", 11, 64405},
	{"WORDNET", 7, 64406},
	{"WLIF", 4, 64407},
	{"LETF", 4, 64408},
	{"GCUS", 4, 64409},
	{"WILLEM", 6, 64410},
	{"RIEG", 4, 64411},
	{"CSOC", 4, 64412},
	{"WEDI", 4, 64413},
	{"SLAVIC", 6, 64414},
	{"PQUA", 4, 64415},
	{"KEYES", 5, 64416},
	{"PHOTOCOPYING", 12, 64417},
	{"NUTRITIOUS", 10, 64418},
	{"MARGUERITE", 10, 64419},
	{"YVB", 3, 64420},
	{"DZF", 3, 64421},
	{"VAPOUR", 6, 64422},
	{"PLUCK", 5, 64423},
	{"MYSU", 4, 64424},
	{"CAUTIOUSLY", 10, 64425},
	{"PRICK", 5, 64426},
	{"CONTINGENCIES", 13, 64427},
	{"DRESSAGE", 8, 64428},
	{"CAFEPRESS", 9, 64429},
	{"OGEY", 4, 64430},
	{"PHYLOGENETIC", 12, 64431},
	{"COERCION", 8, 64432},
	{"KURTZ", 5, 64433},
	{"LKHA", 4, 64434},
	{"IGMO", 4, 64435},
	{"MORBID", 6, 64436},
	{"REFRESHER", 9, 64437},
	{"PICARD", 6, 64438},
	{"AVYT", 4, 64439},
	{"RUBBLE", 6, 64440},
	{"FREAKONOMICS", 12, 64441},
	{"IMPREZA", 7, 64442},
	{"YPEW", 4, 64443},
	{"SCRAMBLED", 9, 64444},
	{"CHEEKY", 6, 64445},
	{"ARCO", 4, 64446},
	{"AGITATION", 9, 64447},
	{"PROPONENT", 9, 64448},
	{"BRASILEIRO", 10, 64449},
	{"GUNW", 4, 64450},
	{"ROJO", 4, 64451},
	{"TRUTHFUL", 8, 64452},
	{"WOODPECKER", 10, 64453},
	{"PERSCRIPTION", 12, 64454},
	{"UCAL", 4, 64455},
	{"FTHU", 4, 64456},
	{"STREISAND", 9, 64457},
	{"EASTSIDE", 8, 64458},
	{"YERL", 4, 64459},
	{"HERDS", 5, 64460},
	{"CORSICA", 7, 64461},
	{"ERUD", 4, 64462},
	{"DIPP", 4, 64463},
	{"BIOETHICS", 9, 64464},
	{"REDO", 4, 64465},
	{"PENETRATED", 10, 64466},
	{"RKDI", 4, 64467},
	{"LATB", 4, 64468},
	{"HLAB", 4, 64469},
	{"UMPU", 4, 64470},
	{"PIRANHA", 7, 64471},
	{"UCHU", 4, 64472},
	{"ERPT", 4, 64473},
	{"CMU", 3, 64474},
	{"RISY", 4, 64475},
	{"MFAC", 4, 64476},
	{"CHBL", 4, 64477},
	{"UNCOMPRESSED", 12, 64478},
	{"PSEUDOMONAS", 11, 64479},
	{"ADDER", 5, 64480},
	{"SOTHEBY", 7, 64481},
	{"WEAKEST", 7, 64482},
	{"WEAKENING", 9, 64483},
	{"AVIONICS", 8, 64484},
	{"ITQU", 4, 64485},
	{"MINIMIZATION", 12, 64486},
	{"ASCOT", 5, 64487},
	{"THORNE", 6, 64488},
	{"LINEARLY", 8, 64489},
	{"DOLAN", 5, 64490},
	{"NYEV", 4, 64491},
	{"NBYO", 4, 64492},
	{"CTUN", 4, 64493},
	{"TITLEIST", 8, 64494},
	{"ANTICIPATES", 11, 64495},
	{"SFUE", 4, 64496},
	{"GENESEE", 7, 64497},
	{"POIGNANT", 8, 64498},
	{"GERMS", 5, 64499},
	{"GRAYS", 5, 64500},
	{"FDC", 3, 64501},
	{"YSPU", 4, 64502},
	{"RWID", 4, 64503},
	{"NGUR", 4, 64504},
	{"LTYM", 4, 64505},
	{"AILG", 4, 64506},
	{"IGME", 4, 64507},
	{"FREES", 5, 64508},
	{"VWW", 3, 64509},
	{"VMY", 3, 64510},
	{"PUNISHABLE", 10, 64511},
	{"FRACTURED", 9, 64512},
	{"VADI", 4, 64513},
	{"FHAM", 4, 64514},
	{"PSYCHIATRISTS", 13, 64515},
	{"WATERMAN", 8, 64516},
	{"URNM", 4, 64517},
	{"BRAT", 4, 64518},
	{"PBEF", 4, 64519},
	{"URANUS", 6, 64520},
	{"MULTIPLEX", 9, 64521},
	{"YREO", 4, 64522},
	{"SALIENT", 7, 64523},
	{"BRADBURY", 8, 64524},
	{"BABYSITTING", 11, 64525},
	{"UBFO", 4, 64526},
	{"GABE", 4, 64527},
	{"USUP", 4, 64528},
	{"FSAY", 4, 64529},
	{"EWKI", 4, 64530},
	{"RWAI", 4, 64531},
	{"GHMI", 4, 64532},
	{"BEEHIVE", 7, 64533},
	{"CENSOR", 6, 64534},
	{"LIVIN", 5, 64535},
	{"LEBLANC", 7, 64536},
	{"RKEA", 4, 64537},
	{"SHORTY", 6, 64538},
	{"INJECTING", 9, 64539},
	{"DISCONTINUITY", 13, 64540},
	{"SEMITIC", 7, 64541},
	{"UBSP", 4, 64542},
	{"AKRA", 4, 64543},
	{"LITTLEWOODS", 11, 64544},
	{"ENQUIRER", 8, 64545},
	{"PERVERTED", 9, 64546},
	{"DOWNTURN", 8, 64547},
	{"BORDERING", 9, 64548},
	{"FISSION", 7, 64549},
	{"MODULATOR", 9, 64550},
	{"NOCU", 4, 64551},
	{"WIDOWED", 7, 64552},
	{"SPYBOT", 6, 64553},
	{"HEFC", 4, 64554},
	{"TOMBSTONE", 9, 64555},
	{"WORLDVIEW", 9, 64556},
	{"CHOREOGRAPHY", 12, 64557},
	{"FDOU", 4, 64558},
	{"BEGGED", 6, 64559},
	{"BUFFERING", 9, 64560},
	{"DENISON", 7, 64561},
	{"KILLARNEY", 9, 64562},
	{"FLUSHED", 7, 64563},
	{"SCOPING", 7, 64564},
	{"CAUTIONS", 8, 64565},
	{"LAVISH", 6, 64566},
	{"ROSCOE", 6, 64567},
	{"BRIGHTEN", 8, 64568},
	{"VIXEN", 5, 64569},
	{"MAMMOGRAPHY", 11, 64570},
	{"UNME", 4, 64571},
	{"WHIPS", 5, 64572},
	{"TYSY", 4, 64573},
	{"PIEG", 4, 64574},
	{"MARCHES", 7, 64575},
	{"MADH", 4, 64576},
	{"NEPALESE", 8, 64577},
	{"MJUL", 4, 64578},
	{"EWGU", 4, 64579},
	{"COMMUNICABLE", 12, 64580},
	{"ENZYMATIC", 9, 64581},
	{"UTIR", 4, 64582},
	{"URUG", 4, 64583},
	{"MELANOGASTER", 12, 64584},
	{"CTBY", 4, 64585},
	{"EXTRAVAGANZA", 12, 64586},
	{"COMMANDMENT", 11, 64587},
	{"WKJ", 3, 64588},
	{"UNDETERMINED", 12, 64589},
	{"KAMLOOPS", 8, 64590},
	{"HORNER", 6, 64591},
	{"CONCEDED", 8, 64592},
	{"TFTP", 4, 64593},
	{"POSTPONE", 8, 64594},
	{"ROTHERHAM", 9, 64595},
	{"FWIS", 4, 64596},
	{"CTIB", 4, 64597},
	{"UNDERESTIMATE", 13, 64598},
	{"ULLU", 4, 64599},
	{"NRAP", 4, 64600},
	{"DISPROPORTIONATE", 16, 64601},
	{"PHEASANT", 8, 64602},
	{"ALONSO", 6, 64603},
	{"BALLY", 5, 64604},
	{"ZIJN", 4, 64605},
	{"YGUE", 4, 64606},
	{"MACB", 4, 64607},
	{"GUILLAUME", 9, 64608},
	{"MYCAREER", 8, 64609},
	{"MARRYING", 8, 64610},
	{"BITL", 4, 64611},
	{"CARVINGS", 8, 64612},
	{"COOLEY", 6, 64613},
	{"GRATUITEMENT", 12, 64614},
	{"ERIKSSON", 8, 64615},
	{"IRDH", 4, 64616},
	{"SCHAUMBURG", 10, 64617},
	{"EXPONENTIALLY", 13, 64618},
	{"NLYY", 4, 64619},
	{"CHECHEN", 7, 64620},
	{"CARRIBEAN", 9, 64621},
	{"COMPLAINS", 9, 64622},
	{"IFIM", 4, 64623},
	{"BUNNIES", 7, 64624},
	{"CHOPPERS", 8, 64625},
	{"PSYC", 4, 64626},
	{"PEDERSEN", 8, 64627},
	{"CSBU", 4, 64628},
	{"RMSM", 4, 64629},
	{"DIFE", 4, 64630},
	{"DFAV", 4, 64631},
	{"EARPHONES", 9, 64632},
	{"OUTFLOW", 7, 64633},
	{"RESIDED", 7, 64634},
	{"EYAG", 4, 64635},
	{"TERRIERS", 8, 64636},
	{"SCARAB", 6, 64637},
	{"TOASTERS", 8, 64638},
	{"SKIERS", 6, 64639},
	{"ILFU", 4, 64640},
	{"EMEV", 4, 64641},
	{"SMYT", 4, 64642},
	{"RPHE", 4, 64643},
	{"JAMAL", 5, 64644},
	{"WEASEL", 6, 64645},
	{"OAPL", 4, 64646},
	{"RAUNCHY", 7, 64647},
	{"BIOLOGICALLY", 12, 64648},
	{"VANB", 4, 64649},
	{"LAYN", 4, 64650},
	{"VENERABLE", 9, 64651},
	{"DSKE", 4, 64652},
	{"MFOL", 4, 64653},
	{"ZYRTEC", 6, 64654},
	{"PREIS", 5, 64655},
	{"RIYADH", 6, 64656},
	{"RERR", 4, 64657},
	{"OSFR", 4, 64658},
	{"PELL", 4, 64659},
	{"TOASTED", 7, 64660},
	{"ADMIRABLE", 9, 64661},
	{"PUSC", 4, 64662},
	{"ILLUMINATE", 10, 64663},
	{"QUICKSEARCH", 11, 64664},
	{"HOLBROOK", 8, 64665},
	{"FADES", 5, 64666},
	{"COATES", 6, 64667},
	{"OCTANE", 6, 64668},
	{"BULGE", 5, 64669},
	{"LFCL", 4, 64670},
	{"KRABI", 5, 64671},
	{"ELLER", 5, 64672},
	{"TRAJ", 4, 64673},
	{"LUCINDA", 7, 64674},
	{"NBAB", 4, 64675},
	{"FUNDERS", 7, 64676},
	{"WGG", 3, 64677},
	{"OVIR", 4, 64678},
	{"HURI", 4, 64679},
	{"BRITTLE", 7, 64680},
	{"LLAK", 4, 64681},
	{"EAUR", 4, 64682},
	{"DKEV", 4, 64683},
	{"CCP", 3, 64684},
	{"ENVIRONMENTALISTS", 17, 64685},
	{"FATAH", 5, 64686},
	{"BANDITS", 7, 64687},
	{"GYDE", 4, 64688},
	{"POLITELY", 8, 64689},
	{"ACKERMAN", 8, 64690},
	{"GBC", 3, 64691},
	{"SOAPBOX", 7, 64692},
	{"NEWBERRY", 8, 64693},
	{"DESDE", 5, 64694},
	{"WATERMELON", 10, 64695},
	{"INGENIOUS", 9, 64696},
	{"DEANNA", 6, 64697},
	{"CAROLS", 6, 64698},
	{"BESTELLEN", 9, 64699},
	{"PENSIONERS", 10, 64700},
	{"ELONGATION", 10, 64701},
	{"SUPB", 4, 64702},
	{"WEBCRAWLER", 10, 64703},
	{"WANKING", 7, 64704},
	{"UMAD", 4, 64705},
	{"RPAP", 4, 64706},
	{"OFSTED", 6, 64707},
	{"YKEP", 4, 64708},
	{"WINV", 4, 64709},
	{"ALMB", 4, 64710},
	{"DORTMUND", 8, 64711},
	{"OBADIAH", 7, 64712},
	{"MANNHEIM", 8, 64713},
	{"BOARDROOM", 9, 64714},
	{"RAYD", 4, 64715},
	{"MROC", 4, 64716},
	{"SYLU", 4, 64717},
	{"TAPING", 6, 64718},
	{"ATLEAST", 7, 64719},
	{"SOMATIC", 7, 64720},
	{"LJAN", 4, 64721},
	{"MALLOC", 6, 64722},
	{"HEPBURN", 7, 64723},
	{"OLWO", 4, 64724},
	{"FETCHED", 7, 64725},
	{"RLUC", 4, 64726},
	{"VALM", 4, 64727},
	{"GDET", 4, 64728},
	{"CMET", 4, 64729},
	{"LANZAROTE", 9, 64730},
	{"ALDERMAN", 8, 64731},
	{"BSWH", 4, 64732},
	{"SLUMP", 5, 64733},
	{"NERDS", 5, 64734},
	{"LAUDE", 5, 64735},
	{"LOCKWOOD", 8, 64736},
	{"SIMULATING", 10, 64737},
	{"COUGHING", 8, 64738},
	{"ILAU", 4, 64739},
	{"CAWI", 4, 64740},
	{"HIATUS", 6, 64741},
	{"ENROL", 5, 64742},
	{"UPHOLSTERED", 11, 64743},
	{"EVANGELIST", 10, 64744},
	{"LOUVRE", 6, 64745},
	{"SPURIOUS", 8, 64746},
	{"CFLAGS", 6, 64747},
	{"GLOOM", 5, 64748},
	{"SEVERN", 6, 64749},
	{"DATAFIELDNAME", 13, 64750},
	{"WYCLIFFE", 8, 64751},
	{"VEKE", 4, 64752},
	{"AIKIDO", 6, 64753},
	{"WPY", 3, 64754},
	{"NTYG", 4, 64755},
	{"BATCHES", 7, 64756},
	{"GWON", 4, 64757},
	{"ANGELIC", 7, 64758},
	{"EDEQ", 4, 64759},
	{"ASTROLOGICAL", 12, 64760},
	{"KOURNIKOVA", 10, 64761},
	{"MOSHE", 5, 64762},
	{"AOFM", 4, 64763},
	{"NOBILITY", 8, 64764},
	{"FSBO", 4, 64765},
	{"SHIPPERS", 8, 64766},
	{"TUPP", 4, 64767},
	{"MPOF", 4, 64768},
	{"MONJ", 4, 64769},
	{"KFIN", 4, 64770},
	{"DTUN", 4, 64771},
	{"WILDFLOWERS", 11, 64772},
	{"BAYERN", 6, 64773},
	{"POLYGONS", 8, 64774},
	{"DELIMITED", 9, 64775},
	{"NONCOMPLIANCE", 13, 64776},
	{"CKSN", 4, 64777},
	{"AFTERNOONS", 10, 64778},
	{"RAMIFICATIONS", 13, 64779},
	{"FGUA", 4, 64780},
	{"WAKES", 5, 64781},
	{"ASHORE", 6, 64782},
	{"RUDG", 4, 64783},
	{"IRGU", 4, 64784},
	{"WORKMAN", 7, 64785},
	{"SWIMMER", 7, 64786},
	{"PUTB", 4, 64787},
	{"KDRO", 4, 64788},
	{"UNLOAD", 6, 64789},
	{"BWIL", 4, 64790},
	{"VIDSVIDSVIDS", 12, 64791},
	{"TKIC", 4, 64792},
	{"FBOU", 4, 64793},
	{"HERTS", 5, 64794},
	{"BELLAGIO", 8, 64795},
	{"WEBAPP", 6, 64796},
	{"HARYANA", 7, 64797},
	{"DLLS", 4, 64798},
	{"PBRI", 4, 64799},
	{"IDSD", 4, 64800},
	{"BABYSITTER", 10, 64801},
	{"LINOTYPE", 8, 64802},
	{"PRODUKTE", 8, 64803},
	{"MARGE", 5, 64804},
	{"IALK", 4, 64805},
	{"MEDIATORS", 9, 64806},
	{"GBEI", 4, 64807},
	{"RIGGS", 5, 64808},
	{"JOCKEYS", 7, 64809},
	{"WANDERERS", 9, 64810},
	{"SEATER", 6, 64811},
	{"YLOG", 4, 64812},
	{"BRIGHTSTOR", 10, 64813},
	{"DELIVERABLE", 11, 64814},
	{"YBYH", 4, 64815},
	{"BADNESS", 7, 64816},
	{"UMSP", 4, 64817},
	{"NTYJ", 4, 64818},
	{"LKES", 4, 64819},
	{"LANR", 4, 64820},
	{"BESL", 4, 64821},
	{"SANDING", 7, 64822},
	{"GEXA", 4, 64823},
	{"UNDERTAKES", 10, 64824},
	{"AMSG", 4, 64825},
	{"MISCARRIAGE", 11, 64826},
	{"VULGATE", 7, 64827},
	{"STONED", 6, 64828},
	{"BUFFERED", 8, 64829},
	{"KILY", 4, 64830},
	{"PROVOKED", 8, 64831},
	{"ORTON", 5, 64832},
	{"DNOD", 4, 64833},
	{"AYIW", 4, 64834},
	{"INDESIGN", 8, 64835},
	{"LAKESHORE", 9, 64836},
	{"FFUL", 4, 64837},
	{"ICVO", 4, 64838},
	{"HERR", 4, 64839},
	{"FABLES", 6, 64840},
	{"GFEL", 4, 64841},
	{"ALAND", 5, 64842},
	{"CLARINS", 7, 64843},
	{"SOFQ", 4, 64844},
	{"RDCL", 4, 64845},
	{"LTYW", 4, 64846},
	{"PELHAM", 6, 64847},
	{"CRUMBS", 6, 64848},
	{"YWK", 3, 64849},
	{"RPQ", 3, 64850},
	{"LRJ", 3, 64851},
	{"GFJ", 3, 64852},
	{"WORT", 4, 64853},
	{"RONIN", 5, 64854},
	{"FTOV", 4, 64855},
	{"COMPS", 5, 64856},
	{"UTOL", 4, 64857},
	{"OUGI", 4, 64858},
	{"LTIL", 4, 64859},
	{"GISF", 4, 64860},
	{"GRECO", 5, 64861},
	{"KONTAKTE", 8, 64862},
	{"PALISADES", 9, 64863},
	{"EDEMA", 5, 64864},
	{"CONFIDENTLY", 11, 64865},
	{"OLLF", 4, 64866},
	{"LEADERBOARD", 11, 64867},
	{"YHIR", 4, 64868},
	{"FTBY", 4, 64869},
	{"COMMENCES", 9, 64870},
	{"EMYL", 4, 64871},
	{"GLAB", 4, 64872},
	{"FLAU", 4, 64873},
	{"DISPENSE", 8, 64874},
	{"GEOCITIES", 9, 64875},
	{"ARGC", 4, 64876},
	{"DANGEROUSLY", 11, 64877},
	{"LKAL", 4, 64878},
	{"FIGARO", 6, 64879},
	{"SADIE", 5, 64880},
	{"CCLU", 4, 64881},
	{"PALOS", 5, 64882},
	{"OGRI", 4, 64883},
	{"PROTESTED", 9, 64884},
	{"CAPITALISTS", 11, 64885},
	{"NSUD", 4, 64886},
	{"CAROTID", 7, 64887},
	{"ACCUSING", 8, 64888},
	{"STINK", 5, 64889},
	{"CONVENT", 7, 64890},
	{"VALDEZ", 6, 64891},
	{"GGLO", 4, 64892},
	{"AFLU", 4, 64893},
	{"CHILDISH", 8, 64894},
	{"YEDR", 4, 64895},
	{"UALV", 4, 64896},
	{"RODN", 4, 64897},
	{"CKGO", 4, 64898},
	{"ACYB", 4, 64899},
	{"SQUISH", 6, 64900},
	{"GORHAM", 6, 64901},
	{"MYON", 4, 64902},
	{"ADHERED", 7, 64903},
	{"PRIESTHOOD", 10, 64904},
	{"CALPHALON", 9, 64905},
	{"GCHU", 4, 64906},
	{"BLASEN", 6, 64907},
	{"KERU", 4, 64908},
	{"JAGGED", 6, 64909},
	{"MIDWIVES", 8, 64910},
	{"NETBEANS", 8, 64911},
	{"RRAF", 4, 64912},
	{"EJAD", 4, 64913},
	{"CYCLONES", 8, 64914},
	{"DISPERSAL", 9, 64915},
	{"TAPETY", 6, 64916},
	{"OCKG", 4, 64917},
	{"OVERT", 5, 64918},
	{"SNOWFLAKE", 9, 64919},
	{"OOBU", 4, 64920},
	{"KSAW", 4, 64921},
	{"UTHG", 4, 64922},
	{"OKEC", 4, 64923},
	{"BLACKHAWK", 9, 64924},
	{"WEINSTEIN", 9, 64925},
	{"VERBALLY", 8, 64926},
	{"GAWH", 4, 64927},
	{"SQUEAK", 6, 64928},
	{"STERILIZATION", 13, 64929},
	{"ASSESSORS", 9, 64930},
	{"CHENILLE", 8, 64931},
	{"DEHYDRATION", 11, 64932},
	{"HAIRCUT", 7, 64933},
	{"FHWA", 4, 64934},
	{"MISCONCEPTIONS", 14, 64935},
	{"CONSTITUTING", 12, 64936},
	{"ALTERNET", 8, 64937},
	{"UNDECLARED", 10, 64938},
	{"BARI", 4, 64939},
	{"TEMY", 4, 64940},
	{"RSTK", 4, 64941},
	{"LEMY", 4, 64942},
	{"ARXI", 4, 64943},
	{"UWAI", 4, 64944},
	{"NFIC", 4, 64945},
	{"CYNI", 4, 64946},
	{"SONGWRITERS", 11, 64947},
	{"TOLERANCES", 10, 64948},
	{"INCARCERATION", 13, 64949},
	{"LVV", 3, 64950},
	{"GKF", 3, 64951},
	{"SGIF", 4, 64952},
	{"LUOR", 4, 64953},
	{"KERJ", 4, 64954},
	{"PRONOUNCE", 9, 64955},
	{"SCORPIONS", 9, 64956},
	{"HIERARCHIES", 11, 64957},
	{"LYJA", 4, 64958},
	{"BYEV", 4, 64959},
	{"REDONDO", 7, 64960},
	{"LACTATING", 9, 64961},
	{"RICG", 4, 64962},
	{"FEBU", 4, 64963},
	{"COWE", 4, 64964},
	{"INCOMPLETENESS", 14, 64965},
	{"THURSTON", 8, 64966},
	{"AQUAMARINE", 10, 64967},
	{"DPOE", 4, 64968},
	{"DEARLY", 6, 64969},
	{"SUGGESTIVE", 10, 64970},
	{"RJEF", 4, 64971},
	{"ALFP", 4, 64972},
	{"SEDIMENTATION", 13, 64973},
	{"OPTOMETRY", 9, 64974},
	{"YPAG", 4, 64975},
	{"TURR", 4, 64976},
	{"ELECTRIFIED", 11, 64977},
	{"SHMU", 4, 64978},
	{"RMHO", 4, 64979},
	{"PTWH", 4, 64980},
	{"MOBILIZE", 8, 64981},
	{"ATTENDEE", 8, 64982},
	{"UNBALANCED", 10, 64983},
	{"YASB", 4, 64984},
	{"KVIL", 4, 64985},
	{"BMD", 3, 64986},
	{"DIALOGS", 7, 64987},
	{"GYPSUM", 6, 64988},
	{"ULAL", 4, 64989},
	{"ORIP", 4, 64990},
	{"SLIME", 5, 64991},
	{"BARONESS", 8, 64992},
	{"VIKTOR", 6, 64993},
	{"TRAJECTORIES", 12, 64994},
	{"GYHA", 4, 64995},
	{"DSRI", 4, 64996},
	{"WINNINGS", 8, 64997},
	{"FEDERICO", 8, 64998},
	{"SOLY", 4, 64999},
	{"IMAGINABLE", 10, 65000},
	{"OPENVMS", 7, 65001},
	{"XAGG", 4, 65002},
	{"BROMIDE", 7, 65003},
	{"EDIW", 4, 65004},
	{"PRECIO", 6, 65005},
	{"LEAPFROG", 8, 65006},
	{"THERMOPLASTIC", 13, 65007},
	{"XTCO", 4, 65008},
	{"SBOB", 4, 65009},
	{"GREQ", 4, 65010},
	{"DLYL", 4, 65011},
	{"CRUSADERS", 9, 65012},
	{"WNRU", 4, 65013},
	{"UCEH", 4, 65014},
	{"CKAY", 4, 65015},
	{"SUMMING", 7, 65016},
	{"LAMENT", 6, 65017},
	{"YNAG", 4, 65018},
	{"GREGOR", 6, 65019},
	{"TERRACES", 8, 65020},
	{"CANYONS", 7, 65021},
	{"GCOO", 4, 65022},
	{"KINGMAN", 7, 65023},
	{"PREDATORY", 9, 65024},
	{"TOWNE", 5, 65025},
	{"IFIL", 4, 65026},
	{"DESCENDANT", 10, 65027},
	{"DISGUST", 7, 65028},
	{"DETERRENT", 9, 65029},
	{"GHRAIB", 6, 65030},
	{"LELL", 4, 65031},
	{"KCRE", 4, 65032},
	{"EPGA", 4, 65033},
	{"BANKED", 6, 65034},
	{"RVEW", 4, 65035},
	{"DSUD", 4, 65036},
	{"DUPLICATING", 11, 65037},
	{"TYJA", 4, 65038},
	{"RATIONALITY", 11, 65039},
	{"SCREWING", 8, 65040},
	{"DISMAL", 6, 65041},
	{"TELB", 4, 65042},
	{"RANCHES", 7, 65043},
	{"COCHIN", 6, 65044},
	{"WIPO", 4, 65045},
	{"TUBA", 4, 65046},
	{"PROLOGUE", 8, 65047},
	{"EAKC", 4, 65048},
	{"ENCODES", 7, 65049},
	{"WHALING", 7, 65050},
	{"GARAMOND", 8, 65051},
	{"THUP", 4, 65052},
	{"CIRRUS", 6, 65053},
	{"ALANIS", 6, 65054},
	{"KILOMETER", 9, 65055},
	{"PATROLS", 7, 65056},
	{"UTSL", 4, 65057},
	{"BALLARAT", 8, 65058},
	{"GLYH", 4, 65059},
	{"VLW", 3, 65060},
	{"WACOM", 5, 65061},
	{"STUMBLING", 9, 65062},
	{"SWUNG", 5, 65063},
	{"OUTLAWS", 7, 65064},
	{"ACTIONSCRIPT", 12, 65065},
	{"WAVED", 5, 65066},
	{"FNOW", 4, 65067},
	{"MODIFIERS", 9, 65068},
	{"HIJACK", 6, 65069},
	{"GYWH", 4, 65070},
	{"LIBEL", 5, 65071},
	{"ELLIPSE", 7, 65072},
	{"THOMASVILLE", 11, 65073},
	{"BEOR", 4, 65074},
	{"ACCORDED", 8, 65075},
	{"ALARMED", 7, 65076},
	{"JUSTINE", 7, 65077},
	{"HORC", 4, 65078},
	{"ANYQ", 4, 65079},
	{"FRYER", 5, 65080},
	{"NAMCO", 5, 65081},
	{"GARDA", 5, 65082},
	{"XMMS", 4, 65083},
	{"ESKIMO", 6, 65084},
	{"CAESARS", 7, 65085},
	{"SUEB", 4, 65086},
	{"DIOX", 4, 65087},
	{"DAMMIT", 6, 65088},
	{"KBON", 4, 65089},
	{"LUCE", 4, 65090},
	{"PRODUKTER", 9, 65091},
	{"CHTU", 4, 65092},
	{"MOTORHOME", 9, 65093},
	{"STYR", 4, 65094},
	{"RGSA", 4, 65095},
	{"MFRS", 4, 65096},
	{"EDITABLE", 8, 65097},
	{"GREATS", 6, 65098},
	{"MILOSEVIC", 9, 65099},
	{"MARCY", 5, 65100},
	{"BORON", 5, 65101},
	{"AIDV", 4, 65102},
	{"CREIGHTON", 9, 65103},
	{"STRAPPED", 8, 65104},
	{"WOLFENSTEIN", 11, 65105},
	{"EWEP", 4, 65106},
	{"DYSI", 4, 65107},
	{"BOLIVIAN", 8, 65108},
	{"ROWBOX", 6, 65109},
	{"YAVI", 4, 65110},
	{"AKOV", 4, 65111},
	{"RELUCTANTLY", 11, 65112},
	{"UTVE", 4, 65113},
	{"PAULS", 5, 65114},
	{"PHOBIA", 6, 65115},
	{"LFSE", 4, 65116},
	{"SUPERFUND", 9, 65117},
	{"WOODWORK", 8, 65118},
	{"VCC", 3, 65119},
	{"SADLER", 6, 65120},
	{"CENTRIFUGAL", 11, 65121},
	{"ARUT", 4, 65122},
	{"AUTHORSHIP", 10, 65123},
	{"PIERCINGS", 9, 65124},
	{"UPSF", 4, 65125},
	{"OFCY", 4, 65126},
	{"ITYJ", 4, 65127},
	{"AGNU", 4, 65128},
	{"RIFFS", 5, 65129},
	{"CAVITIES", 8, 65130},
	{"BUXTON", 6, 65131},
	{"LTUP", 4, 65132},
	{"GWED", 4, 65133},
	{"ALAZ", 4, 65134},
	{"MAUG", 4, 65135},
	{"EEGY", 4, 65136},
	{"CRAVINGS", 8, 65137},
	{"DECIDEDLY", 9, 65138},
	{"APATHY", 6, 65139},
	{"TLAP", 4, 65140},
	{"BRIANA", 6, 65141},
	{"BINL", 4, 65142},
	{"MERCANTILE", 10, 65143},
	{"STALLED", 7, 65144},
	{"SBYG", 4, 65145},
	{"PLOA", 4, 65146},
	{"KCLO", 4, 65147},
	{"CCOO", 4, 65148},
	{"INFUSED", 7, 65149},
	{"GERONIMO", 8, 65150},
	{"PEAKED", 6, 65151},
	{"STRONGHOLD", 10, 65152},
	{"TETRA", 5, 65153},
	{"HUXLEY", 6, 65154},
	{"MTRY", 4, 65155},
	{"HMIG", 4, 65156},
	{"FREAKIN", 7, 65157},
	{"UUF", 3, 65158},
	{"KXM", 3, 65159},
	{"WDES", 4, 65160},
	{"KRIT", 4, 65161},
	{"RETROFIT", 8, 65162},
	{"PLAQ", 4, 65163},
	{"LENM", 4, 65164},
	{"MORITZ", 6, 65165},
	{"BEARDED", 7, 65166},
	{"CYTOKINE", 8, 65167},
	{"STYLESHEETS", 11, 65168},
	{"GREASY", 6, 65169},
	{"COALITIONS", 10, 65170},
	{"WJOB", 4, 65171},
	{"KEBI", 4, 65172},
	{"TACTILE", 7, 65173},
	{"VOWED", 5, 65174},
	{"CINEMATOGRAPHY", 14, 65175},
	{"RSYA", 4, 65176},
	{"REOW", 4, 65177},
	{"APUT", 4, 65178},
	{"ABBL", 4, 65179},
	{"VIVITAR", 7, 65180},
	{"VIDP", 4, 65181},
	{"PUST", 4, 65182},
	{"CTIL", 4, 65183},
	{"WANNABE", 7, 65184},
	{"CARNAGE", 7, 65185},
	{"BLOGWISE", 8, 65186},
	{"KEYD", 4, 65187},
	{"DWRE", 4, 65188},
	{"COWR", 4, 65189},
	{"CONL", 4, 65190},
	{"CKAW", 4, 65191},
	{"BPRI", 4, 65192},
	{"ASHER", 5, 65193},
	{"AMADOR", 6, 65194},
	{"SKIER", 5, 65195},
	{"RLDN", 4, 65196},
	{"OWCR", 4, 65197},
	{"STORYTELLER", 11, 65198},
	{"WUND", 4, 65199},
	{"PELICULA", 8, 65200},
	{"KLYF", 4, 65201},
	{"INGENUITY", 9, 65202},
	{"URNR", 4, 65203},
	{"DDAD", 4, 65204},
	{"ISCHEMIA", 8, 65205},
	{"TLOG", 4, 65206},
	{"OLLH", 4, 65207},
	{"MORT", 4, 65208},
	{"KISP", 4, 65209},
	{"DABB", 4, 65210},
	{"COMPUT", 6, 65211},
	{"INFESTED", 8, 65212},
	{"WRISTBANDS", 10, 65213},
	{"CREEKS", 6, 65214},
	{"LIVECAMS", 8, 65215},
	{"BESSIE", 6, 65216},
	{"HIBISCUS", 8, 65217},
	{"ADELE", 5, 65218},
	{"OCKU", 4, 65219},
	{"KGOO", 4, 65220},
	{"GAYM", 4, 65221},
	{"FAWE", 4, 65222},
	{"EWBI", 4, 65223},
	{"RHEUMATOLOGY", 12, 65224},
	{"SOMERS", 6, 65225},
	{"UCKM", 4, 65226},
	{"LYED", 4, 65227},
	{"RATTAN", 6, 65228},
	{"RHEF", 4, 65229},
	{"NJIM", 4, 65230},
	{"CORONER", 7, 65231},
	{"CRAY", 4, 65232},
	{"IRREGULARITIES", 14, 65233},
	{"TILED", 5, 65234},
	{"RLSH", 4, 65235},
	{"GLYF", 4, 65236},
	{"WATERBURY", 9, 65237},
	{"SELECTIVITY", 11, 65238},
	{"CARLOW", 6, 65239},
	{"ELABORATION", 11, 65240},
	{"MAXX", 4, 65241},
	{"HECTIC", 6, 65242},
	{"HAGGAI", 6, 65243},
	{"DEMONSTRATORS", 13, 65244},
	{"RAISER", 6, 65245},
	{"YFER", 4, 65246},
	{"SLOY", 4, 65247},
	{"BYSM", 4, 65248},
	{"SANGER", 6, 65249},
	{"MULLEN", 6, 65250},
	{"KTAK", 4, 65251},
	{"PERIPHERY", 9, 65252},
	{"PREDICTORS", 10, 65253},
	{"SNUFF", 5, 65254},
	{"CONVENE", 7, 65255},
	{"WOODWIND", 8, 65256},
	{"OMKA", 4, 65257},
	{"GLIO", 4, 65258},
	{"EBYN", 4, 65259},
	{"MODBLOG", 7, 65260},
	{"CALMLY", 6, 65261},
	{"HORRIBLY", 8, 65262},
	{"REPO", 4, 65263},
	{"BURNLEY", 7, 65264},
	{"ELLV", 4, 65265},
	{"DILUTE", 6, 65266},
	{"ANTISPYWARE", 11, 65267},
	{"SUMTER", 6, 65268},
	{"RCD", 3, 65269},
	{"CONTEMPLATION", 13, 65270},
	{"LETD", 4, 65271},
	{"BROI", 4, 65272},
	{"WOODSIDE", 8, 65273},
	{"CARTA", 5, 65274},
	{"TYLENOL", 7, 65275},
	{"GASEOUS", 7, 65276},
	{"MEGABYTES", 9, 65277},
	{"BACKLIGHT", 9, 65278},
	{"DHID", 4, 65279},
	{"AFFLICTED", 9, 65280},
	{"FXV", 3, 65281},
	{"GLOOMY", 6, 65282},
	{"KIRKWOOD", 8, 65283},
	{"NATURIST", 8, 65284},
	{"ZEPHANIAH", 9, 65285},
	{"AMPD", 4, 65286},
	{"AIRBAGS", 7, 65287},
	{"PLETHORA", 8, 65288},
	{"SEDY", 4, 65289},
	{"CABRIOLET", 9, 65290},
	{"RKDO", 4, 65291},
	{"LFBA", 4, 65292},
	{"RETIREE", 7, 65293},
	{"ANTHROPOLOGICAL", 15, 65294},
	{"MIKASA", 6, 65295},
	{"IVERSON", 7, 65296},
	{"VEDJ", 4, 65297},
	{"KIDI", 4, 65298},
	{"ORCHARDS", 8, 65299},
	{"PROPHECIES", 10, 65300},
	{"BUCKEYE", 7, 65301},
	{"DOLLHOUSE", 9, 65302},
	{"USHIP", 5, 65303},
	{"UBISOFT", 7, 65304},
	{"ESCALADE", 8, 65305},
	{"ROWR", 4, 65306},
	{"BREAKAWAY", 9, 65307},
	{"NOGU", 4, 65308},
	{"KFAC", 4, 65309},
	{"PRODUKT", 7, 65310},
	{"MARQUES", 7, 65311},
	{"LEXO", 4, 65312},
	{"AORG", 4, 65313},
	{"SEALANTS", 8, 65314},
	{"MONTCLAIR", 9, 65315},
	{"SEPTUAGINT", 10, 65316},
	{"DINGHY", 6, 65317},
	{"UNBO", 4, 65318},
	{"MEBL", 4, 65319},
	{"IRPI", 4, 65320},
	{"ALKH", 4, 65321},
	{"PERTAINS", 8, 65322},
	{"GNUS", 4, 65323},
	{"RUGC", 4, 65324},
	{"ILUN", 4, 65325},
	{"HRIF", 4, 65326},
	{"MELIA", 5, 65327},
	{"FEEDBACKS", 9, 65328},
	{"CONCURRENCY", 11, 65329},
	{"HEALTHGRADES", 12, 65330},
	{"CLOTHED", 7, 65331},
	{"ODBO", 4, 65332},
	{"IMVE", 4, 65333},
	{"PLUMMER", 7, 65334},
	{"REVISTA", 7, 65335},
	{"ITALIANS", 8, 65336},
	{"LRC", 3, 65337},
	{"FLIED", 5, 65338},
	{"TALON", 5, 65339},
	{"CILC", 4, 65340},
	{"BYTI", 4, 65341},
	{"AKLE", 4, 65342},
	{"REPELLENT", 9, 65343},
	{"JOLIET", 6, 65344},
	{"CHAPPELL", 8, 65345},
	{"OOMD", 4, 65346},
	{"NYUS", 4, 65347},
	{"FOXN", 4, 65348},
	{"WOLLONGONG", 10, 65349},
	{"BLOWERS", 7, 65350},
	{"YENV", 4, 65351},
	{"LAVAL", 5, 65352},
	{"SORCERY", 7, 65353},
	{"DOUBLEDAY", 9, 65354},
	{"RSFU", 4, 65355},
	{"LYEF", 4, 65356},
	{"LELS", 4, 65357},
	{"DBOL", 4, 65358},
	{"GUIDANT", 7, 65359},
	{"ABSTAIN", 7, 65360},
	{"FNEG", 4, 65361},
	{"ELSIE", 5, 65362},
	{"WEME", 4, 65363},
	{"REMODELED", 9, 65364},
	{"RRAH", 4, 65365},
	{"RMYD", 4, 65366},
	{"BARRING", 7, 65367},
	{"UNDERMINED", 10, 65368},
	{"OWBY", 4, 65369},
	{"BCP", 3, 65370},
	{"SITUATIONAL", 11, 65371},
	{"FZY", 3, 65372},
	{"IEDV", 4, 65373},
	{"BESTOWED", 8, 65374},
	{"CHAKRA", 6, 65375},
	{"HABEAS", 6, 65376},
	{"INACTIVITY", 10, 65377},
	{"CREWE", 5, 65378},
	{"JAMMU", 5, 65379},
	{"GRASSY", 6, 65380},
	{"APRONS", 6, 65381},
	{"RIAP", 4, 65382},
	{"CLUMSY", 6, 65383},
	{"RDGE", 4, 65384},
	{"WETSUITS", 8, 65385},
	{"YVIA", 4, 65386},
	{"UTYS", 4, 65387},
	{"KTOU", 4, 65388},
	{"GREI", 4, 65389},
	{"GKID", 4, 65390},
	{"BIRKENSTOCK", 11, 65391},
	{"UBIO", 4, 65392},
	{"POKM", 4, 65393},
	{"HYYO", 4, 65394},
	{"AMVE", 4, 65395},
	{"VIVENDI", 7, 65396},
	{"COLUMBIAN", 9, 65397},
	{"EMULSION", 8, 65398},
	{"FIELDER", 7, 65399},
	{"IGLI", 4, 65400},
	{"SORTA", 5, 65401},
	{"COURSEWARE", 10, 65402},
	{"BIOSPHERE", 9, 65403},
	{"PLUMPERS", 8, 65404},
	{"MUSCHI", 6, 65405},
	{"POUNDED", 7, 65406},
	{"QCD", 3, 65407},
	{"OLLIE", 5, 65408},
	{"CARRINGTON", 10, 65409},
	{"GURGAON", 7, 65410},
	{"RWXR", 4, 65411},
	{"UDEE", 4, 65412},
	{"FEDERALISM", 10, 65413},
	{"GIZMODO", 7, 65414},
	{"UTNU", 4, 65415},
	{"ROUSSEAU", 8, 65416},
	{"SARCASM", 7, 65417},
	{"LAMINATING", 10, 65418},
	{"COLTRANE", 8, 65419},
	{"ACCOMPLISHING", 13, 65420},
	{"COLITIS", 7, 65421},
	{"UNINCORPORATED", 14, 65422},
	{"MYDO", 4, 65423},
	{"RMOL", 4, 65424},
	{"LIANG", 5, 65425},
	{"BLOGGED", 7, 65426},
	{"CRYOGENIC", 9, 65427},
	{"ANTISPAM", 8, 65428},
	{"OVERTURNED", 10, 65429},
	{"ICGU", 4, 65430},
	{"IGUO", 4, 65431},
	{"ACOF", 4, 65432},
	{"UPHILL", 6, 65433},
	{"HASSLES", 7, 65434},
	{"MAXIMUS", 7, 65435},
	{"SYMPTOMATIC", 11, 65436},
	{"WARMED", 6, 65437},
	{"PARABLE", 7, 65438},
	{"LODY", 4, 65439},
	{"CKYE", 4, 65440},
	{"JOLT", 4, 65441},
	{"ETDR", 4, 65442},
	{"AFFORDS", 7, 65443},
	{"TRADEMANAGER", 12, 65444},
	{"BIPARTISAN", 10, 65445},
	{"GPIN", 4, 65446},
	{"EBYG", 4, 65447},
	{"WOSC", 4, 65448},
	{"RHODIUM", 7, 65449},
	{"EXCHANGER", 9, 65450},
	{"PRESEASON", 9, 65451},
	{"OPEM", 4, 65452},
	{"HGOL", 4, 65453},
	{"JANUAR", 6, 65454},
	{"IWAL", 4, 65455},
	{"BUMBLE", 6, 65456},
	{"INTIMIDATING", 12, 65457},
	{"SCUI", 4, 65458},
	{"DEADLOCK", 8, 65459},
	{"RANDI", 5, 65460},
	{"IMSF", 4, 65461},
	{"PLACENTA", 8, 65462},
	{"VMJ", 3, 65463},
	{"MZB", 3, 65464},
	{"SKYT", 4, 65465},
	{"ABBOTSFORD", 10, 65466},
	{"ICPI", 4, 65467},
	{"DIOU", 4, 65468},
	{"DULLES", 6, 65469},
	{"BRAINSTORMING", 13, 65470},
	{"LCAB", 4, 65471},
	{"DERIVING", 8, 65472},
	{"DOUGHERTY", 9, 65473},
	{"CSDE", 4, 65474},
	{"SARCOMA", 7, 65475},
	{"SNIFFER", 7, 65476},
	{"QUADRANGLE", 10, 65477},
	{"ROTORUA", 7, 65478},
	{"ELECTS", 6, 65479},
	{"LIEBE", 5, 65480},
	{"BAHASA", 6, 65481},
	{"ERADICATE", 9, 65482},
	{"BIOSCIENCE", 10, 65483},
	{"AULB", 4, 65484},
	{"TRICIA", 6, 65485},
	{"RESIDUALS", 9, 65486},
	{"GFORGE", 6, 65487},
	{"LIKENESS", 8, 65488},
	{"WSWA", 4, 65489},
	{"POFR", 4, 65490},
	{"OWEM", 4, 65491},
	{"OKPR", 4, 65492},
	{"COPD", 4, 65493},
	{"HOMIE", 5, 65494},
	{"UNTER", 5, 65495},
	{"TBYW", 4, 65496},
	{"RYEF", 4, 65497},
	{"ALPACA", 6, 65498},
	{"DEGRADE", 7, 65499},
	{"RNRA", 4, 65500},
	{"LEESBURG", 8, 65501},
	{"XREF", 4, 65502},
	{"FLASHPOINT", 10, 65503},
	{"DULG", 4, 65504},
	{"FLEMISH", 7, 65505},
	{"VIDR", 4, 65506},
	{"ULYP", 4, 65507},
	{"EBPA", 4, 65508},
	{"MOBYGAMES", 9, 65509},
	{"CORTLAND", 8, 65510},
	{"DAYY", 4, 65511},
	{"SHRED", 5, 65512},
	{"MAILERS", 7, 65513},
	{"BARW", 4, 65514},
	{"CONSEIL", 7, 65515},
	{"TENTED", 6, 65516},
	{"LDAW", 4, 65517},
	{"EYPI", 4, 65518},
	{"STEAMED", 7, 65519},
	{"NICHOLLS", 8, 65520},
	{"SKEW", 4, 65521},
	{"MAHONEY", 7, 65522},
	{"INFOPLEASE", 10, 65523},
	{"WCLA", 4, 65524},
	{"AROUSED", 7, 65525},
	{"WISW", 4, 65526},
	{"OPLU", 4, 65527},
	{"CYSE", 4, 65528},
	{"BUDD", 4, 65529},
	{"RZON", 4, 65530},
	{"HOLLANDS", 8, 65531},
	{"MUNI", 4, 65532},
	{"GEGO", 4, 65533},
	{"MODERNISM", 9, 65534},
	{"REMITTANCE", 10, 65535},
	{"SIEVE", 5, 65536},
	{"BLOCH", 5, 65537},
	{"RSYE", 4, 65538},
	{"ALIENATION", 10, 65539},
	{"ELIZABETHTOWN", 13, 65540},
	{"LRUS", 4, 65541},
	{"DUNHILL", 7, 65542},
	{"DIDN", 4, 65543},
	{"GUIDEBOOKS", 10, 65544},
	{"REDDISH", 7, 65545},
	{"KBEA", 4, 65546},
	{"SCOTTS", 6, 65547},
	{"BIOSCIENCES", 11, 65548},
	{"MACGREGOR", 9, 65549},
	{"HABAKKUK", 8, 65550},
	{"BEBL", 4, 65551},
	{"DEPAUL", 6, 65552},
	{"BINGE", 5, 65553},
	{"RYTW", 4, 65554},
	{"BEID", 4, 65555},
	{"IMPULSES", 8, 65556},
	{"INTERPOL", 8, 65557},
	{"UNEL", 4, 65558},
	{"POFL", 4, 65559},
	{"NSBL", 4, 65560},
	{"PLEADS", 6, 65561},
	{"GPOT", 4, 65562},
	{"APFO", 4, 65563},
	{"WHITBY", 6, 65564},
	{"ACOD", 4, 65565},
	{"CYST", 4, 65566},
	{"PTWA", 4, 65567},
	{"HEXADECIMAL", 11, 65568},
	{"SCISSOR", 7, 65569},
	{"GOLIATH", 7, 65570},
	{"UDLE", 4, 65571},
	{"PROGRA", 6, 65572},
	{"SMYTH", 5, 65573},
	{"CAPRICE", 7, 65574},
	{"RYSF", 4, 65575},
	{"HORNED", 6, 65576},
	{"UWOR", 4, 65577},
	{"JAZZY", 5, 65578},
	{"HEADBOARD", 9, 65579},
	{"FOWL", 4, 65580},
	{"JANUS", 5, 65581},
	{"TCOD", 4, 65582},
	{"HROC", 4, 65583},
	{"DIFLUCAN", 8, 65584},
	{"HESTER", 6, 65585},
	{"BRONSON", 7, 65586},
	{"BENEVOLENT", 10, 65587},
	{"SUPERSTITION", 12, 65588},
	{"IKOL", 4, 65589},
	{"YJOU", 4, 65590},
	{"RKDA", 4, 65591},
	{"AMAU", 4, 65592},
	{"STANDARDISED", 12, 65593},
	{"CATIONS", 7, 65594},
	{"UMHE", 4, 65595},
	{"RMYR", 4, 65596},
	{"CICS", 4, 65597},
	{"RDOT", 4, 65598},
	{"NNYR", 4, 65599},
	{"BIDO", 4, 65600},
	{"COHORTS", 7, 65601},
	{"ECOLE", 5, 65602},
	{"CENTOS", 6, 65603},
	{"USOL", 4, 65604},
	{"DIDD", 4, 65605},
	{"DRIB", 4, 65606},
	{"WCOA", 4, 65607},
	{"NWEG", 4, 65608},
	{"USUR", 4, 65609},
	{"IEFD", 4, 65610},
	{"IABR", 4, 65611},
	{"HYSTERECTOMY", 12, 65612},
	{"HOUSINGS", 8, 65613},
	{"TLAM", 4, 65614},
	{"WRC", 3, 65615},
	{"CAMILLA", 7, 65616},
	{"WGRE", 4, 65617},
	{"MOVADO", 6, 65618},
	{"MCDONOUGH", 9, 65619},
	{"OWNK", 4, 65620},
	{"KRISTA", 6, 65621},
	{"WFRE", 4, 65622},
	{"OMHU", 4, 65623},
	{"HJUN", 4, 65624},
	{"EMYE", 4, 65625},
	{"CTAV", 4, 65626},
	{"PHARMACOKINETICS", 16, 65627},
	{"CHANTAL", 7, 65628},
	{"SJEF", 4, 65629},
	{"MORRISTOWN", 10, 65630},
	{"RIVERVIEW", 9, 65631},
	{"LOOPBACK", 8, 65632},
	{"TORSION", 7, 65633},
	{"ULTRASTRUCTURE", 14, 65634},
	{"RARITY", 6, 65635},
	{"URIF", 4, 65636},
	{"RNSL", 4, 65637},
	{"GDID", 4, 65638},
	{"LIMBO", 5, 65639},
	{"LUCIDA", 6, 65640},
	{"LEFTOVER", 8, 65641},
	{"TYBI", 4, 65642},
	{"KDON", 4, 65643},
	{"SYKES", 5, 65644},
	{"ANECDOTAL", 9, 65645},
	{"RHEIMS", 6, 65646},
	{"INTEGRATORS", 11, 65647},
	{"GADR", 4, 65648},
	{"UNLV", 4, 65649},
	{"BERNARDO", 8, 65650},
	{"ULPI", 4, 65651},
	{"ARBORETUM", 9, 65652},
	{"SHAREALIKE", 10, 65653},
	{"FLAKE", 5, 65654},
	{"RMLI", 4, 65655},
	{"LOWEPRO", 7, 65656},
	{"KSEC", 4, 65657},
	{"RORR", 4, 65658},
	{"ISCHEMIC", 8, 65659},
	{"ILLUSTRATORS", 12, 65660},
	{"EWCR", 4, 65661},
	{"HATING", 6, 65662},
	{"UNAG", 4, 65663},
	{"PLYH", 4, 65664},
	{"SEWERS", 6, 65665},
	{"SPORES", 6, 65666},
	{"PLUGGING", 8, 65667},
	{"QUOW", 4, 65668},
	{"MAHMOUD", 7, 65669},
	{"MACBOOK", 7, 65670},
	{"BJP", 3, 65671},
	{"ROWC", 4, 65672},
	{"LUBL", 4, 65673},
	{"CEEL", 4, 65674},
	{"ARENT", 5, 65675},
	{"VIGNETTE", 8, 65676},
	{"KSDA", 4, 65677},
	{"EGAB", 4, 65678},
	{"SHEARS", 6, 65679},
	{"MUCHO", 5, 65680},
	{"HOMEBREW", 8, 65681},
	{"ALTOONA", 7, 65682},
	{"PHEROMONE", 9, 65683},
	{"FIREBALL", 8, 65684},
	{"FLUTES", 6, 65685},
	{"TABERNACLE", 10, 65686},
	{"DECORATOR", 9, 65687},
	{"FRANKEN", 7, 65688},
	{"KRET", 4, 65689},
	{"GUSI", 4, 65690},
	{"DOGT", 4, 65691},
	{"ADIP", 4, 65692},
	{"NETPBM", 6, 65693},
	{"MINCED", 6, 65694},
	{"ANTALYA", 7, 65695},
	{"HARMONIOUS", 10, 65696},
	{"RECORDKEEPING", 13, 65697},
	{"WESTERLY", 8, 65698},
	{"MODERNISATION", 13, 65699},
	{"DESPATCHED", 10, 65700},
	{"MYX", 3, 65701},
	{"SKYI", 4, 65702},
	{"MUNITIONS", 9, 65703},
	{"ORNP", 4, 65704},
	{"GODB", 4, 65705},
	{"FOCT", 4, 65706},
	{"FGUI", 4, 65707},
	{"MUSKEGON", 8, 65708},
	{"SYMMETRICAL", 11, 65709},
	{"DALEY", 5, 65710},
	{"MODALITY", 8, 65711},
	{"LIBERALISATION", 14, 65712},
	{"RTFE", 4, 65713},
	{"KEGE", 4, 65714},
	{"ORNATE", 6, 65715},
	{"UTILISE", 7, 65716},
	{"MIDWIFE", 7, 65717},
	{"ARTURO", 6, 65718},
	{"APPELLEE", 8, 65719},
	{"GRANULES", 8, 65720},
	{"UNIFORMED", 9, 65721},
	{"MULTIDIMENSIONAL", 16, 65722},
	{"DYDI", 4, 65723},
	{"ROLLOUT", 7, 65724},
	{"SNUG", 4, 65725},
	{"UMSC", 4, 65726},
	{"DULI", 4, 65727},
	{"AJAM", 4, 65728},
	{"HOMEGROWN", 9, 65729},
	{"DATAMONITOR", 11, 65730},
	{"REINFORCES", 10, 65731},
	{"RMWE", 4, 65732},
	{"COVETED", 7, 65733},
	{"DIRHAM", 6, 65734},
	{"KRID", 4, 65735},
	{"LEAHY", 5, 65736},
	{"ODGR", 4, 65737},
	{"MYC", 3, 65738},
	{"PROHIBITIONS", 12, 65739},
	{"ESOPHAGEAL", 10, 65740},
	{"MOULDED", 7, 65741},
	{"DECEIVED", 8, 65742},
	{"KIRA", 4, 65743},
	{"GITD", 4, 65744},
	{"APPROXIMATIONS", 14, 65745},
	{"WEPU", 4, 65746},
	{"FORZIERI", 8, 65747},
	{"INTERMEDIATES", 13, 65748},
	{"ALBUMIN", 7, 65749},
	{"GRANTEES", 8, 65750},
	{"MTRI", 4, 65751},
	{"GAUN", 4, 65752},
	{"FDIA", 4, 65753},
	{"TOSSING", 7, 65754},
	{"YORH", 4, 65755},
	{"KEJO", 4, 65756},
	{"LOVELAND", 8, 65757},
	{"REGULARITY", 10, 65758},
	{"MALONEY", 7, 65759},
	{"CRITICISED", 10, 65760},
	{"SATIVA", 6, 65761},
	{"IDFE", 4, 65762},
	{"LAWFULLY", 8, 65763},
	{"RSIC", 4, 65764},
	{"PARAMEDIC", 9, 65765},
	{"TRADEMARKED", 11, 65766},
	{"EDGEWOOD", 8, 65767},
	{"JOEB", 4, 65768},
	{"GOETHE", 6, 65769},
	{"STRESSING", 9, 65770},
	{"SLADE", 5, 65771},
	{"POTABLE", 7, 65772},
	{"LIMPOPO", 7, 65773},
	{"INTENSITIES", 11, 65774},
	{"ONCOGENE", 8, 65775},
	{"YSTW", 4, 65776},
	{"RYKE", 4, 65777},
	{"DUMAS", 5, 65778},
	{"ANTIDEPRESSANT", 14, 65779},
	{"JESTER", 6, 65780},
	{"NOTIFIES", 8, 65781},
	{"RECOUNT", 7, 65782},
	{"BALLPARK", 8, 65783},
	{"POWYS", 5, 65784},
	{"IELB", 4, 65785},
	{"ORCA", 4, 65786},
	{"MASCARA", 7, 65787},
	{"NDZA", 4, 65788},
	{"GPAN", 4, 65789},
	{"FEWG", 4, 65790},
	{"PROLINE", 7, 65791},
	{"DEAREST", 7, 65792},
	{"MOLINA", 6, 65793},
	{"WIPERS", 6, 65794},
	{"ILOC", 4, 65795},
	{"SNOOPY", 6, 65796},
	{"INFORMATIONEN", 13, 65797},
	{"COMMENSURATE", 12, 65798},
	{"RIVERDALE", 9, 65799},
	{"SCHILLER", 8, 65800},
	{"BOWLER", 6, 65801},
	{"UNLEASH", 7, 65802},
	{"YSEM", 4, 65803},
	{"JUELZ", 5, 65804},
	{"NOARCH", 6, 65805},
	{"WFIN", 4, 65806},
	{"AWWI", 4, 65807},
	{"CAPTIONED", 9, 65808},
	{"PHAV", 4, 65809},
	{"WISER", 5, 65810},
	{"GALLANT", 7, 65811},
	{"ASYW", 4, 65812},
	{"SUMMARIZING", 11, 65813},
	{"UCSD", 4, 65814},
	{"DISBELIEF", 9, 65815},
	{"ONPM", 4, 65816},
	{"FNEC", 4, 65817},
	{"ADUE", 4, 65818},
	{"GLEASON", 7, 65819},
	{"OXCO", 4, 65820},
	{"BARITONE", 8, 65821},
	{"UNQUALIFIED", 11, 65822},
	{"CAUTIONED", 9, 65823},
	{"RECOLLECTION", 12, 65824},
	{"TJIM", 4, 65825},
	{"INDEPENDANT", 11, 65826},
	{"CHLAMYDIA", 9, 65827},
	{"RELATIVISTIC", 12, 65828},
	{"ROTORS", 6, 65829},
	{"DRISCOLL", 8, 65830},
	{"YINK", 4, 65831},
	{"ANDALUCIA", 9, 65832},
	{"MULHER", 6, 65833},
	{"RDYO", 4, 65834},
	{"BAGELS", 6, 65835},
	{"EJOR", 4, 65836},
	{"LOCOMOTIVES", 11, 65837},
	{"OPAD", 4, 65838},
	{"CONDEMNS", 8, 65839},
	{"FASTENING", 9, 65840},
	{"JEWELER", 7, 65841},
	{"SUBLIMINAL", 10, 65842},
	{"INSECTICIDE", 11, 65843},
	{"NUREMBERG", 9, 65844},
	{"SEGAL", 5, 65845},
	{"FGUY", 4, 65846},
	{"NBAK", 4, 65847},
	{"DSRO", 4, 65848},
	{"KCHE", 4, 65849},
	{"ROPU", 4, 65850},
	{"OSTRICH", 7, 65851},
	{"MAUD", 4, 65852},
	{"SPLINE", 6, 65853},
	{"UNDISCLOSED", 11, 65854},
	{"FLIRTING", 8, 65855},
	{"PTUA", 4, 65856},
	{"ZKL", 3, 65857},
	{"RVJ", 3, 65858},
	{"LETTERMAN", 9, 65859},
	{"RVAC", 4, 65860},
	{"ALMERIA", 7, 65861},
	{"BRYSON", 6, 65862},
	{"RGYM", 4, 65863},
	{"MISPLACED", 9, 65864},
	{"PROSECUTIONS", 12, 65865},
	{"DIDO", 4, 65866},
	{"TOWSON", 6, 65867},
	{"POISONED", 8, 65868},
	{"OLSD", 4, 65869},
	{"RESEARCHES", 10, 65870},
	{"HTACCESS", 8, 65871},
	{"MALAYALAM", 9, 65872},
	{"LLUR", 4, 65873},
	{"DYSU", 4, 65874},
	{"DIEB", 4, 65875},
	{"ADFE", 4, 65876},
	{"CHOU", 4, 65877},
	{"DISCRIMINATING", 14, 65878},
	{"CRUE", 4, 65879},
	{"FGOI", 4, 65880},
	{"EDYC", 4, 65881},
	{"PINOY", 5, 65882},
	{"RNLA", 4, 65883},
	{"PALLETS", 7, 65884},
	{"UPLINK", 6, 65885},
	{"SHEBOYGAN", 9, 65886},
	{"EXCLAMATION", 11, 65887},
	{"IUSC", 4, 65888},
	{"HQUI", 4, 65889},
	{"COLLINGWOOD", 11, 65890},
	{"OGLA", 4, 65891},
	{"TERRENCE", 8, 65892},
	{"INTERCEPTED", 11, 65893},
	{"PKEE", 4, 65894},
	{"EMAW", 4, 65895},
	{"ASCENDANT", 9, 65896},
	{"LFSU", 4, 65897},
	{"GCEL", 4, 65898},
	{"FLUNG", 5, 65899},
	{"GATESHEAD", 9, 65900},
	{"PROBATIONARY", 12, 65901},
	{"LYIG", 4, 65902},
	{"ABDUCTED", 8, 65903},
	{"WARLOCK", 7, 65904},
	{"BREAKUP", 7, 65905},
	{"CLOVIS", 6, 65906},
	{"FICHE", 5, 65907},
	{"GSFI", 4, 65908},
	{"FGAL", 4, 65909},
	{"CILF", 4, 65910},
	{"BOWDEN", 6, 65911},
	{"GOGGLE", 6, 65912},
	{"KINV", 4, 65913},
	{"RAILING", 7, 65914},
	{"METABOLITES", 11, 65915},
	{"CREMATION", 9, 65916},
	{"BRAINSTORM", 10, 65917},
	{"BANTER", 6, 65918},
	{"SAGL", 4, 65919},
	{"EKAG", 4, 65920},
	{"BALCONIES", 9, 65921},
	{"AWAKEN", 6, 65922},
	{"EWHU", 4, 65923},
	{"DGIL", 4, 65924},
	{"AUCO", 4, 65925},
	{"BATEMAN", 7, 65926},
	{"GNAF", 4, 65927},
	{"FBLU", 4, 65928},
	{"EGCS", 4, 65929},
	{"CHIRAC", 6, 65930},
	{"MUSEO", 5, 65931},
	{"PIGEONS", 7, 65932},
	{"COFFEEHOUSE", 11, 65933},
	{"SINGULARITY", 11, 65934},
	{"URND", 4, 65935},
	{"RDVI", 4, 65936},
	{"IJAC", 4, 65937},
	{"EOFQ", 4, 65938},
	{"SCITECH", 7, 65939},
	{"SIGNIFY", 7, 65940},
	{"GRANDDAUGHTER", 13, 65941},
	{"TROLLING", 8, 65942},
	{"YREU", 4, 65943},
	{"OZAR", 4, 65944},
	{"MPHR", 4, 65945},
	{"ELMORE", 6, 65946},
	{"SUBDIRECTORY", 12, 65947},
	{"BANCROFT", 8, 65948},
	{"PROGENY", 7, 65949},
	{"GRADS", 5, 65950},
	{"ALTERS", 6, 65951},
	{"YSFE", 4, 65952},
	{"LOCALPREF", 9, 65953},
	{"KAYLA", 5, 65954},
	{"CCL", 3, 65955},
	{"HDOC", 4, 65956},
	{"GRATEFULLY", 10, 65957},
	{"DIVERGENT", 9, 65958},
	{"FLEETS", 6, 65959},
	{"ITYK", 4, 65960},
	{"IDGI", 4, 65961},
	{"SMEG", 4, 65962},
	{"LENJ", 4, 65963},
	{"DORIAN", 6, 65964},
	{"DONUT", 5, 65965},
	{"LIBIDO", 6, 65966},
	{"JULI", 4, 65967},
	{"FUSELAGE", 8, 65968},
	{"DIABETICS", 9, 65969},
	{"TACKLED", 7, 65970},
	{"ECKY", 4, 65971},
	{"BALLERINA", 9, 65972},
	{"XUX", 3, 65973},
	{"MWX", 3, 65974},
	{"YSSP", 4, 65975},
	{"CRP", 3, 65976},
	{"GTAB", 4, 65977},
	{"SHOALS", 6, 65978},
	{"MORGANTOWN", 10, 65979},
	{"PASEO", 5, 65980},
	{"TRIBUTARY", 9, 65981},
	{"PURG", 4, 65982},
	{"CLIQUE", 6, 65983},
	{"ROSY", 4, 65984},
	{"PTSD", 4, 65985},
	{"CILH", 4, 65986},
	{"REDHEADS", 8, 65987},
	{"KAGO", 4, 65988},
	{"GIMA", 4, 65989},
	{"CURRAN", 6, 65990},
	{"DIAM", 4, 65991},
	{"PTFR", 4, 65992},
	{"BALR", 4, 65993},
	{"SATANIC", 7, 65994},
	{"RAGNAROK", 8, 65995},
	{"STUBBS", 6, 65996},
	{"SUMMARISED", 10, 65997},
	{"DURCH", 5, 65998},
	{"MTUR", 4, 65999},
	{"CUET", 4, 66000},
	{"TORMENT", 7, 66001},
	{"ULBA", 4, 66002},
	{"POFE", 4, 66003},
	{"MUSSELS", 7, 66004},
	{"CAITLIN", 7, 66005},
	{"EMIGRATION", 10, 66006},
	{"CONSCIENTIOUS", 13, 66007},
	{"HOWL", 4, 66008},
	{"NERK", 4, 66009},
	{"DIGR", 4, 66010},
	{"BANDAI", 6, 66011},
	{"IGLESIAS", 8, 66012},
	{"NUSP", 4, 66013},
	{"IALY", 4, 66014},
	{"ENDOMETRIOSIS", 13, 66015},
	{"CUSHIONING", 10, 66016},
	{"OADG", 4, 66017},
	{"MCNEIL", 6, 66018},
	{"ECCLESIASTICAL", 14, 66019},
	{"YALN", 4, 66020},
	{"GPIE", 4, 66021},
	{"CRIPPLED", 8, 66022},
	{"BELVEDERE", 9, 66023},
	{"HILLTOP", 7, 66024},
	{"LFOC", 4, 66025},
	{"TABOR", 5, 66026},
	{"PEUT", 4, 66027},
	{"SICG", 4, 66028},
	{"GKOK", 4, 66029},
	{"ACETYL", 6, 66030},
	{"BOOMER", 6, 66031},
	{"FIFTEENTH", 9, 66032},
	{"TOLY", 4, 66033},
	{"AVYB", 4, 66034},
	{"CHUTE", 5, 66035},
	{"PERINATAL", 9, 66036},
	{"AUTOMAKE", 8, 66037},
	{"RBOF", 4, 66038},
	{"LDAI", 4, 66039},
	{"MULTICHANNEL", 12, 66040},
	{"PETR", 4, 66041},
	{"BOHEMIA", 7, 66042},
	{"DAREDEVIL", 9, 66043},
	{"CORCORAN", 8, 66044},
	{"MOUNTAINOUS", 11, 66045},
	{"LEYN", 4, 66046},
	{"MRP", 3, 66047},
	{"HOLLIDAY", 8, 66048},
	{"DAIMLERCHRYSLER", 15, 66049},
	{"FONDS", 5, 66050},
	{"BOWES", 5, 66051},
	{"MCGOWAN", 7, 66052},
	{"WOWN", 4, 66053},
	{"AGFA", 4, 66054},
	{"UPEV", 4, 66055},
	{"OGRE", 4, 66056},
	{"UNFORESEEN", 10, 66057},
	{"PICKLES", 7, 66058},
	{"SUBMISSIVE", 10, 66059},
	{"NYAP", 4, 66060},
	{"FFRU", 4, 66061},
	{"CURSES", 6, 66062},
	{"MULCH", 5, 66063},
	{"STAMPEDE", 8, 66064},
	{"JVM", 3, 66065},
	{"UTILISED", 8, 66066},
	{"HARWOOD", 7, 66067},
	{"TRIESTE", 7, 66068},
	{"QUEH", 4, 66069},
	{"DOSP", 4, 66070},
	{"RANMA", 5, 66071},
	{"WNBR", 4, 66072},
	{"GOTF", 4, 66073},
	{"MARINAS", 7, 66074},
	{"YSOW", 4, 66075},
	{"SJAP", 4, 66076},
	{"WHINE", 5, 66077},
	{"MOBIPOCKET", 10, 66078},
	{"LBEV", 4, 66079},
	{"STREPTOCOCCUS", 13, 66080},
	{"MURCIA", 6, 66081},
	{"CORG", 4, 66082},
	{"YUX", 3, 66083},
	{"LDOI", 4, 66084},
	{"KSGO", 4, 66085},
	{"RKHI", 4, 66086},
	{"UEUN", 4, 66087},
	{"BYCU", 4, 66088},
	{"LANDFILLS", 9, 66089},
	{"OYBE", 4, 66090},
	{"MCKNIGHT", 8, 66091},
	{"FATALITY", 8, 66092},
	{"TIERRA", 6, 66093},
	{"CTAD", 4, 66094},
	{"BAUD", 4, 66095},
	{"MCFARLAND", 9, 66096},
	{"OWFL", 4, 66097},
	{"DESIGNLINE", 10, 66098},
	{"LOOMING", 7, 66099},
	{"UNDIES", 6, 66100},
	{"UELW", 4, 66101},
	{"PREPAY", 6, 66102},
	{"CEGI", 4, 66103},
	{"SPED", 4, 66104},
	{"KODIAK", 6, 66105},
	{"PRINTOUT", 8, 66106},
	{"NONRESIDENT", 11, 66107},
	{"MARYSVILLE", 10, 66108},
	{"CURSO", 5, 66109},
	{"PALMOS", 6, 66110},
	{"FFEY", 4, 66111},
	{"DORSEY", 6, 66112},
	{"IGWA", 4, 66113},
	{"ANKLES", 6, 66114},
	{"LLYQ", 4, 66115},
	{"SOULFUL", 7, 66116},
	{"TEDQ", 4, 66117},
	{"ILSB", 4, 66118},
	{"GGUY", 4, 66119},
	{"KSFA", 4, 66120},
	{"FTYP", 4, 66121},
	{"EAFC", 4, 66122},
	{"MOSQUES", 7, 66123},
	{"WEBSEARCH", 9, 66124},
	{"INFOTRAC", 8, 66125},
	{"MPGS", 4, 66126},
	{"FOULS", 5, 66127},
	{"OPENSSH", 7, 66128},
	{"BRAVENET", 8, 66129},
	{"FUCHS", 5, 66130},
	{"GUERILLA", 8, 66131},
	{"DYGU", 4, 66132},
	{"LTHW", 4, 66133},
	{"SQUEEZING", 9, 66134},
	{"FISK", 4, 66135},
	{"RAAL", 4, 66136},
	{"NYBL", 4, 66137},
	{"CANES", 5, 66138},
	{"SERENDIPITY", 11, 66139},
	{"FOLLOWER", 8, 66140},
	{"EULER", 5, 66141},
	{"SEQUENTIALLY", 12, 66142},
	{"YPUN", 4, 66143},
	{"WDEN", 4, 66144},
	{"NBCS", 4, 66145},
	{"YOGI", 4, 66146},
	{"BYCI", 4, 66147},
	{"PSUL", 4, 66148},
	{"LANDSLIDE", 9, 66149},
	{"HOWTOS", 6, 66150},
	{"TYJU", 4, 66151},
	{"LSVI", 4, 66152},
	{"HEPG", 4, 66153},
	{"SKOOL", 5, 66154},
	{"ALUMINA", 7, 66155},
	{"UCEB", 4, 66156},
	{"TBYI", 4, 66157},
	{"ILMH", 4, 66158},
	{"AELR", 4, 66159},
	{"DEGENERATE", 10, 66160},
	{"SPIKED", 6, 66161},
	{"EVOLVES", 7, 66162},
	{"FFSW", 4, 66163},
	{"CRU", 3, 66164},
	{"FDZ", 3, 66165},
	{"CATU", 4, 66166},
	{"XASW", 4, 66167},
	{"OLAK", 4, 66168},
	{"LSAW", 4, 66169},
	{"LMOM", 4, 66170},
	{"MISREPRESENTATION", 17, 66171},
	{"IBERIA", 6, 66172},
	{"TFIX", 4, 66173},
	{"SODR", 4, 66174},
	{"EGOB", 4, 66175},
	{"ANAKIN", 6, 66176},
	{"DUFFEL", 6, 66177},
	{"YKIC", 4, 66178},
	{"DBIS", 4, 66179},
	{"AYJO", 4, 66180},
	{"GOODRICH", 8, 66181},
	{"STRUNG", 6, 66182},
	{"SUBFAMILY", 9, 66183},
	{"CHANTING", 8, 66184},
	{"WRESTLER", 8, 66185},
	{"PERENNIALS", 10, 66186},
	{"OFFICIATING", 11, 66187},
	{"HERMIT", 6, 66188},
	{"BEHAVING", 8, 66189},
	{"COLBERT", 7, 66190},
	{"MATCHMAKER", 10, 66191},
	{"SAGITTARIUS", 11, 66192},
	{"RTDA", 4, 66193},
	{"LOCATES", 7, 66194},
	{"DYSFUNCTIONAL", 13, 66195},
	{"MAASTRICHT", 10, 66196},
	{"BULLETPROOF", 11, 66197},
	{"JOSIAH", 6, 66198},
	{"DEEPEN", 6, 66199},
	{"ELDN", 4, 66200},
	{"MCR", 3, 66201},
	{"SIXB", 4, 66202},
	{"STENOSIS", 8, 66203},
	{"LSIX", 4, 66204},
	{"ACADIA", 6, 66205},
	{"RECENTCHANGES", 13, 66206},
	{"REMY", 4, 66207},
	{"ABRASION", 8, 66208},
	{"VALENTIN", 8, 66209},
	{"EINDHOVEN", 9, 66210},
	{"MORA", 4, 66211},
	{"ENRICO", 6, 66212},
	{"RECIPROCITY", 11, 66213},
	{"YBOW", 4, 66214},
	{"WBRO", 4, 66215},
	{"LFEM", 4, 66216},
	{"CEBI", 4, 66217},
	{"OPPORTUNISTIC", 13, 66218},
	{"KFOU", 4, 66219},
	{"FAWI", 4, 66220},
	{"PCL", 3, 66221},
	{"ANALOGS", 7, 66222},
	{"OALP", 4, 66223},
	{"ERGT", 4, 66224},
	{"DYSC", 4, 66225},
	{"CREASE", 6, 66226},
	{"HILLCREST", 9, 66227},
	{"GAFU", 4, 66228},
	{"CANTOR", 6, 66229},
	{"ECONOMETRIC", 11, 66230},
	{"IGFO", 4, 66231},
	{"TRAFFORD", 8, 66232},
	{"LORL", 4, 66233},
	{"EYRU", 4, 66234},
	{"RYTU", 4, 66235},
	{"LESJ", 4, 66236},
	{"ERZO", 4, 66237},
	{"EDYW", 4, 66238},
	{"EBUZ", 4, 66239},
	{"BARTHOLOMEW", 11, 66240},
	{"ELKHART", 7, 66241},
	{"OLPA", 4, 66242},
	{"RINGERS", 7, 66243},
	{"DICED", 5, 66244},
	{"FAIRGROUNDS", 11, 66245},
	{"CUYAHOGA", 8, 66246},
	{"PERSEVERANCE", 12, 66247},
	{"CARTONS", 7, 66248},
	{"MUSTANGS", 8, 66249},
	{"LLOI", 4, 66250},
	{"HOFU", 4, 66251},
	{"AKOR", 4, 66252},
	{"ADDONS", 6, 66253},
	{"WSTRICT", 7, 66254},
	{"CATALONIA", 9, 66255},
	{"PHARMACOLOGICAL", 15, 66256},
	{"HEADWEAR", 8, 66257},
	{"PAEDIATRIC", 10, 66258},
	{"GENITALS", 8, 66259},
	{"VINW", 4, 66260},
	{"HENDRICKS", 9, 66261},
	{"DALG", 4, 66262},
	{"TELEMEDICINE", 12, 66263},
	{"JUDI", 4, 66264},
	{"YORKTOWN", 8, 66265},
	{"RKRO", 4, 66266},
	{"NTMY", 4, 66267},
	{"KUWA", 4, 66268},
	{"IMPEDE", 6, 66269},
	{"WWQ", 3, 66270},
	{"WVP", 3, 66271},
	{"WQB", 3, 66272},
	{"ACADEMICALLY", 12, 66273},
	{"CHILTON", 7, 66274},
	{"NDVD", 4, 66275},
	{"DAMH", 4, 66276},
	{"AMAYA", 5, 66277},
	{"FLICKRBLOG", 10, 66278},
	{"CLASPS", 6, 66279},
	{"FDUR", 4, 66280},
	{"AWAB", 4, 66281},
	{"TILTED", 6, 66282},
	{"VICAR", 5, 66283},
	{"GHME", 4, 66284},
	{"FEDT", 4, 66285},
	{"CONFINES", 8, 66286},
	{"YGAL", 4, 66287},
	{"FULBRIGHT", 9, 66288},
	{"FOAF", 4, 66289},
	{"CLLR", 4, 66290},
	{"PRANK", 5, 66291},
	{"KNOR", 4, 66292},
	{"FPAY", 4, 66293},
	{"YSSC", 4, 66294},
	{"SPLO", 4, 66295},
	{"YTOY", 4, 66296},
	{"AULH", 4, 66297},
	{"REPENT", 6, 66298},
	{"EYRI", 4, 66299},
	{"FULLTEXT", 8, 66300},
	{"IFEJ", 4, 66301},
	{"AGREEABLE", 9, 66302},
	{"RYVO", 4, 66303},
	{"MADN", 4, 66304},
	{"RVAS", 4, 66305},
	{"NFOX", 4, 66306},
	{"CENTRUM", 7, 66307},
	{"TECRA", 5, 66308},
	{"MERJ", 4, 66309},
	{"AUDU", 4, 66310},
	{"KINKS", 5, 66311},
	{"RIDDLES", 7, 66312},
	{"UNISYS", 6, 66313},
	{"PRESCHOOLS", 10, 66314},
	{"BENNINGTON", 10, 66315},
	{"MCALLEN", 7, 66316},
	{"PULPIT", 6, 66317},
	{"INKD", 4, 66318},
	{"APPRECIATES", 11, 66319},
	{"CONTOURED", 9, 66320},
	{"ABERDEENSHIRE", 13, 66321},
	{"SCHENECTADY", 11, 66322},
	{"MEKE", 4, 66323},
	{"MASJ", 4, 66324},
	{"BEDU", 4, 66325},
	{"AIRV", 4, 66326},
	{"MARSHES", 7, 66327},
	{"SCHEMATICS", 10, 66328},
	{"BELLIES", 7, 66329},
	{"ARKK", 4, 66330},
	{"NGDY", 4, 66331},
	{"DOJO", 4, 66332},
	{"IBUR", 4, 66333},
	{"ESERVER", 7, 66334},
	{"CORROSIVE", 9, 66335},
	{"AMBUSH", 6, 66336},
	{"INTERFACING", 11, 66337},
	{"BORROWINGS", 10, 66338},
	{"RGTH", 4, 66339},
	{"PALAZZO", 7, 66340},
	{"FRANCISCAN", 10, 66341},
	{"KBRI", 4, 66342},
	{"OLWE", 4, 66343},
	{"HEPARIN", 7, 66344},
	{"UNIVERSITEIT", 12, 66345},
	{"KREL", 4, 66346},
	{"TUPH", 4, 66347},
	{"RILB", 4, 66348},
	{"FIGURATIVE", 10, 66349},
	{"HARDCOPY", 8, 66350},
	{"YLLB", 4, 66351},
	{"EMPHASISED", 10, 66352},
	{"SUSD", 4, 66353},
	{"CONNECTIVE", 10, 66354},
	{"BONFIRE", 7, 66355},
	{"GADM", 4, 66356},
	{"KTWO", 4, 66357},
	{"AVERSION", 8, 66358},
	{"NSFL", 4, 66359},
	{"FDAM", 4, 66360},
	{"ADKINS", 6, 66361},
	{"SRUM", 4, 66362},
	{"DUNLAP", 6, 66363},
	{"YQW", 3, 66364},
	{"YJV", 3, 66365},
	{"LKZ", 3, 66366},
	{"FQW", 3, 66367},
	{"CLONAZEPAM", 10, 66368},
	{"WIKINAME", 8, 66369},
	{"RFUE", 4, 66370},
	{"MYCL", 4, 66371},
	{"GAITHERSBURG", 12, 66372},
	{"VICENTE", 7, 66373},
	{"BIOPHYSICS", 10, 66374},
	{"CHROMATIN", 9, 66375},
	{"MATHIS", 6, 66376},
	{"BULOVA", 6, 66377},
	{"ROXANNE", 7, 66378},
	{"FEWL", 4, 66379},
	{"BBYA", 4, 66380},
	{"MBRY", 4, 66381},
	{"GEUP", 4, 66382},
	{"DRG", 3, 66383},
	{"STILES", 6, 66384},
	{"STEWARDS", 8, 66385},
	{"REFURB", 6, 66386},
	{"CHAUFFEUR", 9, 66387},
	{"WASTELAND", 9, 66388},
	{"ELICIT", 6, 66389},
	{"PLOTTER", 7, 66390},
	{"IODB", 4, 66391},
	{"FINDLAY", 7, 66392},
	{"HENRIETTA", 9, 66393},
	{"SLAPPED", 7, 66394},
	{"BITTEN", 6, 66395},
	{"CYMRAEG", 7, 66396},
	{"MEEK", 4, 66397},
	{"BOXW", 4, 66398},
	{"LIND", 4, 66399},
	{"LCYC", 4, 66400},
	{"BAYW", 4, 66401},
	{"PHONEBOOK", 9, 66402},
	{"LSUF", 4, 66403},
	{"KGRA", 4, 66404},
	{"DOODLE", 6, 66405},
	{"WABASH", 6, 66406},
	{"EBUM", 4, 66407},
	{"SALAMANCA", 9, 66408},
	{"MARTYN", 6, 66409},
	{"DYNAMO", 6, 66410},
	{"HOBSON", 6, 66411},
	{"CHRONOLOGICALLY", 15, 66412},
	{"OTMY", 4, 66413},
	{"LAFI", 4, 66414},
	{"LOTC", 4, 66415},
	{"IRCE", 4, 66416},
	{"IBYA", 4, 66417},
	{"DLYG", 4, 66418},
	{"WHITFIELD", 9, 66419},
	{"MCHENRY", 7, 66420},
	{"EKLO", 4, 66421},
	{"DBOM", 4, 66422},
	{"DUSSELDORF", 10, 66423},
	{"SUMMON", 6, 66424},
	{"SKELETONS", 9, 66425},
	{"MMOL", 4, 66426},
	{"PMFR", 4, 66427},
	{"OVAB", 4, 66428},
	{"SHABBAT", 7, 66429},
	{"MAWE", 4, 66430},
	{"DOWL", 4, 66431},
	{"NCLB", 4, 66432},
	{"PARCHMENT", 9, 66433},
	{"ACCOMMODATES", 12, 66434},
	{"VIAC", 4, 66435},
	{"UNKY", 4, 66436},
	{"MECE", 4, 66437},
	{"KMAI", 4, 66438},
	{"LINGUA", 6, 66439},
	{"STACKER", 7, 66440},
	{"DISTRACTIONS", 12, 66441},
	{"LEMH", 4, 66442},
	{"IRSK", 4, 66443},
	{"EYSL", 4, 66444},
	{"CKYM", 4, 66445},
	{"FORFEIT", 7, 66446},
	{"PEPE", 4, 66447},
	{"PADDLES", 7, 66448},
	{"WOSP", 4, 66449},
	{"UNPOPULAR", 9, 66450},
	{"REPUBLICS", 9, 66451},
	{"TOUCHDOWNS", 10, 66452},
	{"OBLU", 4, 66453},
	{"LEWR", 4, 66454},
	{"BAYI", 4, 66455},
	{"PLASMAS", 7, 66456},
	{"INSPECTING", 10, 66457},
	{"RETAINER", 8, 66458},
	{"OMDU", 4, 66459},
	{"NPSY", 4, 66460},
	{"HARDENING", 9, 66461},
	{"BARBELL", 7, 66462},
	{"LOOSEN", 6, 66463},
	{"BIBS", 4, 66464},
	{"BEOWULF", 7, 66465},
	{"SNEAKY", 6, 66466},
	{"UNDISCOVERED", 12, 66467},
	{"EINEM", 5, 66468},
	{"UGME", 4, 66469},
	{"USFU", 4, 66470},
	{"MBLO", 4, 66471},
	{"FGIV", 4, 66472},
	{"SMARTS", 6, 66473},
	{"LANKAN", 6, 66474},
	{"SYNTHETASE", 10, 66475},
	{"IMPUTED", 7, 66476},
	{"LIGHTWAVE", 9, 66477},
	{"ALIGNMENTS", 10, 66478},
	{"CABS", 4, 66479},
	{"RNPE", 4, 66480},
	{"COACHED", 7, 66481},
	{"CHEATED", 7, 66482},
	{"OUSK", 4, 66483},
	{"FRAMINGHAM", 10, 66484},
	{"OPENSOURCE", 10, 66485},
	{"OJAC", 4, 66486},
	{"CYX", 3, 66487},
	{"RESTROOM", 8, 66488},
	{"MTER", 4, 66489},
	{"VIDEOGRAPHY", 11, 66490},
	{"LCR", 3, 66491},
	{"SPATIALLY", 9, 66492},
	{"DOANH", 5, 66493},
	{"WILLOWS", 7, 66494},
	{"LFCA", 4, 66495},
	{"PREPROCESSOR", 12, 66496},
	{"HUMP", 4, 66497},
	{"DELFT", 5, 66498},
	{"MORH", 4, 66499},
	{"IDCR", 4, 66500},
	{"MARGINALLY", 10, 66501},
	{"COMMUNICATIVE", 13, 66502},
	{"CAVALLI", 7, 66503},
	{"GGUN", 4, 66504},
	{"BONF", 4, 66505},
	{"AWAG", 4, 66506},
	{"GRIEVING", 8, 66507},
	{"DDC", 3, 66508},
	{"GRUNGE", 6, 66509},
	{"CHASTITY", 8, 66510},
	{"WTOF", 4, 66511},
	{"INVOICING", 9, 66512},
	{"CARNEY", 6, 66513},
	{"YDOY", 4, 66514},
	{"RXIS", 4, 66515},
	{"BRAINTREE", 9, 66516},
	{"TEGU", 4, 66517},
	{"REXH", 4, 66518},
	{"NDYR", 4, 66519},
	{"LROY", 4, 66520},
	{"JOBF", 4, 66521},
	{"SOUTHSIDE", 9, 66522},
	{"FLIPPED", 7, 66523},
	{"UOSF", 4, 66524},
	{"LNEX", 4, 66525},
	{"CABRERA", 7, 66526},
	{"WMET", 4, 66527},
	{"FAUST", 5, 66528},
	{"FRIGHT", 6, 66529},
	{"VECI", 4, 66530},
	{"UMPL", 4, 66531},
	{"RDJO", 4, 66532},
	{"HARBORS", 7, 66533},
	{"ADORNED", 7, 66534},
	{"OBNOXIOUS", 9, 66535},
	{"MINDY", 5, 66536},
	{"DILIGENTLY", 10, 66537},
	{"SURFACED", 8, 66538},
	{"DECAYS", 6, 66539},
	{"GLAM", 4, 66540},
	{"YDEG", 4, 66541},
	{"COWGIRL", 7, 66542},
	{"MORTIMER", 8, 66543},
	{"IAMF", 4, 66544},
	{"CYOU", 4, 66545},
	{"MARVELLOUS", 10, 66546},
	{"NOUVELLE", 8, 66547},
	{"FWOU", 4, 66548},
	{"CKAM", 4, 66549},
	{"EASING", 6, 66550},
	{"LOGINLOGIN", 10, 66551},
	{"LOBJ", 4, 66552},
	{"NAKAMURA", 8, 66553},
	{"MATHIEU", 7, 66554},
	{"LATV", 4, 66555},
	{"BIKI", 4, 66556},
	{"LAYOFFS", 7, 66557},
	{"RTIB", 4, 66558},
	{"PICKET", 6, 66559},
	{"MATURES", 7, 66560},
	{"THRONES", 7, 66561},
	{"MOFN", 4, 66562},
	{"LDAU", 4, 66563},
	{"EMILIA", 6, 66564},
	{"EYRE", 4, 66565},
	{"IGGY", 4, 66566},
	{"MATURING", 8, 66567},
	{"MARGARINE", 9, 66568},
	{"ILLOGICAL", 9, 66569},
	{"AWAKENED", 8, 66570},
	{"SUING", 5, 66571},
	{"IMGE", 4, 66572},
	{"BRINE", 5, 66573},
	{"LORNA", 5, 66574},
	{"SNEAKER", 7, 66575},
	{"WANING", 6, 66576},
	{"YDUT", 4, 66577},
	{"THMC", 4, 66578},
	{"RSIR", 4, 66579},
	{"CARTWRIGHT", 10, 66580},
	{"RKSL", 4, 66581},
	{"GNRE", 4, 66582},
	{"TLLB", 4, 66583},
	{"GLYCOPROTEIN", 12, 66584},
	{"EGUT", 4, 66585},
	{"DUPG", 4, 66586},
	{"ARMOIRE", 7, 66587},
	{"RSVE", 4, 66588},
	{"UROV", 4, 66589},
	{"IGCH", 4, 66590},
	{"AURS", 4, 66591},
	{"QUEUED", 6, 66592},
	{"SAYC", 4, 66593},
	{"CADO", 4, 66594},
	{"HYDROXIDE", 9, 66595},
	{"PILED", 5, 66596},
	{"YVD", 3, 66597},
	{"GYX", 3, 66598},
	{"HRAM", 4, 66599},
	{"HANLEY", 6, 66600},
	{"CELLULITE", 9, 66601},
	{"UNDV", 4, 66602},
	{"MLIV", 4, 66603},
	{"FBON", 4, 66604},
	{"LSDU", 4, 66605},
	{"HWANG", 5, 66606},
	{"XAMS", 4, 66607},
	{"TWINKLE", 7, 66608},
	{"MCQUEEN", 7, 66609},
	{"USTV", 4, 66610},
	{"MYAL", 4, 66611},
	{"HAQU", 4, 66612},
	{"LODGINGS", 8, 66613},
	{"PASSAT", 6, 66614},
	{"KOVS", 4, 66615},
	{"KHIL", 4, 66616},
	{"FLUFF", 5, 66617},
	{"SHIFTER", 7, 66618},
	{"MASG", 4, 66619},
	{"AOFP", 4, 66620},
	{"MAITLAND", 8, 66621},
	{"CARTOGRAPHY", 11, 66622},
	{"SUPPLE", 6, 66623},
	{"FIRSTPREVIOUS", 13, 66624},
	{"OFEG", 4, 66625},
	{"APSF", 4, 66626},
	{"ALDT", 4, 66627},
	{"GELD", 4, 66628},
	{"FABIO", 5, 66629},
	{"PREDICATES", 10, 66630},
	{"BCL", 3, 66631},
	{"UNFIT", 5, 66632},
	{"ODTR", 4, 66633},
	{"ANLY", 4, 66634},
	{"TYIM", 4, 66635},
	{"JORO", 4, 66636},
	{"UTTERED", 7, 66637},
	{"DOUAY", 5, 66638},
	{"RUMANIAN", 8, 66639},
	{"ZEITGEIST", 9, 66640},
	{"NICKELODEON", 11, 66641},
	{"DRU", 3, 66642},
	{"APAR", 4, 66643},
	{"TENDING", 7, 66644},
	{"SHAGGY", 6, 66645},
	{"GSPL", 4, 66646},
	{"ELONGATED", 9, 66647},
	{"OGYD", 4, 66648},
	{"NWRE", 4, 66649},
	{"VROL", 4, 66650},
	{"ORDEAL", 6, 66651},
	{"PEGS", 4, 66652},
	{"HERNIA", 6, 66653},
	{"PREISVERGLEICH", 14, 66654},
	{"WNSF", 4, 66655},
	{"GLYW", 4, 66656},
	{"INCOMPETENCE", 12, 66657},
	{"BRITTON", 7, 66658},
	{"STABILIZING", 11, 66659},
	{"SOCOM", 5, 66660},
	{"FLICKER", 7, 66661},
	{"RAMSAY", 6, 66662},
	{"MIDSIZE", 7, 66663},
	{"ALOL", 4, 66664},
	{"RELIEVING", 9, 66665},
	{"PULLOVER", 8, 66666},
	{"RLSI", 4, 66667},
	{"BYFL", 4, 66668},
	{"EYEC", 4, 66669},
	{"TOWERING", 8, 66670},
	{"OPERAS", 6, 66671},
	{"HALV", 4, 66672},
	{"SLAUGHTERED", 11, 66673},
	{"HOODWINKED", 10, 66674},
	{"PBUI", 4, 66675},
	{"NKSL", 4, 66676},
	{"ALUC", 4, 66677},
	{"UBSW", 4, 66678},
	{"PHOTOES", 7, 66679},
	{"ASSAULTED", 9, 66680},
	{"SKYR", 4, 66681},
	{"ROUSE", 5, 66682},
	{"APPEL", 5, 66683},
	{"YUCCA", 5, 66684},
	{"ARMAND", 6, 66685},
	{"HARVESTER", 9, 66686},
	{"RDCE", 4, 66687},
	{"JORH", 4, 66688},
	{"EMMETT", 6, 66689},
	{"SMWH", 4, 66690},
	{"RGYF", 4, 66691},
	{"RIOF", 4, 66692},
	{"SPIEL", 5, 66693},
	{"IMPURITIES", 10, 66694},
	{"STEMMING", 8, 66695},
	{"INSCRIPTIONS", 12, 66696},
	{"OBSTRUCTIVE", 11, 66697},
	{"THLU", 4, 66698},
	{"SKSW", 4, 66699},
	{"CHOB", 4, 66700},
	{"KJF", 3, 66701},
	{"PACMAN", 6, 66702},
	{"TENTATIVELY", 11, 66703},
	{"OCRU", 4, 66704},
	{"DAER", 4, 66705},
	{"TRAGEDIES", 9, 66706},
	{"INTERLUDE", 9, 66707},
	{"WLAW", 4, 66708},
	{"FOFH", 4, 66709},
	{"EAKL", 4, 66710},
	{"RETROACTIVE", 11, 66711},
	{"BRIEFED", 7, 66712},
	{"BEBE", 4, 66713},
	{"DIALECTS", 8, 66714},
	{"KRUSELL", 7, 66715},
	{"OVID", 4, 66716},
	{"CLICKZ", 6, 66717},
	{"DEOW", 4, 66718},
	{"CARCASS", 7, 66719},
	{"KERMIT", 6, 66720},
	{"GIZMO", 5, 66721},
	{"ATHEROSCLEROSIS", 15, 66722},
	{"CASUALLY", 8, 66723},
	{"SCAMP", 5, 66724},
	{"DEMOGRAPHY", 10, 66725},
	{"EELR", 4, 66726},
	{"FREEDMAN", 8, 66727},
	{"MIGRAINES", 9, 66728},
	{"EUNW", 4, 66729},
	{"WALLINGFORD", 11, 66730},
	{"NLUT", 4, 66731},
	{"NEWBORNS", 8, 66732},
	{"UMFR", 4, 66733},
	{"YDIN", 4, 66734},
	{"LLUC", 4, 66735},
	{"LETV", 4, 66736},
	{"GYWI", 4, 66737},
	{"GYWA", 4, 66738},
	{"GDEE", 4, 66739},
	{"LJUBLJANA", 9, 66740},
	{"RESTARTED", 9, 66741},
	{"REPRISE", 7, 66742},
	{"MEOW", 4, 66743},
	{"YUPO", 4, 66744},
	{"UDOL", 4, 66745},
	{"LYSY", 4, 66746},
	{"FESC", 4, 66747},
	{"KCHI", 4, 66748},
	{"THAYER", 6, 66749},
	{"KILOGRAMS", 9, 66750},
	{"NCYL", 4, 66751},
	{"PACKAGER", 8, 66752},
	{"POPULATE", 8, 66753},
	{"PEMBROKESHIRE", 13, 66754},
	{"DBIN", 4, 66755},
	{"ILLS", 4, 66756},
	{"ARCANE", 6, 66757},
	{"WLET", 4, 66758},
	{"IMPRACTICAL", 11, 66759},
	{"SIMMS", 5, 66760},
	{"DANES", 5, 66761},
	{"KIRE", 4, 66762},
	{"ODAU", 4, 66763},
	{"CKGA", 4, 66764},
	{"DECENTRALIZATION", 16, 66765},
	{"HONEYMOONS", 10, 66766},
	{"AUTHORITARIAN", 13, 66767},
	{"UGDE", 4, 66768},
	{"PONF", 4, 66769},
	{"JUDAICA", 7, 66770},
	{"TROPICANA", 9, 66771},
	{"UMSF", 4, 66772},
	{"UASK", 4, 66773},
	{"GTHU", 4, 66774},
	{"EBOG", 4, 66775},
	{"CTBO", 4, 66776},
	{"CARDHOLDER", 10, 66777},
	{"UBTR", 4, 66778},
	{"DYFR", 4, 66779},
	{"PEAVEY", 6, 66780},
	{"GOTHENBURG", 10, 66781},
	{"PEBBLES", 7, 66782},
	{"LOIL", 4, 66783},
	{"GEOCACHING", 10, 66784},
	{"IDENT", 5, 66785},
	{"FLUOXETINE", 10, 66786},
	{"TIPTON", 6, 66787},
	{"QUICKSILVER", 11, 66788},
	{"EXBO", 4, 66789},
	{"DEOV", 4, 66790},
	{"SACKED", 6, 66791},
	{"URGT", 4, 66792},
	{"PJUS", 4, 66793},
	{"EFFORTLESSLY", 12, 66794},
	{"FAILOVER", 8, 66795},
	{"EYRS", 4, 66796},
	{"FORFEITED", 9, 66797},
	{"CYSTS", 5, 66798},
	{"MYME", 4, 66799},
	{"PRIMETIME", 9, 66800},
	{"KENOSHA", 7, 66801},
	{"KOKOMO", 6, 66802},
	{"IDMU", 4, 66803},
	{"AWNB", 4, 66804},
	{"GXC", 3, 66805},
	{"PENNEY", 6, 66806},
	{"STIPEND", 7, 66807},
	{"DDUC", 4, 66808},
	{"CONCEPTIONS", 11, 66809},
	{"SNORKEL", 7, 66810},
	{"RMSL", 4, 66811},
	{"IRIDIUM", 7, 66812},
	{"DWYER", 5, 66813},
	{"CONSERVING", 10, 66814},
	{"RKMO", 4, 66815},
	{"MPOI", 4, 66816},
	{"TOPPERS", 7, 66817},
	{"AMULET", 6, 66818},
	{"ULIU", 4, 66819},
	{"ODGA", 4, 66820},
	{"CFG", 3, 66821},
	{"INFORMALLY", 10, 66822},
	{"ALTERNATOR", 10, 66823},
	{"YOBA", 4, 66824},
	{"ICJO", 4, 66825},
	{"NYSGRC", 6, 66826},
	{"UNDERWRITER", 11, 66827},
	{"SPRINGHILL", 10, 66828},
	{"PANHANDLE", 9, 66829},
	{"SARCASTIC", 9, 66830},
	{"TCYC", 4, 66831},
	{"RBSA", 4, 66832},
	{"LISG", 4, 66833},
	{"CGRE", 4, 66834},
	{"JOANN", 5, 66835},
	{"ISOFORM", 7, 66836},
	{"INDEMNIFICATION", 15, 66837},
	{"HAWKE", 5, 66838},
	{"UBSO", 4, 66839},
	{"BORDEN", 6, 66840},
	{"BOMBED", 6, 66841},
	{"COMPLEXION", 10, 66842},
	{"HFEW", 4, 66843},
	{"DAISIES", 7, 66844},
	{"INFORMANT", 9, 66845},
	{"SORROWS", 7, 66846},
	{"FCUS", 4, 66847},
	{"HALTON", 6, 66848},
	{"RMYM", 4, 66849},
	{"EMEB", 4, 66850},
	{"EBRY", 4, 66851},
	{"MBAY", 4, 66852},
	{"KLOA", 4, 66853},
	{"GUARANTEEING", 12, 66854},
	{"DREJ", 4, 66855},
	{"AEGEAN", 6, 66856},
	{"FASTA", 5, 66857},
	{"GONZAGA", 7, 66858},
	{"BOOBIES", 7, 66859},
	{"YPLU", 4, 66860},
	{"KHIG", 4, 66861},
	{"NADINE", 6, 66862},
	{"ANDERE", 6, 66863},
	{"OPIL", 4, 66864},
	{"BREITLING", 9, 66865},
	{"NUTR", 4, 66866},
	{"NIKK", 4, 66867},
	{"ICKJ", 4, 66868},
	{"INGERSOLL", 9, 66869},
	{"SANDIA", 6, 66870},
	{"UTSB", 4, 66871},
	{"SUDB", 4, 66872},
	{"DCRY", 4, 66873},
	{"PACS", 4, 66874},
	{"AZUR", 4, 66875},
	{"FTRY", 4, 66876},
	{"SLUGGISH", 8, 66877},
	{"RDFE", 4, 66878},
	{"PHEM", 4, 66879},
	{"OAMU", 4, 66880},
	{"AELF", 4, 66881},
	{"HELMS", 5, 66882},
	{"BRIG", 4, 66883},
	{"SRCDIR", 6, 66884},
	{"LIAD", 4, 66885},
	{"TIEMPO", 6, 66886},
	{"SHERPA", 6, 66887},
	{"TUFF", 4, 66888},
	{"MARSDEN", 7, 66889},
	{"LIGANDS", 7, 66890},
	{"SMALLTALK", 9, 66891},
	{"EGYT", 4, 66892},
	{"SORGHUM", 7, 66893},
	{"GROUSE", 6, 66894},
	{"UCTW", 4, 66895},
	{"MGAM", 4, 66896},
	{"SSDU", 4, 66897},
	{"NUCLEOTIDES", 11, 66898},
	{"MMV", 3, 66899},
	{"REGINALD", 8, 66900},
	{"WIERD", 5, 66901},
	{"CWY", 3, 66902},
	{"WOUR", 4, 66903},
	{"NDZE", 4, 66904},
	{"PASTED", 6, 66905},
	{"MOTHS", 5, 66906},
	{"LMAO", 4, 66907},
	{"ENHANCERS", 9, 66908},
	{"COLLABORATED", 12, 66909},
	{"PRODU", 5, 66910},
	{"LILA", 4, 66911},
	{"BATAVIA", 7, 66912},
	{"EVOKE", 5, 66913},
	{"SLOTTED", 7, 66914},
	{"DLEL", 4, 66915},
	{"FILA", 4, 66916},
	{"DECKING", 7, 66917},
	{"TELU", 4, 66918},
	{"DISPOSITIONS", 12, 66919},
	{"HAYWOOD", 7, 66920},
	{"WDEC", 4, 66921},
	{"NCOW", 4, 66922},
	{"EMDI", 4, 66923},
	{"STAUNTON", 8, 66924},
	{"ZZIN", 4, 66925},
	{"REYT", 4, 66926},
	{"NDYT", 4, 66927},
	{"GHGA", 4, 66928},
	{"ACCELERATORS", 12, 66929},
	{"HOWSTUFFWORKS", 13, 66930},
	{"AYPU", 4, 66931},
	{"NGZH", 4, 66932},
	{"AMORPHOUS", 9, 66933},
	{"NEIGHBOURHOODS", 14, 66934},
	{"TDIG", 4, 66935},
	{"RIFH", 4, 66936},
	{"ANGG", 4, 66937},
	{"MICHAL", 6, 66938},
	{"TRIBUTARIES", 11, 66939},
	{"TOWNSHIPS", 9, 66940},
	{"WSAG", 4, 66941},
	{"EKIR", 4, 66942},
	{"HIDEAWAY", 8, 66943},
	{"DWAYNE", 6, 66944},
	{"CODA", 4, 66945},
	{"NANTES", 6, 66946},
	{"RFLU", 4, 66947},
	{"OYDS", 4, 66948},
	{"LWAI", 4, 66949},
	{"CYANIDE", 7, 66950},
	{"ECEW", 4, 66951},
	{"KOSTENLOSE", 10, 66952},
	{"YERG", 4, 66953},
	{"OFEF", 4, 66954},
	{"GROTESK", 7, 66955},
	{"ASSAM", 5, 66956},
	{"LYMY", 4, 66957},
	{"LVIO", 4, 66958},
	{"MAREK", 5, 66959},
	{"INTERLIBRARY", 12, 66960},
	{"YBYR", 4, 66961},
	{"NEFU", 4, 66962},
	{"FUNO", 4, 66963},
	{"MOUSSE", 6, 66964},
	{"PROVENANCE", 10, 66965},
	{"RVEF", 4, 66966},
	{"ZINKLE", 6, 66967},
	{"YDOL", 4, 66968},
	{"RMUP", 4, 66969},
	{"RABT", 4, 66970},
	{"SHAMEFUL", 8, 66971},
	{"GISG", 4, 66972},
	{"CHIFFON", 7, 66973},
	{"FANFARE", 7, 66974},
	{"MAPPER", 6, 66975},
	{"BOYCE", 5, 66976},
	{"MLK", 3, 66977},
	{"DYSTROPHY", 9, 66978},
	{"INFOMATION", 10, 66979},
	{"ARCHAIC", 7, 66980},
	{"ELEVATE", 7, 66981},
	{"DEAFNESS", 8, 66982},
	{"RUSB", 4, 66983},
	{"NYCI", 4, 66984},
	{"HRUB", 4, 66985},
	{"FOOTBALLS", 9, 66986},
	{"UEVA", 4, 66987},
	{"FFNE", 4, 66988},
	{"DMEC", 4, 66989},
	{"DELD", 4, 66990},
	{"EMAILEMAIL", 10, 66991},
	{"BATHURST", 8, 66992},
	{"DURACELL", 8, 66993},
	{"ICPH", 4, 66994},
	{"LAUREATE", 8, 66995},
	{"FEINSTEIN", 9, 66996},
	{"CONTEMPORARIES", 14, 66997},
	{"SYPHILIS", 8, 66998},
	{"VIGILANCE", 9, 66999},
	{"MAGNAVOX", 8, 67000},
	{"APPALLING", 9, 67001},
	{"PALMYRA", 7, 67002},
	{"LIDP", 4, 67003},
	{"FOXES", 5, 67004},
	{"SIDU", 4, 67005},
	{"LGAL", 4, 67006},
	{"HYWI", 4, 67007},
	{"EYOP", 4, 67008},
	{"DAVIE", 5, 67009},
	{"WZU", 3, 67010},
	{"EVRA", 4, 67011},
	{"ELCL", 4, 67012},
	{"HALC", 4, 67013},
	{"AFFIXED", 7, 67014},
	{"SERVLETS", 8, 67015},
	{"OPBU", 4, 67016},
	{"NEILL", 5, 67017},
	{"TICKING", 7, 67018},
	{"YLAY", 4, 67019},
	{"EFTR", 4, 67020},
	{"PANTHEON", 8, 67021},
	{"GULLY", 5, 67022},
	{"EIFW", 4, 67023},
	{"EPITHELIUM", 10, 67024},
	{"BITTERNESS", 10, 67025},
	{"OFBY", 4, 67026},
	{"LPHY", 4, 67027},
	{"COSP", 4, 67028},
	{"UEWE", 4, 67029},
	{"OVOC", 4, 67030},
	{"ARZE", 4, 67031},
	{"BRILL", 5, 67032},
	{"DEFY", 4, 67033},
	{"WEBBING", 7, 67034},
	{"FAKI", 4, 67035},
	{"JAYA", 4, 67036},
	{"CONSUMES", 8, 67037},
	{"LOVINGLY", 8, 67038},
	{"PEBE", 4, 67039},
	{"FICB", 4, 67040},
	{"MAME", 4, 67041},
	{"AGUA", 4, 67042},
	{"UBDU", 4, 67043},
	{"SPSY", 4, 67044},
	{"THRUSH", 6, 67045},
	{"WNAD", 4, 67046},
	{"PBEA", 4, 67047},
	{"IGSC", 4, 67048},
	{"BRIBERY", 7, 67049},
	{"EMUSIC", 6, 67050},
	{"SMOKES", 6, 67051},
	{"GLENCOE", 7, 67052},
	{"UNTESTED", 8, 67053},
	{"VENTILATED", 10, 67054},
	{"NYMU", 4, 67055},
	{"OVERVIEWS", 9, 67056},
	{"AFFLECK", 7, 67057},
	{"OPLO", 4, 67058},
	{"KETTLES", 7, 67059},
	{"ASCEND", 6, 67060},
	{"WDEA", 4, 67061},
	{"KATM", 4, 67062},
	{"FLINDERS", 8, 67063},
	{"UCEN", 4, 67064},
	{"INFORMATIONHIDE", 15, 67065},
	{"HEARST", 6, 67066},
	{"VERIFIES", 8, 67067},
	{"REVERB", 6, 67068},
	{"KAYS", 4, 67069},
	{"RWEW", 4, 67070},
	{"JOBH", 4, 67071},
	{"DBAK", 4, 67072},
	{"COMMUTERS", 9, 67073},
	{"RCP", 3, 67074},
	{"NUTMEG", 6, 67075},
	{"WELIVETOGETHER", 14, 67076},
	{"CRIT", 4, 67077},
	{"DURBIN", 6, 67078},
	{"CHAINED", 7, 67079},
	{"RIKEN", 5, 67080},
	{"CANCELING", 9, 67081},
	{"BROOKHAVEN", 10, 67082},
	{"RKOV", 4, 67083},
	{"PTIB", 4, 67084},
	{"MAGNIFY", 7, 67085},
	{"GAUSS", 5, 67086},
	{"PRECAUTIONARY", 13, 67087},
	{"ARTISTRY", 8, 67088},
	{"EKLE", 4, 67089},
	{"TRAVAIL", 7, 67090},
	{"PHPNUKE", 7, 67091},
	{"LIVRES", 6, 67092},
	{"FIDDLER", 7, 67093},
	{"FALKIRK", 7, 67094},
	{"WHOLESOME", 9, 67095},
	{"PITTS", 5, 67096},
	{"YMEL", 4, 67097},
	{"DELV", 4, 67098},
	{"WRISTS", 6, 67099},
	{"SEVERED", 7, 67100},
	{"MITES", 5, 67101},
	{"RNTR", 4, 67102},
	{"RASR", 4, 67103},
	{"KWON", 4, 67104},
	{"RUBRIC", 6, 67105},
	{"HEADLAMP", 8, 67106},
	{"FFWE", 4, 67107},
	{"DITG", 4, 67108},
	{"OPERAND", 7, 67109},
	{"PUDDLE", 6, 67110},
	{"NUEB", 4, 67111},
	{"KIPE", 4, 67112},
	{"AZORES", 6, 67113},
	{"PXW", 3, 67114},
	{"KRISTI", 6, 67115},
	{"YASMIN", 6, 67116},
	{"ZAWA", 4, 67117},
	{"NRAL", 4, 67118},
	{"BPAG", 4, 67119},
	{"BAYC", 4, 67120},
	{"ASGL", 4, 67121},
	{"VEGETATIVE", 10, 67122},
	{"ACDBVERTEX", 10, 67123},
	{"AGORA", 5, 67124},
	{"ILLINI", 6, 67125},
	{"MACHO", 5, 67126},
	{"NINGBO", 6, 67127},
	{"UGGA", 4, 67128},
	{"LDBI", 4, 67129},
	{"ELABORATED", 10, 67130},
	{"LOTP", 4, 67131},
	{"REEVE", 5, 67132},
	{"EMBELLISHMENTS", 14, 67133},
	{"WILLFUL", 7, 67134},
	{"GRANDEUR", 8, 67135},
	{"PLOUGH", 6, 67136},
	{"LNOM", 4, 67137},
	{"LUSF", 4, 67138},
	{"DRAR", 4, 67139},
	{"STAPHYLOCOCCUS", 14, 67140},
	{"PRITCHARD", 9, 67141},
	{"MANSIONS", 8, 67142},
	{"IEWM", 4, 67143},
	{"AKAG", 4, 67144},
	{"MBTH", 4, 67145},
	{"BUSTING", 7, 67146},
	{"GFP", 3, 67147},
	{"DAFG", 4, 67148},
	{"MACPHERSON", 10, 67149},
	{"OVERHEARD", 9, 67150},
	{"SLOANE", 6, 67151},
	{"WOOSTER", 7, 67152},
	{"LOTU", 4, 67153},
	{"DELONG", 6, 67154},
	{"PERSISTED", 9, 67155},
	{"ONLU", 4, 67156},
	{"NAJU", 4, 67157},
	{"KEDV", 4, 67158},
	{"NILSSON", 7, 67159},
	{"WHEREABOUTS", 11, 67160},
	{"SUBSTRING", 9, 67161},
	{"HAYDN", 5, 67162},
	{"SYMPHONIES", 10, 67163},
	{"RECLINING", 9, 67164},
	{"SMELLY", 6, 67165},
	{"RODRIGO", 7, 67166},
	{"GALLATIN", 8, 67167},
	{"BOUNDING", 8, 67168},
	{"RBIK", 4, 67169},
	{"HANGAR", 6, 67170},
	{"TBYE", 4, 67171},
	{"EPHEMERA", 8, 67172},
	{"ANNEXED", 7, 67173},
	{"ATHEISTS", 8, 67174},
	{"ONYD", 4, 67175},
	{"CSBE", 4, 67176},
	{"YOBJ", 4, 67177},
	{"GENB", 4, 67178},
	{"UMPIRE", 6, 67179},
	{"TESTICULAR", 10, 67180},
	{"DFLU", 4, 67181},
	{"ORTHODOXY", 9, 67182},
	{"MIRAMAR", 7, 67183},
	{"KILT", 4, 67184},
	{"UGHK", 4, 67185},
	{"PUPW", 4, 67186},
	{"KEFU", 4, 67187},
	{"ADFU", 4, 67188},
	{"DOUBTLESS", 9, 67189},
	{"WEARABLE", 8, 67190},
	{"CARLING", 7, 67191},
	{"PITF", 4, 67192},
	{"MFIL", 4, 67193},
	{"BUILDUP", 7, 67194},
	{"WOFH", 4, 67195},
	{"RYGI", 4, 67196},
	{"LYIR", 4, 67197},
	{"WEAPONRY", 8, 67198},
	{"KEYED", 5, 67199},
	{"SWANN", 5, 67200},
	{"ESQUIRE", 7, 67201},
	{"CRYPTIC", 7, 67202},
	{"PRIMUS", 6, 67203},
	{"UWHE", 4, 67204},
	{"DIEW", 4, 67205},
	{"LANDLINE", 8, 67206},
	{"WHEREFORE", 9, 67207},
	{"JEOP", 4, 67208},
	{"ENTREES", 7, 67209},
	{"CORPORA", 7, 67210},
	{"PRIV", 4, 67211},
	{"GEEKLOG", 7, 67212},
	{"MISW", 4, 67213},
	{"LYEQ", 4, 67214},
	{"CHOLERA", 7, 67215},
	{"ODBL", 4, 67216},
	{"AROY", 4, 67217},
	{"ANTIVIRAL", 9, 67218},
	{"MIDSUMMER", 9, 67219},
	{"COLOURING", 9, 67220},
	{"PROFILER", 8, 67221},
	{"LODI", 4, 67222},
	{"CYRA", 4, 67223},
	{"KXX", 3, 67224},
	{"BQB", 3, 67225},
	{"UKEA", 4, 67226},
	{"OBOY", 4, 67227},
	{"NDKR", 4, 67228},
	{"INTOXICATED", 11, 67229},
	{"WHYM", 4, 67230},
	{"VARR", 4, 67231},
	{"FMEL", 4, 67232},
	{"MINIMALIST", 10, 67233},
	{"MYSORE", 6, 67234},
	{"LYSK", 4, 67235},
	{"EEMM", 4, 67236},
	{"JERKS", 5, 67237},
	{"WOLVERINES", 10, 67238},
	{"OWQU", 4, 67239},
	{"YMOL", 4, 67240},
	{"RANR", 4, 67241},
	{"BBCODE", 6, 67242},
	{"FBIO", 4, 67243},
	{"AVYF", 4, 67244},
	{"PROTAGONIST", 11, 67245},
	{"DARIUS", 6, 67246},
	{"RSJA", 4, 67247},
	{"OUDB", 4, 67248},
	{"DRAV", 4, 67249},
	{"BULLION", 7, 67250},
	{"DEFLECTION", 10, 67251},
	{"HATEFUL", 7, 67252},
	{"UDOI", 4, 67253},
	{"TILB", 4, 67254},
	{"PROPENSITY", 10, 67255},
	{"FREEPHONE", 9, 67256},
	{"RIQU", 4, 67257},
	{"OYSF", 4, 67258},
	{"PLM", 3, 67259},
	{"JOURNALISTIC", 12, 67260},
	{"RAYTHEON", 8, 67261},
	{"ESSENCES", 8, 67262},
	{"UTCU", 4, 67263},
	{"OWJU", 4, 67264},
	{"REFSEQ", 6, 67265},
	{"KINGFISHER", 10, 67266},
	{"UPPI", 4, 67267},
	{"GVOL", 4, 67268},
	{"NUMARK", 6, 67269},
	{"MOLINE", 6, 67270},
	{"TAKERS", 6, 67271},
	{"DISPENSED", 9, 67272},
	{"AMANA", 5, 67273},
	{"WORLDCOM", 8, 67274},
	{"HIROYUKI", 8, 67275},
	{"HMAG", 4, 67276},
	{"EWRU", 4, 67277},
	{"PROCTER", 7, 67278},
	{"PRAGMA", 6, 67279},
	{"ODAF", 4, 67280},
	{"KEAV", 4, 67281},
	{"WINKLER", 7, 67282},
	{"WALLEYE", 7, 67283},
	{"LEMONS", 6, 67284},
	{"BAGEL", 5, 67285},
	{"YUNF", 4, 67286},
	{"ASBURY", 6, 67287},
	{"STRATUM", 7, 67288},
	{"UPUT", 4, 67289},
	{"VENDETTA", 8, 67290},
	{"ALPHARETTA", 10, 67291},
	{"LTWE", 4, 67292},
	{"SYNCMASTER", 10, 67293},
	{"NYEM", 4, 67294},
	{"WISTS", 5, 67295},
	{"XFX", 3, 67296},
	{"WICKLOW", 7, 67297},
	{"XARE", 4, 67298},
	{"PHOF", 4, 67299},
	{"AMIB", 4, 67300},
	{"BAER", 4, 67301},
	{"FELICIA", 7, 67302},
	{"OPDE", 4, 67303},
	{"CMR", 3, 67304},
	{"POFW", 4, 67305},
	{"AYBI", 4, 67306},
	{"RESTRAIN", 8, 67307},
	{"CLUTCHES", 8, 67308},
	{"PCAM", 4, 67309},
	{"LIDD", 4, 67310},
	{"CHIL", 4, 67311},
	{"LEFTFIELD", 9, 67312},
	{"ACAV", 4, 67313},
	{"LETTINGS", 8, 67314},
	{"WALKWAY", 7, 67315},
	{"CULTS", 5, 67316},
	{"AMAZE", 5, 67317},
	{"NRAG", 4, 67318},
	{"FYAR", 4, 67319},
	{"PETROCHEMICAL", 13, 67320},
	{"MANASSAS", 8, 67321},
	{"REMBRANDT", 9, 67322},
	{"ESTADO", 6, 67323},
	{"EASEL", 5, 67324},
	{"REISEN", 6, 67325},
	{"CHULA", 5, 67326},
	{"ZALMAN", 6, 67327},
	{"CARER", 5, 67328},
	{"UCEO", 4, 67329},
	{"TJAP", 4, 67330},
	{"NJEF", 4, 67331},
	{"HUMANKIND", 9, 67332},
	{"POTION", 6, 67333},
	{"OVATION", 7, 67334},
	{"RYUP", 4, 67335},
	{"NOCR", 4, 67336},
	{"PADDOCK", 7, 67337},
	{"XXG", 3, 67338},
	{"LJV", 3, 67339},
	{"KXW", 3, 67340},
	{"DWX", 3, 67341},
	{"WLYF", 4, 67342},
	{"CMMS", 4, 67343},
	{"HAWLEY", 6, 67344},
	{"INVERTERS", 9, 67345},
	{"OARM", 4, 67346},
	{"NUMERALS", 8, 67347},
	{"PUSW", 4, 67348},
	{"HJIM", 4, 67349},
	{"DEXF", 4, 67350},
	{"SURPASSED", 9, 67351},
	{"TYKI", 4, 67352},
	{"LDEG", 4, 67353},
	{"AMYO", 4, 67354},
	{"GABLE", 5, 67355},
	{"JOHNNIE", 7, 67356},
	{"MCCORMACK", 9, 67357},
	{"OCID", 4, 67358},
	{"THIRTEENTH", 10, 67359},
	{"PDU", 3, 67360},
	{"LACED", 5, 67361},
	{"FACEPLATES", 10, 67362},
	{"YEATS", 5, 67363},
	{"UBAC", 4, 67364},
	{"EKRA", 4, 67365},
	{"MOTORHOMES", 10, 67366},
	{"QUILL", 5, 67367},
	{"LSYM", 4, 67368},
	{"UEAC", 4, 67369},
	{"EWSY", 4, 67370},
	{"MCMURRAY", 8, 67371},
	{"ZUCCHINI", 8, 67372},
	{"TYOP", 4, 67373},
	{"MARES", 5, 67374},
	{"ENTHUSIASTICALLY", 16, 67375},
	{"FETCHING", 8, 67376},
	{"CHAPS", 5, 67377},
	{"LANAI", 5, 67378},
	{"OGYM", 4, 67379},
	{"NDUK", 4, 67380},
	{"IRSM", 4, 67381},
	{"BYCE", 4, 67382},
	{"OIDB", 4, 67383},
	{"CTOM", 4, 67384},
	{"TENDON", 6, 67385},
	{"PWC", 3, 67386},
	{"CHIRAL", 6, 67387},
	{"FERMI", 5, 67388},
	{"NBYN", 4, 67389},
	{"LREN", 4, 67390},
	{"NEWSREADER", 10, 67391},
	{"BELLOWS", 7, 67392},
	{"MULTICULTURALISM", 16, 67393},
	{"KEATS", 5, 67394},
	{"CUDDLY", 6, 67395},
	{"WWEH", 4, 67396},
	{"LISTINFO", 8, 67397},
	{"DECEIT", 6, 67398},
	{"CARO", 4, 67399},
	{"PUTR", 4, 67400},
	{"GGIS", 4, 67401},
	{"UNMARKED", 8, 67402},
	{"JOYOUS", 6, 67403},
	{"LVID", 4, 67404},
	{"PRIMEDIA", 8, 67405},
	{"BOSWELL", 7, 67406},
	{"LUEM", 4, 67407},
	{"VENTING", 7, 67408},
	{"ESTRADA", 7, 67409},
	{"PRICEY", 6, 67410},
	{"UGEB", 4, 67411},
	{"CSSU", 4, 67412},
	{"SHEKEL", 6, 67413},
	{"INFRINGING", 10, 67414},
	{"DIOCESAN", 8, 67415},
	{"YSBI", 4, 67416},
	{"DCOF", 4, 67417},
	{"READOUT", 7, 67418},
	{"OSUL", 4, 67419},
	{"EYGI", 4, 67420},
	{"AJUM", 4, 67421},
	{"BLYTHE", 6, 67422},
	{"CVER", 4, 67423},
	{"AQWA", 4, 67424},
	{"CHISHOLM", 8, 67425},
	{"CLARIFIES", 9, 67426},
	{"TOBV", 4, 67427},
	{"SORJ", 4, 67428},
	{"KLM", 3, 67429},
	{"GUNNER", 6, 67430},
	{"DIMES", 5, 67431},
	{"VERSO", 5, 67432},
	{"TYVE", 4, 67433},
	{"KMFR", 4, 67434},
	{"EYTU", 4, 67435},
	{"SAMOAN", 6, 67436},
	{"PACQ", 4, 67437},
	{"ABSORBENT", 9, 67438},
	{"REVLON", 6, 67439},
	{"IMSB", 4, 67440},
	{"GEJU", 4, 67441},
	{"GROSSLY", 7, 67442},
	{"CRANKY", 6, 67443},
	{"CLEFT", 5, 67444},
	{"PAPARAZZI", 9, 67445},
	{"ZHENG", 5, 67446},
	{"MERIDA", 6, 67447},
	{"BAMBI", 5, 67448},
	{"TMYC", 4, 67449},
	{"ERKR", 4, 67450},
	{"INTERCEPTOR", 11, 67451},
	{"RITD", 4, 67452},
	{"PUTN", 4, 67453},
	{"CLOG", 4, 67454},
	{"OOKY", 4, 67455},
	{"AVYI", 4, 67456},
	{"KFY", 3, 67457},
	{"TCRY", 4, 67458},
	{"HONGKONG", 8, 67459},
	{"IMPOVERISHED", 12, 67460},
	{"STABBED", 7, 67461},
	{"JAMSTER", 7, 67462},
	{"FEDB", 4, 67463},
	{"NORITAKE", 8, 67464},
	{"TEASPOONS", 9, 67465},
	{"BANDING", 7, 67466},
	{"NONSTICK", 8, 67467},
	{"WOFS", 4, 67468},
	{"OKAC", 4, 67469},
	{"KWEA", 4, 67470},
	{"ORIGAMI", 7, 67471},
	{"MARKETWATCH", 11, 67472},
	{"COMEDIANS", 9, 67473},
	{"AWNINGS", 7, 67474},
	{"UMBILICAL", 9, 67475},
	{"SILL", 4, 67476},
	{"LINZ", 4, 67477},
	{"DONATES", 7, 67478},
	{"FOURSOME", 8, 67479},
	{"BANP", 4, 67480},
	{"LAWRENCEVILLE", 13, 67481},
	{"LUCKNOW", 7, 67482},
	{"BLEACHING", 9, 67483},
	{"AZUL", 4, 67484},
	{"ISOLDE", 6, 67485},
	{"RBYF", 4, 67486},
	{"STARTLED", 8, 67487},
	{"SPRINGDALE", 10, 67488},
	{"MATHEMATICIAN", 13, 67489},
	{"UNTRUE", 6, 67490},
	{"ALGONQUIN", 9, 67491},
	{"SGOR", 4, 67492},
	{"IZUR", 4, 67493},
	{"IGHU", 4, 67494},
	{"MOISTURIZING", 12, 67495},
	{"HURRIED", 7, 67496},
	{"LOEB", 4, 67497},
	{"DTAU", 4, 67498},
	{"FJER", 4, 67499},
	{"HUSTON", 6, 67500},
	{"WBLO", 4, 67501},
	{"KFRE", 4, 67502},
	{"GATOS", 5, 67503},
	{"DSOB", 4, 67504},
	{"DISQUALIFICATION", 16, 67505},
	{"SUUNTO", 6, 67506},
	{"ANGIOTENSIN", 11, 67507},
	{"SPITFIRE", 8, 67508},
	{"DIESER", 6, 67509},
	{"LOWJ", 4, 67510},
	{"WFP", 3, 67511},
	{"STAGGERED", 9, 67512},
	{"RMUD", 4, 67513},
	{"OKBE", 4, 67514},
	{"FROL", 4, 67515},
	{"REALNETWORKS", 12, 67516},
	{"VACATED", 7, 67517},
	{"ILMR", 4, 67518},
	{"IAPL", 4, 67519},
	{"EKMA", 4, 67520},
	{"SUMMATION", 9, 67521},
	{"PLAME", 5, 67522},
	{"QUERYING", 8, 67523},
	{"GOCA", 4, 67524},
	{"FFEM", 4, 67525},
	{"GPC", 3, 67526},
	{"VENTE", 5, 67527},
	{"DAMT", 4, 67528},
	{"AUTONOMIC", 9, 67529},
	{"PATHNAME", 8, 67530},
	{"NOVARTIS", 8, 67531},
	{"ELCR", 4, 67532},
	{"UFOS", 4, 67533},
	{"VRES", 4, 67534},
	{"OABL", 4, 67535},
	{"MRIC", 4, 67536},
	{"LOFJ", 4, 67537},
	{"FITZ", 4, 67538},
	{"DURA", 4, 67539},
	{"FINGERED", 8, 67540},
	{"MANATEE", 7, 67541},
	{"RYEM", 4, 67542},
	{"RAYP", 4, 67543},
	{"APPRENTICES", 11, 67544},
	{"RESTRUCTURE", 11, 67545},
	{"LARVAL", 6, 67546},
	{"SOCAL", 5, 67547},
	{"RYSW", 4, 67548},
	{"RESETTLEMENT", 12, 67549},
	{"MISTAKENLY", 10, 67550},
	{"RADIATIVE", 9, 67551},
	{"UWHI", 4, 67552},
	{"MSAM", 4, 67553},
	{"DEJU", 4, 67554},
	{"CERCA", 5, 67555},
	{"WSEV", 4, 67556},
	{"SAWF", 4, 67557},
	{"DYSF", 4, 67558},
	{"INTIMATELY", 10, 67559},
	{"KOREANS", 7, 67560},
	{"REALY", 5, 67561},
	{"RTGO", 4, 67562},
	{"WOMANS", 6, 67563},
	{"GROIN", 5, 67564},
	{"GREENWAY", 8, 67565},
	{"SPAMASSASSIN", 12, 67566},
	{"RDDU", 4, 67567},
	{"KREV", 4, 67568},
	{"ILIF", 4, 67569},
	{"WOBI", 4, 67570},
	{"MJOH", 4, 67571},
	{"HPUR", 4, 67572},
	{"EYSB", 4, 67573},
	{"GIGAGALLERIES", 13, 67574},
	{"BOOTED", 6, 67575},
	{"FPAK", 4, 67576},
	{"ALLIE", 5, 67577},
	{"ALGERIAN", 8, 67578},
	{"FRAT", 4, 67579},
	{"EGULLET", 7, 67580},
	{"LBUY", 4, 67581},
	{"ELECTRICS", 9, 67582},
	{"YGV", 3, 67583},
	{"XUK", 3, 67584},
	{"SPROUTS", 7, 67585},
	{"BOWER", 5, 67586},
	{"WERV", 4, 67587},
	{"RFIT", 4, 67588},
	{"HAMF", 4, 67589},
	{"AMCL", 4, 67590},
	{"IFFU", 4, 67591},
	{"STENCILS", 8, 67592},
	{"MOAB", 4, 67593},
	{"WOLCOTT", 7, 67594},
	{"EXTREMITY", 9, 67595},
	{"SAYL", 4, 67596},
	{"RSOB", 4, 67597},
	{"REINVENTING", 11, 67598},
	{"ORPHANED", 8, 67599},
	{"REQUISITES", 10, 67600},
	{"GYAS", 4, 67601},
	{"REQS", 4, 67602},
	{"LATTE", 5, 67603},
	{"SHAOLIN", 7, 67604},
	{"PRUDENCE", 8, 67605},
	{"OMYM", 4, 67606},
	{"MUNC", 4, 67607},
	{"SHOPPED", 7, 67608},
	{"BEATTIE", 7, 67609},
	{"OFKU", 4, 67610},
	{"KAUFMANN", 8, 67611},
	{"HYPNOTHERAPY", 12, 67612},
	{"MUPPET", 6, 67613},
	{"HIGG", 4, 67614},
	{"GINGERBREAD", 11, 67615},
	{"WHOY", 4, 67616},
	{"PLIG", 4, 67617},
	{"BIGGS", 5, 67618},
	{"TASTEFUL", 8, 67619},
	{"PURITAN", 7, 67620},
	{"CHECKPOINTS", 11, 67621},
	{"OSIRIS", 6, 67622},
	{"AFFIRMING", 9, 67623},
	{"DERECHOS", 8, 67624},
	{"PIETER", 6, 67625},
	{"SALUD", 5, 67626},
	{"EXCAVATIONS", 11, 67627},
	{"TIMESSELECT", 11, 67628},
	{"VIACOM", 6, 67629},
	{"KCLA", 4, 67630},
	{"FOREARM", 7, 67631},
	{"STRCMP", 6, 67632},
	{"KARDON", 6, 67633},
	{"TADU", 4, 67634},
	{"SEAPORT", 7, 67635},
	{"FLASHED", 7, 67636},
	{"LONGS", 5, 67637},
	{"SIDESHOW", 8, 67638},
	{"EWVI", 4, 67639},
	{"CLASSIFIER", 10, 67640},
	{"WESTBROOK", 9, 67641},
	{"REPRO", 5, 67642},
	{"WONW", 4, 67643},
	{"MOSER", 5, 67644},
	{"DAWES", 5, 67645},
	{"STUDI", 5, 67646},
	{"BUNS", 4, 67647},
	{"KPOL", 4, 67648},
	{"DECEIVE", 7, 67649},
	{"COLONIALISM", 11, 67650},
	{"SUPERMICRO", 10, 67651},
	{"AUGM", 4, 67652},
	{"CIVILISATION", 12, 67653},
	{"STARVED", 7, 67654},
	{"SCORERS", 7, 67655},
	{"SITCOM", 6, 67656},
	{"LLJA", 4, 67657},
	{"PASTRIES", 8, 67658},
	{"AMICO", 5, 67659},
	{"UBTA", 4, 67660},
	{"RILH", 4, 67661},
	{"MCGI", 4, 67662},
	{"AYTU", 4, 67663},
	{"ALDO", 4, 67664},
	{"COLOSSEUM", 9, 67665},
	{"DCAV", 4, 67666},
	{"STIPULATION", 11, 67667},
	{"AZIM", 4, 67668},
	{"YAQU", 4, 67669},
	{"WDEM", 4, 67670},
	{"FROO", 4, 67671},
	{"AUTHORIZATIONS", 14, 67672},
	{"EMPTINESS", 9, 67673},
	{"MADDOX", 6, 67674},
	{"HOLSTERS", 8, 67675},
	{"NEUROPATHY", 10, 67676},
	{"BACKORDER", 9, 67677},
	{"DTAY", 4, 67678},
	{"SHOEMAKER", 9, 67679},
	{"HUMPHREYS", 9, 67680},
	{"TBOB", 4, 67681},
	{"CEGU", 4, 67682},
	{"METROID", 7, 67683},
	{"CUSHIONED", 9, 67684},
	{"DADA", 4, 67685},
	{"GGUA", 4, 67686},
	{"OSBORN", 6, 67687},
	{"HASTILY", 7, 67688},
	{"NIKKOR", 6, 67689},
	{"MCF", 3, 67690},
	{"JACOBSEN", 8, 67691},
	{"RUNM", 4, 67692},
	{"RTYG", 4, 67693},
	{"YATF", 4, 67694},
	{"ULWO", 4, 67695},
	{"YYB", 3, 67696},
	{"UVG", 3, 67697},
	{"LJG", 3, 67698},
	{"DZP", 3, 67699},
	{"CKFE", 4, 67700},
	{"FUL", 3, 67701},
	{"INVADER", 7, 67702},
	{"FKAR", 4, 67703},
	{"PATRIARCH", 9, 67704},
	{"CONJUGATED", 10, 67705},
	{"CONSENTS", 8, 67706},
	{"LCC", 3, 67707},
	{"LSBR", 4, 67708},
	{"UNETHICAL", 9, 67709},
	{"POLYNESIAN", 10, 67710},
	{"USSW", 4, 67711},
	{"UNMI", 4, 67712},
	{"ERTV", 4, 67713},
	{"SWAIN", 5, 67714},
	{"VACANCES", 8, 67715},
	{"NYBI", 4, 67716},
	{"WWIN", 4, 67717},
	{"ALPHANUMERIC", 12, 67718},
	{"GRUMPY", 6, 67719},
	{"DRYI", 4, 67720},
	{"FIXEDHF", 7, 67721},
	{"HOLM", 4, 67722},
	{"GRONINGEN", 9, 67723},
	{"SIRENS", 6, 67724},
	{"IXMI", 4, 67725},
	{"EMILIO", 6, 67726},
	{"MOURN", 5, 67727},
	{"ULYE", 4, 67728},
	{"BENELUX", 7, 67729},
	{"ABANDONING", 10, 67730},
	{"ODDITIES", 8, 67731},
	{"CATERS", 6, 67732},
	{"PRASAD", 6, 67733},
	{"LYPS", 4, 67734},
	{"KIRKPATRICK", 11, 67735},
	{"JAMAHIRIYA", 10, 67736},
	{"TROUPE", 6, 67737},
	{"ZLED", 4, 67738},
	{"BLACKSMITH", 10, 67739},
	{"COAGULATION", 11, 67740},
	{"SUICIDES", 8, 67741},
	{"GIRLY", 5, 67742},
	{"POWERFULLY", 10, 67743},
	{"ARCHDIOCESE", 11, 67744},
	{"JOKI", 4, 67745},
	{"EAKY", 4, 67746},
	{"COMPROMISES", 11, 67747},
	{"ORBITER", 7, 67748},
	{"HELENE", 6, 67749},
	{"THIRDLY", 7, 67750},
	{"OLUS", 4, 67751},
	{"HDOU", 4, 67752},
	{"ALYI", 4, 67753},
	{"EDGEWATER", 9, 67754},
	{"CLASSIFYING", 11, 67755},
	{"YALP", 4, 67756},
	{"DEEPENING", 9, 67757},
	{"KEYLESS", 7, 67758},
	{"REPATRIATION", 12, 67759},
	{"TORTILLA", 8, 67760},
	{"NBOB", 4, 67761},
	{"DISSOCIATION", 12, 67762},
	{"INDUSTRIE", 9, 67763},
	{"WATERCOLOUR", 11, 67764},
	{"UCB", 3, 67765},
	{"WAITE", 5, 67766},
	{"SWRE", 4, 67767},
	{"UNFAIRLY", 8, 67768},
	{"MADSEN", 6, 67769},
	{"OPTICIANS", 9, 67770},
	{"FECH", 4, 67771},
	{"NEWMAP", 6, 67772},
	{"CONNEXIONS", 10, 67773},
	{"CALICO", 6, 67774},
	{"DPAG", 4, 67775},
	{"WRONGS", 6, 67776},
	{"BOTTLENECK", 10, 67777},
	{"PORES", 5, 67778},
	{"REGRESSIONS", 11, 67779},
	{"JOHNSTONE", 9, 67780},
	{"LINTON", 6, 67781},
	{"UNDERMINING", 11, 67782},
	{"BURNSIDE", 8, 67783},
	{"DLEP", 4, 67784},
	{"AKRI", 4, 67785},
	{"COLOSSUS", 8, 67786},
	{"WGOV", 4, 67787},
	{"VIDG", 4, 67788},
	{"RENJ", 4, 67789},
	{"MCCU", 4, 67790},
	{"KBEL", 4, 67791},
	{"BUCKEYES", 8, 67792},
	{"CXW", 3, 67793},
	{"BANW", 4, 67794},
	{"BODYWORK", 8, 67795},
	{"TYYO", 4, 67796},
	{"TYVA", 4, 67797},
	{"DUSO", 4, 67798},
	{"APPLIQUE", 8, 67799},
	{"JEWELL", 6, 67800},
	{"FRIVOLOUS", 9, 67801},
	{"GYFR", 4, 67802},
	{"HORNBY", 6, 67803},
	{"INDECENT", 8, 67804},
	{"LPMA", 4, 67805},
	{"DISHONESTY", 10, 67806},
	{"XPOI", 4, 67807},
	{"OKAP", 4, 67808},
	{"DOWT", 4, 67809},
	{"REDEFINED", 9, 67810},
	{"OILED", 5, 67811},
	{"TURNBULL", 8, 67812},
	{"MICROBES", 8, 67813},
	{"EMPOWERS", 8, 67814},
	{"PREO", 4, 67815},
	{"SHARPEN", 7, 67816},
	{"INFORMIX", 8, 67817},
	{"GOALKEEPER", 10, 67818},
	{"STARTSEITE", 10, 67819},
	{"PHONETIC", 8, 67820},
	{"BLURB", 5, 67821},
	{"FEEDBURNER", 10, 67822},
	{"RRIM", 4, 67823},
	{"ECDO", 4, 67824},
	{"BWHE", 4, 67825},
	{"NORCROSS", 8, 67826},
	{"COMPILES", 8, 67827},
	{"BANCORP", 7, 67828},
	{"TYEM", 4, 67829},
	{"LIAG", 4, 67830},
	{"HEMV", 4, 67831},
	{"YJOS", 4, 67832},
	{"MCRO", 4, 67833},
	{"KUSE", 4, 67834},
	{"ENCODERS", 8, 67835},
	{"OPPRESSIVE", 10, 67836},
	{"UPAM", 4, 67837},
	{"PSLE", 4, 67838},
	{"PMP", 3, 67839},
	{"COINED", 6, 67840},
	{"UBIL", 4, 67841},
	{"OFUE", 4, 67842},
	{"BOOMERANG", 9, 67843},
	{"WREL", 4, 67844},
	{"AXWE", 4, 67845},
	{"TEMECULA", 8, 67846},
	{"RBYI", 4, 67847},
	{"GDOU", 4, 67848},
	{"STRUCTURALLY", 12, 67849},
	{"MORAY", 5, 67850},
	{"NAUL", 4, 67851},
	{"SIMEON", 6, 67852},
	{"CAVEATS", 7, 67853},
	{"LIMC", 4, 67854},
	{"LBIG", 4, 67855},
	{"FTLY", 4, 67856},
	{"ONSLAUGHT", 9, 67857},
	{"HOMEOWNERSHIP", 13, 67858},
	{"JORW", 4, 67859},
	{"BIRDIE", 6, 67860},
	{"DISSEMINATING", 13, 67861},
	{"NATIONALE", 9, 67862},
	{"LANYARD", 7, 67863},
	{"HORST", 5, 67864},
	{"NYIM", 4, 67865},
	{"GICC", 4, 67866},
	{"GBLU", 4, 67867},
	{"INTERLOCK", 9, 67868},
	{"PAGERS", 6, 67869},
	{"SCYC", 4, 67870},
	{"LUPT", 4, 67871},
	{"TREASURED", 9, 67872},
	{"SHARPNESS", 9, 67873},
	{"ESOPHAGUS", 9, 67874},
	{"CORRAL", 6, 67875},
	{"EVEJ", 4, 67876},
	{"JACKPOTS", 8, 67877},
	{"FKID", 4, 67878},
	{"DOMH", 4, 67879},
	{"WDEF", 4, 67880},
	{"HORF", 4, 67881},
	{"OPTOMETRISTS", 12, 67882},
	{"KRUEGER", 7, 67883},
	{"FORTNIGHT", 9, 67884},
	{"HICKEY", 6, 67885},
	{"ERODE", 5, 67886},
	{"UNLICENSED", 10, 67887},
	{"UNDJ", 4, 67888},
	{"PLUNGED", 7, 67889},
	{"REALS", 5, 67890},
	{"RJAP", 4, 67891},
	{"MODULATED", 9, 67892},
	{"DEFIANT", 7, 67893},
	{"ITCU", 4, 67894},
	{"ANMY", 4, 67895},
	{"TERMITE", 7, 67896},
	{"IBUPROFEN", 9, 67897},
	{"XBUT", 4, 67898},
	{"MYWE", 4, 67899},
	{"GMID", 4, 67900},
	{"EYEM", 4, 67901},
	{"DRUGSTORE", 9, 67902},
	{"BRISK", 5, 67903},
	{"AUDIOLOGY", 9, 67904},
	{"GANNON", 6, 67905},
	{"UBEI", 4, 67906},
	{"OFOX", 4, 67907},
	{"INTEGRALS", 9, 67908},
	{"FREMANTLE", 9, 67909},
	{"PITU", 4, 67910},
	{"IRDU", 4, 67911},
	{"ATUC", 4, 67912},
	{"LYSINE", 6, 67913},
	{"NLAM", 4, 67914},
	{"LURI", 4, 67915},
	{"AWAV", 4, 67916},
	{"EUNB", 4, 67917},
	{"RXK", 3, 67918},
	{"MZR", 3, 67919},
	{"SIZZLING", 8, 67920},
	{"WNAP", 4, 67921},
	{"MACROECONOMICS", 14, 67922},
	{"ECKM", 4, 67923},
	{"THULE", 5, 67924},
	{"MEATH", 5, 67925},
	{"PONCE", 5, 67926},
	{"NFIF", 4, 67927},
	{"DUGO", 4, 67928},
	{"PERJURY", 7, 67929},
	{"EEPROM", 6, 67930},
	{"KALEIDOSCOPE", 12, 67931},
	{"YGLO", 4, 67932},
	{"EKUR", 4, 67933},
	{"DEXO", 4, 67934},
	{"DMITRY", 6, 67935},
	{"THAWTE", 6, 67936},
	{"BUSTERS", 7, 67937},
	{"OFFICEMAX", 9, 67938},
	{"GENERALITY", 10, 67939},
	{"VORY", 4, 67940},
	{"EFJU", 4, 67941},
	{"ABSORBER", 8, 67942},
	{"VIGILANT", 8, 67943},
	{"NESSUS", 6, 67944},
	{"PRONTO", 6, 67945},
	{"VISTAS", 6, 67946},
	{"IMAGER", 6, 67947},
	{"CEBU", 4, 67948},
	{"RMBA", 4, 67949},
	{"OMKE", 4, 67950},
	{"LDUT", 4, 67951},
	{"EERIE", 5, 67952},
	{"KANNADA", 7, 67953},
	{"SAILBOAT", 8, 67954},
	{"HECTARE", 7, 67955},
	{"NETBALL", 7, 67956},
	{"FURL", 4, 67957},
	{"HOLOGRAPHIC", 11, 67958},
	{"GVID", 4, 67959},
	{"STONEWALL", 9, 67960},
	{"LUBP", 4, 67961},
	{"WRESTLERS", 9, 67962},
	{"DEFRA", 5, 67963},
	{"TRER", 4, 67964},
	{"MPUB", 4, 67965},
	{"CKYW", 4, 67966},
	{"SALAAM", 6, 67967},
	{"JACKASS", 7, 67968},
	{"WBOR", 4, 67969},
	{"UPWO", 4, 67970},
	{"RESPIRATOR", 10, 67971},
	{"ELYY", 4, 67972},
	{"COUNTERTOP", 10, 67973},
	{"WLYC", 4, 67974},
	{"INSTALLMENTS", 12, 67975},
	{"ROYH", 4, 67976},
	{"EFIB", 4, 67977},
	{"HOGG", 4, 67978},
	{"PARTYING", 8, 67979},
	{"TUPD", 4, 67980},
	{"GCIR", 4, 67981},
	{"AYYE", 4, 67982},
	{"WEATHERFORD", 11, 67983},
	{"EXITED", 6, 67984},
	{"GEOMETRICAL", 11, 67985},
	{"HDAR", 4, 67986},
	{"CRISPY", 6, 67987},
	{"PRIORY", 6, 67988},
	{"COFFEES", 7, 67989},
	{"TDAL", 4, 67990},
	{"ULHE", 4, 67991},
	{"DLEH", 4, 67992},
	{"KNOWHERE", 8, 67993},
	{"SEQUIN", 6, 67994},
	{"EUKS", 4, 67995},
	{"BENDIGO", 7, 67996},
	{"WHYP", 4, 67997},
	{"EPSOM", 5, 67998},
	{"BANDWAGON", 9, 67999},
	{"CORPSES", 7, 68000},
	{"WIPING", 6, 68001},
	{"OKEM", 4, 68002},
	{"MERCENARIES", 11, 68003},
	{"BRONCHITIS", 10, 68004},
	{"JANSSEN", 7, 68005},
	{"USSM", 4, 68006},
	{"MYST", 4, 68007},
	{"PAYD", 4, 68008},
	{"POLYMERIZATION", 14, 68009},
	{"BYVAL", 5, 68010},
	{"TEUP", 4, 68011},
	{"SCOG", 4, 68012},
	{"THERESE", 7, 68013},
	{"WHIRLWIND", 9, 68014},
	{"OKSM", 4, 68015},
	{"EMYD", 4, 68016},
	{"HOWLING", 7, 68017},
	{"APPREHENSION", 12, 68018},
	{"NOZZLES", 7, 68019},
	{"RAISINS", 7, 68020},
	{"OMSF", 4, 68021},
	{"TURKEYS", 7, 68022},
	{"LABVIEW", 7, 68023},
	{"SNITZ", 5, 68024},
	{"UNBELIEVABLY", 12, 68025},
	{"RDFL", 4, 68026},
	{"HLOV", 4, 68027},
	{"DYEX", 4, 68028},
	{"PASTING", 7, 68029},
	{"ZZQ", 3, 68030},
	{"XVP", 3, 68031},
	{"GLJ", 3, 68032},
	{"TLUN", 4, 68033},
	{"RASY", 4, 68034},
	{"KBEG", 4, 68035},
	{"BUTYL", 5, 68036},
	{"PPD", 3, 68037},
	{"FORESTED", 8, 68038},
	{"WOLI", 4, 68039},
	{"UNRIVALED", 9, 68040},
	{"BOBBIE", 6, 68041},
	{"NDKU", 4, 68042},
	{"KBYA", 4, 68043},
	{"ROADWAYS", 8, 68044},
	{"SHALE", 5, 68045},
	{"DILIGENT", 8, 68046},
	{"VARNA", 5, 68047},
	{"UGUA", 4, 68048},
	{"MAIDENHEAD", 10, 68049},
	{"NACHRICHTEN", 11, 68050},
	{"EJEF", 4, 68051},
	{"ALMANACS", 8, 68052},
	{"ADVERSITY", 9, 68053},
	{"GFX", 3, 68054},
	{"POFO", 4, 68055},
	{"FSUM", 4, 68056},
	{"RANDOMNESS", 10, 68057},
	{"MIDDLEBURY", 10, 68058},
	{"ELPG", 4, 68059},
	{"DSDA", 4, 68060},
	{"MUON", 4, 68061},
	{"RINGO", 5, 68062},
	{"PCLA", 4, 68063},
	{"GOUL", 4, 68064},
	{"CALIPER", 7, 68065},
	{"LMB", 3, 68066},
	{"TYRU", 4, 68067},
	{"TTYD", 4, 68068},
	{"WOOLF", 5, 68069},
	{"WIGGINS", 7, 68070},
	{"INNOVATORS", 10, 68071},
	{"ANODE", 5, 68072},
	{"MICROPROCESSORS", 15, 68073},
	{"TORTS", 5, 68074},
	{"NCOF", 4, 68075},
	{"SITING", 6, 68076},
	{"MISINFORMATION", 14, 68077},
	{"ANEURYSM", 8, 68078},
	{"OAFU", 4, 68079},
	{"CLOSEUPS", 8, 68080},
	{"SHPL", 4, 68081},
	{"LAMT", 4, 68082},
	{"AOFW", 4, 68083},
	{"KINSEY", 6, 68084},
	{"OWMY", 4, 68085},
	{"EGRESS", 6, 68086},
	{"PRP", 3, 68087},
	{"CNBC", 4, 68088},
	{"ERODED", 6, 68089},
	{"ADJECTIVES", 10, 68090},
	{"CREPE", 5, 68091},
	{"IGWI", 4, 68092},
	{"LONNIE", 6, 68093},
	{"PHEC", 4, 68094},
	{"MYFE", 4, 68095},
	{"DUM", 3, 68096},
	{"HARTLEPOOL", 10, 68097},
	{"ALASTAIR", 8, 68098},
	{"BNOR", 4, 68099},
	{"SHEEPSKIN", 9, 68100},
	{"FAFSA", 5, 68101},
	{"JAVAC", 5, 68102},
	{"ROYC", 4, 68103},
	{"RCEE", 4, 68104},
	{"GGLA", 4, 68105},
	{"DYRO", 4, 68106},
	{"CONCAVE", 7, 68107},
	{"UCLIBC", 6, 68108},
	{"FODOR", 5, 68109},
	{"MSAF", 4, 68110},
	{"CHSL", 4, 68111},
	{"HERESY", 6, 68112},
	{"AFRIKAANSE", 10, 68113},
	{"ARMORY", 6, 68114},
	{"CHIW", 4, 68115},
	{"COLOGNES", 8, 68116},
	{"CONTESTANT", 10, 68117},
	{"ZEDL", 4, 68118},
	{"SNELL", 5, 68119},
	{"RGWA", 4, 68120},
	{"AMDU", 4, 68121},
	{"PRESCREENED", 11, 68122},
	{"BELIEVABLE", 10, 68123},
	{"ANESTHESIOLOGY", 14, 68124},
	{"FORTHWITH", 9, 68125},
	{"AVERT", 5, 68126},
	{"GUISE", 5, 68127},
	{"ELMHURST", 8, 68128},
	{"VERQ", 4, 68129},
	{"BECE", 4, 68130},
	{"MISHA", 5, 68131},
	{"CURIOUSLY", 9, 68132},
	{"FULLNESS", 8, 68133},
	{"CULMINATING", 11, 68134},
	{"IEFB", 4, 68135},
	{"KIPLING", 7, 68136},
	{"MELATONIN", 9, 68137},
	{"VOMIT", 5, 68138},
	{"BONGO", 5, 68139},
	{"ETYL", 4, 68140},
	{"RMB", 3, 68141},
	{"COMPOUNDING", 11, 68142},
	{"MDF", 3, 68143},
	{"AFAR", 4, 68144},
	{"GPUT", 4, 68145},
	{"ELDQ", 4, 68146},
	{"TERR", 4, 68147},
	{"SHAKY", 5, 68148},
	{"BLOKE", 5, 68149},
	{"RUGD", 4, 68150},
	{"EWBL", 4, 68151},
	{"OXNARD", 6, 68152},
	{"BRUTALLY", 8, 68153},
	{"ZYQ", 3, 68154},
	{"GKV", 3, 68155},
	{"FJW", 3, 68156},
	{"PENNANT", 7, 68157},
	{"CEDEX", 5, 68158},
	{"URVO", 4, 68159},
	{"TYTW", 4, 68160},
	{"ELECTROCHEMICAL", 15, 68161},
	{"NICEST", 6, 68162},
	{"BREVARD", 7, 68163},
	{"BRW", 3, 68164},
	{"UMCH", 4, 68165},
	{"NUPB", 4, 68166},
	{"KMAK", 4, 68167},
	{"BRENNER", 7, 68168},
	{"WILLOUGHBY", 10, 68169},
	{"IRYO", 4, 68170},
	{"SLALOM", 6, 68171},
	{"NECKS", 5, 68172},
	{"MATHIAS", 7, 68173},
	{"WATERHOUSE", 10, 68174},
	{"CALIF", 5, 68175},
	{"ACCES", 5, 68176},
	{"AQUATICS", 8, 68177},
	{"LEVEE", 5, 68178},
	{"HINDUS", 6, 68179},
	{"CARI", 4, 68180},
	{"LURKER", 6, 68181},
	{"BUFFETT", 7, 68182},
	{"CHEWS", 5, 68183},
	{"PTRO", 4, 68184},
	{"DEDY", 4, 68185},
	{"HOODIES", 7, 68186},
	{"TOMF", 4, 68187},
	{"LDUE", 4, 68188},
	{"KYEA", 4, 68189},
	{"PHONY", 5, 68190},
	{"VILA", 4, 68191},
	{"SELW", 4, 68192},
	{"POWERLESS", 9, 68193},
	{"GMAKE", 5, 68194},
	{"NIKKO", 5, 68195},
	{"LMOO", 4, 68196},
	{"POPULACE", 8, 68197},
	{"GRASSLANDS", 10, 68198},
	{"OPAP", 4, 68199},
	{"GASD", 4, 68200},
	{"EZWH", 4, 68201},
	{"DELIBERATION", 12, 68202},
	{"SOLES", 5, 68203},
	{"MONOLITHIC", 10, 68204},
	{"EXME", 4, 68205},
	{"JETTY", 5, 68206},
	{"POLIFONICZNE", 12, 68207},
	{"BUGTRAQ", 7, 68208},
	{"MFAI", 4, 68209},
	{"CPAGE", 5, 68210},
	{"ENGR", 4, 68211},
	{"LUSTER", 6, 68212},
	{"USKA", 4, 68213},
	{"OYOF", 4, 68214},
	{"GDYN", 4, 68215},
	{"SUBCONTRACT", 11, 68216},
	{"OVERRUN", 7, 68217},
	{"UNDONE", 6, 68218},
	{"PROPHYLAXIS", 11, 68219},
	{"TEXINFO", 7, 68220},
	{"SROD", 4, 68221},
	{"CADV", 4, 68222},
	{"COTSWOLD", 8, 68223},
	{"PTCO", 4, 68224},
	{"APAD", 4, 68225},
	{"DELIA", 5, 68226},
	{"GUILLERMO", 9, 68227},
	{"UNSTRUCTURED", 12, 68228},
	{"UTAV", 4, 68229},
	{"RHUG", 4, 68230},
	{"OBWA", 4, 68231},
	{"LFSA", 4, 68232},
	{"HABITUAL", 8, 68233},
	{"ALHAMBRA", 8, 68234},
	{"BOOP", 4, 68235},
	{"HITMAN", 6, 68236},
	{"LTYC", 4, 68237},
	{"HWED", 4, 68238},
	{"GNTY", 4, 68239},
	{"UPLIFT", 6, 68240},
	{"CAUSEWAY", 8, 68241},
	{"MERCIER", 7, 68242},
	{"MURDERERS", 9, 68243},
	{"BIOD", 4, 68244},
	{"RESTATED", 8, 68245},
	{"NUKES", 5, 68246},
	{"DUPLICATOR", 10, 68247},
	{"REOPENED", 8, 68248},
	{"MEHTA", 5, 68249},
	{"MACOMB", 6, 68250},
	{"FUNDAMENTALISM", 14, 68251},
	{"AUSTRALASIAN", 12, 68252},
	{"GUID", 4, 68253},
	{"INHABIT", 7, 68254},
	{"LORENZ", 6, 68255},
	{"CONGLOMERATE", 12, 68256},
	{"WINR", 4, 68257},
	{"ABUC", 4, 68258},
	{"RERUN", 5, 68259},
	{"MODA", 4, 68260},
	{"SEGMENTED", 9, 68261},
	{"CRANBERRIES", 11, 68262},
	{"SUZU", 4, 68263},
	{"OLUC", 4, 68264},
	{"FASTENED", 8, 68265},
	{"PLEATED", 7, 68266},
	{"WNRO", 4, 68267},
	{"NOWJ", 4, 68268},
	{"GWHY", 4, 68269},
	{"HANDSHAKE", 9, 68270},
	{"TOMPKINS", 8, 68271},
	{"EXTRADITION", 11, 68272},
	{"DIGESTS", 7, 68273},
	{"GESCHICHTE", 10, 68274},
	{"INNOVATE", 8, 68275},
	{"PERILS", 6, 68276},
	{"GOODE", 5, 68277},
	{"ERISA", 5, 68278},
	{"JERKY", 5, 68279},
	{"DISMANTLING", 11, 68280},
	{"PROPORTIONATE", 13, 68281},
	{"UPBA", 4, 68282},
	{"FERRELL", 7, 68283},
	{"COMPTE", 6, 68284},
	{"HELLOMETRO", 10, 68285},
	{"IXFO", 4, 68286},
	{"LEAVENWORTH", 11, 68287},
	{"ALGO", 4, 68288},
	{"EFFS", 4, 68289},
	{"BYNU", 4, 68290},
	{"SNOWMOBILING", 12, 68291},
	{"BOROUGHS", 8, 68292},
	{"FORA", 4, 68293},
	{"FDR", 3, 68294},
	{"GABA", 4, 68295},
	{"DELIVERANCE", 11, 68296},
	{"RESISTS", 7, 68297},
	{"LOVELL", 6, 68298},
	{"DLC", 3, 68299},
	{"DISCOURSES", 10, 68300},
	{"BYERS", 5, 68301},
	{"YAUD", 4, 68302},
	{"IEPR", 4, 68303},
	{"SUBDUED", 7, 68304},
	{"ADHERING", 8, 68305},
	{"FALK", 4, 68306},
	{"CODON", 5, 68307},
	{"MCRA", 4, 68308},
	{"IMEK", 4, 68309},
	{"DYCH", 4, 68310},
	{"SUSPICIONS", 10, 68311},
	{"WEBNOTIFY", 9, 68312},
	{"HAMPERED", 8, 68313},
	{"PYLORI", 6, 68314},
	{"LOOMIS", 6, 68315},
	{"UCKC", 4, 68316},
	{"FUNF", 4, 68317},
	{"ACIDITY", 7, 68318},
	{"GERSHWIN", 8, 68319},
	{"BRUXELLES", 9, 68320},
	{"RIKS", 4, 68321},
	{"FORMALDEHYDE", 12, 68322},
	{"DETRIMENT", 9, 68323},
	{"DBAI", 4, 68324},
	{"WELDER", 6, 68325},
	{"CYP", 3, 68326},
	{"KENDRA", 6, 68327},
	{"RGYB", 4, 68328},
	{"SWITCHER", 8, 68329},
	{"PREJUDICES", 10, 68330},
	{"OCAML", 5, 68331},
	{"RIGN", 4, 68332},
	{"HKIL", 4, 68333},
	{"GOLDIE", 6, 68334},
	{"GOOSHING", 8, 68335},
	{"YDIG", 4, 68336},
	{"PURPORTED", 9, 68337},
	{"MOCKINGBIRD", 11, 68338},
	{"UCSO", 4, 68339},
	{"PONTE", 5, 68340},
	{"LKIE", 4, 68341},
	{"IPDE", 4, 68342},
	{"ALZO", 4, 68343},
	{"MANGROVE", 8, 68344},
	{"NDUI", 4, 68345},
	{"FAWN", 4, 68346},
	{"UTEU", 4, 68347},
	{"FAFF", 4, 68348},
	{"BBLI", 4, 68349},
	{"HOGWARTS", 8, 68350},
	{"JUICER", 6, 68351},
	{"LLOYDS", 6, 68352},
	{"ECHELON", 7, 68353},
	{"GABBA", 5, 68354},
	{"ROLH", 4, 68355},
	{"MQUI", 4, 68356},
	{"EOXF", 4, 68357},
	{"ARRANGER", 8, 68358},
	{"SCAFFOLDING", 11, 68359},
	{"PRIN", 4, 68360},
	{"NARROWS", 7, 68361},
	{"UMBRO", 5, 68362},
	{"TCAB", 4, 68363},
	{"METALLURGY", 10, 68364},
	{"SENSED", 6, 68365},
	{"RISV", 4, 68366},
	{"DSGA", 4, 68367},
	{"LITEON", 6, 68368},
	{"QUEUING", 7, 68369},
	{"TMUN", 4, 68370},
	{"BIQU", 4, 68371},
	{"VSIZE", 5, 68372},
	{"INSURING", 8, 68373},
	{"PEDN", 4, 68374},
	{"IMLA", 4, 68375},
	{"BABCOCK", 7, 68376},
	{"RHYS", 4, 68377},
	{"BYGU", 4, 68378},
	{"BOASTING", 8, 68379},
	{"SHIITE", 6, 68380},
	{"VALUING", 7, 68381},
	{"XWEL", 4, 68382},
	{"ARGON", 5, 68383},
	{"COHEED", 6, 68384},
	{"HOORAY", 6, 68385},
	{"FLIGHTPLAN", 10, 68386},
	{"WBEI", 4, 68387},
	{"RWAV", 4, 68388},
	{"HBOY", 4, 68389},
	{"XREV", 4, 68390},
	{"NORAH", 5, 68391},
	{"CAREFREE", 8, 68392},
	{"SOUZA", 5, 68393},
	{"KERSHAW", 7, 68394},
	{"MILLAR", 6, 68395},
	{"FTOL", 4, 68396},
	{"EPMO", 4, 68397},
	{"BIOTIN", 6, 68398},
	{"SALTER", 6, 68399},
	{"TESTICLES", 9, 68400},
	{"UMPK", 4, 68401},
	{"TMIX", 4, 68402},
	{"RWEH", 4, 68403},
	{"ESMC", 4, 68404},
	{"ASCERTAINED", 11, 68405},
	{"PXB", 3, 68406},
	{"MZF", 3, 68407},
	{"MORPH", 5, 68408},
	{"ECONOMETRICS", 12, 68409},
	{"REMO", 4, 68410},
	{"UGOU", 4, 68411},
	{"MRMA", 4, 68412},
	{"MSEC", 4, 68413},
	{"MARCONI", 7, 68414},
	{"FLUCTUATION", 11, 68415},
	{"JEANNIE", 7, 68416},
	{"RECEIVERDVB", 11, 68417},
	{"EXPATRIATE", 10, 68418},
	{"LLIL", 4, 68419},
	{"KMIL", 4, 68420},
	{"TWENTIES", 8, 68421},
	{"TANTRA", 6, 68422},
	{"CODIFIED", 8, 68423},
	{"WNGO", 4, 68424},
	{"OTBL", 4, 68425},
	{"HREY", 4, 68426},
	{"BYMY", 4, 68427},
	{"OVERLAYS", 8, 68428},
	{"UPQU", 4, 68429},
	{"THINGY", 6, 68430},
	{"MONSTROUS", 9, 68431},
	{"COMFORTERS", 10, 68432},
	{"CONSERVATORIES", 14, 68433},
	{"RUSKIN", 6, 68434},
	{"DPF", 3, 68435},
	{"STETSON", 7, 68436},
	{"CYNDI", 5, 68437},
	{"ACCUSES", 7, 68438},
	{"CALIBRE", 7, 68439},
	{"NOBLES", 6, 68440},
	{"UNMO", 4, 68441},
	{"ILFE", 4, 68442},
	{"GERMINATION", 11, 68443},
	{"RNFL", 4, 68444},
	{"EMLE", 4, 68445},
	{"DUNP", 4, 68446},
	{"LIPOPROTEIN", 11, 68447},
	{"AYURVEDIC", 9, 68448},
	{"PLANETARIUM", 11, 68449},
	{"TRIBECA", 7, 68450},
	{"BIHAR", 5, 68451},
	{"KEENAN", 6, 68452},
	{"FUMBLE", 6, 68453},
	{"DISCOS", 6, 68454},
	{"ATTRITION", 9, 68455},
	{"GIWA", 4, 68456},
	{"ATHERTON", 8, 68457},
	{"LASSEN", 6, 68458},
	{"EASTBOURNE", 10, 68459},
	{"ROBLES", 6, 68460},
	{"GITM", 4, 68461},
	{"GIANNI", 6, 68462},
	{"DXF", 3, 68463},
	{"HOMEBUYERS", 10, 68464},
	{"PROVERB", 7, 68465},
	{"NOGROUP", 7, 68466},
	{"DARIN", 5, 68467},
	{"MERCENARY", 9, 68468},
	{"CLAMS", 5, 68469},
	{"FREESCALE", 9, 68470},
	{"OPYI", 4, 68471},
	{"AWSW", 4, 68472},
	{"OMEZ", 4, 68473},
	{"CKAP", 4, 68474},
	{"WICCAN", 6, 68475},
	{"WONC", 4, 68476},
	{"TIJU", 4, 68477},
	{"KPOR", 4, 68478},
	{"TIGHTENED", 9, 68479},
	{"MERRIMACK", 9, 68480},
	{"LEVIES", 6, 68481},
	{"DRSQ", 4, 68482},
	{"SPECK", 5, 68483},
	{"GUNO", 4, 68484},
	{"GROTON", 6, 68485},
	{"BILLBOARDS", 10, 68486},
	{"SEARCHER", 8, 68487},
	{"UTTAR", 5, 68488},
	{"GUTTERS", 7, 68489},
	{"MAILINGLIST", 11, 68490},
	{"RNPI", 4, 68491},
	{"LKWA", 4, 68492},
	{"IABY", 4, 68493},
	{"DDSO", 4, 68494},
	{"DDAS", 4, 68495},
	{"METACRAWLER", 11, 68496},
	{"PRISER", 6, 68497},
	{"OSCEOLA", 7, 68498},
	{"YLIC", 4, 68499},
	{"BIOTERRORISM", 12, 68500},
	{"TOURMALINE", 10, 68501},
	{"LEATHERMAN", 10, 68502},
	{"MURDEROUS", 9, 68503},
	{"UPEN", 4, 68504},
	{"RUDDER", 6, 68505},
	{"MICRONS", 7, 68506},
	{"UNIFYING", 8, 68507},
	{"ANAESTHESIA", 11, 68508},
	{"VIDEOGAME", 9, 68509},
	{"YYET", 4, 68510},
	{"GLIE", 4, 68511},
	{"SCARES", 6, 68512},
	{"INTRANETS", 9, 68513},
	{"ESCALATING", 10, 68514},
	{"BLUEBIRD", 8, 68515},
	{"NBOM", 4, 68516},
	{"IUCN", 4, 68517},
	{"MAHJONG", 7, 68518},
	{"DEFORMED", 8, 68519},
	{"WRETCHED", 8, 68520},
	{"INTERSTELLAR", 12, 68521},
	{"KENTON", 6, 68522},
	{"DECADENT", 8, 68523},
	{"UNDERESTIMATED", 14, 68524},
	{"INCARCERATED", 12, 68525},
	{"UNSURPASSED", 11, 68526},
	{"SURPASS", 7, 68527},
	{"UALU", 4, 68528},
	{"GUOU", 4, 68529},
	{"LOUDSPEAKERS", 12, 68530},
	{"FLEXI", 5, 68531},
	{"RATD", 4, 68532},
	{"ANNIHILATION", 12, 68533},
	{"JUNCTIONS", 9, 68534},
	{"YFK", 3, 68535},
	{"LPZ", 3, 68536},
	{"REDMAN", 6, 68537},
	{"TRANSFERASE", 11, 68538},
	{"BVLGARI", 7, 68539},
	{"WOBU", 4, 68540},
	{"UTRY", 4, 68541},
	{"HAMPDEN", 7, 68542},
	{"PIETRO", 6, 68543},
	{"TJEW", 4, 68544},
	{"SELBY", 5, 68545},
	{"WAUSAU", 6, 68546},
	{"STOPPERS", 8, 68547},
	{"SNOWSHOEING", 11, 68548},
	{"EYKI", 4, 68549},
	{"MEMORANDA", 9, 68550},
	{"STEAMING", 8, 68551},
	{"RKTE", 4, 68552},
	{"MAGNIFYING", 10, 68553},
	{"UPPERCASE", 9, 68554},
	{"SERRA", 5, 68555},
	{"LDIG", 4, 68556},
	{"CIRRHOSIS", 9, 68557},
	{"PUBLIB", 6, 68558},
	{"RDSY", 4, 68559},
	{"ABAK", 4, 68560},
	{"METROLOGY", 9, 68561},
	{"NGUT", 4, 68562},
	{"HIDEOUS", 7, 68563},
	{"YSDR", 4, 68564},
	{"PSLO", 4, 68565},
	{"ABREAST", 7, 68566},
	{"INTUITIVELY", 11, 68567},
	{"RIFO", 4, 68568},
	{"CONNEXION", 9, 68569},
	{"MREF", 4, 68570},
	{"FITP", 4, 68571},
	{"STONEWARE", 9, 68572},
	{"MONCTON", 7, 68573},
	{"RMUT", 4, 68574},
	{"PHIB", 4, 68575},
	{"FOLE", 4, 68576},
	{"FFEB", 4, 68577},
	{"TRACI", 5, 68578},
	{"IKIP", 4, 68579},
	{"ICQU", 4, 68580},
	{"KRUMBLE", 7, 68581},
	{"PATHOGENIC", 10, 68582},
	{"RASMUS", 6, 68583},
	{"RARITAN", 7, 68584},
	{"RIVERFRONT", 10, 68585},
	{"DALP", 4, 68586},
	{"HUMANIST", 8, 68587},
	{"USEFULL", 7, 68588},
	{"RESJ", 4, 68589},
	{"EXTREMITIES", 11, 68590},
	{"POMPANO", 7, 68591},
	{"TYRANT", 6, 68592},
	{"SKEWED", 6, 68593},
	{"CLEARY", 6, 68594},
	{"WSWO", 4, 68595},
	{"UEPE", 4, 68596},
	{"DECENCY", 7, 68597},
	{"PAPAL", 5, 68598},
	{"OFFN", 4, 68599},
	{"DMEO", 4, 68600},
	{"LUDACRIS", 8, 68601},
	{"SEQUENCED", 9, 68602},
	{"SPRANG", 6, 68603},
	{"WEXA", 4, 68604},
	{"TBYN", 4, 68605},
	{"PALAIS", 6, 68606},
	{"OBSCURED", 8, 68607},
	{"UBWI", 4, 68608},
	{"TLYV", 4, 68609},
	{"RTVI", 4, 68610},
	{"TEAMING", 7, 68611},
	{"FLATSHARE", 9, 68612},
	{"AROMAS", 6, 68613},
	{"DUETS", 5, 68614},
	{"OLTR", 4, 68615},
	{"POSITIONAL", 10, 68616},
	{"ALESIS", 6, 68617},
	{"GLYCINE", 7, 68618},
	{"WBOO", 4, 68619},
	{"RTPU", 4, 68620},
	{"EVEF", 4, 68621},
	{"BREAKTHROUGHS", 13, 68622},
	{"UPEA", 4, 68623},
	{"KBRA", 4, 68624},
	{"MOUNTAINEERS", 12, 68625},
	{"CASHBACK", 8, 68626},
	{"THROWBACK", 9, 68627},
	{"BLOUNT", 6, 68628},
	{"USHY", 4, 68629},
	{"KSCR", 4, 68630},
	{"CHARLESTOWN", 11, 68631},
	{"NEXRAD", 6, 68632},
	{"GESTATION", 9, 68633},
	{"POWERING", 8, 68634},
	{"MAGEE", 5, 68635},
	{"ODUP", 4, 68636},
	{"KBOT", 4, 68637},
	{"OSNEWS", 6, 68638},
	{"LOGINS", 6, 68639},
	{"LTHM", 4, 68640},
	{"FUSC", 4, 68641},
	{"MUNCIE", 6, 68642},
	{"BUTCHERS", 8, 68643},
	{"APOLOGISE", 9, 68644},
	{"PANORAMAS", 9, 68645},
	{"AUSP", 4, 68646},
	{"PLENUM", 6, 68647},
	{"AOTEAROA", 8, 68648},
	{"LOWV", 4, 68649},
	{"GEOLOGIST", 9, 68650},
	{"PICCADILLY", 10, 68651},
	{"FORO", 4, 68652},
	{"HYDROLYSIS", 10, 68653},
	{"FLAC", 4, 68654},
	{"AXIOMS", 6, 68655},
	{"LABIA", 5, 68656},
	{"YSYM", 4, 68657},
	{"BANQ", 4, 68658},
	{"ALFF", 4, 68659},
	{"IMMUNIZATIONS", 13, 68660},
	{"EXISTENTIAL", 11, 68661},
	{"UMC", 3, 68662},
	{"SWEATY", 6, 68663},
	{"YTIG", 4, 68664},
	{"EWPI", 4, 68665},
	{"MOGUL", 5, 68666},
	{"FIERCELY", 8, 68667},
	{"GOPH", 4, 68668},
	{"VARNISH", 7, 68669},
	{"HYSTERIA", 8, 68670},
	{"UEBO", 4, 68671},
	{"HEPM", 4, 68672},
	{"BERV", 4, 68673},
	{"SEGOND", 6, 68674},
	{"ADDIS", 5, 68675},
	{"RILF", 4, 68676},
	{"RDCR", 4, 68677},
	{"LWEI", 4, 68678},
	{"BEASLEY", 7, 68679},
	{"SLYL", 4, 68680},
	{"UELB", 4, 68681},
	{"HGAV", 4, 68682},
	{"EWIZ", 4, 68683},
	{"DHEK", 4, 68684},
	{"GEVO", 4, 68685},
	{"FSUF", 4, 68686},
	{"BREACHED", 8, 68687},
	{"ROUNDER", 7, 68688},
	{"ICHJ", 4, 68689},
	{"EMLO", 4, 68690},
	{"PERCHED", 7, 68691},
	{"WROU", 4, 68692},
	{"VIDEOCONFERENCING", 17, 68693},
	{"HOMM", 4, 68694},
	{"CYTOPLASM", 9, 68695},
	{"INSISTENCE", 10, 68696},
	{"MAKIN", 5, 68697},
	{"SEDIMENTARY", 11, 68698},
	{"CLOCKWORK", 9, 68699},
	{"LAURIER", 7, 68700},
	{"OKFI", 4, 68701},
	{"LPAG", 4, 68702},
	{"LLGU", 4, 68703},
	{"CKEV", 4, 68704},
	{"MECKLENBURG", 11, 68705},
	{"AACHEN", 6, 68706},
	{"OLNEY", 5, 68707},
	{"MASSIMO", 7, 68708},
	{"CHLOROPHYLL", 11, 68709},
	{"SCOP", 4, 68710},
	{"SHIPYARD", 8, 68711},
	{"CENTERING", 9, 68712},
	{"MANLEY", 6, 68713},
	{"SUNROOF", 7, 68714},
	{"DVORAK", 6, 68715},
	{"ANSWERER", 8, 68716},
	{"BRIEFCASES", 10, 68717},
	{"INTELLIGENTLY", 13, 68718},
	{"GWENT", 5, 68719},
	{"FUER", 4, 68720},
	{"VIALS", 5, 68721},
	{"BOGART", 6, 68722},
	{"IMPUTATION", 10, 68723},
	{"ALBRECHT", 8, 68724},
	{"KAUFEN", 6, 68725},
	{"UTPI", 4, 68726},
	{"ULVE", 4, 68727},
	{"VEID", 4, 68728},
	{"AADV", 4, 68729},
	{"DENSELY", 7, 68730},
	{"UNTRANSLATED", 12, 68731},
	{"DROIT", 5, 68732},
	{"RAFFLES", 7, 68733},
	{"RECONNECT", 9, 68734},
	{"COLTON", 6, 68735},
	{"IMGL", 4, 68736},
	{"IDTU", 4, 68737},
	{"HIPY", 4, 68738},
	{"GNPR", 4, 68739},
	{"TEENY", 5, 68740},
	{"DISTRUST", 8, 68741},
	{"ULM", 3, 68742},
	{"ASSASSINS", 9, 68743},
	{"TBYO", 4, 68744},
	{"PTBY", 4, 68745},
	{"DADW", 4, 68746},
	{"HATTON", 6, 68747},
	{"USRU", 4, 68748},
	{"FENV", 4, 68749},
	{"EGUR", 4, 68750},
	{"FRATERNAL", 9, 68751},
	{"BENTHIC", 7, 68752},
	{"MCMANUS", 7, 68753},
	{"BDOM", 4, 68754},
	{"INFOTECH", 8, 68755},
	{"CARLIN", 6, 68756},
	{"LITHOGRAPH", 10, 68757},
	{"REFINEMENTS", 11, 68758},
	{"KOND", 4, 68759},
	{"HFLE", 4, 68760},
	{"DYLE", 4, 68761},
	{"STONER", 6, 68762},
	{"REPOST", 6, 68763},
	{"DYGO", 4, 68764},
	{"RESURFACING", 11, 68765},
	{"KELLI", 5, 68766},
	{"IOFR", 4, 68767},
	{"ELOQUENT", 8, 68768},
	{"SPITZER", 7, 68769},
	{"NVOK", 4, 68770},
	{"FTSP", 4, 68771},
	{"SILAS", 5, 68772},
	{"WONDROUS", 8, 68773},
	{"MOCT", 4, 68774},
	{"DECREES", 7, 68775},
	{"DUNNE", 5, 68776},
	{"HYPERBOLIC", 10, 68777},
	{"THGL", 4, 68778},
	{"MYDI", 4, 68779},
	{"BISQUE", 6, 68780},
	{"ANZEIGEN", 8, 68781},
	{"TOUCHSTONE", 10, 68782},
	{"STANDOFF", 8, 68783},
	{"ELKI", 4, 68784},
	{"WESTBURY", 8, 68785},
	{"SOLANO", 6, 68786},
	{"KAILUA", 6, 68787},
	{"ACOUSTICAL", 10, 68788},
	{"ETEXT", 5, 68789},
	{"REYI", 4, 68790},
	{"LFAD", 4, 68791},
	{"XGM", 3, 68792},
	{"PHOTOVOLTAIC", 12, 68793},
	{"OFEP", 4, 68794},
	{"MEWR", 4, 68795},
	{"DRAYTON", 7, 68796},
	{"ORCHESTRAS", 10, 68797},
	{"REDLINE", 7, 68798},
	{"TLYK", 4, 68799},
	{"ELFG", 4, 68800},
	{"GRIEVE", 6, 68801},
	{"REIGNS", 6, 68802},
	{"TLOR", 4, 68803},
	{"LHEC", 4, 68804},
	{"PLEASURABLE", 11, 68805},
	{"DOBBS", 5, 68806},
	{"REGGAETON", 9, 68807},
	{"QSTRING", 7, 68808},
	{"DECLAN", 6, 68809},
	{"TUNIS", 5, 68810},
	{"SVAC", 4, 68811},
	{"OWRU", 4, 68812},
	{"KSOL", 4, 68813},
	{"BUSTLING", 8, 68814},
	{"WANK", 4, 68815},
	{"VIROL", 5, 68816},
	{"GALT", 4, 68817},
	{"FLUE", 4, 68818},
	{"SOLVERS", 7, 68819},
	{"LINUXWORLD", 10, 68820},
	{"CANADIENS", 9, 68821},
	{"USHP", 4, 68822},
	{"ILUS", 4, 68823},
	{"HUPS", 4, 68824},
	{"LUCERNE", 7, 68825},
	{"FIASCO", 6, 68826},
	{"EMIR", 4, 68827},
	{"ROCKABILLY", 10, 68828},
	{"DEACONS", 7, 68829},
	{"SMOKIN", 6, 68830},
	{"AGOJ", 4, 68831},
	{"TUMOURS", 7, 68832},
	{"DAYV", 4, 68833},
	{"LOUDSPEAKER", 11, 68834},
	{"HANDICAPPING", 12, 68835},
	{"EIZU", 4, 68836},
	{"DDUT", 4, 68837},
	{"SLINGS", 6, 68838},
	{"DWARFS", 6, 68839},
	{"SREW", 4, 68840},
	{"GFED", 4, 68841},
	{"ETDU", 4, 68842},
	{"EVANGELION", 10, 68843},
	{"GHEV", 4, 68844},
	{"FFYO", 4, 68845},
	{"EXCRETION", 9, 68846},
	{"BREAKAGE", 8, 68847},
	{"NEGRA", 5, 68848},
	{"YBYD", 4, 68849},
	{"ICOD", 4, 68850},
	{"HORSHAM", 7, 68851},
	{"JING", 4, 68852},
	{"APPORTIONMENT", 13, 68853},
	{"UCKN", 4, 68854},
	{"RTCU", 4, 68855},
	{"NKAG", 4, 68856},
	{"PETRO", 5, 68857},
	{"THOREAU", 7, 68858},
	{"NOTATIONS", 9, 68859},
	{"REINS", 5, 68860},
	{"HEMK", 4, 68861},
	{"GECI", 4, 68862},
	{"FGAN", 4, 68863},
	{"MIDGETS", 7, 68864},
	{"COMPRAR", 7, 68865},
	{"CKYB", 4, 68866},
	{"HOMEMAKER", 9, 68867},
	{"NEVERWINTER", 11, 68868},
	{"BROADEST", 8, 68869},
	{"SCRAMBLING", 10, 68870},
	{"NKMO", 4, 68871},
	{"FTAC", 4, 68872},
	{"DWEV", 4, 68873},
	{"MISFORTUNE", 10, 68874},
	{"DRENCHED", 8, 68875},
	{"DANV", 4, 68876},
	{"AULC", 4, 68877},
	{"OWGE", 4, 68878},
	{"MYNO", 4, 68879},
	{"EJAR", 4, 68880},
	{"ARMP", 4, 68881},
	{"CATEGORIZE", 10, 68882},
	{"GEOPHYS", 7, 68883},
	{"IDCL", 4, 68884},
	{"FORESKIN", 8, 68885},
	{"JORNADA", 7, 68886},
	{"YGUN", 4, 68887},
	{"INETPUB", 7, 68888},
	{"YPSY", 4, 68889},
	{"YONR", 4, 68890},
	{"VEED", 4, 68891},
	{"UDOR", 4, 68892},
	{"PREMIERGUIDE", 12, 68893},
	{"REFLEXOLOGY", 11, 68894},
	{"ASTONISHED", 10, 68895},
	{"KIEL", 4, 68896},
	{"SUBCONSCIOUS", 12, 68897},
	{"INCANDESCENT", 12, 68898},
	{"STUL", 4, 68899},
	{"NZEM", 4, 68900},
	{"NLEB", 4, 68901},
	{"SOPHOS", 6, 68902},
	{"WCIT", 4, 68903},
	{"LPET", 4, 68904},
	{"HELPHELP", 8, 68905},
	{"FOUNDRIES", 9, 68906},
	{"REGISTRANTS", 11, 68907},
	{"LEMN", 4, 68908},
	{"DISAPPOINT", 10, 68909},
	{"SWEATS", 6, 68910},
	{"YFEM", 4, 68911},
	{"SAYG", 4, 68912},
	{"CAPSTONE", 8, 68913},
	{"NPED", 4, 68914},
	{"EMAV", 4, 68915},
	{"AGEJ", 4, 68916},
	{"ADECCO", 6, 68917},
	{"RZZ", 3, 68918},
	{"RYAI", 4, 68919},
	{"SENSEI", 6, 68920},
	{"PUBLICIZED", 10, 68921},
	{"MOBS", 4, 68922},
	{"CRIS", 4, 68923},
	{"TRANSESSUALE", 12, 68924},
	{"FEDERALIST", 10, 68925},
	{"XTIM", 4, 68926},
	{"OBJECTWEB", 9, 68927},
	{"YPHA", 4, 68928},
	{"KWES", 4, 68929},
	{"LDSN", 4, 68930},
	{"REHEARSALS", 10, 68931},
	{"MASSA", 5, 68932},
	{"PORTRAYS", 8, 68933},
	{"POSTGRES", 8, 68934},
	{"FESSELN", 7, 68935},
	{"HIDALGO", 7, 68936},
	{"PROSTHETIC", 10, 68937},
	{"FIREWOOD", 8, 68938},
	{"SERENADE", 8, 68939},
	{"KRISTINE", 8, 68940},
	{"MICROFICHE", 10, 68941},
	{"MYTI", 4, 68942},
	{"IGDI", 4, 68943},
	{"WATERGATE", 9, 68944},
	{"SETBACKS", 8, 68945},
	{"KARAN", 5, 68946},
	{"WEATHERED", 9, 68947},
	{"LAPL", 4, 68948},
	{"EDUG", 4, 68949},
	{"BYTU", 4, 68950},
	{"CDATA", 5, 68951},
	{"TRUFFLES", 8, 68952},
	{"KFC", 3, 68953},
	{"LZON", 4, 68954},
	{"ETBL", 4, 68955},
	{"DILU", 4, 68956},
	{"GRANDVIEW", 9, 68957},
	{"OBMA", 4, 68958},
	{"KEPLER", 6, 68959},
	{"AMERISUITES", 11, 68960},
	{"AURAL", 5, 68961},
	{"GATEKEEPER", 10, 68962},
	{"HEINEMANN", 9, 68963},
	{"ANKU", 4, 68964},
	{"DECOMMISSIONING", 15, 68965},
	{"TEATRO", 6, 68966},
	{"LAWLESS", 7, 68967},
	{"YNOD", 4, 68968},
	{"UPTW", 4, 68969},
	{"ARIP", 4, 68970},
	{"GESTION", 7, 68971},
	{"PBYA", 4, 68972},
	{"KITU", 4, 68973},
	{"FWEH", 4, 68974},
	{"CSOR", 4, 68975},
	{"THERMODYNAMIC", 13, 68976},
	{"PATRICE", 7, 68977},
	{"PROFILED", 8, 68978},
	{"GOUT", 4, 68979},
	{"COINCIDES", 9, 68980},
	{"DISAMBIGUATION", 14, 68981},
	{"MMMM", 4, 68982},
	{"WLOC", 4, 68983},
	{"RIEW", 4, 68984},
	{"KTRI", 4, 68985},
	{"BANR", 4, 68986},
	{"BITTERSWEET", 11, 68987},
	{"INHUMAN", 7, 68988},
	{"MUL", 3, 68989},
	{"UBSH", 4, 68990},
	{"GUSTAVO", 7, 68991},
	{"SLTD", 4, 68992},
	{"GENTILES", 8, 68993},
	{"GISU", 4, 68994},
	{"CADM", 4, 68995},
	{"JARDIN", 6, 68996},
	{"NJUM", 4, 68997},
	{"WICZ", 4, 68998},
	{"MAFE", 4, 68999},
	{"DIOV", 4, 69000},
	{"RUBS", 4, 69001},
	{"ISOLATING", 9, 69002},
	{"PTSF", 4, 69003},
	{"LDGU", 4, 69004},
	{"BIGFOOT", 7, 69005},
	{"TWIF", 4, 69006},
	{"MYCOBACTERIUM", 13, 69007},
	{"IRRITATED", 9, 69008},
	{"YAMADA", 6, 69009},
	{"NFUE", 4, 69010},
	{"DESPISE", 7, 69011},
	{"COLDWATER", 9, 69012},
	{"WHITEHOUSE", 10, 69013},
	{"CULTIVARS", 9, 69014},
	{"YRNE", 4, 69015},
	{"FLOATED", 7, 69016},
	{"MUGABE", 6, 69017},
	{"MARGO", 5, 69018},
	{"FRESCO", 6, 69019},
	{"RUNDOWN", 7, 69020},
	{"AUTEUR", 6, 69021},
	{"CUSTARD", 7, 69022},
	{"CARBONDALE", 10, 69023},
	{"TYDR", 4, 69024},
	{"ODGO", 4, 69025},
	{"PRIUS", 5, 69026},
	{"NLEW", 4, 69027},
	{"GIZMOS", 6, 69028},
	{"BRANCHED", 8, 69029},
	{"EFFINGHAM", 9, 69030},
	{"YJOE", 4, 69031},
	{"WCAM", 4, 69032},
	{"SHIPBUILDING", 12, 69033},
	{"MILDEW", 6, 69034},
	{"TOMBS", 5, 69035},
	{"GNSW", 4, 69036},
	{"AKIR", 4, 69037},
	{"AGUS", 4, 69038},
	{"WPV", 3, 69039},
	{"UCD", 3, 69040},
	{"DOWLING", 7, 69041},
	{"FULFILMENT", 10, 69042},
	{"ACCORDS", 7, 69043},
	{"UCCU", 4, 69044},
	{"PSDO", 4, 69045},
	{"AFOC", 4, 69046},
	{"MITAC", 5, 69047},
	{"STEELS", 6, 69048},
	{"PRIVY", 5, 69049},
	{"ECOB", 4, 69050},
	{"OAKDALE", 7, 69051},
	{"CARETAKER", 9, 69052},
	{"ANTONIA", 7, 69053},
	{"MYSTIQUE", 8, 69054},
	{"FEEBLE", 6, 69055},
	{"GENTILE", 7, 69056},
	{"CORTISLIM", 9, 69057},
	{"KTOY", 4, 69058},
	{"HABB", 4, 69059},
	{"ELTC", 4, 69060},
	{"CONTRACTIONS", 12, 69061},
	{"DISP", 4, 69062},
	{"LOADERS", 7, 69063},
	{"TROUSER", 7, 69064},
	{"COMBATANTS", 10, 69065},
	{"KMSO", 4, 69066},
	{"HYWH", 4, 69067},
	{"CHVA", 4, 69068},
	{"MUPT", 4, 69069},
	{"GEDN", 4, 69070},
	{"HOBOKEN", 7, 69071},
	{"ANNUALS", 7, 69072},
	{"SEPIA", 5, 69073},
	{"DIFFERENTIALS", 13, 69074},
	{"LANU", 4, 69075},
	{"GECU", 4, 69076},
	{"CNAB", 4, 69077},
	{"CHAMPLAIN", 9, 69078},
	{"VALENCE", 7, 69079},
	{"HDEB", 4, 69080},
	{"AKYA", 4, 69081},
	{"DETERIORATED", 12, 69082},
	{"DANCEHALL", 9, 69083},
	{"IGPR", 4, 69084},
	{"SARAJEVO", 8, 69085},
	{"DROITS", 6, 69086},
	{"BRAVA", 5, 69087},
	{"DGEU", 4, 69088},
	{"DISOBEDIENCE", 12, 69089},
	{"UNDERSCORES", 11, 69090},
	{"ROADSHOW", 8, 69091},
	{"GILM", 4, 69092},
	{"UNPACK", 6, 69093},
	{"DSKA", 4, 69094},
	{"SABAH", 5, 69095},
	{"DIVINATION", 10, 69096},
	{"NATIONALITIES", 13, 69097},
	{"CULTIVATING", 11, 69098},
	{"OUAB", 4, 69099},
	{"GACE", 4, 69100},
	{"RUSSEL", 6, 69101},
	{"BYIM", 4, 69102},
	{"APEU", 4, 69103},
	{"NEPHROLOGY", 10, 69104},
	{"AOFB", 4, 69105},
	{"SQUAMOUS", 8, 69106},
	{"WHUN", 4, 69107},
	{"RTEB", 4, 69108},
	{"BSBU", 4, 69109},
	{"MALDEN", 6, 69110},
	{"USEJ", 4, 69111},
	{"UPBR", 4, 69112},
	{"ORISSA", 6, 69113},
	{"TRIUMPHANT", 10, 69114},
	{"RYSK", 4, 69115},
	{"FINW", 4, 69116},
	{"VFR", 3, 69117},
	{"SUPERBLY", 8, 69118},
	{"OXCH", 4, 69119},
	{"CHIANTI", 7, 69120},
	{"HOMBRES", 7, 69121},
	{"MINSK", 5, 69122},
	{"COFFEY", 6, 69123},
	{"YREH", 4, 69124},
	{"LTYB", 4, 69125},
	{"DOMESTICALLY", 12, 69126},
	{"CONSTRAIN", 9, 69127},
	{"ZZIE", 4, 69128},
	{"WETL", 4, 69129},
	{"LIRT", 4, 69130},
	{"QANTAS", 6, 69131},
	{"YTWE", 4, 69132},
	{"RBYD", 4, 69133},
	{"FBOR", 4, 69134},
	{"BRANDI", 6, 69135},
	{"ARTEFACTS", 9, 69136},
	{"DOXC", 4, 69137},
	{"SOLIHULL", 8, 69138},
	{"TATION", 6, 69139},
	{"MAGICIANS", 9, 69140},
	{"TCHAIKOVSKY", 11, 69141},
	{"HOBBES", 6, 69142},
	{"CONTENDED", 9, 69143},
	{"WECH", 4, 69144},
	{"LROC", 4, 69145},
	{"CHEQ", 4, 69146},
	{"NAZARENE", 8, 69147},
	{"REFINERIES", 10, 69148},
	{"TGUE", 4, 69149},
	{"ODYK", 4, 69150},
	{"KMOF", 4, 69151},
	{"CBEC", 4, 69152},
	{"RONAN", 5, 69153},
	{"PRICEWATERHOUSECOOPERS", 22, 69154},
	{"SWIMSUITS", 9, 69155},
	{"AUTOMATES", 9, 69156},
	{"SBOL", 4, 69157},
	{"DELG", 4, 69158},
	{"POTSDAM", 7, 69159},
	{"WYLIE", 5, 69160},
	{"IODF", 4, 69161},
	{"EGYA", 4, 69162},
	{"DDRY", 4, 69163},
	{"ASUL", 4, 69164},
	{"WHOMEVER", 8, 69165},
	{"GENEVIEVE", 9, 69166},
	{"SHILOH", 6, 69167},
	{"DAMPER", 6, 69168},
	{"SIDELINES", 9, 69169},
	{"OUKI", 4, 69170},
	{"AFRIKA", 6, 69171},
	{"SHAFFER", 7, 69172},
	{"LDOA", 4, 69173},
	{"TOOLBARS", 8, 69174},
	{"UZJ", 3, 69175},
	{"UXX", 3, 69176},
	{"NKLA", 4, 69177},
	{"PRESERVATIVES", 13, 69178},
	{"KSBO", 4, 69179},
	{"IDOB", 4, 69180},
	{"ICYS", 4, 69181},
	{"WAGGA", 5, 69182},
	{"WDAN", 4, 69183},
	{"KENAI", 5, 69184},
	{"BOBS", 4, 69185},
	{"OLCL", 4, 69186},
	{"NOBV", 4, 69187},
	{"MORTENSEN", 9, 69188},
	{"FORGIVING", 9, 69189},
	{"UNPLANNED", 9, 69190},
	{"CHARACTERISATION", 16, 69191},
	{"GKIL", 4, 69192},
	{"YAHWEH", 6, 69193},
	{"WUPO", 4, 69194},
	{"UEDR", 4, 69195},
	{"MADMAN", 6, 69196},
	{"PEERING", 7, 69197},
	{"FOPEN", 5, 69198},
	{"SHBY", 4, 69199},
	{"EWBY", 4, 69200},
	{"SLUMBER", 7, 69201},
	{"SHIMMERING", 10, 69202},
	{"WMISSING", 8, 69203},
	{"WDIN", 4, 69204},
	{"SSLU", 4, 69205},
	{"ICEK", 4, 69206},
	{"RIGIDITY", 8, 69207},
	{"MARIUS", 6, 69208},
	{"LDFU", 4, 69209},
	{"GMOU", 4, 69210},
	{"RUDD", 4, 69211},
	{"INVENTING", 9, 69212},
	{"BOURKE", 6, 69213},
	{"KUPW", 4, 69214},
	{"CHIPPED", 7, 69215},
	{"PELVIS", 6, 69216},
	{"GOODMANS", 8, 69217},
	{"POTLUCK", 7, 69218},
	{"IOFFER", 6, 69219},
	{"CIAL", 4, 69220},
	{"DAVIDOFF", 8, 69221},
	{"CREAMER", 7, 69222},
	{"FORTS", 5, 69223},
	{"ULEC", 4, 69224},
	{"TUMBLING", 8, 69225},
	{"CONTAX", 6, 69226},
	{"FDRE", 4, 69227},
	{"COLUMBINE", 9, 69228},
	{"PORTABLES", 9, 69229},
	{"INTERPRETS", 10, 69230},
	{"FLEDGED", 7, 69231},
	{"URVA", 4, 69232},
	{"IRKE", 4, 69233},
	{"BGRO", 4, 69234},
	{"ADHU", 4, 69235},
	{"AQUINAS", 7, 69236},
	{"KIDZ", 4, 69237},
	{"EDONKEY", 7, 69238},
	{"SURAT", 5, 69239},
	{"IRHU", 4, 69240},
	{"HOURGLASS", 9, 69241},
	{"DORMITORY", 9, 69242},
	{"PAGETOP", 7, 69243},
	{"PALOMA", 6, 69244},
	{"CONFISCATED", 11, 69245},
	{"DISCHARGING", 11, 69246},
	{"GUNMEN", 6, 69247},
	{"LRYA", 4, 69248},
	{"DISABLES", 8, 69249},
	{"WNCL", 4, 69250},
	{"FBUD", 4, 69251},
	{"SSANGYONG", 9, 69252},
	{"ANTIRETROVIRAL", 14, 69253},
	{"PBAS", 4, 69254},
	{"MOBA", 4, 69255},
	{"MOSCHINO", 8, 69256},
	{"LOCKPORT", 8, 69257},
	{"PITTSFIELD", 10, 69258},
	{"POLLACK", 7, 69259},
	{"LTBU", 4, 69260},
	{"HOYLE", 5, 69261},
	{"AROUSAL", 7, 69262},
	{"UNNOTICED", 9, 69263},
	{"RIDICULE", 8, 69264},
	{"DJEA", 4, 69265},
	{"VANDALS", 7, 69266},
	{"INHIBITING", 10, 69267},
	{"REINSTATED", 10, 69268},
	{"LIZZY", 5, 69269},
	{"UNPACKING", 9, 69270},
	{"KLYW", 4, 69271},
	{"DARIEN", 6, 69272},
	{"INTERSECT", 9, 69273},
	{"FINDEN", 6, 69274},
	{"RTIU", 4, 69275},
	{"PSTU", 4, 69276},
	{"MAMMARY", 7, 69277},
	{"ICSG", 4, 69278},
	{"ACYP", 4, 69279},
	{"JANVIER", 7, 69280},
	{"TRAMPOLINES", 11, 69281},
	{"EMUD", 4, 69282},
	{"HILLMAN", 7, 69283},
	{"GARNISH", 7, 69284},
	{"DESIGNATES", 10, 69285},
	{"WPOW", 4, 69286},
	{"UTBL", 4, 69287},
	{"RLAM", 4, 69288},
	{"HEXM", 4, 69289},
	{"GHVA", 4, 69290},
	{"TRIMMERS", 8, 69291},
	{"PEELING", 7, 69292},
	{"LEVIS", 5, 69293},
	{"RGYW", 4, 69294},
	{"CEFF", 4, 69295},
	{"BLINDLY", 7, 69296},
	{"BRIDGESTONE", 11, 69297},
	{"RJEN", 4, 69298},
	{"BBYS", 4, 69299},
	{"UNINTENTIONAL", 13, 69300},
	{"DURANT", 6, 69301},
	{"UOSW", 4, 69302},
	{"RUPO", 4, 69303},
	{"REPERTORY", 9, 69304},
	{"MUVO", 4, 69305},
	{"NIRR", 4, 69306},
	{"WCITIES", 7, 69307},
	{"DIDDY", 5, 69308},
	{"CONVEYANCING", 12, 69309},
	{"DISAGREEMENTS", 13, 69310},
	{"LMPR", 4, 69311},
	{"NKPE", 4, 69312},
	{"LDSR", 4, 69313},
	{"FTHG", 4, 69314},
	{"ECHINACEA", 9, 69315},
	{"PHISH", 5, 69316},
	{"FRIGIDAIRE", 10, 69317},
	{"VEIF", 4, 69318},
	{"RKCH", 4, 69319},
	{"CHJA", 4, 69320},
	{"RMSR", 4, 69321},
	{"OMCU", 4, 69322},
	{"ECAK", 4, 69323},
	{"DATK", 4, 69324},
	{"HALIBUT", 7, 69325},
	{"FIFTIES", 7, 69326},
	{"SDIM", 4, 69327},
	{"CKOV", 4, 69328},
	{"PENRITH", 7, 69329},
	{"POGR", 4, 69330},
	{"BRNO", 4, 69331},
	{"SILVERWARE", 10, 69332},
	{"TEOMA", 5, 69333},
	{"YPRU", 4, 69334},
	{"RAML", 4, 69335},
	{"RCRA", 4, 69336},
	{"UILA", 4, 69337},
	{"RHIR", 4, 69338},
	{"HTGR", 4, 69339},
	{"GOODY", 5, 69340},
	{"UGEO", 4, 69341},
	{"DMYC", 4, 69342},
	{"IDEOLOGIES", 10, 69343},
	{"FEMINISTS", 9, 69344},
	{"UOSM", 4, 69345},
	{"GOVA", 4, 69346},
	{"FFF", 3, 69347},
	{"RMEC", 4, 69348},
	{"IKOV", 4, 69349},
	{"FICN", 4, 69350},
	{"SCULPTED", 8, 69351},
	{"EMBO", 4, 69352},
	{"DUGOUT", 6, 69353},
	{"BATTLESHIP", 10, 69354},
	{"ULAF", 4, 69355},
	{"LIAF", 4, 69356},
	{"ROLLIN", 6, 69357},
	{"CONTRAINDICATIONS", 17, 69358},
	{"OFEW", 4, 69359},
	{"TALISMAN", 8, 69360},
	{"REBUTTAL", 8, 69361},
	{"UPOU", 4, 69362},
	{"UNDERSIDE", 9, 69363},
	{"BLACKWOOD", 9, 69364},
	{"ALUMNUS", 7, 69365},
	{"ARCHEOLOGY", 10, 69366},
	{"PREISE", 6, 69367},
	{"WLYR", 4, 69368},
	{"ONTOLOGIES", 10, 69369},
	{"RPSO", 4, 69370},
	{"FENDERS", 7, 69371},
	{"FRISBEE", 7, 69372},
	{"HMMMM", 5, 69373},
	{"GIGGLE", 6, 69374},
	{"HYPERACTIVITY", 13, 69375},
	{"SEAGULL", 7, 69376},
	{"WORDEN", 6, 69377},
	{"NANOTUBES", 9, 69378},
	{"POLOS", 5, 69379},
	{"BONAIRE", 7, 69380},
	{"UDYF", 4, 69381},
	{"GYST", 4, 69382},
	{"GEGI", 4, 69383},
	{"HEHEHE", 6, 69384},
	{"REECE", 5, 69385},
	{"ELSIF", 5, 69386},
	{"SPINNERS", 8, 69387},
	{"WJUS", 4, 69388},
	{"PAYL", 4, 69389},
	{"MILN", 4, 69390},
	{"PZU", 3, 69391},
	{"PXV", 3, 69392},
	{"DEFORESTATION", 13, 69393},
	{"ANNEALING", 9, 69394},
	{"MAXIMIZES", 9, 69395},
	{"STREAKS", 7, 69396},
	{"RODERICK", 8, 69397},
	{"CORINTH", 7, 69398},
	{"PERVERSE", 8, 69399},
	{"HAFU", 4, 69400},
	{"GLITTERING", 10, 69401},
	{"PLD", 3, 69402},
	{"NHUG", 4, 69403},
	{"EURASIA", 7, 69404},
	{"JAILS", 5, 69405},
	{"ZZAN", 4, 69406},
	{"RMDA", 4, 69407},
	{"NZYM", 4, 69408},
	{"CASKET", 6, 69409},
	{"BRIGITTE", 8, 69410},
	{"DICKEY", 6, 69411},
	{"AFTD", 4, 69412},
	{"DETOUR", 6, 69413},
	{"MYGU", 4, 69414},
	{"GHDO", 4, 69415},
	{"DUMO", 4, 69416},
	{"COBU", 4, 69417},
	{"BANM", 4, 69418},
	{"ALKF", 4, 69419},
	{"CARPETING", 9, 69420},
	{"YORKERS", 7, 69421},
	{"EUKARYOTIC", 10, 69422},
	{"IRDY", 4, 69423},
	{"BEXLEY", 6, 69424},
	{"HUSBANDRY", 9, 69425},
	{"BREMER", 6, 69426},
	{"MARISA", 6, 69427},
	{"RMAH", 4, 69428},
	{"MORL", 4, 69429},
	{"MELV", 4, 69430},
	{"EBUB", 4, 69431},
	{"FRUSTRATIONS", 12, 69432},
	{"VISIBLY", 7, 69433},
	{"DELGADO", 7, 69434},
	{"DEFUNCT", 7, 69435},
	{"VYCO", 4, 69436},
	{"DICR", 4, 69437},
	{"CGOV", 4, 69438},
	{"RESECTION", 9, 69439},
	{"DIOXIN", 6, 69440},
	{"ISLAMIST", 8, 69441},
	{"UNVEIL", 6, 69442},
	{"CIRCULARS", 9, 69443},
	{"BRANT", 5, 69444},
	{"KUBRICK", 7, 69445},
	{"FCOS", 4, 69446},
	{"IFAX", 4, 69447},
	{"EOCL", 4, 69448},
	{"TOUCHSCREEN", 11, 69449},
	{"LAYOFF", 6, 69450},
	{"FACELIFT", 8, 69451},
	{"DECODED", 7, 69452},
	{"GRY", 3, 69453},
	{"UOSL", 4, 69454},
	{"SOBY", 4, 69455},
	{"NYAB", 4, 69456},
	{"NDOY", 4, 69457},
	{"ITUL", 4, 69458},
	{"DODGER", 6, 69459},
	{"MERCIFUL", 8, 69460},
	{"YSAU", 4, 69461},
	{"YAMB", 4, 69462},
	{"DUSS", 4, 69463},
	{"CTEV", 4, 69464},
	{"LESSIG", 6, 69465},
	{"CYME", 4, 69466},
	{"THMR", 4, 69467},
	{"CBUI", 4, 69468},
	{"TIPPERARY", 9, 69469},
	{"REVELL", 6, 69470},
	{"SCHED", 5, 69471},
	{"RPGS", 4, 69472},
	{"MNOV", 4, 69473},
	{"EXWA", 4, 69474},
	{"KINSHIP", 7, 69475},
	{"SPRINGTIME", 10, 69476},
	{"EUPHORIA", 8, 69477},
	{"ACUITY", 6, 69478},
	{"POPPER", 6, 69479},
	{"MDRI", 4, 69480},
	{"KYIN", 4, 69481},
	{"CHSW", 4, 69482},
	{"PHILIPP", 7, 69483},
	{"LOCKDOWN", 8, 69484},
	{"YJAI", 4, 69485},
	{"TRANSMITTAL", 11, 69486},
	{"BLOUSES", 7, 69487},
	{"HEATSINK", 8, 69488},
	{"ASSHOLES", 8, 69489},
	{"HAYMAN", 6, 69490},
	{"EQUILIBRIA", 10, 69491},
	{"REQUESTER", 9, 69492},
	{"HEMLOCK", 7, 69493},
	{"SKYB", 4, 69494},
	{"NUSF", 4, 69495},
	{"NDSV", 4, 69496},
	{"SNIFFING", 8, 69497},
	{"ODOP", 4, 69498},
	{"ALLRECIPES", 10, 69499},
	{"SERIALIZED", 10, 69500},
	{"HANGZHOU", 8, 69501},
	{"ZLES", 4, 69502},
	{"BJORK", 5, 69503},
	{"UNCANNY", 7, 69504},
	{"STRINGER", 8, 69505},
	{"YASD", 4, 69506},
	{"RSWR", 4, 69507},
	{"ROWP", 4, 69508},
	{"PEXP", 4, 69509},
	{"OMFU", 4, 69510},
	{"EWIM", 4, 69511},
	{"CEBL", 4, 69512},
	{"NANJING", 7, 69513},
	{"XUY", 3, 69514},
	{"GAPB", 4, 69515},
	{"BELC", 4, 69516},
	{"MILLIGRAMS", 10, 69517},
	{"SNOHOMISH", 9, 69518},
	{"STORK", 5, 69519},
	{"KAYL", 4, 69520},
	{"STRATHCLYDE", 11, 69521},
	{"YOKO", 4, 69522},
	{"NDCY", 4, 69523},
	{"MEIL", 4, 69524},
	{"INTRAMURAL", 10, 69525},
	{"LPSH", 4, 69526},
	{"CURATED", 7, 69527},
	{"FINALISED", 9, 69528},
	{"XMAR", 4, 69529},
	{"COMBUSTIBLE", 11, 69530},
	{"FALLACY", 7, 69531},
	{"IRRU", 4, 69532},
	{"CDD", 3, 69533},
	{"GUND", 4, 69534},
	{"TASCAM", 6, 69535},
	{"UBAL", 4, 69536},
	{"FTEM", 4, 69537},
	{"NICKNAMES", 9, 69538},
	{"HARDSTYLE", 9, 69539},
	{"ARUN", 4, 69540},
	{"FSYS", 4, 69541},
	{"WAISTBAND", 9, 69542},
	{"NOXIOUS", 7, 69543},
	{"FIBROBLASTS", 11, 69544},
	{"HTJU", 4, 69545},
	{"TUNIC", 5, 69546},
	{"FARCE", 5, 69547},
	{"TSGU", 4, 69548},
	{"MBAU", 4, 69549},
	{"LEANDRO", 7, 69550},
	{"DROWSINESS", 10, 69551},
	{"YADJ", 4, 69552},
	{"WAIR", 4, 69553},
	{"UGAD", 4, 69554},
	{"OLTZ", 4, 69555},
	{"AWDE", 4, 69556},
	{"METASTASIS", 10, 69557},
	{"RKIM", 4, 69558},
	{"USERPICS", 8, 69559},
	{"GREENBELT", 9, 69560},
	{"CHANTS", 6, 69561},
	{"ULYD", 4, 69562},
	{"OBBS", 4, 69563},
	{"LEUVEN", 6, 69564},
	{"RHONE", 5, 69565},
	{"PRINTK", 6, 69566},
	{"LUNATIC", 7, 69567},
	{"RMYP", 4, 69568},
	{"REACHABLE", 9, 69569},
	{"UMLE", 4, 69570},
	{"PYRENEES", 8, 69571},
	{"LPPR", 4, 69572},
	{"RADIOACTIVITY", 13, 69573},
	{"AUCTIONEER", 10, 69574},
	{"CAINE", 5, 69575},
	{"RECOVERS", 8, 69576},
	{"GYFER", 5, 69577},
	{"BOCH", 4, 69578},
	{"HOWDY", 5, 69579},
	{"MGOO", 4, 69580},
	{"IXER", 4, 69581},
	{"MARLON", 6, 69582},
	{"TIMMY", 5, 69583},
	{"LIGA", 4, 69584},
	{"YJUM", 4, 69585},
	{"EJUI", 4, 69586},
	{"GREGORIAN", 9, 69587},
	{"HAGGARD", 7, 69588},
	{"LUEH", 4, 69589},
	{"AYGI", 4, 69590},
	{"AUDR", 4, 69591},
	{"REORDER", 7, 69592},
	{"AEROSOLS", 8, 69593},
	{"MANGER", 6, 69594},
	{"ARCHEOLOGICAL", 13, 69595},
	{"NGMR", 4, 69596},
	{"FTBU", 4, 69597},
	{"DVES", 4, 69598},
	{"BYEI", 4, 69599},
	{"LOGARITHMIC", 11, 69600},
	{"LMSH", 4, 69601},
	{"BETU", 4, 69602},
	{"ADPI", 4, 69603},
	{"ROBBY", 5, 69604},
	{"COMPLETIONS", 11, 69605},
	{"YEARNING", 8, 69606},
	{"TRANSPORTERS", 12, 69607},
	{"YUNP", 4, 69608},
	{"SANDALWOOD", 10, 69609},
	{"MEGS", 4, 69610},
	{"CHILLS", 6, 69611},
	{"WHACK", 5, 69612},
	{"NLIC", 4, 69613},
	{"DRONE", 5, 69614},
	{"UPAD", 4, 69615},
	{"UEPO", 4, 69616},
	{"MEDK", 4, 69617},
	{"BCRE", 4, 69618},
	{"RAPIDSHARE", 10, 69619},
	{"OMSL", 4, 69620},
	{"OLKL", 4, 69621},
	{"KLYP", 4, 69622},
	{"BREEZES", 7, 69623},
	{"OOLU", 4, 69624},
	{"LUSB", 4, 69625},
	{"KLEF", 4, 69626},
	{"EAKM", 4, 69627},
	{"OMNIBOOK", 8, 69628},
	{"ESTEEMED", 8, 69629},
	{"GODLY", 5, 69630},
	{"OBAG", 4, 69631},
	{"MUMP", 4, 69632},
	{"GTWI", 4, 69633},
	{"SPIRE", 5, 69634},
	{"DISTILLATION", 12, 69635},
	{"EDGING", 6, 69636},
	{"GAMEPRO", 7, 69637},
	{"LANGDON", 7, 69638},
	{"MATHEMATICIANS", 14, 69639},
	{"DECONTAMINATION", 15, 69640},
	{"TAMIYA", 6, 69641},
	{"UTOW", 4, 69642},
	{"MYTA", 4, 69643},
	{"DTAM", 4, 69644},
	{"RLBO", 4, 69645},
	{"EUCLIDEAN", 9, 69646},
	{"CYMBALS", 7, 69647},
	{"SALINA", 6, 69648},
	{"ANTIDOTE", 8, 69649},
	{"EMBLEMS", 7, 69650},
	{"NJUA", 4, 69651},
	{"AYRU", 4, 69652},
	{"CARICATURE", 10, 69653},
	{"JVW", 3, 69654},
	{"WOODFORD", 8, 69655},
	{"FORMALISM", 9, 69656},
	{"SHROUD", 6, 69657},
	{"WCEN", 4, 69658},
	{"OWOP", 4, 69659},
	{"ACHING", 6, 69660},
	{"AUDIGY", 6, 69661},
	{"LIBEXEC", 7, 69662},
	{"STEAD", 5, 69663},
	{"RECOIL", 6, 69664},
	{"YRER", 4, 69665},
	{"FGOA", 4, 69666},
	{"EYEPIECE", 8, 69667},
	{"RECONCILED", 10, 69668},
	{"DAZE", 4, 69669},
	{"PMMO", 4, 69670},
	{"FSAF", 4, 69671},
	{"CMAH", 4, 69672},
	{"RAISIN", 6, 69673},
	{"BIBL", 4, 69674},
	{"TELM", 4, 69675},
	{"EMIM", 4, 69676},
	{"BOBCAT", 6, 69677},
	{"FREEHAND", 8, 69678},
	{"YAMU", 4, 69679},
	{"ROUC", 4, 69680},
	{"NUGENT", 6, 69681},
	{"VEYT", 4, 69682},
	{"METB", 4, 69683},
	{"KILLEEN", 7, 69684},
	{"AMOUNTING", 9, 69685},
	{"JAMMING", 7, 69686},
	{"SCHON", 5, 69687},
	{"RGHI", 4, 69688},
	{"PLYL", 4, 69689},
	{"APPLICATOR", 10, 69690},
	{"ICRC", 4, 69691},
	{"RSKY", 4, 69692},
	{"MEZZANINE", 9, 69693},
	{"BOER", 4, 69694},
	{"POISONS", 7, 69695},
	{"EPAW", 4, 69696},
	{"MEGHAN", 6, 69697},
	{"CUPERTINO", 9, 69698},
	{"NAMELESS", 8, 69699},
	{"LOGFILE", 7, 69700},
	{"KISB", 4, 69701},
	{"MCUR", 4, 69702},
	{"HUMIDIFIER", 10, 69703},
	{"PADILLA", 7, 69704},
	{"PTRU", 4, 69705},
	{"IPSU", 4, 69706},
	{"IARM", 4, 69707},
	{"ARNW", 4, 69708},
	{"SUSANNE", 7, 69709},
	{"COLLAPSES", 9, 69710},
	{"MUSICALLY", 9, 69711},
	{"YUNG", 4, 69712},
	{"INTENSIFY", 9, 69713},
	{"VOLTAIRE", 8, 69714},
	{"LONGWOOD", 8, 69715},
	{"KRW", 3, 69716},
	{"HARMONIES", 9, 69717},
	{"BENITO", 6, 69718},
	{"LYEI", 4, 69719},
	{"MAINSTAY", 8, 69720},
	{"DESCR", 5, 69721},
	{"OMCI", 4, 69722},
	{"FAGI", 4, 69723},
	{"INDEBTED", 8, 69724},
	{"WALD", 4, 69725},
	{"ATCC", 4, 69726},
	{"TASMAN", 6, 69727},
	{"BREATHED", 8, 69728},
	{"OKAM", 4, 69729},
	{"ACCESSOIRES", 11, 69730},
	{"MUCOSA", 6, 69731},
	{"NSKR", 4, 69732},
	{"ILYV", 4, 69733},
	{"IDRU", 4, 69734},
	{"DACHSHUND", 9, 69735},
	{"SYRINGES", 8, 69736},
	{"MISLED", 6, 69737},
	{"GFAL", 4, 69738},
	{"BINW", 4, 69739},
	{"BREAKPOINT", 10, 69740},
	{"TELUS", 5, 69741},
	{"OOFM", 4, 69742},
	{"ITDU", 4, 69743},
	{"STONEY", 6, 69744},
	{"CULPRIT", 7, 69745},
	{"RNJU", 4, 69746},
	{"PANZ", 4, 69747},
	{"TRANSACT", 8, 69748},
	{"NEPALI", 6, 69749},
	{"LYIW", 4, 69750},
	{"BILLIG", 6, 69751},
	{"REGIMENS", 8, 69752},
	{"TMYE", 4, 69753},
	{"NBAU", 4, 69754},
	{"COER", 4, 69755},
	{"CANOLA", 6, 69756},
	{"WZZ", 3, 69757},
	{"WXR", 3, 69758},
	{"QLW", 3, 69759},
	{"KRX", 3, 69760},
	{"SLICING", 7, 69761},
	{"KLEB", 4, 69762},
	{"GIOV", 4, 69763},
	{"REPRODUCIBLE", 12, 69764},
	{"UNKB", 4, 69765},
	{"RYSB", 4, 69766},
	{"EXPERI", 6, 69767},
	{"YVOI", 4, 69768},
	{"SPICED", 6, 69769},
	{"BERNE", 5, 69770},
	{"SKYDIVING", 9, 69771},
	{"TBYG", 4, 69772},
	{"MORW", 4, 69773},
	{"MCGU", 4, 69774},
	{"BOGOTA", 6, 69775},
	{"DISCOGS", 7, 69776},
	{"DATAGRAM", 8, 69777},
	{"VIDEOGRAPHERS", 13, 69778},
	{"PRON", 4, 69779},
	{"YSIZ", 4, 69780},
	{"YDOO", 4, 69781},
	{"LGIN", 4, 69782},
	{"NICKS", 5, 69783},
	{"PUNCTURE", 8, 69784},
	{"PLATELETS", 9, 69785},
	{"UTPM", 4, 69786},
	{"RMFR", 4, 69787},
	{"NRAV", 4, 69788},
	{"NELLA", 5, 69789},
	{"TRANNIES", 8, 69790},
	{"LIGHTEN", 7, 69791},
	{"YSRI", 4, 69792},
	{"DRMA", 4, 69793},
	{"PAMPER", 6, 69794},
	{"PRACTISED", 9, 69795},
	{"UNKT", 4, 69796},
	{"UADI", 4, 69797},
	{"CANTEEN", 7, 69798},
	{"NINETIES", 8, 69799},
	{"BRACKNELL", 9, 69800},
	{"UROB", 4, 69801},
	{"HYSTERICAL", 10, 69802},
	{"FICK", 4, 69803},
	{"DISINFECTION", 12, 69804},
	{"PERFUSION", 9, 69805},
	{"DARKENED", 8, 69806},
	{"REQUISITION", 11, 69807},
	{"UPSL", 4, 69808},
	{"UMNE", 4, 69809},
	{"POSTSEASON", 10, 69810},
	{"TIGERDIRECT", 11, 69811},
	{"DANF", 4, 69812},
	{"BOILS", 5, 69813},
	{"ENCHANTMENT", 11, 69814},
	{"SMOOTHIE", 8, 69815},
	{"GJUN", 4, 69816},
	{"BYED", 4, 69817},
	{"GRETA", 5, 69818},
	{"COVEY", 5, 69819},
	{"PUNISHER", 8, 69820},
	{"DONNE", 5, 69821},
	{"TABBED", 6, 69822},
	{"ALENE", 5, 69823},
	{"LKEY", 4, 69824},
	{"FUNW", 4, 69825},
	{"FCIN", 4, 69826},
	{"LISMORE", 7, 69827},
	{"COQUITLAM", 9, 69828},
	{"AUCTIONEERS", 11, 69829},
	{"SOMETHIN", 8, 69830},
	{"UDAS", 4, 69831},
	{"DANIELA", 7, 69832},
	{"LOATHING", 8, 69833},
	{"UPTU", 4, 69834},
	{"DUC", 3, 69835},
	{"DIALS", 5, 69836},
	{"ENHYDRA", 7, 69837},
	{"KYRGYZ", 6, 69838},
	{"BIANCHI", 7, 69839},
	{"BUSCADOR", 8, 69840},
	{"ROADRUNNER", 10, 69841},
	{"BLACKHAWKS", 10, 69842},
	{"WOOF", 4, 69843},
	{"OMINOUS", 7, 69844},
	{"MISFITS", 7, 69845},
	{"QUIKSILVER", 10, 69846},
	{"PARLOUR", 7, 69847},
	{"LFMI", 4, 69848},
	{"HAMMOCKS", 8, 69849},
	{"QUIETER", 7, 69850},
	{"RUMT", 4, 69851},
	{"CTLO", 4, 69852},
	{"SQLITE", 6, 69853},
	{"POKING", 6, 69854},
	{"TARANTINO", 9, 69855},
	{"ADDI", 4, 69856},
	{"BUYOUT", 6, 69857},
	{"YYES", 4, 69858},
	{"PSLA", 4, 69859},
	{"LMSS", 4, 69860},
	{"ELTB", 4, 69861},
	{"AYID", 4, 69862},
	{"REPLAYS", 7, 69863},
	{"ADRENERGIC", 10, 69864},
	{"BOTTLING", 8, 69865},
	{"TWRE", 4, 69866},
	{"OLLR", 4, 69867},
	{"CALDERA", 7, 69868},
	{"BASEMAN", 7, 69869},
	{"HUSW", 4, 69870},
	{"BOTANICALS", 10, 69871},
	{"TECHIE", 6, 69872},
	{"FARR", 4, 69873},
	{"TALLEST", 7, 69874},
	{"VTECH", 5, 69875},
	{"WRESTLE", 7, 69876},
	{"OCKV", 4, 69877},
	{"LAOF", 4, 69878},
	{"BONC", 4, 69879},
	{"DONDE", 5, 69880},
	{"ENTRENCHED", 10, 69881},
	{"BEYER", 5, 69882},
	{"VERSIONTRACKER", 14, 69883},
	{"WEPA", 4, 69884},
	{"IMCH", 4, 69885},
	{"EMCL", 4, 69886},
	{"RECTIFY", 7, 69887},
	{"HUSM", 4, 69888},
	{"VIRTUOUS", 8, 69889},
	{"HASHCODE", 8, 69890},
	{"TRADESHOW", 9, 69891},
	{"LEWISVILLE", 10, 69892},
	{"ASTER", 5, 69893},
	{"TRANSPARENCIES", 14, 69894},
	{"DAVY", 4, 69895},
	{"BLOOMINGDALE", 12, 69896},
	{"LWIS", 4, 69897},
	{"NORTHROP", 8, 69898},
	{"SNAILS", 6, 69899},
	{"NBLE", 4, 69900},
	{"ILDD", 4, 69901},
	{"DECIPHER", 8, 69902},
	{"WJF", 3, 69903},
	{"LXU", 3, 69904},
	{"INCAPACITY", 10, 69905},
	{"MITTENS", 7, 69906},
	{"REVO", 4, 69907},
	{"TYSR", 4, 69908},
	{"OVERKILL", 8, 69909},
	{"NLRB", 4, 69910},
	{"WLYB", 4, 69911},
	{"KYIS", 4, 69912},
	{"FERNS", 5, 69913},
	{"LAZIO", 5, 69914},
	{"CURLS", 5, 69915},
	{"DIAG", 4, 69916},
	{"RKSR", 4, 69917},
	{"CHIAPAS", 7, 69918},
	{"DYBY", 4, 69919},
	{"TMEG", 4, 69920},
	{"IMFA", 4, 69921},
	{"FREEDICT", 8, 69922},
	{"DISPONIBLE", 10, 69923},
	{"MORISSETTE", 10, 69924},
	{"LEIW", 4, 69925},
	{"EFFORTLESS", 10, 69926},
	{"HYDROELECTRIC", 13, 69927},
	{"RADH", 4, 69928},
	{"CRANIAL", 7, 69929},
	{"HINDSIGHT", 9, 69930},
	{"WRECKED", 7, 69931},
	{"WINCE", 5, 69932},
	{"EYFL", 4, 69933},
	{"ORIENTATED", 10, 69934},
	{"FRIENDLINESS", 12, 69935},
	{"ABRASIVES", 9, 69936},
	{"INVINCIBLE", 10, 69937},
	{"LTIF", 4, 69938},
	{"ILBY", 4, 69939},
	{"HEALTHIEST", 10, 69940},
	{"SAWW", 4, 69941},
	{"AJUR", 4, 69942},
	{"FPC", 3, 69943},
	{"PROMETHEUS", 10, 69944},
	{"RPON", 4, 69945},
	{"NRYI", 4, 69946},
	{"BRL", 3, 69947},
	{"VPNS", 4, 69948},
	{"RUSHES", 6, 69949},
	{"DEITIES", 7, 69950},
	{"FEINGOLD", 8, 69951},
	{"THUNDERBIRDS", 12, 69952},
	{"GLAZ", 4, 69953},
	{"GEOG", 4, 69954},
	{"COMANCHE", 8, 69955},
	{"WOFU", 4, 69956},
	{"UXOF", 4, 69957},
	{"LETB", 4, 69958},
	{"GHOP", 4, 69959},
	{"MELTS", 5, 69960},
	{"HARRAH", 6, 69961},
	{"TRICKLE", 7, 69962},
	{"WXGA", 4, 69963},
	{"DISAPPROVE", 10, 69964},
	{"NMFS", 4, 69965},
	{"ERRATIC", 7, 69966},
	{"VILC", 4, 69967},
	{"FAMILIARIZE", 11, 69968},
	{"BOYNTON", 7, 69969},
	{"CASHING", 7, 69970},
	{"TAXF", 4, 69971},
	{"SPOUSAL", 7, 69972},
	{"INSUFFICIENCY", 13, 69973},
	{"ABUSERS", 7, 69974},
	{"TWINLAB", 7, 69975},
	{"VICK", 4, 69976},
	{"SODIMM", 6, 69977},
	{"DRIFTED", 7, 69978},
	{"COPLEY", 6, 69979},
	{"MALLARD", 7, 69980},
	{"TWIKIPREFERENCES", 16, 69981},
	{"AIRMAN", 6, 69982},
	{"LELT", 4, 69983},
	{"KFLO", 4, 69984},
	{"PROPAGATED", 10, 69985},
	{"CONFIGURATOR", 12, 69986},
	{"CLC", 3, 69987},
	{"LEJE", 4, 69988},
	{"HARDSHIPS", 9, 69989},
	{"NEUROBIOLOGY", 12, 69990},
	{"UDYC", 4, 69991},
	{"KTUR", 4, 69992},
	{"SABRES", 6, 69993},
	{"DIAMANTE", 8, 69994},
	{"FORAGING", 8, 69995},
	{"DREAMWORKS", 10, 69996},
	{"CORSETS", 7, 69997},
	{"URAW", 4, 69998},
	{"DOWD", 4, 69999},
	{"WASPS", 5, 70000},
	{"ESCRITURAS", 10, 70001},
	{"BUREAUCRATS", 11, 70002},
	{"SONGTEXT", 8, 70003},
	{"NGMC", 4, 70004},
	{"WHAM", 4, 70005},
	{"PHPGROUPWARE", 12, 70006},
	{"TBID", 4, 70007},
	{"RRYJ", 4, 70008},
	{"IUMD", 4, 70009},
	{"CYCLIN", 6, 70010},
	{"CONYERS", 7, 70011},
	{"CHIEN", 5, 70012},
	{"YOULL", 5, 70013},
	{"NCYE", 4, 70014},
	{"MSEY", 4, 70015},
	{"KOWLOON", 7, 70016},
	{"FAIRYTALE", 9, 70017},
	{"PICKENS", 7, 70018},
	{"BYBEL", 5, 70019},
	{"UOSD", 4, 70020},
	{"FFWO", 4, 70021},
	{"WRES", 4, 70022},
	{"UKEM", 4, 70023},
	{"RCRY", 4, 70024},
	{"KYST", 4, 70025},
	{"BARM", 4, 70026},
	{"DSYN", 4, 70027},
	{"AMPLITUDES", 10, 70028},
	{"NMAP", 4, 70029},
	{"RYU", 3, 70030},
	{"MICROCONTROLLER", 15, 70031},
	{"PREMIERED", 9, 70032},
	{"MITRE", 5, 70033},
	{"PLYN", 4, 70034},
	{"LICG", 4, 70035},
	{"INSTITUTIONALIZED", 17, 70036},
	{"HAMM", 4, 70037},
	{"GYNO", 4, 70038},
	{"BHOPAL", 6, 70039},
	{"TONNAGE", 7, 70040},
	{"CORALS", 6, 70041},
	{"CIRCULATORY", 11, 70042},
	{"RNEM", 4, 70043},
	{"FLUN", 4, 70044},
	{"DOWW", 4, 70045},
	{"CWOU", 4, 70046},
	{"CENTERLINE", 10, 70047},
	{"CHAIRMEN", 8, 70048},
	{"MILLE", 5, 70049},
	{"MPOO", 4, 70050},
	{"DACY", 4, 70051},
	{"GUERLAIN", 8, 70052},
	{"PEDO", 4, 70053},
	{"WBET", 4, 70054},
	{"AFFH", 4, 70055},
	{"HUSSAIN", 7, 70056},
	{"PORTLET", 7, 70057},
	{"CONTINUANCE", 11, 70058},
	{"PROSCAR", 7, 70059},
	{"MPWI", 4, 70060},
	{"HLYO", 4, 70061},
	{"HISTONE", 7, 70062},
	{"OPIOID", 6, 70063},
	{"UNRECOGNIZED", 12, 70064},
	{"TOTALLING", 9, 70065},
	{"PREMIERES", 9, 70066},
	{"PYOBJECT", 8, 70067},
	{"AFFECTIONATE", 12, 70068},
	{"BAPTISTE", 8, 70069},
	{"TEPD", 4, 70070},
	{"TRANSLATIONAL", 13, 70071},
	{"UNIMPORTANT", 11, 70072},
	{"LEHMANN", 7, 70073},
	{"PRAH", 4, 70074},
	{"GUIR", 4, 70075},
	{"FERRARA", 7, 70076},
	{"GREENER", 7, 70077},
	{"BOWLES", 6, 70078},
	{"ENDOWMENTS", 10, 70079},
	{"YPAP", 4, 70080},
	{"YAWO", 4, 70081},
	{"NYVA", 4, 70082},
	{"KEATON", 6, 70083},
	{"GRUDGE", 6, 70084},
	{"ELKINS", 6, 70085},
	{"RTCR", 4, 70086},
	{"JAMISON", 7, 70087},
	{"INTERSTITIAL", 12, 70088},
	{"ZOOLOGICAL", 10, 70089},
	{"TANZANITE", 9, 70090},
	{"HELICAL", 7, 70091},
	{"REDLANDS", 8, 70092},
	{"SAGRADAS", 8, 70093},
	{"FONDUE", 6, 70094},
	{"CAOF", 4, 70095},
	{"NORSE", 5, 70096},
	{"WINDSCREEN", 10, 70097},
	{"BYMR", 4, 70098},
	{"SBYJ", 4, 70099},
	{"OMYR", 4, 70100},
	{"GOFJ", 4, 70101},
	{"WETTING", 7, 70102},
	{"ADDERALL", 8, 70103},
	{"OTHELLO", 7, 70104},
	{"SUPERSONIC", 10, 70105},
	{"POCATELLO", 9, 70106},
	{"BOSOM", 5, 70107},
	{"MANIACS", 7, 70108},
	{"LSMU", 4, 70109},
	{"KYMO", 4, 70110},
	{"SYSADMIN", 8, 70111},
	{"SFYI", 4, 70112},
	{"FOOTHILL", 8, 70113},
	{"EARMARKED", 9, 70114},
	{"HIGHSPEED", 9, 70115},
	{"UNCHECK", 7, 70116},
	{"PEBU", 4, 70117},
	{"IDEJ", 4, 70118},
	{"BALES", 5, 70119},
	{"BLACKBIRD", 9, 70120},
	{"CAUSATION", 9, 70121},
	{"TOWW", 4, 70122},
	{"FADR", 4, 70123},
	{"PERSECUTED", 10, 70124},
	{"VLAD", 4, 70125},
	{"DECIDUOUS", 9, 70126},
	{"LIDG", 4, 70127},
	{"PHOTOSYNTHESIS", 14, 70128},
	{"EMCG", 4, 70129},
	{"EELU", 4, 70130},
	{"EAJU", 4, 70131},
	{"JUNIT", 5, 70132},
	{"REMOTES", 7, 70133},
	{"CONVOCATION", 11, 70134},
	{"LFAB", 4, 70135},
	{"CYBU", 4, 70136},
	{"MCM", 3, 70137},
	{"MERRICK", 7, 70138},
	{"PRECAUTION", 10, 70139},
	{"UCF", 3, 70140},
	{"BUSO", 4, 70141},
	{"NACL", 4, 70142},
	{"PLAYMATES", 9, 70143},
	{"EMPIRICALLY", 11, 70144},
	{"ERNK", 4, 70145},
	{"DFES", 4, 70146},
	{"ADDON", 5, 70147},
	{"FEELIN", 6, 70148},
	{"CALLMANAGER", 11, 70149},
	{"DETERIORATING", 13, 70150},
	{"STATENVERTALING", 15, 70151},
	{"RUTG", 4, 70152},
	{"RBIE", 4, 70153},
	{"BOYH", 4, 70154},
	{"CYPRIOT", 7, 70155},
	{"EWCE", 4, 70156},
	{"ENTERT", 6, 70157},
	{"FASCIA", 6, 70158},
	{"WOBURN", 6, 70159},
	{"PHILANTHROPIC", 13, 70160},
	{"NCAV", 4, 70161},
	{"JALAN", 5, 70162},
	{"FRYERS", 6, 70163},
	{"CALLY", 5, 70164},
	{"LAYERING", 8, 70165},
	{"IRYT", 4, 70166},
	{"GERIATRICS", 10, 70167},
	{"MANEUVERS", 9, 70168},
	{"STRATIFIED", 10, 70169},
	{"PICKY", 5, 70170},
	{"CONLEY", 6, 70171},
	{"CRITTER", 7, 70172},
	{"OWLW", 4, 70173},
	{"RXJ", 3, 70174},
	{"GUQ", 3, 70175},
	{"DZZ", 3, 70176},
	{"JPMO", 4, 70177},
	{"DEDK", 4, 70178},
	{"ALTD", 4, 70179},
	{"BEGS", 4, 70180},
	{"BOCES", 5, 70181},
	{"EMPHASISE", 9, 70182},
	{"BARTH", 5, 70183},
	{"GWEI", 4, 70184},
	{"LVM", 3, 70185},
	{"MOORING", 7, 70186},
	{"MCDONELL", 8, 70187},
	{"EXPATS", 6, 70188},
	{"BIZARR", 6, 70189},
	{"CBAN", 4, 70190},
	{"LOADAVG", 7, 70191},
	{"ADRESSE", 7, 70192},
	{"PERLA", 5, 70193},
	{"MICHEAL", 7, 70194},
	{"MFAR", 4, 70195},
	{"CEOC", 4, 70196},
	{"FRIENDSTER", 10, 70197},
	{"CONNELL", 7, 70198},
	{"BUSTS", 5, 70199},
	{"ENDOSCOPY", 9, 70200},
	{"BUZZWORDS", 9, 70201},
	{"CUTANEOUS", 9, 70202},
	{"SDOY", 4, 70203},
	{"MFEA", 4, 70204},
	{"FVAN", 4, 70205},
	{"LUMEN", 5, 70206},
	{"AIRWAVES", 8, 70207},
	{"PORTERS", 7, 70208},
	{"JAGGER", 6, 70209},
	{"HMAJ", 4, 70210},
	{"FORGERY", 7, 70211},
	{"SETUPS", 6, 70212},
	{"INMAN", 5, 70213},
	{"ZEWH", 4, 70214},
	{"EGIB", 4, 70215},
	{"SCHINDLER", 9, 70216},
	{"LIMEWIRE", 8, 70217},
	{"PEREIRA", 7, 70218},
	{"DRAWSTRING", 10, 70219},
	{"INFREQUENT", 10, 70220},
	{"MIDRANGE", 8, 70221},
	{"MULL", 4, 70222},
	{"EGYI", 4, 70223},
	{"FRODO", 5, 70224},
	{"SUPERPOWER", 10, 70225},
	{"RECLINER", 8, 70226},
	{"BRANDENBURG", 11, 70227},
	{"RCOW", 4, 70228},
	{"CYOR", 4, 70229},
	{"OUDC", 4, 70230},
	{"ITYY", 4, 70231},
	{"INCISION", 8, 70232},
	{"TRISHA", 6, 70233},
	{"TRIUM", 5, 70234},
	{"GRIMSBY", 7, 70235},
	{"WYETH", 5, 70236},
	{"IEWR", 4, 70237},
	{"GJUM", 4, 70238},
	{"ADJUSTER", 8, 70239},
	{"USDU", 4, 70240},
	{"RINU", 4, 70241},
	{"EVUE", 4, 70242},
	{"JUMBLE", 6, 70243},
	{"IMPECCABLE", 10, 70244},
	{"SHARI", 5, 70245},
	{"OWAK", 4, 70246},
	{"LEXM", 4, 70247},
	{"MARKETPLACES", 12, 70248},
	{"COGNAC", 6, 70249},
	{"RLEO", 4, 70250},
	{"RCOF", 4, 70251},
	{"WADING", 6, 70252},
	{"TEFL", 4, 70253},
	{"SUDO", 4, 70254},
	{"WOPI", 4, 70255},
	{"GSOV", 4, 70256},
	{"ERMH", 4, 70257},
	{"TECHNISCHE", 10, 70258},
	{"CHARACTERIZING", 14, 70259},
	{"GAWKER", 6, 70260},
	{"GAGGING", 7, 70261},
	{"BANL", 4, 70262},
	{"IMITATE", 7, 70263},
	{"GRASPING", 8, 70264},
	{"CYCLIST", 7, 70265},
	{"URAF", 4, 70266},
	{"BORNEO", 6, 70267},
	{"GENERICS", 8, 70268},
	{"MORTUARY", 8, 70269},
	{"RICHEY", 6, 70270},
	{"MAGNETO", 7, 70271},
	{"UIRR", 4, 70272},
	{"RPEE", 4, 70273},
	{"NWOL", 4, 70274},
	{"IEGR", 4, 70275},
	{"ARMR", 4, 70276},
	{"MHOP", 4, 70277},
	{"CRUNCHY", 7, 70278},
	{"TELETEXT", 8, 70279},
	{"NKOU", 4, 70280},
	{"HLAU", 4, 70281},
	{"DUPM", 4, 70282},
	{"DRWXRWXR", 8, 70283},
	{"CRABTREE", 8, 70284},
	{"UNDERFULL", 9, 70285},
	{"HEMSCOTT", 8, 70286},
	{"WEBMASTERWORLD", 14, 70287},
	{"OBJC", 4, 70288},
	{"MUSICMATCH", 10, 70289},
	{"WDEV", 4, 70290},
	{"BODE", 4, 70291},
	{"SEALANT", 7, 70292},
	{"THORNS", 6, 70293},
	{"TIMBERWOLVES", 12, 70294},
	{"RIGHTFUL", 8, 70295},
	{"HARRIERS", 8, 70296},
	{"TDIC", 4, 70297},
	{"SHANGRI", 7, 70298},
	{"ROBO", 4, 70299},
	{"IFTB", 4, 70300},
	{"EEFL", 4, 70301},
	{"MNEM", 4, 70302},
	{"AIDAN", 5, 70303},
	{"WMOD", 4, 70304},
	{"DUED", 4, 70305},
	{"FIDEL", 5, 70306},
	{"EXECUTABLES", 11, 70307},
	{"MQV", 3, 70308},
	{"CQW", 3, 70309},
	{"SCARECROW", 9, 70310},
	{"RPIO", 4, 70311},
	{"CONCERTOS", 9, 70312},
	{"UGOI", 4, 70313},
	{"GMUN", 4, 70314},
	{"EXTRACURRICULAR", 15, 70315},
	{"HAVERHILL", 9, 70316},
	{"MOSAICS", 7, 70317},
	{"SQUIRTERS", 9, 70318},
	{"PIOUS", 5, 70319},
	{"UTTERANCE", 9, 70320},
	{"TOMD", 4, 70321},
	{"LOAK", 4, 70322},
	{"BORP", 4, 70323},
	{"UNDEVELOPED", 11, 70324},
	{"BASALT", 6, 70325},
	{"UTAU", 4, 70326},
	{"GASR", 4, 70327},
	{"UNDISPUTED", 10, 70328},
	{"DISTRACTING", 11, 70329},
	{"UNRO", 4, 70330},
	{"OLPL", 4, 70331},
	{"MVEH", 4, 70332},
	{"CTHR", 4, 70333},
	{"TONAL", 5, 70334},
	{"RMWO", 4, 70335},
	{"DKIT", 4, 70336},
	{"URNS", 4, 70337},
	{"UNFOLDS", 7, 70338},
	{"BROCADE", 7, 70339},
	{"YMYS", 4, 70340},
	{"TDAU", 4, 70341},
	{"RDBI", 4, 70342},
	{"NKPA", 4, 70343},
	{"ASHTRAY", 7, 70344},
	{"SEAWEED", 7, 70345},
	{"GPU", 3, 70346},
	{"PAYTON", 6, 70347},
	{"SBUN", 4, 70348},
	{"NOPU", 4, 70349},
	{"IPEF", 4, 70350},
	{"PSYCHOANALYSIS", 14, 70351},
	{"HESITANT", 8, 70352},
	{"DTIR", 4, 70353},
	{"COMU", 4, 70354},
	{"AFEB", 4, 70355},
	{"POCO", 4, 70356},
	{"PREVAILS", 8, 70357},
	{"NEDSTAT", 7, 70358},
	{"XDAY", 4, 70359},
	{"GVIO", 4, 70360},
	{"CIUS", 4, 70361},
	{"AMEQ", 4, 70362},
	{"RCMP", 4, 70363},
	{"MICROCHIP", 9, 70364},
	{"EROTICOS", 8, 70365},
	{"YPTA", 4, 70366},
	{"DKER", 4, 70367},
	{"CEKN", 4, 70368},
	{"CANDLELIGHT", 11, 70369},
	{"VOTIVE", 6, 70370},
	{"WAFERS", 6, 70371},
	{"MESSINA", 7, 70372},
	{"KORS", 4, 70373},
	{"DBUC", 4, 70374},
	{"SCHUMANN", 8, 70375},
	{"SUSQUEHANNA", 11, 70376},
	{"USERINFO", 8, 70377},
	{"MODULO", 6, 70378},
	{"ANTLER", 6, 70379},
	{"TARTS", 5, 70380},
	{"CUTHBERT", 8, 70381},
	{"VELV", 4, 70382},
	{"NWAG", 4, 70383},
	{"GEUR", 4, 70384},
	{"NANCE", 5, 70385},
	{"BANGLADESHI", 11, 70386},
	{"DESKING", 7, 70387},
	{"WMED", 4, 70388},
	{"UNWE", 4, 70389},
	{"PMIL", 4, 70390},
	{"GSAG", 4, 70391},
	{"NIKOLAI", 7, 70392},
	{"NUYS", 4, 70393},
	{"LUDHIANA", 8, 70394},
	{"MYBI", 4, 70395},
	{"EKBU", 4, 70396},
	{"RDR", 3, 70397},
	{"SPANKINGS", 9, 70398},
	{"BABBLE", 6, 70399},
	{"CHATROOMS", 9, 70400},
	{"PRETREATMENT", 12, 70401},
	{"BRITTNEY", 8, 70402},
	{"PESSIMISTIC", 11, 70403},
	{"TYSW", 4, 70404},
	{"NICHES", 6, 70405},
	{"TIANJIN", 7, 70406},
	{"VIDD", 4, 70407},
	{"MCGE", 4, 70408},
	{"AWFR", 4, 70409},
	{"UNTILL", 6, 70410},
	{"WINNEBAGO", 9, 70411},
	{"QUID", 4, 70412},
	{"MCFADDEN", 8, 70413},
	{"NOTECARDS", 9, 70414},
	{"REYM", 4, 70415},
	{"FOXA", 4, 70416},
	{"DYGR", 4, 70417},
	{"CADIZ", 5, 70418},
	{"SHORTWAVE", 9, 70419},
	{"MURFREESBORO", 12, 70420},
	{"OVERLOOKS", 9, 70421},
	{"DIVERSIFY", 9, 70422},
	{"IVOL", 4, 70423},
	{"EDZO", 4, 70424},
	{"QUATERNARY", 10, 70425},
	{"SUBTRACTED", 10, 70426},
	{"HOLB", 4, 70427},
	{"HUGGING", 7, 70428},
	{"TROPEZ", 6, 70429},
	{"POSTMAN", 7, 70430},
	{"MCGOVERN", 8, 70431},
	{"OLIVETTI", 8, 70432},
	{"HIKERS", 6, 70433},
	{"VIVALDI", 7, 70434},
	{"OVERBOARD", 9, 70435},
	{"GODDESSES", 9, 70436},
	{"CUTIES", 6, 70437},
	{"RYAW", 4, 70438},
	{"FAITHLESS", 9, 70439},
	{"REGAINED", 8, 70440},
	{"COOLIDGE", 8, 70441},
	{"OSBU", 4, 70442},
	{"OKUS", 4, 70443},
	{"DUNB", 4, 70444},
	{"BEFL", 4, 70445},
	{"EPHRAIM", 7, 70446},
	{"GILCHRIST", 9, 70447},
	{"YBLE", 4, 70448},
	{"EKSC", 4, 70449},
	{"DRUR", 4, 70450},
	{"PREHEAT", 7, 70451},
	{"BERNADETTE", 10, 70452},
	{"LOPH", 4, 70453},
	{"DRIT", 4, 70454},
	{"MICRODRIVE", 10, 70455},
	{"PELH", 4, 70456},
	{"HEUC", 4, 70457},
	{"ROOKIES", 7, 70458},
	{"OVERTON", 7, 70459},
	{"FOGGY", 5, 70460},
	{"NARL", 4, 70461},
	{"POTPOURRI", 9, 70462},
	{"QFM", 3, 70463},
	{"PYZ", 3, 70464},
	{"PHYC", 4, 70465},
	{"GOFU", 4, 70466},
	{"CRITICIZING", 11, 70467},
	{"LEAFY", 5, 70468},
	{"FBUL", 4, 70469},
	{"PASSIONATELY", 12, 70470},
	{"NEIMAN", 6, 70471},
	{"WBAS", 4, 70472},
	{"ICDU", 4, 70473},
	{"STROKING", 8, 70474},
	{"ORJI", 4, 70475},
	{"CEIW", 4, 70476},
	{"JARHEAD", 7, 70477},
	{"MOMO", 4, 70478},
	{"WJON", 4, 70479},
	{"CVIE", 4, 70480},
	{"UZBEK", 5, 70481},
	{"DUBYA", 5, 70482},
	{"OUTQ", 4, 70483},
	{"EIRQ", 4, 70484},
	{"ECOY", 4, 70485},
	{"SIGNATORY", 9, 70486},
	{"HCUL", 4, 70487},
	{"GATU", 4, 70488},
	{"ENERGIZED", 9, 70489},
	{"BRITE", 5, 70490},
	{"MATURED", 7, 70491},
	{"FUTI", 4, 70492},
	{"MINIMUMS", 8, 70493},
	{"NEEDLEPOINT", 11, 70494},
	{"DENG", 4, 70495},
	{"CAMARGO", 7, 70496},
	{"BOLLE", 5, 70497},
	{"DOLOR", 5, 70498},
	{"OWIW", 4, 70499},
	{"WEBRINGS", 8, 70500},
	{"EHRLICH", 7, 70501},
	{"FIREFIGHTING", 12, 70502},
	{"ICALENDAR", 9, 70503},
	{"DISALLOW", 8, 70504},
	{"PROCURED", 8, 70505},
	{"SUPC", 4, 70506},
	{"EXCH", 4, 70507},
	{"MCLACHLAN", 9, 70508},
	{"ZARAGOZA", 8, 70509},
	{"BRIXTON", 7, 70510},
	{"NOKL", 4, 70511},
	{"EGEG", 4, 70512},
	{"EXCELLENCY", 10, 70513},
	{"CAMELS", 6, 70514},
	{"PARTIE", 6, 70515},
	{"KILO", 4, 70516},
	{"FITG", 4, 70517},
	{"TCMSEQ", 6, 70518},
	{"JUSTIFYING", 10, 70519},
	{"MOISTURIZER", 11, 70520},
	{"SUONERIE", 8, 70521},
	{"YSCU", 4, 70522},
	{"REMANDED", 8, 70523},
	{"EMPRESA", 7, 70524},
	{"OFJI", 4, 70525},
	{"SHOEBOX", 7, 70526},
	{"DISAGREES", 9, 70527},
	{"LOWDOWN", 7, 70528},
	{"TROVE", 5, 70529},
	{"RCOI", 4, 70530},
	{"EASED", 5, 70531},
	{"SLAY", 4, 70532},
	{"DEPRIVE", 7, 70533},
	{"KREMLIN", 7, 70534},
	{"FILER", 5, 70535},
	{"APOLOGETICS", 11, 70536},
	{"LUSTY", 5, 70537},
	{"WORB", 4, 70538},
	{"SAVV", 4, 70539},
	{"ENGLISCH", 8, 70540},
	{"TEXARKANA", 9, 70541},
	{"THREONINE", 9, 70542},
	{"RJOR", 4, 70543},
	{"EUNG", 4, 70544},
	{"METART", 6, 70545},
	{"ENCEPHALITIS", 12, 70546},
	{"BYET", 4, 70547},
	{"VIRTUOSO", 8, 70548},
	{"TOMATOMETER", 11, 70549},
	{"SUZA", 4, 70550},
	{"BUZZING", 7, 70551},
	{"XTRO", 4, 70552},
	{"BADH", 4, 70553},
	{"DAUPHIN", 7, 70554},
	{"ARIAS", 5, 70555},
	{"STEED", 5, 70556},
	{"COWLEY", 6, 70557},
	{"UGIT", 4, 70558},
	{"PARAFFIN", 8, 70559},
	{"KENNER", 6, 70560},
	{"UNITES", 6, 70561},
	{"STIMULANT", 9, 70562},
	{"BSRE", 4, 70563},
	{"ANAMORPHIC", 10, 70564},
	{"SUBSPACE", 8, 70565},
	{"CLEATS", 6, 70566},
	{"REALISING", 9, 70567},
	{"MILLET", 6, 70568},
	{"CIRC", 4, 70569},
	{"INVERT", 6, 70570},
	{"PRESSURED", 9, 70571},
	{"GVIL", 4, 70572},
	{"PEPPERMILL", 10, 70573},
	{"FTOC", 4, 70574},
	{"CLARIFICATIONS", 14, 70575},
	{"ZIONISM", 7, 70576},
	{"RETIN", 5, 70577},
	{"RNVI", 4, 70578},
	{"OYSP", 4, 70579},
	{"DIFO", 4, 70580},
	{"VERMILION", 9, 70581},
	{"NDRH", 4, 70582},
	{"MPIT", 4, 70583},
	{"ELUG", 4, 70584},
	{"ELGE", 4, 70585},
	{"GRINNED", 7, 70586},
	{"KLICKEN", 7, 70587},
	{"NYPI", 4, 70588},
	{"IGAV", 4, 70589},
	{"HDOG", 4, 70590},
	{"MARCHE", 6, 70591},
	{"DISJOINT", 8, 70592},
	{"FBZ", 3, 70593},
	{"CUOU", 4, 70594},
	{"OPENLDAP", 8, 70595},
	{"THELMA", 6, 70596},
	{"FPOE", 4, 70597},
	{"KOENIG", 6, 70598},
	{"YICA", 4, 70599},
	{"EGMA", 4, 70600},
	{"CARATS", 6, 70601},
	{"HIJACKED", 8, 70602},
	{"BURLINGAME", 10, 70603},
	{"CHECKBOOK", 9, 70604},
	{"CANDICE", 7, 70605},
	{"ENLIGHTENING", 12, 70606},
	{"ENDLESSLY", 9, 70607},
	{"UDOS", 4, 70608},
	{"OBEJ", 4, 70609},
	{"LDIC", 4, 70610},
	{"GBYS", 4, 70611},
	{"COWORKERS", 9, 70612},
	{"HASTY", 5, 70613},
	{"KARLA", 5, 70614},
	{"ERAZ", 4, 70615},
	{"DEXTERITY", 9, 70616},
	{"PUZZLING", 8, 70617},
	{"ULFC", 4, 70618},
	{"RMHI", 4, 70619},
	{"STATM", 5, 70620},
	{"DIESES", 6, 70621},
	{"HAIFA", 5, 70622},
	{"TUSP", 4, 70623},
	{"GYSE", 4, 70624},
	{"REINCARNATION", 13, 70625},
	{"BUDWEISER", 9, 70626},
	{"HEURISTICS", 10, 70627},
	{"SUMATRA", 7, 70628},
	{"UGSI", 4, 70629},
	{"RELD", 4, 70630},
	{"DWOL", 4, 70631},
	{"TUNISIAN", 8, 70632},
	{"UCEF", 4, 70633},
	{"DSJU", 4, 70634},
	{"HOLOGRAM", 8, 70635},
	{"MACULAR", 7, 70636},
	{"ERAL", 4, 70637},
	{"KENDRICK", 8, 70638},
	{"DJOK", 4, 70639},
	{"ADUC", 4, 70640},
	{"REFINISHING", 11, 70641},
	{"PRIZED", 6, 70642},
	{"CELESTRON", 9, 70643},
	{"LEYLAND", 7, 70644},
	{"ARRESTING", 9, 70645},
	{"LMAM", 4, 70646},
	{"ALGL", 4, 70647},
	{"BEWITCHED", 9, 70648},
	{"RELOADING", 9, 70649},
	{"KEHU", 4, 70650},
	{"HOMBRE", 6, 70651},
	{"MUNCH", 5, 70652},
	{"BASF", 4, 70653},
	{"RESUMPTION", 10, 70654},
	{"ZONC", 4, 70655},
	{"ROLLEYES", 8, 70656},
	{"IRMA", 4, 70657},
	{"INTIMIDATED", 11, 70658},
	{"BIDIRECTIONAL", 13, 70659},
	{"SIFW", 4, 70660},
	{"KPUB", 4, 70661},
	{"ESGL", 4, 70662},
	{"TRAITOR", 7, 70663},
	{"CLOVE", 5, 70664},
	{"CHICA", 5, 70665},
	{"ORSV", 4, 70666},
	{"LKIT", 4, 70667},
	{"ILLITERATE", 10, 70668},
	{"STARFISH", 8, 70669},
	{"KURDISTAN", 9, 70670},
	{"BORO", 4, 70671},
	{"WIDENED", 7, 70672},
	{"HEARTBREAK", 10, 70673},
	{"PREPS", 5, 70674},
	{"BORDERED", 8, 70675},
	{"MALLET", 6, 70676},
	{"IRINA", 5, 70677},
	{"RDOP", 4, 70678},
	{"LEECH", 5, 70679},
	{"MYLAR", 5, 70680},
	{"GIVER", 5, 70681},
	{"WNDO", 4, 70682},
	{"TYQU", 4, 70683},
	{"DISCONTENT", 10, 70684},
	{"CONGESTIVE", 10, 70685},
	{"DMD", 3, 70686},
	{"SCHILLING", 9, 70687},
	{"RTYV", 4, 70688},
	{"NWAV", 4, 70689},
	{"MBOY", 4, 70690},
	{"TWIKIVARIABLES", 14, 70691},
	{"BATTLEGROUND", 12, 70692},
	{"TECTONIC", 8, 70693},
	{"EQUATE", 6, 70694},
	{"POLD", 4, 70695},
	{"BANF", 4, 70696},
	{"CORBIS", 6, 70697},
	{"INFLATABLES", 11, 70698},
	{"BORW", 4, 70699},
	{"PUNISHING", 9, 70700},
	{"SEEDLING", 8, 70701},
	{"VEPH", 4, 70702},
	{"RSVA", 4, 70703},
	{"OUFR", 4, 70704},
	{"LHUR", 4, 70705},
	{"AWRO", 4, 70706},
	{"NAACP", 5, 70707},
	{"PATHOLOGIST", 11, 70708},
	{"MINNETONKA", 10, 70709},
	{"DWELLERS", 8, 70710},
	{"LANGSTON", 8, 70711},
	{"YINU", 4, 70712},
	{"RNOB", 4, 70713},
	{"MOUTHPIECE", 10, 70714},
	{"MEMORIAM", 8, 70715},
	{"WNSL", 4, 70716},
	{"UNDERSERVED", 11, 70717},
	{"FNIG", 4, 70718},
	{"CBRI", 4, 70719},
	{"RECTIFI", 7, 70720},
	{"SCAF", 4, 70721},
	{"LCOP", 4, 70722},
	{"KDID", 4, 70723},
	{"HCEL", 4, 70724},
	{"ELMWOOD", 7, 70725},
	{"RJEW", 4, 70726},
	{"GBYL", 4, 70727},
	{"FUKUOKA", 7, 70728},
	{"FQUI", 4, 70729},
	{"GLBT", 4, 70730},
	{"PARR", 4, 70731},
	{"CHGU", 4, 70732},
	{"WELLES", 6, 70733},
	{"NYMPH", 5, 70734},
	{"REASSURING", 10, 70735},
	{"XRW", 3, 70736},
	{"KVF", 3, 70737},
	{"LOGT", 4, 70738},
	{"KSPL", 4, 70739},
	{"GUJARATI", 8, 70740},
	{"SPORTSLINE", 10, 70741},
	{"USHD", 4, 70742},
	{"ULOV", 4, 70743},
	{"PINL", 4, 70744},
	{"CKYI", 4, 70745},
	{"HEALTHWISE", 10, 70746},
	{"VRML", 4, 70747},
	{"AZRES", 5, 70748},
	{"CETU", 4, 70749},
	{"ACRY", 4, 70750},
	{"ASTOR", 5, 70751},
	{"SAPPORO", 7, 70752},
	{"MBOF", 4, 70753},
	{"AULR", 4, 70754},
	{"JSCRIPT", 7, 70755},
	{"WMOV", 4, 70756},
	{"LMEL", 4, 70757},
	{"GJAM", 4, 70758},
	{"PREDICTABILITY", 14, 70759},
	{"PAJAMA", 6, 70760},
	{"PADDLESPORTS", 12, 70761},
	{"WBRE", 4, 70762},
	{"NMYE", 4, 70763},
	{"ADENOCARCINOMA", 14, 70764},
	{"LPME", 4, 70765},
	{"HUSR", 4, 70766},
	{"MYLES", 5, 70767},
	{"TONING", 6, 70768},
	{"GESTATIONAL", 11, 70769},
	{"KRAVITZ", 7, 70770},
	{"PTCLDY", 6, 70771},
	{"SNOWBALL", 8, 70772},
	{"TRAVELOGUES", 11, 70773},
	{"CRL", 3, 70774},
	{"YIAM", 4, 70775},
	{"MIDM", 4, 70776},
	{"ZOCOR", 5, 70777},
	{"ECOTOURISM", 10, 70778},
	{"LEADTEK", 7, 70779},
	{"HKCU", 4, 70780},
	{"MOREHEAD", 8, 70781},
	{"YNOP", 4, 70782},
	{"PREMATURELY", 11, 70783},
	{"FUELING", 7, 70784},
	{"YAWI", 4, 70785},
	{"WSDE", 4, 70786},
	{"OLSL", 4, 70787},
	{"FRAIL", 5, 70788},
	{"ADVENTURER", 10, 70789},
	{"ORTHOPAEDICS", 12, 70790},
	{"CRAYONS", 7, 70791},
	{"TIKES", 5, 70792},
	{"REVAMPED", 8, 70793},
	{"OLAP", 4, 70794},
	{"IRRADIATED", 10, 70795},
	{"PFUN", 4, 70796},
	{"DUEI", 4, 70797},
	{"AWFULLY", 7, 70798},
	{"MAYFLOWER", 9, 70799},
	{"UVEB", 4, 70800},
	{"ARCHED", 6, 70801},
	{"CURFEW", 6, 70802},
	{"OCIR", 4, 70803},
	{"HAMLIN", 6, 70804},
	{"BRANDEIS", 8, 70805},
	{"ENLIST", 6, 70806},
	{"AFEG", 4, 70807},
	{"BREE", 4, 70808},
	{"VEDIC", 5, 70809},
	{"EXEMPLIFIED", 11, 70810},
	{"STYLISTIC", 9, 70811},
	{"CORNEAL", 7, 70812},
	{"PROFANE", 7, 70813},
	{"KEEX", 4, 70814},
	{"BECKMAN", 7, 70815},
	{"CRUSHER", 7, 70816},
	{"RIVA", 4, 70817},
	{"CORNELIA", 8, 70818},
	{"VIDT", 4, 70819},
	{"PREFS", 5, 70820},
	{"MILITARIA", 9, 70821},
	{"ROMNEY", 6, 70822},
	{"MACARONI", 8, 70823},
	{"RSPH", 4, 70824},
	{"ELECTING", 8, 70825},
	{"DICTATION", 9, 70826},
	{"MARSHFIELD", 10, 70827},
	{"SWANK", 5, 70828},
	{"ROBBER", 6, 70829},
	{"EVACUATE", 8, 70830},
	{"SBOM", 4, 70831},
	{"JUPI", 4, 70832},
	{"MATISSE", 7, 70833},
	{"VILLEROY", 8, 70834},
	{"VILD", 4, 70835},
	{"LGUE", 4, 70836},
	{"IXRE", 4, 70837},
	{"CONVENIENCES", 12, 70838},
	{"PROACTIVELY", 11, 70839},
	{"CKSG", 4, 70840},
	{"MCCARTY", 7, 70841},
	{"ROVING", 6, 70842},
	{"IQUA", 4, 70843},
	{"GEPU", 4, 70844},
	{"EWOP", 4, 70845},
	{"DRINKER", 7, 70846},
	{"RYIF", 4, 70847},
	{"PIDT", 4, 70848},
	{"OMSB", 4, 70849},
	{"SOFTENED", 8, 70850},
	{"WWEC", 4, 70851},
	{"ACDBCIRCLE", 10, 70852},
	{"HORNEY", 6, 70853},
	{"MODELER", 7, 70854},
	{"OUFA", 4, 70855},
	{"NYYO", 4, 70856},
	{"PEKING", 6, 70857},
	{"PROGRESSIVES", 12, 70858},
	{"GROSVENOR", 9, 70859},
	{"LINGER", 6, 70860},
	{"FILLET", 6, 70861},
	{"MAAR", 4, 70862},
	{"CREATIONISM", 11, 70863},
	{"CHURN", 5, 70864},
	{"DORK", 4, 70865},
	{"SUNM", 4, 70866},
	{"CLARITIN", 8, 70867},
	{"NIMBUS", 6, 70868},
	{"RNFI", 4, 70869},
	{"RDKE", 4, 70870},
	{"ETYD", 4, 70871},
	{"PSYCHOSIS", 9, 70872},
	{"SMARTEST", 8, 70873},
	{"OKME", 4, 70874},
	{"ZRF", 3, 70875},
	{"ZCP", 3, 70876},
	{"FIRSTHAND", 9, 70877},
	{"GIGI", 4, 70878},
	{"NEALE", 5, 70879},
	{"CRANSTON", 8, 70880},
	{"FOPT", 4, 70881},
	{"HAYLEY", 6, 70882},
	{"MADRE", 5, 70883},
	{"ULYM", 4, 70884},
	{"UDBE", 4, 70885},
	{"DMUT", 4, 70886},
	{"IMPART", 6, 70887},
	{"MUTED", 5, 70888},
	{"FEATS", 5, 70889},
	{"TURBIDITY", 9, 70890},
	{"MOUNTABLE", 9, 70891},
	{"WACT", 4, 70892},
	{"KIKI", 4, 70893},
	{"CONCOMITANT", 11, 70894},
	{"AVONDALE", 8, 70895},
	{"RLEI", 4, 70896},
	{"OOFR", 4, 70897},
	{"OCEANOGRAPHIC", 13, 70898},
	{"TAMW", 4, 70899},
	{"DFIX", 4, 70900},
	{"ZZZ", 3, 70901},
	{"DONNER", 6, 70902},
	{"SCAFFOLD", 8, 70903},
	{"MILLIE", 6, 70904},
	{"NONZERO", 7, 70905},
	{"IWORK", 5, 70906},
	{"LIBRO", 5, 70907},
	{"LEISURELY", 9, 70908},
	{"LOKI", 4, 70909},
	{"TILC", 4, 70910},
	{"EUDA", 4, 70911},
	{"DISLIKES", 8, 70912},
	{"MAYONNAISE", 10, 70913},
	{"UDYB", 4, 70914},
	{"SCAVENGER", 9, 70915},
	{"GRUL", 4, 70916},
	{"TOUTED", 6, 70917},
	{"CANDACE", 7, 70918},
	{"GECE", 4, 70919},
	{"BHAD", 4, 70920},
	{"KAVA", 4, 70921},
	{"KRONOS", 6, 70922},
	{"ADJUVANT", 8, 70923},
	{"PSAY", 4, 70924},
	{"TYNESIDE", 8, 70925},
	{"ECHB", 4, 70926},
	{"TRAVOLTA", 8, 70927},
	{"LIMITLESS", 9, 70928},
	{"YBYB", 4, 70929},
	{"SWRA", 4, 70930},
	{"LKLO", 4, 70931},
	{"KNOPF", 5, 70932},
	{"PREVENTABLE", 11, 70933},
	{"HANGMAN", 7, 70934},
	{"BUMPY", 5, 70935},
	{"ALEPH", 5, 70936},
	{"NOLU", 4, 70937},
	{"CONROY", 6, 70938},
	{"MASTERMIND", 10, 70939},
	{"VACCINATED", 10, 70940},
	{"SLOPING", 7, 70941},
	{"WWAT", 4, 70942},
	{"SYEL", 4, 70943},
	{"COBURN", 6, 70944},
	{"RAWK", 4, 70945},
	{"ACCEPTABILITY", 13, 70946},
	{"LFAG", 4, 70947},
	{"CONSTITUTIONALLY", 16, 70948},
	{"YDIC", 4, 70949},
	{"GHWO", 4, 70950},
	{"STRYKER", 7, 70951},
	{"DISAPPROVAL", 11, 70952},
	{"BAVARIAN", 8, 70953},
	{"SURCHARGES", 10, 70954},
	{"CRUCIFIED", 9, 70955},
	{"POCAHONTAS", 10, 70956},
	{"NOTICEBOARD", 11, 70957},
	{"MASONS", 6, 70958},
	{"CHAPIN", 6, 70959},
	{"PERMUTATION", 11, 70960},
	{"SURGES", 6, 70961},
	{"LITERATURES", 11, 70962},
	{"COLPO", 5, 70963},
	{"WDRI", 4, 70964},
	{"UCSC", 4, 70965},
	{"MULLIGAN", 8, 70966},
	{"LGAN", 4, 70967},
	{"FSAV", 4, 70968},
	{"UNLUCKY", 7, 70969},
	{"YAWN", 4, 70970},
	{"WNDA", 4, 70971},
	{"IFYW", 4, 70972},
	{"GSOW", 4, 70973},
	{"EDOZ", 4, 70974},
	{"DISTORT", 7, 70975},
	{"UTTU", 4, 70976},
	{"KETCHUP", 7, 70977},
	{"ALIMONY", 7, 70978},
	{"WWWS", 4, 70979},
	{"HICD", 4, 70980},
	{"FPUN", 4, 70981},
	{"VISCOUS", 7, 70982},
	{"DOGM", 4, 70983},
	{"WAHL", 4, 70984},
	{"CMM", 3, 70985},
	{"UNAMBIGUOUS", 11, 70986},
	{"POFD", 4, 70987},
	{"MPMA", 4, 70988},
	{"MEVO", 4, 70989},
	{"CEDV", 4, 70990},
	{"LOOSING", 7, 70991},
	{"CANOPIES", 8, 70992},
	{"HANDICRAFT", 10, 70993},
	{"WSAY", 4, 70994},
	{"UVAL", 4, 70995},
	{"RMIA", 4, 70996},
	{"EMPHYSEMA", 9, 70997},
	{"BUSCAR", 6, 70998},
	{"VRK", 3, 70999},
	{"LJJ", 3, 71000},
	{"FCQ", 3, 71001},
	{"BXC", 3, 71002},
	{"SORV", 4, 71003},
	{"OLYP", 4, 71004},
	{"GGOT", 4, 71005},
	{"DYIE", 4, 71006},
	{"EPISTEMOLOGY", 12, 71007},
	{"GRANTHAM", 8, 71008},
	{"AVILA", 5, 71009},
	{"SOLANA", 6, 71010},
	{"PILING", 6, 71011},
	{"TOOLKITS", 8, 71012},
	{"SOLOIST", 7, 71013},
	{"REJUVENATION", 12, 71014},
	{"ANACONDA", 8, 71015},
	{"BSNL", 4, 71016},
	{"BASILICA", 8, 71017},
	{"YROT", 4, 71018},
	{"ILSD", 4, 71019},
	{"AMINE", 5, 71020},
	{"WDEL", 4, 71021},
	{"ROBBERS", 7, 71022},
	{"CARFAX", 6, 71023},
	{"LEVERAGED", 9, 71024},
	{"WEGA", 4, 71025},
	{"AMIW", 4, 71026},
	{"SCANJET", 7, 71027},
	{"LIPR", 4, 71028},
	{"MENG", 4, 71029},
	{"UMDI", 4, 71030},
	{"BURLEY", 6, 71031},
	{"NGHY", 4, 71032},
	{"PLASMIDS", 8, 71033},
	{"STEFFEN", 7, 71034},
	{"WOOFER", 6, 71035},
	{"RANJ", 4, 71036},
	{"AGAP", 4, 71037},
	{"LADA", 4, 71038},
	{"HINCKLEY", 8, 71039},
	{"JULIANA", 7, 71040},
	{"MILLIMETER", 10, 71041},
	{"SNAPE", 5, 71042},
	{"ROLLERCOASTER", 13, 71043},
	{"MUPA", 4, 71044},
	{"LOWLAND", 7, 71045},
	{"NMEC", 4, 71046},
	{"CONNERY", 7, 71047},
	{"XCLA", 4, 71048},
	{"NIFF", 4, 71049},
	{"SAUSAGES", 8, 71050},
	{"SPAKE", 5, 71051},
	{"NEWSWATCH", 9, 71052},
	{"FEUD", 4, 71053},
	{"SUBORDINATED", 12, 71054},
	{"OJAM", 4, 71055},
	{"ROUNDUPS", 8, 71056},
	{"DMEG", 4, 71057},
	{"BOWM", 4, 71058},
	{"AWOKE", 5, 71059},
	{"KEYLOGGER", 9, 71060},
	{"PARKA", 5, 71061},
	{"UNHEARD", 7, 71062},
	{"PRUNE", 5, 71063},
	{"SCOUSE", 6, 71064},
	{"YASY", 4, 71065},
	{"WOFC", 4, 71066},
	{"TTYF", 4, 71067},
	{"NSLU", 4, 71068},
	{"ILUT", 4, 71069},
	{"UNISTS", 6, 71070},
	{"ENDANGER", 8, 71071},
	{"CAIRN", 5, 71072},
	{"NOMADIC", 7, 71073},
	{"LSOJ", 4, 71074},
	{"BRYO", 4, 71075},
	{"SPOCK", 5, 71076},
	{"MYVI", 4, 71077},
	{"BMJ", 3, 71078},
	{"FARRAR", 6, 71079},
	{"DECOMPRESSION", 13, 71080},
	{"DISGUSTED", 9, 71081},
	{"RWOL", 4, 71082},
	{"RRYE", 4, 71083},
	{"DRACO", 5, 71084},
	{"MIKA", 4, 71085},
	{"GALENA", 6, 71086},
	{"MSFT", 4, 71087},
	{"URYN", 4, 71088},
	{"KGOD", 4, 71089},
	{"INACTIVATION", 12, 71090},
	{"METAFILTER", 10, 71091},
	{"MBNA", 4, 71092},
	{"LYMPHATIC", 9, 71093},
	{"GGON", 4, 71094},
	{"OLFACTORY", 9, 71095},
	{"LBAD", 4, 71096},
	{"GACI", 4, 71097},
	{"BERKS", 5, 71098},
	{"WIRRAL", 6, 71099},
	{"PROLONG", 7, 71100},
	{"BOXSET", 6, 71101},
	{"PEYT", 4, 71102},
	{"KSME", 4, 71103},
	{"HAFL", 4, 71104},
	{"ASHRAE", 6, 71105},
	{"FONTAINE", 8, 71106},
	{"ILFORD", 6, 71107},
	{"XASC", 4, 71108},
	{"UISB", 4, 71109},
	{"TACQ", 4, 71110},
	{"ALLMAN", 6, 71111},
	{"KNITS", 5, 71112},
	{"KROON", 5, 71113},
	{"VEOB", 4, 71114},
	{"BUILTIN", 7, 71115},
	{"LISBOA", 6, 71116},
	{"THINLY", 6, 71117},
	{"ROLLBACK", 8, 71118},
	{"GARNETT", 7, 71119},
	{"WESTGATE", 8, 71120},
	{"USSL", 4, 71121},
	{"GALEN", 5, 71122},
	{"AVYL", 4, 71123},
	{"BOBO", 4, 71124},
	{"CROCKPOT", 8, 71125},
	{"WEANING", 7, 71126},
	{"SNOWSHOE", 8, 71127},
	{"HIJACKTHIS", 10, 71128},
	{"USJU", 4, 71129},
	{"RABH", 4, 71130},
	{"ERGM", 4, 71131},
	{"ARABLE", 6, 71132},
	{"BACKSIDE", 8, 71133},
	{"ZRB", 3, 71134},
	{"PARALLELISM", 11, 71135},
	{"BRUT", 4, 71136},
	{"FETCHMAIL", 9, 71137},
	{"CANDLEWOOD", 10, 71138},
	{"NYRI", 4, 71139},
	{"FTDE", 4, 71140},
	{"ENFC", 4, 71141},
	{"ANGELFIRE", 9, 71142},
	{"VERNACULAR", 10, 71143},
	{"IUMM", 4, 71144},
	{"LATITUDES", 9, 71145},
	{"UCSF", 4, 71146},
	{"ALKALI", 6, 71147},
	{"YTUE", 4, 71148},
	{"DSFE", 4, 71149},
	{"ADTU", 4, 71150},
	{"YFUT", 4, 71151},
	{"MOWING", 6, 71152},
	{"PAINKILLER", 10, 71153},
	{"NUTTY", 5, 71154},
	{"FORESEEN", 8, 71155},
	{"FENWAY", 6, 71156},
	{"RESTROOMS", 9, 71157},
	{"PALMERSTON", 10, 71158},
	{"SEVER", 5, 71159},
	{"MYELOMA", 7, 71160},
	{"MEHU", 4, 71161},
	{"EXPEND", 6, 71162},
	{"STAHL", 5, 71163},
	{"AUNTIE", 6, 71164},
	{"MEMY", 4, 71165},
	{"AFGHANS", 7, 71166},
	{"SCALLOPS", 8, 71167},
	{"MPOP", 4, 71168},
	{"CUTW", 4, 71169},
	{"BLAMES", 6, 71170},
	{"SUBDIVIDED", 10, 71171},
	{"OSTEOPATHIC", 11, 71172},
	{"SIGM", 4, 71173},
	{"AVEQ", 4, 71174},
	{"VIVIDLY", 7, 71175},
	{"RMIT", 4, 71176},
	{"HAPPIEST", 8, 71177},
	{"GEBL", 4, 71178},
	{"COUNTERMEASURES", 15, 71179},
	{"OFERTAS", 7, 71180},
	{"GWINNETT", 8, 71181},
	{"LUCCA", 5, 71182},
	{"FRANCINE", 8, 71183},
	{"DIRS", 4, 71184},
	{"DUVALL", 6, 71185},
	{"WILDFLOWER", 10, 71186},
	{"EAKR", 4, 71187},
	{"CINV", 4, 71188},
	{"STACKABLE", 9, 71189},
	{"GREENSBURG", 10, 71190},
	{"BAREBONES", 9, 71191},
	{"FSQU", 4, 71192},
	{"EXRE", 4, 71193},
	{"MERINO", 6, 71194},
	{"RESERVING", 9, 71195},
	{"RHYM", 4, 71196},
	{"NDSJ", 4, 71197},
	{"IMDI", 4, 71198},
	{"NAGASAKI", 8, 71199},
	{"STOOGES", 7, 71200},
	{"CHATSWORTH", 10, 71201},
	{"JELLO", 5, 71202},
	{"ELCE", 4, 71203},
	{"MTIME", 5, 71204},
	{"RJAS", 4, 71205},
	{"NTUL", 4, 71206},
	{"NKOV", 4, 71207},
	{"INDENTED", 8, 71208},
	{"KISM", 4, 71209},
	{"BARIUM", 6, 71210},
	{"TORIC", 5, 71211},
	{"UEMI", 4, 71212},
	{"OPTW", 4, 71213},
	{"GDIA", 4, 71214},
	{"LOOTING", 7, 71215},
	{"KIEFER", 6, 71216},
	{"HUMMING", 7, 71217},
	{"MAURO", 5, 71218},
	{"DISCLAIM", 8, 71219},
	{"ILSM", 4, 71220},
	{"SHEARER", 7, 71221},
	{"DECCA", 5, 71222},
	{"HYDROPHOBIC", 11, 71223},
	{"UNSW", 4, 71224},
	{"GAPU", 4, 71225},
	{"FRANS", 5, 71226},
	{"MILLARD", 7, 71227},
	{"DIAMETERS", 9, 71228},
	{"EXERTED", 7, 71229},
	{"POFG", 4, 71230},
	{"JUSTIFIES", 9, 71231},
	{"FREIBURG", 8, 71232},
	{"TERRASERVER", 11, 71233},
	{"RUEO", 4, 71234},
	{"RETURNABLE", 10, 71235},
	{"HOCR", 4, 71236},
	{"GDRE", 4, 71237},
	{"DIFW", 4, 71238},
	{"RESUSCITATION", 13, 71239},
	{"CANCELLING", 10, 71240},
	{"STRATIFICATION", 14, 71241},
	{"REGENERATE", 10, 71242},
	{"OLIVEIRA", 8, 71243},
	{"CAHILL", 6, 71244},
	{"GRUMMAN", 7, 71245},
	{"WEBDAV", 6, 71246},
	{"TITRE", 5, 71247},
	{"TUMBLER", 7, 71248},
	{"ADAGIO", 6, 71249},
	{"SUNBURST", 8, 71250},
	{"YMIK", 4, 71251},
	{"KNER", 4, 71252},
	{"HPAY", 4, 71253},
	{"BONNE", 5, 71254},
	{"IMPROVISED", 10, 71255},
	{"VANM", 4, 71256},
	{"FNAM", 4, 71257},
	{"AYUMI", 5, 71258},
	{"RKYA", 4, 71259},
	{"PSRA", 4, 71260},
	{"BELA", 4, 71261},
	{"STARTUPS", 8, 71262},
	{"MXU", 3, 71263},
	{"GPJ", 3, 71264},
	{"FZM", 3, 71265},
	{"CXB", 3, 71266},
	{"SDOD", 4, 71267},
	{"NUNB", 4, 71268},
	{"FLOCKS", 6, 71269},
	{"RANTING", 7, 71270},
	{"BOTHERING", 9, 71271},
	{"UDAIPUR", 7, 71272},
	{"GARNERED", 8, 71273},
	{"EDKO", 4, 71274},
	{"TONYA", 5, 71275},
	{"KLYE", 4, 71276},
	{"BBRO", 4, 71277},
	{"ERUPTED", 7, 71278},
	{"GHOSTSCRIPT", 11, 71279},
	{"MYEY", 4, 71280},
	{"AMJU", 4, 71281},
	{"MELTDOWN", 8, 71282},
	{"FLING", 5, 71283},
	{"RKBR", 4, 71284},
	{"OMSD", 4, 71285},
	{"NYGE", 4, 71286},
	{"IDKE", 4, 71287},
	{"RAINWATER", 9, 71288},
	{"GELLAR", 6, 71289},
	{"COMRADE", 7, 71290},
	{"NEDK", 4, 71291},
	{"ASCENDED", 8, 71292},
	{"CNRS", 4, 71293},
	{"REDEFINING", 10, 71294},
	{"MUMW", 4, 71295},
	{"ARIR", 4, 71296},
	{"JULIETTE", 8, 71297},
	{"OGMA", 4, 71298},
	{"EGAW", 4, 71299},
	{"ZEWA", 4, 71300},
	{"NUPG", 4, 71301},
	{"VESICLES", 8, 71302},
	{"PICCOLO", 7, 71303},
	{"SCALIA", 6, 71304},
	{"RESIZING", 8, 71305},
	{"PORCUPINE", 9, 71306},
	{"SHOWROOMS", 9, 71307},
	{"VERIFIABLE", 10, 71308},
	{"CHOPPING", 8, 71309},
	{"UDOW", 4, 71310},
	{"TJEF", 4, 71311},
	{"LOBO", 4, 71312},
	{"ENACTING", 8, 71313},
	{"BOYDS", 5, 71314},
	{"HAVENS", 6, 71315},
	{"BACTERIUM", 9, 71316},
	{"UMBY", 4, 71317},
	{"AZZO", 4, 71318},
	{"ACEJ", 4, 71319},
	{"SIDELINE", 8, 71320},
	{"BBOR", 4, 71321},
	{"STABBING", 8, 71322},
	{"METAMORPHOSIS", 13, 71323},
	{"BUSHING", 7, 71324},
	{"LIGAMENT", 8, 71325},
	{"WRET", 4, 71326},
	{"ULEM", 4, 71327},
	{"APLI", 4, 71328},
	{"PENPALS", 7, 71329},
	{"DYHO", 4, 71330},
	{"TRANSLOCATION", 13, 71331},
	{"COSTCO", 6, 71332},
	{"SERIALIZATION", 13, 71333},
	{"PLAYGROUNDS", 11, 71334},
	{"HILDA", 5, 71335},
	{"UNIVERSIDADE", 12, 71336},
	{"WNSB", 4, 71337},
	{"KAWH", 4, 71338},
	{"OMYP", 4, 71339},
	{"WANDERER", 8, 71340},
	{"FONG", 4, 71341},
	{"LKIS", 4, 71342},
	{"FLATTENED", 9, 71343},
	{"ZIPS", 4, 71344},
	{"ULIV", 4, 71345},
	{"HSQU", 4, 71346},
	{"HRUG", 4, 71347},
	{"DAWKINS", 7, 71348},
	{"SPITTING", 8, 71349},
	{"WTWO", 4, 71350},
	{"EIGENVALUE", 10, 71351},
	{"INCONVENIENT", 12, 71352},
	{"SGRU", 4, 71353},
	{"PMWE", 4, 71354},
	{"OALR", 4, 71355},
	{"EDSR", 4, 71356},
	{"ABYW", 4, 71357},
	{"SEACOAST", 8, 71358},
	{"WESU", 4, 71359},
	{"BLOI", 4, 71360},
	{"CONDUCTANCE", 11, 71361},
	{"IMPERFECTIONS", 13, 71362},
	{"LEWES", 5, 71363},
	{"PCHI", 4, 71364},
	{"OOKV", 4, 71365},
	{"CHANCERY", 8, 71366},
	{"ALBEMARLE", 9, 71367},
	{"RAVING", 6, 71368},
	{"MUDD", 4, 71369},
	{"WPAS", 4, 71370},
	{"KBEN", 4, 71371},
	{"IORJ", 4, 71372},
	{"NIELS", 5, 71373},
	{"EXPLODES", 8, 71374},
	{"LINDY", 5, 71375},
	{"NYCU", 4, 71376},
	{"LBLU", 4, 71377},
	{"COIMBATORE", 10, 71378},
	{"PANZER", 6, 71379},
	{"WTRI", 4, 71380},
	{"FDIG", 4, 71381},
	{"ABUY", 4, 71382},
	{"AUDIOSCROBBLER", 14, 71383},
	{"KERI", 4, 71384},
	{"EPFA", 4, 71385},
	{"DNEU", 4, 71386},
	{"SOVIETS", 7, 71387},
	{"KESG", 4, 71388},
	{"TWEETER", 7, 71389},
	{"EXECUTOR", 8, 71390},
	{"PONCHO", 6, 71391},
	{"ANGLESEY", 8, 71392},
	{"CHOIRS", 6, 71393},
	{"REYP", 4, 71394},
	{"PFIR", 4, 71395},
	{"IULI", 4, 71396},
	{"FAERIE", 6, 71397},
	{"OCEANA", 6, 71398},
	{"UNAP", 4, 71399},
	{"WAKEBOARDING", 12, 71400},
	{"STINGER", 7, 71401},
	{"YRZ", 3, 71402},
	{"WBJ", 3, 71403},
	{"YUBA", 4, 71404},
	{"CHIPSETS", 8, 71405},
	{"WREATHS", 7, 71406},
	{"GBER", 4, 71407},
	{"FATW", 4, 71408},
	{"ANASTACIA", 9, 71409},
	{"COLLAPSING", 10, 71410},
	{"TASTELESS", 9, 71411},
	{"TOMAHAWK", 8, 71412},
	{"PROJET", 6, 71413},
	{"ULFU", 4, 71414},
	{"LDWR", 4, 71415},
	{"INSTRUCTIVE", 11, 71416},
	{"SAYF", 4, 71417},
	{"ABSORBS", 7, 71418},
	{"SUSANNAH", 8, 71419},
	{"TOUTES", 6, 71420},
	{"YBOX", 4, 71421},
	{"OPOV", 4, 71422},
	{"GWYNETH", 7, 71423},
	{"MATHEMATICALLY", 14, 71424},
	{"BUMF", 4, 71425},
	{"AKWH", 4, 71426},
	{"GODWIN", 6, 71427},
	{"KUWAITI", 7, 71428},
	{"DRIER", 5, 71429},
	{"JALBUM", 6, 71430},
	{"STORAGEWORKS", 12, 71431},
	{"YLLI", 4, 71432},
	{"VINB", 4, 71433},
	{"DOGF", 4, 71434},
	{"DUPLICATORS", 11, 71435},
	{"BOTHERS", 7, 71436},
	{"PARADES", 7, 71437},
	{"CUBICLE", 7, 71438},
	{"CMEM", 4, 71439},
	{"WINFREY", 7, 71440},
	{"YRAP", 4, 71441},
	{"SDUN", 4, 71442},
	{"AVANTI", 6, 71443},
	{"BLIGE", 5, 71444},
	{"WGAM", 4, 71445},
	{"DMYT", 4, 71446},
	{"SHOVED", 6, 71447},
	{"INVOKES", 7, 71448},
	{"PAPAYA", 6, 71449},
	{"FERV", 4, 71450},
	{"CANNONS", 7, 71451},
	{"AUGER", 5, 71452},
	{"MACCLESFIELD", 12, 71453},
	{"MONGOOSE", 8, 71454},
	{"HAMISH", 6, 71455},
	{"CROSSFADE", 9, 71456},
	{"INSTRUMENTALS", 13, 71457},
	{"ICONIC", 6, 71458},
	{"SULFIDE", 7, 71459},
	{"DAWG", 4, 71460},
	{"UMTE", 4, 71461},
	{"UMEM", 4, 71462},
	{"CHROMATIC", 9, 71463},
	{"RIFE", 4, 71464},
	{"MAHLER", 6, 71465},
	{"MAURER", 6, 71466},
	{"RALLYING", 8, 71467},
	{"AUSCHWITZ", 9, 71468},
	{"GAMBIT", 6, 71469},
	{"ACCOM", 5, 71470},
	{"ENOCH", 5, 71471},
	{"YIWO", 4, 71472},
	{"TIMG", 4, 71473},
	{"SUSM", 4, 71474},
	{"CARRIAGES", 9, 71475},
	{"DALES", 5, 71476},
	{"UXBRIDGE", 8, 71477},
	{"POLLED", 6, 71478},
	{"AGNOSTIC", 8, 71479},
	{"ALDM", 4, 71480},
	{"BAUMATIC", 8, 71481},
	{"EMPTIED", 7, 71482},
	{"DENOUNCED", 9, 71483},
	{"LANDIS", 6, 71484},
	{"DELUSION", 8, 71485},
	{"FREDRICK", 8, 71486},
	{"RIMINI", 6, 71487},
	{"JOGGER", 6, 71488},
	{"OCCLUSION", 9, 71489},
	{"VERITY", 6, 71490},
	{"IRSF", 4, 71491},
	{"CHARLIZE", 8, 71492},
	{"COVENT", 6, 71493},
	{"TURRET", 6, 71494},
	{"REINVESTMENT", 12, 71495},
	{"YSMU", 4, 71496},
	{"NYAW", 4, 71497},
	{"DMEW", 4, 71498},
	{"SSDASDAS", 8, 71499},
	{"CHATTERBOX", 10, 71500},
	{"NEUTRONS", 8, 71501},
	{"TBUC", 4, 71502},
	{"LCOT", 4, 71503},
	{"CTMI", 4, 71504},
	{"BFRO", 4, 71505},
	{"PRECEDE", 7, 71506},
	{"ORKJ", 4, 71507},
	{"LYET", 4, 71508},
	{"POLYSTYRENE", 11, 71509},
	{"JODHPUR", 7, 71510},
	{"BETTS", 5, 71511},
	{"INTELLIGENCER", 13, 71512},
	{"RZEN", 4, 71513},
	{"GSIL", 4, 71514},
	{"CRUB", 4, 71515},
	{"DUNDAS", 6, 71516},
	{"NETMAG", 6, 71517},
	{"WRIN", 4, 71518},
	{"WOKI", 4, 71519},
	{"SLEC", 4, 71520},
	{"RGYL", 4, 71521},
	{"HROD", 4, 71522},
	{"MOLOKAI", 7, 71523},
	{"AKSF", 4, 71524},
	{"PLURALISM", 9, 71525},
	{"DOMES", 5, 71526},
	{"KOBAYASHI", 9, 71527},
	{"UNQU", 4, 71528},
	{"GINU", 4, 71529},
	{"TETANUS", 7, 71530},
	{"BCD", 3, 71531},
	{"NEUROMUSCULAR", 13, 71532},
	{"FKQ", 3, 71533},
	{"CARIBE", 6, 71534},
	{"NPHASE", 6, 71535},
	{"WEMO", 4, 71536},
	{"MULTIFAMILY", 11, 71537},
	{"TIMRES", 6, 71538},
	{"NRCS", 4, 71539},
	{"VEOC", 4, 71540},
	{"DIWE", 4, 71541},
	{"FARNHAM", 7, 71542},
	{"COORS", 5, 71543},
	{"GYEF", 4, 71544},
	{"ECUA", 4, 71545},
	{"EXECS", 5, 71546},
	{"HAUSER", 6, 71547},
	{"CITESEER", 8, 71548},
	{"HIKER", 5, 71549},
	{"MANUF", 5, 71550},
	{"MPWA", 4, 71551},
	{"STRATEGIST", 10, 71552},
	{"WILDEST", 7, 71553},
	{"TUSM", 4, 71554},
	{"ELECTROCLASH", 12, 71555},
	{"OUTLAYS", 7, 71556},
	{"ZLOTY", 5, 71557},
	{"EUMW", 4, 71558},
	{"FOODSTUFFS", 10, 71559},
	{"OSMOSIS", 7, 71560},
	{"PRIMING", 7, 71561},
	{"GWEB", 4, 71562},
	{"EKRI", 4, 71563},
	{"VOWELS", 6, 71564},
	{"RMEX", 4, 71565},
	{"MPOV", 4, 71566},
	{"NURT", 4, 71567},
	{"HEWB", 4, 71568},
	{"MOJAVE", 6, 71569},
	{"RENOVA", 6, 71570},
	{"SULPHATE", 8, 71571},
	{"SOOTHE", 6, 71572},
	{"MARIPOSA", 8, 71573},
	{"ADVANCEMENTS", 12, 71574},
	{"FRANCK", 6, 71575},
	{"TDOL", 4, 71576},
	{"NEYJ", 4, 71577},
	{"BBAN", 4, 71578},
	{"BOCK", 4, 71579},
	{"CLANDESTINE", 11, 71580},
	{"BEHU", 4, 71581},
	{"MIGRATIONS", 10, 71582},
	{"HOVERING", 8, 71583},
	{"LEARY", 5, 71584},
	{"SLURRY", 6, 71585},
	{"OLOB", 4, 71586},
	{"IGAB", 4, 71587},
	{"AOFR", 4, 71588},
	{"TEXTE", 5, 71589},
	{"RUBA", 4, 71590},
	{"TAMPER", 6, 71591},
	{"PUGH", 4, 71592},
	{"SOULMATES", 9, 71593},
	{"MARISSA", 7, 71594},
	{"RILP", 4, 71595},
	{"DDUK", 4, 71596},
	{"UBWH", 4, 71597},
	{"CIPH", 4, 71598},
	{"BERETTA", 7, 71599},
	{"PUNISHMENTS", 11, 71600},
	{"CHIROPRACTOR", 12, 71601},
	{"VIBRATIONAL", 11, 71602},
	{"DAGEN", 5, 71603},
	{"HEATHEN", 7, 71604},
	{"SANDUSKY", 8, 71605},
	{"OBSIDIAN", 8, 71606},
	{"UNDULY", 6, 71607},
	{"DRESSERS", 8, 71608},
	{"WINGER", 6, 71609},
	{"ENDEAVOURS", 10, 71610},
	{"RIGGED", 6, 71611},
	{"ARGONNE", 7, 71612},
	{"PHLE", 4, 71613},
	{"RUNNIN", 6, 71614},
	{"YORL", 4, 71615},
	{"OJOB", 4, 71616},
	{"HRUL", 4, 71617},
	{"GSUI", 4, 71618},
	{"UTVA", 4, 71619},
	{"UPDI", 4, 71620},
	{"ODFE", 4, 71621},
	{"LLTY", 4, 71622},
	{"DOMICILE", 8, 71623},
	{"GAYE", 4, 71624},
	{"COLFAX", 6, 71625},
	{"OOFB", 4, 71626},
	{"NECD", 4, 71627},
	{"CHARGEABLE", 10, 71628},
	{"OWDW", 4, 71629},
	{"LSGA", 4, 71630},
	{"KWEN", 4, 71631},
	{"FANNING", 7, 71632},
	{"WNRA", 4, 71633},
	{"SPURRED", 7, 71634},
	{"LOGICS", 6, 71635},
	{"CAMEDIA", 7, 71636},
	{"BROUGHTON", 9, 71637},
	{"MYPL", 4, 71638},
	{"LTMO", 4, 71639},
	{"OPTIMISE", 8, 71640},
	{"ERNESTO", 7, 71641},
	{"VOEG", 4, 71642},
	{"OSAGE", 5, 71643},
	{"ADAMSON", 7, 71644},
	{"COEDS", 5, 71645},
	{"REVU", 4, 71646},
	{"QUOA", 4, 71647},
	{"NPIK", 4, 71648},
	{"LCRU", 4, 71649},
	{"FOFI", 4, 71650},
	{"EZBO", 4, 71651},
	{"PEREGRINE", 9, 71652},
	{"TABITHA", 7, 71653},
	{"OPFL", 4, 71654},
	{"SUBDIRECTORIES", 14, 71655},
	{"PUEDE", 5, 71656},
	{"CRUMB", 5, 71657},
	{"FOSTERED", 8, 71658},
	{"WLYE", 4, 71659},
	{"ESKU", 4, 71660},
	{"CULMINATION", 11, 71661},
	{"REVOLVES", 8, 71662},
	{"GUILDER", 7, 71663},
	{"COMPARATOR", 10, 71664},
	{"MEND", 4, 71665},
	{"THEORETIC", 9, 71666},
	{"SEALER", 6, 71667},
	{"SLEAZY", 6, 71668},
	{"SOFTENING", 9, 71669},
	{"LLOD", 4, 71670},
	{"VKV", 3, 71671},
	{"ONSTAGE", 7, 71672},
	{"TODAS", 5, 71673},
	{"WATERPROOFING", 13, 71674},
	{"RMIX", 4, 71675},
	{"IDKA", 4, 71676},
	{"HOPC", 4, 71677},
	{"DEVLIN", 6, 71678},
	{"GLIMPSES", 8, 71679},
	{"RIEL", 4, 71680},
	{"PINKY", 5, 71681},
	{"HATTIE", 6, 71682},
	{"LEWISHAM", 8, 71683},
	{"MINTS", 5, 71684},
	{"UIRK", 4, 71685},
	{"RNIL", 4, 71686},
	{"FBEF", 4, 71687},
	{"WDM", 3, 71688},
	{"AVOCENT", 7, 71689},
	{"INVERTEBRATE", 12, 71690},
	{"BREA", 4, 71691},
	{"TYVO", 4, 71692},
	{"GEBI", 4, 71693},
	{"REBELLIOUS", 10, 71694},
	{"CARNITINE", 9, 71695},
	{"XEDS", 4, 71696},
	{"IERU", 4, 71697},
	{"DAYK", 4, 71698},
	{"TRIB", 4, 71699},
	{"TASTEFULLY", 10, 71700},
	{"RZAI", 4, 71701},
	{"WEBEX", 5, 71702},
	{"CAPO", 4, 71703},
	{"RKGR", 4, 71704},
	{"FIDD", 4, 71705},
	{"CLOA", 4, 71706},
	{"ADEJ", 4, 71707},
	{"PAIRINGS", 8, 71708},
	{"GUESTHOUSES", 11, 71709},
	{"YIKES", 5, 71710},
	{"GRATE", 5, 71711},
	{"LOURDES", 7, 71712},
	{"EXORCISM", 8, 71713},
	{"IDSR", 4, 71714},
	{"GRILLES", 7, 71715},
	{"CULTIVAR", 8, 71716},
	{"FLYW", 4, 71717},
	{"DATV", 4, 71718},
	{"ORSON", 5, 71719},
	{"DISEASED", 8, 71720},
	{"KENILWORTH", 10, 71721},
	{"HRVATSKA", 8, 71722},
	{"UGIV", 4, 71723},
	{"PTUN", 4, 71724},
	{"SEQUENCER", 9, 71725},
	{"DEMONIC", 7, 71726},
	{"OTCU", 4, 71727},
	{"WONKA", 5, 71728},
	{"ECYL", 4, 71729},
	{"MARGOT", 6, 71730},
	{"SOCIALISTS", 10, 71731},
	{"PREZZO", 6, 71732},
	{"DEDUCED", 7, 71733},
	{"COLLABORATIVELY", 15, 71734},
	{"OBERLIN", 7, 71735},
	{"BUTTOCKS", 8, 71736},
	{"PSFI", 4, 71737},
	{"FPSY", 4, 71738},
	{"UNMANNED", 8, 71739},
	{"RAINBOWS", 8, 71740},
	{"GUNNAR", 6, 71741},
	{"GORDA", 5, 71742},
	{"ULPL", 4, 71743},
	{"GDUE", 4, 71744},
	{"EIMF", 4, 71745},
	{"NEWBURGH", 8, 71746},
	{"ALCOA", 5, 71747},
	{"MUMS", 4, 71748},
	{"GHAG", 4, 71749},
	{"VENJ", 4, 71750},
	{"SAWY", 4, 71751},
	{"BURIALS", 7, 71752},
	{"FACS", 4, 71753},
	{"TUPC", 4, 71754},
	{"JEVI", 4, 71755},
	{"EUNICE", 6, 71756},
	{"BOUNTIFUL", 9, 71757},
	{"SALAZAR", 7, 71758},
	{"LOSSLESS", 8, 71759},
	{"MMP", 3, 71760},
	{"OBRU", 4, 71761},
	{"IOBR", 4, 71762},
	{"EBYJ", 4, 71763},
	{"IMBALANCES", 10, 71764},
	{"MESOPOTAMIA", 11, 71765},
	{"JETZT", 5, 71766},
	{"ANDEAN", 6, 71767},
	{"POSEIDON", 8, 71768},
	{"SUPERCONDUCTING", 15, 71769},
	{"GLYL", 4, 71770},
	{"GICE", 4, 71771},
	{"CSWA", 4, 71772},
	{"SPECTROSCOPIC", 13, 71773},
	{"ARMPIT", 6, 71774},
	{"RATIFY", 6, 71775},
	{"DECT", 4, 71776},
	{"WORSENING", 9, 71777},
	{"SYMP", 4, 71778},
	{"METALWORKING", 12, 71779},
	{"GROUNDHOG", 9, 71780},
	{"CLOMID", 6, 71781},
	{"MEXICANS", 8, 71782},
	{"UKIS", 4, 71783},
	{"FBIA", 4, 71784},
	{"GINKGO", 6, 71785},
	{"FIEND", 5, 71786},
	{"DDIP", 4, 71787},
	{"BERNICE", 7, 71788},
	{"DEPORTED", 8, 71789},
	{"DECEDENT", 8, 71790},
	{"OBFO", 4, 71791},
	{"DIMETHYL", 8, 71792},
	{"MUZZLE", 6, 71793},
	{"ENTRANT", 7, 71794},
	{"CKUS", 4, 71795},
	{"RETVAL", 6, 71796},
	{"SCHOOLHOUSE", 11, 71797},
	{"OPENURL", 7, 71798},
	{"BAKU", 4, 71799},
	{"UCEE", 4, 71800},
	{"HMEL", 4, 71801},
	{"TELESCOPIC", 10, 71802},
	{"VESPA", 5, 71803},
	{"PHASING", 7, 71804},
	{"LACTATE", 7, 71805},
	{"LUSU", 4, 71806},
	{"POUGHKEEPSIE", 12, 71807},
	{"DODSON", 6, 71808},
	{"MONORAIL", 8, 71809},
	{"RETRIBUTION", 11, 71810},
	{"BOOKWORM", 8, 71811},
	{"ENERO", 5, 71812},
	{"SABBATICAL", 10, 71813},
	{"YUSUF", 5, 71814},
	{"STALLMAN", 8, 71815},
	{"SKEPTIC", 7, 71816},
	{"BACKLIT", 7, 71817},
	{"UYIS", 4, 71818},
	{"NUEC", 4, 71819},
	{"MSBO", 4, 71820},
	{"WFX", 3, 71821},
	{"KENTECH", 7, 71822},
	{"LAMETTE", 7, 71823},
	{"SLANDER", 7, 71824},
	{"PHDI", 4, 71825},
	{"MWAN", 4, 71826},
	{"BASING", 6, 71827},
	{"YFRU", 4, 71828},
	{"HENNEPIN", 8, 71829},
	{"FOUCAULT", 8, 71830},
	{"LEMR", 4, 71831},
	{"DLAP", 4, 71832},
	{"AXBR", 4, 71833},
	{"BAITS", 5, 71834},
	{"FIRESIDE", 8, 71835},
	{"ONSHORE", 7, 71836},
	{"ACLS", 4, 71837},
	{"PWM", 3, 71838},
	{"FLORALS", 7, 71839},
	{"LHED", 4, 71840},
	{"MILLIMETERS", 11, 71841},
	{"KRAUSS", 6, 71842},
	{"PHYB", 4, 71843},
	{"DISPOSING", 9, 71844},
	{"WICKS", 5, 71845},
	{"PATHOLOGISTS", 12, 71846},
	{"FANFICTION", 10, 71847},
	{"HERZOG", 6, 71848},
	{"PATHOL", 6, 71849},
	{"SUFFRAGE", 8, 71850},
	{"UOSR", 4, 71851},
	{"UCIF", 4, 71852},
	{"TOXICS", 6, 71853},
	{"IPCC", 4, 71854},
	{"TRIUMPHS", 8, 71855},
	{"ODSL", 4, 71856},
	{"HPLE", 4, 71857},
	{"CHIZ", 4, 71858},
	{"FORTIFYING", 10, 71859},
	{"SLEEPLESS", 9, 71860},
	{"KINESIOLOGY", 11, 71861},
	{"SCHIFF", 6, 71862},
	{"POTIONS", 7, 71863},
	{"YDAL", 4, 71864},
	{"RTIR", 4, 71865},
	{"MREV", 4, 71866},
	{"GGAS", 4, 71867},
	{"SQUIRTS", 7, 71868},
	{"DELMAR", 6, 71869},
	{"UPTS", 4, 71870},
	{"STORYBOOK", 9, 71871},
	{"WATERED", 7, 71872},
	{"GRENADES", 8, 71873},
	{"ETREX", 5, 71874},
	{"FLEAS", 5, 71875},
	{"TULLY", 5, 71876},
	{"CONTRASTED", 10, 71877},
	{"BUCC", 4, 71878},
	{"OPTING", 6, 71879},
	{"GEDV", 4, 71880},
	{"HAULED", 6, 71881},
	{"TAUPE", 5, 71882},
	{"RENTA", 5, 71883},
	{"ULPO", 4, 71884},
	{"PITW", 4, 71885},
	{"NDDY", 4, 71886},
	{"GGOI", 4, 71887},
	{"GRD", 3, 71888},
	{"JIANGSU", 7, 71889},
	{"RKAG", 4, 71890},
	{"MALN", 4, 71891},
	{"FSLO", 4, 71892},
	{"VENTURED", 8, 71893},
	{"HOOKUP", 6, 71894},
	{"RECITE", 6, 71895},
	{"MYRON", 5, 71896},
	{"NDRS", 4, 71897},
	{"KAIR", 4, 71898},
	{"CTDA", 4, 71899},
	{"DOREEN", 6, 71900},
	{"ALTIMA", 6, 71901},
	{"VENV", 4, 71902},
	{"RSUL", 4, 71903},
	{"CHHU", 4, 71904},
	{"KEEPSAKES", 9, 71905},
	{"SEAWATER", 8, 71906},
	{"ECKO", 4, 71907},
	{"ZARQAWI", 7, 71908},
	{"FEEF", 4, 71909},
	{"CONTENDERS", 10, 71910},
	{"KNEELING", 8, 71911},
	{"IRBL", 4, 71912},
	{"NEGATION", 8, 71913},
	{"OMLY", 4, 71914},
	{"IRLT", 4, 71915},
	{"DJOR", 4, 71916},
	{"CONVEYORS", 9, 71917},
	{"ACCENTURE", 9, 71918},
	{"IAGORA", 6, 71919},
	{"OOMP", 4, 71920},
	{"HAIER", 5, 71921},
	{"KISR", 4, 71922},
	{"CRUTCHFIELD", 11, 71923},
	{"IRPH", 4, 71924},
	{"AFAY", 4, 71925},
	{"DISMAY", 6, 71926},
	{"FULFILLS", 8, 71927},
	{"RARU", 4, 71928},
	{"ESYD", 4, 71929},
	{"KELSO", 5, 71930},
	{"PETALUMA", 8, 71931},
	{"SMELLED", 7, 71932},
	{"YTUN", 4, 71933},
	{"IFRS", 4, 71934},
	{"JUTE", 4, 71935},
	{"SERVICIOS", 9, 71936},
	{"PRINTMAKING", 11, 71937},
	{"HEALS", 5, 71938},
	{"MIATA", 5, 71939},
	{"JULIANNE", 8, 71940},
	{"DOTNET", 6, 71941},
	{"PRIM", 4, 71942},
	{"RECONSTRUCTIVE", 14, 71943},
	{"METCALF", 7, 71944},
	{"VICKSBURG", 9, 71945},
	{"BOOKSHELVES", 11, 71946},
	{"TRESPASS", 8, 71947},
	{"CONCILIATION", 12, 71948},
	{"SUPERMODELS", 11, 71949},
	{"WFRI", 4, 71950},
	{"TPMF", 4, 71951},
	{"GLYCEROL", 8, 71952},
	{"WISEMAN", 7, 71953},
	{"BEPI", 4, 71954},
	{"COMPASSES", 9, 71955},
	{"GROOMED", 7, 71956},
	{"LEAPING", 7, 71957},
	{"IMPUNITY", 8, 71958},
	{"SUNKEN", 6, 71959},
	{"SLIDERS", 7, 71960},
	{"XESF", 4, 71961},
	{"FPIN", 4, 71962},
	{"EEKG", 4, 71963},
	{"CARHARTT", 8, 71964},
	{"INAUGURATED", 11, 71965},
	{"ZUU", 3, 71966},
	{"YVG", 3, 71967},
	{"WDZ", 3, 71968},
	{"PYQ", 3, 71969},
	{"REDFORD", 7, 71970},
	{"WNEV", 4, 71971},
	{"ENCOUNTERING", 12, 71972},
	{"ITEMIZED", 8, 71973},
	{"YANB", 4, 71974},
	{"RAMN", 4, 71975},
	{"MGAR", 4, 71976},
	{"IGED", 4, 71977},
	{"EALV", 4, 71978},
	{"COAU", 4, 71979},
	{"INFERNAL", 8, 71980},
	{"DEFAMATORY", 10, 71981},
	{"SEWELL", 6, 71982},
	{"PANG", 4, 71983},
	{"MATHESON", 8, 71984},
	{"AMALFI", 6, 71985},
	{"CURRENTVERSION", 14, 71986},
	{"SWAG", 4, 71987},
	{"RENMINBI", 8, 71988},
	{"REARED", 6, 71989},
	{"PAMPERED", 8, 71990},
	{"RTEV", 4, 71991},
	{"OGGL", 4, 71992},
	{"IRYA", 4, 71993},
	{"MANGAS", 6, 71994},
	{"BOTTLENECKS", 11, 71995},
	{"SYWA", 4, 71996},
	{"AHYP", 4, 71997},
	{"PYREX", 5, 71998},
	{"INQUIRING", 9, 71999},
	{"HUFFINGTON", 10, 72000},
	{"SCULPTING", 9, 72001},
	{"NUMERO", 6, 72002},
	{"GENW", 4, 72003},
	{"SEDANS", 6, 72004},
	{"PRAISING", 8, 72005},
	{"HOOBASTANK", 10, 72006},
	{"MOMENTARY", 9, 72007},
	{"LAUNCHERS", 9, 72008},
	{"FINISHERS", 9, 72009},
	{"COMMEMORATION", 13, 72010},
	{"WBEE", 4, 72011},
	{"SFEM", 4, 72012},
	{"CTOC", 4, 72013},
	{"PSYCHOLOGICALLY", 15, 72014},
	{"FAVRE", 5, 72015},
	{"DGLI", 4, 72016},
	{"SCHAEFFER", 9, 72017},
	{"NORTHSIDE", 9, 72018},
	{"POLI", 4, 72019},
	{"HOLSTEIN", 8, 72020},
	{"INTERDEPENDENCE", 15, 72021},
	{"OGWA", 4, 72022},
	{"SERPENTINE", 10, 72023},
	{"MICROFINANCE", 12, 72024},
	{"DROPLETS", 8, 72025},
	{"INDUCTED", 8, 72026},
	{"HANGINGS", 8, 72027},
	{"WARV", 4, 72028},
	{"LUGAR", 5, 72029},
	{"UNINITIALIZED", 13, 72030},
	{"CONOR", 5, 72031},
	{"OWVI", 4, 72032},
	{"SUNDRY", 6, 72033},
	{"REPERCUSSIONS", 13, 72034},
	{"PROTESTANTS", 11, 72035},
	{"THEREFROM", 9, 72036},
	{"WOKING", 6, 72037},
	{"LONGMONT", 8, 72038},
	{"TDUN", 4, 72039},
	{"LOCU", 4, 72040},
	{"MEDION", 6, 72041},
	{"ESPACE", 6, 72042},
	{"MONIKA", 6, 72043},
	{"AZZL", 4, 72044},
	{"HYDROLOGICAL", 12, 72045},
	{"RUNES", 5, 72046},
	{"WRECKING", 8, 72047},
	{"HOBBYHUREN", 10, 72048},
	{"CRISTO", 6, 72049},
	{"OGLI", 4, 72050},
	{"PIQUE", 5, 72051},
	{"URPU", 4, 72052},
	{"RBYE", 4, 72053},
	{"APWI", 4, 72054},
	{"ORTEGA", 6, 72055},
	{"BREWERIES", 9, 72056},
	{"ULYR", 4, 72057},
	{"TMEC", 4, 72058},
	{"RMMO", 4, 72059},
	{"AKAP", 4, 72060},
	{"LANDON", 6, 72061},
	{"BURRELL", 7, 72062},
	{"FORECASTER", 10, 72063},
	{"QUICKIE", 7, 72064},
	{"STEPHANE", 8, 72065},
	{"TFIF", 4, 72066},
	{"SWORE", 5, 72067},
	{"PARABOLIC", 9, 72068},
	{"DTIL", 4, 72069},
	{"BOREAL", 6, 72070},
	{"BANKROLL", 8, 72071},
	{"BIOASSAY", 8, 72072},
	{"NOVEMBRE", 8, 72073},
	{"FAWCETT", 7, 72074},
	{"MARTINSVILLE", 12, 72075},
	{"ZHAD", 4, 72076},
	{"LDEM", 4, 72077},
	{"INTERVENTIONAL", 14, 72078},
	{"TABULATION", 10, 72079},
	{"NMCG", 4, 72080},
	{"EKWE", 4, 72081},
	{"JOOP", 4, 72082},
	{"JOURNEYMAN", 10, 72083},
	{"ENLIGHTEN", 9, 72084},
	{"DESCARTES", 9, 72085},
	{"WELA", 4, 72086},
	{"TSLU", 4, 72087},
	{"MIKM", 4, 72088},
	{"TRIER", 5, 72089},
	{"ARBITRAGE", 9, 72090},
	{"FLASHY", 6, 72091},
	{"KSUS", 4, 72092},
	{"IMDU", 4, 72093},
	{"PROWESS", 7, 72094},
	{"ABSTRACTIONS", 12, 72095},
	{"ENRICHING", 9, 72096},
	{"DOGWOOD", 7, 72097},
	{"TRAMPLING", 9, 72098},
	{"SIGNET", 6, 72099},
	{"BELLO", 5, 72100},
	{"IROQUOIS", 8, 72101},
	{"CONVERGENT", 10, 72102},
	{"ENVIAR", 6, 72103},
	{"DIGESTED", 8, 72104},
	{"RCOC", 4, 72105},
	{"ROTHSCHILD", 10, 72106},
	{"TRUMPETS", 8, 72107},
	{"DYFA", 4, 72108},
	{"MAJORING", 8, 72109},
	{"TECHWR", 6, 72110},
	{"GLITCHES", 8, 72111},
	{"DUGG", 4, 72112},
	{"LPCO", 4, 72113},
	{"EMBODIES", 8, 72114},
	{"QWERTY", 6, 72115},
	{"EQUIVALENCY", 11, 72116},
	{"MESSE", 5, 72117},
	{"RGYR", 4, 72118},
	{"EUPL", 4, 72119},
	{"RELA", 4, 72120},
	{"SEDATION", 8, 72121},
	{"MANHOOD", 7, 72122},
	{"KINCAID", 7, 72123},
	{"LSPU", 4, 72124},
	{"CANNIBAL", 8, 72125},
	{"QUIK", 4, 72126},
	{"YHEP", 4, 72127},
	{"ROSEMONT", 8, 72128},
	{"NEPHEWS", 7, 72129},
	{"QVG", 3, 72130},
	{"AVVY", 4, 72131},
	{"OBLIVIOUS", 9, 72132},
	{"ATMOSPHERES", 11, 72133},
	{"STRICTER", 8, 72134},
	{"HARMONICS", 9, 72135},
	{"DEVI", 4, 72136},
	{"HIGHSCHOOL", 10, 72137},
	{"ORVIS", 5, 72138},
	{"CENTIMETERS", 11, 72139},
	{"JETER", 5, 72140},
	{"MEMES", 5, 72141},
	{"LAVATORY", 8, 72142},
	{"ROUGHNESS", 9, 72143},
	{"DESTRUCTOR", 10, 72144},
	{"ACCELERATES", 11, 72145},
	{"GHVO", 4, 72146},
	{"ANCIENTS", 8, 72147},
	{"RELOCATIONS", 11, 72148},
	{"WILCO", 5, 72149},
	{"TRICARE", 7, 72150},
	{"BECKLEY", 7, 72151},
	{"SNAPPING", 8, 72152},
	{"ZEDU", 4, 72153},
	{"NBIK", 4, 72154},
	{"LMUN", 4, 72155},
	{"DGLE", 4, 72156},
	{"JETHRO", 6, 72157},
	{"RYDE", 4, 72158},
	{"JANUARI", 7, 72159},
	{"CAULIFLOWER", 11, 72160},
	{"BLACKSBURG", 10, 72161},
	{"ANOVA", 5, 72162},
	{"LNIC", 4, 72163},
	{"GDRO", 4, 72164},
	{"MIDFIELDER", 10, 72165},
	{"FEUDAL", 6, 72166},
	{"FCRU", 4, 72167},
	{"TORNADOES", 9, 72168},
	{"UNBEARABLE", 10, 72169},
	{"YUNR", 4, 72170},
	{"LONP", 4, 72171},
	{"LADD", 4, 72172},
	{"DOCKLANDS", 9, 72173},
	{"PERPETRATED", 11, 72174},
	{"TANZANIAN", 9, 72175},
	{"PADI", 4, 72176},
	{"SSYR", 4, 72177},
	{"OILB", 4, 72178},
	{"CLAMAV", 6, 72179},
	{"NNYG", 4, 72180},
	{"LKAW", 4, 72181},
	{"MEGASTORE", 9, 72182},
	{"BASSES", 6, 72183},
	{"UETR", 4, 72184},
	{"FULV", 4, 72185},
	{"XANDER", 6, 72186},
	{"JUNI", 4, 72187},
	{"BOARDED", 7, 72188},
	{"OLYMPIAN", 8, 72189},
	{"WWES", 4, 72190},
	{"PHYF", 4, 72191},
	{"WINELANDS", 9, 72192},
	{"SYLLABI", 7, 72193},
	{"ELIF", 4, 72194},
	{"LORNE", 5, 72195},
	{"OWGA", 4, 72196},
	{"EOPR", 4, 72197},
	{"NOIDA", 5, 72198},
	{"VISALIA", 7, 72199},
	{"MYKONOS", 7, 72200},
	{"KIRB", 4, 72201},
	{"WCC", 3, 72202},
	{"KRIEGER", 7, 72203},
	{"SAFEWAY", 7, 72204},
	{"RWAG", 4, 72205},
	{"SEDGWICK", 8, 72206},
	{"NNYF", 4, 72207},
	{"LMUR", 4, 72208},
	{"KRUN", 4, 72209},
	{"SHERI", 5, 72210},
	{"PROSITE", 7, 72211},
	{"LIVRE", 5, 72212},
	{"WIKIS", 5, 72213},
	{"MOZZARELLA", 10, 72214},
	{"MWRI", 4, 72215},
	{"HGOD", 4, 72216},
	{"GLENDA", 6, 72217},
	{"SYWI", 4, 72218},
	{"FFID", 4, 72219},
	{"INTERFERES", 10, 72220},
	{"EKOU", 4, 72221},
	{"CKKE", 4, 72222},
	{"DEVOTIONS", 9, 72223},
	{"MYRA", 4, 72224},
	{"DEVOTEES", 8, 72225},
	{"ACQUAINTANCES", 13, 72226},
	{"RWIR", 4, 72227},
	{"PESB", 4, 72228},
	{"HELG", 4, 72229},
	{"DQG", 3, 72230},
	{"SECTARIAN", 9, 72231},
	{"WATERVILLE", 10, 72232},
	{"YONKERS", 7, 72233},
	{"OFTD", 4, 72234},
	{"ILGO", 4, 72235},
	{"DREH", 4, 72236},
	{"FATHOM", 6, 72237},
	{"REPUBLISH", 9, 72238},
	{"COOLS", 5, 72239},
	{"RDPU", 4, 72240},
	{"KYHA", 4, 72241},
	{"ENDOSCOPIC", 10, 72242},
	{"DILBERT", 7, 72243},
	{"VFD", 3, 72244},
	{"TRANSEN", 7, 72245},
	{"KONQUEROR", 9, 72246},
	{"WNOV", 4, 72247},
	{"SEGUNDO", 7, 72248},
	{"FELIZ", 5, 72249},
	{"APPRECIATIVE", 12, 72250},
	{"INNUMERABLE", 11, 72251},
	{"YJAP", 4, 72252},
	{"TYSD", 4, 72253},
	{"SDUM", 4, 72254},
	{"CEAV", 4, 72255},
	{"PARRAMATTA", 10, 72256},
	{"LDSD", 4, 72257},
	{"BISCAYNE", 8, 72258},
	{"LMCO", 4, 72259},
	{"EMFI", 4, 72260},
	{"DEBCONF", 7, 72261},
	{"PTIL", 4, 72262},
	{"DISPROPORTIONATELY", 18, 72263},
	{"NOTICEABLY", 10, 72264},
	{"FURS", 4, 72265},
	{"TASKBAR", 7, 72266},
	{"LIBERO", 6, 72267},
	{"SYNCHROTRON", 11, 72268},
	{"MEMORIZE", 8, 72269},
	{"YSOV", 4, 72270},
	{"STYW", 4, 72271},
	{"RBTH", 4, 72272},
	{"MARQUEZ", 7, 72273},
	{"WILLISTON", 9, 72274},
	{"MUPPETS", 7, 72275},
	{"VOLUMETRIC", 10, 72276},
	{"ATONEMENT", 9, 72277},
	{"EXTANT", 6, 72278},
	{"IGNACIO", 7, 72279},
	{"UNMASK", 6, 72280},
	{"UMPIRES", 7, 72281},
	{"SHUTTLES", 8, 72282},
	{"LTPR", 4, 72283},
	{"UFV", 3, 72284},
	{"QCU", 3, 72285},
	{"JUMPSTART", 9, 72286},
	{"CHISEL", 6, 72287},
	{"RNBR", 4, 72288},
	{"MOTOGP", 6, 72289},
	{"HYPERPLASIA", 11, 72290},
	{"NBER", 4, 72291},
	{"UOLL", 4, 72292},
	{"DONAHUE", 7, 72293},
	{"MYSTERIOUSLY", 12, 72294},
	{"PARODIES", 8, 72295},
	{"MPUN", 4, 72296},
	{"PRADO", 5, 72297},
	{"WAYWARD", 7, 72298},
	{"LEGIT", 5, 72299},
	{"REDNESS", 7, 72300},
	{"UMLI", 4, 72301},
	{"RYOB", 4, 72302},
	{"HUMAX", 5, 72303},
	{"DREAMLAND", 9, 72304},
	{"SKSF", 4, 72305},
	{"SCRAPPED", 8, 72306},
	{"DILLARD", 7, 72307},
	{"WANDS", 5, 72308},
	{"ORPHANAGE", 9, 72309},
	{"ILLUSTRIOUS", 11, 72310},
	{"DISRUPTIONS", 11, 72311},
	{"ERASURE", 7, 72312},
	{"FISHY", 5, 72313},
	{"PREAMP", 6, 72314},
	{"ORGH", 4, 72315},
	{"BOWD", 4, 72316},
	{"PAUSES", 6, 72317},
	{"MCALLISTER", 10, 72318},
	{"LUEE", 4, 72319},
	{"ZIEGLER", 7, 72320},
	{"LOEWE", 5, 72321},
	{"INTOXICATION", 12, 72322},
	{"DOWLOAD", 7, 72323},
	{"XVIL", 4, 72324},
	{"IMIF", 4, 72325},
	{"IPTV", 4, 72326},
	{"BONDI", 5, 72327},
	{"FREELANCER", 10, 72328},
	{"PFLO", 4, 72329},
	{"MBTO", 4, 72330},
	{"ALFY", 4, 72331},
	{"GLIMMER", 7, 72332},
	{"FELTON", 6, 72333},
	{"DPP", 3, 72334},
	{"GHPL", 4, 72335},
	{"UMAX", 4, 72336},
	{"ODCR", 4, 72337},
	{"RADARS", 6, 72338},
	{"DMG", 3, 72339},
	{"TPMI", 4, 72340},
	{"MATERIEL", 8, 72341},
	{"MEGADETH", 8, 72342},
	{"BLOODED", 7, 72343},
	{"SLAMMING", 8, 72344},
	{"COOPERSTOWN", 11, 72345},
	{"REEJ", 4, 72346},
	{"NKEP", 4, 72347},
	{"KIEC", 4, 72348},
	{"EBIC", 4, 72349},
	{"SYLLABLES", 9, 72350},
	{"STAFFERS", 8, 72351},
	{"MAWR", 4, 72352},
	{"WHIM", 4, 72353},
	{"COMPTIA", 7, 72354},
	{"TEDDIES", 7, 72355},
	{"UPSILON", 7, 72356},
	{"FEBO", 4, 72357},
	{"SIZABLE", 7, 72358},
	{"COENZYME", 8, 72359},
	{"KLYM", 4, 72360},
	{"CSTY", 4, 72361},
	{"FILMY", 5, 72362},
	{"TIMID", 5, 72363},
	{"XPON", 4, 72364},
	{"WONR", 4, 72365},
	{"NDYH", 4, 72366},
	{"GYSO", 4, 72367},
	{"CHTW", 4, 72368},
	{"AFTERLIFE", 9, 72369},
	{"MATHER", 6, 72370},
	{"NCURSES", 7, 72371},
	{"ORDV", 4, 72372},
	{"LOFV", 4, 72373},
	{"ISMAIL", 6, 72374},
	{"HARDDRIVE", 9, 72375},
	{"CML", 3, 72376},
	{"OGYE", 4, 72377},
	{"NORJ", 4, 72378},
	{"HEKL", 4, 72379},
	{"TAMPERING", 9, 72380},
	{"RJEA", 4, 72381},
	{"COUNTERPOINT", 12, 72382},
	{"UMEW", 4, 72383},
	{"EWCU", 4, 72384},
	{"WEAVERS", 7, 72385},
	{"BATESVILLE", 10, 72386},
	{"MAGICALLY", 9, 72387},
	{"SKYWALKER", 9, 72388},
	{"TAUC", 4, 72389},
	{"FRANKE", 6, 72390},
	{"PIED", 4, 72391},
	{"THYSELF", 7, 72392},
	{"TAKASHI", 7, 72393},
	{"WRISTBAND", 9, 72394},
	{"YITD", 4, 72395},
	{"WOWH", 4, 72396},
	{"EWAF", 4, 72397},
	{"DYUN", 4, 72398},
	{"BMER", 4, 72399},
	{"JIMENEZ", 7, 72400},
	{"ESQUE", 5, 72401},
	{"CHILLER", 7, 72402},
	{"DISV", 4, 72403},
	{"ROOTING", 7, 72404},
	{"RGLE", 4, 72405},
	{"LELU", 4, 72406},
	{"PRETENDED", 9, 72407},
	{"UECR", 4, 72408},
	{"FIRO", 4, 72409},
	{"CORV", 4, 72410},
	{"BARRA", 5, 72411},
	{"THEREWITH", 9, 72412},
	{"INTERMENT", 9, 72413},
	{"WORTHING", 8, 72414},
	{"PARTITIONED", 11, 72415},
	{"JONATHON", 8, 72416},
	{"OBSB", 4, 72417},
	{"GEJO", 4, 72418},
	{"SUMP", 4, 72419},
	{"BREADCRUMB", 10, 72420},
	{"ALLER", 5, 72421},
	{"SUCROSE", 7, 72422},
	{"AMRO", 4, 72423},
	{"KSYO", 4, 72424},
	{"XCER", 4, 72425},
	{"PYFO", 4, 72426},
	{"PORTEGE", 7, 72427},
	{"NEOGEO", 6, 72428},
	{"YLZ", 3, 72429},
	{"POPULOUS", 8, 72430},
	{"RENEWABLES", 10, 72431},
	{"FILIPINA", 8, 72432},
	{"YDOA", 4, 72433},
	{"GGIO", 4, 72434},
	{"CRIV", 4, 72435},
	{"CFOO", 4, 72436},
	{"MODESTY", 7, 72437},
	{"MBAS", 4, 72438},
	{"CORTISOL", 8, 72439},
	{"RUGP", 4, 72440},
	{"PONP", 4, 72441},
	{"GOTL", 4, 72442},
	{"COVI", 4, 72443},
	{"BANSHEE", 7, 72444},
	{"SUPERSEDES", 10, 72445},
	{"VEILS", 5, 72446},
	{"BULLSEYE", 8, 72447},
	{"UGLI", 4, 72448},
	{"TMYP", 4, 72449},
	{"PREZZI", 6, 72450},
	{"FREI", 4, 72451},
	{"PACINO", 6, 72452},
	{"ROBR", 4, 72453},
	{"LFBY", 4, 72454},
	{"KSEL", 4, 72455},
	{"CAJON", 5, 72456},
	{"DOWNLOADER", 10, 72457},
	{"YKAN", 4, 72458},
	{"SEABROOK", 8, 72459},
	{"LEIF", 4, 72460},
	{"ALKR", 4, 72461},
	{"AFFC", 4, 72462},
	{"SUMPTUOUS", 9, 72463},
	{"JRR", 3, 72464},
	{"TARANAKI", 8, 72465},
	{"CHRONICALLY", 11, 72466},
	{"MERKEL", 6, 72467},
	{"MEGAMAN", 7, 72468},
	{"PRESCHOOLERS", 12, 72469},
	{"VCL", 3, 72470},
	{"LTCA", 4, 72471},
	{"FNER", 4, 72472},
	{"BYVE", 4, 72473},
	{"UNENFORCEABLE", 13, 72474},
	{"BUSI", 4, 72475},
	{"AIRU", 4, 72476},
	{"ROTC", 4, 72477},
	{"FISHEYE", 7, 72478},
	{"YHEB", 4, 72479},
	{"TGOR", 4, 72480},
	{"RJES", 4, 72481},
	{"OAXACA", 6, 72482},
	{"WAYSIDE", 7, 72483},
	{"UROA", 4, 72484},
	{"SPOTLESS", 8, 72485},
	{"GERONTOLOGY", 11, 72486},
	{"MICROSANO", 9, 72487},
	{"TYIF", 4, 72488},
	{"PREDATION", 9, 72489},
	{"KILIMANJARO", 11, 72490},
	{"EXACERBATED", 11, 72491},
	{"INFESTATION", 11, 72492},
	{"FEFR", 4, 72493},
	{"WICH", 4, 72494},
	{"OBOX", 4, 72495},
	{"OARC", 4, 72496},
	{"YARRA", 5, 72497},
	{"VOLKER", 6, 72498},
	{"SUPG", 4, 72499},
	{"LINEARITY", 9, 72500},
	{"HUEY", 4, 72501},
	{"AERIALS", 7, 72502},
	{"SUMMITS", 7, 72503},
	{"STYLIST", 7, 72504},
	{"WAVI", 4, 72505},
	{"POROSITY", 8, 72506},
	{"SCHOFIELD", 9, 72507},
	{"ALAM", 4, 72508},
	{"SPRAYER", 7, 72509},
	{"TIROL", 5, 72510},
	{"PDEC", 4, 72511},
	{"EEFU", 4, 72512},
	{"DFEN", 4, 72513},
	{"BANC", 4, 72514},
	{"GLIDERS", 7, 72515},
	{"VYRA", 4, 72516},
	{"UTHV", 4, 72517},
	{"TGIL", 4, 72518},
	{"CORBY", 5, 72519},
	{"WENATCHEE", 9, 72520},
	{"BARBED", 6, 72521},
	{"PROGNOSTIC", 10, 72522},
	{"TMYH", 4, 72523},
	{"ODBR", 4, 72524},
	{"UNREGULATED", 11, 72525},
	{"USYA", 4, 72526},
	{"OMTU", 4, 72527},
	{"LLIH", 4, 72528},
	{"PITTMAN", 7, 72529},
	{"LEGIONS", 7, 72530},
	{"BBL", 3, 72531},
	{"LUSTRE", 6, 72532},
	{"HADITH", 6, 72533},
	{"KDELIBS", 7, 72534},
	{"ECKC", 4, 72535},
	{"JAYHAWKS", 8, 72536},
	{"TEESSIDE", 8, 72537},
	{"SUNFLOWERS", 10, 72538},
	{"LGOE", 4, 72539},
	{"RRYK", 4, 72540},
	{"DOMC", 4, 72541},
	{"LOBOS", 5, 72542},
	{"YOUY", 4, 72543},
	{"SOMMER", 6, 72544},
	{"WOYO", 4, 72545},
	{"NKBU", 4, 72546},
	{"ECSTATIC", 8, 72547},
	{"REPORTABLE", 10, 72548},
	{"RYWR", 4, 72549},
	{"WLYD", 4, 72550},
	{"MAHM", 4, 72551},
	{"CAMPANIA", 8, 72552},
	{"DICKERSON", 9, 72553},
	{"UMEC", 4, 72554},
	{"RGHP", 4, 72555},
	{"CAROTENE", 8, 72556},
	{"FGK", 3, 72557},
	{"BLASPHEMY", 9, 72558},
	{"WISP", 4, 72559},
	{"LWRE", 4, 72560},
	{"DHAY", 4, 72561},
	{"FILESYSTEMS", 11, 72562},
	{"ENROLLEES", 9, 72563},
	{"COUNTENANCE", 11, 72564},
	{"OPFR", 4, 72565},
	{"BEVA", 4, 72566},
	{"SKINNING", 8, 72567},
	{"SANJAY", 6, 72568},
	{"COMPACTION", 10, 72569},
	{"LUPS", 4, 72570},
	{"JUICERS", 7, 72571},
	{"GEMM", 4, 72572},
	{"METHIONINE", 10, 72573},
	{"LALA", 4, 72574},
	{"TOPLIST", 7, 72575},
	{"HOLYOKE", 7, 72576},
	{"DEWPOINT", 8, 72577},
	{"RDIFF", 5, 72578},
	{"DELIMITER", 9, 72579},
	{"FORSAKEN", 8, 72580},
	{"RICHFIELD", 9, 72581},
	{"RECOUNTS", 8, 72582},
	{"EVOW", 4, 72583},
	{"HANGOUT", 7, 72584},
	{"STRIPTEASE", 10, 72585},
	{"SONICWALL", 9, 72586},
	{"BURGEONING", 10, 72587},
	{"ADVENTURERS", 11, 72588},
	{"SNUR", 4, 72589},
	{"LBIR", 4, 72590},
	{"OKTOBER", 7, 72591},
	{"UNICAST", 7, 72592},
	{"AMNESIA", 7, 72593},
	{"BIGOTRY", 7, 72594},
	{"CIPRO", 5, 72595},
	{"RIWO", 4, 72596},
	{"PMSU", 4, 72597},
	{"IDVI", 4, 72598},
	{"LEAKY", 5, 72599},
	{"CONTRADICTS", 11, 72600},
	{"TWEG", 4, 72601},
	{"OUSQ", 4, 72602},
	{"CHERIE", 6, 72603},
	{"KLIP", 4, 72604},
	{"LEVEN", 5, 72605},
	{"LIBXT", 5, 72606},
	{"UPBO", 4, 72607},
	{"LIDF", 4, 72608},
	{"MENSWEAR", 8, 72609},
	{"INTHEVIP", 8, 72610},
	{"WMEA", 4, 72611},
	{"MAYJ", 4, 72612},
	{"PAGANS", 6, 72613},
	{"WRENCHES", 8, 72614},
	{"ACTUATE", 7, 72615},
	{"RUEP", 4, 72616},
	{"PHAG", 4, 72617},
	{"OBSF", 4, 72618},
	{"NDOZ", 4, 72619},
	{"DINARS", 6, 72620},
	{"DIESEM", 6, 72621},
	{"BYQU", 4, 72622},
	{"AYTW", 4, 72623},
	{"CAPOTE", 6, 72624},
	{"CVD", 3, 72625},
	{"FLEXERIL", 8, 72626},
	{"MOLAR", 5, 72627},
	{"DATABANK", 8, 72628},
	{"FUME", 4, 72629},
	{"MONTEVIDEO", 10, 72630},
	{"SUNGLASS", 8, 72631},
	{"LBYS", 4, 72632},
	{"AFLOAT", 6, 72633},
	{"KASSEL", 6, 72634},
	{"RMAB", 4, 72635},
	{"OWYE", 4, 72636},
	{"NNYL", 4, 72637},
	{"ASUF", 4, 72638},
	{"BRUISED", 7, 72639},
	{"FLATTERING", 10, 72640},
	{"FOLLOWINGS", 10, 72641},
	{"SHIPLEY", 7, 72642},
	{"SAYP", 4, 72643},
	{"BRIGADES", 8, 72644},
	{"WTHW", 4, 72645},
	{"LEUR", 4, 72646},
	{"ENGROSSED", 9, 72647},
	{"ACCRETION", 9, 72648},
	{"DBLI", 4, 72649},
	{"DAOF", 4, 72650},
	{"DASHES", 6, 72651},
	{"IMPEACH", 7, 72652},
	{"SFEB", 4, 72653},
	{"ATROPHY", 7, 72654},
	{"BULLPEN", 7, 72655},
	{"MAMAS", 5, 72656},
	{"SCHREIBER", 9, 72657},
	{"BRAG", 4, 72658},
	{"DYSPLASIA", 9, 72659},
	{"FREEROLL", 8, 72660},
	{"EARLS", 5, 72661},
	{"UTOPIAN", 7, 72662},
	{"UHAR", 4, 72663},
	{"FTHP", 4, 72664},
	{"CONFERS", 7, 72665},
	{"TOTALITY", 8, 72666},
	{"ZENB", 4, 72667},
	{"RNSM", 4, 72668},
	{"RGWH", 4, 72669},
	{"NYAF", 4, 72670},
	{"OLRO", 4, 72671},
	{"DYTA", 4, 72672},
	{"HLYF", 4, 72673},
	{"HSFR", 4, 72674},
	{"NEGRIL", 6, 72675},
	{"HYPED", 5, 72676},
	{"ZRW", 3, 72677},
	{"UVY", 3, 72678},
	{"UJY", 3, 72679},
	{"EPIDERMAL", 9, 72680},
	{"BOULDERS", 8, 72681},
	{"AUTOPILOT", 9, 72682},
	{"GARZA", 5, 72683},
	{"GUPP", 4, 72684},
	{"DECRYPT", 7, 72685},
	{"BATIK", 5, 72686},
	{"NEGOTIATOR", 10, 72687},
	{"YOLANDA", 7, 72688},
	{"CRAIN", 5, 72689},
	{"SUBD", 4, 72690},
	{"AWIF", 4, 72691},
	{"UTILISING", 9, 72692},
	{"AMGR", 4, 72693},
	{"FERMANAGH", 9, 72694},
	{"MUFF", 4, 72695},
	{"INTEROPERABLE", 13, 72696},
	{"MAUDE", 5, 72697},
	{"ARSJ", 4, 72698},
	{"ODOUR", 5, 72699},
	{"DELANO", 6, 72700},
	{"BELLAMY", 7, 72701},
	{"CPHE", 4, 72702},
	{"SONJA", 5, 72703},
	{"BIOF", 4, 72704},
	{"FRINGES", 7, 72705},
	{"GOUGH", 5, 72706},
	{"EXCAVATED", 9, 72707},
	{"PLEX", 4, 72708},
	{"COMPAT", 6, 72709},
	{"UMLA", 4, 72710},
	{"GNOL", 4, 72711},
	{"BYSS", 4, 72712},
	{"SMOOTHED", 8, 72713},
	{"REPLACEABLE", 11, 72714},
	{"FORINT", 6, 72715},
	{"UPAY", 4, 72716},
	{"MGIV", 4, 72717},
	{"CYEA", 4, 72718},
	{"NUDISM", 6, 72719},
	{"NETCOM", 6, 72720},
	{"FORMULARY", 9, 72721},
	{"UGRE", 4, 72722},
	{"NDYL", 4, 72723},
	{"CILR", 4, 72724},
	{"AFFIRMS", 7, 72725},
	{"IRVIN", 5, 72726},
	{"GALERY", 6, 72727},
	{"HOUNSLOW", 8, 72728},
	{"FOSAMAX", 7, 72729},
	{"GULCH", 5, 72730},
	{"STRIPING", 8, 72731},
	{"EXCAVATING", 10, 72732},
	{"NLYJ", 4, 72733},
	{"HOJU", 4, 72734},
	{"ALDC", 4, 72735},
	{"RECOVERIES", 10, 72736},
	{"NELR", 4, 72737},
	{"MRSA", 4, 72738},
	{"MAINSTREAMING", 13, 72739},
	{"IRREVOCABLE", 11, 72740},
	{"WIEDER", 6, 72741},
	{"RSHR", 4, 72742},
	{"AMIM", 4, 72743},
	{"HOODY", 5, 72744},
	{"MOANED", 6, 72745},
	{"AXLES", 5, 72746},
	{"TIFL", 4, 72747},
	{"CHVO", 4, 72748},
	{"GERI", 4, 72749},
	{"GRACIOUSLY", 10, 72750},
	{"TTYR", 4, 72751},
	{"FTAB", 4, 72752},
	{"SEASONINGS", 10, 72753},
	{"MARCELO", 7, 72754},
	{"WROO", 4, 72755},
	{"NUEP", 4, 72756},
	{"NKSD", 4, 72757},
	{"CEEM", 4, 72758},
	{"PANTECH", 7, 72759},
	{"WQUI", 4, 72760},
	{"OACK", 4, 72761},
	{"CBRA", 4, 72762},
	{"FCP", 3, 72763},
	{"SCARICARE", 9, 72764},
	{"TZEL", 4, 72765},
	{"NRYW", 4, 72766},
	{"NGSV", 4, 72767},
	{"ROXBURY", 7, 72768},
	{"CLAMPING", 8, 72769},
	{"WHIPLASH", 8, 72770},
	{"ADMY", 4, 72771},
	{"RADIATED", 8, 72772},
	{"TAKEOFF", 7, 72773},
	{"TYRS", 4, 72774},
	{"WIGGLE", 6, 72775},
	{"TRUELY", 6, 72776},
	{"OFZE", 4, 72777},
	{"CARTESIAN", 9, 72778},
	{"BRIBE", 5, 72779},
	{"GAMEZONE", 8, 72780},
	{"PROPEL", 6, 72781},
	{"GTEM", 4, 72782},
	{"DDVD", 4, 72783},
	{"AYPM", 4, 72784},
	{"YANK", 4, 72785},
	{"OUTSPOKEN", 9, 72786},
	{"LLEWELLYN", 9, 72787},
	{"ASYMMETRICAL", 12, 72788},
	{"IDOP", 4, 72789},
	{"FESU", 4, 72790},
	{"UNIVERSITAT", 11, 72791},
	{"WILLIAMSTOWN", 12, 72792},
	{"TROLLEYS", 8, 72793},
	{"INTERLOCKING", 12, 72794},
	{"VERILY", 6, 72795},
	{"DOPED", 5, 72796},
	{"HEADBAND", 8, 72797},
	{"ARDENT", 6, 72798},
	{"INTERNETWEEK", 12, 72799},
	{"WORI", 4, 72800},
	{"GPHI", 4, 72801},
	{"EPSW", 4, 72802},
	{"OUTPERFORM", 10, 72803},
	{"HARMONIZATION", 13, 72804},
	{"FORCIBLY", 8, 72805},
	{"HAMID", 5, 72806},
	{"DIFFERENTIATING", 15, 72807},
	{"EYYO", 4, 72808},
	{"HITTERS", 7, 72809},
	{"KONRAD", 6, 72810},
	{"WICKETS", 7, 72811},
	{"TYBL", 4, 72812},
	{"LDHU", 4, 72813},
	{"ICSK", 4, 72814},
	{"RESTARTING", 10, 72815},
	{"PRESIDED", 8, 72816},
	{"MPWH", 4, 72817},
	{"LLSV", 4, 72818},
	{"BCM", 3, 72819},
	{"XILINX", 6, 72820},
	{"ODAD", 4, 72821},
	{"LIPF", 4, 72822},
	{"WIDEBAND", 8, 72823},
	{"TMOBILE", 7, 72824},
	{"ROCHA", 5, 72825},
	{"NKSR", 4, 72826},
	{"PBOX", 4, 72827},
	{"SHIMMER", 7, 72828},
	{"STEVENAGE", 9, 72829},
	{"TREMOR", 6, 72830},
	{"MOORHEAD", 8, 72831},
	{"DIRECTORIO", 10, 72832},
	{"RESTRUCTURED", 12, 72833},
	{"SEYB", 4, 72834},
	{"AERODYNAMIC", 11, 72835},
	{"HOPEWELL", 8, 72836},
	{"YVV", 3, 72837},
	{"YFJ", 3, 72838},
	{"WVF", 3, 72839},
	{"VXX", 3, 72840},
	{"UDQ", 3, 72841},
	{"BQW", 3, 72842},
	{"EVALUATIVE", 10, 72843},
	{"LOANED", 6, 72844},
	{"VIOLINS", 7, 72845},
	{"ZUMA", 4, 72846},
	{"LWED", 4, 72847},
	{"HOFK", 4, 72848},
	{"BEBI", 4, 72849},
	{"EXTRAVAGANT", 11, 72850},
	{"ANNUAIRE", 8, 72851},
	{"GHENT", 5, 72852},
	{"YSJO", 4, 72853},
	{"NMIX", 4, 72854},
	{"MCAU", 4, 72855},
	{"LZHE", 4, 72856},
	{"KISF", 4, 72857},
	{"CTDO", 4, 72858},
	{"ASTUTE", 6, 72859},
	{"JAMIESON", 8, 72860},
	{"PEMBERTON", 9, 72861},
	{"SUBTRACTING", 11, 72862},
	{"HUSP", 4, 72863},
	{"BRAM", 4, 72864},
	{"KUNA", 4, 72865},
	{"LOGBOOK", 7, 72866},
	{"RYGU", 4, 72867},
	{"HJAM", 4, 72868},
	{"LOUTH", 5, 72869},
	{"PICT", 4, 72870},
	{"INFLICT", 7, 72871},
	{"TRUETONES", 9, 72872},
	{"GABOR", 5, 72873},
	{"USIF", 4, 72874},
	{"RKEI", 4, 72875},
	{"MRUS", 4, 72876},
	{"ROTATES", 7, 72877},
	{"INVALIDATE", 10, 72878},
	{"EZCONTENTOBJECTTREENODE", 23, 72879},
	{"GMER", 4, 72880},
	{"RIDICULOUSLY", 12, 72881},
	{"LEANNE", 6, 72882},
	{"LEGIBLE", 7, 72883},
	{"MPTF", 4, 72884},
	{"FPOO", 4, 72885},
	{"BGCOLOR", 7, 72886},
	{"TOWED", 5, 72887},
	{"RESCUES", 7, 72888},
	{"FEEX", 4, 72889},
	{"BYDU", 4, 72890},
	{"RIFS", 4, 72891},
	{"MLAU", 4, 72892},
	{"DISREGARDED", 11, 72893},
	{"AUGUSTE", 7, 72894},
	{"RLWI", 4, 72895},
	{"DEIF", 4, 72896},
	{"PUC", 3, 72897},
	{"SALTED", 6, 72898},
	{"CORSA", 5, 72899},
	{"CAUSALITY", 9, 72900},
	{"TILING", 6, 72901},
	{"ETHNOGRAPHIC", 12, 72902},
	{"ATTRACTIVENESS", 14, 72903},
	{"RKUS", 4, 72904},
	{"WAFFLES", 7, 72905},
	{"DOUBLY", 6, 72906},
	{"FFES", 4, 72907},
	{"CALAMITY", 8, 72908},
	{"FANDANGO", 8, 72909},
	{"POWERMAC", 8, 72910},
	{"CATALYSIS", 9, 72911},
	{"BREWED", 6, 72912},
	{"ARISTOCRATS", 11, 72913},
	{"ANNEXES", 7, 72914},
	{"LISLE", 5, 72915},
	{"PUSHJ", 5, 72916},
	{"FIANCE", 6, 72917},
	{"OCOC", 4, 72918},
	{"SPRAWLING", 9, 72919},
	{"VULTURE", 7, 72920},
	{"NAYLOR", 6, 72921},
	{"RONX", 4, 72922},
	{"DZER", 4, 72923},
	{"MISLEAD", 7, 72924},
	{"WRONGDOING", 10, 72925},
	{"RUGI", 4, 72926},
	{"CWER", 4, 72927},
	{"AMGE", 4, 72928},
	{"VENTRAL", 7, 72929},
	{"PADUCAH", 7, 72930},
	{"XEDO", 4, 72931},
	{"OXVI", 4, 72932},
	{"NDEY", 4, 72933},
	{"GICW", 4, 72934},
	{"GUNTER", 6, 72935},
	{"RETARD", 6, 72936},
	{"DSUL", 4, 72937},
	{"BITF", 4, 72938},
	{"IRANIANS", 8, 72939},
	{"MEDIO", 5, 72940},
	{"PLATTERS", 8, 72941},
	{"RGYD", 4, 72942},
	{"HGUI", 4, 72943},
	{"EYBL", 4, 72944},
	{"CANTO", 5, 72945},
	{"COMMANDOS", 9, 72946},
	{"GERMANIC", 8, 72947},
	{"FTLE", 4, 72948},
	{"ABCD", 4, 72949},
	{"HARASSED", 8, 72950},
	{"REPEATABLE", 10, 72951},
	{"EPIPHONE", 8, 72952},
	{"OFIF", 4, 72953},
	{"DSKY", 4, 72954},
	{"DISCRIMINATED", 13, 72955},
	{"ACTY", 4, 72956},
	{"ESTELLE", 7, 72957},
	{"WEEKENDER", 9, 72958},
	{"MILNER", 6, 72959},
	{"SCHOTT", 6, 72960},
	{"WELDERS", 7, 72961},
	{"EEUP", 4, 72962},
	{"SPONGES", 7, 72963},
	{"SEMIFINALS", 10, 72964},
	{"WNSM", 4, 72965},
	{"ULKA", 4, 72966},
	{"LSFE", 4, 72967},
	{"CAVENDISH", 9, 72968},
	{"QUANTIZATION", 12, 72969},
	{"SURFACING", 9, 72970},
	{"RINY", 4, 72971},
	{"PHYR", 4, 72972},
	{"RECEPTACLES", 11, 72973},
	{"VEGETARIANS", 11, 72974},
	{"HAGERSTOWN", 10, 72975},
	{"YITB", 4, 72976},
	{"JACINTO", 7, 72977},
	{"RAYR", 4, 72978},
	{"REVERED", 7, 72979},
	{"POLYCLONAL", 10, 72980},
	{"SMFR", 4, 72981},
	{"LESQ", 4, 72982},
	{"TRANSPONDER", 11, 72983},
	{"HARASSING", 9, 72984},
	{"ERDY", 4, 72985},
	{"GOTTLIEB", 8, 72986},
	{"WITHDRAWL", 9, 72987},
	{"DISLOCATION", 11, 72988},
	{"SHINGLE", 7, 72989},
	{"LFYE", 4, 72990},
	{"GTHW", 4, 72991},
	{"GATB", 4, 72992},
	{"EJUV", 4, 72993},
	{"DEGU", 4, 72994},
	{"GENEID", 6, 72995},
	{"TIERNEY", 7, 72996},
	{"TIMBERS", 7, 72997},
	{"UNDERGOES", 9, 72998},
	{"GLOCK", 5, 72999},
	{"SKMO", 4, 73000},
	{"ICKK", 4, 73001},
	{"HEPY", 4, 73002},
	{"YBV", 3, 73003},
	{"VYQ", 3, 73004},
	{"VGG", 3, 73005},
	{"KZL", 3, 73006},
	{"GJJ", 3, 73007},
	{"DZG", 3, 73008},
	{"GUATEMALAN", 10, 73009},
	{"UNUP", 4, 73010},
	{"LSEB", 4, 73011},
	{"IGUANA", 6, 73012},
	{"MATF", 4, 73013},
	{"KSVI", 4, 73014},
	{"GLARING", 7, 73015},
	{"CIFRAS", 6, 73016},
	{"SALMAN", 6, 73017},
	{"UEAB", 4, 73018},
	{"CHOKER", 6, 73019},
	{"TILTING", 7, 73020},
	{"ECOLOGICALLY", 12, 73021},
	{"YITM", 4, 73022},
	{"CUND", 4, 73023},
	{"SCOREBOARDS", 11, 73024},
	{"CONQUERING", 10, 73025},
	{"IPBA", 4, 73026},
	{"IDSG", 4, 73027},
	{"MOHR", 4, 73028},
	{"SPACESHIP", 9, 73029},
	{"DIGIMAX", 7, 73030},
	{"MOREMI", 6, 73031},
	{"HARASS", 6, 73032},
	{"TECHNOLOGIE", 11, 73033},
	{"MEDITATE", 8, 73034},
	{"TUNICA", 6, 73035},
	{"WIRL", 4, 73036},
	{"POWERBUILDER", 12, 73037},
	{"AORTA", 5, 73038},
	{"OUKE", 4, 73039},
	{"NVOC", 4, 73040},
	{"HOBU", 4, 73041},
	{"UNCONFIRMED", 11, 73042},
	{"DIMITRI", 7, 73043},
	{"ALSACE", 6, 73044},
	{"DENOMINATED", 11, 73045},
	{"RKBO", 4, 73046},
	{"LDVO", 4, 73047},
	{"DEGENERATIVE", 12, 73048},
	{"DELVE", 5, 73049},
	{"TORREY", 6, 73050},
	{"OSTENSIBLY", 10, 73051},
	{"CELICA", 6, 73052},
	{"BELOIT", 6, 73053},
	{"EWOW", 4, 73054},
	{"ADSD", 4, 73055},
	{"SUBSTR", 6, 73056},
	{"LOWRANCE", 8, 73057},
	{"BALLANTINE", 10, 73058},
	{"CRIMP", 5, 73059},
	{"LUMPS", 5, 73060},
	{"LVOI", 4, 73061},
	{"FACIE", 5, 73062},
	{"EMPLOI", 6, 73063},
	{"CRETACEOUS", 10, 73064},
	{"MOUSEPAD", 8, 73065},
	{"MYSC", 4, 73066},
	{"UMBRIA", 6, 73067},
	{"FISHED", 6, 73068},
	{"OREGANO", 7, 73069},
	{"RASHID", 6, 73070},
	{"MICROTEK", 8, 73071},
	{"GEARY", 5, 73072},
	{"GGOE", 4, 73073},
	{"EUKR", 4, 73074},
	{"MSDA", 4, 73075},
	{"DRIZZLE", 7, 73076},
	{"BOATERS", 7, 73077},
	{"YBOM", 4, 73078},
	{"TFUE", 4, 73079},
	{"VISUALISATION", 13, 73080},
	{"BRACING", 7, 73081},
	{"MESURE", 6, 73082},
	{"MOSL", 4, 73083},
	{"CYRU", 4, 73084},
	{"COMH", 4, 73085},
	{"BRIANNA", 7, 73086},
	{"HANDLEBARS", 10, 73087},
	{"BLACKMAIL", 9, 73088},
	{"WEIGHTLOSS", 10, 73089},
	{"OWOV", 4, 73090},
	{"KDOE", 4, 73091},
	{"INTERCONNECTS", 13, 73092},
	{"PPTH", 4, 73093},
	{"PLAYTIME", 8, 73094},
	{"CORTE", 5, 73095},
	{"ENROLLMENTS", 11, 73096},
	{"OILD", 4, 73097},
	{"LDCI", 4, 73098},
	{"IFTL", 4, 73099},
	{"FWEI", 4, 73100},
	{"GYLLENHAAL", 10, 73101},
	{"CRITICALITY", 11, 73102},
	{"GEOSCIENCE", 10, 73103},
	{"MHONARC", 7, 73104},
	{"GOLIVE", 6, 73105},
	{"DEVILLE", 7, 73106},
	{"RTFU", 4, 73107},
	{"HORL", 4, 73108},
	{"MOSELEY", 7, 73109},
	{"REMORSE", 7, 73110},
	{"NAVARRE", 7, 73111},
	{"CLOUT", 5, 73112},
	{"YCOD", 4, 73113},
	{"VIAD", 4, 73114},
	{"SPACERS", 7, 73115},
	{"UNIDO", 5, 73116},
	{"JOURS", 5, 73117},
	{"NJOR", 4, 73118},
	{"IGFI", 4, 73119},
	{"EABD", 4, 73120},
	{"DEFERRAL", 8, 73121},
	{"HERSH", 5, 73122},
	{"HILLIARD", 8, 73123},
	{"SKAB", 4, 73124},
	{"VLSI", 4, 73125},
	{"KEEGAN", 6, 73126},
	{"FECES", 5, 73127},
	{"FELLA", 5, 73128},
	{"MOUNTAINEER", 11, 73129},
	{"BUTE", 4, 73130},
	{"PONDERING", 9, 73131},
	{"ACTIVEWEAR", 10, 73132},
	{"SMWI", 4, 73133},
	{"JUBI", 4, 73134},
	{"DASV", 4, 73135},
	{"TRANSCRIPTIONS", 14, 73136},
	{"METERED", 7, 73137},
	{"LITF", 4, 73138},
	{"IBUL", 4, 73139},
	{"BUGFIXES", 8, 73140},
	{"LLEU", 4, 73141},
	{"FTSC", 4, 73142},
	{"DOWC", 4, 73143},
	{"DMYB", 4, 73144},
	{"CAMI", 4, 73145},
	{"INTERNA", 7, 73146},
	{"QUINTESSENTIAL", 14, 73147},
	{"BABYCENTER", 10, 73148},
	{"GARDENA", 7, 73149},
	{"CULTURA", 7, 73150},
	{"STOCKPILE", 9, 73151},
	{"PSYCHICS", 8, 73152},
	{"PEDIATR", 7, 73153},
	{"WILLIAMSPORT", 12, 73154},
	{"WESTLAW", 7, 73155},
	{"UGEM", 4, 73156},
	{"ELTU", 4, 73157},
	{"HETERO", 6, 73158},
	{"METEORITE", 9, 73159},
	{"PURPOSELY", 9, 73160},
	{"UOFF", 4, 73161},
	{"IRCI", 4, 73162},
	{"HFAL", 4, 73163},
	{"WORSHIPPED", 10, 73164},
	{"LUCIFER", 7, 73165},
	{"EXTRUDED", 8, 73166},
	{"UNHOLY", 6, 73167},
	{"LAKH", 4, 73168},
	{"STARWARE", 8, 73169},
	{"OKEV", 4, 73170},
	{"MMID", 4, 73171},
	{"MEIG", 4, 73172},
	{"PHAGE", 5, 73173},
	{"LASZLO", 6, 73174},
	{"SPECTACLES", 10, 73175},
	{"HERNANDO", 8, 73176},
	{"DKRI", 4, 73177},
	{"DINQ", 4, 73178},
	{"DULCE", 5, 73179},
	{"VOGT", 4, 73180},
	{"MUTTERED", 8, 73181},
	{"NYJO", 4, 73182},
	{"EKTR", 4, 73183},
	{"CBRO", 4, 73184},
	{"WOLFPACK", 8, 73185},
	{"LAGS", 4, 73186},
	{"ELDRIDGE", 8, 73187},
	{"AQUILA", 6, 73188},
	{"WRAY", 4, 73189},
	{"HAJJ", 4, 73190},
	{"OYWI", 4, 73191},
	{"OKBU", 4, 73192},
	{"KLOO", 4, 73193},
	{"FYOR", 4, 73194},
	{"HOFF", 4, 73195},
	{"GQW", 3, 73196},
	{"DQF", 3, 73197},
	{"EDIRECTORY", 10, 73198},
	{"SUEC", 4, 73199},
	{"KMAD", 4, 73200},
	{"IRSL", 4, 73201},
	{"LONGSTANDING", 12, 73202},
	{"KNITWEAR", 8, 73203},
	{"SDUB", 4, 73204},
	{"BTRE", 4, 73205},
	{"APOCALYPTIC", 11, 73206},
	{"FATTIES", 7, 73207},
	{"DARMSTADT", 9, 73208},
	{"TOFQ", 4, 73209},
	{"SKYH", 4, 73210},
	{"NUPC", 4, 73211},
	{"LFSO", 4, 73212},
	{"HENCEFORTH", 10, 73213},
	{"UCSB", 4, 73214},
	{"YINY", 4, 73215},
	{"EXRO", 4, 73216},
	{"DSED", 4, 73217},
	{"FILLINGS", 8, 73218},
	{"MARTI", 5, 73219},
	{"ABERYSTWYTH", 11, 73220},
	{"OCUB", 4, 73221},
	{"HCIR", 4, 73222},
	{"ARGO", 4, 73223},
	{"INFINEON", 8, 73224},
	{"GDOG", 4, 73225},
	{"FDD", 3, 73226},
	{"INFLOWS", 7, 73227},
	{"TMPL", 4, 73228},
	{"ESTUARINE", 9, 73229},
	{"LUDW", 4, 73230},
	{"NUBUCK", 6, 73231},
	{"STRAPPING", 9, 73232},
	{"SOCIALIZATION", 13, 73233},
	{"ESTOCK", 6, 73234},
	{"UZUK", 4, 73235},
	{"TWEK", 4, 73236},
	{"ONYL", 4, 73237},
	{"MBIT", 4, 73238},
	{"EXPEDIENT", 9, 73239},
	{"UNCONDITIONALLY", 15, 73240},
	{"VALIGN", 6, 73241},
	{"VILP", 4, 73242},
	{"AGAY", 4, 73243},
	{"CAVING", 6, 73244},
	{"EUMB", 4, 73245},
	{"BLYU", 4, 73246},
	{"SECRETED", 8, 73247},
	{"ALKYL", 5, 73248},
	{"BUCH", 4, 73249},
	{"ARTICHOKE", 9, 73250},
	{"LEASEHOLD", 9, 73251},
	{"DIRECTGOV", 9, 73252},
	{"UBIQUITIN", 9, 73253},
	{"FLEF", 4, 73254},
	{"CHAUCER", 7, 73255},
	{"LIVERY", 6, 73256},
	{"RECAPTURE", 9, 73257},
	{"FUERTEVENTURA", 13, 73258},
	{"YFLY", 4, 73259},
	{"RGST", 4, 73260},
	{"CHEVALIER", 9, 73261},
	{"HAIRDRESSING", 12, 73262},
	{"RJUM", 4, 73263},
	{"ISUG", 4, 73264},
	{"INCOMPATIBILITY", 15, 73265},
	{"FECHA", 5, 73266},
	{"DPIA", 4, 73267},
	{"QUIGLEY", 7, 73268},
	{"ANCHORING", 9, 73269},
	{"YELLOWPAGES", 11, 73270},
	{"WATK", 4, 73271},
	{"LEXF", 4, 73272},
	{"EDSQ", 4, 73273},
	{"CWIN", 4, 73274},
	{"PRETEC", 6, 73275},
	{"NAVIGABLE", 9, 73276},
	{"KDEC", 4, 73277},
	{"BIOMECHANICS", 12, 73278},
	{"MICROCOMPUTER", 13, 73279},
	{"PERSONAS", 8, 73280},
	{"MILIEU", 6, 73281},
	{"UKEW", 4, 73282},
	{"DISCIPLESHIP", 12, 73283},
	{"STONEHENGE", 10, 73284},
	{"HELLA", 5, 73285},
	{"LEKM", 4, 73286},
	{"DAMC", 4, 73287},
	{"WOMACK", 6, 73288},
	{"MAGNIFIER", 9, 73289},
	{"WBRA", 4, 73290},
	{"NGTY", 4, 73291},
	{"IDIW", 4, 73292},
	{"ACDBTEXT", 8, 73293},
	{"PITNEY", 6, 73294},
	{"KNUCKLES", 8, 73295},
	{"ZOEKEN", 6, 73296},
	{"ESTERS", 6, 73297},
	{"XWIL", 4, 73298},
	{"MALK", 4, 73299},
	{"OFCOM", 5, 73300},
	{"INTERMISSION", 12, 73301},
	{"AMAV", 4, 73302},
	{"ABLATION", 8, 73303},
	{"NUTCRACKER", 10, 73304},
	{"AMAZEMENT", 9, 73305},
	{"MEDUSA", 6, 73306},
	{"PAGODA", 6, 73307},
	{"MANIFESTS", 9, 73308},
	{"DOSAGES", 7, 73309},
	{"BCOU", 4, 73310},
	{"PRIMED", 6, 73311},
	{"RECITED", 7, 73312},
	{"MULTIPLEXING", 12, 73313},
	{"MMYW", 4, 73314},
	{"ISUL", 4, 73315},
	{"INDENTATION", 11, 73316},
	{"HAZMAT", 6, 73317},
	{"REFORMERS", 9, 73318},
	{"DALHOUSIE", 9, 73319},
	{"ENSUED", 6, 73320},
	{"SHPU", 4, 73321},
	{"RNCI", 4, 73322},
	{"KEJA", 4, 73323},
	{"JUSTLY", 6, 73324},
	{"THROATS", 7, 73325},
	{"RETARDANT", 9, 73326},
	{"SHANKAR", 7, 73327},
	{"BARRAGE", 7, 73328},
	{"OVERHEADS", 9, 73329},
	{"EKWO", 4, 73330},
	{"SOUTHFIELD", 10, 73331},
	{"PARI", 4, 73332},
	{"LALM", 4, 73333},
	{"BUOYANCY", 8, 73334},
	{"AUSSI", 5, 73335},
	{"GNUSTEP", 7, 73336},
	{"ZECO", 4, 73337},
	{"VIGN", 4, 73338},
	{"VCHA", 4, 73339},
	{"CURLED", 6, 73340},
	{"RAOUL", 5, 73341},
	{"PEEPING", 7, 73342},
	{"QFL", 3, 73343},
	{"GXW", 3, 73344},
	{"AZKABAN", 7, 73345},
	{"DERMAL", 6, 73346},
	{"ETJU", 4, 73347},
	{"METAR", 5, 73348},
	{"SIZEABLE", 8, 73349},
	{"AFTERSHAVE", 10, 73350},
	{"EORU", 4, 73351},
	{"ENLU", 4, 73352},
	{"PACES", 5, 73353},
	{"HEAVIEST", 8, 73354},
	{"LAHAINA", 7, 73355},
	{"ODCL", 4, 73356},
	{"EARNERS", 7, 73357},
	{"TENDERLOIN", 10, 73358},
	{"RHEG", 4, 73359},
	{"REZS", 4, 73360},
	{"HYOR", 4, 73361},
	{"CTJU", 4, 73362},
	{"YAWH", 4, 73363},
	{"KUPI", 4, 73364},
	{"HAMBURGERS", 10, 73365},
	{"RBYL", 4, 73366},
	{"WALNUTS", 7, 73367},
	{"OLIVA", 5, 73368},
	{"GAULTIER", 8, 73369},
	{"RMCH", 4, 73370},
	{"GSHU", 4, 73371},
	{"ENUG", 4, 73372},
	{"MARGIE", 6, 73373},
	{"JOYM", 4, 73374},
	{"COFR", 4, 73375},
	{"AVAD", 4, 73376},
	{"WANDSWORTH", 10, 73377},
	{"BROADENED", 9, 73378},
	{"CALTECH", 7, 73379},
	{"LASHES", 6, 73380},
	{"STAPLETON", 9, 73381},
	{"ROEC", 4, 73382},
	{"OWLC", 4, 73383},
	{"ESPLANADE", 9, 73384},
	{"FRANCOPHONE", 11, 73385},
	{"LMEC", 4, 73386},
	{"DMEX", 4, 73387},
	{"XOXO", 4, 73388},
	{"URGC", 4, 73389},
	{"GIOR", 4, 73390},
	{"FFUR", 4, 73391},
	{"EYQU", 4, 73392},
	{"PRAIRIES", 8, 73393},
	{"COORD", 5, 73394},
	{"MANDEL", 6, 73395},
	{"CONICAL", 7, 73396},
	{"YACE", 4, 73397},
	{"MOCKING", 7, 73398},
	{"YBUC", 4, 73399},
	{"TRICKED", 7, 73400},
	{"SERENGETI", 9, 73401},
	{"ETYMOLOGY", 9, 73402},
	{"UNJU", 4, 73403},
	{"RBUN", 4, 73404},
	{"RACCOON", 7, 73405},
	{"SHRINKAGE", 9, 73406},
	{"CHEAPLY", 7, 73407},
	{"PRD", 3, 73408},
	{"ALLEGE", 6, 73409},
	{"URIS", 4, 73410},
	{"HAMSTERS", 8, 73411},
	{"IFAR", 4, 73412},
	{"CODPHENTERMINE", 14, 73413},
	{"THRASHERS", 9, 73414},
	{"SUBTLY", 6, 73415},
	{"MANSLAUGHTER", 12, 73416},
	{"CALIBRATE", 9, 73417},
	{"GILMOUR", 7, 73418},
	{"WHYB", 4, 73419},
	{"RAMBO", 5, 73420},
	{"SGAY", 4, 73421},
	{"GEIM", 4, 73422},
	{"CONSORT", 7, 73423},
	{"CLEBURNE", 8, 73424},
	{"SERRANO", 7, 73425},
	{"NIACIN", 6, 73426},
	{"STRAWBERRYNET", 13, 73427},
	{"WESSON", 6, 73428},
	{"ORMOND", 6, 73429},
	{"OXYCONTIN", 9, 73430},
	{"BIBLIOGRAPHICAL", 15, 73431},
	{"SBUC", 4, 73432},
	{"FAQU", 4, 73433},
	{"BSPE", 4, 73434},
	{"FLEETING", 8, 73435},
	{"WYNNE", 5, 73436},
	{"GLYPH", 5, 73437},
	{"NAGIOS", 6, 73438},
	{"MARINATED", 9, 73439},
	{"MARKO", 5, 73440},
	{"SIBLEY", 6, 73441},
	{"GENOTYPES", 9, 73442},
	{"CONDE", 5, 73443},
	{"OAUD", 4, 73444},
	{"ALFORD", 6, 73445},
	{"HFUR", 4, 73446},
	{"MADURAI", 7, 73447},
	{"EVACUEES", 8, 73448},
	{"URBANIZATION", 12, 73449},
	{"KILGORE", 7, 73450},
	{"ORDK", 4, 73451},
	{"HKAR", 4, 73452},
	{"UNWIRED", 7, 73453},
	{"ELSEIF", 6, 73454},
	{"PNEUMONIAE", 10, 73455},
	{"UOSG", 4, 73456},
	{"PULO", 4, 73457},
	{"HMCC", 4, 73458},
	{"PLUMB", 5, 73459},
	{"EBAGS", 5, 73460},
	{"PEMB", 4, 73461},
	{"NEEDLEWORK", 10, 73462},
	{"TOOLED", 6, 73463},
	{"INTERMEC", 8, 73464},
	{"CHARLOTTETOWN", 13, 73465},
	{"SUBMERSIBLE", 11, 73466},
	{"ZELA", 4, 73467},
	{"EPOK", 4, 73468},
	{"CONDENSATE", 10, 73469},
	{"MATCHUP", 7, 73470},
	{"CABALLERO", 9, 73471},
	{"UNDEFEATED", 10, 73472},
	{"ANNOYANCES", 10, 73473},
	{"YETM", 4, 73474},
	{"CFIL", 4, 73475},
	{"MOVIN", 5, 73476},
	{"ZMR", 3, 73477},
	{"WVG", 3, 73478},
	{"VCY", 3, 73479},
	{"LQV", 3, 73480},
	{"CZG", 3, 73481},
	{"VIDIO", 5, 73482},
	{"BACCHUS", 7, 73483},
	{"LKNE", 4, 73484},
	{"HUSU", 4, 73485},
	{"CHUCKLE", 7, 73486},
	{"PHOTOGRAPHING", 13, 73487},
	{"POCONO", 6, 73488},
	{"UNFOLDED", 8, 73489},
	{"TRACKERS", 8, 73490},
	{"KINKADE", 7, 73491},
	{"UNIFY", 5, 73492},
	{"DISSIDENT", 9, 73493},
	{"SPERRY", 6, 73494},
	{"BEDP", 4, 73495},
	{"IFRAME", 6, 73496},
	{"ICOV", 4, 73497},
	{"GNIC", 4, 73498},
	{"ISRAELITES", 10, 73499},
	{"COMMU", 5, 73500},
	{"BRIAR", 5, 73501},
	{"JOEC", 4, 73502},
	{"XTERM", 5, 73503},
	{"WAVY", 4, 73504},
	{"SWAPPED", 7, 73505},
	{"VERMILLION", 10, 73506},
	{"MOULDS", 6, 73507},
	{"ANGIOGRAPHY", 11, 73508},
	{"WLYI", 4, 73509},
	{"MGER", 4, 73510},
	{"AREACONNECT", 11, 73511},
	{"BROCKTON", 8, 73512},
	{"SKEV", 4, 73513},
	{"ABCDEFGHIJKLMNOPQRSTUVWXYZ", 26, 73514},
	{"HINDERED", 8, 73515},
	{"DUNST", 5, 73516},
	{"LIVONIA", 7, 73517},
	{"SPECIALISATION", 14, 73518},
	{"BLOATED", 7, 73519},
	{"JRAN", 4, 73520},
	{"EVIB", 4, 73521},
	{"WALGREENS", 9, 73522},
	{"PRANKS", 6, 73523},
	{"PLASTICITY", 10, 73524},
	{"DKHA", 4, 73525},
	{"MANTEL", 6, 73526},
	{"CRUX", 4, 73527},
	{"OSPU", 4, 73528},
	{"GNSF", 4, 73529},
	{"EFFA", 4, 73530},
	{"LANGUEDOC", 9, 73531},
	{"FATIMA", 6, 73532},
	{"ARMBAND", 7, 73533},
	{"LEAMINGTON", 10, 73534},
	{"EBBL", 4, 73535},
	{"MOSLEY", 6, 73536},
	{"DISORDERED", 10, 73537},
	{"BELATED", 7, 73538},
	{"MCHR", 4, 73539},
	{"DSTW", 4, 73540},
	{"STEMMED", 7, 73541},
	{"APPLEBY", 7, 73542},
	{"GRAYSCALE", 9, 73543},
	{"LABONTE", 7, 73544},
	{"SREU", 4, 73545},
	{"KFOL", 4, 73546},
	{"EKSF", 4, 73547},
	{"CARTOONIST", 10, 73548},
	{"ENGLISHMAN", 10, 73549},
	{"FLOTATION", 9, 73550},
	{"GEOL", 4, 73551},
	{"WINDER", 6, 73552},
	{"PARALYZED", 9, 73553},
	{"DETERRENCE", 10, 73554},
	{"RKPO", 4, 73555},
	{"KCAS", 4, 73556},
	{"DBUN", 4, 73557},
	{"JUNTA", 5, 73558},
	{"CARDIN", 6, 73559},
	{"SHRUNK", 6, 73560},
	{"CRAMMED", 7, 73561},
	{"AARDVARK", 8, 73562},
	{"COSMOLOGICAL", 12, 73563},
	{"DOTHAN", 6, 73564},
	{"DREU", 4, 73565},
	{"ISOTOPIC", 8, 73566},
	{"HADLEIONOV", 10, 73567},
	{"LANGFORD", 8, 73568},
	{"HATCHET", 7, 73569},
	{"UNSUSPECTING", 12, 73570},
	{"UNDERSTATED", 11, 73571},
	{"YIRA", 4, 73572},
	{"THWR", 4, 73573},
	{"RBEY", 4, 73574},
	{"BUSW", 4, 73575},
	{"RANDOMISED", 10, 73576},
	{"AMPHETAMINE", 11, 73577},
	{"OJIM", 4, 73578},
	{"KFOO", 4, 73579},
	{"GROUT", 5, 73580},
	{"DISMISSING", 10, 73581},
	{"REBA", 4, 73582},
	{"WRX", 3, 73583},
	{"RSGI", 4, 73584},
	{"XASR", 4, 73585},
	{"BHARAT", 6, 73586},
	{"CETERA", 6, 73587},
	{"WINDFALL", 8, 73588},
	{"CUPB", 4, 73589},
	{"FILAMENTS", 9, 73590},
	{"JOCELYN", 7, 73591},
	{"KILOMETRE", 9, 73592},
	{"TRISTAR", 7, 73593},
	{"GIPPSLAND", 9, 73594},
	{"PASTELS", 7, 73595},
	{"COMPANIONSHIP", 13, 73596},
	{"LABY", 4, 73597},
	{"DIMO", 4, 73598},
	{"STALLIONS", 9, 73599},
	{"CREEPER", 7, 73600},
	{"UPSB", 4, 73601},
	{"NBCA", 4, 73602},
	{"PARAMEDICS", 10, 73603},
	{"CUANDO", 6, 73604},
	{"EPIDEMICS", 9, 73605},
	{"FISHBASE", 8, 73606},
	{"ILLEGITIMATE", 12, 73607},
	{"ROLLA", 5, 73608},
	{"CURIE", 5, 73609},
	{"BOOTABLE", 8, 73610},
	{"USOM", 4, 73611},
	{"AYVE", 4, 73612},
	{"AFTM", 4, 73613},
	{"SLAG", 4, 73614},
	{"SOURCEWATCH", 11, 73615},
	{"WNCR", 4, 73616},
	{"UNDISTURBED", 11, 73617},
	{"DECIMALS", 8, 73618},
	{"RLDG", 4, 73619},
	{"OKSU", 4, 73620},
	{"LJAM", 4, 73621},
	{"KCOR", 4, 73622},
	{"HJER", 4, 73623},
	{"CIAW", 4, 73624},
	{"TRANSCENDENTAL", 14, 73625},
	{"YVID", 4, 73626},
	{"CATANIA", 7, 73627},
	{"GEORGINA", 8, 73628},
	{"CHANTILLY", 9, 73629},
	{"GHPI", 4, 73630},
	{"COUNTERTOPS", 11, 73631},
	{"FARMED", 6, 73632},
	{"XPY", 3, 73633},
	{"VXC", 3, 73634},
	{"KXV", 3, 73635},
	{"FYQ", 3, 73636},
	{"FUENTES", 7, 73637},
	{"OPTR", 4, 73638},
	{"CKFL", 4, 73639},
	{"PAOLA", 5, 73640},
	{"ELWOOD", 6, 73641},
	{"MALO", 4, 73642},
	{"HOCKING", 7, 73643},
	{"PRERELEASE", 10, 73644},
	{"SEQTYPE", 7, 73645},
	{"FEMORAL", 7, 73646},
	{"EAUF", 4, 73647},
	{"VISCERAL", 8, 73648},
	{"UPTL", 4, 73649},
	{"KSKI", 4, 73650},
	{"DYAC", 4, 73651},
	{"FRUCTOSE", 8, 73652},
	{"COMPLICATE", 10, 73653},
	{"SILVERSTEIN", 11, 73654},
	{"BRODERICK", 9, 73655},
	{"ZOOMING", 7, 73656},
	{"ALSTON", 6, 73657},
	{"RREH", 4, 73658},
	{"IRNU", 4, 73659},
	{"INDISTINGUISHABLE", 17, 73660},
	{"HAMASAKI", 8, 73661},
	{"KESWICK", 7, 73662},
	{"EXTINGUISHER", 12, 73663},
	{"SUBPOENAS", 9, 73664},
	{"SPIELE", 6, 73665},
	{"RINCON", 6, 73666},
	{"VINR", 4, 73667},
	{"PLL", 3, 73668},
	{"DONNY", 5, 73669},
	{"VITALE", 6, 73670},
	{"FLEDGLING", 9, 73671},
	{"BOINC", 5, 73672},
	{"TRAVERSAL", 9, 73673},
	{"BAGDER", 6, 73674},
	{"ERICK", 5, 73675},
	{"SKILLFUL", 8, 73676},
	{"KCAL", 4, 73677},
	{"UCEL", 4, 73678},
	{"MIDFIELD", 8, 73679},
	{"HYPERSENSITIVITY", 16, 73680},
	{"GROOT", 5, 73681},
	{"REDSHIFT", 8, 73682},
	{"GLASER", 6, 73683},
	{"AGAW", 4, 73684},
	{"CUSCO", 5, 73685},
	{"IMAGEMAGICK", 11, 73686},
	{"FERNANDES", 9, 73687},
	{"UVIA", 4, 73688},
	{"COMPENSATING", 12, 73689},
	{"PROSTHESIS", 10, 73690},
	{"UNAU", 4, 73691},
	{"RITF", 4, 73692},
	{"BYYE", 4, 73693},
	{"APHD", 4, 73694},
	{"OVERRATED", 9, 73695},
	{"UEDP", 4, 73696},
	{"TFLU", 4, 73697},
	{"RKAM", 4, 73698},
	{"BDUE", 4, 73699},
	{"BCTH", 4, 73700},
	{"BEDM", 4, 73701},
	{"REASONABLENESS", 14, 73702},
	{"ARKV", 4, 73703},
	{"OMRON", 5, 73704},
	{"NUANCES", 7, 73705},
	{"ALBERGHI", 8, 73706},
	{"ELECTRICALS", 11, 73707},
	{"KNUCKLE", 7, 73708},
	{"UPSM", 4, 73709},
	{"SSWR", 4, 73710},
	{"KELP", 4, 73711},
	{"TAKER", 5, 73712},
	{"GEGE", 4, 73713},
	{"PLACEHOLDER", 11, 73714},
	{"MOULTON", 7, 73715},
	{"YALL", 4, 73716},
	{"UEAD", 4, 73717},
	{"GHFE", 4, 73718},
	{"CROT", 4, 73719},
	{"BASTION", 7, 73720},
	{"NPDES", 5, 73721},
	{"RUSP", 4, 73722},
	{"DREO", 4, 73723},
	{"MASSAGES", 8, 73724},
	{"GBUL", 4, 73725},
	{"CATALIST", 8, 73726},
	{"METARATING", 10, 73727},
	{"TUPELO", 6, 73728},
	{"SYRIANA", 7, 73729},
	{"GYPSIES", 7, 73730},
	{"CONCURRING", 10, 73731},
	{"DBMS", 4, 73732},
	{"VIDEOTAPES", 10, 73733},
	{"ASSEMBLAGE", 10, 73734},
	{"NSYR", 4, 73735},
	{"DEOB", 4, 73736},
	{"BACKSEAT", 8, 73737},
	{"KAUFFMAN", 8, 73738},
	{"MANIPULATIONS", 13, 73739},
	{"ACCOMODATE", 10, 73740},
	{"ALIW", 4, 73741},
	{"TIOGA", 5, 73742},
	{"UYIT", 4, 73743},
	{"IDAU", 4, 73744},
	{"WATERY", 6, 73745},
	{"SUBMENU", 7, 73746},
	{"KWACHA", 6, 73747},
	{"JUANITA", 7, 73748},
	{"COILED", 6, 73749},
	{"UBCA", 4, 73750},
	{"LTAM", 4, 73751},
	{"YUCATAN", 7, 73752},
	{"SIPPING", 7, 73753},
	{"CHONDROITIN", 11, 73754},
	{"BEATRIX", 7, 73755},
	{"SANDPIPER", 9, 73756},
	{"TMIR", 4, 73757},
	{"MBYA", 4, 73758},
	{"VAMP", 4, 73759},
	{"CHEERFULLY", 10, 73760},
	{"OVERARCHING", 11, 73761},
	{"JANES", 5, 73762},
	{"SELECTORS", 9, 73763},
	{"CONDOLEEZZA", 11, 73764},
	{"INTERNATIONALS", 14, 73765},
	{"LGON", 4, 73766},
	{"GHNU", 4, 73767},
	{"EABC", 4, 73768},
	{"DPON", 4, 73769},
	{"ESTUARIES", 9, 73770},
	{"SCHULZE", 7, 73771},
	{"PALEONTOLOGY", 12, 73772},
	{"YROY", 4, 73773},
	{"PMEE", 4, 73774},
	{"LFEN", 4, 73775},
	{"EOUL", 4, 73776},
	{"ASYB", 4, 73777},
	{"SLEDGE", 6, 73778},
	{"EMPORIO", 7, 73779},
	{"STEPPER", 7, 73780},
	{"GILDED", 6, 73781},
	{"REYKJAVIK", 9, 73782},
	{"MURDERING", 9, 73783},
	{"WPAT", 4, 73784},
	{"LTDE", 4, 73785},
	{"WATERSKIING", 11, 73786},
	{"DIJON", 5, 73787},
	{"WSUR", 4, 73788},
	{"KJET", 4, 73789},
	{"XKW", 3, 73790},
	{"RENFREWSHIRE", 12, 73791},
	{"UNBROKEN", 8, 73792},
	{"MFIG", 4, 73793},
	{"LPSO", 4, 73794},
	{"SUPERHEROES", 11, 73795},
	{"SAGES", 5, 73796},
	{"OUBR", 4, 73797},
	{"TROPIC", 6, 73798},
	{"URSK", 4, 73799},
	{"RDTD", 4, 73800},
	{"ETPU", 4, 73801},
	{"EJAV", 4, 73802},
	{"CAPELLA", 7, 73803},
	{"MARG", 4, 73804},
	{"LEFTOVERS", 9, 73805},
	{"BEIM", 4, 73806},
	{"MARIANO", 7, 73807},
	{"BANGBOAT", 8, 73808},
	{"CONDEMNING", 10, 73809},
	{"GUESTROOMS", 10, 73810},
	{"URETHANE", 8, 73811},
	{"STOUGHTON", 9, 73812},
	{"PAPHOS", 6, 73813},
	{"UITL", 4, 73814},
	{"SODU", 4, 73815},
	{"EPEP", 4, 73816},
	{"ALZH", 4, 73817},
	{"ENTOURAGE", 9, 73818},
	{"SPRINKLERS", 10, 73819},
	{"TRAVERS", 7, 73820},
	{"YMIX", 4, 73821},
	{"NRAY", 4, 73822},
	{"LGOD", 4, 73823},
	{"ERTZ", 4, 73824},
	{"EECR", 4, 73825},
	{"FAMILIA", 7, 73826},
	{"DATSUN", 6, 73827},
	{"SAINSBURY", 9, 73828},
	{"CHEFMOZ", 7, 73829},
	{"RBIC", 4, 73830},
	{"OKCH", 4, 73831},
	{"HLYB", 4, 73832},
	{"DDYN", 4, 73833},
	{"YVETTE", 6, 73834},
	{"REALIST", 7, 73835},
	{"IUMR", 4, 73836},
	{"ILVI", 4, 73837},
	{"PROCMAIL", 8, 73838},
	{"MIDSOLE", 7, 73839},
	{"AYUDA", 5, 73840},
	{"MWID", 4, 73841},
	{"FFHO", 4, 73842},
	{"GEOCHEMISTRY", 12, 73843},
	{"REFLECTIVITY", 12, 73844},
	{"MOOG", 4, 73845},
	{"DSIF", 4, 73846},
	{"SUPPRESSING", 11, 73847},
	{"DURAND", 6, 73848},
	{"LINEA", 5, 73849},
	{"BUTTERWORTH", 11, 73850},
	{"OUOR", 4, 73851},
	{"OFMP", 4, 73852},
	{"DATAGRID", 8, 73853},
	{"METETRA", 7, 73854},
	{"ILSL", 4, 73855},
	{"RODRIGUES", 9, 73856},
	{"SCORN", 5, 73857},
	{"CRUSADES", 8, 73858},
	{"RPOC", 4, 73859},
	{"OYSM", 4, 73860},
	{"HIPU", 4, 73861},
	{"GKIC", 4, 73862},
	{"PRIS", 4, 73863},
	{"DSDR", 4, 73864},
	{"WHIRL", 5, 73865},
	{"APPRENTICESHIPS", 15, 73866},
	{"ONCOL", 5, 73867},
	{"PERVERT", 7, 73868},
	{"ASYMPTOMATIC", 12, 73869},
	{"RETAILS", 7, 73870},
	{"DEFENCES", 8, 73871},
	{"HUMILIATING", 11, 73872},
	{"OFFROAD", 7, 73873},
	{"UDCO", 4, 73874},
	{"OMQU", 4, 73875},
	{"OKDE", 4, 73876},
	{"BUSR", 4, 73877},
	{"SIMPLETECH", 10, 73878},
	{"CIRCLED", 7, 73879},
	{"WITHERS", 7, 73880},
	{"SPROUT", 6, 73881},
	{"GORW", 4, 73882},
	{"ALEJ", 4, 73883},
	{"ELICITED", 8, 73884},
	{"SWIRLING", 8, 73885},
	{"OLUL", 4, 73886},
	{"OCRY", 4, 73887},
	{"LFPA", 4, 73888},
	{"DDUP", 4, 73889},
	{"GANDALF", 7, 73890},
	{"MINOT", 5, 73891},
	{"CAMPOS", 6, 73892},
	{"PINV", 4, 73893},
	{"HBOB", 4, 73894},
	{"EVIDENTIARY", 11, 73895},
	{"CLINGING", 8, 73896},
	{"RUMW", 4, 73897},
	{"AWIR", 4, 73898},
	{"BUNCHES", 7, 73899},
	{"BAGGED", 6, 73900},
	{"RIPR", 4, 73901},
	{"GPET", 4, 73902},
	{"DPIP", 4, 73903},
	{"WHELAN", 6, 73904},
	{"DECU", 4, 73905},
	{"ARUB", 4, 73906},
	{"SYNTHESIZE", 10, 73907},
	{"LOCALISATION", 12, 73908},
	{"NEGOTIATORS", 11, 73909},
	{"NFIX", 4, 73910},
	{"EGOW", 4, 73911},
	{"DEVIATE", 7, 73912},
	{"LAPAROSCOPIC", 12, 73913},
	{"HOTELGUIDE", 10, 73914},
	{"BAYVIEW", 7, 73915},
	{"NUPH", 4, 73916},
	{"HBRU", 4, 73917},
	{"OVERRIDDEN", 10, 73918},
	{"SORENSEN", 8, 73919},
	{"BLACKENED", 9, 73920},
	{"HINDS", 5, 73921},
	{"MANAGMENT", 9, 73922},
	{"WHEREUPON", 9, 73923},
	{"RIWH", 4, 73924},
	{"GSAV", 4, 73925},
	{"ECAG", 4, 73926},
	{"RACIALLY", 8, 73927},
	{"STINKY", 6, 73928},
	{"RIVERTON", 8, 73929},
	{"EXPERTLY", 8, 73930},
	{"UGEH", 4, 73931},
	{"HMYS", 4, 73932},
	{"HCIV", 4, 73933},
	{"FINM", 4, 73934},
	{"ECCH", 4, 73935},
	{"DYGA", 4, 73936},
	{"MGC", 3, 73937},
	{"MURIEL", 6, 73938},
	{"WOEX", 4, 73939},
	{"GEKI", 4, 73940},
	{"FHIL", 4, 73941},
	{"LANGKAWI", 8, 73942},
	{"MYEN", 4, 73943},
	{"AMHU", 4, 73944},
	{"HOSTILITIES", 11, 73945},
	{"ATELIER", 7, 73946},
	{"FTPD", 4, 73947},
	{"YYW", 3, 73948},
	{"UYQ", 3, 73949},
	{"COLLOIDAL", 9, 73950},
	{"GUARANTOR", 9, 73951},
	{"IMPERIALIST", 11, 73952},
	{"VENEERS", 7, 73953},
	{"REAFFIRMED", 10, 73954},
	{"ZAMBEZI", 7, 73955},
	{"YBOS", 4, 73956},
	{"TIBIA", 5, 73957},
	{"RAQUEL", 6, 73958},
	{"PENNED", 6, 73959},
	{"KIDDIE", 6, 73960},
	{"CONTE", 5, 73961},
	{"TULARE", 6, 73962},
	{"VENTURI", 7, 73963},
	{"PIGE", 4, 73964},
	{"EMFA", 4, 73965},
	{"BOWT", 4, 73966},
	{"BIAU", 4, 73967},
	{"SUNDRIES", 8, 73968},
	{"HORATIO", 7, 73969},
	{"CHEERED", 7, 73970},
	{"LINEBACKER", 10, 73971},
	{"FADU", 4, 73972},
	{"DANZIG", 6, 73973},
	{"NEUROL", 6, 73974},
	{"EUSL", 4, 73975},
	{"BEANIES", 7, 73976},
	{"IRREDUCIBLE", 11, 73977},
	{"TAXW", 4, 73978},
	{"NROG", 4, 73979},
	{"EYAF", 4, 73980},
	{"TRIXIE", 6, 73981},
	{"RIDGEWAY", 8, 73982},
	{"BLED", 4, 73983},
	{"HENCKELS", 8, 73984},
	{"VERIFIER", 8, 73985},
	{"VIEB", 4, 73986},
	{"DIMENSIONNAME", 13, 73987},
	{"THROBBING", 9, 73988},
	{"FBYT", 4, 73989},
	{"SLEEPERS", 8, 73990},
	{"ULRO", 4, 73991},
	{"PITB", 4, 73992},
	{"BVER", 4, 73993},
	{"EURASIAN", 8, 73994},
	{"FEOR", 4, 73995},
	{"FARU", 4, 73996},
	{"DCOI", 4, 73997},
	{"SEITEN", 6, 73998},
	{"NJAR", 4, 73999},
	{"MPAY", 4, 74000},
	{"EAUW", 4, 74001},
	{"GALBRAITH", 9, 74002},
	{"FGRI", 4, 74003},
	{"SALLIE", 6, 74004},
	{"ZZER", 4, 74005},
	{"GDOI", 4, 74006},
	{"ERKU", 4, 74007},
	{"SOLACE", 6, 74008},
	{"PESKY", 5, 74009},
	{"QWAR", 4, 74010},
	{"OFRH", 4, 74011},
	{"ICTD", 4, 74012},
	{"UNDERWIRE", 9, 74013},
	{"LUCIEN", 6, 74014},
	{"HAVRE", 5, 74015},
	{"ALLQ", 4, 74016},
	{"MOLES", 5, 74017},
	{"SALVIA", 6, 74018},
	{"UNLOADED", 8, 74019},
	{"PROJECTILE", 10, 74020},
	{"RADIOSHACK", 10, 74021},
	{"SPORTSTAR", 9, 74022},
	{"ALANA", 5, 74023},
	{"TRANSPLANTED", 12, 74024},
	{"IFLI", 4, 74025},
	{"BANDAGES", 8, 74026},
	{"UPD", 3, 74027},
	{"DUMA", 4, 74028},
	{"DDBJ", 4, 74029},
	{"HANDCUFFS", 9, 74030},
	{"RKFI", 4, 74031},
	{"DRUP", 4, 74032},
	{"SCRIPTED", 8, 74033},
	{"RKNI", 4, 74034},
	{"GSEP", 4, 74035},
	{"DNUT", 4, 74036},
	{"BEACONS", 7, 74037},
	{"MUTAGENESIS", 11, 74038},
	{"SSKY", 4, 74039},
	{"LKID", 4, 74040},
	{"STUCCO", 6, 74041},
	{"POSADA", 6, 74042},
	{"VOCALISTS", 9, 74043},
	{"TIBURON", 7, 74044},
	{"INTRINSICALLY", 13, 74045},
	{"LPC", 3, 74046},
	{"GEIGER", 6, 74047},
	{"CMYK", 4, 74048},
	{"EVERLAST", 8, 74049},
	{"GESCHICHTEN", 11, 74050},
	{"OBITS", 5, 74051},
	{"JEKYLL", 6, 74052},
	{"SPORTSBOOKS", 11, 74053},
	{"IMPERVIOUS", 10, 74054},
	{"ANDAMAN", 7, 74055},
	{"YPOU", 4, 74056},
	{"IFYH", 4, 74057},
	{"HALLAM", 6, 74058},
	{"SPOOFING", 8, 74059},
	{"RAHW", 4, 74060},
	{"ROCKHAMPTON", 11, 74061},
	{"REAUTHORIZATION", 15, 74062},
	{"POOLSIDE", 8, 74063},
	{"SHAMS", 5, 74064},
	{"SHAWLS", 6, 74065},
	{"XIAMEN", 6, 74066},
	{"FLOURISHING", 11, 74067},
	{"SHCU", 4, 74068},
	{"NELU", 4, 74069},
	{"MFAM", 4, 74070},
	{"FKEE", 4, 74071},
	{"PRECEDES", 8, 74072},
	{"BRUISES", 7, 74073},
	{"CHOPARD", 7, 74074},
	{"NKRI", 4, 74075},
	{"LSIF", 4, 74076},
	{"SKEPTICS", 8, 74077},
	{"YCAB", 4, 74078},
	{"RKAD", 4, 74079},
	{"DMYM", 4, 74080},
	{"INSTRUCTS", 9, 74081},
	{"PALATINE", 8, 74082},
	{"MOTORIST", 8, 74083},
	{"LFDI", 4, 74084},
	{"GUYE", 4, 74085},
	{"FFIF", 4, 74086},
	{"KWIK", 4, 74087},
	{"PERITONEAL", 10, 74088},
	{"JAFFE", 5, 74089},
	{"ZAKH", 4, 74090},
	{"UFFW", 4, 74091},
	{"NBUN", 4, 74092},
	{"KEPU", 4, 74093},
	{"EZED", 4, 74094},
	{"ELOM", 4, 74095},
	{"FREEBIE", 7, 74096},
	{"HARARE", 6, 74097},
	{"TUNBRIDGE", 9, 74098},
	{"SPYCAM", 6, 74099},
	{"LOWES", 5, 74100},
	{"LINETO", 6, 74101},
	{"NCAAB", 5, 74102},
	{"RFRU", 4, 74103},
	{"CARNATION", 9, 74104},
	{"PUBLICIZE", 9, 74105},
	{"YACI", 4, 74106},
	{"YWJ", 3, 74107},
	{"KANGAROOS", 9, 74108},
	{"MMYT", 4, 74109},
	{"NEOHAPSIS", 9, 74110},
	{"SANIBEL", 7, 74111},
	{"BULIMIA", 7, 74112},
	{"NEWQUAY", 7, 74113},
	{"INTROS", 6, 74114},
	{"RIOP", 4, 74115},
	{"LADYBUG", 7, 74116},
	{"ANALYSER", 8, 74117},
	{"ARMANDO", 7, 74118},
	{"CONWY", 5, 74119},
	{"DIJU", 4, 74120},
	{"SLUM", 4, 74121},
	{"RUFFLE", 6, 74122},
	{"ALGORITHMIC", 11, 74123},
	{"RECTIFIER", 9, 74124},
	{"BANKNOTES", 9, 74125},
	{"BOOKSHOT", 8, 74126},
	{"YGOR", 4, 74127},
	{"LTAF", 4, 74128},
	{"KONB", 4, 74129},
	{"EWQU", 4, 74130},
	{"BASSOON", 7, 74131},
	{"KNACK", 5, 74132},
	{"NNUC", 4, 74133},
	{"RIVET", 5, 74134},
	{"ARAGON", 6, 74135},
	{"SCRAPBOOKS", 10, 74136},
	{"HYDROPOWER", 10, 74137},
	{"RDOB", 4, 74138},
	{"NGXI", 4, 74139},
	{"AGGIE", 5, 74140},
	{"TILLY", 5, 74141},
	{"OWDT", 4, 74142},
	{"SONYA", 5, 74143},
	{"CLEARANCES", 10, 74144},
	{"DAJU", 4, 74145},
	{"CSIG", 4, 74146},
	{"DENOMINATIONAL", 14, 74147},
	{"GRUNT", 5, 74148},
	{"DOMINGUEZ", 9, 74149},
	{"WOFL", 4, 74150},
	{"MCCR", 4, 74151},
	{"TAMRON", 6, 74152},
	{"TALMUD", 6, 74153},
	{"DFID", 4, 74154},
	{"VLANS", 5, 74155},
	{"UZZE", 4, 74156},
	{"HULE", 4, 74157},
	{"SPREADER", 8, 74158},
	{"GRAMMARS", 8, 74159},
	{"OTOLARYNGOLOGY", 14, 74160},
	{"RDMU", 4, 74161},
	{"MTEM", 4, 74162},
	{"OVERALLS", 8, 74163},
	{"EZINES", 6, 74164},
	{"VBSEO", 5, 74165},
	{"SNOWMOBILES", 11, 74166},
	{"ULSC", 4, 74167},
	{"DUAR", 4, 74168},
	{"DOUBTED", 7, 74169},
	{"EDUCA", 5, 74170},
	{"RAVAGED", 7, 74171},
	{"LAGRANGIAN", 10, 74172},
	{"DUBROVNIK", 9, 74173},
	{"PPYF", 4, 74174},
	{"WHISTLING", 9, 74175},
	{"YPEL", 4, 74176},
	{"RTGE", 4, 74177},
	{"DVAC", 4, 74178},
	{"UPHOLDING", 9, 74179},
	{"AILING", 6, 74180},
	{"OBEYED", 6, 74181},
	{"TATTOOED", 8, 74182},
	{"GHOSTLY", 7, 74183},
	{"HIPPOCAMPUS", 11, 74184},
	{"SBAG", 4, 74185},
	{"CRIM", 4, 74186},
	{"REPEATERS", 9, 74187},
	{"LONGORIA", 8, 74188},
	{"MUTINY", 6, 74189},
	{"DELUSIONS", 9, 74190},
	{"FORESEE", 7, 74191},
	{"MATSUSHITA", 10, 74192},
	{"HUPW", 4, 74193},
	{"GEED", 4, 74194},
	{"CKYH", 4, 74195},
	{"RATIONS", 7, 74196},
	{"BITTERLY", 8, 74197},
	{"KOTOR", 5, 74198},
	{"ENCODINGS", 9, 74199},
	{"UPCL", 4, 74200},
	{"IFUN", 4, 74201},
	{"YUEN", 4, 74202},
	{"WINDMILLS", 9, 74203},
	{"PERPETRATOR", 11, 74204},
	{"XASP", 4, 74205},
	{"HDOM", 4, 74206},
	{"GALG", 4, 74207},
	{"ACTIONABLE", 10, 74208},
	{"CORNEA", 6, 74209},
	{"OVERFULL", 8, 74210},
	{"YRAY", 4, 74211},
	{"YEXH", 4, 74212},
	{"PALD", 4, 74213},
	{"BOUC", 4, 74214},
	{"SOUTHGATE", 9, 74215},
	{"CLEVERLY", 8, 74216},
	{"MINIBAR", 7, 74217},
	{"KITCHENETTE", 11, 74218},
	{"SBYU", 4, 74219},
	{"ODSD", 4, 74220},
	{"INGX", 4, 74221},
	{"MISUNDERSTANDINGS", 17, 74222},
	{"LIBERIAN", 8, 74223},
	{"IPSD", 4, 74224},
	{"BATW", 4, 74225},
	{"ADPH", 4, 74226},
	{"AMERIKA", 7, 74227},
	{"REPAIRERS", 9, 74228},
	{"LICZNIKI", 8, 74229},
	{"COUNSELLORS", 11, 74230},
	{"RCC", 3, 74231},
	{"NUMEROLOGY", 10, 74232},
	{"YSIR", 4, 74233},
	{"YPEF", 4, 74234},
	{"ARMITAGE", 8, 74235},
	{"BRAC", 4, 74236},
	{"BARWARE", 7, 74237},
	{"RSLU", 4, 74238},
	{"RBLI", 4, 74239},
	{"FTPR", 4, 74240},
	{"FLEU", 4, 74241},
	{"ALTV", 4, 74242},
	{"CORSI", 5, 74243},
	{"NORMALIZE", 9, 74244},
	{"FFPO", 4, 74245},
	{"FFAP", 4, 74246},
	{"ALMT", 4, 74247},
	{"SISTERHOOD", 10, 74248},
	{"BCR", 3, 74249},
	{"LIGHTENING", 10, 74250},
	{"BUFFS", 5, 74251},
	{"TAMOXIFEN", 9, 74252},
	{"OVERTURN", 8, 74253},
	{"PHENOTYPES", 10, 74254},
	{"WSYS", 4, 74255},
	{"NKFR", 4, 74256},
	{"GUNL", 4, 74257},
	{"ARUR", 4, 74258},
	{"ZRR", 3, 74259},
	{"JMY", 3, 74260},
	{"KINROSS", 7, 74261},
	{"GHID", 4, 74262},
	{"THOUGHTFULLY", 12, 74263},
	{"KIERAN", 6, 74264},
	{"MORTEM", 6, 74265},
	{"INFORMATIE", 10, 74266},
	{"RTCI", 4, 74267},
	{"RGCO", 4, 74268},
	{"LFLU", 4, 74269},
	{"KETG", 4, 74270},
	{"FJOS", 4, 74271},
	{"MCCALLUM", 8, 74272},
	{"TRIPLET", 7, 74273},
	{"GEOSCIENCES", 11, 74274},
	{"RENCONTRE", 9, 74275},
	{"SONICS", 6, 74276},
	{"TIMMINS", 7, 74277},
	{"RISKING", 7, 74278},
	{"DJANGO", 6, 74279},
	{"AWNM", 4, 74280},
	{"PLLC", 4, 74281},
	{"LOTTA", 5, 74282},
	{"UPG", 3, 74283},
	{"PROPRIETORS", 11, 74284},
	{"YLAM", 4, 74285},
	{"RKAC", 4, 74286},
	{"SWISSPROT", 9, 74287},
	{"ARCHAEOLOGISTS", 14, 74288},
	{"WRUL", 4, 74289},
	{"KADD", 4, 74290},
	{"GRON", 4, 74291},
	{"MOVETO", 6, 74292},
	{"TATIANA", 7, 74293},
	{"INGRESS", 7, 74294},
	{"TENTACLE", 8, 74295},
	{"IAUDIO", 6, 74296},
	{"GROS", 4, 74297},
	{"BARBERS", 7, 74298},
	{"PREDNISONE", 10, 74299},
	{"SALESPEOPLE", 11, 74300},
	{"MOTILITY", 8, 74301},
	{"RETIRES", 7, 74302},
	{"EMGO", 4, 74303},
	{"DENGUE", 6, 74304},
	{"DURO", 4, 74305},
	{"GAIMAN", 6, 74306},
	{"COMMOTION", 9, 74307},
	{"INCINERATION", 12, 74308},
	{"DUMONT", 6, 74309},
	{"SHANKS", 6, 74310},
	{"BISSELL", 7, 74311},
	{"ORGANZA", 7, 74312},
	{"DEDUCE", 6, 74313},
	{"CENTRALISED", 11, 74314},
	{"UNBREAKABLE", 11, 74315},
	{"ALUK", 4, 74316},
	{"SUPERSIZED", 10, 74317},
	{"DEPICTIONS", 10, 74318},
	{"WML", 3, 74319},
	{"KAFFE", 5, 74320},
	{"BOLTED", 6, 74321},
	{"DUDL", 4, 74322},
	{"MATERIALISM", 11, 74323},
	{"DUNR", 4, 74324},
	{"AKBA", 4, 74325},
	{"ETERNALLY", 9, 74326},
	{"KARIM", 5, 74327},
	{"SENSELESS", 9, 74328},
	{"RABID", 5, 74329},
	{"WBEF", 4, 74330},
	{"CEMY", 4, 74331},
	{"REASSURE", 8, 74332},
	{"RECOLLECTIONS", 13, 74333},
	{"PROBED", 6, 74334},
	{"YDOR", 4, 74335},
	{"OPBY", 4, 74336},
	{"PBL", 3, 74337},
	{"CAEL", 4, 74338},
	{"SEPARATORS", 10, 74339},
	{"INFORMATIQUE", 12, 74340},
	{"RESETTING", 9, 74341},
	{"INDEPTH", 7, 74342},
	{"RMCL", 4, 74343},
	{"GLYM", 4, 74344},
	{"GHMU", 4, 74345},
	{"FUNNIES", 7, 74346},
	{"KDAN", 4, 74347},
	{"GCUL", 4, 74348},
	{"ABIK", 4, 74349},
	{"CHICAGOLAND", 11, 74350},
	{"KEYSTROKES", 10, 74351},
	{"HAMLETS", 7, 74352},
	{"SETTERS", 7, 74353},
	{"INERTIAL", 8, 74354},
	{"WOAL", 4, 74355},
	{"PAYLESS", 7, 74356},
	{"UNWRITTEN", 9, 74357},
	{"YNDA", 4, 74358},
	{"YADU", 4, 74359},
	{"RPOE", 4, 74360},
	{"PAYEE", 5, 74361},
	{"CINEMATOGRAPHER", 15, 74362},
	{"PREORDER", 8, 74363},
	{"SKAY", 4, 74364},
	{"ICNU", 4, 74365},
	{"GPAY", 4, 74366},
	{"GESG", 4, 74367},
	{"TEENIES", 7, 74368},
	{"PPV", 3, 74369},
	{"VENTILATOR", 10, 74370},
	{"ANNONCES", 8, 74371},
	{"CAMELBAK", 8, 74372},
	{"KLEAR", 5, 74373},
	{"RATG", 4, 74374},
	{"JAMMED", 6, 74375},
	{"MICROGRAMS", 10, 74376},
	{"MOVEABLE", 8, 74377},
	{"TSUD", 4, 74378},
	{"AGWA", 4, 74379},
	{"HOUSEKEEPER", 11, 74380},
	{"PEDIATRICIAN", 12, 74381},
	{"CYMBAL", 6, 74382},
	{"CONVECTIVE", 10, 74383},
	{"HAYMARKET", 9, 74384},
	{"AGRARIAN", 8, 74385},
	{"HUMANA", 6, 74386},
	{"NOSED", 5, 74387},
	{"SHOGUN", 6, 74388},
	{"RESCHEDULED", 11, 74389},
	{"UBUN", 4, 74390},
	{"NGCY", 4, 74391},
	{"BALA", 4, 74392},
	{"SIDESTEP", 8, 74393},
	{"DSFU", 4, 74394},
	{"READLINE", 8, 74395},
	{"PREEMPTION", 10, 74396},
	{"MICROBIOLOGICAL", 15, 74397},
	{"CORTICOSTEROIDS", 15, 74398},
	{"TUNU", 4, 74399},
	{"PPAY", 4, 74400},
	{"EVIG", 4, 74401},
	{"LOVABLE", 7, 74402},
	{"PSEUDOEPHEDRINE", 15, 74403},
	{"WNEY", 4, 74404},
	{"STOCKHOLDER", 11, 74405},
	{"ENGNET", 6, 74406},
	{"QUANTA", 6, 74407},
	{"STURGIS", 7, 74408},
	{"SYNAPSE", 7, 74409},
	{"CWD", 3, 74410},
	{"INNOSTREAM", 10, 74411},
	{"SKAP", 4, 74412},
	{"AIRPLAY", 7, 74413},
	{"SAWMILL", 7, 74414},
	{"ABRAM", 5, 74415},
	{"CATHARINE", 9, 74416},
	{"UPPERS", 6, 74417},
	{"TERZ", 4, 74418},
	{"OOFP", 4, 74419},
	{"GSFA", 4, 74420},
	{"PITMAN", 6, 74421},
	{"BODRUM", 6, 74422},
	{"CONSENTED", 9, 74423},
	{"PERSEUS", 7, 74424},
	{"LEATHERS", 8, 74425},
	{"STYX", 4, 74426},
	{"EMBOSSING", 9, 74427},
	{"RYOL", 4, 74428},
	{"ZRY", 3, 74429},
	{"VWG", 3, 74430},
	{"UJW", 3, 74431},
	{"QUF", 3, 74432},
	{"KXC", 3, 74433},
	{"REDIRECTS", 9, 74434},
	{"CONGESTED", 9, 74435},
	{"BANISHED", 8, 74436},
	{"FUZZ", 4, 74437},
	{"RIMB", 4, 74438},
	{"OWSV", 4, 74439},
	{"MADV", 4, 74440},
	{"ROSCOMMON", 9, 74441},
	{"MERYL", 5, 74442},
	{"IZMIR", 5, 74443},
	{"METICULOUS", 10, 74444},
	{"TERRACED", 8, 74445},
	{"MULTIPLEXER", 11, 74446},
	{"MENORCA", 7, 74447},
	{"BUTTERMILK", 10, 74448},
	{"LACES", 5, 74449},
	{"ULKI", 4, 74450},
	{"CYPE", 4, 74451},
	{"DENDRITIC", 9, 74452},
	{"MINIMA", 6, 74453},
	{"WSTNSAND", 8, 74454},
	{"TYCI", 4, 74455},
	{"TVCO", 4, 74456},
	{"NAPROXEN", 8, 74457},
	{"OPERANDS", 8, 74458},
	{"HUGGED", 6, 74459},
	{"PGOI", 4, 74460},
	{"ODEU", 4, 74461},
	{"NYAG", 4, 74462},
	{"MIKAEL", 6, 74463},
	{"CONCEPTUALLY", 12, 74464},
	{"BORL", 4, 74465},
	{"FLURRY", 6, 74466},
	{"GOWER", 5, 74467},
	{"CRICHTON", 8, 74468},
	{"BYOV", 4, 74469},
	{"WARMEST", 7, 74470},
	{"HARDWOODS", 9, 74471},
	{"CLARITA", 7, 74472},
	{"CAPPING", 7, 74473},
	{"TDUT", 4, 74474},
	{"SSJU", 4, 74475},
	{"PARISIAN", 8, 74476},
	{"HUMANISM", 8, 74477},
	{"HIROSHI", 7, 74478},
	{"HIPSTER", 7, 74479},
	{"HORRIFIED", 9, 74480},
	{"ACCEL", 5, 74481},
	{"ANNUALIZED", 10, 74482},
	{"FCAU", 4, 74483},
	{"DNOF", 4, 74484},
	{"WALPOLE", 7, 74485},
	{"SANDI", 5, 74486},
	{"BECCA", 5, 74487},
	{"BASILDON", 8, 74488},
	{"TESTIS", 6, 74489},
	{"UCLINUX", 7, 74490},
	{"BYOP", 4, 74491},
	{"CADA", 4, 74492},
	{"UNUSABLE", 8, 74493},
	{"TIGGER", 6, 74494},
	{"BERTRAM", 7, 74495},
	{"PERTURBATIONS", 13, 74496},
	{"APPROXIMATED", 12, 74497},
	{"RDIL", 4, 74498},
	{"ADVERSARIES", 11, 74499},
	{"CONSULATES", 10, 74500},
	{"WONKETTE", 8, 74501},
	{"JOBM", 4, 74502},
	{"HSUG", 4, 74503},
	{"VERSIONING", 10, 74504},
	{"AUNTS", 5, 74505},
	{"WALN", 4, 74506},
	{"REYF", 4, 74507},
	{"OJOU", 4, 74508},
	{"DYTR", 4, 74509},
	{"CETW", 4, 74510},
	{"VAPORS", 6, 74511},
	{"BREAKDOWNS", 10, 74512},
	{"SKYLIGHT", 8, 74513},
	{"LFBR", 4, 74514},
	{"GOJE", 4, 74515},
	{"FAPI", 4, 74516},
	{"AARD", 4, 74517},
	{"PERIODONTAL", 11, 74518},
	{"MACMALL", 7, 74519},
	{"IPHOTO", 6, 74520},
	{"WSIG", 4, 74521},
	{"UEZS", 4, 74522},
	{"MYOR", 4, 74523},
	{"LSCU", 4, 74524},
	{"DALH", 4, 74525},
	{"CASF", 4, 74526},
	{"BEIF", 4, 74527},
	{"UNCREDITED", 10, 74528},
	{"RECORDI", 7, 74529},
	{"GEMMA", 5, 74530},
	{"NMIR", 4, 74531},
	{"FINP", 4, 74532},
	{"LACROIX", 7, 74533},
	{"RUPIAH", 6, 74534},
	{"BULLISH", 7, 74535},
	{"CONSTANTINOPLE", 14, 74536},
	{"HIPPY", 5, 74537},
	{"AKSW", 4, 74538},
	{"KLIK", 4, 74539},
	{"USVA", 4, 74540},
	{"GNTR", 4, 74541},
	{"NORTHERNER", 10, 74542},
	{"MSQU", 4, 74543},
	{"GASG", 4, 74544},
	{"FFUE", 4, 74545},
	{"MACKINTOSH", 10, 74546},
	{"KENNEY", 6, 74547},
	{"FABRICATORS", 11, 74548},
	{"MUTATED", 7, 74549},
	{"CUEA", 4, 74550},
	{"LAYNE", 5, 74551},
	{"MOONSTONE", 9, 74552},
	{"SCILLY", 6, 74553},
	{"SHENG", 5, 74554},
	{"YETF", 4, 74555},
	{"LMSF", 4, 74556},
	{"IELW", 4, 74557},
	{"MONARCHS", 8, 74558},
	{"STREP", 5, 74559},
	{"OFFICAL", 7, 74560},
	{"FENW", 4, 74561},
	{"TAMPERE", 7, 74562},
	{"UNSOLVED", 8, 74563},
	{"STRENUOUS", 9, 74564},
	{"ROOST", 5, 74565},
	{"IUME", 4, 74566},
	{"AKEJ", 4, 74567},
	{"UNREASONABLY", 12, 74568},
	{"SYNERGIES", 9, 74569},
	{"OGYR", 4, 74570},
	{"NYSF", 4, 74571},
	{"CKOP", 4, 74572},
	{"SHUFFLING", 9, 74573},
	{"FUNDAMENTALISTS", 15, 74574},
	{"LUDICROUS", 9, 74575},
	{"YJEW", 4, 74576},
	{"AMYLOID", 7, 74577},
	{"EMACHINES", 9, 74578},
	{"UNDERSTANDABLY", 14, 74579},
	{"YKEY", 4, 74580},
	{"KCEN", 4, 74581},
	{"EAUB", 4, 74582},
	{"ICARUS", 6, 74583},
	{"APPLETALK", 9, 74584},
	{"TENETS", 6, 74585},
	{"URHU", 4, 74586},
	{"TUSQ", 4, 74587},
	{"TFRU", 4, 74588},
	{"GMEE", 4, 74589},
	{"ALBANIANS", 9, 74590},
	{"GOFF", 4, 74591},
	{"DIALED", 6, 74592},
	{"GHAW", 4, 74593},
	{"DPLO", 4, 74594},
	{"PIUS", 4, 74595},
	{"GARB", 4, 74596},
	{"GEOXTRACK", 9, 74597},
	{"MMYB", 4, 74598},
	{"LOBL", 4, 74599},
	{"BEMIDJI", 7, 74600},
	{"HARCORE", 7, 74601},
	{"ZENC", 4, 74602},
	{"GUEE", 4, 74603},
	{"STEADFAST", 9, 74604},
	{"INTERMODAL", 10, 74605},
	{"RMAF", 4, 74606},
	{"GINY", 4, 74607},
	{"BUMR", 4, 74608},
	{"CATALUNYA", 9, 74609},
	{"YGK", 3, 74610},
	{"FJK", 3, 74611},
	{"CFOU", 4, 74612},
	{"BAYMONT", 7, 74613},
	{"NIALL", 5, 74614},
	{"RECKONED", 8, 74615},
	{"PROMISSORY", 10, 74616},
	{"OVERFLOWS", 9, 74617},
	{"MITTS", 5, 74618},
	{"PREI", 4, 74619},
	{"HALP", 4, 74620},
	{"DDYA", 4, 74621},
	{"NAPPY", 5, 74622},
	{"DIARIO", 6, 74623},
	{"KHALID", 6, 74624},
	{"TYED", 4, 74625},
	{"IAMJ", 4, 74626},
	{"FUCHSIA", 7, 74627},
	{"CHOWHOUND", 9, 74628},
	{"MUSCAT", 6, 74629},
	{"QUERIED", 7, 74630},
	{"FFFF", 4, 74631},
	{"RIDT", 4, 74632},
	{"DKNI", 4, 74633},
	{"NDAQ", 4, 74634},
	{"MMEE", 4, 74635},
	{"KMART", 5, 74636},
	{"HANDOVER", 8, 74637},
	{"SQUARELY", 8, 74638},
	{"SOFTNESS", 8, 74639},
	{"KNOTT", 5, 74640},
	{"UNWO", 4, 74641},
	{"CRAYON", 6, 74642},
	{"MGOV", 4, 74643},
	{"MFOO", 4, 74644},
	{"APWH", 4, 74645},
	{"AELG", 4, 74646},
	{"BUTTERFIELD", 11, 74647},
	{"HIALEAH", 7, 74648},
	{"FINNEY", 6, 74649},
	{"ROTTING", 7, 74650},
	{"SALAMANDER", 10, 74651},
	{"DRIVEWAYS", 9, 74652},
	{"OJUL", 4, 74653},
	{"DRUI", 4, 74654},
	{"UMMM", 4, 74655},
	{"EXHILARATING", 12, 74656},
	{"AYRES", 5, 74657},
	{"LUKAS", 5, 74658},
	{"CAVAN", 5, 74659},
	{"UTYW", 4, 74660},
	{"LFAV", 4, 74661},
	{"GBYP", 4, 74662},
	{"EXCEPTED", 8, 74663},
	{"ASWELL", 6, 74664},
	{"SKIPPY", 6, 74665},
	{"MARGINALIZED", 12, 74666},
	{"SOONERS", 7, 74667},
	{"FLAVOURED", 9, 74668},
	{"CITYGUIDE", 9, 74669},
	{"MARITIMES", 9, 74670},
	{"KEDJ", 4, 74671},
	{"MARQUE", 6, 74672},
	{"PERMANENTE", 10, 74673},
	{"TEXACO", 6, 74674},
	{"MOGE", 4, 74675},
	{"BOOKMAKERS", 10, 74676},
	{"DITCHES", 7, 74677},
	{"SPECI", 5, 74678},
	{"HGTV", 4, 74679},
	{"MILLIONAIRES", 12, 74680},
	{"CONTACTO", 8, 74681},
	{"OPSD", 4, 74682},
	{"GARW", 4, 74683},
	{"FFUT", 4, 74684},
	{"AWNC", 4, 74685},
	{"MBC", 3, 74686},
	{"MARSTON", 7, 74687},
	{"EVADE", 5, 74688},
	{"NEWSLINE", 8, 74689},
	{"COVERAGES", 9, 74690},
	{"LSIV", 4, 74691},
	{"KNUC", 4, 74692},
	{"ERMG", 4, 74693},
	{"SPECIALITIES", 12, 74694},
	{"PARS", 4, 74695},
	{"IRAU", 4, 74696},
	{"DIMN", 4, 74697},
	{"ABYI", 4, 74698},
	{"LOCA", 4, 74699},
	{"SYSTEMATICS", 11, 74700},
	{"RENDERER", 8, 74701},
	{"MATSUI", 6, 74702},
	{"REWORK", 6, 74703},
	{"GNWH", 4, 74704},
	{"CLIV", 4, 74705},
	{"SNOWMASS", 8, 74706},
	{"COFFS", 5, 74707},
	{"SCOURGE", 7, 74708},
	{"TWIG", 4, 74709},
	{"CLEANSERS", 9, 74710},
	{"LAPIS", 5, 74711},
	{"BANDAGE", 7, 74712},
	{"DETACH", 6, 74713},
	{"WEBBY", 5, 74714},
	{"FOOTBED", 7, 74715},
	{"VIRGINITY", 9, 74716},
	{"RIPC", 4, 74717},
	{"INICIO", 6, 74718},
	{"MORETRADE", 9, 74719},
	{"APOGEE", 6, 74720},
	{"ALLERGENS", 9, 74721},
	{"MALA", 4, 74722},
	{"UTIG", 4, 74723},
	{"RDAW", 4, 74724},
	{"FLYF", 4, 74725},
	{"CTGR", 4, 74726},
	{"DOCTRINAL", 9, 74727},
	{"WORSEN", 6, 74728},
	{"MLC", 3, 74729},
	{"APPLICA", 7, 74730},
	{"ROYW", 4, 74731},
	{"TANKERS", 7, 74732},
	{"ADAPTABILITY", 12, 74733},
	{"CRAMPED", 7, 74734},
	{"WUPW", 4, 74735},
	{"BAPP", 4, 74736},
	{"AWMI", 4, 74737},
	{"WHOPPING", 8, 74738},
	{"ISSEY", 5, 74739},
	{"OSGR", 4, 74740},
	{"BAYR", 4, 74741},
	{"WEPT", 4, 74742},
	{"GANZ", 4, 74743},
	{"OMYD", 4, 74744},
	{"ERTJ", 4, 74745},
	{"BUSD", 4, 74746},
	{"CUST", 4, 74747},
	{"BROOKES", 7, 74748},
	{"OWKE", 4, 74749},
	{"RACKING", 7, 74750},
	{"OUAG", 4, 74751},
	{"HYBE", 4, 74752},
	{"ANGZ", 4, 74753},
	{"TULL", 4, 74754},
	{"IXWI", 4, 74755},
	{"FEEB", 4, 74756},
	{"AZYA", 4, 74757},
	{"CORRECTS", 8, 74758},
	{"AVIGNON", 7, 74759},
	{"INFORMATICA", 11, 74760},
	{"COMPUTERACTIVE", 14, 74761},
	{"SERVICIO", 8, 74762},
	{"FINLINE", 7, 74763},
	{"PERMISSIONROLE", 14, 74764},
	{"QUICKCAM", 8, 74765},
	{"SHUNT", 5, 74766},
	{"UMWE", 4, 74767},
	{"RODEWAY", 7, 74768},
	{"SCROLLBAR", 9, 74769},
	{"BREEN", 5, 74770},
	{"LRIN", 4, 74771},
	{"FMUC", 4, 74772},
	{"VOYUERWEB", 9, 74773},
	{"VANISHES", 8, 74774},
	{"KENSHIN", 7, 74775},
	{"DPM", 3, 74776},
	{"CLACKAMAS", 9, 74777},
	{"SYNCH", 5, 74778},
	{"PATTEN", 6, 74779},
	{"OBEDIENT", 8, 74780},
	{"LEPPARD", 7, 74781},
	{"ALLIS", 5, 74782},
	{"WLIT", 4, 74783},
	{"RREW", 4, 74784},
	{"GUNE", 4, 74785},
	{"GTEX", 4, 74786},
	{"GMEC", 4, 74787},
	{"SELKIRK", 7, 74788},
	{"ESTIMATORS", 10, 74789},
	{"MUR", 3, 74790},
	{"SECTS", 5, 74791},
	{"FUNCTIONALITIES", 15, 74792},
	{"DOWNES", 6, 74793},
	{"KOFFICE", 7, 74794},
	{"RUEM", 4, 74795},
	{"IVEQ", 4, 74796},
	{"EVIDENCES", 9, 74797},
	{"MUX", 3, 74798},
	{"MODO", 4, 74799},
	{"DBX", 3, 74800},
	{"FETISHES", 8, 74801},
	{"ISAACS", 6, 74802},
	{"OUTRIGGER", 9, 74803},
	{"XUF", 3, 74804},
	{"WXF", 3, 74805},
	{"VJD", 3, 74806},
	{"KQB", 3, 74807},
	{"FVV", 3, 74808},
	{"BFJ", 3, 74809},
	{"MARW", 4, 74810},
	{"GPHY", 4, 74811},
	{"ENCLAVE", 7, 74812},
	{"ANXIOUSLY", 9, 74813},
	{"FIBRILLATION", 12, 74814},
	{"ASCRIBED", 8, 74815},
	{"URIP", 4, 74816},
	{"RGHE", 4, 74817},
	{"PHOW", 4, 74818},
	{"LICORICE", 8, 74819},
	{"STRIKERS", 8, 74820},
	{"UMSS", 4, 74821},
	{"TADJ", 4, 74822},
	{"STATICALLY", 10, 74823},
	{"DIXONS", 6, 74824},
	{"GOLDMINE", 8, 74825},
	{"LHASA", 5, 74826},
	{"DEVELOPMENTALLY", 15, 74827},
	{"ZIGGY", 5, 74828},
	{"UTKN", 4, 74829},
	{"SKME", 4, 74830},
	{"LBUL", 4, 74831},
	{"OPTIMIST", 8, 74832},
	{"INGLES", 6, 74833},
	{"ULWE", 4, 74834},
	{"OILM", 4, 74835},
	{"LFPO", 4, 74836},
	{"DOWJ", 4, 74837},
	{"SENDERS", 7, 74838},
	{"GRATIFICATION", 13, 74839},
	{"SEASHORE", 8, 74840},
	{"AUTOMATON", 9, 74841},
	{"OTROS", 5, 74842},
	{"PIERSON", 7, 74843},
	{"NWIR", 4, 74844},
	{"UNSKILLED", 9, 74845},
	{"STEAMY", 6, 74846},
	{"UYON", 4, 74847},
	{"MADHYA", 6, 74848},
	{"MARINADE", 8, 74849},
	{"PASSWORT", 8, 74850},
	{"BRIGADIER", 9, 74851},
	{"WBAR", 4, 74852},
	{"OOLK", 4, 74853},
	{"LIEP", 4, 74854},
	{"LEYJ", 4, 74855},
	{"KISW", 4, 74856},
	{"DIGM", 4, 74857},
	{"CEAY", 4, 74858},
	{"EXTINGUISHERS", 13, 74859},
	{"STRATOSPHERE", 12, 74860},
	{"TBILISI", 7, 74861},
	{"UPDATER", 7, 74862},
	{"CONSONANT", 9, 74863},
	{"GEICO", 5, 74864},
	{"VALG", 4, 74865},
	{"ARSV", 4, 74866},
	{"FLD", 3, 74867},
	{"CABOS", 5, 74868},
	{"COMPANYS", 8, 74869},
	{"PDEF", 4, 74870},
	{"ERZA", 4, 74871},
	{"AGOU", 4, 74872},
	{"ACETIC", 6, 74873},
	{"TINPUTIMAGE", 11, 74874},
	{"GGG", 3, 74875},
	{"NICARAGUAN", 10, 74876},
	{"UNARMED", 7, 74877},
	{"WANGANUI", 8, 74878},
	{"DYEING", 6, 74879},
	{"INTOLERABLE", 11, 74880},
	{"REPUBLISHED", 11, 74881},
	{"TAWNY", 5, 74882},
	{"SCONCES", 7, 74883},
	{"INSULATOR", 9, 74884},
	{"DEIM", 4, 74885},
	{"ENDOMETRIAL", 11, 74886},
	{"MOHAN", 5, 74887},
	{"TBOM", 4, 74888},
	{"AMPP", 4, 74889},
	{"ABSINTHE", 8, 74890},
	{"HEGEMONY", 8, 74891},
	{"YLAK", 4, 74892},
	{"YETR", 4, 74893},
	{"IXAR", 4, 74894},
	{"FSAC", 4, 74895},
	{"DHYD", 4, 74896},
	{"FOCUSSING", 9, 74897},
	{"PBOA", 4, 74898},
	{"ONYG", 4, 74899},
	{"GALLERIE", 8, 74900},
	{"BIOPERL", 7, 74901},
	{"EPRINT", 6, 74902},
	{"UBSF", 4, 74903},
	{"ALYW", 4, 74904},
	{"TENNANT", 7, 74905},
	{"TRYPTOPHAN", 10, 74906},
	{"SSBL", 4, 74907},
	{"ILIM", 4, 74908},
	{"HYGIENIC", 8, 74909},
	{"CHECKIN", 7, 74910},
	{"GILROY", 6, 74911},
	{"NUPW", 4, 74912},
	{"FAFU", 4, 74913},
	{"ALSQ", 4, 74914},
	{"EXTENSIBILITY", 13, 74915},
	{"MCCULLOCH", 9, 74916},
	{"SUFFERINGS", 10, 74917},
	{"UABO", 4, 74918},
	{"IMUR", 4, 74919},
	{"THANG", 5, 74920},
	{"LOREM", 5, 74921},
	{"LMGR", 4, 74922},
	{"EOKL", 4, 74923},
	{"AVYH", 4, 74924},
	{"WOCL", 4, 74925},
	{"GOPR", 4, 74926},
	{"TAHITIAN", 8, 74927},
	{"PROPAGATING", 11, 74928},
	{"SACRAMENTS", 10, 74929},
	{"BIANCO", 6, 74930},
	{"EWCI", 4, 74931},
	{"SALMA", 5, 74932},
	{"LAYMAN", 6, 74933},
	{"CONSORTIA", 9, 74934},
	{"ASIMOV", 6, 74935},
	{"KLEW", 4, 74936},
	{"RENATO", 6, 74937},
	{"BUNGEE", 6, 74938},
	{"MURDOCK", 7, 74939},
	{"GROI", 4, 74940},
	{"BAYP", 4, 74941},
	{"VELLUM", 6, 74942},
	{"HOKKAIDO", 8, 74943},
	{"IGNATIUS", 8, 74944},
	{"ALTERNATES", 10, 74945},
	{"AFEF", 4, 74946},
	{"BRDRS", 5, 74947},
	{"EMPERORS", 8, 74948},
	{"CONFIGURES", 10, 74949},
	{"LDOB", 4, 74950},
	{"DUSC", 4, 74951},
	{"BOTC", 4, 74952},
	{"MULTILEVEL", 10, 74953},
	{"FERRO", 5, 74954},
	{"OLFH", 4, 74955},
	{"LLOM", 4, 74956},
	{"HKID", 4, 74957},
	{"ALBERTSON", 9, 74958},
	{"RENOIR", 6, 74959},
	{"UIDO", 4, 74960},
	{"FRUL", 4, 74961},
	{"STALKS", 6, 74962},
	{"STANZA", 6, 74963},
	{"GETCLASS", 8, 74964},
	{"PERTHSHIRE", 10, 74965},
	{"MUCUS", 5, 74966},
	{"SUSPENDERS", 10, 74967},
	{"REALTEK", 7, 74968},
	{"LONDRES", 7, 74969},
	{"MORONS", 6, 74970},
	{"DISMANTLE", 9, 74971},
	{"TERMINATIONS", 12, 74972},
	{"NOVICES", 7, 74973},
	{"NUSM", 4, 74974},
	{"LSRI", 4, 74975},
	{"AROQ", 4, 74976},
	{"GRASPED", 7, 74977},
	{"PHAROS", 6, 74978},
	{"BEQUEST", 7, 74979},
	{"MWZ", 3, 74980},
	{"LQC", 3, 74981},
	{"ZOVIRAX", 7, 74982},
	{"LMAP", 4, 74983},
	{"IPTW", 4, 74984},
	{"BEGGARS", 7, 74985},
	{"TWIKIGUEST", 10, 74986},
	{"IPYA", 4, 74987},
	{"HYLE", 4, 74988},
	{"CYHE", 4, 74989},
	{"REIMPLEMENTED", 13, 74990},
	{"EAVESDROPPING", 13, 74991},
	{"REDEEMER", 8, 74992},
	{"ORGS", 4, 74993},
	{"NUMERATOR", 9, 74994},
	{"FLORIN", 6, 74995},
	{"VIAR", 4, 74996},
	{"USIL", 4, 74997},
	{"ORUR", 4, 74998},
	{"AYMY", 4, 74999},
	{"QUIXOTE", 7, 75000},
	{"RESURGENCE", 10, 75001},
	{"CHAISE", 6, 75002},
	{"DYPL", 4, 75003},
	{"AVAM", 4, 75004},
	{"PATERNAL", 8, 75005},
	{"METASTASES", 10, 75006},
	{"YEDN", 4, 75007},
	{"EDYF", 4, 75008},
	{"RAINED", 6, 75009},
	{"TIMINGS", 7, 75010},
	{"MECHA", 5, 75011},
	{"CARBURETOR", 10, 75012},
	{"MERGES", 6, 75013},
	{"LIGHTBOXES", 10, 75014},
	{"INDIGENT", 8, 75015},
	{"ICRA", 4, 75016},
	{"TEPM", 4, 75017},
	{"LIDR", 4, 75018},
	{"HBYA", 4, 75019},
	{"FMYT", 4, 75020},
	{"FFDE", 4, 75021},
	{"TRELLIS", 7, 75022},
	{"JEOPARDIZE", 10, 75023},
	{"LOEWS", 5, 75024},
	{"FANLISTING", 10, 75025},
	{"FLET", 4, 75026},
	{"HYLAND", 6, 75027},
	{"IDDY", 4, 75028},
	{"EXPERIAN", 8, 75029},
	{"SCREENWRITING", 13, 75030},
	{"YZIN", 4, 75031},
	{"FLEB", 4, 75032},
	{"CILY", 4, 75033},
	{"BYAI", 4, 75034},
	{"BLEK", 4, 75035},
	{"KEYRINGS", 8, 75036},
	{"HYDROLASE", 9, 75037},
	{"TRABAJO", 7, 75038},
	{"MOBILIZED", 9, 75039},
	{"YUNK", 4, 75040},
	{"LFHI", 4, 75041},
	{"EPTD", 4, 75042},
	{"ACCUTANE", 8, 75043},
	{"ZONEALARM", 9, 75044},
	{"CANAVERAL", 9, 75045},
	{"FLAGLER", 7, 75046},
	{"MYTHIC", 6, 75047},
	{"MJON", 4, 75048},
	{"CRYSTALLIZATION", 15, 75049},
	{"SOMEPLACE", 9, 75050},
	{"VCARD", 5, 75051},
	{"MARRIES", 7, 75052},
	{"ECHOING", 7, 75053},
	{"XTLE", 4, 75054},
	{"UKHA", 4, 75055},
	{"OBDO", 4, 75056},
	{"ICUR", 4, 75057},
	{"ANTIBACTERIAL", 13, 75058},
	{"RUND", 4, 75059},
	{"EXTREMISM", 9, 75060},
	{"EDGY", 4, 75061},
	{"FLUCTUATE", 9, 75062},
	{"TASKED", 6, 75063},
	{"NAGPUR", 6, 75064},
	{"WSDO", 4, 75065},
	{"PTSW", 4, 75066},
	{"LSGE", 4, 75067},
	{"EYWR", 4, 75068},
	{"APYA", 4, 75069},
	{"FUNROLL", 7, 75070},
	{"WNVE", 4, 75071},
	{"VIDF", 4, 75072},
	{"GTIC", 4, 75073},
	{"FLIPS", 5, 75074},
	{"PETSMART", 8, 75075},
	{"LIBUCLIBC", 9, 75076},
	{"RAGH", 4, 75077},
	{"ERTK", 4, 75078},
	{"CHANEY", 6, 75079},
	{"RECITATION", 10, 75080},
	{"AVENTIS", 7, 75081},
	{"MACROPHAGE", 10, 75082},
	{"APTLY", 5, 75083},
	{"ALLEVIATION", 11, 75084},
	{"SMCA", 4, 75085},
	{"INKG", 4, 75086},
	{"LIEGE", 5, 75087},
	{"REMITTANCES", 11, 75088},
	{"PALMAS", 6, 75089},
	{"USEABLE", 7, 75090},
	{"ROMANCES", 8, 75091},
	{"YBOB", 4, 75092},
	{"LSDR", 4, 75093},
	{"NIECES", 6, 75094},
	{"VEDY", 4, 75095},
	{"ULTZ", 4, 75096},
	{"FERNDALE", 8, 75097},
	{"UEUE", 4, 75098},
	{"SAIPAN", 6, 75099},
	{"CHARACTERIZES", 13, 75100},
	{"COUNCILOR", 9, 75101},
	{"MYINFO", 6, 75102},
	{"JELLYFISH", 9, 75103},
	{"NEWINGTON", 9, 75104},
	{"REISSUED", 8, 75105},
	{"MPV", 3, 75106},
	{"ELEL", 4, 75107},
	{"AIRCONDITIONING", 15, 75108},
	{"PAPYRUS", 7, 75109},
	{"WIGGLES", 7, 75110},
	{"OFAQ", 4, 75111},
	{"SYNTHS", 6, 75112},
	{"KENNESAW", 8, 75113},
	{"RUBBERMAID", 10, 75114},
	{"CANDLESTICK", 11, 75115},
	{"LETL", 4, 75116},
	{"SPECTOR", 7, 75117},
	{"MEDICA", 6, 75118},
	{"AYER", 4, 75119},
	{"RRYN", 4, 75120},
	{"NMUT", 4, 75121},
	{"ARNU", 4, 75122},
	{"ASHOK", 5, 75123},
	{"VERN", 4, 75124},
	{"GVOI", 4, 75125},
	{"WRITABLE", 8, 75126},
	{"OKSD", 4, 75127},
	{"USEPA", 5, 75128},
	{"REFLECTANCE", 11, 75129},
	{"MOBO", 4, 75130},
	{"TREJ", 4, 75131},
	{"BUNN", 4, 75132},
	{"CIRCLING", 8, 75133},
	{"HELLAS", 6, 75134},
	{"SHEIK", 5, 75135},
	{"PINTS", 5, 75136},
	{"CHIBA", 5, 75137},
	{"TIMD", 4, 75138},
	{"OWIR", 4, 75139},
	{"UMPF", 4, 75140},
	{"DFOX", 4, 75141},
	{"BWOR", 4, 75142},
	{"COLIFORM", 8, 75143},
	{"UTVO", 4, 75144},
	{"RDYA", 4, 75145},
	{"EMCD", 4, 75146},
	{"SELENA", 6, 75147},
	{"OLMSTED", 7, 75148},
	{"BROOMFIELD", 10, 75149},
	{"DARPA", 5, 75150},
	{"WRUN", 4, 75151},
	{"NONPOINT", 8, 75152},
	{"REALIGNMENT", 11, 75153},
	{"GIRDLE", 6, 75154},
	{"SIAMESE", 7, 75155},
	{"UNDERMINES", 10, 75156},
	{"FERREIRA", 8, 75157},
	{"TIPR", 4, 75158},
	{"VEILED", 6, 75159},
	{"DEFIBRILLATORS", 14, 75160},
	{"BLOTTING", 8, 75161},
	{"KRAUS", 5, 75162},
	{"CERTS", 5, 75163},
	{"JSTOR", 5, 75164},
	{"INTIMATES", 9, 75165},
	{"AARHUS", 6, 75166},
	{"SUPERCOMPUTER", 13, 75167},
	{"ERUPTIONS", 9, 75168},
	{"UFFR", 4, 75169},
	{"LFCE", 4, 75170},
	{"IGNG", 4, 75171},
	{"JAVELIN", 7, 75172},
	{"BOUNCER", 7, 75173},
	{"YEMO", 4, 75174},
	{"IPSUM", 5, 75175},
	{"PHENOL", 6, 75176},
	{"RSYN", 4, 75177},
	{"JIGS", 4, 75178},
	{"LOUDOUN", 7, 75179},
	{"LIFETIMES", 9, 75180},
	{"GRUNDY", 6, 75181},
	{"STARES", 6, 75182},
	{"EASTWARD", 8, 75183},
	{"HISTAMINE", 9, 75184},
	{"BYLINE", 6, 75185},
	{"MBOX", 4, 75186},
	{"MUSTAFA", 7, 75187},
	{"YDED", 4, 75188},
	{"VINF", 4, 75189},
	{"BEDLAM", 6, 75190},
	{"IOEXCEPTION", 11, 75191},
	{"ENTREE", 6, 75192},
	{"ABDEL", 5, 75193},
	{"BOTHELL", 7, 75194},
	{"SYNERGISTIC", 11, 75195},
	{"DESIST", 6, 75196},
	{"GRASSHOPPER", 11, 75197},
	{"RETB", 4, 75198},
	{"MMYH", 4, 75199},
	{"GHGO", 4, 75200},
	{"RHEUMATIC", 9, 75201},
	{"LIPPINCOTT", 10, 75202},
	{"MAPLEWOOD", 9, 75203},
	{"TILLMAN", 7, 75204},
	{"KRUS", 4, 75205},
	{"AUTOBIOGRAPHICAL", 16, 75206},
	{"MAINTS", 6, 75207},
	{"PIETY", 5, 75208},
	{"EMBODY", 6, 75209},
	{"PETITES", 7, 75210},
	{"GRIS", 4, 75211},
	{"CRAWLED", 7, 75212},
	{"YPIL", 4, 75213},
	{"HANDBALL", 8, 75214},
	{"SHANDONG", 8, 75215},
	{"STYLIZED", 8, 75216},
	{"UBRO", 4, 75217},
	{"TBAG", 4, 75218},
	{"GNEG", 4, 75219},
	{"FOLATE", 6, 75220},
	{"LENOIR", 6, 75221},
	{"PDAN", 4, 75222},
	{"MANITOU", 7, 75223},
	{"CYTOMETRY", 9, 75224},
	{"UNOW", 4, 75225},
	{"OLBR", 4, 75226},
	{"LTOV", 4, 75227},
	{"ECEB", 4, 75228},
	{"SOILED", 6, 75229},
	{"GOOFS", 5, 75230},
	{"WOKINGHAM", 9, 75231},
	{"CONNORS", 7, 75232},
	{"DICH", 4, 75233},
	{"KBRE", 4, 75234},
	{"FROZE", 5, 75235},
	{"MUSC", 4, 75236},
	{"RIPON", 5, 75237},
	{"SUPERFLUOUS", 11, 75238},
	{"NYPD", 4, 75239},
	{"UOWE", 4, 75240},
	{"JOYO", 4, 75241},
	{"PLEXUS", 6, 75242},
	{"SYSTOLIC", 8, 75243},
	{"HYMAN", 5, 75244},
	{"UNREACHABLE", 11, 75245},
	{"DEEPAK", 6, 75246},
	{"KONP", 4, 75247},
	{"GNOV", 4, 75248},
	{"DESARROLLO", 10, 75249},
	{"DISARM", 6, 75250},
	{"JISC", 4, 75251},
	{"MERC", 4, 75252},
	{"TACIT", 5, 75253},
	{"COVINA", 6, 75254},
	{"NOONAN", 6, 75255},
	{"UFC", 3, 75256},
	{"RADJ", 4, 75257},
	{"OWJA", 4, 75258},
	{"HPAU", 4, 75259},
	{"MODERNIST", 9, 75260},
	{"OLFP", 4, 75261},
	{"WARING", 6, 75262},
	{"CHANSONS", 8, 75263},
	{"PARENTHESIS", 11, 75264},
	{"REORGANIZED", 11, 75265},
	{"DAYBREAK", 8, 75266},
	{"RALLIED", 7, 75267},
	{"JANIE", 5, 75268},
	{"QUAKERS", 7, 75269},
	{"EFAD", 4, 75270},
	{"DWEM", 4, 75271},
	{"FAMS", 4, 75272},
	{"PENTECOST", 9, 75273},
	{"YASSER", 6, 75274},
	{"WEATHERING", 10, 75275},
	{"TOTALITARIAN", 12, 75276},
	{"PUTTERS", 7, 75277},
	{"WAYPOINT", 8, 75278},
	{"PRX", 3, 75279},
	{"INTERRELATED", 12, 75280},
	{"BEULAH", 6, 75281},
	{"EEJU", 4, 75282},
	{"DELRAY", 6, 75283},
	{"LIFEDRIVE", 9, 75284},
	{"SANTANDER", 9, 75285},
	{"MCER", 4, 75286},
	{"GONJ", 4, 75287},
	{"DUSH", 4, 75288},
	{"CHJE", 4, 75289},
	{"SOUTHBOUND", 10, 75290},
	{"MSGO", 4, 75291},
	{"HAKY", 4, 75292},
	{"EDAQ", 4, 75293},
	{"CAPU", 4, 75294},
	{"UNVEILING", 9, 75295},
	{"SOLIDWORKS", 10, 75296},
	{"CRONIN", 6, 75297},
	{"AVERATEC", 8, 75298},
	{"UTIQ", 4, 75299},
	{"OLPO", 4, 75300},
	{"BURG", 4, 75301},
	{"HUREN", 5, 75302},
	{"ASTRAY", 6, 75303},
	{"YZK", 3, 75304},
	{"KBG", 3, 75305},
	{"JJY", 3, 75306},
	{"CXF", 3, 75307},
	{"BLISTERS", 8, 75308},
	{"PATIOS", 6, 75309},
	{"INFIRMARY", 9, 75310},
	{"FIREBOX", 7, 75311},
	{"SYNOPSES", 8, 75312},
	{"XEDM", 4, 75313},
	{"KKNI", 4, 75314},
	{"VENTA", 5, 75315},
	{"HINTED", 6, 75316},
	{"SLDQ", 4, 75317},
	{"GHCL", 4, 75318},
	{"SANCTITY", 8, 75319},
	{"SADR", 4, 75320},
	{"TUPLES", 6, 75321},
	{"WDAT", 4, 75322},
	{"RPTH", 4, 75323},
	{"LYAY", 4, 75324},
	{"MODUS", 5, 75325},
	{"ORDJ", 4, 75326},
	{"NUSB", 4, 75327},
	{"PEDANTIC", 8, 75328},
	{"BRDRNONE", 8, 75329},
	{"DIARRHOEA", 9, 75330},
	{"SONATAS", 7, 75331},
	{"XEDP", 4, 75332},
	{"BESTE", 5, 75333},
	{"BARBECUES", 9, 75334},
	{"DENNISON", 8, 75335},
	{"GRANDES", 7, 75336},
	{"PADO", 4, 75337},
	{"MDEM", 4, 75338},
	{"CKBL", 4, 75339},
	{"BULLIES", 7, 75340},
	{"WALTHER", 7, 75341},
	{"NOTORIOUSLY", 11, 75342},
	{"LUCIUS", 6, 75343},
	{"YHUG", 4, 75344},
	{"KYOT", 4, 75345},
	{"DEADWOOD", 8, 75346},
	{"KIRSTY", 6, 75347},
	{"MANCINI", 7, 75348},
	{"RPMLIB", 6, 75349},
	{"LIEG", 4, 75350},
	{"MILPITAS", 8, 75351},
	{"COMMONSENSE", 11, 75352},
	{"LITD", 4, 75353},
	{"DGOB", 4, 75354},
	{"CAUSTIC", 7, 75355},
	{"ROOK", 4, 75356},
	{"VANR", 4, 75357},
	{"ULAD", 4, 75358},
	{"SEDK", 4, 75359},
	{"RLEW", 4, 75360},
	{"NDKM", 4, 75361},
	{"ROMFORD", 7, 75362},
	{"EMPORIA", 7, 75363},
	{"GLEAMING", 8, 75364},
	{"DIGIDESIGN", 10, 75365},
	{"RAUC", 4, 75366},
	{"GDAV", 4, 75367},
	{"DOMINOES", 8, 75368},
	{"VIOLATORS", 9, 75369},
	{"PHRASEBOOK", 10, 75370},
	{"RECONFIGURATION", 15, 75371},
	{"WGUI", 4, 75372},
	{"HALW", 4, 75373},
	{"PAROCHIAL", 9, 75374},
	{"BERTIE", 6, 75375},
	{"SLEDDING", 8, 75376},
	{"LAKEFRONT", 9, 75377},
	{"EXCISION", 8, 75378},
	{"TRACEABILITY", 12, 75379},
	{"UPJU", 4, 75380},
	{"KSRA", 4, 75381},
	{"YANGON", 6, 75382},
	{"BOOKTITLE", 9, 75383},
	{"LEMONY", 6, 75384},
	{"RECURSIVELY", 11, 75385},
	{"UBSS", 4, 75386},
	{"GSBO", 4, 75387},
	{"KILDA", 5, 75388},
	{"AUCTIONED", 9, 75389},
	{"HENNESSY", 8, 75390},
	{"UELF", 4, 75391},
	{"MNOF", 4, 75392},
	{"BASSET", 6, 75393},
	{"MOREAU", 6, 75394},
	{"ANTWERPEN", 9, 75395},
	{"PALTROW", 7, 75396},
	{"MOWE", 4, 75397},
	{"LERJ", 4, 75398},
	{"LIMITER", 7, 75399},
	{"IMTOO", 5, 75400},
	{"PRECEDENTS", 10, 75401},
	{"CORNWELL", 8, 75402},
	{"IROV", 4, 75403},
	{"DOGR", 4, 75404},
	{"EXILED", 6, 75405},
	{"HOWELLS", 7, 75406},
	{"BLUEBERRIES", 11, 75407},
	{"KREF", 4, 75408},
	{"EGUM", 4, 75409},
	{"PALL", 4, 75410},
	{"MUSTERED", 8, 75411},
	{"PRETEXT", 7, 75412},
	{"NOTTING", 7, 75413},
	{"COMPREHENSIVELY", 15, 75414},
	{"WHISK", 5, 75415},
	{"FLARED", 6, 75416},
	{"CEWR", 4, 75417},
	{"KLEINE", 6, 75418},
	{"AMAR", 4, 75419},
	{"DEFTONES", 8, 75420},
	{"DEFERENCE", 9, 75421},
	{"RKAP", 4, 75422},
	{"OAFG", 4, 75423},
	{"MSDU", 4, 75424},
	{"LEOC", 4, 75425},
	{"ZYXEL", 5, 75426},
	{"LIMELIGHT", 9, 75427},
	{"SCHMID", 6, 75428},
	{"EMUM", 4, 75429},
	{"AMPG", 4, 75430},
	{"ARTFUL", 6, 75431},
	{"SOLIS", 5, 75432},
	{"CDX", 3, 75433},
	{"GAPH", 4, 75434},
	{"GFLI", 4, 75435},
	{"MJU", 3, 75436},
	{"HOOSIERS", 8, 75437},
	{"WIGA", 4, 75438},
	{"GOTD", 4, 75439},
	{"ELUT", 4, 75440},
	{"CRISS", 5, 75441},
	{"GLYNN", 5, 75442},
	{"AUDACITY", 8, 75443},
	{"VILT", 4, 75444},
	{"SERK", 4, 75445},
	{"RJUR", 4, 75446},
	{"PTOY", 4, 75447},
	{"MARGATE", 7, 75448},
	{"AEROTEK", 7, 75449},
	{"UNMET", 5, 75450},
	{"COMPETES", 8, 75451},
	{"JUDSON", 6, 75452},
	{"AJIB", 4, 75453},
	{"OLATHE", 6, 75454},
	{"COMPOSITIONAL", 13, 75455},
	{"SODD", 4, 75456},
	{"FCOV", 4, 75457},
	{"TRIG", 4, 75458},
	{"TAYLORMADE", 10, 75459},
	{"CATAWBA", 7, 75460},
	{"MBYTES", 6, 75461},
	{"DOWNWARDS", 9, 75462},
	{"RKVI", 4, 75463},
	{"RGTO", 4, 75464},
	{"ORDINAL", 7, 75465},
	{"OELL", 4, 75466},
	{"INASMUCH", 8, 75467},
	{"PLOTTERS", 8, 75468},
	{"CARESS", 6, 75469},
	{"INGLEWOOD", 9, 75470},
	{"HAILS", 5, 75471},
	{"GILA", 4, 75472},
	{"SWAM", 4, 75473},
	{"MAGNITUDES", 10, 75474},
	{"DOWNED", 6, 75475},
	{"FIRSTNAME", 9, 75476},
	{"WILFRED", 7, 75477},
	{"MFEB", 4, 75478},
	{"CSWO", 4, 75479},
	{"MAUVE", 5, 75480},
	{"METAIRIE", 8, 75481},
	{"HAZY", 4, 75482},
	{"TWITCH", 6, 75483},
	{"KJD", 3, 75484},
	{"JVR", 3, 75485},
	{"FLZ", 3, 75486},
	{"EPYR", 4, 75487},
	{"POLLUTING", 9, 75488},
	{"ALEGRE", 6, 75489},
	{"WELLCOME", 8, 75490},
	{"LKCO", 4, 75491},
	{"AARR", 4, 75492},
	{"EKEV", 4, 75493},
	{"GLORIFIED", 9, 75494},
	{"COMBED", 6, 75495},
	{"RECLAIMING", 10, 75496},
	{"TRYU", 4, 75497},
	{"SUBG", 4, 75498},
	{"EDJI", 4, 75499},
	{"CLIG", 4, 75500},
	{"CFIG", 4, 75501},
	{"PEDICURE", 8, 75502},
	{"DUPLEXES", 8, 75503},
	{"EDGEWALL", 8, 75504},
	{"WEBCHANGES", 10, 75505},
	{"BACKPLANE", 9, 75506},
	{"DASCHLE", 7, 75507},
	{"PSBY", 4, 75508},
	{"LTOK", 4, 75509},
	{"ILDN", 4, 75510},
	{"TRANSCEIVERS", 12, 75511},
	{"DISRUPTING", 10, 75512},
	{"BIODEGRADABLE", 13, 75513},
	{"LNAD", 4, 75514},
	{"EYSR", 4, 75515},
	{"ACYR", 4, 75516},
	{"SPORE", 5, 75517},
	{"MEPS", 4, 75518},
	{"PHPMYADMIN", 10, 75519},
	{"BLOODRAYNE", 10, 75520},
	{"BAPTISTS", 8, 75521},
	{"UNREALIZED", 10, 75522},
	{"PARAPHRASE", 10, 75523},
	{"ARTISTAS", 8, 75524},
	{"OSYM", 4, 75525},
	{"OALD", 4, 75526},
	{"MVEN", 4, 75527},
	{"LEXB", 4, 75528},
	{"GSRA", 4, 75529},
	{"ELSK", 4, 75530},
	{"DDUM", 4, 75531},
	{"FLOUNDER", 8, 75532},
	{"CREPT", 5, 75533},
	{"RNEB", 4, 75534},
	{"FIBROUS", 7, 75535},
	{"SWAMPS", 6, 75536},
	{"OMBT", 4, 75537},
	{"HDRU", 4, 75538},
	{"ROOMATE", 7, 75539},
	{"EPILOGUE", 8, 75540},
	{"NYSL", 4, 75541},
	{"EPISTLE", 7, 75542},
	{"ACETONE", 7, 75543},
	{"ALANINE", 7, 75544},
	{"RYSD", 4, 75545},
	{"RWEC", 4, 75546},
	{"ELKO", 4, 75547},
	{"EXILES", 6, 75548},
	{"WHEATLEY", 8, 75549},
	{"SWEK", 4, 75550},
	{"NCAK", 4, 75551},
	{"ERKL", 4, 75552},
	{"DVDRW", 5, 75553},
	{"CLAPPING", 8, 75554},
	{"FINESSE", 7, 75555},
	{"XREL", 4, 75556},
	{"HYGI", 4, 75557},
	{"FBRU", 4, 75558},
	{"NDIX", 4, 75559},
	{"BLITZKRIEG", 10, 75560},
	{"OFTP", 4, 75561},
	{"METM", 4, 75562},
	{"NICKELS", 7, 75563},
	{"SOCIALE", 7, 75564},
	{"CORDELIA", 8, 75565},
	{"XBUR", 4, 75566},
	{"UNOV", 4, 75567},
	{"INFREQUENTLY", 12, 75568},
	{"BANBURY", 7, 75569},
	{"DMYP", 4, 75570},
	{"FAVORING", 8, 75571},
	{"CONVERGING", 10, 75572},
	{"OPTRA", 5, 75573},
	{"COUR", 4, 75574},
	{"LFSH", 4, 75575},
	{"BISM", 4, 75576},
	{"CHOCTAW", 7, 75577},
	{"ISSAQUAH", 8, 75578},
	{"WJAC", 4, 75579},
	{"INTERACTIVELY", 13, 75580},
	{"FREDRIK", 7, 75581},
	{"AVENTURA", 8, 75582},
	{"DPIC", 4, 75583},
	{"MUFFLERS", 8, 75584},
	{"RPST", 4, 75585},
	{"KARZ", 4, 75586},
	{"QUARKS", 6, 75587},
	{"KOFJ", 4, 75588},
	{"FIRMA", 5, 75589},
	{"INQUISITION", 11, 75590},
	{"REFACTORING", 11, 75591},
	{"MONROVIA", 8, 75592},
	{"REDQ", 4, 75593},
	{"CYRI", 4, 75594},
	{"REPUTED", 7, 75595},
	{"FORMAN", 6, 75596},
	{"DINAH", 5, 75597},
	{"MARRAKECH", 9, 75598},
	{"OPTOMA", 6, 75599},
	{"WALKWAYS", 8, 75600},
	{"SEDUCE", 6, 75601},
	{"UEBY", 4, 75602},
	{"LFGA", 4, 75603},
	{"HEINEKEN", 8, 75604},
	{"SHELBYVILLE", 11, 75605},
	{"BEARERS", 7, 75606},
	{"YJIM", 4, 75607},
	{"UVRE", 4, 75608},
	{"SNBC", 4, 75609},
	{"ELUR", 4, 75610},
	{"KIMONO", 6, 75611},
	{"GUESSES", 7, 75612},
	{"OXIDIZED", 8, 75613},
	{"BUGFIX", 6, 75614},
	{"SHARIF", 6, 75615},
	{"FOOTE", 5, 75616},
	{"BLOODSTREAM", 11, 75617},
	{"FCUT", 4, 75618},
	{"UNDERPINNING", 12, 75619},
	{"RESISTIVITY", 11, 75620},
	{"IMPOSSIBILITY", 13, 75621},
	{"ETUL", 4, 75622},
	{"CEYLON", 6, 75623},
	{"HOLLINGER", 9, 75624},
	{"CONFORMAL", 9, 75625},
	{"RACQUETS", 8, 75626},
	{"COURANT", 7, 75627},
	{"FTCH", 4, 75628},
	{"SHERRI", 6, 75629},
	{"DBD", 3, 75630},
	{"INVASIONS", 9, 75631},
	{"EMINENCE", 8, 75632},
	{"MRAI", 4, 75633},
	{"EBYZ", 4, 75634},
	{"NEVERMIND", 9, 75635},
	{"ZRM", 3, 75636},
	{"PQW", 3, 75637},
	{"PQF", 3, 75638},
	{"GJK", 3, 75639},
	{"TENCHI", 6, 75640},
	{"CANNA", 5, 75641},
	{"POTTERS", 7, 75642},
	{"DETERGENTS", 10, 75643},
	{"TTUC", 4, 75644},
	{"KONF", 4, 75645},
	{"BORF", 4, 75646},
	{"CHERI", 5, 75647},
	{"LIBERATE", 8, 75648},
	{"GRACIE", 6, 75649},
	{"BOMBARDIER", 10, 75650},
	{"SUBSP", 5, 75651},
	{"CYTOTOXIC", 9, 75652},
	{"FRAG", 4, 75653},
	{"OPAM", 4, 75654},
	{"NFRU", 4, 75655},
	{"LMUT", 4, 75656},
	{"GICB", 4, 75657},
	{"GHEM", 4, 75658},
	{"ESEMINARS", 9, 75659},
	{"GUNTHER", 7, 75660},
	{"COLOPHON", 8, 75661},
	{"HANGED", 6, 75662},
	{"TPMW", 4, 75663},
	{"LOWK", 4, 75664},
	{"MORIN", 5, 75665},
	{"FLATTER", 7, 75666},
	{"ACQUITTED", 9, 75667},
	{"OLYR", 4, 75668},
	{"AXDO", 4, 75669},
	{"TATUM", 5, 75670},
	{"UNFORGIVEN", 10, 75671},
	{"THESAURI", 8, 75672},
	{"TWOJ", 4, 75673},
	{"TBAB", 4, 75674},
	{"PURT", 4, 75675},
	{"MATM", 4, 75676},
	{"FOFC", 4, 75677},
	{"GAFFNEY", 7, 75678},
	{"HARRELL", 7, 75679},
	{"TOOWOOMBA", 9, 75680},
	{"TMYB", 4, 75681},
	{"TBOL", 4, 75682},
	{"FKEY", 4, 75683},
	{"EFTD", 4, 75684},
	{"PSDI", 4, 75685},
	{"FGUN", 4, 75686},
	{"DIMMER", 6, 75687},
	{"FRIENDFINDER", 12, 75688},
	{"CAULDRON", 8, 75689},
	{"MPCO", 4, 75690},
	{"BYLU", 4, 75691},
	{"BOOTSNALL", 9, 75692},
	{"RELAIS", 6, 75693},
	{"DREDGE", 6, 75694},
	{"TINGLING", 8, 75695},
	{"PREFERRING", 10, 75696},
	{"NAUC", 4, 75697},
	{"FNUC", 4, 75698},
	{"ALLOCATES", 9, 75699},
	{"FREECOM", 7, 75700},
	{"CORDIAL", 7, 75701},
	{"KABBALAH", 8, 75702},
	{"REASSURANCE", 11, 75703},
	{"RANL", 4, 75704},
	{"CESV", 4, 75705},
	{"PUNKS", 5, 75706},
	{"CHORLEY", 7, 75707},
	{"IVANOV", 6, 75708},
	{"SUPERINTENDENTS", 15, 75709},
	{"UNANNOTATED", 11, 75710},
	{"YEWI", 4, 75711},
	{"RUSF", 4, 75712},
	{"ENDIAN", 6, 75713},
	{"NERVOUSNESS", 11, 75714},
	{"DELINEATED", 10, 75715},
	{"IMAGINATIONS", 12, 75716},
	{"DARI", 4, 75717},
	{"YCIV", 4, 75718},
	{"OFOK", 4, 75719},
	{"PATCHY", 6, 75720},
	{"HATERS", 6, 75721},
	{"MUTEX", 5, 75722},
	{"QUARREL", 7, 75723},
	{"WORLDNOW", 8, 75724},
	{"UCTC", 4, 75725},
	{"ABYP", 4, 75726},
	{"GIULIANI", 8, 75727},
	{"MILLENNIA", 9, 75728},
	{"UMPW", 4, 75729},
	{"RMIR", 4, 75730},
	{"RANQ", 4, 75731},
	{"NJAY", 4, 75732},
	{"EALQ", 4, 75733},
	{"PATHOPHYSIOLOGY", 15, 75734},
	{"FRITH", 5, 75735},
	{"EDTY", 4, 75736},
	{"ARYAN", 5, 75737},
	{"DORAN", 5, 75738},
	{"TENDERING", 9, 75739},
	{"TRANSITIVE", 10, 75740},
	{"REMIXED", 7, 75741},
	{"UELM", 4, 75742},
	{"FURTHERING", 10, 75743},
	{"CONNOISSEUR", 11, 75744},
	{"IDEALISM", 8, 75745},
	{"HYPOXIA", 7, 75746},
	{"NEWYORK", 7, 75747},
	{"JAYH", 4, 75748},
	{"SBAK", 4, 75749},
	{"EWEF", 4, 75750},
	{"PENILE", 6, 75751},
	{"SEPARABLE", 9, 75752},
	{"POSITRON", 8, 75753},
	{"METALLURGICAL", 13, 75754},
	{"ORDINATING", 10, 75755},
	{"RVEG", 4, 75756},
	{"CAREGIVING", 10, 75757},
	{"MOLYBDENUM", 10, 75758},
	{"EASLEY", 6, 75759},
	{"LIQUEUR", 7, 75760},
	{"SPOKES", 6, 75761},
	{"ULBR", 4, 75762},
	{"AWLA", 4, 75763},
	{"ARRH", 4, 75764},
	{"PASTIME", 7, 75765},
	{"PURSUES", 7, 75766},
	{"HEXAGONAL", 9, 75767},
	{"THROATED", 8, 75768},
	{"CONTRAVENTION", 13, 75769},
	{"UCTL", 4, 75770},
	{"BUGLE", 5, 75771},
	{"BACTERIOL", 9, 75772},
	{"HEALERS", 7, 75773},
	{"YKAT", 4, 75774},
	{"TMYT", 4, 75775},
	{"RDSV", 4, 75776},
	{"OWBL", 4, 75777},
	{"DCYC", 4, 75778},
	{"AFTR", 4, 75779},
	{"SUPERBIKE", 9, 75780},
	{"LUXEMBURG", 9, 75781},
	{"DISPERSE", 8, 75782},
	{"BIOSAFETY", 9, 75783},
	{"ORNY", 4, 75784},
	{"DISJ", 4, 75785},
	{"BINOMIAL", 8, 75786},
	{"UDEG", 4, 75787},
	{"AYVA", 4, 75788},
	{"ENGELS", 6, 75789},
	{"INCOHERENT", 10, 75790},
	{"FOURS", 5, 75791},
	{"SYRU", 4, 75792},
	{"RDPI", 4, 75793},
	{"LPDE", 4, 75794},
	{"STAYBRIDGE", 10, 75795},
	{"MMYF", 4, 75796},
	{"MULLET", 6, 75797},
	{"CANFIELD", 8, 75798},
	{"UGCO", 4, 75799},
	{"HARDBALL", 8, 75800},
	{"OREM", 4, 75801},
	{"SCHOLL", 6, 75802},
	{"ARHU", 4, 75803},
	{"RENOVATE", 8, 75804},
	{"DVDR", 4, 75805},
	{"TREFFEN", 7, 75806},
	{"DEVOUT", 6, 75807},
	{"STROM", 5, 75808},
	{"PHENTERMINEBUY", 14, 75809},
	{"METFORMIN", 9, 75810},
	{"ACTUARY", 7, 75811},
	{"ADDRESSBOOK", 11, 75812},
	{"XQUERY", 6, 75813},
	{"ALVA", 4, 75814},
	{"PURDY", 5, 75815},
	{"UNFURNISHED", 11, 75816},
	{"RATTUS", 6, 75817},
	{"RQR", 3, 75818},
	{"DKZ", 3, 75819},
	{"YEVO", 4, 75820},
	{"EKAB", 4, 75821},
	{"BLINDING", 8, 75822},
	{"LATCHES", 7, 75823},
	{"ARDMORE", 7, 75824},
	{"COSMETOLOGY", 11, 75825},
	{"EMITTER", 7, 75826},
	{"ODOG", 4, 75827},
	{"GALU", 4, 75828},
	{"GRILS", 5, 75829},
	{"RALSTON", 7, 75830},
	{"INACTION", 8, 75831},
	{"URSY", 4, 75832},
	{"RDJA", 4, 75833},
	{"OIDD", 4, 75834},
	{"ESTADOS", 7, 75835},
	{"BEGINING", 8, 75836},
	{"APARTAMENTOS", 12, 75837},
	{"SASSOON", 7, 75838},
	{"HOTLOG", 6, 75839},
	{"YPNO", 4, 75840},
	{"DUQUESNE", 8, 75841},
	{"OCLUG", 5, 75842},
	{"FORMATTER", 9, 75843},
	{"RHINESTONES", 11, 75844},
	{"SHOOTINGS", 9, 75845},
	{"SPLITTERS", 9, 75846},
	{"GDM", 3, 75847},
	{"OPMU", 4, 75848},
	{"PIZZAS", 6, 75849},
	{"CONTIG", 6, 75850},
	{"NORTHWARD", 9, 75851},
	{"DRYW", 4, 75852},
	{"IGRI", 4, 75853},
	{"CYSH", 4, 75854},
	{"TROTTER", 7, 75855},
	{"RSSW", 4, 75856},
	{"RIWI", 4, 75857},
	{"WHITTAKER", 9, 75858},
	{"SUBVERSIVE", 10, 75859},
	{"CONTRE", 6, 75860},
	{"TRAFIC", 6, 75861},
	{"OJEV", 4, 75862},
	{"WINDERS", 7, 75863},
	{"YOBV", 4, 75864},
	{"OGIR", 4, 75865},
	{"IMPEDIMENTS", 11, 75866},
	{"WALKIE", 6, 75867},
	{"ARMOURED", 8, 75868},
	{"ADORAMA", 7, 75869},
	{"UUCP", 4, 75870},
	{"BREATHLESS", 10, 75871},
	{"INTERTWINED", 11, 75872},
	{"POSTMARKED", 10, 75873},
	{"UDYP", 4, 75874},
	{"ITMY", 4, 75875},
	{"DEVOLUTION", 10, 75876},
	{"AVION", 5, 75877},
	{"CORKSCREW", 9, 75878},
	{"REUNIFICATION", 13, 75879},
	{"IZUMI", 5, 75880},
	{"CAENORHABDITIS", 14, 75881},
	{"MODERATING", 10, 75882},
	{"RDSK", 4, 75883},
	{"ABYE", 4, 75884},
	{"TROP", 4, 75885},
	{"GADSDEN", 7, 75886},
	{"AFFECTIONS", 10, 75887},
	{"CTHULHU", 7, 75888},
	{"WEEV", 4, 75889},
	{"ROLR", 4, 75890},
	{"INHERITS", 8, 75891},
	{"EUROSTAR", 8, 75892},
	{"MORTALS", 7, 75893},
	{"PURGATORY", 9, 75894},
	{"BAIJ", 4, 75895},
	{"DOOLEY", 6, 75896},
	{"DIEBOLD", 7, 75897},
	{"COMER", 5, 75898},
	{"UNSATURATED", 11, 75899},
	{"CYDI", 4, 75900},
	{"CFES", 4, 75901},
	{"MWOO", 4, 75902},
	{"HOTSYNC", 7, 75903},
	{"RYERSON", 7, 75904},
	{"TILLAGE", 7, 75905},
	{"BFD", 3, 75906},
	{"PERE", 4, 75907},
	{"GNDE", 4, 75908},
	{"NONEXISTENT", 11, 75909},
	{"DISCLOSES", 9, 75910},
	{"LIQUIDATED", 10, 75911},
	{"DECODERS", 8, 75912},
	{"GHCR", 4, 75913},
	{"FCIR", 4, 75914},
	{"AIMP", 4, 75915},
	{"VALIDATES", 9, 75916},
	{"EASTERLY", 8, 75917},
	{"FICG", 4, 75918},
	{"JACKMAN", 7, 75919},
	{"LAGGED", 6, 75920},
	{"SRIP", 4, 75921},
	{"MPOT", 4, 75922},
	{"BIOPHYSICAL", 11, 75923},
	{"MENDES", 6, 75924},
	{"LASAGNA", 7, 75925},
	{"LANDERS", 7, 75926},
	{"BELTON", 6, 75927},
	{"QING", 4, 75928},
	{"DOCU", 4, 75929},
	{"TAPAS", 5, 75930},
	{"HAWKER", 6, 75931},
	{"SMRE", 4, 75932},
	{"RMTR", 4, 75933},
	{"CKRU", 4, 75934},
	{"CALLA", 5, 75935},
	{"CURRICULUMS", 11, 75936},
	{"SUPERMODEL", 10, 75937},
	{"VERTEBRATES", 11, 75938},
	{"REZONING", 8, 75939},
	{"GBOU", 4, 75940},
	{"DANP", 4, 75941},
	{"ANUB", 4, 75942},
	{"TOUGHNESS", 9, 75943},
	{"DISRESPECT", 10, 75944},
	{"SCHUMER", 7, 75945},
	{"EXCLUSIVITY", 11, 75946},
	{"MOTIVATES", 9, 75947},
	{"DEBUTED", 7, 75948},
	{"LIFEGUARD", 9, 75949},
	{"LAGGING", 7, 75950},
	{"CHRISSY", 7, 75951},
	{"UNCOVERING", 10, 75952},
	{"HAVASU", 6, 75953},
	{"OPMT", 4, 75954},
	{"DANFORTH", 8, 75955},
	{"INDETERMINATE", 13, 75956},
	{"KILMARNOCK", 10, 75957},
	{"REFRESHMENT", 11, 75958},
	{"BIGNATURALS", 11, 75959},
	{"MOMENTARILY", 11, 75960},
	{"FESTA", 5, 75961},
	{"LANGER", 6, 75962},
	{"NGIG", 4, 75963},
	{"LUTE", 4, 75964},
	{"HENDERSONVILLE", 14, 75965},
	{"ROSETTE", 7, 75966},
	{"POWEREDGE", 9, 75967},
	{"SEQUELS", 7, 75968},
	{"LICENSOR", 8, 75969},
	{"CHANGEABLE", 10, 75970},
	{"PANTONE", 7, 75971},
	{"UDSA", 4, 75972},
	{"KAPL", 4, 75973},
	{"GRANBY", 6, 75974},
	{"TRAGICALLY", 10, 75975},
	{"LABORATOIRE", 11, 75976},
	{"HEADTEACHER", 11, 75977},
	{"VIAJES", 6, 75978},
	{"ETOSHA", 6, 75979},
	{"WAVERLEY", 8, 75980},
	{"UEOU", 4, 75981},
	{"NYDR", 4, 75982},
	{"NFLT", 4, 75983},
	{"KEQU", 4, 75984},
	{"CUSM", 4, 75985},
	{"COEXISTENCE", 11, 75986},
	{"LEONA", 5, 75987},
	{"DPR", 3, 75988},
	{"WOFM", 4, 75989},
	{"MNUM", 4, 75990},
	{"BROWNFIELD", 10, 75991},
	{"CLAPHAM", 7, 75992},
	{"AGUILAR", 7, 75993},
	{"SUPERVISES", 10, 75994},
	{"ORTHOLOGS", 9, 75995},
	{"PBAN", 4, 75996},
	{"AZIR", 4, 75997},
	{"ADYU", 4, 75998},
	{"TRUMPS", 6, 75999},
	{"PATAKI", 6, 76000},
	{"REDISTRICTING", 13, 76001},
	{"RNSR", 4, 76002},
	{"AMRITSAR", 8, 76003},
	{"JUSTIFIABLE", 11, 76004},
	{"QFU", 3, 76005},
	{"QDD", 3, 76006},
	{"MKZ", 3, 76007},
	{"DJQ", 3, 76008},
	{"XEDU", 4, 76009},
	{"PRAM", 4, 76010},
	{"TWOFOLD", 7, 76011},
	{"FTOG", 4, 76012},
	{"SICILIAN", 8, 76013},
	{"ACQUA", 5, 76014},
	{"MEKONG", 6, 76015},
	{"MARLOWE", 7, 76016},
	{"ANESTHETIC", 10, 76017},
	{"NKIF", 4, 76018},
	{"CUAD", 4, 76019},
	{"BUYB", 4, 76020},
	{"MADURAS", 7, 76021},
	{"OUAD", 4, 76022},
	{"NMOM", 4, 76023},
	{"PAPERLESS", 9, 76024},
	{"PERC", 4, 76025},
	{"FANSITES", 8, 76026},
	{"SHERBROOKE", 10, 76027},
	{"EGYPTIENNE", 10, 76028},
	{"ANISOTROPY", 10, 76029},
	{"ZENP", 4, 76030},
	{"ZEDG", 4, 76031},
	{"TELD", 4, 76032},
	{"EGIG", 4, 76033},
	{"UNEARNED", 8, 76034},
	{"THWART", 6, 76035},
	{"HEATON", 6, 76036},
	{"POTTED", 6, 76037},
	{"RENNIE", 6, 76038},
	{"CHANSON", 7, 76039},
	{"REDOX", 5, 76040},
	{"CLADDING", 8, 76041},
	{"SEAWORLD", 8, 76042},
	{"HOTLIST", 7, 76043},
	{"AMELIE", 6, 76044},
	{"TRUMBULL", 8, 76045},
	{"INCURRING", 9, 76046},
	{"ZBOL", 4, 76047},
	{"LMDI", 4, 76048},
	{"ILPE", 4, 76049},
	{"RETRANSMISSION", 14, 76050},
	{"LUAU", 4, 76051},
	{"GRACIAS", 7, 76052},
	{"TISCALI", 7, 76053},
	{"OVERLAPS", 8, 76054},
	{"METICULOUSLY", 12, 76055},
	{"CONVALESCENT", 12, 76056},
	{"SITKA", 5, 76057},
	{"TERME", 5, 76058},
	{"MACKEREL", 8, 76059},
	{"SUSR", 4, 76060},
	{"PANF", 4, 76061},
	{"OWSG", 4, 76062},
	{"GOINGS", 6, 76063},
	{"MIDG", 4, 76064},
	{"BRIM", 4, 76065},
	{"KACT", 4, 76066},
	{"CLINCH", 6, 76067},
	{"PROVIDENT", 9, 76068},
	{"LEPROSY", 7, 76069},
	{"CHUM", 4, 76070},
	{"LERV", 4, 76071},
	{"LBIT", 4, 76072},
	{"HYPN", 4, 76073},
	{"GDEG", 4, 76074},
	{"AWAP", 4, 76075},
	{"COMETH", 6, 76076},
	{"HELLBOY", 7, 76077},
	{"TWEF", 4, 76078},
	{"JAKUB", 5, 76079},
	{"HANSELMAN", 9, 76080},
	{"RANGEMASTER", 11, 76081},
	{"INTERCEPTIONS", 13, 76082},
	{"FITTER", 6, 76083},
	{"TUSR", 4, 76084},
	{"ORAQ", 4, 76085},
	{"RRC", 3, 76086},
	{"DYNA", 4, 76087},
	{"APPT", 4, 76088},
	{"UNBR", 4, 76089},
	{"PAMO", 4, 76090},
	{"LOSP", 4, 76091},
	{"GEEC", 4, 76092},
	{"DIPI", 4, 76093},
	{"NONVIOLENT", 10, 76094},
	{"GLUT", 4, 76095},
	{"XTAP", 4, 76096},
	{"SSGU", 4, 76097},
	{"RBYO", 4, 76098},
	{"CYWO", 4, 76099},
	{"FASTEN", 6, 76100},
	{"EVANGELICALS", 12, 76101},
	{"CUNNY", 5, 76102},
	{"WOLFOWITZ", 9, 76103},
	{"LOCKSMITH", 9, 76104},
	{"LGUN", 4, 76105},
	{"LFMO", 4, 76106},
	{"ELGU", 4, 76107},
	{"DWEG", 4, 76108},
	{"INTERRUPTING", 12, 76109},
	{"SULLA", 5, 76110},
	{"EPPING", 6, 76111},
	{"ACCRA", 5, 76112},
	{"BIMBO", 5, 76113},
	{"DAGGERS", 7, 76114},
	{"UNKR", 4, 76115},
	{"SRAY", 4, 76116},
	{"LBEY", 4, 76117},
	{"PLEASES", 7, 76118},
	{"JAMBOREE", 8, 76119},
	{"MULTICOLOR", 10, 76120},
	{"MOORS", 5, 76121},
	{"EMCH", 4, 76122},
	{"GERANIUM", 8, 76123},
	{"KENDAL", 6, 76124},
	{"IFPR", 4, 76125},
	{"TRITIUM", 7, 76126},
	{"PUTW", 4, 76127},
	{"PTFE", 4, 76128},
	{"REVOLVE", 7, 76129},
	{"RUTO", 4, 76130},
	{"GDIN", 4, 76131},
	{"CHOC", 4, 76132},
	{"LEACHING", 8, 76133},
	{"WBIG", 4, 76134},
	{"RKCL", 4, 76135},
	{"MDRA", 4, 76136},
	{"IMRI", 4, 76137},
	{"SAUER", 5, 76138},
	{"LENL", 4, 76139},
	{"INCW", 4, 76140},
	{"DJAR", 4, 76141},
	{"CRICINFO", 8, 76142},
	{"ISOMORPHISM", 11, 76143},
	{"ESTAB", 5, 76144},
	{"WAGED", 5, 76145},
	{"UCHV", 4, 76146},
	{"REIB", 4, 76147},
	{"STOCKBRIDGE", 11, 76148},
	{"INVARIANTS", 10, 76149},
	{"JILLIAN", 7, 76150},
	{"WAXED", 5, 76151},
	{"CONCOURSE", 9, 76152},
	{"ISLIP", 5, 76153},
	{"RSSL", 4, 76154},
	{"LKOR", 4, 76155},
	{"CONFINE", 7, 76156},
	{"NDYP", 4, 76157},
	{"DIDIER", 6, 76158},
	{"JADED", 5, 76159},
	{"MINGLE", 6, 76160},
	{"CAPISTRANO", 10, 76161},
	{"RKPE", 4, 76162},
	{"YARDAGE", 7, 76163},
	{"ENVIRO", 6, 76164},
	{"BODYBUILDERS", 12, 76165},
	{"OMOG", 4, 76166},
	{"RANCHERS", 8, 76167},
	{"BREMERTON", 9, 76168},
	{"WBC", 3, 76169},
	{"PURIFY", 6, 76170},
	{"EGOU", 4, 76171},
	{"RADII", 5, 76172},
	{"DESOLATE", 8, 76173},
	{"WITHDRAWS", 9, 76174},
	{"ZWW", 3, 76175},
	{"XGB", 3, 76176},
	{"KJG", 3, 76177},
	{"KFJ", 3, 76178},
	{"SCHWINN", 7, 76179},
	{"CHOKED", 6, 76180},
	{"EXPANDER", 8, 76181},
	{"WHEREOF", 7, 76182},
	{"REGT", 4, 76183},
	{"REFERER", 7, 76184},
	{"ELECTROLYSIS", 12, 76185},
	{"MSKI", 4, 76186},
	{"GYET", 4, 76187},
	{"COOW", 4, 76188},
	{"SIGNATORIES", 11, 76189},
	{"PAPE", 4, 76190},
	{"GRUESOME", 8, 76191},
	{"WETSUIT", 7, 76192},
	{"FLATRATE", 8, 76193},
	{"TWIR", 4, 76194},
	{"RDKI", 4, 76195},
	{"MWAY", 4, 76196},
	{"GEFL", 4, 76197},
	{"VENDITA", 7, 76198},
	{"NAZIONALE", 9, 76199},
	{"PEROXIDASE", 10, 76200},
	{"PLEADINGS", 9, 76201},
	{"FOLKESTONE", 10, 76202},
	{"ANGKOR", 6, 76203},
	{"YHID", 4, 76204},
	{"DEFYING", 7, 76205},
	{"DELCAMPE", 8, 76206},
	{"TAYLORS", 7, 76207},
	{"RAHUL", 5, 76208},
	{"MMR", 3, 76209},
	{"PERISHED", 8, 76210},
	{"UMPY", 4, 76211},
	{"BYSW", 4, 76212},
	{"ERSKINE", 7, 76213},
	{"TENTACLES", 9, 76214},
	{"BRITONS", 7, 76215},
	{"VSERVER", 7, 76216},
	{"PRINGLE", 7, 76217},
	{"OUTCAST", 7, 76218},
	{"NEUROLOGIC", 10, 76219},
	{"WNGA", 4, 76220},
	{"IZEL", 4, 76221},
	{"ILPM", 4, 76222},
	{"OPAC", 4, 76223},
	{"FARADAY", 7, 76224},
	{"TCUP", 4, 76225},
	{"KKER", 4, 76226},
	{"CMV", 3, 76227},
	{"OBLONG", 6, 76228},
	{"MACABRE", 7, 76229},
	{"OPHELIA", 7, 76230},
	{"AVYP", 4, 76231},
	{"NEURONTIN", 9, 76232},
	{"POPEYE", 6, 76233},
	{"GRUBER", 6, 76234},
	{"WEARER", 6, 76235},
	{"EXCERPTED", 9, 76236},
	{"SPOTTER", 7, 76237},
	{"PYONGYANG", 9, 76238},
	{"LSHU", 4, 76239},
	{"RTDR", 4, 76240},
	{"OOML", 4, 76241},
	{"AUPR", 4, 76242},
	{"BELTONEN", 8, 76243},
	{"TBEV", 4, 76244},
	{"CHAMONIX", 8, 76245},
	{"RECYCLER", 8, 76246},
	{"PROPRIETY", 9, 76247},
	{"DECLARATIVE", 11, 76248},
	{"SEMAPHORE", 9, 76249},
	{"ATTAINABLE", 10, 76250},
	{"DPRK", 4, 76251},
	{"CARMARTHENSHIRE", 15, 76252},
	{"UWEN", 4, 76253},
	{"HELC", 4, 76254},
	{"HEARSAY", 7, 76255},
	{"TRISTATE", 8, 76256},
	{"STANDARDIZE", 11, 76257},
	{"RECYCLABLE", 10, 76258},
	{"YSJU", 4, 76259},
	{"RIOB", 4, 76260},
	{"KDRA", 4, 76261},
	{"KNICKERS", 8, 76262},
	{"ROOMY", 5, 76263},
	{"OVERLOADING", 11, 76264},
	{"BRUTUS", 6, 76265},
	{"ANGIOPLASTY", 11, 76266},
	{"WAYJ", 4, 76267},
	{"OUYO", 4, 76268},
	{"FANBOY", 6, 76269},
	{"OBSCURITY", 9, 76270},
	{"SHARAPOVA", 9, 76271},
	{"HEROS", 5, 76272},
	{"DESERET", 7, 76273},
	{"LOFK", 4, 76274},
	{"EASTBAY", 7, 76275},
	{"COLONISTS", 9, 76276},
	{"MATTING", 7, 76277},
	{"OVERFLOWING", 11, 76278},
	{"OFKR", 4, 76279},
	{"NKLO", 4, 76280},
	{"GOAB", 4, 76281},
	{"DDUS", 4, 76282},
	{"CAPERS", 6, 76283},
	{"ANDROGEN", 8, 76284},
	{"ENTICE", 6, 76285},
	{"PARKES", 6, 76286},
	{"KILOGRAM", 8, 76287},
	{"XBRE", 4, 76288},
	{"MSIZ", 4, 76289},
	{"EPBU", 4, 76290},
	{"PACEMAKER", 9, 76291},
	{"DUARTE", 6, 76292},
	{"EVALUATORS", 10, 76293},
	{"URGP", 4, 76294},
	{"RKGI", 4, 76295},
	{"TARBALL", 7, 76296},
	{"NEARS", 5, 76297},
	{"KAPOOR", 6, 76298},
	{"MATB", 4, 76299},
	{"LMSE", 4, 76300},
	{"ALLARD", 6, 76301},
	{"LASSO", 5, 76302},
	{"YONDER", 6, 76303},
	{"VIRULENCE", 9, 76304},
	{"TURES", 5, 76305},
	{"YTAC", 4, 76306},
	{"YSYN", 4, 76307},
	{"WTER", 4, 76308},
	{"MLEV", 4, 76309},
	{"STANDOUT", 8, 76310},
	{"LLL", 3, 76311},
	{"HOLLEY", 6, 76312},
	{"KROB", 4, 76313},
	{"TRANSAMERICA", 12, 76314},
	{"BDRM", 4, 76315},
	{"HERETIC", 7, 76316},
	{"XTDE", 4, 76317},
	{"NKPR", 4, 76318},
	{"COMPARABILITY", 13, 76319},
	{"BUCKHEAD", 8, 76320},
	{"INDUSTRIALIZATION", 17, 76321},
	{"LMTO", 4, 76322},
	{"CABANA", 6, 76323},
	{"MBR", 3, 76324},
	{"DRAUGHT", 7, 76325},
	{"COMICAL", 7, 76326},
	{"ODOY", 4, 76327},
	{"GENERALIZATIONS", 15, 76328},
	{"YOSHI", 5, 76329},
	{"WAITERS", 7, 76330},
	{"GASPED", 6, 76331},
	{"UEGO", 4, 76332},
	{"MRHA", 4, 76333},
	{"DLAI", 4, 76334},
	{"SKOKIE", 6, 76335},
	{"CATWALK", 7, 76336},
	{"GEOLOGISTS", 10, 76337},
	{"CAVERNS", 7, 76338},
	{"KICO", 4, 76339},
	{"HOMESITE", 8, 76340},
	{"BOARDER", 7, 76341},
	{"PECOS", 5, 76342},
	{"STINSON", 7, 76343},
	{"BLURRY", 6, 76344},
	{"ETRUST", 6, 76345},
	{"YADR", 4, 76346},
	{"PUDD", 4, 76347},
	{"MINIBUS", 7, 76348},
	{"BUMPING", 7, 76349},
	{"COTY", 4, 76350},
	{"DENBY", 5, 76351},
	{"OPENBOOK", 8, 76352},
	{"UNFUNDED", 8, 76353},
	{"JOBSITE", 7, 76354},
	{"GREETS", 6, 76355},
	{"YRUP", 4, 76356},
	{"RDOD", 4, 76357},
	{"IJAY", 4, 76358},
	{"AUDS", 4, 76359},
	{"CZJ", 3, 76360},
	{"CJJ", 3, 76361},
	{"LEVINSON", 8, 76362},
	{"KASEY", 5, 76363},
	{"OIDF", 4, 76364},
	{"DISBURSED", 9, 76365},
	{"YSBY", 4, 76366},
	{"ULAG", 4, 76367},
	{"OWLG", 4, 76368},
	{"AMYA", 4, 76369},
	{"CRISTIAN", 8, 76370},
	{"WAXES", 5, 76371},
	{"BALLOONING", 10, 76372},
	{"ANTINEOPLASTIC", 14, 76373},
	{"AMPLIFY", 7, 76374},
	{"SYCA", 4, 76375},
	{"GYCA", 4, 76376},
	{"SHITTING", 8, 76377},
	{"WHIZ", 4, 76378},
	{"BEVEL", 5, 76379},
	{"STRAINING", 9, 76380},
	{"CODEN", 5, 76381},
	{"CONGRESSMEN", 11, 76382},
	{"AKUM", 4, 76383},
	{"STRAPLESS", 9, 76384},
	{"SEDUCED", 7, 76385},
	{"QUALITATIVELY", 13, 76386},
	{"STRUC", 5, 76387},
	{"WHITEFISH", 9, 76388},
	{"FLOURISHED", 10, 76389},
	{"EJECTION", 8, 76390},
	{"YLAP", 4, 76391},
	{"NCTL", 4, 76392},
	{"PUYALLUP", 8, 76393},
	{"BONHAM", 6, 76394},
	{"COSPLAY", 7, 76395},
	{"GAZDUIRE", 8, 76396},
	{"DODGY", 5, 76397},
	{"PARASITOLOGY", 12, 76398},
	{"THYMUS", 6, 76399},
	{"HTBL", 4, 76400},
	{"EXPU", 4, 76401},
	{"CKJU", 4, 76402},
	{"HANDLEBAR", 9, 76403},
	{"SANBORN", 7, 76404},
	{"BEALE", 5, 76405},
	{"ANGRILY", 7, 76406},
	{"LOCATORS", 8, 76407},
	{"BELIVE", 6, 76408},
	{"CROQUET", 7, 76409},
	{"KMOS", 4, 76410},
	{"MNOGOSEARCH", 11, 76411},
	{"VACATE", 6, 76412},
	{"CHILDRESS", 9, 76413},
	{"PPPOE", 5, 76414},
	{"PHYTOPLANKTON", 13, 76415},
	{"WIRELINE", 8, 76416},
	{"TRUI", 4, 76417},
	{"NMYW", 4, 76418},
	{"IEDY", 4, 76419},
	{"HANDPAINTED", 11, 76420},
	{"STANISLAUS", 10, 76421},
	{"WEKE", 4, 76422},
	{"TAUP", 4, 76423},
	{"LGLA", 4, 76424},
	{"INDJ", 4, 76425},
	{"AKCO", 4, 76426},
	{"SUPRISE", 7, 76427},
	{"SOUNDNESS", 9, 76428},
	{"CASSEROLES", 10, 76429},
	{"YISV", 4, 76430},
	{"WBRU", 4, 76431},
	{"EYSD", 4, 76432},
	{"GENERATIONAL", 12, 76433},
	{"MARQUISE", 8, 76434},
	{"PPYS", 4, 76435},
	{"LNEG", 4, 76436},
	{"IELM", 4, 76437},
	{"GPAP", 4, 76438},
	{"AYCI", 4, 76439},
	{"COPPOLA", 7, 76440},
	{"BURRITO", 7, 76441},
	{"SANDTON", 7, 76442},
	{"SPYLOG", 6, 76443},
	{"BILTMORE", 8, 76444},
	{"CORIANDER", 9, 76445},
	{"EDTV", 4, 76446},
	{"BONJOUR", 7, 76447},
	{"CHOPRA", 6, 76448},
	{"UMNU", 4, 76449},
	{"SRYA", 4, 76450},
	{"DIPO", 4, 76451},
	{"XXIII", 5, 76452},
	{"PROTRACTED", 10, 76453},
	{"STREAMFLOW", 10, 76454},
	{"MONTOYA", 7, 76455},
	{"SIEGFRIED", 9, 76456},
	{"BANB", 4, 76457},
	{"AFFAIRES", 8, 76458},
	{"MANIPULATIVE", 12, 76459},
	{"DIGBY", 5, 76460},
	{"HYPNOTIZE", 9, 76461},
	{"EYELID", 6, 76462},
	{"LIAISONS", 8, 76463},
	{"BACKERS", 7, 76464},
	{"UPEO", 4, 76465},
	{"MRST", 4, 76466},
	{"EVOCATIVE", 9, 76467},
	{"UNDENIABLE", 10, 76468},
	{"TAMING", 6, 76469},
	{"MCCLELLAND", 10, 76470},
	{"CENTERFOLD", 10, 76471},
	{"KKIN", 4, 76472},
	{"HOFY", 4, 76473},
	{"BURCH", 5, 76474},
	{"CHESTERTON", 10, 76475},
	{"PRECLUDED", 9, 76476},
	{"ZERW", 4, 76477},
	{"WARLORD", 7, 76478},
	{"REPRESSED", 9, 76479},
	{"PERFORCE", 8, 76480},
	{"XHOU", 4, 76481},
	{"DYBO", 4, 76482},
	{"GUAGE", 5, 76483},
	{"POWERBALL", 9, 76484},
	{"SNIDER", 6, 76485},
	{"RJET", 4, 76486},
	{"OWDU", 4, 76487},
	{"CREUSET", 7, 76488},
	{"WILDLAND", 8, 76489},
	{"OSTER", 5, 76490},
	{"BARONS", 6, 76491},
	{"CONTI", 5, 76492},
	{"SICHUAN", 7, 76493},
	{"WRIGLEY", 7, 76494},
	{"TIMC", 4, 76495},
	{"MULC", 4, 76496},
	{"IFSU", 4, 76497},
	{"CTGA", 4, 76498},
	{"BOLLINGER", 9, 76499},
	{"SENSITIVITIES", 13, 76500},
	{"OFFSHORING", 10, 76501},
	{"BOUNDLESS", 9, 76502},
	{"HOPELESSLY", 10, 76503},
	{"BAYES", 5, 76504},
	{"VIPIX", 5, 76505},
	{"IGIM", 4, 76506},
	{"AMPHIBIAN", 9, 76507},
	{"SUBSTATION", 10, 76508},
	{"OPTICALLY", 9, 76509},
	{"SUCRE", 5, 76510},
	{"CEASEFIRE", 9, 76511},
	{"SWARTZ", 6, 76512},
	{"NANOPARTICLES", 13, 76513},
	{"PASTEUR", 7, 76514},
	{"NFEW", 4, 76515},
	{"EWPU", 4, 76516},
	{"AFFINE", 6, 76517},
	{"SITIOS", 6, 76518},
	{"VALUABLES", 9, 76519},
	{"MKEN", 4, 76520},
	{"INDIGNATION", 11, 76521},
	{"RNMU", 4, 76522},
	{"KJOH", 4, 76523},
	{"EGYO", 4, 76524},
	{"AGRU", 4, 76525},
	{"UNAME", 5, 76526},
	{"EMPLOYMENTNEW", 13, 76527},
	{"SPRINKLED", 9, 76528},
	{"MENSTRUATION", 12, 76529},
	{"KVY", 3, 76530},
	{"GVY", 3, 76531},
	{"EBCA", 4, 76532},
	{"ASROCK", 6, 76533},
	{"STUFFS", 6, 76534},
	{"HIJACKING", 9, 76535},
	{"BLURBS", 6, 76536},
	{"ANTICHRIST", 10, 76537},
	{"EMPTYING", 8, 76538},
	{"TBLI", 4, 76539},
	{"MALV", 4, 76540},
	{"DOWNSIZING", 10, 76541},
	{"SUBCUTANEOUS", 12, 76542},
	{"CREATININE", 10, 76543},
	{"UCKP", 4, 76544},
	{"RDBL", 4, 76545},
	{"FACTORIZATION", 13, 76546},
	{"REITERATE", 9, 76547},
	{"NETBIOS", 7, 76548},
	{"FLESHLIGHT", 10, 76549},
	{"TYCU", 4, 76550},
	{"GMIG", 4, 76551},
	{"RELIEVER", 8, 76552},
	{"ENDER", 5, 76553},
	{"INDENTURE", 9, 76554},
	{"ARLEN", 5, 76555},
	{"TRAILBLAZER", 11, 76556},
	{"CONEY", 5, 76557},
	{"ONDJ", 4, 76558},
	{"OFYU", 4, 76559},
	{"LJAP", 4, 76560},
	{"HIMALAYAS", 9, 76561},
	{"AVENIDA", 7, 76562},
	{"SHOCKER", 7, 76563},
	{"BARNSTABLE", 10, 76564},
	{"MONOPOLIES", 10, 76565},
	{"ZERT", 4, 76566},
	{"UNFL", 4, 76567},
	{"UEAP", 4, 76568},
	{"GHPU", 4, 76569},
	{"BRIU", 4, 76570},
	{"SOWING", 6, 76571},
	{"WREQ", 4, 76572},
	{"WEMP", 4, 76573},
	{"AMFE", 4, 76574},
	{"IOCTL", 5, 76575},
	{"BRONTE", 6, 76576},
	{"REFRIGERANT", 11, 76577},
	{"CATERHAM", 8, 76578},
	{"FRILLS", 6, 76579},
	{"BAJAR", 5, 76580},
	{"MOVEI", 5, 76581},
	{"ILBL", 4, 76582},
	{"IERV", 4, 76583},
	{"SHEARING", 8, 76584},
	{"BARKLEY", 7, 76585},
	{"DATACENTER", 10, 76586},
	{"PRESIDIO", 8, 76587},
	{"RUINING", 7, 76588},
	{"TRANSFECTION", 12, 76589},
	{"YMDA", 4, 76590},
	{"FUNG", 4, 76591},
	{"PINION", 6, 76592},
	{"LEGG", 4, 76593},
	{"MOYER", 5, 76594},
	{"ROUX", 4, 76595},
	{"SAWP", 4, 76596},
	{"NFLC", 4, 76597},
	{"WINDWARD", 8, 76598},
	{"HERMOSA", 7, 76599},
	{"HAUNTS", 6, 76600},
	{"UNSERE", 6, 76601},
	{"RWRE", 4, 76602},
	{"RECTANGLES", 10, 76603},
	{"CASELOAD", 8, 76604},
	{"TBYJ", 4, 76605},
	{"OUBO", 4, 76606},
	{"HROY", 4, 76607},
	{"FTPA", 4, 76608},
	{"BRAWL", 5, 76609},
	{"DELIRIUM", 8, 76610},
	{"CATHARINES", 10, 76611},
	{"PDX", 3, 76612},
	{"WGET", 4, 76613},
	{"COLLABORATOR", 12, 76614},
	{"CRUZER", 6, 76615},
	{"YAGG", 4, 76616},
	{"UPGA", 4, 76617},
	{"RTAY", 4, 76618},
	{"ASYR", 4, 76619},
	{"UNFOUNDED", 9, 76620},
	{"SAUSALITO", 9, 76621},
	{"IMYO", 4, 76622},
	{"HEROISM", 7, 76623},
	{"CLAS", 4, 76624},
	{"GILLIS", 6, 76625},
	{"XENOPUS", 7, 76626},
	{"REFLECTORS", 10, 76627},
	{"RGHO", 4, 76628},
	{"RERF", 4, 76629},
	{"ILRA", 4, 76630},
	{"RUTLEDGE", 8, 76631},
	{"ENDORSING", 9, 76632},
	{"QINGDAO", 7, 76633},
	{"GSAW", 4, 76634},
	{"DGEG", 4, 76635},
	{"KIWANIS", 7, 76636},
	{"BARRISTER", 9, 76637},
	{"ONLINEPHENTERMINE", 17, 76638},
	{"GIAR", 4, 76639},
	{"REPLICATOR", 10, 76640},
	{"NEGLECTING", 10, 76641},
	{"ASSERTIVE", 9, 76642},
	{"ALDERSHOT", 9, 76643},
	{"WEIRDNESS", 9, 76644},
	{"OBLAST", 6, 76645},
	{"TOWNHALL", 8, 76646},
	{"SAXONY", 6, 76647},
	{"SUNNYSIDE", 9, 76648},
	{"KAREL", 5, 76649},
	{"DATOS", 5, 76650},
	{"TAXL", 4, 76651},
	{"PHAM", 4, 76652},
	{"GLYCOGEN", 8, 76653},
	{"SELANGOR", 8, 76654},
	{"DETAINEE", 8, 76655},
	{"BRD", 3, 76656},
	{"ALIENATED", 9, 76657},
	{"HOOSIER", 7, 76658},
	{"OOMR", 4, 76659},
	{"KSGR", 4, 76660},
	{"HSBU", 4, 76661},
	{"BALEARIC", 8, 76662},
	{"SYNAGOGUES", 10, 76663},
	{"TOLUENE", 7, 76664},
	{"TUBAL", 5, 76665},
	{"TYJO", 4, 76666},
	{"TAJU", 4, 76667},
	{"LMHA", 4, 76668},
	{"DALD", 4, 76669},
	{"LONGFORD", 8, 76670},
	{"JOHANSEN", 8, 76671},
	{"PHOTOCOPIES", 11, 76672},
	{"MITB", 4, 76673},
	{"FFSF", 4, 76674},
	{"ECHF", 4, 76675},
	{"BEMY", 4, 76676},
	{"HACCP", 5, 76677},
	{"NMYD", 4, 76678},
	{"KIMP", 4, 76679},
	{"GHBY", 4, 76680},
	{"BELW", 4, 76681},
	{"NARCONON", 8, 76682},
	{"DYNO", 4, 76683},
	{"BLAKELY", 7, 76684},
	{"KLONOPIN", 8, 76685},
	{"PHOTONIC", 8, 76686},
	{"KYIV", 4, 76687},
	{"RTCE", 4, 76688},
	{"HIJACKERS", 9, 76689},
	{"ENTANGLED", 9, 76690},
	{"BUELL", 5, 76691},
	{"INFORMAZIONI", 12, 76692},
	{"REISE", 5, 76693},
	{"LIBERATING", 10, 76694},
	{"UNGK", 4, 76695},
	{"PLYE", 4, 76696},
	{"MCCRACKEN", 9, 76697},
	{"ULTRASONOGRAPHY", 15, 76698},
	{"EYMC", 4, 76699},
	{"DOBT", 4, 76700},
	{"APEV", 4, 76701},
	{"EMBARKING", 9, 76702},
	{"CALE", 4, 76703},
	{"ALYSON", 6, 76704},
	{"TAUPO", 5, 76705},
	{"POSSUM", 6, 76706},
	{"TONNEAU", 7, 76707},
	{"CYNICISM", 8, 76708},
	{"MILLIGAN", 8, 76709},
	{"ROSACEA", 7, 76710},
	{"TRANSGENDERED", 13, 76711},
	{"BAYONET", 7, 76712},
	{"CONSIDERATE", 11, 76713},
	{"TOXICOLOGICAL", 13, 76714},
	{"EXTRANEOUS", 10, 76715},
	{"WNVI", 4, 76716},
	{"THRY", 4, 76717},
	{"LPPE", 4, 76718},
	{"DHYP", 4, 76719},
	{"CEOB", 4, 76720},
	{"JANITOR", 7, 76721},
	{"ENVIRONS", 8, 76722},
	{"MACKEY", 6, 76723},
	{"RISTORANTE", 10, 76724},
	{"OBAMA", 5, 76725},
	{"RBSO", 4, 76726},
	{"DVC", 3, 76727},
	{"JERMAINE", 8, 76728},
	{"RNUP", 4, 76729},
	{"CTSG", 4, 76730},
	{"PLATYPUS", 8, 76731},
	{"BREAKBEAT", 9, 76732},
	{"KARINA", 6, 76733},
	{"JANG", 4, 76734},
	{"THEREUNDER", 10, 76735},
	{"KINK", 4, 76736},
	{"WINTON", 6, 76737},
	{"EDSD", 4, 76738},
	{"ACBO", 4, 76739},
	{"HOLLA", 5, 76740},
	{"REVERSES", 8, 76741},
	{"MULTILAYER", 10, 76742},
	{"FWJ", 3, 76743},
	{"STRCPY", 6, 76744},
	{"XZIBIT", 6, 76745},
	{"ODGU", 4, 76746},
	{"IDMC", 4, 76747},
	{"REUNITE", 7, 76748},
	{"MOHAIR", 6, 76749},
	{"CHORE", 5, 76750},
	{"HAWKEYE", 7, 76751},
	{"STEERS", 6, 76752},
	{"RAVENNA", 7, 76753},
	{"LFAF", 4, 76754},
	{"KWEH", 4, 76755},
	{"CROCKERY", 8, 76756},
	{"JURIES", 6, 76757},
	{"KGB", 3, 76758},
	{"VULG", 4, 76759},
	{"RUSM", 4, 76760},
	{"EWIP", 4, 76761},
	{"PRESIDENTE", 10, 76762},
	{"WREM", 4, 76763},
	{"HGIR", 4, 76764},
	{"EPFR", 4, 76765},
	{"PREEMPTIVE", 10, 76766},
	{"GARE", 4, 76767},
	{"GUZMAN", 6, 76768},
	{"LEGACIES", 8, 76769},
	{"ULIO", 4, 76770},
	{"RABD", 4, 76771},
	{"HOPB", 4, 76772},
	{"SUBCONTRACTING", 14, 76773},
	{"COUNTERTERRORISM", 16, 76774},
	{"COMMUNICATORS", 13, 76775},
	{"EMBODIMENTS", 11, 76776},
	{"SOCIEDAD", 8, 76777},
	{"PODT", 4, 76778},
	{"MPSU", 4, 76779},
	{"TASKFORCE", 9, 76780},
	{"GATINEAU", 8, 76781},
	{"THEOLOGIANS", 11, 76782},
	{"PERTUSSIS", 9, 76783},
	{"LSEF", 4, 76784},
	{"GHUS", 4, 76785},
	{"CONCENTRATOR", 12, 76786},
	{"ASTROPHYSICAL", 13, 76787},
	{"APAP", 4, 76788},
	{"PAIRWISE", 8, 76789},
	{"NAGY", 4, 76790},
	{"ARNAUD", 6, 76791},
	{"ENTICING", 8, 76792},
	{"GELW", 4, 76793},
	{"EMBANKMENT", 10, 76794},
	{"QUADRUPLE", 9, 76795},
	{"HOFSTRA", 7, 76796},
	{"CRAZED", 6, 76797},
	{"XXII", 4, 76798},
	{"FILMSTRIP", 9, 76799},
	{"SHORTCAKE", 9, 76800},
	{"EQUIPPING", 9, 76801},
	{"USIB", 4, 76802},
	{"GUPB", 4, 76803},
	{"FONDLY", 6, 76804},
	{"WHITHER", 7, 76805},
	{"CHILLIWACK", 10, 76806},
	{"COUNTERACT", 10, 76807},
	{"BIDORBUY", 8, 76808},
	{"SIGHS", 5, 76809},
	{"YIFH", 4, 76810},
	{"GLUN", 4, 76811},
	{"TETRACYCLINE", 12, 76812},
	{"LOVETT", 6, 76813},
	{"MOTORHEAD", 9, 76814},
	{"DISCOURAGING", 12, 76815},
	{"SALAM", 5, 76816},
	{"HOFMANN", 7, 76817},
	{"PARAMILITARY", 12, 76818},
	{"FLIPPER", 7, 76819},
	{"EYEBALL", 7, 76820},
	{"OUTFITTER", 9, 76821},
	{"WISB", 4, 76822},
	{"GSEM", 4, 76823},
	{"EWEY", 4, 76824},
	{"AULP", 4, 76825},
	{"MINDEN", 6, 76826},
	{"HARDWICK", 8, 76827},
	{"FLASKS", 6, 76828},
	{"IMMUNOLOGICAL", 13, 76829},
	{"WIFES", 5, 76830},
	{"PHENYL", 6, 76831},
	{"UOUT", 4, 76832},
	{"TYFL", 4, 76833},
	{"RETM", 4, 76834},
	{"IMSM", 4, 76835},
	{"TELEFAX", 7, 76836},
	{"PPYH", 4, 76837},
	{"NDYU", 4, 76838},
	{"ALHY", 4, 76839},
	{"ACYH", 4, 76840},
	{"PRESERVATIVE", 12, 76841},
	{"FAMOUSLY", 8, 76842},
	{"HATTIESBURG", 11, 76843},
	{"TELEMATICS", 10, 76844},
	{"MAIER", 5, 76845},
	{"WWEW", 4, 76846},
	{"CHSY", 4, 76847},
	{"TRIBULATION", 11, 76848},
	{"BOSSIER", 7, 76849},
	{"FRANCHISEES", 11, 76850},
	{"FALCO", 5, 76851},
	{"PEPR", 4, 76852},
	{"KSAP", 4, 76853},
	{"FTSU", 4, 76854},
	{"EXWH", 4, 76855},
	{"BRIDESMAIDS", 11, 76856},
	{"ARMIN", 5, 76857},
	{"RAIDED", 6, 76858},
	{"IQUE", 4, 76859},
	{"CONTROLLABLE", 12, 76860},
	{"RASG", 4, 76861},
	{"PMFO", 4, 76862},
	{"GLYU", 4, 76863},
	{"SURFACTANT", 10, 76864},
	{"TELECOMMUTING", 13, 76865},
	{"CULVERT", 7, 76866},
	{"OYDO", 4, 76867},
	{"EKRO", 4, 76868},
	{"PRESCRIPTIVE", 12, 76869},
	{"WCAG", 4, 76870},
	{"FFEI", 4, 76871},
	{"DIFN", 4, 76872},
	{"SALARIED", 8, 76873},
	{"IUML", 4, 76874},
	{"HYAL", 4, 76875},
	{"GVEN", 4, 76876},
	{"SPANNER", 7, 76877},
	{"MCHUGH", 6, 76878},
	{"EUOF", 4, 76879},
	{"MISES", 5, 76880},
	{"FIREHOUSE", 9, 76881},
	{"INTOLERANT", 10, 76882},
	{"RARITIES", 8, 76883},
	{"CURRYS", 6, 76884},
	{"RPES", 4, 76885},
	{"NDRB", 4, 76886},
	{"LPON", 4, 76887},
	{"DIADORA", 7, 76888},
	{"LAPORTE", 7, 76889},
	{"WGBH", 4, 76890},
	{"TELEKOM", 7, 76891},
	{"PURI", 4, 76892},
	{"ZAKA", 4, 76893},
	{"RYBC", 4, 76894},
	{"RPTI", 4, 76895},
	{"FACTSHEETS", 10, 76896},
	{"BATTLED", 7, 76897},
	{"KARTS", 5, 76898},
	{"ORTHODONTIC", 11, 76899},
	{"VISORS", 6, 76900},
	{"OBSTRUCTIONS", 12, 76901},
	{"LESTE", 5, 76902},
	{"LITHOGRAPHY", 11, 76903},
	{"BONOBO", 6, 76904},
	{"VIAW", 4, 76905},
	{"RYSR", 4, 76906},
	{"BYFU", 4, 76907},
	{"HAMPTONS", 8, 76908},
	{"PROOFREADING", 12, 76909},
	{"RMX", 3, 76910},
	{"YASR", 4, 76911},
	{"OPSL", 4, 76912},
	{"MFAL", 4, 76913},
	{"FLDR", 4, 76914},
	{"DISCREDIT", 9, 76915},
	{"EVOKES", 6, 76916},
	{"KJAC", 4, 76917},
	{"DMEH", 4, 76918},
	{"JDM", 3, 76919},
	{"GROTESQUE", 9, 76920},
	{"ARTISTES", 8, 76921},
	{"MSAG", 4, 76922},
	{"DEHYDRATED", 10, 76923},
	{"WHYTE", 5, 76924},
	{"INTEROP", 7, 76925},
	{"INITIALIZING", 12, 76926},
	{"ELIR", 4, 76927},
	{"ADKN", 4, 76928},
	{"PERUGIA", 7, 76929},
	{"MANFROTTO", 9, 76930},
	{"WAVEGUIDE", 9, 76931},
	{"GHOC", 4, 76932},
	{"AUSSIES", 7, 76933},
	{"MURTHA", 6, 76934},
	{"REINHARD", 8, 76935},
	{"PERMACULTURE", 12, 76936},
	{"SPOILS", 6, 76937},
	{"LWJ", 3, 76938},
	{"GKK", 3, 76939},
	{"SUBURBIA", 8, 76940},
	{"KAMAL", 5, 76941},
	{"CATWOMAN", 8, 76942},
	{"OPTIMALLY", 9, 76943},
	{"DARKO", 5, 76944},
	{"MONASTERIES", 11, 76945},
	{"WINDSTAR", 8, 76946},
	{"URFL", 4, 76947},
	{"UCLI", 4, 76948},
	{"TWEP", 4, 76949},
	{"MUMT", 4, 76950},
	{"HSUM", 4, 76951},
	{"FFPE", 4, 76952},
	{"DRYC", 4, 76953},
	{"CRUCIBLE", 8, 76954},
	{"MODENA", 6, 76955},
	{"GENERALIZE", 10, 76956},
	{"POLYMORPHISMS", 13, 76957},
	{"MDM", 3, 76958},
	{"LYSB", 4, 76959},
	{"EMBRYOLOGY", 10, 76960},
	{"STYRENE", 7, 76961},
	{"PRONOUNS", 8, 76962},
	{"ALUMNAE", 7, 76963},
	{"INDUCIBLE", 9, 76964},
	{"RETP", 4, 76965},
	{"NRYC", 4, 76966},
	{"HJUL", 4, 76967},
	{"FAHU", 4, 76968},
	{"DOAG", 4, 76969},
	{"MISCONCEPTION", 13, 76970},
	{"RUDIMENTARY", 11, 76971},
	{"RIESLING", 8, 76972},
	{"TRIAGE", 6, 76973},
	{"FAFG", 4, 76974},
	{"PROTEGE", 7, 76975},
	{"VULGARIS", 8, 76976},
	{"BEAK", 4, 76977},
	{"SETTLER", 7, 76978},
	{"PEAB", 4, 76979},
	{"OPDI", 4, 76980},
	{"KRUGMAN", 7, 76981},
	{"PRAG", 4, 76982},
	{"MAZATLAN", 8, 76983},
	{"SILENCER", 8, 76984},
	{"RABBLE", 6, 76985},
	{"RUNG", 4, 76986},
	{"FORECLOSED", 10, 76987},
	{"CHERNOBYL", 9, 76988},
	{"RIGBY", 5, 76989},
	{"ALLERGEN", 8, 76990},
	{"OFOW", 4, 76991},
	{"LSKE", 4, 76992},
	{"PIPED", 5, 76993},
	{"FHAW", 4, 76994},
	{"EWPH", 4, 76995},
	{"ORPHEUS", 7, 76996},
	{"RETOUR", 6, 76997},
	{"INSURGENT", 9, 76998},
	{"CRYSTALLOGRAPHY", 15, 76999},
	{"FROSTING", 8, 77000},
	{"RIGHTFULLY", 10, 77001},
	{"HILFE", 5, 77002},
	{"GALLBLADDER", 11, 77003},
	{"PHOTOGALLERY", 12, 77004},
	{"NIGHTWEAR", 9, 77005},
	{"SCONCE", 6, 77006},
	{"MEDICI", 6, 77007},
	{"FABRICE", 7, 77008},
	{"MARSHALS", 8, 77009},
	{"MTOJ", 4, 77010},
	{"VGC", 3, 77011},
	{"DRIVETRAIN", 10, 77012},
	{"SKELTON", 7, 77013},
	{"OVARIES", 7, 77014},
	{"DKIR", 4, 77015},
	{"AYFL", 4, 77016},
	{"MAMOB", 5, 77017},
	{"PHENTERMINECHEAP", 16, 77018},
	{"AMOP", 4, 77019},
	{"DADDIES", 7, 77020},
	{"CRUMBLING", 9, 77021},
	{"IMPRESSIONIST", 13, 77022},
	{"LYZI", 4, 77023},
	{"RELEGATED", 9, 77024},
	{"TOURISME", 8, 77025},
	{"ALLOTMENTS", 10, 77026},
	{"IMMER", 5, 77027},
	{"STAGNANT", 8, 77028},
	{"GIACOMO", 7, 77029},
	{"LAAL", 4, 77030},
	{"CLIF", 4, 77031},
	{"FOLLIES", 7, 77032},
	{"TLEJ", 4, 77033},
	{"FAIRWAYS", 8, 77034},
	{"WATERCOLORS", 11, 77035},
	{"KLIPSCH", 7, 77036},
	{"UECL", 4, 77037},
	{"LMCA", 4, 77038},
	{"HREB", 4, 77039},
	{"CLYA", 4, 77040},
	{"DELLS", 5, 77041},
	{"HEGP", 4, 77042},
	{"TEKKEN", 6, 77043},
	{"LACTIC", 6, 77044},
	{"CLEANLY", 7, 77045},
	{"UNCLEAN", 7, 77046},
	{"SEIZING", 7, 77047},
	{"MOLASSES", 8, 77048},
	{"BYDD", 4, 77049},
	{"KATANA", 6, 77050},
	{"TABLECLOTH", 10, 77051},
	{"AMERIQUEST", 10, 77052},
	{"BOSON", 5, 77053},
	{"CULO", 4, 77054},
	{"MILLED", 6, 77055},
	{"RWIF", 4, 77056},
	{"MAYV", 4, 77057},
	{"OUOF", 4, 77058},
	{"OKBO", 4, 77059},
	{"GDUT", 4, 77060},
	{"MCARTHUR", 8, 77061},
	{"HUTCHINS", 8, 77062},
	{"PURIFYING", 9, 77063},
	{"DELINEATION", 11, 77064},
	{"SCHOONER", 8, 77065},
	{"RLWA", 4, 77066},
	{"IAMV", 4, 77067},
	{"ANALGESIC", 9, 77068},
	{"DIGNIFIED", 9, 77069},
	{"NUMBNESS", 8, 77070},
	{"ZESW", 4, 77071},
	{"RPIS", 4, 77072},
	{"MIFT", 4, 77073},
	{"HCUS", 4, 77074},
	{"BTEC", 4, 77075},
	{"GEEZ", 4, 77076},
	{"WDIF", 4, 77077},
	{"PEKA", 4, 77078},
	{"MNAM", 4, 77079},
	{"PAPIER", 6, 77080},
	{"CROCHETED", 9, 77081},
	{"MACHINIST", 9, 77082},
	{"YKER", 4, 77083},
	{"ANIMA", 5, 77084},
	{"ACETYLCHOLINE", 13, 77085},
	{"MODBLOGS", 8, 77086},
	{"YSRU", 4, 77087},
	{"LORU", 4, 77088},
	{"EYFU", 4, 77089},
	{"APOLOGIZED", 10, 77090},
	{"MESHES", 6, 77091},
	{"PUD", 3, 77092},
	{"FIRSTS", 6, 77093},
	{"FERRETS", 7, 77094},
	{"HCOC", 4, 77095},
	{"ENLIGHT", 7, 77096},
	{"GROTTO", 6, 77097},
	{"MENZIES", 7, 77098},
	{"AGONISTS", 8, 77099},
	{"MARAIS", 6, 77100},
	{"EISNER", 6, 77101},
	{"RYMC", 4, 77102},
	{"CALQ", 4, 77103},
	{"STAROFFICE", 10, 77104},
	{"LOAM", 4, 77105},
	{"RERH", 4, 77106},
	{"NNUR", 4, 77107},
	{"POLITIQUE", 9, 77108},
	{"UBBY", 4, 77109},
	{"PHOTOMETRIC", 11, 77110},
	{"FOKUS", 5, 77111},
	{"FZD", 3, 77112},
	{"FOXT", 4, 77113},
	{"CARNATIONS", 10, 77114},
	{"BUZZER", 6, 77115},
	{"RIVETS", 6, 77116},
	{"JEUNE", 5, 77117},
	{"HATCHING", 8, 77118},
	{"LEVELED", 7, 77119},
	{"XTPR", 4, 77120},
	{"GRACES", 6, 77121},
	{"TRAMS", 5, 77122},
	{"VICKIE", 6, 77123},
	{"TINNITUS", 8, 77124},
	{"CORINNE", 7, 77125},
	{"VECTRA", 6, 77126},
	{"ILKS", 4, 77127},
	{"ADHERES", 7, 77128},
	{"BENIDORM", 8, 77129},
	{"KSIF", 4, 77130},
	{"GERRARD", 7, 77131},
	{"COLLUSION", 9, 77132},
	{"AOFL", 4, 77133},
	{"MARKETWORKS", 11, 77134},
	{"LIBERTARIANS", 12, 77135},
	{"RAWHIDE", 7, 77136},
	{"DOWNERS", 7, 77137},
	{"KEVLAR", 6, 77138},
	{"RRAW", 4, 77139},
	{"MDEB", 4, 77140},
	{"PROPOS", 6, 77141},
	{"SEQUESTRATION", 13, 77142},
	{"YOSHIDA", 7, 77143},
	{"WMAY", 4, 77144},
	{"SELU", 4, 77145},
	{"LLUD", 4, 77146},
	{"INOSITOL", 8, 77147},
	{"PRAIA", 5, 77148},
	{"FOLLICLE", 8, 77149},
	{"UYSS", 4, 77150},
	{"ORHY", 4, 77151},
	{"KNOTTED", 7, 77152},
	{"ITEMSSHOW", 9, 77153},
	{"BRUNNER", 7, 77154},
	{"AGITATED", 8, 77155},
	{"INDORE", 6, 77156},
	{"INSPECTORATE", 12, 77157},
	{"UEZA", 4, 77158},
	{"ORNR", 4, 77159},
	{"OFTL", 4, 77160},
	{"NUPR", 4, 77161},
	{"GWEC", 4, 77162},
	{"SORTER", 6, 77163},
	{"ULTRALIGHT", 10, 77164},
	{"TOUTPUTIMAGE", 12, 77165},
	{"MISUSED", 7, 77166},
	{"GEIF", 4, 77167},
	{"SAUDIS", 6, 77168},
	{"OCTAL", 5, 77169},
	{"RELIEVES", 8, 77170},
	{"DEBILITATING", 12, 77171},
	{"LINGUIST", 8, 77172},
	{"KEYPRESS", 8, 77173},
	{"NOTIFYALL", 9, 77174},
	{"RIGOROUSLY", 10, 77175},
	{"ERRONEOUSLY", 11, 77176},
	{"CORRS", 5, 77177},
	{"TURKU", 5, 77178},
	{"CENTRIFUGE", 10, 77179},
	{"FCOC", 4, 77180},
	{"EUMT", 4, 77181},
	{"ERGN", 4, 77182},
	{"AFAK", 4, 77183},
	{"ESPECIAL", 8, 77184},
	{"BETRAY", 6, 77185},
	{"DARIO", 5, 77186},
	{"CURATORS", 8, 77187},
	{"MULTIPOINT", 10, 77188},
	{"GJAC", 4, 77189},
	{"QUANG", 5, 77190},
	{"UYAS", 4, 77191},
	{"UCTD", 4, 77192},
	{"MARLA", 5, 77193},
	{"HEYWOOD", 7, 77194},
	{"SUSPENDING", 10, 77195},
	{"NMYA", 4, 77196},
	{"LTID", 4, 77197},
	{"DCOT", 4, 77198},
	{"MORMONS", 7, 77199},
	{"CAFFE", 5, 77200},
	{"DAVIDS", 6, 77201},
	{"PROJECTIVE", 10, 77202},
	{"FANDOM", 6, 77203},
	{"IRKA", 4, 77204},
	{"GUYH", 4, 77205},
	{"SZER", 4, 77206},
	{"LWEH", 4, 77207},
	{"KEJU", 4, 77208},
	{"GIUL", 4, 77209},
	{"DEBACLE", 7, 77210},
	{"ARGH", 4, 77211},
	{"BENNET", 6, 77212},
	{"PLANTINGS", 9, 77213},
	{"LANDMINES", 9, 77214},
	{"PPYB", 4, 77215},
	{"NBAF", 4, 77216},
	{"KRIV", 4, 77217},
	{"FTSF", 4, 77218},
	{"FSWA", 4, 77219},
	{"DMYH", 4, 77220},
	{"PROCLAIMING", 11, 77221},
	{"KHALED", 6, 77222},
	{"ULSP", 4, 77223},
	{"KIMMEL", 6, 77224},
	{"PURPOSEFUL", 10, 77225},
	{"FAMC", 4, 77226},
	{"LBEJ", 4, 77227},
	{"UNDRESS", 7, 77228},
	{"ARBITRATORS", 11, 77229},
	{"DEAKIN", 6, 77230},
	{"INSTOCK", 7, 77231},
	{"UBTF", 4, 77232},
	{"LFUT", 4, 77233},
	{"PROCRASTINATION", 15, 77234},
	{"GILLIGAN", 8, 77235},
	{"HEMEL", 5, 77236},
	{"GAUZE", 5, 77237},
	{"UDST", 4, 77238},
	{"SAYR", 4, 77239},
	{"RUPI", 4, 77240},
	{"UNPOSSIBLE", 10, 77241},
	{"WALDRON", 7, 77242},
	{"KIHEI", 5, 77243},
	{"PRECEPTS", 8, 77244},
	{"RGNE", 4, 77245},
	{"IRAW", 4, 77246},
	{"HALU", 4, 77247},
	{"BRONCHIAL", 9, 77248},
	{"CONSTELLATIONS", 14, 77249},
	{"IRSB", 4, 77250},
	{"GAZED", 5, 77251},
	{"NANOSCALE", 9, 77252},
	{"SKIPS", 5, 77253},
	{"KISU", 4, 77254},
	{"EMEY", 4, 77255},
	{"AYKI", 4, 77256},
	{"HMONG", 5, 77257},
	{"BROWNFIELDS", 11, 77258},
	{"EMMYLOU", 7, 77259},
	{"ANTCN", 5, 77260},
	{"FORCEFUL", 8, 77261},
	{"UNILATERALLY", 12, 77262},
	{"HEVU", 4, 77263},
	{"HYPOGLYCEMIA", 12, 77264},
	{"BUKAKKE", 7, 77265},
	{"BIGPOND", 7, 77266},
	{"FUENTE", 6, 77267},
	{"OXWI", 4, 77268},
	{"MAGDALENA", 9, 77269},
	{"FAMOSAS", 7, 77270},
	{"NSYNC", 5, 77271},
	{"EBTC", 4, 77272},
	{"OGUY", 4, 77273},
	{"REVALUATION", 11, 77274},
	{"CONDITIONALLY", 13, 77275},
	{"MOIRA", 5, 77276},
	{"TENURED", 7, 77277},
	{"OFKH", 4, 77278},
	{"PADD", 4, 77279},
	{"AMATO", 5, 77280},
	{"DEBENTURES", 10, 77281},
	{"TIGM", 4, 77282},
	{"EBYU", 4, 77283},
	{"RFCS", 4, 77284},
	{"ACYL", 4, 77285},
	{"REHOBOTH", 8, 77286},
	{"YBYF", 4, 77287},
	{"HWID", 4, 77288},
	{"DVED", 4, 77289},
	{"CAFT", 4, 77290},
	{"LMC", 3, 77291},
	{"SUBTERRANEAN", 12, 77292},
	{"DRUCKER", 7, 77293},
	{"RUMORED", 7, 77294},
	{"UYZ", 3, 77295},
	{"UJM", 3, 77296},
	{"GALICIA", 7, 77297},
	{"CIGNA", 5, 77298},
	{"DLR", 3, 77299},
	{"NIFL", 4, 77300},
	{"AMUSE", 5, 77301},
	{"RNJA", 4, 77302},
	{"VILLAGER", 8, 77303},
	{"FIXER", 5, 77304},
	{"SEALY", 5, 77305},
	{"CONDENSING", 10, 77306},
	{"USPH", 4, 77307},
	{"GIDO", 4, 77308},
	{"CARREY", 6, 77309},
	{"EMANATING", 9, 77310},
	{"EVESHAM", 7, 77311},
	{"ASSASSINATED", 12, 77312},
	{"OWOL", 4, 77313},
	{"OUCL", 4, 77314},
	{"ORRH", 4, 77315},
	{"MCNEILL", 7, 77316},
	{"MANITOWOC", 9, 77317},
	{"BRODIE", 6, 77318},
	{"UNTIMELY", 8, 77319},
	{"RICV", 4, 77320},
	{"DOPR", 4, 77321},
	{"AIMW", 4, 77322},
	{"BAGUETTE", 8, 77323},
	{"HAVES", 5, 77324},
	{"ERECTIONS", 9, 77325},
	{"ASSOCIATING", 11, 77326},
	{"ROMP", 4, 77327},
	{"NYVE", 4, 77328},
	{"OVERPRICED", 10, 77329},
	{"GRANTOR", 7, 77330},
	{"ORBITING", 8, 77331},
	{"SOARES", 6, 77332},
	{"UGTR", 4, 77333},
	{"CERG", 4, 77334},
	{"IDIOM", 5, 77335},
	{"TANGLE", 6, 77336},
	{"LEGITIMATELY", 12, 77337},
	{"RESUBMIT", 8, 77338},
	{"BADER", 5, 77339},
	{"USTJ", 4, 77340},
	{"ULIF", 4, 77341},
	{"GYMBOREE", 8, 77342},
	{"CONGRATULATED", 13, 77343},
	{"YUNNAN", 6, 77344},
	{"COURIERS", 8, 77345},
	{"ODOD", 4, 77346},
	{"KACR", 4, 77347},
	{"ADOD", 4, 77348},
	{"MIYAKE", 6, 77349},
	{"SAGGY", 5, 77350},
	{"UNWELCOME", 9, 77351},
	{"KSCL", 4, 77352},
	{"IYAM", 4, 77353},
	{"FEPR", 4, 77354},
	{"SUBTYPES", 8, 77355},
	{"MOULTRIE", 8, 77356},
	{"CONCURRED", 9, 77357},
	{"VASQUEZ", 7, 77358},
	{"CORU", 4, 77359},
	{"IOGEAR", 6, 77360},
	{"MERCH", 5, 77361},
	{"UPLINKED", 8, 77362},
	{"COGNOS", 6, 77363},
	{"UPSETS", 6, 77364},
	{"NORTHBOUND", 10, 77365},
	{"SCEPTRE", 7, 77366},
	{"CARDIGANS", 9, 77367},
	{"CONFEDERACY", 11, 77368},
	{"TAGLINES", 8, 77369},
	{"USERNAMES", 9, 77370},
	{"OKPO", 4, 77371},
	{"LLEJ", 4, 77372},
	{"MATINEE", 7, 77373},
	{"GPSMAP", 6, 77374},
	{"PLUNDER", 7, 77375},
	{"YJER", 4, 77376},
	{"YAPL", 4, 77377},
	{"UPYI", 4, 77378},
	{"ODQU", 4, 77379},
	{"GYON", 4, 77380},
	{"MIDWEEK", 7, 77381},
	{"IMPROMPTU", 9, 77382},
	{"PIRELLI", 7, 77383},
	{"RIALTO", 6, 77384},
	{"DURATIONS", 9, 77385},
	{"BUSTLE", 6, 77386},
	{"TRAWL", 5, 77387},
	{"YIRR", 4, 77388},
	{"FAYO", 4, 77389},
	{"SHREDDING", 9, 77390},
	{"REINER", 6, 77391},
	{"LIAP", 4, 77392},
	{"APEG", 4, 77393},
	{"RISERS", 6, 77394},
	{"SEARCHERS", 9, 77395},
	{"TAEKWONDO", 9, 77396},
	{"EBXML", 5, 77397},
	{"GAMUT", 5, 77398},
	{"CZAR", 4, 77399},
	{"UNEDITED", 8, 77400},
	{"PUTNEY", 6, 77401},
	{"SHATTERING", 10, 77402},
	{"INHALER", 7, 77403},
	{"AGUL", 4, 77404},
	{"REFUTE", 6, 77405},
	{"GRANULARITY", 11, 77406},
	{"ALBATROSS", 9, 77407},
	{"RAWW", 4, 77408},
	{"OLOD", 4, 77409},
	{"NSWR", 4, 77410},
	{"HGUY", 4, 77411},
	{"FFSS", 4, 77412},
	{"FORMALIZED", 10, 77413},
	{"RETRAINING", 10, 77414},
	{"NERVOSA", 7, 77415},
	{"ICAV", 4, 77416},
	{"GAQU", 4, 77417},
	{"BYSL", 4, 77418},
	{"IPBY", 4, 77419},
	{"HCRU", 4, 77420},
	{"FASW", 4, 77421},
	{"CATV", 4, 77422},
	{"CERTIFICATED", 12, 77423},
	{"AMPHIBIOUS", 10, 77424},
	{"SPICER", 6, 77425},
	{"MUSH", 4, 77426},
	{"UTIK", 4, 77427},
	{"SHUDDER", 7, 77428},
	{"KARSTEN", 7, 77429},
	{"SURFBOARD", 9, 77430},
	{"EYESIGHT", 8, 77431},
	{"FTAF", 4, 77432},
	{"PARSON", 6, 77433},
	{"INFIDELITY", 10, 77434},
	{"GARFUNKEL", 9, 77435},
	{"FIREMEN", 7, 77436},
	{"SKRE", 4, 77437},
	{"RITP", 4, 77438},
	{"HBLU", 4, 77439},
	{"HANDGUNS", 8, 77440},
	{"IDEOGRAPH", 9, 77441},
	{"CONTRIVED", 9, 77442},
	{"CGEE", 4, 77443},
	{"PAPILLON", 8, 77444},
	{"EXHAUSTS", 8, 77445},
	{"OPPOSITES", 9, 77446},
	{"DREAMERS", 8, 77447},
	{"CITYWIDE", 8, 77448},
	{"YANP", 4, 77449},
	{"GDAR", 4, 77450},
	{"CKEF", 4, 77451},
	{"STINGRAY", 8, 77452},
	{"TOSCANA", 7, 77453},
	{"LARSSON", 7, 77454},
	{"FRANCHISEE", 10, 77455},
	{"PUENTE", 6, 77456},
	{"TYGI", 4, 77457},
	{"SPUM", 4, 77458},
	{"REWN", 4, 77459},
	{"EECU", 4, 77460},
	{"TWIKIUSERS", 10, 77461},
	{"TUSTIN", 6, 77462},
	{"PHYSIK", 6, 77463},
	{"LREE", 4, 77464},
	{"KSBR", 4, 77465},
	{"CGOL", 4, 77466},
	{"FOAL", 4, 77467},
	{"SAVUTE", 6, 77468},
	{"HUSD", 4, 77469},
	{"SLINKY", 6, 77470},
	{"HESITATED", 9, 77471},
	{"CUBASE", 6, 77472},
	{"PWHA", 4, 77473},
	{"CKBI", 4, 77474},
	{"WEATHERPROOF", 12, 77475},
	{"PARKPLATZ", 9, 77476},
	{"ROADSIDETHOUGHTS", 16, 77477},
	{"PRECARIOUS", 10, 77478},
	{"HODDER", 6, 77479},
	{"PEASE", 5, 77480},
	{"MROL", 4, 77481},
	{"CKKI", 4, 77482},
	{"TESTIFYING", 10, 77483},
	{"PTHREAD", 7, 77484},
	{"POSTMENOPAUSAL", 14, 77485},
	{"TOPOGRAPHICAL", 13, 77486},
	{"ULHO", 4, 77487},
	{"UGEW", 4, 77488},
	{"OYDA", 4, 77489},
	{"EMRI", 4, 77490},
	{"DYPE", 4, 77491},
	{"CKLU", 4, 77492},
	{"MIXTAPE", 7, 77493},
	{"INSTRUCTING", 11, 77494},
	{"DREARY", 6, 77495},
	{"WSUC", 4, 77496},
	{"GBES", 4, 77497},
	{"TUXEDOS", 7, 77498},
	{"YYD", 3, 77499},
	{"KZB", 3, 77500},
	{"KRJ", 3, 77501},
	{"FUJIAN", 6, 77502},
	{"BATTERS", 7, 77503},
	{"GOGO", 4, 77504},
	{"QUAC", 4, 77505},
	{"IFTR", 4, 77506},
	{"MINIVANS", 8, 77507},
	{"CRISPIN", 7, 77508},
	{"YORJ", 4, 77509},
	{"YKAR", 4, 77510},
	{"UMVE", 4, 77511},
	{"RMYL", 4, 77512},
	{"LMRE", 4, 77513},
	{"LEMD", 4, 77514},
	{"YEREVAN", 7, 77515},
	{"DUFFLE", 6, 77516},
	{"HORRID", 6, 77517},
	{"HVIR", 4, 77518},
	{"FPOU", 4, 77519},
	{"DOMP", 4, 77520},
	{"POSNER", 6, 77521},
	{"DRYNESS", 7, 77522},
	{"BWV", 3, 77523},
	{"CKYD", 4, 77524},
	{"HGRI", 4, 77525},
	{"GNFI", 4, 77526},
	{"ALDB", 4, 77527},
	{"WRECKAGE", 8, 77528},
	{"TECHNET", 7, 77529},
	{"SDSU", 4, 77530},
	{"DECL", 4, 77531},
	{"PARAS", 5, 77532},
	{"LOMBARDI", 8, 77533},
	{"MUSI", 4, 77534},
	{"IECR", 4, 77535},
	{"UNGER", 5, 77536},
	{"GOPHERS", 7, 77537},
	{"BRANDO", 6, 77538},
	{"MULTIFUNCTIONAL", 15, 77539},
	{"RELIST", 6, 77540},
	{"WEBJAY", 6, 77541},
	{"HICR", 4, 77542},
	{"HAWORTH", 7, 77543},
	{"TRANSFECTED", 11, 77544},
	{"DOCKERS", 7, 77545},
	{"CAPTIVES", 8, 77546},
	{"SCREWDRIVERS", 12, 77547},
	{"DESPISED", 8, 77548},
	{"GUITARISTS", 10, 77549},
	{"CONQUEROR", 9, 77550},
	{"GDAM", 4, 77551},
	{"GCOD", 4, 77552},
	{"INNOCENTS", 9, 77553},
	{"MANTA", 5, 77554},
	{"CHRISTA", 7, 77555},
	{"UNPREPARED", 10, 77556},
	{"MOFFAT", 6, 77557},
	{"RDEI", 4, 77558},
	{"ABYR", 4, 77559},
	{"BOYB", 4, 77560},
	{"SURFBOARDS", 10, 77561},
	{"DETERIORATE", 11, 77562},
	{"COMPO", 5, 77563},
	{"TREACHEROUS", 11, 77564},
	{"FILET", 5, 77565},
	{"FVIL", 4, 77566},
	{"INFIDEL", 7, 77567},
	{"VOLLEY", 6, 77568},
	{"CARNAL", 6, 77569},
	{"PATW", 4, 77570},
	{"OQUO", 4, 77571},
	{"LARCENY", 7, 77572},
	{"CAULFIELD", 9, 77573},
	{"IVIR", 4, 77574},
	{"HOGU", 4, 77575},
	{"MIDPOINT", 8, 77576},
	{"ORLAND", 6, 77577},
	{"MALAGASY", 8, 77578},
	{"NURG", 4, 77579},
	{"DICC", 4, 77580},
	{"CFEE", 4, 77581},
	{"VERSED", 6, 77582},
	{"SHOPLOCAL", 9, 77583},
	{"STANDARDISATION", 15, 77584},
	{"FDER", 4, 77585},
	{"EUCL", 4, 77586},
	{"MATLOCK", 7, 77587},
	{"CONFRONTS", 9, 77588},
	{"POLYMORPHIC", 11, 77589},
	{"PHENOMENOLOGY", 13, 77590},
	{"SUBSTANTIATED", 13, 77591},
	{"YFES", 4, 77592},
	{"UEFE", 4, 77593},
	{"PHONG", 5, 77594},
	{"BANDERA", 7, 77595},
	{"CRED", 4, 77596},
	{"LORRY", 5, 77597},
	{"RECAPS", 6, 77598},
	{"PARLIAMENTS", 11, 77599},
	{"NCYN", 4, 77600},
	{"HEGM", 4, 77601},
	{"ECDP", 4, 77602},
	{"MITIGATED", 9, 77603},
	{"UERY", 4, 77604},
	{"LMSP", 4, 77605},
	{"BLIO", 4, 77606},
	{"ASKU", 4, 77607},
	{"RESOLVER", 8, 77608},
	{"KAGAN", 5, 77609},
	{"CHIU", 4, 77610},
	{"ENIGMATIC", 9, 77611},
	{"ANTHROPOLOGIST", 14, 77612},
	{"OPCODE", 6, 77613},
	{"LMUL", 4, 77614},
	{"GICR", 4, 77615},
	{"FVID", 4, 77616},
	{"EMYG", 4, 77617},
	{"JUGG", 4, 77618},
	{"BRIDLE", 6, 77619},
	{"RHAW", 4, 77620},
	{"ICWR", 4, 77621},
	{"BUSB", 4, 77622},
	{"REVAMP", 6, 77623},
	{"HERBARIUM", 9, 77624},
	{"ODCE", 4, 77625},
	{"KGOV", 4, 77626},
	{"STRETCHER", 9, 77627},
	{"GRB", 3, 77628},
	{"READONLY", 8, 77629},
	{"YGIL", 4, 77630},
	{"ARISTA", 6, 77631},
	{"BARCELO", 7, 77632},
	{"PHYH", 4, 77633},
	{"LDMY", 4, 77634},
	{"KFIL", 4, 77635},
	{"UNKNOWNS", 8, 77636},
	{"ENFANTS", 7, 77637},
	{"LEILA", 5, 77638},
	{"OKFR", 4, 77639},
	{"BROSNAN", 7, 77640},
	{"ULBS", 4, 77641},
	{"PSYS", 4, 77642},
	{"NYNU", 4, 77643},
	{"GUNR", 4, 77644},
	{"BERLINER", 8, 77645},
	{"CHAMOMILE", 9, 77646},
	{"WHED", 4, 77647},
	{"MOBILIZING", 10, 77648},
	{"KSUR", 4, 77649},
	{"KFRI", 4, 77650},
	{"ALLO", 4, 77651},
	{"GEDDES", 6, 77652},
	{"YSGI", 4, 77653},
	{"WAYLAND", 7, 77654},
	{"CERRO", 5, 77655},
	{"METHYLATION", 11, 77656},
	{"EFFECTING", 9, 77657},
	{"WBEA", 4, 77658},
	{"ECOL", 4, 77659},
	{"LDOO", 4, 77660},
	{"KUPF", 4, 77661},
	{"KKEN", 4, 77662},
	{"EYAB", 4, 77663},
	{"ECHM", 4, 77664},
	{"HALLUCINATIONS", 14, 77665},
	{"UNRAVEL", 7, 77666},
	{"CLANLIB", 7, 77667},
	{"JAYSON", 6, 77668},
	{"PROSTATIC", 9, 77669},
	{"DBEK", 4, 77670},
	{"SMUGGLERS", 9, 77671},
	{"INTIMIDATE", 10, 77672},
	{"METCALFE", 8, 77673},
	{"RNGR", 4, 77674},
	{"RUBENS", 6, 77675},
	{"OPPENHEIMER", 11, 77676},
	{"MCCLINTOCK", 10, 77677},
	{"ANDROID", 7, 77678},
	{"GALILEE", 7, 77679},
	{"PRIMARIES", 9, 77680},
	{"FRENCHMAN", 9, 77681},
	{"CONVERGES", 9, 77682},
	{"LATION", 6, 77683},
	{"PTAR", 4, 77684},
	{"NOXV", 4, 77685},
	{"NFEM", 4, 77686},
	{"MRSM", 4, 77687},
	{"ANISOTROPIC", 11, 77688},
	{"FQC", 3, 77689},
	{"UDRA", 4, 77690},
	{"RNFA", 4, 77691},
	{"VOORRAAD", 8, 77692},
	{"UCR", 3, 77693},
	{"TILLER", 6, 77694},
	{"AMBROSIA", 8, 77695},
	{"TSUL", 4, 77696},
	{"RMYN", 4, 77697},
	{"RMME", 4, 77698},
	{"LDOL", 4, 77699},
	{"IEMC", 4, 77700},
	{"HLYU", 4, 77701},
	{"SPRINGBOARD", 11, 77702},
	{"ORIFICE", 7, 77703},
	{"RUBELLA", 7, 77704},
	{"EISENBERG", 9, 77705},
	{"ZERE", 4, 77706},
	{"MLEY", 4, 77707},
	{"LYLU", 4, 77708},
	{"CONSTITUTIVE", 12, 77709},
	{"BRAGGING", 8, 77710},
	{"SIGNOFF", 7, 77711},
	{"HORDES", 6, 77712},
	{"TMEW", 4, 77713},
	{"GUGGENHEIM", 10, 77714},
	{"SAPPHIC", 7, 77715},
	{"KILLINGTON", 10, 77716},
	{"INTEC", 5, 77717},
	{"RNGE", 4, 77718},
	{"GAJO", 4, 77719},
	{"INSTAWARES", 10, 77720},
	{"KEARNS", 6, 77721},
	{"SHOWCASED", 9, 77722},
	{"BERYL", 5, 77723},
	{"SUMMERFIELD", 11, 77724},
	{"UTJE", 4, 77725},
	{"HECF", 4, 77726},
	{"GAID", 4, 77727},
	{"COOPERATIVELY", 13, 77728},
	{"OSHAWA", 6, 77729},
	{"FERRE", 5, 77730},
	{"FORERUNNER", 10, 77731},
	{"GRINNING", 8, 77732},
	{"TARGA", 5, 77733},
	{"GBYC", 4, 77734},
	{"EKPR", 4, 77735},
	{"DYMI", 4, 77736},
	{"TRIPLETS", 8, 77737},
	{"BILLIONAIRE", 11, 77738},
	{"ODUE", 4, 77739},
	{"LEUCINE", 7, 77740},
	{"JOBLESS", 7, 77741},
	{"SLINGSHOT", 9, 77742},
	{"CUTOUT", 6, 77743},
	{"DISGRUNTLED", 11, 77744},
	{"SLASHED", 7, 77745},
	{"USKN", 4, 77746},
	{"COKER", 5, 77747},
	{"WATCHFUL", 8, 77748},
	{"SELINUX", 7, 77749},
	{"TEML", 4, 77750},
	{"CROSSLINKS", 10, 77751},
	{"RESURRECTED", 11, 77752},
	{"YANR", 4, 77753},
	{"PATM", 4, 77754},
	{"KAPR", 4, 77755},
	{"APPALLED", 8, 77756},
	{"SPAMALOT", 8, 77757},
	{"SILENCED", 8, 77758},
	{"RKYO", 4, 77759},
	{"LDEE", 4, 77760},
	{"VANITIES", 8, 77761},
	{"CRB", 3, 77762},
	{"MOVIEFONE", 9, 77763},
	{"BEECHER", 7, 77764},
	{"MPTU", 4, 77765},
	{"FDOZ", 4, 77766},
	{"EXCR", 4, 77767},
	{"EPPR", 4, 77768},
	{"ALKL", 4, 77769},
	{"GOOG", 4, 77770},
	{"EVAPORATED", 10, 77771},
	{"MDGS", 4, 77772},
	{"DEMOCRATIZATION", 15, 77773},
	{"AFFLICTION", 10, 77774},
	{"BIOSTATISTICS", 13, 77775},
	{"SAKAIPROJECT", 12, 77776},
	{"RAEM", 4, 77777},
	{"EKLI", 4, 77778},
	{"BPLA", 4, 77779},
	{"INTESTINES", 10, 77780},
	{"CILANTRO", 8, 77781},
	{"XILISOFT", 8, 77782},
	{"XELS", 4, 77783},
	{"PMAY", 4, 77784},
	{"DYRA", 4, 77785},
	{"TERRACOTTA", 10, 77786},
	{"GARVEY", 6, 77787},
	{"SAUTE", 5, 77788},
	{"HARFORD", 7, 77789},
	{"PCIE", 4, 77790},
	{"DARTFORD", 8, 77791},
	{"DICAPRIO", 8, 77792},
	{"SCHUYLER", 8, 77793},
	{"UCKR", 4, 77794},
	{"SGOB", 4, 77795},
	{"OCIV", 4, 77796},
	{"BOBD", 4, 77797},
	{"AGEK", 4, 77798},
	{"ROSSO", 5, 77799},
	{"IDYLLIC", 7, 77800},
	{"ONLINEBUY", 9, 77801},
	{"GILLIAM", 7, 77802},
	{"CERTIORARI", 10, 77803},
	{"ROZO", 4, 77804},
	{"SATCHEL", 7, 77805},
	{"WALKIN", 6, 77806},
	{"CONTRIBUTORY", 12, 77807},
	{"APPLESCRIPT", 11, 77808},
	{"PERUSE", 6, 77809},
	{"GIGGLES", 7, 77810},
	{"REVEL", 5, 77811},
	{"ALLEYS", 6, 77812},
	{"TPME", 4, 77813},
	{"CSDI", 4, 77814},
	{"BITP", 4, 77815},
	{"ATUK", 4, 77816},
	{"CRUCIFIXION", 11, 77817},
	{"SUTURE", 6, 77818},
	{"JACOBI", 6, 77819},
	{"FARK", 4, 77820},
	{"AUTOBLOG", 8, 77821},
	{"GLAXOSMITHKLINE", 15, 77822},
	{"HARW", 4, 77823},
	{"USKY", 4, 77824},
	{"DOSU", 4, 77825},
	{"XURI", 4, 77826},
	{"RUMF", 4, 77827},
	{"ACCOR", 5, 77828},
	{"HEARN", 5, 77829},
	{"BUFORD", 6, 77830},
	{"USPTO", 5, 77831},
	{"AXMA", 4, 77832},
	{"BALFOUR", 7, 77833},
	{"MADLY", 5, 77834},
	{"UEVI", 4, 77835},
	{"STILLER", 7, 77836},
	{"EXPERIMENTED", 12, 77837},
	{"OUOU", 4, 77838},
	{"DKOR", 4, 77839},
	{"CALIPERS", 8, 77840},
	{"PENALIZED", 9, 77841},
	{"PYRUVATE", 8, 77842},
	{"COMMING", 7, 77843},
	{"LOGGERS", 7, 77844},
	{"UPDU", 4, 77845},
	{"LIMW", 4, 77846},
	{"STEEPED", 7, 77847},
	{"KISSINGER", 9, 77848},
	{"RMC", 3, 77849},
	{"WHEW", 4, 77850},
	{"ORCHESTRATED", 12, 77851},
	{"YSHR", 4, 77852},
	{"RIMC", 4, 77853},
	{"PPIA", 4, 77854},
	{"FFBR", 4, 77855},
	{"GRIPE", 5, 77856},
	{"SUMMA", 5, 77857},
	{"EYELIDS", 7, 77858},
	{"YESF", 4, 77859},
	{"CONFORMATIONAL", 14, 77860},
	{"INMR", 4, 77861},
	{"CHOREOGRAPHER", 13, 77862},
	{"MCSA", 4, 77863},
	{"IMPRESSIONISM", 13, 77864},
	{"THEREUPON", 9, 77865},
	{"TAYF", 4, 77866},
	{"RSJE", 4, 77867},
	{"OFZA", 4, 77868},
	{"KIWH", 4, 77869},
	{"BUCKNELL", 8, 77870},
	{"ULFE", 4, 77871},
	{"OODQ", 4, 77872},
	{"FMEE", 4, 77873},
	{"ZLM", 3, 77874},
	{"XVB", 3, 77875},
	{"WUU", 3, 77876},
	{"UUY", 3, 77877},
	{"DKX", 3, 77878},
	{"BQP", 3, 77879},
	{"BBZ", 3, 77880},
	{"ARCHERS", 7, 77881},
	{"STEAMERS", 8, 77882},
	{"MARTINO", 7, 77883},
	{"BUBBLING", 8, 77884},
	{"FORBIDS", 7, 77885},
	{"CRANBROOK", 9, 77886},
	{"XTHG", 4, 77887},
	{"DISDAIN", 7, 77888},
	{"EXHAUSTING", 10, 77889},
	{"ABSURDITY", 9, 77890},
	{"MAGNIFIED", 9, 77891},
	{"SUBDOMAIN", 9, 77892},
	{"WREV", 4, 77893},
	{"UNAD", 4, 77894},
	{"MBOW", 4, 77895},
	{"ALABASTER", 9, 77896},
	{"REIGNING", 8, 77897},
	{"DEANE", 5, 77898},
	{"PRECIOS", 7, 77899},
	{"SIMCOE", 6, 77900},
	{"ABNORMALITY", 11, 77901},
	{"GEORGIE", 7, 77902},
	{"ZARA", 4, 77903},
	{"VARICOSE", 8, 77904},
	{"NEWTONIAN", 9, 77905},
	{"GENOVA", 6, 77906},
	{"YBYW", 4, 77907},
	{"ONCY", 4, 77908},
	{"LIBOR", 5, 77909},
	{"BRIBES", 6, 77910},
	{"INFOMATICS", 10, 77911},
	{"KIDNAP", 6, 77912},
	{"COERCIVE", 8, 77913},
	{"SYRE", 4, 77914},
	{"DADT", 4, 77915},
	{"AXOP", 4, 77916},
	{"ALTM", 4, 77917},
	{"ROMANTICISM", 11, 77918},
	{"HYANNIS", 7, 77919},
	{"YDUN", 4, 77920},
	{"NYRU", 4, 77921},
	{"NKME", 4, 77922},
	{"GOOV", 4, 77923},
	{"HOWLAND", 7, 77924},
	{"FEDERATIONS", 11, 77925},
	{"SYED", 4, 77926},
	{"FORME", 5, 77927},
	{"URINATION", 9, 77928},
	{"BEWERTUNG", 9, 77929},
	{"KSOV", 4, 77930},
	{"BROADCOM", 8, 77931},
	{"GGOD", 4, 77932},
	{"EEMY", 4, 77933},
	{"DLYU", 4, 77934},
	{"CAUTIONARY", 10, 77935},
	{"ESCALATE", 8, 77936},
	{"SPOTTERS", 8, 77937},
	{"XISM", 4, 77938},
	{"SLEM", 4, 77939},
	{"MMAB", 4, 77940},
	{"LJUL", 4, 77941},
	{"CITW", 4, 77942},
	{"KUCINICH", 8, 77943},
	{"SIDER", 5, 77944},
	{"REINSTATE", 9, 77945},
	{"MITRAL", 6, 77946},
	{"DAFA", 4, 77947},
	{"LDSG", 4, 77948},
	{"EPUZ", 4, 77949},
	{"VERDES", 6, 77950},
	{"INPROCEEDINGS", 13, 77951},
	{"CRESTWOOD", 9, 77952},
	{"UNTHINKABLE", 11, 77953},
	{"VANP", 4, 77954},
	{"LOWLY", 5, 77955},
	{"TAKINGITGLOBAL", 14, 77956},
	{"DMZ", 3, 77957},
	{"ANTISOCIAL", 10, 77958},
	{"XWHE", 4, 77959},
	{"ONMR", 4, 77960},
	{"GANGSTERS", 9, 77961},
	{"DAEMONS", 7, 77962},
	{"OUTBURST", 8, 77963},
	{"RDNI", 4, 77964},
	{"NGSJ", 4, 77965},
	{"KROS", 4, 77966},
	{"GETV", 4, 77967},
	{"AUMO", 4, 77968},
	{"FOUNDATIONAL", 12, 77969},
	{"SCANT", 5, 77970},
	{"PROBS", 5, 77971},
	{"MATTERED", 8, 77972},
	{"FITZROY", 7, 77973},
	{"DDLY", 4, 77974},
	{"ALKM", 4, 77975},
	{"HUNTLEY", 7, 77976},
	{"KANPUR", 6, 77977},
	{"RASPBERRIES", 11, 77978},
	{"UTEG", 4, 77979},
	{"RITL", 4, 77980},
	{"GITR", 4, 77981},
	{"SORELY", 6, 77982},
	{"ELVEN", 5, 77983},
	{"UPGO", 4, 77984},
	{"LFGO", 4, 77985},
	{"PAIL", 4, 77986},
	{"ISOTROPIC", 9, 77987},
	{"ADODB", 5, 77988},
	{"ENLACES", 7, 77989},
	{"SKYD", 4, 77990},
	{"ORMN", 4, 77991},
	{"EDELMAN", 7, 77992},
	{"OBTAINABLE", 10, 77993},
	{"RUBINSTEIN", 10, 77994},
	{"ELVIRA", 6, 77995},
	{"FLIER", 5, 77996},
	{"MASTIFF", 7, 77997},
	{"UHOW", 4, 77998},
	{"RMAA", 4, 77999},
	{"LLSJ", 4, 78000},
	{"GICH", 4, 78001},
	{"GAFL", 4, 78002},
	{"EPDE", 4, 78003},
	{"GRISWOLD", 8, 78004},
	{"DRUMMERS", 8, 78005},
	{"CARCINOGENIC", 12, 78006},
	{"MICR", 4, 78007},
	{"RRNA", 4, 78008},
	{"GOVERMENT", 9, 78009},
	{"REFORMER", 8, 78010},
	{"MERCADO", 7, 78011},
	{"SOLEMNLY", 8, 78012},
	{"TCAV", 4, 78013},
	{"STYB", 4, 78014},
	{"RKEX", 4, 78015},
	{"AYRS", 4, 78016},
	{"AUSB", 4, 78017},
	{"LUM", 3, 78018},
	{"DEKKER", 6, 78019},
	{"SUPERCHARGED", 12, 78020},
	{"LIBERALLY", 9, 78021},
	{"DAHLIA", 6, 78022},
	{"TKEL", 4, 78023},
	{"BIAW", 4, 78024},
	{"MAGICYELLOW", 11, 78025},
	{"PRIMAVERA", 9, 78026},
	{"TIMESCALE", 9, 78027},
	{"CONCENTRIC", 10, 78028},
	{"WFAL", 4, 78029},
	{"RZIN", 4, 78030},
	{"PHIG", 4, 78031},
	{"FBOA", 4, 78032},
	{"FICO", 4, 78033},
	{"OVERWRITTEN", 11, 78034},
	{"ZEDN", 4, 78035},
	{"RMYE", 4, 78036},
	{"PDRI", 4, 78037},
	{"KDEA", 4, 78038},
	{"IMJO", 4, 78039},
	{"GPAL", 4, 78040},
	{"MARCINHO", 8, 78041},
	{"KEANU", 5, 78042},
	{"EDINA", 5, 78043},
	{"PERLE", 5, 78044},
	{"YPHE", 4, 78045},
	{"WTRE", 4, 78046},
	{"NDIJ", 4, 78047},
	{"MPTR", 4, 78048},
	{"DYPO", 4, 78049},
	{"LEBRON", 6, 78050},
	{"UNWARRANTED", 11, 78051},
	{"MARMALADE", 9, 78052},
	{"TERMINALLY", 10, 78053},
	{"BUNDABERG", 9, 78054},
	{"DIEC", 4, 78055},
	{"SANDOVAL", 8, 78056},
	{"BREYER", 6, 78057},
	{"KOCHI", 5, 78058},
	{"PIRATED", 7, 78059},
	{"UITR", 4, 78060},
	{"APPLAUDED", 9, 78061},
	{"LEAVERS", 7, 78062},
	{"RAVINE", 6, 78063},
	{"WNYO", 4, 78064},
	{"TMYM", 4, 78065},
	{"CLOO", 4, 78066},
	{"VPL", 3, 78067},
	{"PUBSULIKE", 9, 78068},
	{"LSRU", 4, 78069},
	{"HMUR", 4, 78070},
	{"CKYC", 4, 78071},
	{"AQUIFERS", 8, 78072},
	{"NITTANY", 7, 78073},
	{"RLDV", 4, 78074},
	{"DAKINE", 6, 78075},
	{"RESCUERS", 8, 78076},
	{"EXPONENTS", 9, 78077},
	{"SURM", 4, 78078},
	{"PINJ", 4, 78079},
	{"MLAR", 4, 78080},
	{"LOGC", 4, 78081},
	{"AMSOIL", 6, 78082},
	{"REVITALIZE", 10, 78083},
	{"BRICE", 5, 78084},
	{"MESSAGEBOARDS", 13, 78085},
	{"KSUC", 4, 78086},
	{"FNAV", 4, 78087},
	{"RESSOURCES", 10, 78088},
	{"LAKEVILLE", 9, 78089},
	{"YBAY", 4, 78090},
	{"UTTY", 4, 78091},
	{"IXMA", 4, 78092},
	{"CYAR", 4, 78093},
	{"CALIFORNIANS", 12, 78094},
	{"PROCURING", 9, 78095},
	{"APOTHEON", 8, 78096},
	{"EUKARYOTA", 9, 78097},
	{"ZUV", 3, 78098},
	{"YJY", 3, 78099},
	{"XWM", 3, 78100},
	{"UJP", 3, 78101},
	{"KXR", 3, 78102},
	{"BQF", 3, 78103},
	{"PERMEABLE", 9, 78104},
	{"YPSE", 4, 78105},
	{"LLTW", 4, 78106},
	{"HCUT", 4, 78107},
	{"BUYM", 4, 78108},
	{"LASTNAME", 8, 78109},
	{"NGAQ", 4, 78110},
	{"LDNR", 4, 78111},
	{"FAXLESS", 7, 78112},
	{"KYSC", 4, 78113},
	{"POURS", 5, 78114},
	{"NAPALM", 6, 78115},
	{"KEFL", 4, 78116},
	{"ANNUNCIO", 8, 78117},
	{"LEER", 4, 78118},
	{"USMLE", 5, 78119},
	{"OPGR", 4, 78120},
	{"RACETRACK", 9, 78121},
	{"ATENOLOL", 8, 78122},
	{"ARRANGES", 8, 78123},
	{"RIVETING", 8, 78124},
	{"CBBC", 4, 78125},
	{"ABSORBERS", 9, 78126},
	{"XSERIES", 7, 78127},
	{"VALHALLA", 8, 78128},
	{"SDRY", 4, 78129},
	{"RDRY", 4, 78130},
	{"MYAI", 4, 78131},
	{"KUPP", 4, 78132},
	{"FIWE", 4, 78133},
	{"BIWEEKLY", 8, 78134},
	{"ADORATION", 9, 78135},
	{"PARKSIDE", 8, 78136},
	{"UGSW", 4, 78137},
	{"KBLA", 4, 78138},
	{"IRYI", 4, 78139},
	{"DERAILED", 8, 78140},
	{"SHOEBUY", 7, 78141},
	{"ASHWORTH", 8, 78142},
	{"AMITY", 5, 78143},
	{"YPEP", 4, 78144},
	{"ICYF", 4, 78145},
	{"HFED", 4, 78146},
	{"SUPERIORS", 9, 78147},
	{"KEIRA", 5, 78148},
	{"DECANTER", 8, 78149},
	{"STARVE", 6, 78150},
	{"YHEF", 4, 78151},
	{"VITR", 4, 78152},
	{"SSFL", 4, 78153},
	{"LEEK", 4, 78154},
	{"MEADVILLE", 9, 78155},
	{"WBEG", 4, 78156},
	{"ISKB", 4, 78157},
	{"GROD", 4, 78158},
	{"GAHU", 4, 78159},
	{"EUKT", 4, 78160},
	{"SHORTNESS", 9, 78161},
	{"SKYNYRD", 7, 78162},
	{"THREECHANNEL", 12, 78163},
	{"MONOLOGUES", 10, 78164},
	{"SUBROUTINES", 11, 78165},
	{"SUBSPECIES", 10, 78166},
	{"OGUR", 4, 78167},
	{"DRUD", 4, 78168},
	{"FRONTED", 7, 78169},
	{"PENTON", 6, 78170},
	{"FIGLEAVES", 9, 78171},
	{"XIND", 4, 78172},
	{"DOBR", 4, 78173},
	{"LIGHTEST", 8, 78174},
	{"BANQUETS", 8, 78175},
	{"KETCHIKAN", 9, 78176},
	{"IMMAGINI", 8, 78177},
	{"PICNICS", 7, 78178},
	{"COMPULSION", 10, 78179},
	{"PREROGATIVE", 11, 78180},
	{"ULNO", 4, 78181},
	{"DRAA", 4, 78182},
	{"SHAFER", 6, 78183},
	{"BROILER", 7, 78184},
	{"LFWE", 4, 78185},
	{"GBAG", 4, 78186},
	{"DSLU", 4, 78187},
	{"CUPR", 4, 78188},
	{"LICKERS", 7, 78189},
	{"AKBAR", 5, 78190},
	{"ABSCESS", 7, 78191},
	{"PARAPHERNALIA", 13, 78192},
	{"CBL", 3, 78193},
	{"CERJ", 4, 78194},
	{"HERETOFORE", 10, 78195},
	{"SKIMPY", 6, 78196},
	{"MEMENTO", 7, 78197},
	{"IMCR", 4, 78198},
	{"REFLEXIVE", 9, 78199},
	{"XWHO", 4, 78200},
	{"OMGU", 4, 78201},
	{"HYLL", 4, 78202},
	{"FTMO", 4, 78203},
	{"ELAZ", 4, 78204},
	{"EFFL", 4, 78205},
	{"TUMBLED", 7, 78206},
	{"MASTERFUL", 9, 78207},
	{"INSOLUBLE", 9, 78208},
	{"TUPM", 4, 78209},
	{"MPHL", 4, 78210},
	{"BWHO", 4, 78211},
	{"DROOL", 5, 78212},
	{"GODIN", 5, 78213},
	{"EXCHANGERS", 10, 78214},
	{"TVPR", 4, 78215},
	{"ORSJ", 4, 78216},
	{"INTERBASE", 9, 78217},
	{"SEPSIS", 6, 78218},
	{"APPLI", 5, 78219},
	{"BOXDATA", 7, 78220},
	{"LAING", 5, 78221},
	{"OSCILLATORS", 11, 78222},
	{"WOBL", 4, 78223},
	{"WEDJ", 4, 78224},
	{"OYSR", 4, 78225},
	{"LSOQ", 4, 78226},
	{"CHOLINE", 7, 78227},
	{"DOOLITTLE", 9, 78228},
	{"TRIKES", 6, 78229},
	{"COCKBURN", 8, 78230},
	{"PDM", 3, 78231},
	{"JOERG", 5, 78232},
	{"URAH", 4, 78233},
	{"REMOVERS", 8, 78234},
	{"GRISHAM", 7, 78235},
	{"HARWICH", 7, 78236},
	{"DIFFUSER", 8, 78237},
	{"INDESIT", 7, 78238},
	{"CASAS", 5, 78239},
	{"ROUBLE", 6, 78240},
	{"MUGH", 4, 78241},
	{"LIDW", 4, 78242},
	{"DLDQ", 4, 78243},
	{"KAMASUTRA", 9, 78244},
	{"CAMILA", 6, 78245},
	{"BELO", 4, 78246},
	{"POSTNATAL", 9, 78247},
	{"SEMPER", 6, 78248},
	{"REPRESSIVE", 10, 78249},
	{"KOIZUMI", 7, 78250},
	{"CLOS", 4, 78251},
	{"IADM", 4, 78252},
	{"DYTE", 4, 78253},
	{"DEHY", 4, 78254},
	{"SWEETER", 7, 78255},
	{"MATTIE", 6, 78256},
	{"DEUTSCHER", 9, 78257},
	{"SPILLING", 8, 78258},
	{"TALLIED", 7, 78259},
	{"IKEZOE", 6, 78260},
	{"UMEH", 4, 78261},
	{"LORAIN", 6, 78262},
	{"SAUCERS", 7, 78263},
	{"OTDU", 4, 78264},
	{"LOYT", 4, 78265},
	{"ECTJ", 4, 78266},
	{"KEYING", 6, 78267},
	{"BALLPOINT", 9, 78268},
	{"ECEF", 4, 78269},
	{"LUPIN", 5, 78270},
	{"MSMU", 4, 78271},
	{"EIDOS", 5, 78272},
	{"GONDOLA", 7, 78273},
	{"COMPUTERISED", 12, 78274},
	{"MUNSON", 6, 78275},
	{"SIMC", 4, 78276},
	{"MYGA", 4, 78277},
	{"GYBU", 4, 78278},
	{"MUNOZ", 5, 78279},
	{"ELIZABETHAN", 11, 78280},
	{"JEFFERSONVILLE", 14, 78281},
	{"WILLFULLY", 9, 78282},
	{"ORIENTEERING", 12, 78283},
	{"SMMA", 4, 78284},
	{"BTOR", 4, 78285},
	{"XCW", 3, 78286},
	{"BXB", 3, 78287},
	{"SPINES", 6, 78288},
	{"CAVS", 4, 78289},
	{"HUMPHRIES", 9, 78290},
	{"REITER", 6, 78291},
	{"PUSS", 4, 78292},
	{"UCOS", 4, 78293},
	{"MAUT", 4, 78294},
	{"IDKI", 4, 78295},
	{"BSAL", 4, 78296},
	{"PODIATRY", 8, 78297},
	{"TRUFFLE", 7, 78298},
	{"AMPHITHEATRE", 12, 78299},
	{"BEAL", 4, 78300},
	{"UPMI", 4, 78301},
	{"KBUI", 4, 78302},
	{"STUPENDOUS", 10, 78303},
	{"FLUTTER", 7, 78304},
	{"KALAHARI", 8, 78305},
	{"BLOCKAGE", 8, 78306},
	{"HALLO", 5, 78307},
	{"FUNP", 4, 78308},
	{"DSIC", 4, 78309},
	{"ABSOLUT", 7, 78310},
	{"SHIVER", 6, 78311},
	{"LUMIERE", 7, 78312},
	{"SHATTER", 7, 78313},
	{"RYAV", 4, 78314},
	{"KEBL", 4, 78315},
	{"HPHY", 4, 78316},
	{"OBSTET", 6, 78317},
	{"BULMA", 5, 78318},
	{"PICKLED", 7, 78319},
	{"CHICOS", 6, 78320},
	{"CLICHE", 6, 78321},
	{"SADC", 4, 78322},
	{"UWHA", 4, 78323},
	{"SRUB", 4, 78324},
	{"ICYD", 4, 78325},
	{"TOLAR", 5, 78326},
	{"SCREENNAME", 10, 78327},
	{"MAPU", 4, 78328},
	{"GCOP", 4, 78329},
	{"CHLORINATED", 11, 78330},
	{"NIEUWE", 6, 78331},
	{"HADES", 5, 78332},
	{"HYPOTHESIZED", 12, 78333},
	{"SUPERIMPOSED", 12, 78334},
	{"UPBRINGING", 10, 78335},
	{"BURDENED", 8, 78336},
	{"GPUN", 4, 78337},
	{"CUSF", 4, 78338},
	{"FMC", 3, 78339},
	{"NEWRY", 5, 78340},
	{"ZONAL", 5, 78341},
	{"DEFUN", 5, 78342},
	{"UNSUSTAINABLE", 13, 78343},
	{"GHOSTBUSTERS", 12, 78344},
	{"INTERDEPENDENT", 14, 78345},
	{"ROCKWOOD", 8, 78346},
	{"CIVICS", 6, 78347},
	{"OGDE", 4, 78348},
	{"LITERALS", 8, 78349},
	{"UNANTICIPATED", 13, 78350},
	{"RANDAL", 6, 78351},
	{"LEUT", 4, 78352},
	{"CDEB", 4, 78353},
	{"SEMINOLES", 9, 78354},
	{"PLIST", 5, 78355},
	{"TABULATED", 9, 78356},
	{"DANDELION", 9, 78357},
	{"WORKLOADS", 9, 78358},
	{"OXWH", 4, 78359},
	{"OWVE", 4, 78360},
	{"ORZI", 4, 78361},
	{"CHEMO", 5, 78362},
	{"VHDL", 4, 78363},
	{"NUANCE", 6, 78364},
	{"YLAD", 4, 78365},
	{"WLAR", 4, 78366},
	{"URIZ", 4, 78367},
	{"DYEN", 4, 78368},
	{"PRETRIAL", 8, 78369},
	{"ULOR", 4, 78370},
	{"LQAI", 4, 78371},
	{"CIAB", 4, 78372},
	{"CABB", 4, 78373},
	{"FERMILAB", 8, 78374},
	{"HOTPLUG", 7, 78375},
	{"ROTATOR", 7, 78376},
	{"KRUPS", 5, 78377},
	{"MYOSIN", 6, 78378},
	{"CLASSMATE", 9, 78379},
	{"CATECHISM", 9, 78380},
	{"YESM", 4, 78381},
	{"TGOB", 4, 78382},
	{"LITM", 4, 78383},
	{"DYBR", 4, 78384},
	{"BORB", 4, 78385},
	{"CARPOOL", 7, 78386},
	{"HONKY", 5, 78387},
	{"MATSUMOTO", 9, 78388},
	{"DRIFTWOOD", 9, 78389},
	{"UEGE", 4, 78390},
	{"ROSALIND", 8, 78391},
	{"ARMPITS", 7, 78392},
	{"CLUG", 4, 78393},
	{"GASOLINA", 8, 78394},
	{"FPAU", 4, 78395},
	{"CARUSO", 6, 78396},
	{"GIORNI", 6, 78397},
	{"JOYSTICKS", 9, 78398},
	{"VISUALIZED", 10, 78399},
	{"BOSWORTH", 8, 78400},
	{"WSAP", 4, 78401},
	{"UEND", 4, 78402},
	{"TWOQ", 4, 78403},
	{"DTVS", 4, 78404},
	{"CKFU", 4, 78405},
	{"AGGL", 4, 78406},
	{"CLITORAL", 8, 78407},
	{"BERS", 4, 78408},
	{"CARSTEN", 7, 78409},
	{"ENDK", 4, 78410},
	{"CDIV", 4, 78411},
	{"BOXC", 4, 78412},
	{"JUIN", 4, 78413},
	{"BIGELOW", 7, 78414},
	{"RIVERWALK", 9, 78415},
	{"ANOINTED", 8, 78416},
	{"MYTHOLOGICAL", 12, 78417},
	{"CONVERTIBLES", 12, 78418},
	{"RILC", 4, 78419},
	{"CYBO", 4, 78420},
	{"AVYO", 4, 78421},
	{"INTERSPERSED", 12, 78422},
	{"LITEROTICA", 10, 78423},
	{"PGM", 3, 78424},
	{"YIVE", 4, 78425},
	{"UGSO", 4, 78426},
	{"RINGETONER", 10, 78427},
	{"CKIF", 4, 78428},
	{"ADUM", 4, 78429},
	{"FLOORPLAN", 9, 78430},
	{"HORSEMAN", 8, 78431},
	{"OSCILLOSCOPE", 12, 78432},
	{"YBIS", 4, 78433},
	{"SDYI", 4, 78434},
	{"RIOM", 4, 78435},
	{"IFMO", 4, 78436},
	{"GETZ", 4, 78437},
	{"NERVOUSLY", 9, 78438},
	{"INTRUDERS", 9, 78439},
	{"MGD", 3, 78440},
	{"ZYAN", 4, 78441},
	{"DICTATORS", 9, 78442},
	{"LEVEES", 6, 78443},
	{"CHAPARRAL", 9, 78444},
	{"WNIF", 4, 78445},
	{"HEUG", 4, 78446},
	{"DOBO", 4, 78447},
	{"DECAYING", 8, 78448},
	{"ANNANDALE", 9, 78449},
	{"HILLEL", 6, 78450},
	{"JEFFRIES", 8, 78451},
	{"PACHECO", 7, 78452},
	{"SLACKER", 7, 78453},
	{"YBIN", 4, 78454},
	{"UTKA", 4, 78455},
	{"OPCU", 4, 78456},
	{"CEHU", 4, 78457},
	{"MUSES", 5, 78458},
	{"MIVA", 4, 78459},
	{"YCEA", 4, 78460},
	{"VESJ", 4, 78461},
	{"UEDC", 4, 78462},
	{"AMUP", 4, 78463},
	{"XCHANGE", 7, 78464},
	{"KRAFTWERK", 9, 78465},
	{"BANDANA", 7, 78466},
	{"PADLOCK", 7, 78467},
	{"GILEAD", 6, 78468},
	{"CLASSED", 7, 78469},
	{"INFORMER", 8, 78470},
	{"PENTECOSTAL", 11, 78471},
	{"YMOB", 4, 78472},
	{"ULFR", 4, 78473},
	{"NYTY", 4, 78474},
	{"NGZO", 4, 78475},
	{"DRYD", 4, 78476},
	{"FREER", 5, 78477},
	{"EXTRAPOLATION", 13, 78478},
	{"FENNEL", 6, 78479},
	{"TELEMARK", 8, 78480},
	{"TOUTE", 5, 78481},
	{"LOPR", 4, 78482},
	{"CALABRIA", 8, 78483},
	{"DISMANTLED", 10, 78484},
	{"OVERCAME", 8, 78485},
	{"OBID", 4, 78486},
	{"NBEY", 4, 78487},
	{"EQUR", 4, 78488},
	{"QUY", 3, 78489},
	{"DATASHEETS", 10, 78490},
	{"EXERTION", 8, 78491},
	{"SOLIDLY", 7, 78492},
	{"FLYWHEEL", 8, 78493},
	{"AFFIDAVITS", 10, 78494},
	{"WEAVES", 6, 78495},
	{"TOKL", 4, 78496},
	{"LYGL", 4, 78497},
	{"CHIMERA", 7, 78498},
	{"HANDKERCHIEF", 12, 78499},
	{"FUTONS", 6, 78500},
	{"INTERVIEWEES", 12, 78501},
	{"MOSFET", 6, 78502},
	{"FOAMING", 7, 78503},
	{"TAILORS", 7, 78504},
	{"BARBARIANS", 10, 78505},
	{"SPLENDOUR", 9, 78506},
	{"XFW", 3, 78507},
	{"LVK", 3, 78508},
	{"NIVEAU", 6, 78509},
	{"OGUS", 4, 78510},
	{"MARYVILLE", 9, 78511},
	{"OSKAR", 5, 78512},
	{"SHERIFFS", 8, 78513},
	{"QUARKXPRESS", 11, 78514},
	{"TASSEL", 6, 78515},
	{"ADMIRING", 8, 78516},
	{"NONDISCRIMINATION", 17, 78517},
	{"REPUBLIKA", 9, 78518},
	{"HARMONIZED", 10, 78519},
	{"KHARTOUM", 8, 78520},
	{"ICICI", 5, 78521},
	{"SIRJ", 4, 78522},
	{"LEANS", 5, 78523},
	{"FIXINGS", 7, 78524},
	{"LEITH", 5, 78525},
	{"FRANKREICH", 10, 78526},
	{"RBAK", 4, 78527},
	{"KICKBOXING", 10, 78528},
	{"BAFFLED", 7, 78529},
	{"DEMING", 6, 78530},
	{"RMFI", 4, 78531},
	{"MROS", 4, 78532},
	{"DEACTIVATED", 11, 78533},
	{"WASTEFUL", 8, 78534},
	{"CALIENTE", 8, 78535},
	{"OLIGONUCLEOTIDE", 15, 78536},
	{"CRTC", 4, 78537},
	{"GOLGI", 5, 78538},
	{"CHANNELING", 10, 78539},
	{"HERTFORD", 8, 78540},
	{"STOPWATCH", 9, 78541},
	{"USOV", 4, 78542},
	{"UJAR", 4, 78543},
	{"LOYO", 4, 78544},
	{"TRIPOLI", 7, 78545},
	{"MAROC", 5, 78546},
	{"LEMIEUX", 7, 78547},
	{"SUBSCRIPT", 9, 78548},
	{"STARFLEET", 9, 78549},
	{"REFRACTION", 10, 78550},
	{"GRAINGER", 8, 78551},
	{"PPAG", 4, 78552},
	{"SUBSTANDARD", 11, 78553},
	{"PENZANCE", 8, 78554},
	{"FILLETS", 7, 78555},
	{"PHENTERMINEPHENTERMINE", 22, 78556},
	{"AZTECS", 6, 78557},
	{"PHONED", 6, 78558},
	{"CONSULTS", 8, 78559},
	{"GMTIME", 6, 78560},
	{"UCRE", 4, 78561},
	{"RMBI", 4, 78562},
	{"FSYM", 4, 78563},
	{"CONVENER", 8, 78564},
	{"BECUASE", 7, 78565},
	{"DAILIES", 7, 78566},
	{"DANSGUARDIAN", 12, 78567},
	{"MIRAMAX", 7, 78568},
	{"BUSTA", 5, 78569},
	{"RKIR", 4, 78570},
	{"EYVO", 4, 78571},
	{"MAURY", 5, 78572},
	{"FOILS", 5, 78573},
	{"RTMY", 4, 78574},
	{"LCEM", 4, 78575},
	{"KRAF", 4, 78576},
	{"JIZZSHOT", 8, 78577},
	{"RETRACT", 7, 78578},
	{"MOYA", 4, 78579},
	{"NACKT", 5, 78580},
	{"COMMERCIALISATION", 17, 78581},
	{"NKBO", 4, 78582},
	{"HJUM", 4, 78583},
	{"CUNNI", 5, 78584},
	{"CARDINALITY", 11, 78585},
	{"RKAF", 4, 78586},
	{"GJOU", 4, 78587},
	{"MACHADO", 7, 78588},
	{"INAUDIBLE", 9, 78589},
	{"NURTURED", 8, 78590},
	{"FRANTICALLY", 11, 78591},
	{"BUOYS", 5, 78592},
	{"INSURANCES", 10, 78593},
	{"TINTING", 7, 78594},
	{"EPIDEMIOLOGIC", 13, 78595},
	{"YUPA", 4, 78596},
	{"RUSD", 4, 78597},
	{"NKUN", 4, 78598},
	{"IRUT", 4, 78599},
	{"FOWN", 4, 78600},
	{"FOCC", 4, 78601},
	{"FFAV", 4, 78602},
	{"BURNIE", 6, 78603},
	{"BUSHINGS", 8, 78604},
	{"RADIONUCLIDE", 12, 78605},
	{"RNEP", 4, 78606},
	{"DNUC", 4, 78607},
	{"TYPEFACE", 8, 78608},
	{"DISINTEGRATION", 14, 78609},
	{"PAOL", 4, 78610},
	{"NKOW", 4, 78611},
	{"HROL", 4, 78612},
	{"GSGE", 4, 78613},
	{"BBYT", 4, 78614},
	{"CHANGEOVER", 10, 78615},
	{"TERMITES", 8, 78616},
	{"DOTNETNUKE", 10, 78617},
	{"THEOLOGIAN", 10, 78618},
	{"DECRYPTION", 10, 78619},
	{"DCCO", 4, 78620},
	{"AQUITAINE", 9, 78621},
	{"LICN", 4, 78622},
	{"BSBE", 4, 78623},
	{"ETNIES", 6, 78624},
	{"SIGMUND", 7, 78625},
	{"SUBSEC", 6, 78626},
	{"CXX", 3, 78627},
	{"INDIVIDUALISM", 13, 78628},
	{"RUEW", 4, 78629},
	{"RSEU", 4, 78630},
	{"RPSY", 4, 78631},
	{"NCTF", 4, 78632},
	{"STARBOARD", 9, 78633},
	{"PRECLUDES", 9, 78634},
	{"BURDENSOME", 10, 78635},
	{"GRINNELL", 8, 78636},
	{"ALEXEI", 6, 78637},
	{"NICV", 4, 78638},
	{"HELLY", 5, 78639},
	{"PROTESTORS", 10, 78640},
	{"SIGNINGS", 8, 78641},
	{"BREST", 5, 78642},
	{"RENOWN", 6, 78643},
	{"MURKY", 5, 78644},
	{"YMUN", 4, 78645},
	{"UZBE", 4, 78646},
	{"URDY", 4, 78647},
	{"PARNELL", 7, 78648},
	{"GRETNA", 6, 78649},
	{"GUIDA", 5, 78650},
	{"TRUTHFULLY", 10, 78651},
	{"DEUTSCHEN", 9, 78652},
	{"YLIO", 4, 78653},
	{"FARSCAPE", 8, 78654},
	{"HDTVS", 5, 78655},
	{"XDOL", 4, 78656},
	{"CCRU", 4, 78657},
	{"TONGS", 5, 78658},
	{"PERPETUATE", 10, 78659},
	{"CYBORG", 6, 78660},
	{"VIGO", 4, 78661},
	{"YANKS", 5, 78662},
	{"PNOW", 4, 78663},
	{"HEMATOPOIETIC", 13, 78664},
	{"CLOT", 4, 78665},
	{"IMPRINTS", 8, 78666},
	{"CABAL", 5, 78667},
	{"SLOD", 4, 78668},
	{"PMOV", 4, 78669},
	{"DLOY", 4, 78670},
	{"AKEK", 4, 78671},
	{"OPENSOLARIS", 11, 78672},
	{"INFLATIONARY", 12, 78673},
	{"MUSA", 4, 78674},
	{"MATERIA", 7, 78675},
	{"INTERWOVEN", 10, 78676},
	{"BEGGAR", 6, 78677},
	{"TRACEROUTE", 10, 78678},
	{"FGM", 3, 78679},
	{"ULRI", 4, 78680},
	{"GICM", 4, 78681},
	{"DASJ", 4, 78682},
	{"CUDDLE", 6, 78683},
	{"PARD", 4, 78684},
	{"WORKBOOKS", 9, 78685},
	{"FALLBACK", 8, 78686},
	{"PERMUTATIONS", 12, 78687},
	{"WTHF", 4, 78688},
	{"MYAD", 4, 78689},
	{"CUER", 4, 78690},
	{"EXTINGUISHED", 12, 78691},
	{"DOWNER", 6, 78692},
	{"ABELIAN", 7, 78693},
	{"SILHOUETTES", 11, 78694},
	{"CABELA", 6, 78695},
	{"TRANSFEREE", 10, 78696},
	{"QUANTITATIVELY", 14, 78697},
	{"ABUNDANTLY", 10, 78698},
	{"DMYL", 4, 78699},
	{"DECLINATION", 11, 78700},
	{"SHEEPDOG", 8, 78701},
	{"CAMERAMAN", 9, 78702},
	{"LKIC", 4, 78703},
	{"KLYO", 4, 78704},
	{"PINOCHET", 8, 78705},
	{"UPFA", 4, 78706},
	{"LYSN", 4, 78707},
	{"ILSY", 4, 78708},
	{"IGLO", 4, 78709},
	{"REPLICATING", 11, 78710},
	{"EXCESSES", 8, 78711},
	{"MUCOUS", 6, 78712},
	{"UNRU", 4, 78713},
	{"SGLE", 4, 78714},
	{"IFDE", 4, 78715},
	{"ZCY", 3, 78716},
	{"POKED", 5, 78717},
	{"WSLA", 4, 78718},
	{"SLASHES", 7, 78719},
	{"STREETPILOT", 11, 78720},
	{"RENOVATING", 10, 78721},
	{"PARALYMPIC", 10, 78722},
	{"NDYF", 4, 78723},
	{"DWARVES", 7, 78724},
	{"CAKEWALK", 8, 78725},
	{"PYRO", 4, 78726},
	{"PHENTERMINEDISCOUNT", 19, 78727},
	{"LPOO", 4, 78728},
	{"KRAU", 4, 78729},
	{"DABD", 4, 78730},
	{"STINKS", 6, 78731},
	{"BEHAV", 5, 78732},
	{"BLACKFOOT", 9, 78733},
	{"CARICATURES", 11, 78734},
	{"LRSQ", 4, 78735},
	{"KLEO", 4, 78736},
	{"SCHAFFER", 8, 78737},
	{"ARTISTE", 7, 78738},
	{"WOFP", 4, 78739},
	{"TDOR", 4, 78740},
	{"ELBL", 4, 78741},
	{"KEMPER", 6, 78742},
	{"LYNS", 4, 78743},
	{"LONJ", 4, 78744},
	{"FFMO", 4, 78745},
	{"BOGEN", 5, 78746},
	{"GLYCEMIC", 8, 78747},
	{"PLESK", 5, 78748},
	{"SLICER", 6, 78749},
	{"BLIZ", 4, 78750},
	{"ARTV", 4, 78751},
	{"JOSHI", 5, 78752},
	{"REPOSE", 6, 78753},
	{"HASTEN", 6, 78754},
	{"TENDERED", 8, 78755},
	{"TEMPERANCE", 10, 78756},
	{"REALTYTRAC", 10, 78757},
	{"METF", 4, 78758},
	{"ITZK", 4, 78759},
	{"SANDBURG", 8, 78760},
	{"REZA", 4, 78761},
	{"MSBR", 4, 78762},
	{"RISQUE", 6, 78763},
	{"OPERABLE", 8, 78764},
	{"RESEMBLED", 9, 78765},
	{"WARGAMES", 8, 78766},
	{"GUERRILLAS", 10, 78767},
	{"GIUS", 4, 78768},
	{"DDWA", 4, 78769},
	{"AYPI", 4, 78770},
	{"AMJO", 4, 78771},
	{"HELPFULNESS", 11, 78772},
	{"YSTF", 4, 78773},
	{"RALQ", 4, 78774},
	{"NOWV", 4, 78775},
	{"KEBY", 4, 78776},
	{"FULLSIZE", 8, 78777},
	{"OMITTING", 8, 78778},
	{"ANZAC", 5, 78779},
	{"KULKARNI", 8, 78780},
	{"RNRI", 4, 78781},
	{"NKSU", 4, 78782},
	{"LTSU", 4, 78783},
	{"EARTHY", 6, 78784},
	{"RABBIS", 6, 78785},
	{"MENDELSSOHN", 11, 78786},
	{"ADORED", 6, 78787},
	{"PMJU", 4, 78788},
	{"LADU", 4, 78789},
	{"HDRO", 4, 78790},
	{"EMBELLISHED", 11, 78791},
	{"FEATHERED", 9, 78792},
	{"AGGRIEVED", 9, 78793},
	{"INVESTIGATIONAL", 15, 78794},
	{"PHOTOJOURNALISM", 15, 78795},
	{"ANAAL", 5, 78796},
	{"HACER", 5, 78797},
	{"ASSISI", 6, 78798},
	{"AGGRAVATING", 11, 78799},
	{"ZEDV", 4, 78800},
	{"LOCT", 4, 78801},
	{"CHRISTIANSEN", 12, 78802},
	{"CENTAUR", 7, 78803},
	{"RUBIO", 5, 78804},
	{"TRANSANDO", 9, 78805},
	{"RFAX", 4, 78806},
	{"OPOG", 4, 78807},
	{"LWRO", 4, 78808},
	{"OHYD", 4, 78809},
	{"GNCA", 4, 78810},
	{"FROY", 4, 78811},
	{"INSULTED", 8, 78812},
	{"PRATCHETT", 9, 78813},
	{"CLIMATOLOGY", 11, 78814},
	{"BAISE", 5, 78815},
	{"LABTEC", 6, 78816},
	{"NLUN", 4, 78817},
	{"NGOM", 4, 78818},
	{"DOGB", 4, 78819},
	{"PRIORITIZATION", 14, 78820},
	{"PINHOLE", 7, 78821},
	{"HDPE", 4, 78822},
	{"BIOENGINEERING", 14, 78823},
	{"FUGITIVES", 9, 78824},
	{"DIRAC", 5, 78825},
	{"MCU", 3, 78826},
	{"ALVEOLAR", 8, 78827},
	{"OWPI", 4, 78828},
	{"OBUD", 4, 78829},
	{"WESTMEATH", 9, 78830},
	{"LEWINSKY", 8, 78831},
	{"PASSE", 5, 78832},
	{"GNBU", 4, 78833},
	{"FSFO", 4, 78834},
	{"WEBX", 4, 78835},
	{"ACCO", 4, 78836},
	{"ANECDOTE", 8, 78837},
	{"CEDJ", 4, 78838},
	{"EXORCIST", 8, 78839},
	{"BIOFEEDBACK", 11, 78840},
	{"ATRIOS", 6, 78841},
	{"HONDURAN", 8, 78842},
	{"PARTAKE", 7, 78843},
	{"SEAVIEW", 7, 78844},
	{"RFIX", 4, 78845},
	{"QAID", 4, 78846},
	{"GSAD", 4, 78847},
	{"FSLE", 4, 78848},
	{"DOBV", 4, 78849},
	{"PSEUDONYM", 9, 78850},
	{"SKAG", 4, 78851},
	{"DOUCHE", 6, 78852},
	{"ALTITUDES", 9, 78853},
	{"SOUNDCARD", 9, 78854},
	{"RESISTIVE", 9, 78855},
	{"CAROLINAS", 9, 78856},
	{"ELFN", 4, 78857},
	{"SYLVAIN", 7, 78858},
	{"CHUBB", 5, 78859},
	{"SNOOPER", 7, 78860},
	{"DBASE", 5, 78861},
	{"UEAM", 4, 78862},
	{"PTOK", 4, 78863},
	{"MCOO", 4, 78864},
	{"STRIKINGLY", 10, 78865},
	{"KATJA", 5, 78866},
	{"VYME", 4, 78867},
	{"LCIV", 4, 78868},
	{"FIREPOWER", 9, 78869},
	{"CISSP", 5, 78870},
	{"MANGALORE", 9, 78871},
	{"LAOIS", 5, 78872},
	{"UNMODIFIED", 10, 78873},
	{"KEYSTROKE", 9, 78874},
	{"ZELL", 4, 78875},
	{"PARKERSBURG", 11, 78876},
	{"GILLMOR", 7, 78877},
	{"JOYNER", 6, 78878},
	{"MPHK", 4, 78879},
	{"KEEM", 4, 78880},
	{"BDON", 4, 78881},
	{"VINNIE", 6, 78882},
	{"RANCHER", 7, 78883},
	{"CCF", 3, 78884},
	{"GROCERS", 7, 78885},
	{"MICN", 4, 78886},
	{"SIMULATES", 9, 78887},
	{"FLATHEAD", 8, 78888},
	{"CASTELLANO", 10, 78889},
	{"SIGIA", 5, 78890},
	{"UELD", 4, 78891},
	{"RHID", 4, 78892},
	{"VESTING", 7, 78893},
	{"MISSPELLED", 10, 78894},
	{"PRONO", 5, 78895},
	{"DSEW", 4, 78896},
	{"HEADCOUNT", 9, 78897},
	{"PANACHE", 7, 78898},
	{"HALLELUJAH", 10, 78899},
	{"KPJ", 3, 78900},
	{"GJG", 3, 78901},
	{"MORN", 4, 78902},
	{"VILM", 4, 78903},
	{"ROPF", 4, 78904},
	{"OTFL", 4, 78905},
	{"CAYUGA", 6, 78906},
	{"MROO", 4, 78907},
	{"ERNY", 4, 78908},
	{"GLUG", 4, 78909},
	{"BODYGUARD", 9, 78910},
	{"GNATS", 5, 78911},
	{"ZODB", 4, 78912},
	{"GUBERNATORIAL", 13, 78913},
	{"GORAN", 5, 78914},
	{"FOFP", 4, 78915},
	{"SOLON", 5, 78916},
	{"BAUHAUS", 7, 78917},
	{"SMBE", 4, 78918},
	{"MRBR", 4, 78919},
	{"EDUARD", 6, 78920},
	{"UEOP", 4, 78921},
	{"RSAK", 4, 78922},
	{"MGOT", 4, 78923},
	{"DETRACT", 7, 78924},
	{"SARAWAK", 7, 78925},
	{"SPARKY", 6, 78926},
	{"SEBASTIEN", 9, 78927},
	{"PORTRAYING", 10, 78928},
	{"ZAGA", 4, 78929},
	{"WSCR", 4, 78930},
	{"LLLY", 4, 78931},
	{"WIRELESSLY", 10, 78932},
	{"SYSOP", 5, 78933},
	{"DOCI", 4, 78934},
	{"BLOA", 4, 78935},
	{"FACTORED", 8, 78936},
	{"PITTED", 6, 78937},
	{"XWOR", 4, 78938},
	{"LFSI", 4, 78939},
	{"ENLARGING", 9, 78940},
	{"EULA", 4, 78941},
	{"WRECKS", 6, 78942},
	{"HURM", 4, 78943},
	{"POLYMERIC", 9, 78944},
	{"BOMBARDMENT", 11, 78945},
	{"SALIVARY", 8, 78946},
	{"FOFW", 4, 78947},
	{"BUCKNER", 7, 78948},
	{"DARES", 5, 78949},
	{"EIGEN", 5, 78950},
	{"ASYNC", 5, 78951},
	{"OERC", 4, 78952},
	{"HDEG", 4, 78953},
	{"KRISTIAN", 8, 78954},
	{"CIRCADIAN", 9, 78955},
	{"ANALGESICS", 10, 78956},
	{"FLINTSHIRE", 10, 78957},
	{"YIDI", 4, 78958},
	{"SIESTA", 6, 78959},
	{"PRAKASH", 7, 78960},
	{"PRODUCTOS", 9, 78961},
	{"SATIRICAL", 9, 78962},
	{"PHENOTYPIC", 10, 78963},
	{"PAAR", 4, 78964},
	{"PELAGIC", 7, 78965},
	{"AGRONOMY", 8, 78966},
	{"ANTOINETTE", 10, 78967},
	{"AIRONET", 7, 78968},
	{"WKSA", 4, 78969},
	{"VIEF", 4, 78970},
	{"UTGU", 4, 78971},
	{"DNTU", 4, 78972},
	{"CYNIC", 5, 78973},
	{"WEIGHTLIFTING", 13, 78974},
	{"AMENABLE", 8, 78975},
	{"YUGO", 4, 78976},
	{"ROAK", 4, 78977},
	{"KMAS", 4, 78978},
	{"FSTY", 4, 78979},
	{"AYQU", 4, 78980},
	{"AUDIOPHILE", 10, 78981},
	{"WNDR", 4, 78982},
	{"KEMC", 4, 78983},
	{"UNIDOS", 6, 78984},
	{"RUNWAYS", 7, 78985},
	{"FROWNED", 7, 78986},
	{"MOTORCYCLING", 12, 78987},
	{"UMFI", 4, 78988},
	{"LYJE", 4, 78989},
	{"RAINE", 5, 78990},
	{"TESTBED", 7, 78991},
	{"PEDIATRICIANS", 13, 78992},
	{"KBAL", 4, 78993},
	{"DYCL", 4, 78994},
	{"COSW", 4, 78995},
	{"FINGERPRINTING", 14, 78996},
	{"BUNBURY", 7, 78997},
	{"TASKING", 7, 78998},
	{"ROUT", 4, 78999},
	{"GMD", 3, 79000},
	{"EMULATED", 8, 79001},
	{"UDLI", 4, 79002},
	{"STYM", 4, 79003},
	{"LYNU", 4, 79004},
	{"EUKI", 4, 79005},
	{"BBCR", 4, 79006},
	{"TWEAKED", 7, 79007},
	{"RUBIES", 6, 79008},
	{"CHECKERED", 9, 79009},
	{"PHONOLOGICAL", 12, 79010},
	{"HATCHED", 7, 79011},
	{"KSAD", 4, 79012},
	{"IXPA", 4, 79013},
	{"BARCO", 5, 79014},
	{"GOMES", 5, 79015},
	{"SKETCHING", 9, 79016},
	{"FARIDABAD", 9, 79017},
	{"MSAV", 4, 79018},
	{"SNAPPY", 6, 79019},
	{"HYPOCRITICAL", 12, 79020},
	{"OUQU", 4, 79021},
	{"TRAMPLE", 7, 79022},
	{"COLONIC", 7, 79023},
	{"JEROEN", 6, 79024},
	{"RLER", 4, 79025},
	{"COURTSHIP", 9, 79026},
	{"ZIRCON", 6, 79027},
	{"CUPBOARDS", 9, 79028},
	{"PBYS", 4, 79029},
	{"LSJU", 4, 79030},
	{"CKYP", 4, 79031},
	{"BSMA", 4, 79032},
	{"DANSKO", 6, 79033},
	{"CASPASE", 7, 79034},
	{"ENCINITAS", 9, 79035},
	{"REMOTING", 8, 79036},
	{"AMRU", 4, 79037},
	{"PLOY", 4, 79038},
	{"ACHAT", 5, 79039},
	{"FREEFIND", 8, 79040},
	{"TOLERABLE", 9, 79041},
	{"XHAD", 4, 79042},
	{"DUSW", 4, 79043},
	{"CSCR", 4, 79044},
	{"SPELLINGS", 9, 79045},
	{"MAGI", 4, 79046},
	{"CANOPUS", 7, 79047},
	{"BRESCIA", 7, 79048},
	{"ALONZO", 6, 79049},
	{"GAULLE", 6, 79050},
	{"TUTTO", 5, 79051},
	{"XXON", 4, 79052},
	{"WWWA", 4, 79053},
	{"UISW", 4, 79054},
	{"KBEI", 4, 79055},
	{"IORK", 4, 79056},
	{"MAPLIN", 6, 79057},
	{"ATTENUATED", 10, 79058},
	{"RNLO", 4, 79059},
	{"EUPE", 4, 79060},
	{"DUTCHESS", 8, 79061},
	{"WATTAGE", 7, 79062},
	{"PUKE", 4, 79063},
	{"DISTINFO", 8, 79064},
	{"INEFFICIENCY", 12, 79065},
	{"EXPEDITIONARY", 13, 79066},
	{"ORMG", 4, 79067},
	{"AMORTIZED", 9, 79068},
	{"TRUCKEE", 7, 79069},
	{"ALBURY", 6, 79070},
	{"HUMANISTIC", 10, 79071},
	{"TRAVELOGUE", 10, 79072},
	{"TRIGLYCERIDES", 13, 79073},
	{"GSTREAMER", 9, 79074},
	{"LEAVITT", 7, 79075},
	{"MERCI", 5, 79076},
	{"RTAW", 4, 79077},
	{"SHOTGUNS", 8, 79078},
	{"DISCOUNTING", 11, 79079},
	{"ETOYS", 5, 79080},
	{"BOOMS", 5, 79081},
	{"THIRTIES", 8, 79082},
	{"SWIPE", 5, 79083},
	{"DIONNE", 6, 79084},
	{"RTUO", 4, 79085},
	{"EYCI", 4, 79086},
	{"DEMENTED", 8, 79087},
	{"EBSCOHOST", 9, 79088},
	{"UEDD", 4, 79089},
	{"PREW", 4, 79090},
	{"KACA", 4, 79091},
	{"BONAPARTE", 9, 79092},
	{"GEOQUOTE", 8, 79093},
	{"UPKEEP", 6, 79094},
	{"WHYO", 4, 79095},
	{"UMAI", 4, 79096},
	{"ALDD", 4, 79097},
	{"TRUNCATION", 10, 79098},
	{"BAUSCH", 6, 79099},
	{"POMEROY", 7, 79100},
	{"IKIL", 4, 79101},
	{"ENUL", 4, 79102},
	{"CKPU", 4, 79103},
	{"MUSKETEERS", 10, 79104},
	{"HARRODS", 7, 79105},
	{"TWICKENHAM", 10, 79106},
	{"VOKI", 4, 79107},
	{"IMGR", 4, 79108},
	{"GLEE", 4, 79109},
	{"DOWNGRADE", 9, 79110},
	{"ROOMATES", 8, 79111},
	{"BILIARY", 7, 79112},
	{"DUMPSTER", 8, 79113},
	{"RDOA", 4, 79114},
	{"MBYS", 4, 79115},
	{"KYCO", 4, 79116},
	{"FMYP", 4, 79117},
	{"UNIVERSALIST", 12, 79118},
	{"ACDBARC", 7, 79119},
	{"TPAK", 4, 79120},
	{"YWCA", 4, 79121},
	{"OCEANVIEW", 9, 79122},
	{"FAZENDO", 7, 79123},
	{"SHAYNE", 6, 79124},
	{"TOMY", 4, 79125},
	{"RESIZED", 7, 79126},
	{"YORKIE", 6, 79127},
	{"GGIA", 4, 79128},
	{"MATTEO", 6, 79129},
	{"SHANAHAN", 8, 79130},
	{"JAPONICA", 8, 79131},
	{"FROOGLE", 7, 79132},
	{"REHNQUIST", 9, 79133},
	{"ORPM", 4, 79134},
	{"MEGABYTE", 8, 79135},
	{"FORGETS", 7, 79136},
	{"GINSBERG", 8, 79137},
	{"RNSD", 4, 79138},
	{"RIPF", 4, 79139},
	{"OLKM", 4, 79140},
	{"LMEI", 4, 79141},
	{"EUME", 4, 79142},
	{"VIVIENNE", 8, 79143},
	{"GRAPPLE", 7, 79144},
	{"PENTICTON", 9, 79145},
	{"LDTW", 4, 79146},
	{"LOWLANDS", 8, 79147},
	{"INSEAM", 6, 79148},
	{"TYHU", 4, 79149},
	{"STIMULANTS", 10, 79150},
	{"MPMT", 4, 79151},
	{"MLER", 4, 79152},
	{"PRESSURIZED", 11, 79153},
	{"FAVES", 5, 79154},
	{"MASSAGERS", 9, 79155},
	{"RMAU", 4, 79156},
	{"IRIU", 4, 79157},
	{"HRAL", 4, 79158},
	{"HEXB", 4, 79159},
	{"GTYP", 4, 79160},
	{"BEJO", 4, 79161},
	{"RSEQ", 4, 79162},
	{"KQUE", 4, 79163},
	{"GREENERY", 8, 79164},
	{"IDPU", 4, 79165},
	{"BIAG", 4, 79166},
	{"PROVERBIAL", 10, 79167},
	{"TIMESHEET", 9, 79168},
	{"ANNISTON", 8, 79169},
	{"SIGUR", 5, 79170},
	{"TOUGHBOOK", 9, 79171},
	{"HISTOLOGICAL", 12, 79172},
	{"CLAYS", 5, 79173},
	{"WONP", 4, 79174},
	{"VINP", 4, 79175},
	{"OUUN", 4, 79176},
	{"LSUG", 4, 79177},
	{"PCX", 3, 79178},
	{"SUZIE", 5, 79179},
	{"HONEYCOMB", 9, 79180},
	{"TRANQUILLITY", 12, 79181},
	{"NUMA", 4, 79182},
	{"DENIER", 6, 79183},
	{"NDOK", 4, 79184},
	{"IDHU", 4, 79185},
	{"ETCETERA", 8, 79186},
	{"REOPENING", 9, 79187},
	{"MONASTIC", 8, 79188},
	{"UNCLES", 6, 79189},
	{"SOARED", 6, 79190},
	{"HERRMANN", 8, 79191},
	{"QUANTIFYING", 11, 79192},
	{"QIGONG", 6, 79193},
	{"HOUSEHOLDERS", 12, 79194},
	{"NESTOR", 6, 79195},
	{"YJEA", 4, 79196},
	{"KURZWEIL", 8, 79197},
	{"CHANUKAH", 8, 79198},
	{"PROGRAMAS", 9, 79199},
	{"FUMBLES", 7, 79200},
	{"JOBSEEKERS", 10, 79201},
	{"NITRITE", 7, 79202},
	{"CATCHERS", 8, 79203},
	{"MOUSER", 6, 79204},
	{"WEOF", 4, 79205},
	{"LVEO", 4, 79206},
	{"KNYSNA", 6, 79207},
	{"ANDREY", 6, 79208},
	{"IMPEDIMENT", 10, 79209},
	{"TEXTAREA", 8, 79210},
	{"FPIE", 4, 79211},
	{"PESTO", 5, 79212},
	{"ANARCHISTS", 10, 79213},
	{"PONDEROSA", 9, 79214},
	{"GUBE", 4, 79215},
	{"KROATIEN", 8, 79216},
	{"TRANSITIONING", 13, 79217},
	{"FREUND", 6, 79218},
	{"WHOOPS", 6, 79219},
	{"PERILOUS", 8, 79220},
	{"DEVONSHIRE", 10, 79221},
	{"CATAMARAN", 9, 79222},
	{"UWAT", 4, 79223},
	{"RHOC", 4, 79224},
	{"OJER", 4, 79225},
	{"GGRI", 4, 79226},
	{"PREOPERATIVE", 12, 79227},
	{"VIOLETS", 7, 79228},
	{"VERILOG", 7, 79229},
	{"NOUVELLES", 9, 79230},
	{"NETHER", 6, 79231},
	{"YGIF", 4, 79232},
	{"UYAH", 4, 79233},
	{"MSIG", 4, 79234},
	{"GINK", 4, 79235},
	{"EYIM", 4, 79236},
	{"EUKE", 4, 79237},
	{"DADH", 4, 79238},
	{"HELIOS", 6, 79239},
	{"WHEELBASE", 9, 79240},
	{"NARAYAN", 7, 79241},
	{"VOYFORUMS", 9, 79242},
	{"UNCTAD", 6, 79243},
	{"MONOMER", 7, 79244},
	{"NOMADS", 6, 79245},
	{"REFUELING", 9, 79246},
	{"ILIFE", 5, 79247},
	{"BIENNIUM", 8, 79248},
	{"PELLEPENNAN", 11, 79249},
	{"RAMBLE", 6, 79250},
	{"IDJE", 4, 79251},
	{"HGUN", 4, 79252},
	{"QUARTILE", 8, 79253},
	{"ANWAR", 5, 79254},
	{"RLTH", 4, 79255},
	{"NKWO", 4, 79256},
	{"IDVE", 4, 79257},
	{"INFOBANK", 8, 79258},
	{"HEXAGON", 7, 79259},
	{"WYAN", 4, 79260},
	{"RYSN", 4, 79261},
	{"RSYT", 4, 79262},
	{"ORTJ", 4, 79263},
	{"MURT", 4, 79264},
	{"GEODETIC", 8, 79265},
	{"AMBULANCES", 10, 79266},
	{"UKET", 4, 79267},
	{"OMBY", 4, 79268},
	{"OLSK", 4, 79269},
	{"GPHA", 4, 79270},
	{"NATURA", 6, 79271},
	{"EMPORIS", 7, 79272},
	{"AHMADINEJAD", 11, 79273},
	{"EDEW", 4, 79274},
	{"LUBES", 5, 79275},
	{"CONSENSUAL", 10, 79276},
	{"ALTIMETER", 9, 79277},
	{"CIZI", 4, 79278},
	{"IDIOTIC", 7, 79279},
	{"RLMA", 4, 79280},
	{"LAWLER", 6, 79281},
	{"SHARPENER", 9, 79282},
	{"STELLENBOSCH", 12, 79283},
	{"SOUNDEX", 7, 79284},
	{"SETENV", 6, 79285},
	{"PARTI", 5, 79286},
	{"GOLDFINGER", 10, 79287},
	{"CERBERUS", 8, 79288},
	{"ASCORBIC", 8, 79289},
	{"BERING", 6, 79290},
	{"MZD", 3, 79291},
	{"DXJ", 3, 79292},
	{"RUPL", 4, 79293},
	{"HIMACHAL", 8, 79294},
	{"DICHOTOMY", 9, 79295},
	{"MNIC", 4, 79296},
	{"LVIR", 4, 79297},
	{"ILLQ", 4, 79298},
	{"COMMUNIGATE", 11, 79299},
	{"FORMOSA", 7, 79300},
	{"COVALENT", 8, 79301},
	{"CANTRELL", 8, 79302},
	{"RREZ", 4, 79303},
	{"KYSA", 4, 79304},
	{"TARPON", 6, 79305},
	{"BOUGH", 5, 79306},
	{"BLUFFTON", 8, 79307},
	{"HEREWITH", 8, 79308},
	{"AKPO", 4, 79309},
	{"RADIX", 5, 79310},
	{"ORTHOLOGOUS", 11, 79311},
	{"TAICHI", 6, 79312},
	{"BOREALIS", 8, 79313},
	{"WORKMEN", 7, 79314},
	{"NERF", 4, 79315},
	{"GRIST", 5, 79316},
	{"ROSEDALE", 8, 79317},
	{"POLICYHOLDERS", 13, 79318},
	{"RACECOURSE", 10, 79319},
	{"PENROSE", 7, 79320},
	{"LDIP", 4, 79321},
	{"EXTRATERRESTRIAL", 16, 79322},
	{"SERVICEMEN", 10, 79323},
	{"STARWOOD", 8, 79324},
	{"DUSTER", 6, 79325},
	{"ROPB", 4, 79326},
	{"PRONOUN", 7, 79327},
	{"PHYLOGENY", 9, 79328},
	{"DEOD", 4, 79329},
	{"DAJA", 4, 79330},
	{"SIGNER", 6, 79331},
	{"TIESTO", 6, 79332},
	{"HTFL", 4, 79333},
	{"EYOW", 4, 79334},
	{"AMERI", 5, 79335},
	{"PLANKTON", 8, 79336},
	{"SLOTH", 5, 79337},
	{"STEELY", 6, 79338},
	{"XRET", 4, 79339},
	{"ULAH", 4, 79340},
	{"SEAMUS", 6, 79341},
	{"PULLEYS", 7, 79342},
	{"SURB", 4, 79343},
	{"OYAM", 4, 79344},
	{"ILOW", 4, 79345},
	{"GJUD", 4, 79346},
	{"SUBLETS", 7, 79347},
	{"FATES", 5, 79348},
	{"UNTHREADED", 10, 79349},
	{"STEWS", 5, 79350},
	{"XFRO", 4, 79351},
	{"MICROSTRATEGY", 13, 79352},
	{"CLEANUPS", 8, 79353},
	{"FITCHBURG", 9, 79354},
	{"FLOWCHART", 9, 79355},
	{"TACKY", 5, 79356},
	{"EFAK", 4, 79357},
	{"SAUK", 4, 79358},
	{"NOURISHMENT", 11, 79359},
	{"SUPERCOMPUTING", 14, 79360},
	{"GRAVITATION", 11, 79361},
	{"ULRA", 4, 79362},
	{"MCHO", 4, 79363},
	{"GORH", 4, 79364},
	{"GGAL", 4, 79365},
	{"ANTIWAR", 7, 79366},
	{"LOOPHOLE", 8, 79367},
	{"ILLAWARRA", 9, 79368},
	{"ULSU", 4, 79369},
	{"FFWR", 4, 79370},
	{"BACL", 4, 79371},
	{"DRAGS", 5, 79372},
	{"BENETTON", 8, 79373},
	{"MENOPAUSAL", 10, 79374},
	{"WORKGROUPS", 10, 79375},
	{"RETROGRADE", 10, 79376},
	{"RELIVE", 6, 79377},
	{"KETCHUM", 7, 79378},
	{"LLOH", 4, 79379},
	{"AYAV", 4, 79380},
	{"EXAGGERATION", 12, 79381},
	{"SHADOWY", 7, 79382},
	{"LIQUORS", 7, 79383},
	{"NIEUWS", 6, 79384},
	{"LREI", 4, 79385},
	{"HIMK", 4, 79386},
	{"MIRAGO", 6, 79387},
	{"REPRODUCIBILITY", 15, 79388},
	{"ARCHANGEL", 9, 79389},
	{"ABALONE", 7, 79390},
	{"WOQU", 4, 79391},
	{"UENZ", 4, 79392},
	{"OPSR", 4, 79393},
	{"CKHU", 4, 79394},
	{"FENWICK", 7, 79395},
	{"CREASES", 7, 79396},
	{"ASHMORE", 7, 79397},
	{"UORI", 4, 79398},
	{"EACHOTHER", 9, 79399},
	{"PRIMORDIAL", 10, 79400},
	{"JUGGS", 5, 79401},
	{"NOURISH", 7, 79402},
	{"GEOMETRIES", 10, 79403},
	{"PETZL", 5, 79404},
	{"XACE", 4, 79405},
	{"URDS", 4, 79406},
	{"PMOD", 4, 79407},
	{"LICV", 4, 79408},
	{"AMYT", 4, 79409},
	{"UPLIFTED", 8, 79410},
	{"QUIRKS", 6, 79411},
	{"YUPD", 4, 79412},
	{"XTHR", 4, 79413},
	{"BUNDY", 5, 79414},
	{"UONL", 4, 79415},
	{"KPOW", 4, 79416},
	{"DLIQ", 4, 79417},
	{"CRAYOLA", 7, 79418},
	{"ACCEPTOR", 8, 79419},
	{"PRECONDITION", 12, 79420},
	{"UAYA", 4, 79421},
	{"BOBM", 4, 79422},
	{"PERCIVAL", 8, 79423},
	{"PADOVA", 6, 79424},
	{"GINGHAM", 7, 79425},
	{"INDICA", 6, 79426},
	{"RODDICK", 7, 79427},
	{"BATTERIE", 8, 79428},
	{"IXCA", 4, 79429},
	{"GOSSAMER", 8, 79430},
	{"TEASERS", 7, 79431},
	{"BEVELED", 7, 79432},
	{"HAIRDRESSER", 11, 79433},
	{"UDAC", 4, 79434},
	{"OWPU", 4, 79435},
	{"LBYC", 4, 79436},
	{"FFPR", 4, 79437},
	{"EOFZ", 4, 79438},
	{"CONSUMERISM", 11, 79439},
	{"PLOVER", 6, 79440},
	{"FLR", 3, 79441},
	{"YEOVIL", 6, 79442},
	{"BONELESS", 8, 79443},
	{"DISLIKED", 8, 79444},
	{"LEINSTER", 8, 79445},
	{"IMPURITY", 8, 79446},
	{"INTRACRANIAL", 12, 79447},
	{"WLIK", 4, 79448},
	{"KBD", 3, 79449},
	{"GAMEDAY", 7, 79450},
	{"SOLUTE", 6, 79451},
	{"LNOL", 4, 79452},
	{"LKSB", 4, 79453},
	{"TUPPERWARE", 10, 79454},
	{"RIDGEFIELD", 10, 79455},
	{"WORSHIPPING", 11, 79456},
	{"QUADRO", 6, 79457},
	{"MUMPS", 5, 79458},
	{"TRUCOS", 6, 79459},
	{"MOPAR", 5, 79460},
	{"UTYM", 4, 79461},
	{"LVEP", 4, 79462},
	{"CHASM", 5, 79463},
	{"HAGGIS", 6, 79464},
	{"ELECTROMECHANICAL", 17, 79465},
	{"STYLI", 5, 79466},
	{"TLYJ", 4, 79467},
	{"PSIC", 4, 79468},
	{"NUOVO", 5, 79469},
	{"WHIPPLE", 7, 79470},
	{"ULAP", 4, 79471},
	{"SKUN", 4, 79472},
	{"RTVA", 4, 79473},
	{"CHKA", 4, 79474},
	{"FPM", 3, 79475},
	{"GREENISH", 8, 79476},
	{"ARCATA", 6, 79477},
	{"PEREGO", 6, 79478},
	{"YEOF", 4, 79479},
	{"UTSD", 4, 79480},
	{"OLMG", 4, 79481},
	{"OFRS", 4, 79482},
	{"NMYR", 4, 79483},
	{"REGIMENTS", 9, 79484},
	{"GUWAHATI", 8, 79485},
	{"LOUDON", 6, 79486},
	{"LEGOLAS", 7, 79487},
	{"YUTI", 4, 79488},
	{"OOFY", 4, 79489},
	{"OBCO", 4, 79490},
	{"EFFB", 4, 79491},
	{"ROCKAWAY", 8, 79492},
	{"ADEL", 4, 79493},
	{"EXHIBITIONIST", 13, 79494},
	{"SELFISHNESS", 11, 79495},
	{"WOOLLEY", 7, 79496},
	{"MSPS", 4, 79497},
	{"REACTIONARY", 11, 79498},
	{"TOOLSET", 7, 79499},
	{"NKIW", 4, 79500},
	{"LUBD", 4, 79501},
	{"VVU", 3, 79502},
	{"CXU", 3, 79503},
	{"FERRAGAMO", 9, 79504},
	{"ADRIATIC", 8, 79505},
	{"GODIVA", 6, 79506},
	{"GNEV", 4, 79507},
	{"CMEE", 4, 79508},
	{"EJECTED", 7, 79509},
	{"GRAPPLING", 9, 79510},
	{"HAMMERING", 9, 79511},
	{"UXAN", 4, 79512},
	{"VFW", 3, 79513},
	{"MASCULINITY", 11, 79514},
	{"MINGLING", 8, 79515},
	{"SCHRADER", 8, 79516},
	{"OLUR", 4, 79517},
	{"EARNESTLY", 9, 79518},
	{"BLD", 3, 79519},
	{"LIGHTFOOT", 9, 79520},
	{"CAPITALIZING", 12, 79521},
	{"ALKU", 4, 79522},
	{"SCRIBES", 7, 79523},
	{"TMYD", 4, 79524},
	{"RAKY", 4, 79525},
	{"IRUP", 4, 79526},
	{"RUCKER", 6, 79527},
	{"LEED", 4, 79528},
	{"MONOLOGUE", 9, 79529},
	{"UYSL", 4, 79530},
	{"EVAG", 4, 79531},
	{"CROE", 4, 79532},
	{"AMPHITHEATER", 12, 79533},
	{"BROWSED", 7, 79534},
	{"FREENET", 7, 79535},
	{"VIVE", 4, 79536},
	{"BUNDLING", 8, 79537},
	{"CANNONDALE", 10, 79538},
	{"MCAT", 4, 79539},
	{"WCRO", 4, 79540},
	{"RCEU", 4, 79541},
	{"NWEM", 4, 79542},
	{"SIGNALED", 8, 79543},
	{"MENCKEN", 7, 79544},
	{"COMMERICAL", 10, 79545},
	{"DAGENHAM", 8, 79546},
	{"YROG", 4, 79547},
	{"NSGU", 4, 79548},
	{"DPAD", 4, 79549},
	{"CODENAME", 8, 79550},
	{"CLEM", 4, 79551},
	{"NESGC", 5, 79552},
	{"FULY", 4, 79553},
	{"LITTERED", 8, 79554},
	{"ACUTELY", 7, 79555},
	{"PROFESS", 7, 79556},
	{"AFEC", 4, 79557},
	{"RAZORS", 6, 79558},
	{"MASSE", 5, 79559},
	{"REARRANGE", 9, 79560},
	{"WARFARIN", 8, 79561},
	{"LEGUMES", 7, 79562},
	{"LPIL", 4, 79563},
	{"STDIN", 5, 79564},
	{"SPECULATED", 10, 79565},
	{"ROHAN", 5, 79566},
	{"OVERHEATING", 11, 79567},
	{"CONDON", 6, 79568},
	{"WSOL", 4, 79569},
	{"UMOV", 4, 79570},
	{"INFLATE", 7, 79571},
	{"WORDED", 6, 79572},
	{"GUNNISON", 8, 79573},
	{"QUANT", 5, 79574},
	{"SFMT", 4, 79575},
	{"SKWA", 4, 79576},
	{"OMJE", 4, 79577},
	{"LHOC", 4, 79578},
	{"BANJ", 4, 79579},
	{"FLESHY", 6, 79580},
	{"DEVONPORT", 9, 79581},
	{"COPYWRITER", 10, 79582},
	{"RNFE", 4, 79583},
	{"IMBT", 4, 79584},
	{"CSLO", 4, 79585},
	{"DESIRABILITY", 12, 79586},
	{"BODYBUILDER", 11, 79587},
	{"PSIGATE", 7, 79588},
	{"AIRFORCE", 8, 79589},
	{"TTBR", 4, 79590},
	{"EYDU", 4, 79591},
	{"DOVI", 4, 79592},
	{"FLEISCHER", 9, 79593},
	{"SUNDOWN", 7, 79594},
	{"ATMEL", 5, 79595},
	{"UDUL", 4, 79596},
	{"NREU", 4, 79597},
	{"LDJA", 4, 79598},
	{"KSRO", 4, 79599},
	{"HMYF", 4, 79600},
	{"EWUS", 4, 79601},
	{"RASTA", 5, 79602},
	{"RAVEL", 5, 79603},
	{"JUPITERRESEARCH", 15, 79604},
	{"FLYCATCHER", 10, 79605},
	{"PERSISTENTLY", 12, 79606},
	{"CUSACK", 6, 79607},
	{"JENNI", 5, 79608},
	{"IXOR", 4, 79609},
	{"GBPS", 4, 79610},
	{"DECOY", 5, 79611},
	{"BALSAM", 6, 79612},
	{"BOMBSHELL", 9, 79613},
	{"YALG", 4, 79614},
	{"RNYO", 4, 79615},
	{"ORIB", 4, 79616},
	{"MFAN", 4, 79617},
	{"JUMB", 4, 79618},
	{"LLBEAN", 6, 79619},
	{"ARNIE", 5, 79620},
	{"SUBDOMAINS", 10, 79621},
	{"PALR", 4, 79622},
	{"OMOM", 4, 79623},
	{"GGEA", 4, 79624},
	{"FJOU", 4, 79625},
	{"LPSE", 4, 79626},
	{"LPPA", 4, 79627},
	{"HBAY", 4, 79628},
	{"DDOZ", 4, 79629},
	{"BARUCH", 6, 79630},
	{"KALE", 4, 79631},
	{"SEYD", 4, 79632},
	{"ITBL", 4, 79633},
	{"PCD", 3, 79634},
	{"SHEMP", 5, 79635},
	{"FINDTECH", 8, 79636},
	{"HUCK", 4, 79637},
	{"VOUYER", 6, 79638},
	{"VERDICTS", 8, 79639},
	{"HORRENDOUS", 10, 79640},
	{"COMPLAINANTS", 12, 79641},
	{"UDAP", 4, 79642},
	{"RKTR", 4, 79643},
	{"ADDY", 4, 79644},
	{"FABRICATING", 11, 79645},
	{"AUTHORISE", 9, 79646},
	{"OUTCRY", 6, 79647},
	{"YIFA", 4, 79648},
	{"KASC", 4, 79649},
	{"FKMM", 4, 79650},
	{"VERDATE", 7, 79651},
	{"EYEGLASS", 8, 79652},
	{"CYBERPUNK", 9, 79653},
	{"ENOTES", 6, 79654},
	{"WATERSIDE", 9, 79655},
	{"PECANS", 6, 79656},
	{"ABABA", 5, 79657},
	{"GRIME", 5, 79658},
	{"WHITEHORSE", 10, 79659},
	{"EXTORTION", 9, 79660},
	{"BARAK", 5, 79661},
	{"JUKE", 4, 79662},
	{"YBYE", 4, 79663},
	{"SCHNAUZER", 9, 79664},
	{"HAIRDRESSERS", 12, 79665},
	{"CORDON", 6, 79666},
	{"RNUS", 4, 79667},
	{"LADW", 4, 79668},
	{"EKAP", 4, 79669},
	{"CKYF", 4, 79670},
	{"PRIORITIZED", 11, 79671},
	{"RAINFORESTS", 11, 79672},
	{"COLORLESS", 9, 79673},
	{"RABIN", 5, 79674},
	{"IDEALISTIC", 10, 79675},
	{"REPM", 4, 79676},
	{"IXDE", 4, 79677},
	{"WORKDAY", 7, 79678},
	{"EARED", 5, 79679},
	{"EARPHONE", 8, 79680},
	{"PASSAIC", 7, 79681},
	{"VESV", 4, 79682},
	{"UMEL", 4, 79683},
	{"LSTW", 4, 79684},
	{"HYPERMEDIA", 10, 79685},
	{"CUTLASS", 7, 79686},
	{"UDB", 3, 79687},
	{"PPAT", 4, 79688},
	{"PLOO", 4, 79689},
	{"OGSC", 4, 79690},
	{"HKMH", 4, 79691},
	{"FNEU", 4, 79692},
	{"JINX", 4, 79693},
	{"ILLITERACY", 10, 79694},
	{"RIGOR", 5, 79695},
	{"YLAI", 4, 79696},
	{"RUGO", 4, 79697},
	{"PBRO", 4, 79698},
	{"KSDU", 4, 79699},
	{"CARCINOGENS", 11, 79700},
	{"GREYHOUNDS", 10, 79701},
	{"RDJU", 4, 79702},
	{"OFFRES", 6, 79703},
	{"GJF", 3, 79704},
	{"BQM", 3, 79705},
	{"ADDRESSEE", 9, 79706},
	{"THEFREEDICTIONARY", 17, 79707},
	{"AMALGAMATION", 12, 79708},
	{"YATU", 4, 79709},
	{"AYBL", 4, 79710},
	{"INFORMANTS", 10, 79711},
	{"XOPH", 4, 79712},
	{"UYTO", 4, 79713},
	{"AULF", 4, 79714},
	{"SUBLIMATION", 11, 79715},
	{"PREPONDERANCE", 13, 79716},
	{"COWARDLY", 8, 79717},
	{"HARNESSING", 10, 79718},
	{"PRETENTIOUS", 11, 79719},
	{"EXTENDERS", 9, 79720},
	{"FISHMAN", 7, 79721},
	{"YFIF", 4, 79722},
	{"GONU", 4, 79723},
	{"ODSR", 4, 79724},
	{"KTEL", 4, 79725},
	{"CERVANTES", 9, 79726},
	{"WVU", 3, 79727},
	{"ZIMMERMANN", 10, 79728},
	{"WIELDING", 8, 79729},
	{"YETD", 4, 79730},
	{"ORKV", 4, 79731},
	{"MYAC", 4, 79732},
	{"MENV", 4, 79733},
	{"DDYW", 4, 79734},
	{"GUSTO", 5, 79735},
	{"DUPAGE", 6, 79736},
	{"MAIDENS", 7, 79737},
	{"BELARUSIAN", 10, 79738},
	{"WEIMAR", 6, 79739},
	{"LYNYRD", 6, 79740},
	{"MESSIANIC", 9, 79741},
	{"RDCU", 4, 79742},
	{"OULB", 4, 79743},
	{"MEXICANA", 8, 79744},
	{"MIJN", 4, 79745},
	{"GENERALIST", 10, 79746},
	{"HUMBLY", 6, 79747},
	{"RLSF", 4, 79748},
	{"GASTRONOMY", 10, 79749},
	{"HUCKLEBERRY", 11, 79750},
	{"RIDGEWOOD", 9, 79751},
	{"CTCR", 4, 79752},
	{"LANGUE", 6, 79753},
	{"ZERP", 4, 79754},
	{"UCKU", 4, 79755},
	{"ODMI", 4, 79756},
	{"GLEU", 4, 79757},
	{"YRIL", 4, 79758},
	{"UPTT", 4, 79759},
	{"LMYS", 4, 79760},
	{"ASYC", 4, 79761},
	{"UNWORTHY", 8, 79762},
	{"EXPECTANT", 9, 79763},
	{"LAURENS", 7, 79764},
	{"LIGHTSABER", 10, 79765},
	{"VIVANCO", 7, 79766},
	{"CATHETERS", 9, 79767},
	{"LFUP", 4, 79768},
	{"AZERBAIJANI", 11, 79769},
	{"WHITMORE", 8, 79770},
	{"FOOTY", 5, 79771},
	{"UPEE", 4, 79772},
	{"SIXL", 4, 79773},
	{"JOINERY", 7, 79774},
	{"WASATCH", 7, 79775},
	{"OCTAGON", 7, 79776},
	{"EQUATES", 7, 79777},
	{"SORENSON", 8, 79778},
	{"AZALEA", 6, 79779},
	{"JEANNETTE", 9, 79780},
	{"FRUITION", 8, 79781},
	{"WEBR", 4, 79782},
	{"TEPW", 4, 79783},
	{"RGIZ", 4, 79784},
	{"RFUM", 4, 79785},
	{"EAMES", 5, 79786},
	{"FLORENTINE", 10, 79787},
	{"TACOS", 5, 79788},
	{"DWELT", 5, 79789},
	{"NBLI", 4, 79790},
	{"MISSPELLINGS", 12, 79791},
	{"VLAANDEREN", 10, 79792},
	{"TRIVANDRUM", 10, 79793},
	{"FFDU", 4, 79794},
	{"CTOW", 4, 79795},
	{"OBERON", 6, 79796},
	{"KINGSVILLE", 10, 79797},
	{"MAGNETICS", 9, 79798},
	{"OPWO", 4, 79799},
	{"OOFL", 4, 79800},
	{"IDFU", 4, 79801},
	{"GAKI", 4, 79802},
	{"HALIDE", 6, 79803},
	{"ENSLAVED", 8, 79804},
	{"CATHAY", 6, 79805},
	{"METABOLITE", 10, 79806},
	{"OODK", 4, 79807},
	{"LAPH", 4, 79808},
	{"HOPM", 4, 79809},
	{"GUYB", 4, 79810},
	{"GENDERS", 7, 79811},
	{"HEADGEAR", 8, 79812},
	{"GRETZKY", 7, 79813},
	{"JURA", 4, 79814},
	{"HARMING", 7, 79815},
	{"YPEE", 4, 79816},
	{"YNEU", 4, 79817},
	{"SUNV", 4, 79818},
	{"KSSP", 4, 79819},
	{"KEEC", 4, 79820},
	{"HTDU", 4, 79821},
	{"FFGO", 4, 79822},
	{"INSOLE", 6, 79823},
	{"COLVIN", 6, 79824},
	{"THURROCK", 8, 79825},
	{"MFEL", 4, 79826},
	{"LLEQ", 4, 79827},
	{"CARDSTOCK", 9, 79828},
	{"JOURNALING", 10, 79829},
	{"UNIVERS", 7, 79830},
	{"CORRESPONDINGLY", 15, 79831},
	{"ARAGORN", 7, 79832},
	{"PRINCIPLED", 10, 79833},
	{"LEGALIZED", 9, 79834},
	{"PREDICAMENT", 11, 79835},
	{"MQUA", 4, 79836},
	{"CCLO", 4, 79837},
	{"BUMM", 4, 79838},
	{"HILLY", 5, 79839},
	{"NAMIBIAN", 8, 79840},
	{"AISLES", 6, 79841},
	{"SLACKS", 6, 79842},
	{"MCSD", 4, 79843},
	{"WMP", 3, 79844},
	{"YBYI", 4, 79845},
	{"WERQ", 4, 79846},
	{"PESU", 4, 79847},
	{"FVET", 4, 79848},
	{"TRUSTY", 6, 79849},
	{"FAIRMOUNT", 9, 79850},
	{"PHYSICA", 7, 79851},
	{"SUBTROPICAL", 11, 79852},
	{"SAGER", 5, 79853},
	{"GRATUITOUS", 10, 79854},
	{"FATALLY", 7, 79855},
	{"BOWFLEX", 7, 79856},
	{"PTRI", 4, 79857},
	{"PPYI", 4, 79858},
	{"OBOB", 4, 79859},
	{"CAGED", 5, 79860},
	{"SUBCOMMITTEES", 13, 79861},
	{"EPHEMERAL", 9, 79862},
	{"SMAM", 4, 79863},
	{"SDYN", 4, 79864},
	{"RADIUM", 6, 79865},
	{"DISSIMILAR", 10, 79866},
	{"RAMESH", 6, 79867},
	{"MUTILATION", 10, 79868},
	{"LHEM", 4, 79869},
	{"ICYR", 4, 79870},
	{"SITEPOINT", 9, 79871},
	{"PRAWN", 5, 79872},
	{"PHYLUM", 6, 79873},
	{"MEPHISTO", 8, 79874},
	{"PRF", 3, 79875},
	{"MUNDIAL", 7, 79876},
	{"WAVEFORMS", 9, 79877},
	{"ALGAL", 5, 79878},
	{"SCHAFER", 7, 79879},
	{"RIDDELL", 7, 79880},
	{"WAGING", 6, 79881},
	{"INFRINGED", 9, 79882},
	{"GIMMICKS", 8, 79883},
	{"REPARATIONS", 11, 79884},
	{"INJECTABLE", 10, 79885},
	{"COGNIZANT", 9, 79886},
	{"PLOU", 4, 79887},
	{"OUFL", 4, 79888},
	{"FMYB", 4, 79889},
	{"CKSK", 4, 79890},
	{"TRONDHEIM", 9, 79891},
	{"PROFIL", 6, 79892},
	{"ANDALUSIA", 9, 79893},
	{"LIBWWW", 6, 79894},
	{"UNEJ", 4, 79895},
	{"UISR", 4, 79896},
	{"PALW", 4, 79897},
	{"EMIP", 4, 79898},
	{"PHENIX", 6, 79899},
	{"ROWDY", 5, 79900},
	{"ARNB", 4, 79901},
	{"POPES", 5, 79902},
	{"TCPDUMP", 7, 79903},
	{"BRAVELY", 7, 79904},
	{"QUINLAN", 7, 79905},
	{"SPORTSMEN", 9, 79906},
	{"ECAMPUS", 7, 79907},
	{"KAYA", 4, 79908},
	{"ETHICALLY", 9, 79909},
	{"KNEY", 4, 79910},
	{"CUIN", 4, 79911},
	{"FKK", 3, 79912},
	{"FREERADIUS", 10, 79913},
	{"PUFFIN", 6, 79914},
	{"RNGO", 4, 79915},
	{"RIMT", 4, 79916},
	{"KUAL", 4, 79917},
	{"CUTP", 4, 79918},
	{"FREERIDE", 8, 79919},
	{"AHERN", 5, 79920},
	{"DMAH", 4, 79921},
	{"SHAPER", 6, 79922},
	{"LOCKSMITHS", 10, 79923},
	{"STUMBLES", 8, 79924},
	{"LICHFIELD", 9, 79925},
	{"CHEATER", 7, 79926},
	{"KEKI", 4, 79927},
	{"IGPI", 4, 79928},
	{"CLEMATIS", 8, 79929},
	{"SLASHING", 8, 79930},
	{"LEGER", 5, 79931},
	{"BOOTCAMP", 8, 79932},
	{"TORUS", 5, 79933},
	{"MONDEO", 6, 79934},
	{"UCTP", 4, 79935},
	{"DRUT", 4, 79936},
	{"XPX", 3, 79937},
	{"GJV", 3, 79938},
	{"COTTA", 5, 79939},
	{"INCOMPREHENSIBLE", 16, 79940},
	{"RVIT", 4, 79941},
	{"SUEZ", 4, 79942},
	{"CLOGGED", 7, 79943},
	{"FTAP", 4, 79944},
	{"VIGNETTES", 9, 79945},
	{"GABRIELLA", 9, 79946},
	{"FLUCTUATING", 11, 79947},
	{"ACULASER", 8, 79948},
	{"DEMEANOR", 8, 79949},
	{"WAXMAN", 6, 79950},
	{"HYPR", 4, 79951},
	{"AWAW", 4, 79952},
	{"SHIPBOARD", 9, 79953},
	{"ORYZA", 5, 79954},
	{"LEASHES", 7, 79955},
	{"YGAN", 4, 79956},
	{"TUNR", 4, 79957},
	{"OPBO", 4, 79958},
	{"OLFB", 4, 79959},
	{"LARJ", 4, 79960},
	{"FMUN", 4, 79961},
	{"DJEC", 4, 79962},
	{"LABOURERS", 9, 79963},
	{"BABYDOLL", 8, 79964},
	{"GITL", 4, 79965},
	{"EBCO", 4, 79966},
	{"CATL", 4, 79967},
	{"PAGANISM", 8, 79968},
	{"SRGB", 4, 79969},
	{"FIDO", 4, 79970},
	{"SOUNDER", 7, 79971},
	{"PRACTICALITY", 12, 79972},
	{"OWFU", 4, 79973},
	{"WINER", 5, 79974},
	{"CALEDONIAN", 10, 79975},
	{"ZENW", 4, 79976},
	{"RAKH", 4, 79977},
	{"OBIR", 4, 79978},
	{"BATTELLE", 8, 79979},
	{"HEGEL", 5, 79980},
	{"EUROPCAR", 8, 79981},
	{"PANCREATITIS", 12, 79982},
	{"AMERICUS", 8, 79983},
	{"BBSA", 4, 79984},
	{"IMMUNOHISTOCHEMISTRY", 20, 79985},
	{"WOODLAWN", 8, 79986},
	{"YFOX", 4, 79987},
	{"HDAM", 4, 79988},
	{"DHIP", 4, 79989},
	{"FILIGREE", 8, 79990},
	{"STENCH", 6, 79991},
	{"FORECASTED", 10, 79992},
	{"RVEM", 4, 79993},
	{"NDUA", 4, 79994},
	{"MIDJ", 4, 79995},
	{"ARLW", 4, 79996},
	{"BYPASSING", 9, 79997},
	{"CHOCK", 5, 79998},
	{"CHOCOLAT", 8, 79999},
	{"YAID", 4, 80000},
	{"UADT", 4, 80001},
	{"SKAW", 4, 80002},
	{"LINY", 4, 80003},
	{"CURSING", 7, 80004},
	{"PMB", 3, 80005},
	{"MESSIER", 7, 80006},
	{"WICKEDNESS", 10, 80007},
	{"GRAVIS", 6, 80008},
	{"EDSON", 5, 80009},
	{"CROUCHING", 9, 80010},
	{"NATHALIE", 8, 80011},
	{"CALENDARIO", 10, 80012},
	{"BLENHEIM", 8, 80013},
	{"IELC", 4, 80014},
	{"HOLC", 4, 80015},
	{"FINB", 4, 80016},
	{"BUQU", 4, 80017},
	{"CLARKSBURG", 10, 80018},
	{"ATTILA", 6, 80019},
	{"EMITS", 5, 80020},
	{"TRIGONOMETRY", 12, 80021},
	{"SWUN", 4, 80022},
	{"PEOU", 4, 80023},
	{"KONR", 4, 80024},
	{"FMCC", 4, 80025},
	{"AVOY", 4, 80026},
	{"VIRUSSCAN", 9, 80027},
	{"FLANGES", 7, 80028},
	{"BOWLERS", 7, 80029},
	{"RNGA", 4, 80030},
	{"NDKY", 4, 80031},
	{"EYHU", 4, 80032},
	{"CULMINATED", 10, 80033},
	{"THEFTS", 6, 80034},
	{"STURM", 5, 80035},
	{"KTAL", 4, 80036},
	{"EBCS", 4, 80037},
	{"HARLINGEN", 9, 80038},
	{"KEYPADS", 7, 80039},
	{"MSOV", 4, 80040},
	{"MAPH", 4, 80041},
	{"ADRY", 4, 80042},
	{"SOSUI", 5, 80043},
	{"WEITER", 6, 80044},
	{"CAMPANILE", 9, 80045},
	{"VASSAR", 6, 80046},
	{"AULD", 4, 80047},
	{"REGRESS", 7, 80048},
	{"GHOSH", 5, 80049},
	{"OBEQ", 4, 80050},
	{"IVEY", 4, 80051},
	{"SPANNED", 7, 80052},
	{"PTMA", 4, 80053},
	{"MEEF", 4, 80054},
	{"DEMM", 4, 80055},
	{"AGAB", 4, 80056},
	{"EBENEZER", 8, 80057},
	{"CLOSENESS", 9, 80058},
	{"TECHDIRT", 8, 80059},
	{"MINUTEMEN", 9, 80060},
	{"REDEEMING", 9, 80061},
	{"POLITY", 6, 80062},
	{"SROG", 4, 80063},
	{"KLYG", 4, 80064},
	{"CELIAC", 6, 80065},
	{"HOUGH", 5, 80066},
	{"INGESTED", 8, 80067},
	{"HYPOTHYROIDISM", 14, 80068},
	{"BOYFRIENDS", 10, 80069},
	{"ROTU", 4, 80070},
	{"POTB", 4, 80071},
	{"OLFF", 4, 80072},
	{"JEONG", 5, 80073},
	{"YNOB", 4, 80074},
	{"UEAF", 4, 80075},
	{"KIRM", 4, 80076},
	{"EQUIFAX", 7, 80077},
	{"BARODA", 6, 80078},
	{"GHGE", 4, 80079},
	{"SCRIPTURAL", 10, 80080},
	{"CYBERNETICS", 11, 80081},
	{"HELW", 4, 80082},
	{"TISSOT", 6, 80083},
	{"TRANSYLVANIA", 12, 80084},
	{"PREFERED", 8, 80085},
	{"RAPPERS", 7, 80086},
	{"DISCONTINUATION", 15, 80087},
	{"PANB", 4, 80088},
	{"ELGAR", 5, 80089},
	{"OBSCENITY", 9, 80090},
	{"BRLTTY", 6, 80091},
	{"GAUL", 4, 80092},
	{"UTYD", 4, 80093},
	{"URAV", 4, 80094},
	{"SAWC", 4, 80095},
	{"HEARTACHE", 9, 80096},
	{"REIGNED", 7, 80097},
	{"ENTITLES", 8, 80098},
	{"KLAN", 4, 80099},
	{"EXACTING", 8, 80100},
	{"GOKU", 4, 80101},
	{"OFFSETTING", 10, 80102},
	{"NUNW", 4, 80103},
	{"WANTON", 6, 80104},
	{"PELLE", 5, 80105},
	{"AIRMEN", 6, 80106},
	{"HALLIWELL", 9, 80107},
	{"IONIZING", 8, 80108},
	{"ANGEBOTE", 8, 80109},
	{"KIFT", 4, 80110},
	{"GYSA", 4, 80111},
	{"CYGR", 4, 80112},
	{"ENFORCES", 8, 80113},
	{"MORPHY", 6, 80114},
	{"BOOKMAKER", 9, 80115},
	{"CURIO", 5, 80116},
	{"YRAL", 4, 80117},
	{"LDAH", 4, 80118},
	{"AMALGAM", 7, 80119},
	{"NECESSITATE", 11, 80120},
	{"LOCKET", 6, 80121},
	{"AVER", 4, 80122},
	{"OUIM", 4, 80123},
	{"HEKM", 4, 80124},
	{"GBOW", 4, 80125},
	{"COMMEMORATING", 13, 80126},
	{"NOTIONAL", 8, 80127},
	{"WEBACTIVE", 9, 80128},
	{"BECHTEL", 7, 80129},
	{"RECONCILING", 11, 80130},
	{"DESOLATION", 10, 80131},
	{"ZAMBIAN", 7, 80132},
	{"REINHARDT", 9, 80133},
	{"BRIDGEND", 8, 80134},
	{"GANDER", 6, 80135},
	{"RMYG", 4, 80136},
	{"GCAB", 4, 80137},
	{"FBEH", 4, 80138},
	{"BENDIX", 6, 80139},
	{"DISTS", 5, 80140},
	{"VCJ", 3, 80141},
	{"KUQ", 3, 80142},
	{"DZX", 3, 80143},
	{"BASTILLE", 8, 80144},
	{"MAGNETOMETER", 12, 80145},
	{"OPMS", 4, 80146},
	{"OLUB", 4, 80147},
	{"HEWL", 4, 80148},
	{"AIMF", 4, 80149},
	{"POPULIST", 8, 80150},
	{"MIMO", 4, 80151},
	{"TRACEABLE", 9, 80152},
	{"RENFREW", 7, 80153},
	{"HESPERIA", 8, 80154},
	{"UBIQ", 4, 80155},
	{"PATB", 4, 80156},
	{"CHAUTAUQUA", 10, 80157},
	{"VOILA", 5, 80158},
	{"MNEMONIC", 8, 80159},
	{"INTERVIEWERS", 12, 80160},
	{"VISB", 4, 80161},
	{"RILD", 4, 80162},
	{"NGYU", 4, 80163},
	{"IFPO", 4, 80164},
	{"GARAGEBAND", 10, 80165},
	{"INVARIANCE", 10, 80166},
	{"MERIDEN", 7, 80167},
	{"ASPARTATE", 9, 80168},
	{"UKAR", 4, 80169},
	{"SAVOR", 5, 80170},
	{"ARAMIS", 6, 80171},
	{"DARKLY", 6, 80172},
	{"FAITHFULNESS", 12, 80173},
	{"VEYW", 4, 80174},
	{"MWAG", 4, 80175},
	{"RESOURCEFUL", 11, 80176},
	{"PLEURAL", 7, 80177},
	{"MEDIATING", 9, 80178},
	{"GABRIELE", 8, 80179},
	{"HERALDRY", 8, 80180},
	{"INCOMPARABLE", 12, 80181},
	{"RESONATOR", 9, 80182},
	{"DILATED", 7, 80183},
	{"YVEA", 4, 80184},
	{"PROVINCETOWN", 12, 80185},
	{"ANGERED", 7, 80186},
	{"SURPLUSES", 9, 80187},
	{"UNEQ", 4, 80188},
	{"ERGC", 4, 80189},
	{"CKYR", 4, 80190},
	{"ERTL", 4, 80191},
	{"CONDONE", 7, 80192},
	{"HOLGER", 6, 80193},
	{"CASTLEVANIA", 11, 80194},
	{"AHORA", 5, 80195},
	{"VANIQA", 6, 80196},
	{"ORIW", 4, 80197},
	{"MITP", 4, 80198},
	{"DNIK", 4, 80199},
	{"FINISHER", 8, 80200},
	{"MADEMOISELLE", 12, 80201},
	{"QUARTETS", 8, 80202},
	{"HEBER", 5, 80203},
	{"MUSCHIS", 7, 80204},
	{"ANTHROPOGENIC", 13, 80205},
	{"CONSTITUTIONALITY", 17, 80206},
	{"RREJ", 4, 80207},
	{"KILD", 4, 80208},
	{"THERMOS", 7, 80209},
	{"MACROSCOPIC", 11, 80210},
	{"VISCOUNT", 8, 80211},
	{"TORRINGTON", 10, 80212},
	{"GILLINGHAM", 10, 80213},
	{"PRELIMINARIES", 13, 80214},
	{"GEOPOLITICAL", 12, 80215},
	{"DEVOLVED", 8, 80216},
	{"LIQUEFIED", 9, 80217},
	{"FLAHERTY", 8, 80218},
	{"NPLO", 4, 80219},
	{"VARIETAL", 8, 80220},
	{"ALCATRAZ", 8, 80221},
	{"WOGU", 4, 80222},
	{"MUNO", 4, 80223},
	{"ENGLE", 5, 80224},
	{"STREAMED", 8, 80225},
	{"GORILLAS", 8, 80226},
	{"FFSB", 4, 80227},
	{"RESORTING", 9, 80228},
	{"SHATNER", 7, 80229},
	{"PWEL", 4, 80230},
	{"IGHJ", 4, 80231},
	{"GARTERS", 7, 80232},
	{"JUAREZ", 6, 80233},
	{"OPAK", 4, 80234},
	{"ADAMANT", 7, 80235},
	{"PONTOON", 7, 80236},
	{"URYG", 4, 80237},
	{"TAYC", 4, 80238},
	{"NHYD", 4, 80239},
	{"EYEF", 4, 80240},
	{"HELICOBACTER", 12, 80241},
	{"EPIDURAL", 8, 80242},
	{"LUISA", 5, 80243},
	{"TEARDROP", 8, 80244},
	{"TABLEAU", 7, 80245},
	{"BUYH", 4, 80246},
	{"GLOSSPOST", 9, 80247},
	{"NUMERAL", 7, 80248},
	{"MDX", 3, 80249},
	{"ORTHODONTICS", 12, 80250},
	{"YAIM", 4, 80251},
	{"WFOO", 4, 80252},
	{"TZMA", 4, 80253},
	{"OWHU", 4, 80254},
	{"LGAD", 4, 80255},
	{"AMCR", 4, 80256},
	{"VERNAL", 6, 80257},
	{"TABBY", 5, 80258},
	{"CYNGOR", 6, 80259},
	{"CLADDAGH", 8, 80260},
	{"THERM", 5, 80261},
	{"YALD", 4, 80262},
	{"UNSL", 4, 80263},
	{"ULGI", 4, 80264},
	{"UGOF", 4, 80265},
	{"RPLO", 4, 80266},
	{"PBRE", 4, 80267},
	{"GEDJ", 4, 80268},
	{"DSEG", 4, 80269},
	{"MYELOID", 7, 80270},
	{"NAPOLEONIC", 10, 80271},
	{"TENNYSON", 8, 80272},
	{"PUGS", 4, 80273},
	{"RUBICON", 7, 80274},
	{"SPROCKET", 8, 80275},
	{"NKCH", 4, 80276},
	{"UNILEVER", 8, 80277},
	{"GENOMEBROWSER", 13, 80278},
	{"WROA", 4, 80279},
	{"EPCH", 4, 80280},
	{"MACLAREN", 8, 80281},
	{"DISORDERLY", 10, 80282},
	{"CHAIRMANS", 9, 80283},
	{"WORKFLOWS", 9, 80284},
	{"YNAV", 4, 80285},
	{"RBYG", 4, 80286},
	{"ECYB", 4, 80287},
	{"CFAN", 4, 80288},
	{"ANSEL", 5, 80289},
	{"DRAGOSTEA", 9, 80290},
	{"IVANHOE", 7, 80291},
	{"HRVATSKI", 8, 80292},
	{"ZTEC", 4, 80293},
	{"YSKN", 4, 80294},
	{"UESY", 4, 80295},
	{"PLUC", 4, 80296},
	{"KAMB", 4, 80297},
	{"DESTROYERS", 10, 80298},
	{"AYALA", 5, 80299},
	{"BFG", 3, 80300},
	{"ANALOGIES", 9, 80301},
	{"TONAWANDA", 9, 80302},
	{"IMOVIE", 6, 80303},
	{"REGIONALS", 9, 80304},
	{"PSUR", 4, 80305},
	{"KAMI", 4, 80306},
	{"FRIGATE", 7, 80307},
	{"JANSPORT", 8, 80308},
	{"FANFIC", 6, 80309},
	{"NIKKEI", 6, 80310},
	{"INSTALMENT", 10, 80311},
	{"LYNNWOOD", 8, 80312},
	{"GLUCOPHAGE", 10, 80313},
	{"DAZED", 5, 80314},
	{"BICENTENNIAL", 12, 80315},
	{"RADIOLOGIC", 10, 80316},
	{"NYHU", 4, 80317},
	{"AGOSTO", 6, 80318},
	{"MINERALOGY", 10, 80319},
	{"MICV", 4, 80320},
	{"EKUN", 4, 80321},
	{"CORSICANA", 9, 80322},
	{"HARRIER", 7, 80323},
	{"SCIENCEDIRECT", 13, 80324},
	{"YZER", 4, 80325},
	{"LMWI", 4, 80326},
	{"CYLA", 4, 80327},
	{"KRUGERPARK", 10, 80328},
	{"OIREACHTAS", 10, 80329},
	{"ESPOSITO", 8, 80330},
	{"ADJUSTERS", 9, 80331},
	{"SENTIENT", 8, 80332},
	{"OLYMPIAD", 8, 80333},
	{"FNAME", 5, 80334},
	{"ALLENDE", 7, 80335},
	{"CKVE", 4, 80336},
	{"LDC", 3, 80337},
	{"SITED", 5, 80338},
	{"ENTRUST", 7, 80339},
	{"SURRY", 5, 80340},
	{"STRAINER", 8, 80341},
	{"YATD", 4, 80342},
	{"VIEM", 4, 80343},
	{"MSYO", 4, 80344},
	{"DFAU", 4, 80345},
	{"AAPR", 4, 80346},
	{"PARAGLIDING", 11, 80347},
	{"WHITETAIL", 9, 80348},
	{"PAGEMAKER", 9, 80349},
	{"GICD", 4, 80350},
	{"ASTRID", 6, 80351},
	{"TRIPLED", 7, 80352},
	{"GWAR", 4, 80353},
	{"ZUJ", 3, 80354},
	{"YZV", 3, 80355},
	{"WSVI", 4, 80356},
	{"WOHU", 4, 80357},
	{"URIG", 4, 80358},
	{"RUGR", 4, 80359},
	{"IRYE", 4, 80360},
	{"IPBO", 4, 80361},
	{"PUFFS", 5, 80362},
	{"ATWATER", 7, 80363},
	{"OVERPAYMENT", 11, 80364},
	{"FAEROE", 6, 80365},
	{"WISENUT", 7, 80366},
	{"BURYING", 7, 80367},
	{"NAGEL", 5, 80368},
	{"BLATANTLY", 9, 80369},
	{"UXEM", 4, 80370},
	{"KAFO", 4, 80371},
	{"DISPATCHING", 11, 80372},
	{"PSKI", 4, 80373},
	{"KICA", 4, 80374},
	{"DIOG", 4, 80375},
	{"CTSY", 4, 80376},
	{"CHICANO", 7, 80377},
	{"CHONGQING", 9, 80378},
	{"CORPORATES", 10, 80379},
	{"APPLICATORS", 11, 80380},
	{"ERASING", 7, 80381},
	{"SVETLANA", 8, 80382},
	{"MSFE", 4, 80383},
	{"DLIL", 4, 80384},
	{"FLEER", 5, 80385},
	{"BOSSA", 5, 80386},
	{"DEUCES", 6, 80387},
	{"YDBE", 4, 80388},
	{"WRAI", 4, 80389},
	{"OFUK", 4, 80390},
	{"FUD", 3, 80391},
	{"DALIAN", 6, 80392},
	{"ANYCOM", 6, 80393},
	{"CYCLOPS", 7, 80394},
	{"GUNFIRE", 7, 80395},
	{"ULBO", 4, 80396},
	{"LOSB", 4, 80397},
	{"ALTZ", 4, 80398},
	{"VERITABLE", 9, 80399},
	{"MCNAIR", 6, 80400},
	{"SUBTILIS", 8, 80401},
	{"POSTERITY", 9, 80402},
	{"PERCUTANEOUS", 12, 80403},
	{"CURSOS", 6, 80404},
	{"ULFS", 4, 80405},
	{"OMIK", 4, 80406},
	{"ESMR", 4, 80407},
	{"COLS", 4, 80408},
	{"URTH", 4, 80409},
	{"NORTHBROOK", 10, 80410},
	{"KEENLY", 6, 80411},
	{"RMK", 3, 80412},
	{"GVEH", 4, 80413},
	{"EDHY", 4, 80414},
	{"MGF", 3, 80415},
	{"HEALTHFUL", 9, 80416},
	{"VOLI", 4, 80417},
	{"LEANN", 5, 80418},
	{"OGYN", 4, 80419},
	{"CESQ", 4, 80420},
	{"MEINE", 5, 80421},
	{"REPEALING", 9, 80422},
	{"PIXMAPS", 7, 80423},
	{"GOURD", 5, 80424},
	{"GIGABLAST", 9, 80425},
	{"METRONOME", 9, 80426},
	{"KPIL", 4, 80427},
	{"FBIT", 4, 80428},
	{"GROANED", 7, 80429},
	{"FEROCIOUS", 9, 80430},
	{"BLACKMAN", 8, 80431},
	{"OBYA", 4, 80432},
	{"VOICING", 7, 80433},
	{"FLIERS", 6, 80434},
	{"RDBMS", 5, 80435},
	{"HYLI", 4, 80436},
	{"ERYJ", 4, 80437},
	{"IMPRIMIR", 8, 80438},
	{"GROUPER", 7, 80439},
	{"NEGATE", 6, 80440},
	{"SACRIFICIAL", 11, 80441},
	{"ROESSLER", 8, 80442},
	{"RGEU", 4, 80443},
	{"EPBE", 4, 80444},
	{"DEFIES", 6, 80445},
	{"INTRASTATE", 10, 80446},
	{"MANAWATU", 8, 80447},
	{"BLASS", 5, 80448},
	{"HEVY", 4, 80449},
	{"AINSWORTH", 9, 80450},
	{"ABNORMALLY", 10, 80451},
	{"DENZEL", 6, 80452},
	{"WTAK", 4, 80453},
	{"ONUC", 4, 80454},
	{"IRMH", 4, 80455},
	{"FPHA", 4, 80456},
	{"EWFL", 4, 80457},
	{"BPAR", 4, 80458},
	{"MOPED", 5, 80459},
	{"RESUMING", 8, 80460},
	{"APPOINTEES", 10, 80461},
	{"BRUISING", 8, 80462},
	{"BUNKERS", 7, 80463},
	{"SPHD", 4, 80464},
	{"RDIP", 4, 80465},
	{"REFRIGERATE", 11, 80466},
	{"LIGASE", 6, 80467},
	{"MBUD", 4, 80468},
	{"FBOD", 4, 80469},
	{"CTFE", 4, 80470},
	{"ALMC", 4, 80471},
	{"FLOGGING", 8, 80472},
	{"RELIGIOUSLY", 11, 80473},
	{"BELEIVE", 7, 80474},
	{"MUNDI", 5, 80475},
	{"WARLORDS", 8, 80476},
	{"SJOK", 4, 80477},
	{"RKOW", 4, 80478},
	{"OXWA", 4, 80479},
	{"OMUP", 4, 80480},
	{"LIPB", 4, 80481},
	{"FWHY", 4, 80482},
	{"EXXO", 4, 80483},
	{"DIZZ", 4, 80484},
	{"HATTERAS", 8, 80485},
	{"SYMLINK", 7, 80486},
	{"ENCROACHMENT", 12, 80487},
	{"ALMEIDA", 7, 80488},
	{"DEMANDE", 7, 80489},
	{"BLOGCRITICS", 11, 80490},
	{"COCHLEAR", 8, 80491},
	{"SEABOARD", 8, 80492},
	{"YCEM", 4, 80493},
	{"SUEM", 4, 80494},
	{"GSGR", 4, 80495},
	{"JANELLE", 7, 80496},
	{"ALPHABETS", 9, 80497},
	{"FOLDABLE", 8, 80498},
	{"USVO", 4, 80499},
	{"DCUF", 4, 80500},
	{"LAPLACE", 7, 80501},
	{"HYDROPONICS", 11, 80502},
	{"PRECAST", 7, 80503},
	{"UNIVER", 6, 80504},
	{"PUREST", 6, 80505},
	{"SOUTHERLY", 9, 80506},
	{"UPMY", 4, 80507},
	{"BEIG", 4, 80508},
	{"FATBOY", 6, 80509},
	{"HUMILIATED", 10, 80510},
	{"UNEARTHED", 9, 80511},
	{"GCRU", 4, 80512},
	{"FLEO", 4, 80513},
	{"CATARACTS", 9, 80514},
	{"WDON", 4, 80515},
	{"UETW", 4, 80516},
	{"SKRA", 4, 80517},
	{"WESTERNERS", 10, 80518},
	{"CAMARILLO", 9, 80519},
	{"KELTY", 5, 80520},
	{"ODFL", 4, 80521},
	{"VOLUNTEERISM", 12, 80522},
	{"SUBORDINATES", 12, 80523},
	{"PDQ", 3, 80524},
	{"OPENACS", 7, 80525},
	{"GOTG", 4, 80526},
	{"NEWHAM", 6, 80527},
	{"ENERGIE", 7, 80528},
	{"RADIOGRAPHIC", 12, 80529},
	{"KINEMATICS", 10, 80530},
	{"ERROL", 5, 80531},
	{"VAGABOND", 8, 80532},
	{"UYSC", 4, 80533},
	{"PSAF", 4, 80534},
	{"NRYH", 4, 80535},
	{"OTABLETEST", 10, 80536},
	{"ISOBARIC", 8, 80537},
	{"YIRE", 4, 80538},
	{"NIFW", 4, 80539},
	{"GEAU", 4, 80540},
	{"FAPU", 4, 80541},
	{"DHAU", 4, 80542},
	{"GRATUITOS", 9, 80543},
	{"LFAP", 4, 80544},
	{"GPLE", 4, 80545},
	{"PERSONALISE", 11, 80546},
	{"CONSECRATED", 11, 80547},
	{"UANP", 4, 80548},
	{"SBIK", 4, 80549},
	{"IUSP", 4, 80550},
	{"OSCILLATING", 11, 80551},
	{"PATENTING", 9, 80552},
	{"RECIPROCATING", 13, 80553},
	{"WFEE", 4, 80554},
	{"LONR", 4, 80555},
	{"SUBCELLULAR", 11, 80556},
	{"BODICE", 6, 80557},
	{"RUER", 4, 80558},
	{"RDYS", 4, 80559},
	{"FORAY", 5, 80560},
	{"MOMM", 4, 80561},
	{"GLAK", 4, 80562},
	{"OPIATE", 6, 80563},
	{"CROSBIE", 7, 80564},
	{"CRISTAL", 7, 80565},
	{"HARMONISATION", 13, 80566},
	{"DUNFERMLINE", 11, 80567},
	{"JANESVILLE", 10, 80568},
	{"UNMISTAKABLE", 12, 80569},
	{"EGROUPWARE", 10, 80570},
	{"CARITAS", 7, 80571},
	{"YAKU", 4, 80572},
	{"WSFI", 4, 80573},
	{"EGYW", 4, 80574},
	{"LWK", 3, 80575},
	{"FILLY", 5, 80576},
	{"RHUBARB", 7, 80577},
	{"DEBHELPER", 9, 80578},
	{"NSAIDS", 6, 80579},
	{"GUYO", 4, 80580},
	{"MILT", 4, 80581},
	{"SILENCING", 9, 80582},
	{"BURLESON", 8, 80583},
	{"FTSW", 4, 80584},
	{"RAGTIME", 7, 80585},
	{"ADOPTERS", 8, 80586},
	{"IMPOR", 5, 80587},
	{"PHILO", 5, 80588},
	{"WUNG", 4, 80589},
	{"AESOP", 5, 80590},
	{"BACKSEATBANGERS", 15, 80591},
	{"RUSHVILLE", 9, 80592},
	{"SAITEK", 6, 80593},
	{"SYNTHESIZERS", 12, 80594},
	{"YOBT", 4, 80595},
	{"OKSR", 4, 80596},
	{"MASV", 4, 80597},
	{"ACYM", 4, 80598},
	{"ARAPAHOE", 8, 80599},
	{"POSEY", 5, 80600},
	{"MINUTEMAN", 9, 80601},
	{"DIMINISHES", 10, 80602},
	{"ZINFANDEL", 9, 80603},
	{"MAYORAL", 7, 80604},
	{"FORTIS", 6, 80605},
	{"MEDICINA", 8, 80606},
	{"LNAR", 4, 80607},
	{"DYSL", 4, 80608},
	{"ACAF", 4, 80609},
	{"GALLARY", 7, 80610},
	{"TIDINGS", 7, 80611},
	{"SNEAKING", 8, 80612},
	{"HONEYS", 6, 80613},
	{"PINUS", 5, 80614},
	{"ORYV", 4, 80615},
	{"DMAU", 4, 80616},
	{"CKEE", 4, 80617},
	{"INTERLINK", 9, 80618},
	{"UNASSISTED", 10, 80619},
	{"GREENING", 8, 80620},
	{"INSIDIOUS", 9, 80621},
	{"XEDF", 4, 80622},
	{"ONYU", 4, 80623},
	{"TESOL", 5, 80624},
	{"ARTNET", 6, 80625},
	{"DIKE", 4, 80626},
	{"CRW", 3, 80627},
	{"IMMUTABLE", 9, 80628},
	{"BANSKO", 6, 80629},
	{"BRIEN", 5, 80630},
	{"LIGR", 4, 80631},
	{"SILVERY", 7, 80632},
	{"CROTON", 6, 80633},
	{"DEPOTS", 6, 80634},
	{"GUEVARA", 7, 80635},
	{"WSIM", 4, 80636},
	{"OBOM", 4, 80637},
	{"NMAU", 4, 80638},
	{"EMGE", 4, 80639},
	{"NODDING", 7, 80640},
	{"THINKIN", 7, 80641},
	{"SEDU", 4, 80642},
	{"YALH", 4, 80643},
	{"KBLU", 4, 80644},
	{"FLEV", 4, 80645},
	{"JASMIN", 6, 80646},
	{"AUTOMAKERS", 10, 80647},
	{"LIBRI", 5, 80648},
	{"IGMP", 4, 80649},
	{"OBWH", 4, 80650},
	{"IWRI", 4, 80651},
	{"EFTG", 4, 80652},
	{"AVIK", 4, 80653},
	{"MISREPRESENTED", 14, 80654},
	{"OVERTAKE", 8, 80655},
	{"RIDC", 4, 80656},
	{"OXBU", 4, 80657},
	{"LMIX", 4, 80658},
	{"DGIF", 4, 80659},
	{"AMICI", 5, 80660},
	{"SEMICOLON", 9, 80661},
	{"BUBBLY", 6, 80662},
	{"EDWARDSVILLE", 12, 80663},
	{"TQUO", 4, 80664},
	{"OOPR", 4, 80665},
	{"NQUO", 4, 80666},
	{"SUBSTANTIATE", 12, 80667},
	{"XSER", 4, 80668},
	{"MDAV", 4, 80669},
	{"ALGIERS", 7, 80670},
	{"QUES", 4, 80671},
	{"HOMEBUYER", 9, 80672},
	{"NODAL", 5, 80673},
	{"TEMPLAR", 7, 80674},
	{"GICF", 4, 80675},
	{"FWAN", 4, 80676},
	{"SABD", 4, 80677},
	{"RZAN", 4, 80678},
	{"RKSN", 4, 80679},
	{"OOMY", 4, 80680},
	{"NTGL", 4, 80681},
	{"UNBEATEN", 8, 80682},
	{"UNFE", 4, 80683},
	{"RUPF", 4, 80684},
	{"LRYW", 4, 80685},
	{"FDUN", 4, 80686},
	{"RAWLS", 5, 80687},
	{"CEDARS", 6, 80688},
	{"FORTITUDE", 9, 80689},
	{"ALOFT", 5, 80690},
	{"WSUN", 4, 80691},
	{"SPUP", 4, 80692},
	{"PICM", 4, 80693},
	{"PHKM", 4, 80694},
	{"DVIT", 4, 80695},
	{"SHEETING", 8, 80696},
	{"TYAU", 4, 80697},
	{"RUEH", 4, 80698},
	{"HALLWAYS", 8, 80699},
	{"MATED", 5, 80700},
	{"WART", 4, 80701},
	{"FDIE", 4, 80702},
	{"BTFU", 4, 80703},
	{"ALZHEIMERS", 10, 80704},
	{"SNOOZE", 6, 80705},
	{"TRIBUS", 6, 80706},
	{"HOLLANDER", 9, 80707},
	{"KESTREL", 7, 80708},
	{"MLAW", 4, 80709},
	{"INYB", 4, 80710},
	{"FNAR", 4, 80711},
	{"EPGO", 4, 80712},
	{"CEID", 4, 80713},
	{"AKSD", 4, 80714},
	{"AMERICORPS", 10, 80715},
	{"PRAWNS", 6, 80716},
	{"NONPARTISAN", 11, 80717},
	{"UECU", 4, 80718},
	{"LDOZ", 4, 80719},
	{"IPSR", 4, 80720},
	{"DESV", 4, 80721},
	{"AZIG", 4, 80722},
	{"RUFFLED", 7, 80723},
	{"DOMINA", 6, 80724},
	{"ARMAMENT", 8, 80725},
	{"UEEX", 4, 80726},
	{"STYC", 4, 80727},
	{"ELDON", 5, 80728},
	{"PLUMS", 5, 80729},
	{"PALOMAR", 7, 80730},
	{"REVISITING", 10, 80731},
	{"RIEDEL", 6, 80732},
	{"FAIRER", 6, 80733},
	{"HOPPERS", 7, 80734},
	{"UMEF", 4, 80735},
	{"NVEG", 4, 80736},
	{"APPH", 4, 80737},
	{"ONSCREEN", 8, 80738},
	{"GDK", 3, 80739},
	{"DISTILLERS", 10, 80740},
	{"ENTERPRISING", 12, 80741},
	{"UPLOADER", 8, 80742},
	{"CALTRANS", 8, 80743},
	{"TYRA", 4, 80744},
	{"UISD", 4, 80745},
	{"PSMI", 4, 80746},
	{"ORUB", 4, 80747},
	{"AULG", 4, 80748},
	{"MTBE", 4, 80749},
	{"HYPERTENSIVE", 12, 80750},
	{"NDYD", 4, 80751},
	{"CHINCHILLA", 10, 80752},
	{"BUCS", 4, 80753},
	{"TRANSFORMATIONAL", 16, 80754},
	{"SAILBOATS", 9, 80755},
	{"HEISMAN", 7, 80756},
	{"PRIDES", 6, 80757},
	{"VAGI", 4, 80758},
	{"EXEMPLIFIES", 11, 80759},
	{"ARRHYTHMIA", 10, 80760},
	{"ASTROMETRIC", 11, 80761},
	{"WORKWEAR", 8, 80762},
	{"ULUN", 4, 80763},
	{"RDVO", 4, 80764},
	{"ERNJ", 4, 80765},
	{"BYJI", 4, 80766},
	{"GRAFTING", 8, 80767},
	{"SMOOTHNESS", 10, 80768},
	{"TRINKET", 7, 80769},
	{"TOLSTOY", 7, 80770},
	{"ASPERGER", 8, 80771},
	{"XODU", 4, 80772},
	{"XEMB", 4, 80773},
	{"SHDU", 4, 80774},
	{"LBLE", 4, 80775},
	{"KOOP", 4, 80776},
	{"NEWYDD", 6, 80777},
	{"TRANSPOSE", 9, 80778},
	{"LPR", 3, 80779},
	{"NEUTRALIZE", 10, 80780},
	{"XRAY", 4, 80781},
	{"FERRER", 6, 80782},
	{"VASCO", 5, 80783},
	{"UWK", 3, 80784},
	{"DXK", 3, 80785},
	{"MICROECONOMICS", 14, 80786},
	{"SVUL", 4, 80787},
	{"LVEY", 4, 80788},
	{"FMOO", 4, 80789},
	{"KAFKA", 5, 80790},
	{"TELLY", 5, 80791},
	{"GRANDSTAND", 10, 80792},
	{"YSDU", 4, 80793},
	{"OYMA", 4, 80794},
	{"GHMY", 4, 80795},
	{"SLURP", 5, 80796},
	{"PLAYWRIGHTS", 11, 80797},
	{"RNOD", 4, 80798},
	{"RCUB", 4, 80799},
	{"IEWD", 4, 80800},
	{"WISHFUL", 7, 80801},
	{"ALLOCATOR", 9, 80802},
	{"ISLAS", 5, 80803},
	{"HEROD", 5, 80804},
	{"WESTLAND", 8, 80805},
	{"INSTANTIATED", 12, 80806},
	{"TRAILED", 7, 80807},
	{"HABITATION", 10, 80808},
	{"AEMP", 4, 80809},
	{"ROGUES", 6, 80810},
	{"SPEECHLESS", 10, 80811},
	{"EXPANSE", 7, 80812},
	{"LEWISBURG", 9, 80813},
	{"STYLISTS", 8, 80814},
	{"VOYS", 4, 80815},
	{"PSIL", 4, 80816},
	{"NIBU", 4, 80817},
	{"APIP", 4, 80818},
	{"AKPA", 4, 80819},
	{"BLACKWATER", 10, 80820},
	{"VIVI", 4, 80821},
	{"HIPPIES", 7, 80822},
	{"PRESIDE", 7, 80823},
	{"PUL", 3, 80824},
	{"WSAF", 4, 80825},
	{"OGEL", 4, 80826},
	{"BAFT", 4, 80827},
	{"LARKSPUR", 8, 80828},
	{"ARLES", 5, 80829},
	{"COLETTE", 7, 80830},
	{"DELIGHTFULLY", 12, 80831},
	{"MOTHERWELL", 10, 80832},
	{"OEUVRES", 7, 80833},
	{"YITR", 4, 80834},
	{"LACQ", 4, 80835},
	{"CAPPELLA", 8, 80836},
	{"NEOCON", 6, 80837},
	{"GETNAME", 7, 80838},
	{"COYLE", 5, 80839},
	{"UCTM", 4, 80840},
	{"TUPL", 4, 80841},
	{"RDOY", 4, 80842},
	{"RUDI", 4, 80843},
	{"DEPARTAMENTO", 12, 80844},
	{"WINRAR", 6, 80845},
	{"MUSSEL", 6, 80846},
	{"PCUL", 4, 80847},
	{"LPLO", 4, 80848},
	{"CONCEALMENT", 11, 80849},
	{"BRITAX", 6, 80850},
	{"DIWALI", 6, 80851},
	{"RAINES", 6, 80852},
	{"WYSE", 4, 80853},
	{"GEOURL", 6, 80854},
	{"YENR", 4, 80855},
	{"LEXU", 4, 80856},
	{"ETHERIDGE", 9, 80857},
	{"DOCOMO", 6, 80858},
	{"WEBINDEX", 8, 80859},
	{"UNRULY", 6, 80860},
	{"ACCREDITING", 11, 80861},
	{"KISG", 4, 80862},
	{"ITZW", 4, 80863},
	{"STAPLER", 7, 80864},
	{"PHEROMONES", 10, 80865},
	{"WOODSON", 7, 80866},
	{"VOLCOM", 6, 80867},
	{"TELEWEST", 8, 80868},
	{"NREJ", 4, 80869},
	{"DKIS", 4, 80870},
	{"LCP", 3, 80871},
	{"OZZIE", 5, 80872},
	{"KITSAP", 6, 80873},
	{"CUTEST", 6, 80874},
	{"TZWA", 4, 80875},
	{"GAGU", 4, 80876},
	{"UNCOMPROMISING", 14, 80877},
	{"MORIARTY", 8, 80878},
	{"OBSTRUCT", 8, 80879},
	{"UNBOUNDED", 9, 80880},
	{"COINCIDED", 9, 80881},
	{"MPP", 3, 80882},
	{"DYMO", 4, 80883},
	{"YOLO", 4, 80884},
	{"UCTB", 4, 80885},
	{"RIRO", 4, 80886},
	{"RFAU", 4, 80887},
	{"BEDC", 4, 80888},
	{"QUINTON", 7, 80889},
	{"ENCASED", 7, 80890},
	{"UNDERTAKER", 10, 80891},
	{"JORGENSEN", 9, 80892},
	{"PRINTOUTS", 9, 80893},
	{"FLICKERING", 10, 80894},
	{"ALIQ", 4, 80895},
	{"TEMPT", 5, 80896},
	{"CREDENTIALING", 13, 80897},
	{"SCALLOPED", 9, 80898},
	{"SEALEY", 6, 80899},
	{"GALVIN", 6, 80900},
	{"WSLO", 4, 80901},
	{"TFOX", 4, 80902},
	{"LIEL", 4, 80903},
	{"KOWI", 4, 80904},
	{"FSLI", 4, 80905},
	{"ARJE", 4, 80906},
	{"ETUDES", 6, 80907},
	{"GURNEY", 6, 80908},
	{"BLUEFLY", 7, 80909},
	{"GUSH", 4, 80910},
	{"SCHWEITZER", 10, 80911},
	{"SADDENED", 8, 80912},
	{"JAWA", 4, 80913},
	{"GEOCHEMICAL", 11, 80914},
	{"ALLEGANY", 8, 80915},
	{"EPTG", 4, 80916},
	{"ALDRIDGE", 8, 80917},
	{"DIGITIZING", 10, 80918},
	{"ORGANICALLY", 11, 80919},
	{"CYLO", 4, 80920},
	{"ARLM", 4, 80921},
	{"AFUM", 4, 80922},
	{"CHATBOARD", 9, 80923},
	{"BATHE", 5, 80924},
	{"LOMB", 4, 80925},
	{"WEXC", 4, 80926},
	{"SCARRED", 7, 80927},
	{"UDDI", 4, 80928},
	{"UANY", 4, 80929},
	{"DOMN", 4, 80930},
	{"AWNW", 4, 80931},
	{"ROLEPLAY", 8, 80932},
	{"IGNITED", 7, 80933},
	{"PAVILLION", 9, 80934},
	{"CROWDING", 8, 80935},
	{"BARSTOW", 7, 80936},
	{"JOEW", 4, 80937},
	{"GODC", 4, 80938},
	{"PATNA", 5, 80939},
	{"ROOTKIT", 7, 80940},
	{"SPEARHEAD", 9, 80941},
	{"MFUN", 4, 80942},
	{"FATC", 4, 80943},
	{"LEONID", 6, 80944},
	{"SUNNIS", 6, 80945},
	{"RETICULUM", 9, 80946},
	{"DULCIMER", 8, 80947},
	{"MBIO", 4, 80948},
	{"KALMAN", 6, 80949},
	{"VROUW", 5, 80950},
	{"CORONAL", 7, 80951},
	{"RENDELL", 7, 80952},
	{"TRANSPARENTLY", 13, 80953},
	{"UBUY", 4, 80954},
	{"DAKN", 4, 80955},
	{"FREEFORM", 8, 80956},
	{"GIANFRANCO", 10, 80957},
	{"TANTRIC", 7, 80958},
	{"IGOL", 4, 80959},
	{"REIF", 4, 80960},
	{"WOODHOUSE", 9, 80961},
	{"GLADIATORS", 10, 80962},
	{"LIFTER", 6, 80963},
	{"KREBS", 5, 80964},
	{"SEYMORE", 7, 80965},
	{"OGLE", 4, 80966},
	{"SAYIN", 5, 80967},
	{"CPAS", 4, 80968},
	{"STODDARD", 8, 80969},
	{"VIDEOGRAPHER", 12, 80970},
	{"SCROOGE", 7, 80971},
	{"WFAM", 4, 80972},
	{"ODOV", 4, 80973},
	{"FNEX", 4, 80974},
	{"STALLONE", 8, 80975},
	{"UAMS", 4, 80976},
	{"PULA", 4, 80977},
	{"AEROPLANE", 9, 80978},
	{"TRUDEAU", 7, 80979},
	{"BUSS", 4, 80980},
	{"OUEST", 5, 80981},
	{"REKS", 4, 80982},
	{"MYVO", 4, 80983},
	{"MIOF", 4, 80984},
	{"BALG", 4, 80985},
	{"NAGGING", 7, 80986},
	{"KORNER", 6, 80987},
	{"FATHERHOOD", 10, 80988},
	{"DEBUSSY", 7, 80989},
	{"REFLEXES", 8, 80990},
	{"OPYA", 4, 80991},
	{"OLFW", 4, 80992},
	{"MCGO", 4, 80993},
	{"LFWO", 4, 80994},
	{"CAWE", 4, 80995},
	{"AGIG", 4, 80996},
	{"CONTEMPORANEOUS", 15, 80997},
	{"WYMAN", 5, 80998},
	{"KINGSPORT", 9, 80999},
	{"YLVI", 4, 81000},
	{"YGIE", 4, 81001},
	{"VOMI", 4, 81002},
	{"RRAA", 4, 81003},
	{"OBBU", 4, 81004},
	{"HIFF", 4, 81005},
	{"PRECIPITATED", 12, 81006},
	{"OUTLAWED", 8, 81007},
	{"GAUTHIER", 8, 81008},
	{"INJURING", 8, 81009},
	{"MLOW", 4, 81010},
	{"HOMU", 4, 81011},
	{"FOXF", 4, 81012},
	{"VADIM", 5, 81013},
	{"BELLOW", 6, 81014},
	{"MAGNETIZATION", 13, 81015},
	{"GIRTH", 5, 81016},
	{"MDUN", 4, 81017},
	{"AITKEN", 6, 81018},
	{"MILLERS", 7, 81019},
	{"TITTED", 6, 81020},
	{"CLERICS", 7, 81021},
	{"POPPIES", 7, 81022},
	{"INLAID", 6, 81023},
	{"BUSSES", 6, 81024},
	{"NOTCHED", 7, 81025},
	{"UNDERPIN", 8, 81026},
	{"BALDNESS", 8, 81027},
	{"DUMBLEDORE", 10, 81028},
	{"DIDACTIC", 8, 81029},
	{"ADLU", 4, 81030},
	{"LILLIE", 6, 81031},
	{"VINNY", 5, 81032},
	{"DELICATELY", 10, 81033},
	{"YMZ", 3, 81034},
	{"WEBROOT", 7, 81035},
	{"PRODUCTI", 8, 81036},
	{"TEKSTY", 6, 81037},
	{"IRRITABILITY", 12, 81038},
	{"PULLOUT", 7, 81039},
	{"IMFE", 4, 81040},
	{"GPIL", 4, 81041},
	{"GDIE", 4, 81042},
	{"EMUG", 4, 81043},
	{"YELLOWCARD", 10, 81044},
	{"OKWE", 4, 81045},
	{"NZIM", 4, 81046},
	{"LCIU", 4, 81047},
	{"IDCI", 4, 81048},
	{"PROVOCATION", 11, 81049},
	{"LUSTROUS", 8, 81050},
	{"REELING", 7, 81051},
	{"BIRDHOUSE", 9, 81052},
	{"UEDM", 4, 81053},
	{"MIKH", 4, 81054},
	{"CHILLICOTHE", 11, 81055},
	{"PEACEKEEPERS", 12, 81056},
	{"DESERTIFICATION", 15, 81057},
	{"SCHMITZ", 7, 81058},
	{"YKEL", 4, 81059},
	{"RTVE", 4, 81060},
	{"LCIN", 4, 81061},
	{"EWFU", 4, 81062},
	{"DYAB", 4, 81063},
	{"RENNES", 6, 81064},
	{"CRESTS", 6, 81065},
	{"SOLENT", 6, 81066},
	{"MOLTO", 5, 81067},
	{"EAPF", 4, 81068},
	{"PROPYLENE", 9, 81069},
	{"LOAFERS", 7, 81070},
	{"SUPERCROSS", 10, 81071},
	{"MULTNOMAH", 9, 81072},
	{"FOXCONN", 7, 81073},
	{"FUELLED", 7, 81074},
	{"BIOHAZARD", 9, 81075},
	{"OGIL", 4, 81076},
	{"NGKU", 4, 81077},
	{"IDTW", 4, 81078},
	{"AOFG", 4, 81079},
	{"SLAPPING", 8, 81080},
	{"HORRIFYING", 10, 81081},
	{"PARQUE", 6, 81082},
	{"TOFFEE", 6, 81083},
	{"FPL", 3, 81084},
	{"RIEMANN", 7, 81085},
	{"RNOP", 4, 81086},
	{"IDOV", 4, 81087},
	{"AKUN", 4, 81088},
	{"SQUIRES", 7, 81089},
	{"INSURES", 7, 81090},
	{"SLAYING", 7, 81091},
	{"MAHATMA", 7, 81092},
	{"MUBARAK", 7, 81093},
	{"BACHMANN", 8, 81094},
	{"CASWELL", 7, 81095},
	{"CHIRON", 6, 81096},
	{"OLGI", 4, 81097},
	{"HTDR", 4, 81098},
	{"HAILEY", 6, 81099},
	{"PIPPIN", 6, 81100},
	{"FRAUDS", 6, 81101},
	{"RAMALLAH", 8, 81102},
	{"ISOFORMS", 8, 81103},
	{"DICTYOSTELIUM", 13, 81104},
	{"TAURANGA", 8, 81105},
	{"HAWKEYES", 8, 81106},
	{"MAXXUM", 6, 81107},
	{"KNOWIT", 6, 81108},
	{"SFAB", 4, 81109},
	{"MPGR", 4, 81110},
	{"GNWO", 4, 81111},
	{"GESK", 4, 81112},
	{"AWSP", 4, 81113},
	{"TOPANGA", 7, 81114},
	{"GELLER", 6, 81115},
	{"PARLIAMENTARIANS", 16, 81116},
	{"YTAB", 4, 81117},
	{"FTUS", 4, 81118},
	{"INADVERTENT", 11, 81119},
	{"EGYF", 4, 81120},
	{"DYHI", 4, 81121},
	{"BOARDMAN", 8, 81122},
	{"DENHAM", 6, 81123},
	{"LOBES", 5, 81124},
	{"ROFL", 4, 81125},
	{"WINCHES", 7, 81126},
	{"YANL", 4, 81127},
	{"OKDO", 4, 81128},
	{"MMEC", 4, 81129},
	{"BASQ", 4, 81130},
	{"UPTODATE", 8, 81131},
	{"CENTRALIA", 9, 81132},
	{"ESCHATON", 8, 81133},
	{"HOAXES", 6, 81134},
	{"HILLINGDON", 10, 81135},
	{"TGLE", 4, 81136},
	{"BUBLE", 5, 81137},
	{"HAIRSPRAY", 9, 81138},
	{"ACDSEE", 6, 81139},
	{"OFFERTE", 7, 81140},
	{"URB", 3, 81141},
	{"INTELLICAST", 11, 81142},
	{"THUNDERING", 10, 81143},
	{"FRC", 3, 81144},
	{"REMUS", 5, 81145},
	{"MCOV", 4, 81146},
	{"EVSK", 4, 81147},
	{"DUNH", 4, 81148},
	{"DSVE", 4, 81149},
	{"ANTISENSE", 9, 81150},
	{"COALS", 5, 81151},
	{"SUCCULENT", 9, 81152},
	{"HEARTILY", 8, 81153},
	{"PELOSI", 6, 81154},
	{"SHADER", 6, 81155},
	{"RYOC", 4, 81156},
	{"RBSI", 4, 81157},
	{"KESK", 4, 81158},
	{"GISBORNE", 8, 81159},
	{"YELLOWISH", 9, 81160},
	{"GRAFTS", 6, 81161},
	{"UNSUCCESSFULLY", 14, 81162},
	{"HILLBILLY", 9, 81163},
	{"INTIFADA", 8, 81164},
	{"NYID", 4, 81165},
	{"GFLE", 4, 81166},
	{"FEBT", 4, 81167},
	{"MODERNE", 7, 81168},
	{"CARINA", 6, 81169},
	{"RRHA", 4, 81170},
	{"RKMI", 4, 81171},
	{"PISB", 4, 81172},
	{"LPSP", 4, 81173},
	{"BRUNEL", 6, 81174},
	{"MOUSTACHE", 9, 81175},
	{"ROALD", 5, 81176},
	{"EXTERNALITIES", 13, 81177},
	{"METZGER", 7, 81178},
	{"LOBSTERS", 8, 81179},
	{"BALSAMIC", 8, 81180},
	{"CLASSICALLY", 11, 81181},
	{"RAQT", 4, 81182},
	{"KSPU", 4, 81183},
	{"FOXW", 4, 81184},
	{"DDSW", 4, 81185},
	{"CESJ", 4, 81186},
	{"EVENTFUL", 8, 81187},
	{"CALORIMETER", 11, 81188},
	{"NECKED", 6, 81189},
	{"IDIOPATHIC", 10, 81190},
	{"ITZP", 4, 81191},
	{"HJOB", 4, 81192},
	{"ANUK", 4, 81193},
	{"LILEKS", 6, 81194},
	{"TAHOMA", 6, 81195},
	{"FEASTS", 6, 81196},
	{"STILETTO", 8, 81197},
	{"YEBR", 4, 81198},
	{"LTIG", 4, 81199},
	{"KPOT", 4, 81200},
	{"IGLA", 4, 81201},
	{"EKDE", 4, 81202},
	{"EDSG", 4, 81203},
	{"UNIDIRECTIONAL", 14, 81204},
	{"WESTBOUND", 9, 81205},
	{"TEACUP", 6, 81206},
	{"REBEKAH", 7, 81207},
	{"NYOB", 4, 81208},
	{"LAYLA", 5, 81209},
	{"GALERIES", 8, 81210},
	{"CABINETRY", 9, 81211},
	{"OUCR", 4, 81212},
	{"NDYK", 4, 81213},
	{"MPTB", 4, 81214},
	{"SUAREZ", 6, 81215},
	{"UMEE", 4, 81216},
	{"RTBL", 4, 81217},
	{"PBOO", 4, 81218},
	{"JORU", 4, 81219},
	{"ALVARADO", 8, 81220},
	{"STIPULATES", 10, 81221},
	{"TOWERTALK", 9, 81222},
	{"SECESSION", 9, 81223},
	{"OPTIMIZES", 9, 81224},
	{"MGEO", 4, 81225},
	{"GACU", 4, 81226},
	{"SERIALIZABLE", 12, 81227},
	{"UNIVERSITE", 10, 81228},
	{"RINGSURF", 8, 81229},
	{"COUNTERED", 9, 81230},
	{"TOQUES", 6, 81231},
	{"BBCN", 4, 81232},
	{"RAYLEIGH", 8, 81233},
	{"INSTINCTIVELY", 13, 81234},
	{"DROPOUTS", 8, 81235},
	{"CONSPIRACIES", 12, 81236},
	{"TRUB", 4, 81237},
	{"CHAPELS", 7, 81238},
	{"GAZPROM", 7, 81239},
	{"BRADEN", 6, 81240},
	{"WPUB", 4, 81241},
	{"LTYR", 4, 81242},
	{"KBOA", 4, 81243},
	{"JASM", 4, 81244},
	{"SINUSITIS", 9, 81245},
	{"RUSK", 4, 81246},
	{"FRACTALS", 8, 81247},
	{"DEPRESSANTS", 11, 81248},
	{"CLEC", 4, 81249},
	{"TRYOUTS", 7, 81250},
	{"GRADO", 5, 81251},
	{"RUSHMORE", 8, 81252},
	{"MINIONS", 7, 81253},
	{"ADAPTS", 6, 81254},
	{"FARLEX", 6, 81255},
	{"EMAC", 4, 81256},
	{"BRUNT", 5, 81257},
	{"UBIA", 4, 81258},
	{"RPSW", 4, 81259},
	{"OSCU", 4, 81260},
	{"OFEB", 4, 81261},
	{"KIRC", 4, 81262},
	{"INFRACTION", 10, 81263},
	{"GORY", 4, 81264},
	{"GLENS", 5, 81265},
	{"XKG", 3, 81266},
	{"UJK", 3, 81267},
	{"STRANGEST", 9, 81268},
	{"UPES", 4, 81269},
	{"FGIR", 4, 81270},
	{"STAGNATION", 10, 81271},
	{"DISPLACE", 8, 81272},
	{"WILB", 4, 81273},
	{"UMAM", 4, 81274},
	{"TEWW", 4, 81275},
	{"REMAX", 5, 81276},
	{"WIZBANG", 7, 81277},
	{"COUNTRYMEN", 10, 81278},
	{"ENDNOTES", 8, 81279},
	{"YISJ", 4, 81280},
	{"OYSG", 4, 81281},
	{"FTAU", 4, 81282},
	{"RODMAN", 6, 81283},
	{"DISSIDENTS", 10, 81284},
	{"ITERATE", 7, 81285},
	{"CONAIR", 6, 81286},
	{"EMBER", 5, 81287},
	{"NEOLITHIC", 9, 81288},
	{"YASG", 4, 81289},
	{"RMEG", 4, 81290},
	{"LIOC", 4, 81291},
	{"PERISHABLE", 10, 81292},
	{"LYRA", 4, 81293},
	{"MGX", 3, 81294},
	{"WFRA", 4, 81295},
	{"VOLN", 4, 81296},
	{"DELN", 4, 81297},
	{"ACUVUE", 6, 81298},
	{"VETOED", 6, 81299},
	{"URUGUAYAN", 9, 81300},
	{"CORRIGAN", 8, 81301},
	{"LIBXML", 6, 81302},
	{"LIOG", 4, 81303},
	{"ICJU", 4, 81304},
	{"BHUT", 4, 81305},
	{"GUSTAVE", 7, 81306},
	{"XTSU", 4, 81307},
	{"HOWJ", 4, 81308},
	{"PROTEUS", 7, 81309},
	{"ETRONICS", 8, 81310},
	{"SIMIAN", 6, 81311},
	{"ATMOS", 5, 81312},
	{"DENOTING", 8, 81313},
	{"GENP", 4, 81314},
	{"APIECE", 6, 81315},
	{"JEANIE", 6, 81316},
	{"STRASSE", 7, 81317},
	{"GAMMON", 6, 81318},
	{"UFFM", 4, 81319},
	{"SMYB", 4, 81320},
	{"AEFF", 4, 81321},
	{"MULTIMODE", 9, 81322},
	{"TEENSFORCASH", 12, 81323},
	{"SUNBURY", 7, 81324},
	{"GIRARDEAU", 9, 81325},
	{"RTSV", 4, 81326},
	{"RMNE", 4, 81327},
	{"PCHE", 4, 81328},
	{"NKDR", 4, 81329},
	{"DBG", 3, 81330},
	{"MORRISVILLE", 11, 81331},
	{"STORMING", 8, 81332},
	{"NETMEETING", 10, 81333},
	{"ESTORE", 6, 81334},
	{"ISLET", 5, 81335},
	{"UZZA", 4, 81336},
	{"LAYY", 4, 81337},
	{"KYWH", 4, 81338},
	{"CYFR", 4, 81339},
	{"CSOL", 4, 81340},
	{"UNIVERSES", 9, 81341},
	{"GANGLIA", 7, 81342},
	{"CONDUITS", 8, 81343},
	{"CINCO", 5, 81344},
	{"HEADWAY", 7, 81345},
	{"YNAP", 4, 81346},
	{"LYSF", 4, 81347},
	{"GWID", 4, 81348},
	{"GHANAIAN", 8, 81349},
	{"WWAL", 4, 81350},
	{"OWGI", 4, 81351},
	{"FDAL", 4, 81352},
	{"RESONANCES", 10, 81353},
	{"FRIARS", 6, 81354},
	{"SUBJECTIVITY", 12, 81355},
	{"REZI", 4, 81356},
	{"MQUE", 4, 81357},
	{"MAPLES", 6, 81358},
	{"ALLURING", 8, 81359},
	{"MICROARRAYS", 11, 81360},
	{"EASYPIC", 7, 81361},
	{"ABBEVILLE", 9, 81362},
	{"NEWSRE", 6, 81363},
	{"IKKE", 4, 81364},
	{"COBBLE", 6, 81365},
	{"LKRA", 4, 81366},
	{"FLIGHTGEAR", 10, 81367},
	{"SPODE", 5, 81368},
	{"BEREA", 5, 81369},
	{"MCKINNON", 8, 81370},
	{"EDOUARD", 7, 81371},
	{"BUZZARD", 7, 81372},
	{"BONY", 4, 81373},
	{"NMCN", 4, 81374},
	{"BUCKY", 5, 81375},
	{"PLUNGER", 7, 81376},
	{"HALTING", 7, 81377},
	{"XING", 4, 81378},
	{"IFAB", 4, 81379},
	{"BOYN", 4, 81380},
	{"ATYW", 4, 81381},
	{"SIGGRAPH", 8, 81382},
	{"HALLEY", 6, 81383},
	{"BOOKENDS", 8, 81384},
	{"KLINGON", 7, 81385},
	{"MORELAND", 8, 81386},
	{"UMPB", 4, 81387},
	{"LPFI", 4, 81388},
	{"KCAP", 4, 81389},
	{"CRANKS", 6, 81390},
	{"LOWERY", 6, 81391},
	{"ELYJ", 4, 81392},
	{"HEADWATERS", 10, 81393},
	{"HISTOGRAMS", 10, 81394},
	{"REVIVING", 8, 81395},
	{"MOLL", 4, 81396},
	{"WTHP", 4, 81397},
	{"RPUP", 4, 81398},
	{"EWSG", 4, 81399},
	{"CHWR", 4, 81400},
	{"BAYF", 4, 81401},
	{"FLOORPLANS", 10, 81402},
	{"NETHERLAND", 10, 81403},
	{"FRASIER", 7, 81404},
	{"BURROW", 6, 81405},
	{"UNIVERSALITY", 12, 81406},
	{"RTYU", 4, 81407},
	{"KDOO", 4, 81408},
	{"ROSSIGNOL", 9, 81409},
	{"POLYLINE", 8, 81410},
	{"VERANDA", 7, 81411},
	{"TFAU", 4, 81412},
	{"LAROCHE", 7, 81413},
	{"CYTOSOL", 7, 81414},
	{"DISPOSALS", 9, 81415},
	{"XFORMS", 6, 81416},
	{"MOSUL", 5, 81417},
	{"MOTU", 4, 81418},
	{"AMERSHAM", 8, 81419},
	{"UNDERRATED", 10, 81420},
	{"CHORDATA", 8, 81421},
	{"YOWE", 4, 81422},
	{"RMFA", 4, 81423},
	{"PPIR", 4, 81424},
	{"CRAFTERS", 8, 81425},
	{"KINGSBURY", 9, 81426},
	{"YOOX", 4, 81427},
	{"HYPHEN", 6, 81428},
	{"DERMALOGICA", 11, 81429},
	{"MORETON", 7, 81430},
	{"GLYCOPROTEINS", 13, 81431},
	{"ARISTIDE", 8, 81432},
	{"IDUR", 4, 81433},
	{"INSATIABLE", 10, 81434},
	{"EXQUISITELY", 11, 81435},
	{"UNSORTED", 8, 81436},
	{"RAMBUS", 6, 81437},
	{"UNFRIENDLY", 10, 81438},
	{"SCORSESE", 8, 81439},
	{"PATRICKS", 8, 81440},
	{"MICROWAREHOUSE", 14, 81441},
	{"HATCHES", 7, 81442},
	{"BLYTH", 5, 81443},
	{"TMRS", 4, 81444},
	{"BIRC", 4, 81445},
	{"CHRISTENED", 10, 81446},
	{"GRAMPIAN", 8, 81447},
	{"LIVEDAILY", 9, 81448},
	{"ACTUALITY", 9, 81449},
	{"TEASED", 6, 81450},
	{"ALIZEE", 6, 81451},
	{"DETAIN", 6, 81452},
	{"ANDRZEJ", 7, 81453},
	{"OPTIMUS", 7, 81454},
	{"ALFIE", 5, 81455},
	{"MURAD", 5, 81456},
	{"ATTICA", 6, 81457},
	{"IMMUNISATION", 12, 81458},
	{"PFALTZGRAFF", 11, 81459},
	{"UNPU", 4, 81460},
	{"HURB", 4, 81461},
	{"HILM", 4, 81462},
	{"GVIR", 4, 81463},
	{"CEDY", 4, 81464},
	{"EYELETS", 7, 81465},
	{"SWORDFISH", 9, 81466},
	{"LEGALS", 6, 81467},
	{"HENDRY", 6, 81468},
	{"FLATTEN", 7, 81469},
	{"HURO", 4, 81470},
	{"SAVANT", 6, 81471},
	{"HARTLAND", 8, 81472},
	{"APPRECIATING", 12, 81473},
	{"RECREATED", 9, 81474},
	{"LEADED", 6, 81475},
	{"HUNAN", 5, 81476},
	{"TOLB", 4, 81477},
	{"SILF", 4, 81478},
	{"SAMW", 4, 81479},
	{"NYSW", 4, 81480},
	{"LEYV", 4, 81481},
	{"GSMU", 4, 81482},
	{"ERKY", 4, 81483},
	{"AKUS", 4, 81484},
	{"SUPERSONICS", 11, 81485},
	{"STINGING", 8, 81486},
	{"AMSTRAD", 7, 81487},
	{"MEMBRES", 7, 81488},
	{"GULLS", 5, 81489},
	{"VINAIGRETTE", 11, 81490},
	{"YBAG", 4, 81491},
	{"RNUR", 4, 81492},
	{"RLEC", 4, 81493},
	{"RIVY", 4, 81494},
	{"MMEI", 4, 81495},
	{"NINTENDOGS", 10, 81496},
	{"PRESCRIBES", 10, 81497},
	{"XCOL", 4, 81498},
	{"RGIF", 4, 81499},
	{"DVX", 3, 81500},
	{"SULTRY", 6, 81501},
	{"SINNED", 6, 81502},
	{"GLOBULAR", 8, 81503},
	{"ZDW", 3, 81504},
	{"VVW", 3, 81505},
	{"VPY", 3, 81506},
	{"PZK", 3, 81507},
	{"KXB", 3, 81508},
	{"ASIATIC", 7, 81509},
	{"UNREADABLE", 10, 81510},
	{"PHYP", 4, 81511},
	{"BAXT", 4, 81512},
	{"MACAULAY", 8, 81513},
	{"PLATTSBURGH", 11, 81514},
	{"BALSA", 5, 81515},
	{"DEPOSITING", 10, 81516},
	{"BRASSERIE", 9, 81517},
	{"GCL", 3, 81518},
	{"TIBU", 4, 81519},
	{"FNAP", 4, 81520},
	{"SALTON", 6, 81521},
	{"PAULSON", 7, 81522},
	{"DVDPLAYER", 9, 81523},
	{"PFLI", 4, 81524},
	{"SILVERTON", 9, 81525},
	{"ENGRAVINGS", 10, 81526},
	{"JOEG", 4, 81527},
	{"ELBI", 4, 81528},
	{"SHOWERING", 9, 81529},
	{"ENDURO", 6, 81530},
	{"PEEPSHOW", 8, 81531},
	{"FANATICAL", 9, 81532},
	{"CAPER", 5, 81533},
	{"SYMO", 4, 81534},
	{"OPOD", 4, 81535},
	{"GIVENS", 6, 81536},
	{"BRISTOW", 7, 81537},
	{"PECUNIARY", 9, 81538},
	{"VINTAGES", 8, 81539},
	{"PREDICATED", 10, 81540},
	{"WSUB", 4, 81541},
	{"FANW", 4, 81542},
	{"OZARKS", 6, 81543},
	{"JOHOR", 5, 81544},
	{"MONTEZUMA", 9, 81545},
	{"FSOV", 4, 81546},
	{"MUCOSAL", 7, 81547},
	{"PREHISTORY", 10, 81548},
	{"LENTILS", 7, 81549},
	{"HISTIDINE", 9, 81550},
	{"QUACK", 5, 81551},
	{"NKAP", 4, 81552},
	{"TECTONICS", 9, 81553},
	{"LORENTZ", 7, 81554},
	{"DISTRIBUTIVE", 12, 81555},
	{"WINJ", 4, 81556},
	{"UGSH", 4, 81557},
	{"SHARPS", 6, 81558},
	{"SEGURIDAD", 9, 81559},
	{"WWAR", 4, 81560},
	{"ULEH", 4, 81561},
	{"TYTV", 4, 81562},
	{"CHLU", 4, 81563},
	{"BISP", 4, 81564},
	{"BRUGES", 6, 81565},
	{"GILBERTO", 8, 81566},
	{"GROOMS", 6, 81567},
	{"SGOU", 4, 81568},
	{"OZZI", 4, 81569},
	{"AORC", 4, 81570},
	{"DOOMSDAY", 8, 81571},
	{"OTTERS", 6, 81572},
	{"GERVAIS", 7, 81573},
	{"MEWS", 4, 81574},
	{"OUSTED", 6, 81575},
	{"SCARRING", 8, 81576},
	{"LYOL", 4, 81577},
	{"LPUL", 4, 81578},
	{"DAYDREAM", 8, 81579},
	{"GOODING", 7, 81580},
	{"SNICKET", 7, 81581},
	{"BICARBONATE", 11, 81582},
	{"BOGGS", 5, 81583},
	{"CASK", 4, 81584},
	{"USOB", 4, 81585},
	{"HLAK", 4, 81586},
	{"GROCER", 6, 81587},
	{"DIETITIAN", 9, 81588},
	{"SPEEDILY", 8, 81589},
	{"YATG", 4, 81590},
	{"LOLY", 4, 81591},
	{"HEWC", 4, 81592},
	{"ELEU", 4, 81593},
	{"HARRIMAN", 8, 81594},
	{"AUBERGE", 7, 81595},
	{"FBUY", 4, 81596},
	{"PAPRIKA", 7, 81597},
	{"CHASES", 6, 81598},
	{"HAVILAND", 8, 81599},
	{"INTERVENED", 10, 81600},
	{"NOVATO", 6, 81601},
	{"LDVA", 4, 81602},
	{"HORNSBY", 7, 81603},
	{"GUJA", 4, 81604},
	{"BIDEN", 5, 81605},
	{"DISALLOWED", 10, 81606},
	{"JORDI", 5, 81607},
	{"CORREO", 6, 81608},
	{"FRIDA", 5, 81609},
	{"CHAPPELLE", 9, 81610},
	{"RESOURCING", 10, 81611},
	{"GOPL", 4, 81612},
	{"DAMY", 4, 81613},
	{"BSWA", 4, 81614},
	{"METHUEN", 7, 81615},
	{"MEZZO", 5, 81616},
	{"ZONEINFO", 8, 81617},
	{"ADELPHI", 7, 81618},
	{"ORBISON", 7, 81619},
	{"GEFFEN", 6, 81620},
	{"UDRI", 4, 81621},
	{"MITD", 4, 81622},
	{"INFORMATIK", 10, 81623},
	{"INCARNATE", 9, 81624},
	{"CHIMNEYS", 8, 81625},
	{"UNCR", 4, 81626},
	{"NOVELLA", 7, 81627},
	{"PREOCCUPIED", 11, 81628},
	{"BRIE", 4, 81629},
	{"HITHER", 6, 81630},
	{"DIGGERS", 7, 81631},
	{"GLANCES", 7, 81632},
	{"GALEON", 6, 81633},
	{"SILOS", 5, 81634},
	{"TYRANTS", 7, 81635},
	{"CONSTANTIN", 10, 81636},
	{"ULMU", 4, 81637},
	{"LRWXRWXRWX", 10, 81638},
	{"SHORTSTOP", 9, 81639},
	{"GIDDY", 5, 81640},
	{"VOUC", 4, 81641},
	{"SOCU", 4, 81642},
	{"DENOUNCE", 8, 81643},
	{"OPRU", 4, 81644},
	{"ENTERTAINMENTS", 14, 81645},
	{"DORDRECHT", 9, 81646},
	{"OAPU", 4, 81647},
	{"PERMISSIVE", 10, 81648},
	{"CRESTON", 7, 81649},
	{"PREC", 4, 81650},
	{"RYKN", 4, 81651},
	{"OYDW", 4, 81652},
	{"NEHRU", 5, 81653},
	{"BROMWICH", 8, 81654},
	{"DISPOSABLES", 11, 81655},
	{"ESTROGENS", 9, 81656},
	{"FURNESS", 7, 81657},
	{"RIPPLES", 7, 81658},
	{"MULHOLLAND", 10, 81659},
	{"NBID", 4, 81660},
	{"IDPI", 4, 81661},
	{"HERZ", 4, 81662},
	{"BLOODSHED", 9, 81663},
	{"UDYG", 4, 81664},
	{"SMYP", 4, 81665},
	{"RNUT", 4, 81666},
	{"RERB", 4, 81667},
	{"LURG", 4, 81668},
	{"DSEQ", 4, 81669},
	{"VIENTO", 6, 81670},
	{"ODOMETER", 8, 81671},
	{"TOOLTIP", 7, 81672},
	{"UPSETTING", 9, 81673},
	{"FYAS", 4, 81674},
	{"EFWA", 4, 81675},
	{"MOSBY", 5, 81676},
	{"DURANTE", 7, 81677},
	{"DRUIDS", 6, 81678},
	{"AGGREGATORS", 11, 81679},
	{"HERFIRSTBIGCOCK", 15, 81680},
	{"OMBW", 4, 81681},
	{"KCHO", 4, 81682},
	{"IPUN", 4, 81683},
	{"ARVADA", 6, 81684},
	{"FIXME", 5, 81685},
	{"RODGER", 6, 81686},
	{"OFDY", 4, 81687},
	{"FBAB", 4, 81688},
	{"TIVELY", 6, 81689},
	{"GIZMONDO", 8, 81690},
	{"CUCINA", 6, 81691},
	{"GRIDDLE", 7, 81692},
	{"NASCENT", 7, 81693},
	{"PRICELIST", 9, 81694},
	{"JUVENTUS", 8, 81695},
	{"RHAB", 4, 81696},
	{"OMYG", 4, 81697},
	{"IACL", 4, 81698},
	{"CYAL", 4, 81699},
	{"CONROE", 6, 81700},
	{"MULTIPLIERS", 11, 81701},
	{"REINFORCEMENTS", 14, 81702},
	{"WEPI", 4, 81703},
	{"MYDU", 4, 81704},
	{"IPCH", 4, 81705},
	{"CSMO", 4, 81706},
	{"APARTHOTEL", 10, 81707},
	{"PRECEPT", 7, 81708},
	{"KITESURFING", 11, 81709},
	{"SALERNO", 7, 81710},
	{"YXG", 3, 81711},
	{"CVJ", 3, 81712},
	{"PAVEMENTS", 9, 81713},
	{"COUPLERS", 8, 81714},
	{"AFTERSHAVES", 11, 81715},
	{"OFTV", 4, 81716},
	{"MURMURED", 8, 81717},
	{"REHABILITATE", 12, 81718},
	{"PATINA", 6, 81719},
	{"PROPELLERS", 10, 81720},
	{"SCANSOFT", 8, 81721},
	{"QUADRA", 6, 81722},
	{"SOUSA", 5, 81723},
	{"VIOLINIST", 9, 81724},
	{"PHONOLOGY", 9, 81725},
	{"DUNKIN", 6, 81726},
	{"YUSH", 4, 81727},
	{"XCHU", 4, 81728},
	{"FREB", 4, 81729},
	{"EZZA", 4, 81730},
	{"EGOM", 4, 81731},
	{"DEBL", 4, 81732},
	{"PLASMODIUM", 10, 81733},
	{"HIMALAYA", 8, 81734},
	{"GIBBON", 6, 81735},
	{"GRATIFYING", 10, 81736},
	{"BUMS", 4, 81737},
	{"UNDERSEA", 8, 81738},
	{"ARETHA", 6, 81739},
	{"BOXSTER", 7, 81740},
	{"BCG", 3, 81741},
	{"OVEREXPRESSION", 14, 81742},
	{"DELIRIOUS", 9, 81743},
	{"EXCEPTING", 9, 81744},
	{"UNLAWFULLY", 10, 81745},
	{"VANADIUM", 8, 81746},
	{"ODVI", 4, 81747},
	{"LDEI", 4, 81748},
	{"WILKERSON", 9, 81749},
	{"RIVERBOAT", 9, 81750},
	{"YFIX", 4, 81751},
	{"OPMI", 4, 81752},
	{"ODAP", 4, 81753},
	{"SPANIEN", 7, 81754},
	{"URCHIN", 6, 81755},
	{"PICP", 4, 81756},
	{"ASLY", 4, 81757},
	{"BGL", 3, 81758},
	{"CONTL", 5, 81759},
	{"POLYGAMY", 8, 81760},
	{"OTTUMWA", 7, 81761},
	{"PNOR", 4, 81762},
	{"IPWE", 4, 81763},
	{"DHYA", 4, 81764},
	{"GYNECOLOGIC", 11, 81765},
	{"UNSTOPPABLE", 11, 81766},
	{"PEDOMETER", 9, 81767},
	{"UTTERANCES", 10, 81768},
	{"DEVISING", 8, 81769},
	{"UACT", 4, 81770},
	{"SHORTFALLS", 10, 81771},
	{"BOOKMARKING", 11, 81772},
	{"INGHAM", 6, 81773},
	{"YODER", 5, 81774},
	{"SUSTAINS", 8, 81775},
	{"BARBERSHOP", 10, 81776},
	{"SJUR", 4, 81777},
	{"RATK", 4, 81778},
	{"OYSD", 4, 81779},
	{"ILPI", 4, 81780},
	{"WOODMAN", 7, 81781},
	{"UMHO", 4, 81782},
	{"ULTN", 4, 81783},
	{"SYMA", 4, 81784},
	{"ASYP", 4, 81785},
	{"GRAVELY", 7, 81786},
	{"DRINKWARE", 9, 81787},
	{"IDIOSYNCRATIC", 13, 81788},
	{"GOOGLEBOT", 9, 81789},
	{"TUPR", 4, 81790},
	{"GORL", 4, 81791},
	{"EDZE", 4, 81792},
	{"CBEA", 4, 81793},
	{"AUGT", 4, 81794},
	{"ERRANDS", 7, 81795},
	{"HELLS", 5, 81796},
	{"FLOPPIES", 8, 81797},
	{"TASHKENT", 8, 81798},
	{"CFEA", 4, 81799},
	{"FOXBORO", 7, 81800},
	{"CARTES", 6, 81801},
	{"ALLSTAR", 7, 81802},
	{"HERVEY", 6, 81803},
	{"OMYL", 4, 81804},
	{"NZEL", 4, 81805},
	{"KDAL", 4, 81806},
	{"KILOWATT", 8, 81807},
	{"IMPULSIVE", 9, 81808},
	{"EVGA", 4, 81809},
	{"NIKOS", 5, 81810},
	{"TANCE", 5, 81811},
	{"TBYU", 4, 81812},
	{"RUPD", 4, 81813},
	{"VARIAN", 6, 81814},
	{"SPASMS", 6, 81815},
	{"MOPS", 4, 81816},
	{"COUGHLIN", 8, 81817},
	{"COMMUTATIVE", 11, 81818},
	{"RATIONALLY", 10, 81819},
	{"SEYF", 4, 81820},
	{"ERAQ", 4, 81821},
	{"LANSDOWNE", 9, 81822},
	{"PSYCHOLOGIE", 11, 81823},
	{"UPROAR", 6, 81824},
	{"BCBG", 4, 81825},
	{"OSUK", 4, 81826},
	{"OFZI", 4, 81827},
	{"OFGD", 4, 81828},
	{"IXWH", 4, 81829},
	{"SYRAH", 5, 81830},
	{"SAVAGES", 7, 81831},
	{"CRATERS", 7, 81832},
	{"AFFX", 4, 81833},
	{"ANGIOGENESIS", 12, 81834},
	{"GOFV", 4, 81835},
	{"NICOSIA", 7, 81836},
	{"NEMATODE", 8, 81837},
	{"KEGG", 4, 81838},
	{"PKR", 3, 81839},
	{"RTWR", 4, 81840},
	{"ODVE", 4, 81841},
	{"NODR", 4, 81842},
	{"KCOA", 4, 81843},
	{"ADEK", 4, 81844},
	{"WILMOT", 6, 81845},
	{"ADMINISTRATIVELY", 16, 81846},
	{"VANL", 4, 81847},
	{"CHEU", 4, 81848},
	{"MOCKERY", 7, 81849},
	{"RAILINGS", 8, 81850},
	{"URIB", 4, 81851},
	{"CAPA", 4, 81852},
	{"PAULINA", 7, 81853},
	{"RONALDO", 7, 81854},
	{"NORTHERLY", 9, 81855},
	{"LEVERAGES", 9, 81856},
	{"TENTHS", 6, 81857},
	{"UMSB", 4, 81858},
	{"JOBP", 4, 81859},
	{"GSOP", 4, 81860},
	{"CANCEROUS", 9, 81861},
	{"QUENCH", 6, 81862},
	{"PASSER", 6, 81863},
	{"BANDERAS", 8, 81864},
	{"PROJEKT", 7, 81865},
	{"GMANE", 5, 81866},
	{"GABRIELA", 8, 81867},
	{"SECRETORY", 9, 81868},
	{"MMX", 3, 81869},
	{"PINEHURST", 9, 81870},
	{"ENCOMPASSED", 11, 81871},
	{"ICJA", 4, 81872},
	{"DCEM", 4, 81873},
	{"AFEP", 4, 81874},
	{"REASSESSMENT", 12, 81875},
	{"IPPP", 4, 81876},
	{"BROIL", 5, 81877},
	{"HURRAH", 6, 81878},
	{"UTMR", 4, 81879},
	{"SWAV", 4, 81880},
	{"RBYN", 4, 81881},
	{"DMYD", 4, 81882},
	{"CHILLERS", 8, 81883},
	{"ELBERT", 6, 81884},
	{"MODESTLY", 8, 81885},
	{"MDEE", 4, 81886},
	{"BUMH", 4, 81887},
	{"BBAG", 4, 81888},
	{"EPITAPH", 7, 81889},
	{"SUNIL", 5, 81890},
	{"ALLAHABAD", 9, 81891},
	{"INSURRECTION", 12, 81892},
	{"BRUGGE", 6, 81893},
	{"YUKI", 4, 81894},
	{"ALGER", 5, 81895},
	{"RAER", 4, 81896},
	{"PERIODICITY", 11, 81897},
	{"EMIGRATED", 9, 81898},
	{"TRYPSIN", 7, 81899},
	{"BURSARY", 7, 81900},
	{"DEPENDABILITY", 13, 81901},
	{"OVERDRAFT", 9, 81902},
	{"DEIRDRE", 7, 81903},
	{"COLONIA", 7, 81904},
	{"MYCOPLASMA", 10, 81905},
	{"BARGES", 6, 81906},
	{"ADELPHIA", 8, 81907},
	{"REKT", 4, 81908},
	{"SCRIBNER", 8, 81909},
	{"ACTIVITES", 9, 81910},
	{"FRANKEL", 7, 81911},
	{"CACTI", 5, 81912},
	{"BUGABOO", 7, 81913},
	{"DJAI", 4, 81914},
	{"DGEJ", 4, 81915},
	{"TREMBLANT", 9, 81916},
	{"PALMDALE", 8, 81917},
	{"AERATION", 8, 81918},
	{"ROCR", 4, 81919},
	{"REAJ", 4, 81920},
	{"KASM", 4, 81921},
	{"DIPH", 4, 81922},
	{"ANTENNAE", 8, 81923},
	{"MUSCLETECH", 10, 81924},
	{"ULDQ", 4, 81925},
	{"PPIT", 4, 81926},
	{"LMUC", 4, 81927},
	{"FERMENTED", 9, 81928},
	{"WATERSPORT", 10, 81929},
	{"YGJ", 3, 81930},
	{"VKY", 3, 81931},
	{"KKJ", 3, 81932},
	{"GGQ", 3, 81933},
	{"YACL", 4, 81934},
	{"SOYB", 4, 81935},
	{"USCG", 4, 81936},
	{"YITP", 4, 81937},
	{"ENFANT", 6, 81938},
	{"GIBB", 4, 81939},
	{"GENER", 5, 81940},
	{"YWET", 4, 81941},
	{"YBLI", 4, 81942},
	{"ORUT", 4, 81943},
	{"CMOR", 4, 81944},
	{"BINF", 4, 81945},
	{"ZHONG", 5, 81946},
	{"CHOWDER", 7, 81947},
	{"EXPATRIATES", 11, 81948},
	{"CENTERPIECES", 12, 81949},
	{"YBIO", 4, 81950},
	{"VSKI", 4, 81951},
	{"HICM", 4, 81952},
	{"FREAKED", 7, 81953},
	{"HEADMASTER", 10, 81954},
	{"CURBS", 5, 81955},
	{"ZBEK", 4, 81956},
	{"YICO", 4, 81957},
	{"WALRUS", 6, 81958},
	{"TRIPHOSPHATE", 12, 81959},
	{"ACRONIS", 7, 81960},
	{"PMOT", 4, 81961},
	{"EFFG", 4, 81962},
	{"SECRETIVE", 9, 81963},
	{"GRIEVOUS", 8, 81964},
	{"WCW", 3, 81965},
	{"PROSTAGLANDIN", 13, 81966},
	{"COMPLETO", 8, 81967},
	{"OLVA", 4, 81968},
	{"DARWINPORTS", 11, 81969},
	{"ABIWORD", 7, 81970},
	{"GENERATIVE", 10, 81971},
	{"HIPPOCAMPAL", 11, 81972},
	{"ASSYRIAN", 8, 81973},
	{"ATLASSIAN", 9, 81974},
	{"UDYH", 4, 81975},
	{"ERBC", 4, 81976},
	{"TECHNIK", 7, 81977},
	{"VINELAND", 8, 81978},
	{"REPETITIONS", 11, 81979},
	{"COMMENTAIRES", 12, 81980},
	{"MAQU", 4, 81981},
	{"LPFO", 4, 81982},
	{"IFFC", 4, 81983},
	{"ABYF", 4, 81984},
	{"HBYS", 4, 81985},
	{"PENSIONER", 9, 81986},
	{"STUTTERING", 10, 81987},
	{"FORCEFULLY", 10, 81988},
	{"DEPO", 4, 81989},
	{"XBAS", 4, 81990},
	{"JAFF", 4, 81991},
	{"CYNT", 4, 81992},
	{"EDINBURG", 8, 81993},
	{"SPELLBOUND", 10, 81994},
	{"KWANZAA", 7, 81995},
	{"KZSU", 4, 81996},
	{"MASCOTS", 7, 81997},
	{"BRETAGNE", 8, 81998},
	{"RFOX", 4, 81999},
	{"HARRISONBURG", 12, 82000},
	{"CADBURY", 7, 82001},
	{"SCOBLE", 6, 82002},
	{"CONUNDRUM", 9, 82003},
	{"BULLARD", 7, 82004},
	{"AIFF", 4, 82005},
	{"TENGO", 5, 82006},
	{"DOMENICO", 8, 82007},
	{"SKYC", 4, 82008},
	{"OKSG", 4, 82009},
	{"COMEDIC", 7, 82010},
	{"FEND", 4, 82011},
	{"APICAL", 6, 82012},
	{"SYNOPTIC", 8, 82013},
	{"USYW", 4, 82014},
	{"SAPPHIRES", 9, 82015},
	{"MIYAZAKI", 8, 82016},
	{"BERYLLIUM", 9, 82017},
	{"ODEJ", 4, 82018},
	{"DISINFECTANT", 12, 82019},
	{"SENTRA", 6, 82020},
	{"COMPRESSING", 11, 82021},
	{"JOKERS", 6, 82022},
	{"PIGLET", 6, 82023},
	{"PFEE", 4, 82024},
	{"MREN", 4, 82025},
	{"MELC", 4, 82026},
	{"IPMO", 4, 82027},
	{"WILDCARDS", 9, 82028},
	{"INTOXICATING", 12, 82029},
	{"TRESOR", 6, 82030},
	{"CRUMBLE", 7, 82031},
	{"SKETCHBOOK", 10, 82032},
	{"RESORTED", 8, 82033},
	{"BBD", 3, 82034},
	{"HALLIDAY", 8, 82035},
	{"HBUL", 4, 82036},
	{"ARPM", 4, 82037},
	{"APFR", 4, 82038},
	{"LECTURING", 9, 82039},
	{"RETREATED", 9, 82040},
	{"MANOLO", 6, 82041},
	{"TIFTON", 6, 82042},
	{"REPRE", 5, 82043},
	{"HENDRICKSON", 11, 82044},
	{"WINDHOEK", 8, 82045},
	{"LOMOND", 6, 82046},
	{"ATAPI", 5, 82047},
	{"SENZA", 5, 82048},
	{"ECCLES", 6, 82049},
	{"MAGDALENE", 9, 82050},
	{"DCU", 3, 82051},
	{"RUGM", 4, 82052},
	{"KSPI", 4, 82053},
	{"SPATULA", 7, 82054},
	{"INTERGENERATIONAL", 17, 82055},
	{"EPUB", 4, 82056},
	{"CATES", 5, 82057},
	{"FEATURETTE", 10, 82058},
	{"GOTCHA", 6, 82059},
	{"KINDERSLEY", 10, 82060},
	{"DRIFTER", 7, 82061},
	{"CVSNT", 5, 82062},
	{"BARH", 4, 82063},
	{"VEER", 4, 82064},
	{"TICJ", 4, 82065},
	{"RUVI", 4, 82066},
	{"LAGERFELD", 9, 82067},
	{"NETTED", 6, 82068},
	{"YDAI", 4, 82069},
	{"WSRO", 4, 82070},
	{"LEWIN", 5, 82071},
	{"YOUVE", 5, 82072},
	{"UNAIDS", 6, 82073},
	{"LARUE", 5, 82074},
	{"STARDOM", 7, 82075},
	{"TFEB", 4, 82076},
	{"NYDU", 4, 82077},
	{"KRAC", 4, 82078},
	{"EXAL", 4, 82079},
	{"DLOB", 4, 82080},
	{"ASSAD", 5, 82081},
	{"GLENVIEW", 8, 82082},
	{"OFUM", 4, 82083},
	{"ILTC", 4, 82084},
	{"EGWA", 4, 82085},
	{"BRANTFORD", 9, 82086},
	{"KELIS", 5, 82087},
	{"RMMI", 4, 82088},
	{"LGLO", 4, 82089},
	{"GITP", 4, 82090},
	{"DGIA", 4, 82091},
	{"DISPEL", 6, 82092},
	{"LXR", 3, 82093},
	{"TOASTMASTERS", 12, 82094},
	{"WARSHIPS", 8, 82095},
	{"YVIN", 4, 82096},
	{"MOWI", 4, 82097},
	{"APPR", 4, 82098},
	{"RECS", 4, 82099},
	{"VIAP", 4, 82100},
	{"RANCHI", 6, 82101},
	{"EXOTICS", 7, 82102},
	{"ARTICULATING", 12, 82103},
	{"WCOR", 4, 82104},
	{"RGFO", 4, 82105},
	{"LADR", 4, 82106},
	{"EEBY", 4, 82107},
	{"DBRY", 4, 82108},
	{"JIFFY", 5, 82109},
	{"TAMAR", 5, 82110},
	{"WOODBINE", 8, 82111},
	{"GOODALL", 7, 82112},
	{"GOAG", 4, 82113},
	{"GELM", 4, 82114},
	{"GCONF", 5, 82115},
	{"VERKAUFEN", 9, 82116},
	{"SCALEXTRIC", 10, 82117},
	{"RYOBI", 5, 82118},
	{"STRAIGHTENING", 13, 82119},
	{"DHEU", 4, 82120},
	{"QNAME", 5, 82121},
	{"IMMERSE", 7, 82122},
	{"FARRIS", 6, 82123},
	{"JOINWELCOME", 11, 82124},
	{"RAPM", 4, 82125},
	{"GWEW", 4, 82126},
	{"DDYI", 4, 82127},
	{"ENVIOUS", 7, 82128},
	{"REGRETTED", 9, 82129},
	{"WITTENBERG", 10, 82130},
	{"COLIC", 5, 82131},
	{"YWAG", 4, 82132},
	{"OUGR", 4, 82133},
	{"ICYP", 4, 82134},
	{"FSMI", 4, 82135},
	{"CAPONE", 6, 82136},
	{"MEMBRE", 6, 82137},
	{"ADOLPH", 6, 82138},
	{"BUSINES", 7, 82139},
	{"REBOUNDING", 10, 82140},
	{"USBORNE", 7, 82141},
	{"ZRD", 3, 82142},
	{"UJB", 3, 82143},
	{"NUSR", 4, 82144},
	{"FARTHEST", 8, 82145},
	{"HIRSUTE", 7, 82146},
	{"INIQUITY", 8, 82147},
	{"XPAR", 4, 82148},
	{"HIMY", 4, 82149},
	{"CKVA", 4, 82150},
	{"AKBE", 4, 82151},
	{"PRELIM", 6, 82152},
	{"PREPRESS", 8, 82153},
	{"FOOLING", 7, 82154},
	{"MILITIAS", 8, 82155},
	{"COMMODORES", 10, 82156},
	{"ECNEXT", 6, 82157},
	{"LTHG", 4, 82158},
	{"DBF", 3, 82159},
	{"GOLDSBORO", 9, 82160},
	{"ASHBURN", 7, 82161},
	{"ROSLYN", 6, 82162},
	{"LSYN", 4, 82163},
	{"NEVERLAND", 9, 82164},
	{"COOLIO", 6, 82165},
	{"VAULTED", 7, 82166},
	{"WARMS", 5, 82167},
	{"LINDBERGH", 9, 82168},
	{"FREECIV", 7, 82169},
	{"FORMALITIES", 11, 82170},
	{"INDICE", 6, 82171},
	{"VERTEBRAL", 9, 82172},
	{"ECTOPIC", 7, 82173},
	{"ABCS", 4, 82174},
	{"RESOUNDING", 10, 82175},
	{"WFAS", 4, 82176},
	{"FDAI", 4, 82177},
	{"COULOMB", 7, 82178},
	{"MINTON", 6, 82179},
	{"RESTATEMENT", 11, 82180},
	{"WAKEBOARD", 9, 82181},
	{"YANF", 4, 82182},
	{"MCPH", 4, 82183},
	{"EYDB", 4, 82184},
	{"UNSCHEDULED", 11, 82185},
	{"BRAZOS", 6, 82186},
	{"SAUCY", 5, 82187},
	{"DBC", 3, 82188},
	{"VISSER", 6, 82189},
	{"CLIPLAND", 8, 82190},
	{"BLISTERING", 10, 82191},
	{"ILLUMINATES", 11, 82192},
	{"PPYD", 4, 82193},
	{"LAFL", 4, 82194},
	{"ALMD", 4, 82195},
	{"THERMOCOUPLE", 12, 82196},
	{"MASALA", 6, 82197},
	{"MASQUE", 6, 82198},
	{"NIGR", 4, 82199},
	{"LIGU", 4, 82200},
	{"EWAU", 4, 82201},
	{"KAZAN", 5, 82202},
	{"SHILLINGS", 9, 82203},
	{"DRW", 3, 82204},
	{"GLEANED", 7, 82205},
	{"ROSAS", 5, 82206},
	{"PARW", 4, 82207},
	{"NUKR", 4, 82208},
	{"DECOMPOSED", 10, 82209},
	{"FLOWERY", 7, 82210},
	{"RDRAM", 5, 82211},
	{"SCANDALOUS", 10, 82212},
	{"MCCLAIN", 7, 82213},
	{"MAKI", 4, 82214},
	{"YERU", 4, 82215},
	{"WAPR", 4, 82216},
	{"NEMM", 4, 82217},
	{"HDIG", 4, 82218},
	{"DDYB", 4, 82219},
	{"ROSENBAUM", 9, 82220},
	{"EAGAN", 5, 82221},
	{"SUNBURN", 7, 82222},
	{"BLAS", 4, 82223},
	{"ULYL", 4, 82224},
	{"KEDY", 4, 82225},
	{"PLEISTOCENE", 11, 82226},
	{"SSMY", 4, 82227},
	{"SMBU", 4, 82228},
	{"SHYD", 4, 82229},
	{"NPUE", 4, 82230},
	{"CYNO", 4, 82231},
	{"CANISTERS", 9, 82232},
	{"CIEL", 4, 82233},
	{"YMBI", 4, 82234},
	{"EYBI", 4, 82235},
	{"MENACING", 8, 82236},
	{"ELECTOR", 7, 82237},
	{"YLEL", 4, 82238},
	{"RURB", 4, 82239},
	{"LILI", 4, 82240},
	{"WADDELL", 7, 82241},
	{"SOLVENCY", 8, 82242},
	{"LYNETTE", 7, 82243},
	{"NEUROTIC", 8, 82244},
	{"PLAINVIEW", 9, 82245},
	{"FIELDED", 7, 82246},
	{"BITUMINOUS", 10, 82247},
	{"OLVO", 4, 82248},
	{"ASKEW", 5, 82249},
	{"BLOWFISH", 8, 82250},
	{"ZYPREXA", 7, 82251},
	{"PHIPPS", 6, 82252},
	{"UNFU", 4, 82253},
	{"FERU", 4, 82254},
	{"GROAN", 5, 82255},
	{"ALTRINCHAM", 10, 82256},
	{"WORKIN", 6, 82257},
	{"DUSTING", 7, 82258},
	{"AFTON", 5, 82259},
	{"TOPOLOGIES", 10, 82260},
	{"TOUTS", 5, 82261},
	{"XELIBRI", 7, 82262},
	{"LOMBARDY", 8, 82263},
	{"UNCONTROLLABLE", 14, 82264},
	{"LORA", 4, 82265},
	{"ZIGE", 4, 82266},
	{"TBUN", 4, 82267},
	{"ISML", 4, 82268},
	{"CFIR", 4, 82269},
	{"BCAM", 4, 82270},
	{"MENDEZ", 6, 82271},
	{"UNDELETE", 8, 82272},
	{"SHACKLES", 8, 82273},
	{"SAMUELS", 7, 82274},
	{"UISL", 4, 82275},
	{"LMOL", 4, 82276},
	{"IXPE", 4, 82277},
	{"BYWR", 4, 82278},
	{"SHRINES", 7, 82279},
	{"BRIDGED", 7, 82280},
	{"RAJESH", 6, 82281},
	{"SOROS", 5, 82282},
	{"UNJUSTIFIED", 11, 82283},
	{"CONSENTING", 10, 82284},
	{"TORTURING", 9, 82285},
	{"CRF", 3, 82286},
	{"TOILE", 5, 82287},
	{"DIGITALE", 8, 82288},
	{"SITCOMS", 7, 82289},
	{"ANALOGUES", 9, 82290},
	{"LEUKAEMIA", 9, 82291},
	{"UKULELE", 7, 82292},
	{"KIED", 4, 82293},
	{"RELENTLESSLY", 12, 82294},
	{"PAPERBOARD", 10, 82295},
	{"BRACKEN", 7, 82296},
	{"FIED", 4, 82297},
	{"LGAE", 4, 82298},
	{"CILB", 4, 82299},
	{"AQUO", 4, 82300},
	{"COBAIN", 6, 82301},
	{"TRILLIAN", 8, 82302},
	{"COUCHES", 7, 82303},
	{"OFFALY", 6, 82304},
	{"DECADENCE", 9, 82305},
	{"LFLY", 4, 82306},
	{"GIRLIE", 6, 82307},
	{"ILCS", 4, 82308},
	{"FRIGGIN", 7, 82309},
	{"UCTF", 4, 82310},
	{"NOURISHING", 10, 82311},
	{"DAVINCI", 7, 82312},
	{"HERSCHEL", 8, 82313},
	{"RECONSIDERED", 12, 82314},
	{"LIWH", 4, 82315},
	{"DAOR", 4, 82316},
	{"EXPRESSIONENGINE", 16, 82317},
	{"BAINS", 5, 82318},
	{"CALLBACKS", 9, 82319},
	{"CDV", 3, 82320},
	{"HANNITY", 7, 82321},
	{"FCOF", 4, 82322},
	{"BUTQ", 4, 82323},
	{"AWAF", 4, 82324},
	{"ANCHE", 5, 82325},
	{"ARDUOUS", 7, 82326},
	{"HEUF", 4, 82327},
	{"MORTEN", 6, 82328},
	{"REPLICATES", 10, 82329},
	{"SIDEWINDER", 10, 82330},
	{"HGLO", 4, 82331},
	{"QUEUEING", 8, 82332},
	{"SLUGGER", 7, 82333},
	{"HUMIDIFIERS", 11, 82334},
	{"RKEP", 4, 82335},
	{"RAMG", 4, 82336},
	{"ODOZ", 4, 82337},
	{"CTGO", 4, 82338},
	{"DESAI", 5, 82339},
	{"RRHE", 4, 82340},
	{"PFIL", 4, 82341},
	{"MUPS", 4, 82342},
	{"ABYD", 4, 82343},
	{"ASSIMILATED", 11, 82344},
	{"WATERMARKS", 10, 82345},
	{"HINGIS", 6, 82346},
	{"VACANZE", 7, 82347},
	{"ONENOTE", 7, 82348},
	{"CREEPS", 6, 82349},
	{"MONTEBELLO", 10, 82350},
	{"STREETCAR", 9, 82351},
	{"SLYG", 4, 82352},
	{"IXWA", 4, 82353},
	{"STOKER", 6, 82354},
	{"FULCRUM", 7, 82355},
	{"SADISTIC", 8, 82356},
	{"CASSIOPEIA", 10, 82357},
	{"CORWIN", 6, 82358},
	{"GRIPPED", 7, 82359},
	{"RGEY", 4, 82360},
	{"VXV", 3, 82361},
	{"QLB", 3, 82362},
	{"MARTINGALE", 10, 82363},
	{"SAUCONY", 7, 82364},
	{"WINSLET", 7, 82365},
	{"UCIE", 4, 82366},
	{"PEMO", 4, 82367},
	{"GBEY", 4, 82368},
	{"CRITICIZES", 10, 82369},
	{"UNSCRUPULOUS", 12, 82370},
	{"BAYTOWN", 7, 82371},
	{"SYNCHRONIZING", 13, 82372},
	{"RECLASSIFICATION", 16, 82373},
	{"NYMPHS", 6, 82374},
	{"NYSB", 4, 82375},
	{"MCKA", 4, 82376},
	{"DPUM", 4, 82377},
	{"WOOHOO", 6, 82378},
	{"CAITHNESS", 9, 82379},
	{"TAKEAWAY", 8, 82380},
	{"UNSETTLED", 9, 82381},
	{"XIDA", 4, 82382},
	{"PBRA", 4, 82383},
	{"IFEK", 4, 82384},
	{"RGOF", 4, 82385},
	{"PEME", 4, 82386},
	{"ISDY", 4, 82387},
	{"TIMEOUTS", 8, 82388},
	{"INSEPARABLE", 11, 82389},
	{"GODL", 4, 82390},
	{"FEEW", 4, 82391},
	{"ERGD", 4, 82392},
	{"DIETZ", 5, 82393},
	{"JURIST", 6, 82394},
	{"DEVO", 4, 82395},
	{"MORGAGE", 7, 82396},
	{"DUCKY", 5, 82397},
	{"TGAY", 4, 82398},
	{"LTGO", 4, 82399},
	{"GHBL", 4, 82400},
	{"VESTAL", 6, 82401},
	{"BOLA", 4, 82402},
	{"MDB", 3, 82403},
	{"MULTIMODAL", 10, 82404},
	{"PMAD", 4, 82405},
	{"GEOC", 4, 82406},
	{"DISMISSES", 9, 82407},
	{"VARIOUSLY", 9, 82408},
	{"RECENTER", 8, 82409},
	{"HEMATITE", 8, 82410},
	{"HENSLEY", 7, 82411},
	{"ASTERIX", 7, 82412},
	{"HOKIES", 6, 82413},
	{"WLYT", 4, 82414},
	{"RYOW", 4, 82415},
	{"QUOB", 4, 82416},
	{"BLUMENTHAL", 10, 82417},
	{"MULTINATIONALS", 14, 82418},
	{"VEPM", 4, 82419},
	{"EIFF", 4, 82420},
	{"ARRAN", 5, 82421},
	{"UNINTENTIONALLY", 15, 82422},
	{"DEBS", 4, 82423},
	{"SPRITES", 7, 82424},
	{"PLAYIN", 6, 82425},
	{"EMERIL", 6, 82426},
	{"MCALESTER", 9, 82427},
	{"ADRIA", 5, 82428},
	{"RFEB", 4, 82429},
	{"OUPN", 4, 82430},
	{"EKCA", 4, 82431},
	{"AFRU", 4, 82432},
	{"DASHING", 7, 82433},
	{"SHIPMAN", 7, 82434},
	{"BURZI", 5, 82435},
	{"IOPL", 4, 82436},
	{"TIRING", 6, 82437},
	{"INCINERATOR", 11, 82438},
	{"ABATE", 5, 82439},
	{"MUENCHEN", 8, 82440},
	{"CONVENING", 9, 82441},
	{"UNORTHODOX", 10, 82442},
	{"FIBROBLAST", 10, 82443},
	{"GLORYHOLES", 10, 82444},
	{"CARRICK", 7, 82445},
	{"PILOTING", 8, 82446},
	{"IMMERSIVE", 9, 82447},
	{"DARMOWE", 7, 82448},
	{"YCOW", 4, 82449},
	{"RKKN", 4, 82450},
	{"CATAGORY", 8, 82451},
	{"GLOB", 4, 82452},
	{"CISPLATIN", 9, 82453},
	{"FERTILISER", 10, 82454},
	{"NUOVA", 5, 82455},
	{"OROG", 4, 82456},
	{"NRUB", 4, 82457},
	{"IGSP", 4, 82458},
	{"HALSTEAD", 8, 82459},
	{"VOIDS", 5, 82460},
	{"REINVENT", 8, 82461},
	{"PENDER", 6, 82462},
	{"BELLIED", 7, 82463},
	{"OILFIELD", 8, 82464},
	{"TUMT", 4, 82465},
	{"NUEV", 4, 82466},
	{"AFRIQUE", 7, 82467},
	{"REAM", 4, 82468},
	{"MILA", 4, 82469},
	{"ROUNDTRIP", 9, 82470},
	{"YWOL", 4, 82471},
	{"WMOS", 4, 82472},
	{"UTSY", 4, 82473},
	{"UNOP", 4, 82474},
	{"HWEB", 4, 82475},
	{"MPL", 3, 82476},
	{"KICKIN", 6, 82477},
	{"DECREED", 7, 82478},
	{"ODPI", 4, 82479},
	{"MOSSY", 5, 82480},
	{"DROID", 5, 82481},
	{"ADDENDA", 7, 82482},
	{"BANQUE", 6, 82483},
	{"AKAC", 4, 82484},
	{"RESTORATIONS", 12, 82485},
	{"BOLL", 4, 82486},
	{"KNIGHTLEY", 9, 82487},
	{"WORKSITE", 8, 82488},
	{"LCG", 3, 82489},
	{"TYPENAME", 8, 82490},
	{"FFNO", 4, 82491},
	{"DOCTYPE", 7, 82492},
	{"BALINESE", 8, 82493},
	{"SPORTSTER", 9, 82494},
	{"EPBR", 4, 82495},
	{"CKKN", 4, 82496},
	{"DENCE", 5, 82497},
	{"KEYHOLE", 7, 82498},
	{"SAVERSOFTWARE", 13, 82499},
	{"WTUR", 4, 82500},
	{"UDAT", 4, 82501},
	{"THYG", 4, 82502},
	{"KTOK", 4, 82503},
	{"USAGES", 6, 82504},
	{"WICKHAM", 7, 82505},
	{"BURSARIES", 9, 82506},
	{"CUNY", 4, 82507},
	{"CARDIOPULMONARY", 15, 82508},
	{"OKBY", 4, 82509},
	{"NCHY", 4, 82510},
	{"LTSD", 4, 82511},
	{"CKSY", 4, 82512},
	{"BIOLOGIC", 8, 82513},
	{"VIEUX", 5, 82514},
	{"WANADOO", 7, 82515},
	{"BOWELS", 6, 82516},
	{"SHIATSU", 7, 82517},
	{"HOMEWARES", 9, 82518},
	{"DPC", 3, 82519},
	{"UNKD", 4, 82520},
	{"KSQU", 4, 82521},
	{"DUSB", 4, 82522},
	{"CORNET", 6, 82523},
	{"SCHIZOPHRENIC", 13, 82524},
	{"REVERSION", 9, 82525},
	{"UNPLUG", 6, 82526},
	{"ALBERGO", 7, 82527},
	{"PRESSROOM", 9, 82528},
	{"SEWR", 4, 82529},
	{"RTJO", 4, 82530},
	{"DRBI", 4, 82531},
	{"GINGRICH", 8, 82532},
	{"SANCTUARIES", 11, 82533},
	{"BASRA", 5, 82534},
	{"GREENBRIER", 10, 82535},
	{"SUPEROXIDE", 10, 82536},
	{"PORCINE", 7, 82537},
	{"OLDFIELD", 8, 82538},
	{"WXDXH", 5, 82539},
	{"KTWI", 4, 82540},
	{"HLOU", 4, 82541},
	{"CONVICTS", 8, 82542},
	{"LUDER", 5, 82543},
	{"MANX", 4, 82544},
	{"UNDERSTATEMENT", 14, 82545},
	{"OSMAN", 5, 82546},
	{"GEDA", 4, 82547},
	{"TORMENTED", 9, 82548},
	{"IMMANUEL", 8, 82549},
	{"WHISTLEBLOWER", 13, 82550},
	{"KFRA", 4, 82551},
	{"BAYSWATER", 9, 82552},
	{"LYNE", 4, 82553},
	{"EPOX", 4, 82554},
	{"KENNEWICK", 9, 82555},
	{"SUBTREE", 7, 82556},
	{"IDBL", 4, 82557},
	{"HGUA", 4, 82558},
	{"GYES", 4, 82559},
	{"LODGER", 6, 82560},
	{"INSHORE", 7, 82561},
	{"HEPNAMES", 8, 82562},
	{"KETTLER", 7, 82563},
	{"CLOTS", 5, 82564},
	{"REDUCER", 7, 82565},
	{"YMEC", 4, 82566},
	{"URGF", 4, 82567},
	{"UEPI", 4, 82568},
	{"NATURISTS", 9, 82569},
	{"LVD", 3, 82570},
	{"FLONASE", 7, 82571},
	{"SANTEE", 6, 82572},
	{"SMYR", 4, 82573},
	{"SYMPA", 5, 82574},
	{"THUNDERBOLT", 11, 82575},
	{"CLAUDIUS", 8, 82576},
	{"HINSDALE", 8, 82577},
	{"TRAV", 4, 82578},
	{"SPINA", 5, 82579},
	{"YBYL", 4, 82580},
	{"WLIG", 4, 82581},
	{"FLYR", 4, 82582},
	{"FJOR", 4, 82583},
	{"MEATBALLS", 9, 82584},
	{"UNDERREPRESENTED", 16, 82585},
	{"TREMORS", 7, 82586},
	{"BPL", 3, 82587},
	{"BRANE", 5, 82588},
	{"APROPOS", 7, 82589},
	{"YBAK", 4, 82590},
	{"MTRO", 4, 82591},
	{"JUNT", 4, 82592},
	{"EWIV", 4, 82593},
	{"TIGHTNESS", 9, 82594},
	{"TRACKLISTING", 12, 82595},
	{"PITIFUL", 7, 82596},
	{"HORIZONTE", 9, 82597},
	{"RGD", 3, 82598},
	{"FUNB", 4, 82599},
	{"CCRO", 4, 82600},
	{"CAAL", 4, 82601},
	{"CONCATENATION", 13, 82602},
	{"SUFFIXES", 8, 82603},
	{"KILMER", 6, 82604},
	{"CLOVERDALE", 10, 82605},
	{"BARBERA", 7, 82606},
	{"XRR", 3, 82607},
	{"LGJ", 3, 82608},
	{"JVF", 3, 82609},
	{"FZV", 3, 82610},
	{"BQR", 3, 82611},
	{"SEASCAPE", 8, 82612},
	{"PGRE", 4, 82613},
	{"WINKEL", 6, 82614},
	{"AMDT", 4, 82615},
	{"LININGS", 7, 82616},
	{"HORSERADISH", 11, 82617},
	{"YISK", 4, 82618},
	{"WNAW", 4, 82619},
	{"TMOL", 4, 82620},
	{"RMLO", 4, 82621},
	{"RJEE", 4, 82622},
	{"EFTK", 4, 82623},
	{"SPARROWS", 8, 82624},
	{"TELEPHARMACY", 12, 82625},
	{"ITASCA", 6, 82626},
	{"VARBUSINESS", 11, 82627},
	{"UDIB", 4, 82628},
	{"PAULSEN", 7, 82629},
	{"BLEACHED", 8, 82630},
	{"CORTINA", 7, 82631},
	{"LMUD", 4, 82632},
	{"ARBITER", 7, 82633},
	{"HAZELNUT", 8, 82634},
	{"ASHFIELD", 8, 82635},
	{"CHACO", 5, 82636},
	{"REINTEGRATION", 13, 82637},
	{"URKO", 4, 82638},
	{"NABD", 4, 82639},
	{"KAAR", 4, 82640},
	{"IGSU", 4, 82641},
	{"EDYB", 4, 82642},
	{"CFAI", 4, 82643},
	{"LOCOMOTION", 10, 82644},
	{"PAMPERING", 9, 82645},
	{"ANTIMONY", 8, 82646},
	{"HATER", 5, 82647},
	{"BOLAND", 6, 82648},
	{"BUOYANT", 7, 82649},
	{"AIRTIME", 7, 82650},
	{"SURREALISM", 10, 82651},
	{"RMPL", 4, 82652},
	{"EXPEL", 5, 82653},
	{"OYSL", 4, 82654},
	{"EMCM", 4, 82655},
	{"CTBR", 4, 82656},
	{"MARTINE", 7, 82657},
	{"CLAMSHELL", 9, 82658},
	{"LUMINANCE", 9, 82659},
	{"IXTAPA", 6, 82660},
	{"GRYPHON", 7, 82661},
	{"CAIR", 4, 82662},
	{"ROCHAS", 6, 82663},
	{"RUEG", 4, 82664},
	{"AGSW", 4, 82665},
	{"COMBATANT", 9, 82666},
	{"FARNSWORTH", 10, 82667},
	{"SYNCHRONISATION", 15, 82668},
	{"SURESH", 6, 82669},
	{"MINNOW", 6, 82670},
	{"BLOOR", 5, 82671},
	{"SWOOP", 5, 82672},
	{"MROA", 4, 82673},
	{"MLIT", 4, 82674},
	{"AWCA", 4, 82675},
	{"ABSB", 4, 82676},
	{"GUMBO", 5, 82677},
	{"FAQFORUM", 8, 82678},
	{"NEUTER", 6, 82679},
	{"KUNAL", 5, 82680},
	{"PREJUDICIAL", 11, 82681},
	{"BUYF", 4, 82682},
	{"JOSSEY", 6, 82683},
	{"GENTE", 5, 82684},
	{"ZQUE", 4, 82685},
	{"WSDI", 4, 82686},
	{"NOMU", 4, 82687},
	{"NEXU", 4, 82688},
	{"MELAMINE", 8, 82689},
	{"WONWINGLO", 9, 82690},
	{"EPISODIC", 8, 82691},
	{"INTROSPECTION", 13, 82692},
	{"XCEL", 4, 82693},
	{"JURYS", 5, 82694},
	{"RDUP", 4, 82695},
	{"MITL", 4, 82696},
	{"DESCENDENTS", 11, 82697},
	{"MEISTER", 7, 82698},
	{"MARIAGE", 7, 82699},
	{"EZMLM", 5, 82700},
	{"TWIKIACCESSCONTROL", 18, 82701},
	{"LATED", 5, 82702},
	{"MONTERO", 7, 82703},
	{"VINL", 4, 82704},
	{"RADW", 4, 82705},
	{"DIVISIVE", 8, 82706},
	{"GUIA", 4, 82707},
	{"GASTONIA", 8, 82708},
	{"BENEDICTINE", 11, 82709},
	{"INAPPROPRIATELY", 15, 82710},
	{"REPUTATIONS", 11, 82711},
	{"VITALLY", 7, 82712},
	{"UNYA", 4, 82713},
	{"SMYC", 4, 82714},
	{"MAVIS", 5, 82715},
	{"VALENTINA", 9, 82716},
	{"LUBRICATING", 11, 82717},
	{"SDIL", 4, 82718},
	{"NYGU", 4, 82719},
	{"MYCR", 4, 82720},
	{"MSVI", 4, 82721},
	{"LPLU", 4, 82722},
	{"DBIK", 4, 82723},
	{"AJER", 4, 82724},
	{"BSFR", 4, 82725},
	{"UNDIVIDED", 9, 82726},
	{"ITWORLD", 7, 82727},
	{"DECA", 4, 82728},
	{"CHATTED", 7, 82729},
	{"LURED", 5, 82730},
	{"BRANFORD", 8, 82731},
	{"NRUD", 4, 82732},
	{"COSB", 4, 82733},
	{"ALUX", 4, 82734},
	{"HURLING", 7, 82735},
	{"KODY", 4, 82736},
	{"ACCRUALS", 8, 82737},
	{"BREVITY", 7, 82738},
	{"EPITOPE", 7, 82739},
	{"VISAGE", 6, 82740},
	{"WTAX", 4, 82741},
	{"ULPH", 4, 82742},
	{"JDJ", 3, 82743},
	{"CRENSHAW", 8, 82744},
	{"PERLMAN", 7, 82745},
	{"PRICKLY", 7, 82746},
	{"MEDALLIONS", 10, 82747},
	{"ROKR", 4, 82748},
	{"MENJ", 4, 82749},
	{"MICROTEL", 8, 82750},
	{"SEPTEMBRE", 9, 82751},
	{"FTLA", 4, 82752},
	{"GRAFF", 5, 82753},
	{"JCSG", 4, 82754},
	{"ASTONISHMENT", 12, 82755},
	{"NIGM", 4, 82756},
	{"COONEY", 6, 82757},
	{"WHITTLE", 7, 82758},
	{"OVERSHADOWED", 12, 82759},
	{"ORYJ", 4, 82760},
	{"ILDG", 4, 82761},
	{"GMTHTTP", 7, 82762},
	{"RAYBURN", 7, 82763},
	{"RESCUING", 8, 82764},
	{"SUPPRESSANT", 11, 82765},
	{"HECHT", 5, 82766},
	{"SPORTSNATION", 12, 82767},
	{"ZWIT", 4, 82768},
	{"SAWB", 4, 82769},
	{"INKJ", 4, 82770},
	{"CCNP", 4, 82771},
	{"REWORKED", 8, 82772},
	{"SENSIBILITIES", 13, 82773},
	{"MYYE", 4, 82774},
	{"CATAPULT", 8, 82775},
	{"MERITORIOUS", 11, 82776},
	{"UCEG", 4, 82777},
	{"OLKE", 4, 82778},
	{"OLFG", 4, 82779},
	{"FWAI", 4, 82780},
	{"CKGE", 4, 82781},
	{"CCAU", 4, 82782},
	{"VRIES", 5, 82783},
	{"PROCURVE", 8, 82784},
	{"CBOT", 4, 82785},
	{"ELITIST", 7, 82786},
	{"CONVOLUTED", 10, 82787},
	{"IBERIAN", 7, 82788},
	{"OPTOELECTRONICS", 15, 82789},
	{"BEHELD", 6, 82790},
	{"MAILSCANNER", 11, 82791},
	{"JANW", 4, 82792},
	{"IRSY", 4, 82793},
	{"ILCL", 4, 82794},
	{"ERDW", 4, 82795},
	{"KAZAKH", 6, 82796},
	{"MARTYRDOM", 9, 82797},
	{"STIMULATOR", 10, 82798},
	{"MANNA", 5, 82799},
	{"OCTOBRE", 7, 82800},
	{"SCHOOLCHILDREN", 14, 82801},
	{"KPAG", 4, 82802},
	{"DGAY", 4, 82803},
	{"COMMWEB", 7, 82804},
	{"THORNHILL", 9, 82805},
	{"MOORINGS", 8, 82806},
	{"TWEEZERS", 8, 82807},
	{"OUVIR", 5, 82808},
	{"FILETYPE", 8, 82809},
	{"ENBC", 4, 82810},
	{"BUDDHISTS", 9, 82811},
	{"BEARCATS", 8, 82812},
	{"FANCLUB", 7, 82813},
	{"YBOL", 4, 82814},
	{"UPUS", 4, 82815},
	{"LADL", 4, 82816},
	{"SOARS", 5, 82817},
	{"BOEHRINGER", 10, 82818},
	{"BRASILEIRA", 10, 82819},
	{"WEBSERVICES", 11, 82820},
	{"KINEMATIC", 9, 82821},
	{"CHEMIE", 6, 82822},
	{"HOUSEWORK", 9, 82823},
	{"UGSB", 4, 82824},
	{"IPFL", 4, 82825},
	{"FTPO", 4, 82826},
	{"DNEP", 4, 82827},
	{"GUNPOWDER", 9, 82828},
	{"UNDRESSED", 9, 82829},
	{"SOUTHWARD", 9, 82830},
	{"INOUE", 5, 82831},
	{"UNSUPERVISED", 12, 82832},
	{"LISZT", 5, 82833},
	{"ZWIL", 4, 82834},
	{"MMUC", 4, 82835},
	{"EMAZ", 4, 82836},
	{"ZWEI", 4, 82837},
	{"NORVEGICUS", 10, 82838},
	{"COPYCAT", 7, 82839},
	{"ORRIN", 5, 82840},
	{"ZORN", 4, 82841},
	{"XCAN", 4, 82842},
	{"UBGR", 4, 82843},
	{"PULT", 4, 82844},
	{"PESM", 4, 82845},
	{"SNOOPING", 8, 82846},
	{"WXC", 3, 82847},
	{"BXF", 3, 82848},
	{"HASHEM", 6, 82849},
	{"TELESYN", 7, 82850},
	{"MVAL", 4, 82851},
	{"DCUB", 4, 82852},
	{"RECOUNTED", 9, 82853},
	{"MCB", 3, 82854},
	{"IMPLE", 5, 82855},
	{"DENIALS", 7, 82856},
	{"PRUSSIAN", 8, 82857},
	{"ADORN", 5, 82858},
	{"DORMS", 5, 82859},
	{"PHRO", 4, 82860},
	{"KETY", 4, 82861},
	{"EXFI", 4, 82862},
	{"EURD", 4, 82863},
	{"DVAS", 4, 82864},
	{"ELIST", 5, 82865},
	{"LAMINATES", 9, 82866},
	{"INGALLS", 7, 82867},
	{"CHECKSUMS", 9, 82868},
	{"TANDBERG", 8, 82869},
	{"IIRC", 4, 82870},
	{"GOPO", 4, 82871},
	{"DUEA", 4, 82872},
	{"MACKINNON", 9, 82873},
	{"RODDY", 5, 82874},
	{"CONTEMPLATIVE", 13, 82875},
	{"MARGOLIS", 8, 82876},
	{"EROTASTE", 8, 82877},
	{"PIMPS", 5, 82878},
	{"RVEP", 4, 82879},
	{"OSMU", 4, 82880},
	{"JIML", 4, 82881},
	{"GCIV", 4, 82882},
	{"EYJA", 4, 82883},
	{"EUGL", 4, 82884},
	{"MCDOUGALL", 9, 82885},
	{"AWKWARDLY", 9, 82886},
	{"PROJETS", 7, 82887},
	{"MPX", 3, 82888},
	{"BELLES", 6, 82889},
	{"STIPULATIONS", 12, 82890},
	{"TRAVELZOO", 9, 82891},
	{"LIFELESS", 8, 82892},
	{"BAFFLE", 6, 82893},
	{"PARED", 5, 82894},
	{"THERMALLY", 9, 82895},
	{"SOBRIETY", 8, 82896},
	{"TELECONFERENCING", 16, 82897},
	{"SYBU", 4, 82898},
	{"ALBINO", 6, 82899},
	{"CARGILL", 7, 82900},
	{"VISUALIZING", 11, 82901},
	{"SLUMS", 5, 82902},
	{"MOTHERCARE", 10, 82903},
	{"ODAG", 4, 82904},
	{"NDRD", 4, 82905},
	{"KUPC", 4, 82906},
	{"SPRINTER", 8, 82907},
	{"ISOMORPHIC", 10, 82908},
	{"PEPPERDINE", 10, 82909},
	{"BURNET", 6, 82910},
	{"CVC", 3, 82911},
	{"MAHON", 5, 82912},
	{"CONJUGATION", 11, 82913},
	{"SPANIARDS", 9, 82914},
	{"MBAD", 4, 82915},
	{"MACALLY", 7, 82916},
	{"ANKLETS", 7, 82917},
	{"IMPASSE", 7, 82918},
	{"KGAM", 4, 82919},
	{"IRDN", 4, 82920},
	{"EBTW", 4, 82921},
	{"DISINFORMATION", 14, 82922},
	{"BEAVIS", 6, 82923},
	{"PILOTED", 7, 82924},
	{"DELICATESSENS", 13, 82925},
	{"INTENSIVELY", 11, 82926},
	{"ECHOCARDIOGRAPHY", 16, 82927},
	{"AMOK", 4, 82928},
	{"SUCCESSIVELY", 12, 82929},
	{"RIDDICK", 7, 82930},
	{"SHFU", 4, 82931},
	{"IDFL", 4, 82932},
	{"BOXF", 4, 82933},
	{"ORDINATES", 9, 82934},
	{"SQUAW", 5, 82935},
	{"SNOWDON", 7, 82936},
	{"GALLARIES", 9, 82937},
	{"BALDUR", 6, 82938},
	{"NCHV", 4, 82939},
	{"KSYS", 4, 82940},
	{"GUPM", 4, 82941},
	{"POMEGRANATE", 11, 82942},
	{"GLAS", 4, 82943},
	{"BOUTS", 5, 82944},
	{"WEXT", 4, 82945},
	{"GIGG", 4, 82946},
	{"AUBR", 4, 82947},
	{"ARTY", 4, 82948},
	{"LEUKOCYTE", 9, 82949},
	{"TRANSCENDS", 10, 82950},
	{"CHAU", 4, 82951},
	{"MURMUR", 6, 82952},
	{"RULT", 4, 82953},
	{"COTTER", 6, 82954},
	{"PEPTIDASE", 9, 82955},
	{"BOOKKEEPER", 10, 82956},
	{"CRICKETS", 8, 82957},
	{"POSTMODERNISM", 13, 82958},
	{"SQUEAKY", 7, 82959},
	{"SILICATE", 8, 82960},
	{"EXTINGUISHING", 13, 82961},
	{"ANGJ", 4, 82962},
	{"ALCOHOLS", 8, 82963},
	{"ZYDECO", 6, 82964},
	{"NOCHE", 5, 82965},
	{"VEEC", 4, 82966},
	{"UADD", 4, 82967},
	{"RIPB", 4, 82968},
	{"CYYO", 4, 82969},
	{"ATTACHE", 7, 82970},
	{"BULGING", 7, 82971},
	{"TRUJILLO", 8, 82972},
	{"PREDICTABLY", 11, 82973},
	{"CHEMISE", 7, 82974},
	{"FEGY", 4, 82975},
	{"WEIDER", 6, 82976},
	{"SHAREHOLDING", 12, 82977},
	{"RDSJ", 4, 82978},
	{"PTUS", 4, 82979},
	{"OIDM", 4, 82980},
	{"OFTM", 4, 82981},
	{"EDUD", 4, 82982},
	{"GIORDANO", 8, 82983},
	{"EPICS", 5, 82984},
	{"TMPH", 4, 82985},
	{"LTFI", 4, 82986},
	{"BDES", 4, 82987},
	{"SMUG", 4, 82988},
	{"CARDIOMYOPATHY", 14, 82989},
	{"APRILIA", 7, 82990},
	{"FLANKING", 8, 82991},
	{"MCNABB", 6, 82992},
	{"EFWH", 4, 82993},
	{"EFDI", 4, 82994},
	{"ECUN", 4, 82995},
	{"LENZ", 4, 82996},
	{"HOMEENCARTA", 11, 82997},
	{"DISCONNECTION", 13, 82998},
	{"SCADA", 5, 82999},
	{"PVER", 4, 83000},
	{"NKOL", 4, 83001},
	{"DKYL", 4, 83002},
	{"LMFO", 4, 83003},
	{"FFPA", 4, 83004},
	{"SPACETIME", 9, 83005},
	{"STADT", 5, 83006},
	{"VEIR", 4, 83007},
	{"NWEF", 4, 83008},
	{"AWOL", 4, 83009},
	{"PREJUDICED", 10, 83010},
	{"BIONIC", 6, 83011},
	{"LARVA", 5, 83012},
	{"MRMC", 4, 83013},
	{"GSAP", 4, 83014},
	{"BOBH", 4, 83015},
	{"BATISTA", 7, 83016},
	{"LAZINESS", 8, 83017},
	{"BOOKSHOPS", 9, 83018},
	{"FEYNMAN", 7, 83019},
	{"CAPTIONING", 10, 83020},
	{"SIBELIUS", 8, 83021},
	{"WQUA", 4, 83022},
	{"IFFW", 4, 83023},
	{"OBSTETRIC", 9, 83024},
	{"MARIGOLD", 8, 83025},
	{"OSTSEE", 6, 83026},
	{"MARTEL", 6, 83027},
	{"ICKV", 4, 83028},
	{"EFPR", 4, 83029},
	{"HCFA", 4, 83030},
	{"UKEN", 4, 83031},
	{"TYPESETTING", 11, 83032},
	{"MOULDINGS", 9, 83033},
	{"TIRELESS", 8, 83034},
	{"USYT", 4, 83035},
	{"MRSH", 4, 83036},
	{"ERVIN", 5, 83037},
	{"CHROMA", 6, 83038},
	{"LEANDER", 7, 83039},
	{"GROWL", 5, 83040},
	{"STEINBECK", 9, 83041},
	{"PUSY", 4, 83042},
	{"BIBLIOTECA", 10, 83043},
	{"NEUTROPHILS", 11, 83044},
	{"SDUC", 4, 83045},
	{"MDAR", 4, 83046},
	{"LTOY", 4, 83047},
	{"GIFI", 4, 83048},
	{"ELMC", 4, 83049},
	{"DUNBARTONSHIRE", 14, 83050},
	{"LOLLIPOP", 8, 83051},
	{"GORGES", 6, 83052},
	{"BRASH", 5, 83053},
	{"RNUC", 4, 83054},
	{"PETC", 4, 83055},
	{"NNBC", 4, 83056},
	{"LMIR", 4, 83057},
	{"DECLARATORY", 11, 83058},
	{"CORUS", 5, 83059},
	{"CANONS", 6, 83060},
	{"ELPH", 4, 83061},
	{"HYDRATE", 7, 83062},
	{"UBB", 3, 83063},
	{"ZONW", 4, 83064},
	{"HYLO", 4, 83065},
	{"PASTIMES", 8, 83066},
	{"DIURNAL", 7, 83067},
	{"LITTLEFIELD", 11, 83068},
	{"NEUTRINOS", 9, 83069},
	{"BRIC", 4, 83070},
	{"UESG", 4, 83071},
	{"NMUM", 4, 83072},
	{"NKUR", 4, 83073},
	{"KIAR", 4, 83074},
	{"GWEH", 4, 83075},
	{"DOJU", 4, 83076},
	{"CISB", 4, 83077},
	{"SUBWAYS", 7, 83078},
	{"COOLNESS", 8, 83079},
	{"WZM", 3, 83080},
	{"UQD", 3, 83081},
	{"FZB", 3, 83082},
	{"LEOMINSTER", 10, 83083},
	{"TUNK", 4, 83084},
	{"FITL", 4, 83085},
	{"SNIPSNAP", 8, 83086},
	{"BUSCA", 5, 83087},
	{"NEGATIVITY", 10, 83088},
	{"ARCVIEW", 7, 83089},
	{"RNPL", 4, 83090},
	{"KYWI", 4, 83091},
	{"CVOT", 4, 83092},
	{"SHIPWRECK", 9, 83093},
	{"PICASA", 6, 83094},
	{"FADER", 5, 83095},
	{"TORTILLAS", 9, 83096},
	{"LIBB", 4, 83097},
	{"IRKN", 4, 83098},
	{"DMYW", 4, 83099},
	{"AWWW", 4, 83100},
	{"DARA", 4, 83101},
	{"UNCONSCIOUSLY", 13, 83102},
	{"BUFFALOES", 9, 83103},
	{"MARNE", 5, 83104},
	{"RAGGA", 5, 83105},
	{"INNOVA", 6, 83106},
	{"DOORBELL", 8, 83107},
	{"RAGL", 4, 83108},
	{"EFSC", 4, 83109},
	{"DISSOLVING", 10, 83110},
	{"OSMOND", 6, 83111},
	{"UNSETTLING", 10, 83112},
	{"OLLD", 4, 83113},
	{"KYDE", 4, 83114},
	{"IGGO", 4, 83115},
	{"EXPLICITO", 9, 83116},
	{"PHILA", 5, 83117},
	{"BUGGER", 6, 83118},
	{"PERSSON", 7, 83119},
	{"EMBOLISM", 8, 83120},
	{"HDAL", 4, 83121},
	{"FHUR", 4, 83122},
	{"SILVERPLATE", 11, 83123},
	{"RUMC", 4, 83124},
	{"IPAW", 4, 83125},
	{"AOFD", 4, 83126},
	{"ROEBUCK", 7, 83127},
	{"HIGHNESS", 8, 83128},
	{"OLLP", 4, 83129},
	{"LIPTON", 6, 83130},
	{"ABSTRACTED", 10, 83131},
	{"STARLING", 8, 83132},
	{"TYPHOID", 7, 83133},
	{"CORELDRAW", 9, 83134},
	{"UOTB", 4, 83135},
	{"MYBL", 4, 83136},
	{"ILPL", 4, 83137},
	{"FHYP", 4, 83138},
	{"BOXB", 4, 83139},
	{"HANEY", 5, 83140},
	{"PERFECTING", 10, 83141},
	{"GLOBEMEDIA", 10, 83142},
	{"BATB", 4, 83143},
	{"ADRENALIN", 9, 83144},
	{"MURPHYS", 7, 83145},
	{"NICKLAUS", 8, 83146},
	{"YARDLEY", 7, 83147},
	{"AFGHANI", 7, 83148},
	{"FURTHERANCE", 11, 83149},
	{"NRAR", 4, 83150},
	{"GOWR", 4, 83151},
	{"DJAZ", 4, 83152},
	{"HAULERS", 7, 83153},
	{"ENERGIZE", 8, 83154},
	{"PROHIBITIVE", 11, 83155},
	{"SYDD", 4, 83156},
	{"BARCODES", 8, 83157},
	{"DLINK", 5, 83158},
	{"SLITS", 5, 83159},
	{"INCLUD", 6, 83160},
	{"INQUIRES", 8, 83161},
	{"ORGIE", 5, 83162},
	{"XSYS", 4, 83163},
	{"EPWO", 4, 83164},
	{"MACNN", 5, 83165},
	{"DANNI", 5, 83166},
	{"IMAGED", 6, 83167},
	{"SPRAYERS", 8, 83168},
	{"YULE", 4, 83169},
	{"LINDBERG", 8, 83170},
	{"SWEF", 4, 83171},
	{"NDZI", 4, 83172},
	{"FILESHARING", 11, 83173},
	{"CALIBRATIONS", 12, 83174},
	{"ATORVASTATIN", 12, 83175},
	{"TEAGUE", 6, 83176},
	{"PHANTASY", 8, 83177},
	{"VANTEC", 6, 83178},
	{"LATTICES", 8, 83179},
	{"CUCAMONGA", 9, 83180},
	{"SPRACHE", 7, 83181},
	{"WARNE", 5, 83182},
	{"DERWENT", 7, 83183},
	{"HOSPITLS", 8, 83184},
	{"FLINTSTONES", 11, 83185},
	{"REZW", 4, 83186},
	{"RECC", 4, 83187},
	{"FMYH", 4, 83188},
	{"ALDF", 4, 83189},
	{"ROTISSERIE", 10, 83190},
	{"ORCS", 4, 83191},
	{"SCALLOP", 7, 83192},
	{"YOIL", 4, 83193},
	{"MHUS", 4, 83194},
	{"LBYP", 4, 83195},
	{"KUPH", 4, 83196},
	{"GENM", 4, 83197},
	{"DGAU", 4, 83198},
	{"BIOSTAR", 7, 83199},
	{"CRUSTY", 6, 83200},
	{"COMPUTATIONALLY", 15, 83201},
	{"STILLNESS", 9, 83202},
	{"JOBSEEKER", 9, 83203},
	{"OGCA", 4, 83204},
	{"MFUR", 4, 83205},
	{"KLOC", 4, 83206},
	{"AMVI", 4, 83207},
	{"PRECIPITATE", 11, 83208},
	{"SUNBATHING", 10, 83209},
	{"RONDA", 5, 83210},
	{"UNDERLIE", 8, 83211},
	{"NRYV", 4, 83212},
	{"KPAN", 4, 83213},
	{"DOWB", 4, 83214},
	{"CERRITOS", 8, 83215},
	{"LMIT", 4, 83216},
	{"FALG", 4, 83217},
	{"PHARISEES", 9, 83218},
	{"CHARD", 5, 83219},
	{"PERSHING", 8, 83220},
	{"CLOTTING", 8, 83221},
	{"PROGRAMM", 8, 83222},
	{"SINGLET", 7, 83223},
	{"MORNINGSIDE", 11, 83224},
	{"MMIA", 4, 83225},
	{"SIMM", 4, 83226},
	{"RPIP", 4, 83227},
	{"RAGT", 4, 83228},
	{"PFIG", 4, 83229},
	{"KECE", 4, 83230},
	{"IZZE", 4, 83231},
	{"FFYA", 4, 83232},
	{"NICKNAMED", 9, 83233},
	{"HACKENSACK", 10, 83234},
	{"KINSHASA", 8, 83235},
	{"AVAILABLITY", 11, 83236},
	{"LRD", 3, 83237},
	{"LUGS", 4, 83238},
	{"DRONES", 6, 83239},
	{"KIDDIES", 7, 83240},
	{"TBAK", 4, 83241},
	{"CPSC", 4, 83242},
	{"HEBERT", 6, 83243},
	{"MINSTER", 7, 83244},
	{"CIMARRON", 8, 83245},
	{"CROWELL", 7, 83246},
	{"FANART", 6, 83247},
	{"WISR", 4, 83248},
	{"LSBI", 4, 83249},
	{"GDOO", 4, 83250},
	{"DJOY", 4, 83251},
	{"NAGIN", 5, 83252},
	{"COLLAPSIBLE", 11, 83253},
	{"HELSING", 7, 83254},
	{"MJAC", 4, 83255},
	{"HPAP", 4, 83256},
	{"SULLY", 5, 83257},
	{"HARINGEY", 8, 83258},
	{"PROPHYLACTIC", 12, 83259},
	{"ROSENFELD", 9, 83260},
	{"CITYSCAPE", 9, 83261},
	{"TRADEOFF", 8, 83262},
	{"INSTILL", 7, 83263},
	{"YPSILANTI", 9, 83264},
	{"XASB", 4, 83265},
	{"RHYP", 4, 83266},
	{"ERJR", 4, 83267},
	{"LIFES", 5, 83268},
	{"IMATE", 5, 83269},
	{"FIRESTORM", 9, 83270},
	{"VIEP", 4, 83271},
	{"OWOW", 4, 83272},
	{"HOMESTAY", 8, 83273},
	{"INEPT", 5, 83274},
	{"SHISEIDO", 8, 83275},
	{"STEVES", 6, 83276},
	{"UTCI", 4, 83277},
	{"SOFZ", 4, 83278},
	{"PERT", 4, 83279},
	{"SASCHA", 6, 83280},
	{"EFSW", 4, 83281},
	{"AXPR", 4, 83282},
	{"DEPOSITIONS", 11, 83283},
	{"CAMPED", 6, 83284},
	{"FRAUGHT", 7, 83285},
	{"PERPLEXED", 9, 83286},
	{"INYU", 4, 83287},
	{"REPLENISH", 9, 83288},
	{"RECONSTRUCTING", 14, 83289},
	{"XTRI", 4, 83290},
	{"FEEC", 4, 83291},
	{"DROPLET", 7, 83292},
	{"NECESSITATED", 12, 83293},
	{"SLOWEST", 7, 83294},
	{"WOFW", 4, 83295},
	{"ISKW", 4, 83296},
	{"HDUE", 4, 83297},
	{"BBEC", 4, 83298},
	{"LAKOTA", 6, 83299},
	{"UNWILLINGNESS", 13, 83300},
	{"PSPL", 4, 83301},
	{"NYVO", 4, 83302},
	{"DEHU", 4, 83303},
	{"REVISES", 7, 83304},
	{"MACRAE", 6, 83305},
	{"XKY", 3, 83306},
	{"CUQ", 3, 83307},
	{"PARLAY", 6, 83308},
	{"WOODVILLE", 9, 83309},
	{"IMKI", 4, 83310},
	{"XLARGE", 6, 83311},
	{"PROFORM", 7, 83312},
	{"ESPERANZA", 9, 83313},
	{"DIVAN", 5, 83314},
	{"GOTHAMIST", 9, 83315},
	{"COEXIST", 7, 83316},
	{"FULLTIME", 8, 83317},
	{"MACOSX", 6, 83318},
	{"METRA", 5, 83319},
	{"UICH", 4, 83320},
	{"OBBA", 4, 83321},
	{"FPLU", 4, 83322},
	{"CYG", 3, 83323},
	{"TURTLENECK", 10, 83324},
	{"LEHRER", 6, 83325},
	{"HOLBORN", 7, 83326},
	{"MBSO", 4, 83327},
	{"BINB", 4, 83328},
	{"AQUOS", 5, 83329},
	{"CONCOURS", 8, 83330},
	{"EXTRAORDINAIRE", 14, 83331},
	{"UMFE", 4, 83332},
	{"NVEC", 4, 83333},
	{"LLEK", 4, 83334},
	{"KWEW", 4, 83335},
	{"IXME", 4, 83336},
	{"EUNM", 4, 83337},
	{"ISBL", 4, 83338},
	{"GIGABYTES", 9, 83339},
	{"TRIANGULATION", 13, 83340},
	{"BURLEIGH", 8, 83341},
	{"ELOQUENCE", 9, 83342},
	{"SUBV", 4, 83343},
	{"NWEP", 4, 83344},
	{"BENF", 4, 83345},
	{"ANARCHISM", 9, 83346},
	{"STABILIZERS", 11, 83347},
	{"GBIC", 4, 83348},
	{"DEFINITIVELY", 12, 83349},
	{"NATCHEZ", 7, 83350},
	{"TRIPPED", 7, 83351},
	{"STREWN", 6, 83352},
	{"CIBA", 4, 83353},
	{"MYMU", 4, 83354},
	{"BIUS", 4, 83355},
	{"ACTIVA", 6, 83356},
	{"TERRANCE", 8, 83357},
	{"SMOOTHIES", 9, 83358},
	{"OMCC", 4, 83359},
	{"DDIL", 4, 83360},
	{"CKTU", 4, 83361},
	{"ORSAY", 5, 83362},
	{"RUBLES", 6, 83363},
	{"BELLING", 7, 83364},
	{"BNSF", 4, 83365},
	{"OPPS", 4, 83366},
	{"YFLU", 4, 83367},
	{"OPHR", 4, 83368},
	{"IRMC", 4, 83369},
	{"REPRESENTATIONAL", 16, 83370},
	{"KAGOME", 6, 83371},
	{"SNARK", 5, 83372},
	{"WOODARD", 7, 83373},
	{"BEWILDERED", 10, 83374},
	{"MALIGNANCY", 10, 83375},
	{"BEATINGS", 8, 83376},
	{"ZPRO", 4, 83377},
	{"SHDR", 4, 83378},
	{"NIMB", 4, 83379},
	{"ELTM", 4, 83380},
	{"EDCY", 4, 83381},
	{"MAKATI", 6, 83382},
	{"CBM", 3, 83383},
	{"COPIOUS", 7, 83384},
	{"CADE", 4, 83385},
	{"RNCR", 4, 83386},
	{"OOKJ", 4, 83387},
	{"DOBL", 4, 83388},
	{"FARAH", 5, 83389},
	{"SITEWIDE", 8, 83390},
	{"NEWFOUND", 8, 83391},
	{"COLLIDER", 8, 83392},
	{"PFRE", 4, 83393},
	{"DOWR", 4, 83394},
	{"TREMBLE", 7, 83395},
	{"CANDI", 5, 83396},
	{"INSTANTANEOUSLY", 15, 83397},
	{"LGF", 3, 83398},
	{"BOYLSTON", 8, 83399},
	{"RIZZO", 5, 83400},
	{"WRISTWATCH", 10, 83401},
	{"OWENSBORO", 9, 83402},
	{"PAPAS", 5, 83403},
	{"SUBSCRIBES", 10, 83404},
	{"THUMP", 5, 83405},
	{"MPES", 4, 83406},
	{"HICF", 4, 83407},
	{"POMPEII", 7, 83408},
	{"WINING", 6, 83409},
	{"ALLUDED", 7, 83410},
	{"ABERRATIONS", 11, 83411},
	{"SOMM", 4, 83412},
	{"AMTU", 4, 83413},
	{"SOJOURN", 7, 83414},
	{"GANESH", 6, 83415},
	{"CASTLETON", 9, 83416},
	{"ZIPPERS", 7, 83417},
	{"DECAF", 5, 83418},
	{"UNDQ", 4, 83419},
	{"HVID", 4, 83420},
	{"ARUD", 4, 83421},
	{"EMPHASISES", 10, 83422},
	{"CBP", 3, 83423},
	{"CRX", 3, 83424},
	{"STATEROOM", 9, 83425},
	{"SHAKUR", 6, 83426},
	{"URAU", 4, 83427},
	{"PTSB", 4, 83428},
	{"KLEG", 4, 83429},
	{"GAYC", 4, 83430},
	{"BENW", 4, 83431},
	{"EUROFFICE", 9, 83432},
	{"ROUSH", 5, 83433},
	{"CALORIC", 7, 83434},
	{"PLAINTEXT", 9, 83435},
	{"DBEJ", 4, 83436},
	{"CTOD", 4, 83437},
	{"AZAL", 4, 83438},
	{"DANIELE", 7, 83439},
	{"NUCLEOSIDE", 10, 83440},
	{"BUTTERCUP", 9, 83441},
	{"OAKES", 5, 83442},
	{"SEARLE", 6, 83443},
	{"PALACIO", 7, 83444},
	{"SHUPPAN", 7, 83445},
	{"LANYARDS", 8, 83446},
	{"CUSHMAN", 7, 83447},
	{"ADHERENTS", 9, 83448},
	{"ADMISSIBILITY", 13, 83449},
	{"OUAP", 4, 83450},
	{"COURTENAY", 9, 83451},
	{"ASPARTAME", 9, 83452},
	{"SLEUTH", 6, 83453},
	{"TRUDY", 5, 83454},
	{"HERBACEOUS", 10, 83455},
	{"DISTINGUISHABLE", 15, 83456},
	{"AJIM", 4, 83457},
	{"IMMATERIAL", 10, 83458},
	{"SURGING", 7, 83459},
	{"MAGIX", 5, 83460},
	{"UMDO", 4, 83461},
	{"SQMI", 4, 83462},
	{"RIXA", 4, 83463},
	{"RIPM", 4, 83464},
	{"CWES", 4, 83465},
	{"AURANGABAD", 10, 83466},
	{"GREASED", 7, 83467},
	{"GOLDING", 7, 83468},
	{"ETHNOGRAPHY", 11, 83469},
	{"YAMAGUCHI", 9, 83470},
	{"CONTRABAND", 10, 83471},
	{"BULKHEAD", 8, 83472},
	{"FLAGGING", 8, 83473},
	{"HERZEGOWINA", 11, 83474},
	{"MYEL", 4, 83475},
	{"ILTM", 4, 83476},
	{"CICE", 4, 83477},
	{"CFLO", 4, 83478},
	{"MINAS", 5, 83479},
	{"PARADISO", 8, 83480},
	{"CITYSCAPES", 10, 83481},
	{"WILLED", 6, 83482},
	{"REPLENISHMENT", 13, 83483},
	{"AUTOBYTEL", 9, 83484},
	{"DFOS", 4, 83485},
	{"WOUNDING", 8, 83486},
	{"KROGER", 6, 83487},
	{"DEXAMETHASONE", 13, 83488},
	{"INCLEMENT", 9, 83489},
	{"STRUNK", 6, 83490},
	{"OBSL", 4, 83491},
	{"LKMU", 4, 83492},
	{"CTMU", 4, 83493},
	{"CHJI", 4, 83494},
	{"BAFI", 4, 83495},
	{"YOGHURT", 7, 83496},
	{"NATIONALISTS", 12, 83497},
	{"DEFINABLE", 9, 83498},
	{"BRUIN", 5, 83499},
	{"PSYCHOANALYTIC", 14, 83500},
	{"MAGPIE", 6, 83501},
	{"SFUS", 4, 83502},
	{"LAMW", 4, 83503},
	{"IPOV", 4, 83504},
	{"GBYH", 4, 83505},
	{"RESERVA", 7, 83506},
	{"NASSER", 6, 83507},
	{"PYAB", 4, 83508},
	{"SIMP", 4, 83509},
	{"ZMAILER", 7, 83510},
	{"BIRTHING", 8, 83511},
	{"ROBBING", 7, 83512},
	{"COLLINSVILLE", 12, 83513},
	{"DIMER", 5, 83514},
	{"POWELLS", 7, 83515},
	{"ABEBOOKS", 8, 83516},
	{"IMPARTIALITY", 12, 83517},
	{"STEMWARE", 8, 83518},
	{"GDOL", 4, 83519},
	{"LANDSAT", 7, 83520},
	{"XCUR", 4, 83521},
	{"TDUK", 4, 83522},
	{"ARLR", 4, 83523},
	{"PHOSPHATES", 10, 83524},
	{"PEEBLES", 7, 83525},
	{"DEWAR", 5, 83526},
	{"DOCKED", 6, 83527},
	{"BURP", 4, 83528},
	{"RADIOISOTOPES", 13, 83529},
	{"OBSTETRICIANS", 13, 83530},
	{"HARPSICHORD", 11, 83531},
	{"MGOL", 4, 83532},
	{"FUNR", 4, 83533},
	{"EUVR", 4, 83534},
	{"DAMD", 4, 83535},
	{"AYEM", 4, 83536},
	{"APIG", 4, 83537},
	{"VINSON", 6, 83538},
	{"FAHEY", 5, 83539},
	{"CAPES", 5, 83540},
	{"MULTISYNC", 9, 83541},
	{"IMPERSONAL", 10, 83542},
	{"PROPOSER", 8, 83543},
	{"WORLEY", 6, 83544},
	{"NYPH", 4, 83545},
	{"FHEM", 4, 83546},
	{"INTERPOLATED", 12, 83547},
	{"KERRI", 5, 83548},
	{"STROLLING", 9, 83549},
	{"ARITH", 5, 83550},
	{"OYDI", 4, 83551},
	{"HRUM", 4, 83552},
	{"MORO", 4, 83553},
	{"DEMOCRATICALLY", 14, 83554},
	{"DATASOURCE", 10, 83555},
	{"SALVO", 5, 83556},
	{"TWIGS", 5, 83557},
	{"MCELROY", 7, 83558},
	{"UMEP", 4, 83559},
	{"JAYC", 4, 83560},
	{"IGOF", 4, 83561},
	{"FURIOUSLY", 9, 83562},
	{"SHOPGENIE", 9, 83563},
	{"EPITOME", 7, 83564},
	{"UDEV", 4, 83565},
	{"ZKW", 3, 83566},
	{"YQC", 3, 83567},
	{"VKW", 3, 83568},
	{"VCK", 3, 83569},
	{"YGAS", 4, 83570},
	{"MIED", 4, 83571},
	{"NICOL", 5, 83572},
	{"CAMARA", 6, 83573},
	{"DEGAS", 5, 83574},
	{"BENASSI", 7, 83575},
	{"PREFABRICATED", 13, 83576},
	{"GASTRO", 6, 83577},
	{"ACCESSOR", 8, 83578},
	{"KENJ", 4, 83579},
	{"DSJO", 4, 83580},
	{"METEORITES", 10, 83581},
	{"JOKED", 5, 83582},
	{"BREATHS", 7, 83583},
	{"LIPOPROTEINS", 12, 83584},
	{"LILIAN", 6, 83585},
	{"WSMI", 4, 83586},
	{"ATTLEBORO", 9, 83587},
	{"GLANCING", 8, 83588},
	{"YTAP", 4, 83589},
	{"RPSH", 4, 83590},
	{"OMMC", 4, 83591},
	{"NUEM", 4, 83592},
	{"KWEC", 4, 83593},
	{"PARENTERAL", 10, 83594},
	{"BIOSYSTEMS", 10, 83595},
	{"DISCARDING", 10, 83596},
	{"FARED", 5, 83597},
	{"FLECK", 5, 83598},
	{"CEREBROVASCULAR", 15, 83599},
	{"XMIL", 4, 83600},
	{"BAHRAINI", 8, 83601},
	{"ACTUARIES", 9, 83602},
	{"DELICATESSEN", 12, 83603},
	{"PSDU", 4, 83604},
	{"EPTL", 4, 83605},
	{"DKAS", 4, 83606},
	{"DBUF", 4, 83607},
	{"MARIANNA", 8, 83608},
	{"CREATAS", 7, 83609},
	{"KIDDERMINSTER", 13, 83610},
	{"WAUKEGAN", 8, 83611},
	{"XEDC", 4, 83612},
	{"MAPT", 4, 83613},
	{"LCUP", 4, 83614},
	{"ANTIFUNGAL", 10, 83615},
	{"INFLAMED", 8, 83616},
	{"PROMULGATE", 10, 83617},
	{"MVR", 3, 83618},
	{"NDHR", 4, 83619},
	{"KWRI", 4, 83620},
	{"KGIA", 4, 83621},
	{"CLOUGH", 6, 83622},
	{"SOCORRO", 7, 83623},
	{"MAXIMIZED", 9, 83624},
	{"UNLINK", 6, 83625},
	{"DLX", 3, 83626},
	{"SHADOWING", 9, 83627},
	{"WERT", 4, 83628},
	{"REGIMENTAL", 10, 83629},
	{"ERYTHROMYCIN", 12, 83630},
	{"IPWR", 4, 83631},
	{"ICYH", 4, 83632},
	{"GELU", 4, 83633},
	{"DTIP", 4, 83634},
	{"AYOB", 4, 83635},
	{"SIGNIFYING", 10, 83636},
	{"TUTTE", 5, 83637},
	{"RECTIFIED", 9, 83638},
	{"SAVOIE", 6, 83639},
	{"NADY", 4, 83640},
	{"LEIBNIZ", 7, 83641},
	{"FLIX", 4, 83642},
	{"LJEW", 4, 83643},
	{"KEPH", 4, 83644},
	{"IGCA", 4, 83645},
	{"GNSP", 4, 83646},
	{"FLANKED", 7, 83647},
	{"CUSP", 4, 83648},
	{"HOMERS", 6, 83649},
	{"CRANDALL", 8, 83650},
	{"HOLCOMB", 7, 83651},
	{"BAYONNE", 7, 83652},
	{"PRIMACY", 7, 83653},
	{"BEAULIEU", 8, 83654},
	{"PACR", 4, 83655},
	{"NMCD", 4, 83656},
	{"LLSQ", 4, 83657},
	{"LBEK", 4, 83658},
	{"IGOU", 4, 83659},
	{"HEBM", 4, 83660},
	{"HDER", 4, 83661},
	{"DYPU", 4, 83662},
	{"CUTM", 4, 83663},
	{"ABINGTON", 8, 83664},
	{"FUEGO", 5, 83665},
	{"POINTY", 6, 83666},
	{"HAMRADIO", 8, 83667},
	{"MONMOUTHSHIRE", 13, 83668},
	{"DANVERS", 7, 83669},
	{"BUCKLAND", 8, 83670},
	{"TDIM", 4, 83671},
	{"SRUI", 4, 83672},
	{"PLOC", 4, 83673},
	{"FMYM", 4, 83674},
	{"BHAV", 4, 83675},
	{"FCAB", 4, 83676},
	{"DJET", 4, 83677},
	{"BAPTISMS", 8, 83678},
	{"CENTRALE", 8, 83679},
	{"BACKPREVIOUS", 12, 83680},
	{"EYEING", 6, 83681},
	{"CARNAVAL", 8, 83682},
	{"RECOMPILE", 9, 83683},
	{"WKSW", 4, 83684},
	{"EWEK", 4, 83685},
	{"AZDA", 4, 83686},
	{"MAINBOARDS", 10, 83687},
	{"FCLOSE", 6, 83688},
	{"BADE", 4, 83689},
	{"MELODIAS", 8, 83690},
	{"INSOLVENT", 9, 83691},
	{"CLIQUEZ", 7, 83692},
	{"MISTS", 5, 83693},
	{"RKFA", 4, 83694},
	{"RBAU", 4, 83695},
	{"MDIE", 4, 83696},
	{"DOBERMAN", 8, 83697},
	{"INSTALLSHIELD", 13, 83698},
	{"FASB", 4, 83699},
	{"CARMINE", 7, 83700},
	{"RERN", 4, 83701},
	{"HTPC", 4, 83702},
	{"RELINQUISH", 10, 83703},
	{"EMILIE", 6, 83704},
	{"STOVER", 6, 83705},
	{"SUCCINCT", 8, 83706},
	{"PALPABLE", 8, 83707},
	{"CERRUTI", 7, 83708},
	{"ELJU", 4, 83709},
	{"BRAINERD", 8, 83710},
	{"OXYCODONE", 9, 83711},
	{"ISTITUTO", 8, 83712},
	{"REVS", 4, 83713},
	{"COMPRESSIVE", 11, 83714},
	{"ESTAR", 5, 83715},
	{"WOMBAT", 6, 83716},
	{"ANTENNE", 7, 83717},
	{"IGCI", 4, 83718},
	{"PATEK", 5, 83719},
	{"ZIPPY", 5, 83720},
	{"NETELLER", 8, 83721},
	{"ODEON", 5, 83722},
	{"SBIR", 4, 83723},
	{"OEUV", 4, 83724},
	{"INHALE", 6, 83725},
	{"DREAMT", 6, 83726},
	{"BACKSLASH", 9, 83727},
	{"TOWNHOME", 8, 83728},
	{"VICTORVILLE", 11, 83729},
	{"AMITYVILLE", 10, 83730},
	{"ARPA", 4, 83731},
	{"CONVULSIONS", 11, 83732},
	{"SNOWSHOES", 9, 83733},
	{"UMLO", 4, 83734},
	{"LAGW", 4, 83735},
	{"GTHF", 4, 83736},
	{"DNTY", 4, 83737},
	{"GOERS", 5, 83738},
	{"CHIPPER", 7, 83739},
	{"GULFSTREAM", 10, 83740},
	{"MODULATE", 8, 83741},
	{"XSERVER", 7, 83742},
	{"INFOSEC", 7, 83743},
	{"FIANCEE", 7, 83744},
	{"XIOM", 4, 83745},
	{"UBVE", 4, 83746},
	{"GBYM", 4, 83747},
	{"UNDERWIRED", 10, 83748},
	{"AMBIGUITIES", 11, 83749},
	{"NOREPINEPHRINE", 14, 83750},
	{"KUNDALINI", 9, 83751},
	{"ELKTON", 6, 83752},
	{"BLUMEN", 6, 83753},
	{"YOLK", 4, 83754},
	{"MEDIOCRITY", 10, 83755},
	{"CARCASSONNE", 11, 83756},
	{"RELT", 4, 83757},
	{"IREJ", 4, 83758},
	{"SAYGRACE", 8, 83759},
	{"RHYMING", 7, 83760},
	{"SUCHT", 5, 83761},
	{"APPENDING", 9, 83762},
	{"TRANSCENDENT", 12, 83763},
	{"LICHEN", 6, 83764},
	{"LAPSED", 6, 83765},
	{"UKIT", 4, 83766},
	{"AALB", 4, 83767},
	{"MARATHI", 7, 83768},
	{"SONGBOOKS", 9, 83769},
	{"ISLAMISTS", 9, 83770},
	{"RECURSOS", 8, 83771},
	{"NEWCOMB", 7, 83772},
	{"STAMPA", 6, 83773},
	{"NEWSCAST", 8, 83774},
	{"UEZW", 4, 83775},
	{"SUEP", 4, 83776},
	{"KIFI", 4, 83777},
	{"STOCKWELL", 9, 83778},
	{"TWAG", 4, 83779},
	{"ORUI", 4, 83780},
	{"IOFU", 4, 83781},
	{"HAGL", 4, 83782},
	{"GSRO", 4, 83783},
	{"NEDERLANDSE", 11, 83784},
	{"OUTTAKES", 8, 83785},
	{"STROKED", 7, 83786},
	{"OLNC", 4, 83787},
	{"KASU", 4, 83788},
	{"JASP", 4, 83789},
	{"FTDR", 4, 83790},
	{"GALLOP", 6, 83791},
	{"LAVIE", 5, 83792},
	{"CULL", 4, 83793},
	{"NAWF", 4, 83794},
	{"KSGA", 4, 83795},
	{"ICUO", 4, 83796},
	{"EBTR", 4, 83797},
	{"UNSATISFIED", 11, 83798},
	{"RETINOPATHY", 11, 83799},
	{"DEPORTES", 8, 83800},
	{"TREMONT", 7, 83801},
	{"BARRIO", 6, 83802},
	{"BUGGIES", 7, 83803},
	{"ZACKS", 5, 83804},
	{"AYGU", 4, 83805},
	{"EXERCISABLE", 11, 83806},
	{"SPEEDUP", 7, 83807},
	{"MINSTREL", 8, 83808},
	{"HOLL", 4, 83809},
	{"CONTENTMENT", 11, 83810},
	{"CIBC", 4, 83811},
	{"ARKJ", 4, 83812},
	{"ONTOLOGICAL", 11, 83813},
	{"FAREHAM", 7, 83814},
	{"THINKSTOCK", 10, 83815},
	{"FLASHBACKS", 10, 83816},
	{"XSPO", 4, 83817},
	{"GNEC", 4, 83818},
	{"KENNETT", 7, 83819},
	{"CRANIUM", 7, 83820},
	{"DENTURES", 8, 83821},
	{"ECKERD", 6, 83822},
	{"XETRA", 5, 83823},
	{"MMYD", 4, 83824},
	{"KEIF", 4, 83825},
	{"FTBO", 4, 83826},
	{"COPL", 4, 83827},
	{"QKU", 3, 83828},
	{"LZV", 3, 83829},
	{"KXF", 3, 83830},
	{"GKJ", 3, 83831},
	{"POLITIC", 7, 83832},
	{"TUMM", 4, 83833},
	{"OWTU", 4, 83834},
	{"OMGI", 4, 83835},
	{"KMOU", 4, 83836},
	{"EKFR", 4, 83837},
	{"REIMBURSABLE", 12, 83838},
	{"INFORMIT", 8, 83839},
	{"CDBG", 4, 83840},
	{"TPMM", 4, 83841},
	{"GIBR", 4, 83842},
	{"AYKE", 4, 83843},
	{"EXCHEQUER", 9, 83844},
	{"YELTSIN", 7, 83845},
	{"NITRATES", 8, 83846},
	{"AERUGINOSA", 10, 83847},
	{"RPATH", 5, 83848},
	{"ARCHAEOLOGIST", 13, 83849},
	{"MITOTIC", 7, 83850},
	{"RMRA", 4, 83851},
	{"ONCD", 4, 83852},
	{"HOWV", 4, 83853},
	{"DOLY", 4, 83854},
	{"BMEM", 4, 83855},
	{"GENERALISED", 11, 83856},
	{"FALSEHOOD", 9, 83857},
	{"OUTLIERS", 8, 83858},
	{"SLUGS", 5, 83859},
	{"FRAC", 4, 83860},
	{"INCK", 4, 83861},
	{"COWON", 5, 83862},
	{"SEMIFINAL", 9, 83863},
	{"DEACTIVATE", 10, 83864},
	{"STUDIE", 6, 83865},
	{"KAZAKSTAN", 9, 83866},
	{"CITESUMMARY", 11, 83867},
	{"KUBOTA", 6, 83868},
	{"KDEF", 4, 83869},
	{"HNBR", 4, 83870},
	{"CHROOT", 6, 83871},
	{"FALCIPARUM", 10, 83872},
	{"SHIFTERS", 8, 83873},
	{"LDIL", 4, 83874},
	{"FPIL", 4, 83875},
	{"EMTR", 4, 83876},
	{"CNOM", 4, 83877},
	{"UNDETECTED", 10, 83878},
	{"MEPIS", 5, 83879},
	{"CARIES", 6, 83880},
	{"CARCASSES", 9, 83881},
	{"UESK", 4, 83882},
	{"HIRU", 4, 83883},
	{"DEXW", 4, 83884},
	{"MICROSTRUCTURE", 14, 83885},
	{"RINGWOOD", 8, 83886},
	{"PLEASER", 7, 83887},
	{"PIERO", 5, 83888},
	{"CANDLESTICKS", 12, 83889},
	{"COMPUSERVE", 10, 83890},
	{"ODDT", 4, 83891},
	{"HPAD", 4, 83892},
	{"DISASSEMBLY", 11, 83893},
	{"MITER", 5, 83894},
	{"PROPOSITIONAL", 13, 83895},
	{"JAVAWORLD", 9, 83896},
	{"WRITEUPS", 8, 83897},
	{"HOSKINS", 7, 83898},
	{"MYES", 4, 83899},
	{"BUYTOP", 6, 83900},
	{"FROME", 5, 83901},
	{"TALKIE", 6, 83902},
	{"ROSALIE", 7, 83903},
	{"OGSF", 4, 83904},
	{"MINGLED", 7, 83905},
	{"EXXONMOBIL", 10, 83906},
	{"EMERYVILLE", 10, 83907},
	{"RAFTS", 5, 83908},
	{"GAMEPAD", 7, 83909},
	{"METAZOA", 7, 83910},
	{"INDULGENT", 9, 83911},
	{"ZESF", 4, 83912},
	{"KML", 3, 83913},
	{"MAUL", 4, 83914},
	{"TAOISEACH", 9, 83915},
	{"SISKIYOU", 8, 83916},
	{"CENSUSES", 8, 83917},
	{"OFFSEASON", 9, 83918},
	{"SCIENZE", 7, 83919},
	{"NFLP", 4, 83920},
	{"LKAS", 4, 83921},
	{"LONGED", 6, 83922},
	{"SHELVED", 7, 83923},
	{"RAMMED", 6, 83924},
	{"CARRYOVER", 9, 83925},
	{"WAILING", 7, 83926},
	{"FAGAN", 5, 83927},
	{"JADA", 4, 83928},
	{"WHOLEHEARTEDLY", 14, 83929},
	{"SHRUGS", 6, 83930},
	{"UREQ", 4, 83931},
	{"MTRU", 4, 83932},
	{"POLYPS", 6, 83933},
	{"AVAST", 5, 83934},
	{"NORTHPORT", 9, 83935},
	{"INELASTIC", 9, 83936},
	{"PUEBLA", 6, 83937},
	{"IDPS", 4, 83938},
	{"WARRENTON", 9, 83939},
	{"WFIL", 4, 83940},
	{"TCOF", 4, 83941},
	{"RMSY", 4, 83942},
	{"LEYK", 4, 83943},
	{"FROW", 4, 83944},
	{"FFSU", 4, 83945},
	{"TRAFFICKERS", 11, 83946},
	{"NECKLINE", 8, 83947},
	{"AERODYNAMICS", 12, 83948},
	{"URGY", 4, 83949},
	{"VERTEBRAE", 9, 83950},
	{"MOANS", 5, 83951},
	{"SATCODX", 7, 83952},
	{"ODAW", 4, 83953},
	{"MDET", 4, 83954},
	{"LPEP", 4, 83955},
	{"APAK", 4, 83956},
	{"BUFFETS", 7, 83957},
	{"ARISTOCRACY", 11, 83958},
	{"LEVIATHAN", 9, 83959},
	{"EAVES", 5, 83960},
	{"DFG", 3, 83961},
	{"CLASSICO", 8, 83962},
	{"HARVMAC", 7, 83963},
	{"UISX", 4, 83964},
	{"ALKY", 4, 83965},
	{"WRINKLED", 8, 83966},
	{"POPULARLY", 9, 83967},
	{"BRINKLEY", 8, 83968},
	{"MARRED", 6, 83969},
	{"XTMA", 4, 83970},
	{"VORW", 4, 83971},
	{"GRAR", 4, 83972},
	{"ELTG", 4, 83973},
	{"MINIMISING", 10, 83974},
	{"BIFURCATION", 11, 83975},
	{"KIMI", 4, 83976},
	{"NPCS", 4, 83977},
	{"ZENM", 4, 83978},
	{"UPOL", 4, 83979},
	{"CNOV", 4, 83980},
	{"FALCONER", 8, 83981},
	{"ASTRAZENECA", 11, 83982},
	{"WATCHMAN", 8, 83983},
	{"FYIT", 4, 83984},
	{"FMOB", 4, 83985},
	{"BLOU", 4, 83986},
	{"POETICS", 7, 83987},
	{"VENTURING", 9, 83988},
	{"MINISERIES", 10, 83989},
	{"UADW", 4, 83990},
	{"RKGO", 4, 83991},
	{"NVUL", 4, 83992},
	{"BAGLEY", 6, 83993},
	{"YESTERDAYS", 10, 83994},
	{"DCM", 3, 83995},
	{"OIDR", 4, 83996},
	{"LBAG", 4, 83997},
	{"EAUL", 4, 83998},
	{"BOXL", 4, 83999},
	{"APAU", 4, 84000},
	{"ALIBI", 5, 84001},
	{"TOXICOL", 7, 84002},
	{"LIBDIR", 6, 84003},
	{"ANGOLAN", 7, 84004},
	{"WAYNESBORO", 10, 84005},
	{"RELAYED", 7, 84006},
	{"FCST", 4, 84007},
	{"ULCERATIVE", 10, 84008},
	{"JELLIES", 7, 84009},
	{"YNEL", 4, 84010},
	{"LHEB", 4, 84011},
	{"KKNO", 4, 84012},
	{"POSTPONEMENT", 12, 84013},
	{"AIRLIFT", 7, 84014},
	{"BROODING", 8, 84015},
	{"DOWNLINK", 8, 84016},
	{"EPPL", 4, 84017},
	{"CYPO", 4, 84018},
	{"ACYG", 4, 84019},
	{"ENDOTHELIUM", 11, 84020},
	{"SUPPRESSES", 10, 84021},
	{"WEINBERGER", 10, 84022},
	{"APPOINTEE", 9, 84023},
	{"DARCS", 5, 84024},
	{"GOSU", 4, 84025},
	{"HASHES", 6, 84026},
	{"ISKR", 4, 84027},
	{"NUFF", 4, 84028},
	{"JUNCTURE", 8, 84029},
	{"GREENLEAF", 9, 84030},
	{"BOREHOLE", 8, 84031},
	{"BWOU", 4, 84032},
	{"HTDIG", 5, 84033},
	{"NATURALIZED", 11, 84034},
	{"NODULES", 7, 84035},
	{"PIKES", 5, 84036},
	{"BOWDOIN", 7, 84037},
	{"ULEL", 4, 84038},
	{"ETCW", 4, 84039},
	{"TUNABLE", 7, 84040},
	{"MEMCPY", 6, 84041},
	{"UCP", 3, 84042},
	{"MEAGER", 6, 84043},
	{"PANELIST", 8, 84044},
	{"NFUC", 4, 84045},
	{"LSAU", 4, 84046},
	{"MAILROOM", 8, 84047},
	{"COMMANDANT", 10, 84048},
	{"COPERNICUS", 10, 84049},
	{"NIJMEGEN", 8, 84050},
	{"BOURGEOISIE", 11, 84051},
	{"PLUCKED", 7, 84052},
	{"MEDALIST", 8, 84053},
	{"YKNI", 4, 84054},
	{"RKUP", 4, 84055},
	{"NRAF", 4, 84056},
	{"MMAJ", 4, 84057},
	{"KPAI", 4, 84058},
	{"GHAZ", 4, 84059},
	{"AXDE", 4, 84060},
	{"RYMAN", 5, 84061},
	{"GMOS", 4, 84062},
	{"RECESSIVE", 9, 84063},
	{"IRIL", 4, 84064},
	{"EBMA", 4, 84065},
	{"INFLEXIBLE", 10, 84066},
	{"FLOWERED", 8, 84067},
	{"PUTAS", 5, 84068},
	{"ABOU", 4, 84069},
	{"ENCRYPTING", 10, 84070},
	{"ENOLA", 5, 84071},
	{"BUENO", 5, 84072},
	{"SOMB", 4, 84073},
	{"GHFL", 4, 84074},
	{"DAGL", 4, 84075},
	{"RIPPERS", 7, 84076},
	{"DISCORD", 7, 84077},
	{"STEYN", 5, 84078},
	{"REDEFINITION", 12, 84079},
	{"INFIELD", 7, 84080},
	{"REFORMAT", 8, 84081},
	{"ATCHISON", 8, 84082},
	{"PWRE", 4, 84083},
	{"PSAM", 4, 84084},
	{"ELDJ", 4, 84085},
	{"YANGTZE", 7, 84086},
	{"QCW", 3, 84087},
	{"LJZ", 3, 84088},
	{"FMZ", 3, 84089},
	{"NYFL", 4, 84090},
	{"KMAL", 4, 84091},
	{"CSKI", 4, 84092},
	{"PEELS", 5, 84093},
	{"PRETERM", 7, 84094},
	{"PATROLLING", 10, 84095},
	{"MINDFULNESS", 11, 84096},
	{"HWND", 4, 84097},
	{"INJURIOUS", 9, 84098},
	{"LEYU", 4, 84099},
	{"HIMJ", 4, 84100},
	{"BELD", 4, 84101},
	{"STANCES", 7, 84102},
	{"SYNAPSES", 8, 84103},
	{"HASHING", 7, 84104},
	{"FDRO", 4, 84105},
	{"BBEN", 4, 84106},
	{"AKSP", 4, 84107},
	{"GERE", 4, 84108},
	{"LRG", 3, 84109},
	{"UNMOUNTED", 9, 84110},
	{"VOITURE", 7, 84111},
	{"RICN", 4, 84112},
	{"ISLY", 4, 84113},
	{"ARMOIRES", 8, 84114},
	{"UTILITARIAN", 11, 84115},
	{"ARCHETYPES", 10, 84116},
	{"BEHEMOTH", 8, 84117},
	{"RCEG", 4, 84118},
	{"KWIS", 4, 84119},
	{"AUFF", 4, 84120},
	{"STEREOPHONICS", 13, 84121},
	{"OBSESSIONS", 10, 84122},
	{"COMPACTED", 9, 84123},
	{"PIOSENEK", 8, 84124},
	{"THROWER", 7, 84125},
	{"DOUGHNUTS", 9, 84126},
	{"PRANA", 5, 84127},
	{"IPWO", 4, 84128},
	{"ESYL", 4, 84129},
	{"TRIKE", 5, 84130},
	{"BMPS", 4, 84131},
	{"DISTILLERY", 10, 84132},
	{"REREAD", 6, 84133},
	{"ESTUDIOS", 8, 84134},
	{"CEREDIGION", 10, 84135},
	{"IGMI", 4, 84136},
	{"FUNNIER", 7, 84137},
	{"STORMED", 7, 84138},
	{"RICKARD", 7, 84139},
	{"DISENGAGEMENT", 13, 84140},
	{"ONBB", 4, 84141},
	{"GYBA", 4, 84142},
	{"FNEV", 4, 84143},
	{"GRATUITA", 8, 84144},
	{"GIFTING", 7, 84145},
	{"LPGA", 4, 84146},
	{"UPAW", 4, 84147},
	{"KHED", 4, 84148},
	{"DEOM", 4, 84149},
	{"DBYZ", 4, 84150},
	{"AHYD", 4, 84151},
	{"MAGLITE", 7, 84152},
	{"IODIDE", 6, 84153},
	{"BAKKER", 6, 84154},
	{"CRUCIFIX", 8, 84155},
	{"HARIRI", 6, 84156},
	{"DIGITIZATION", 12, 84157},
	{"FISTULA", 7, 84158},
	{"CAMPAIGNERS", 11, 84159},
	{"ACCA", 4, 84160},
	{"MESQ", 4, 84161},
	{"DOSW", 4, 84162},
	{"IRREVERENT", 10, 84163},
	{"LAURI", 5, 84164},
	{"ROCKWALL", 8, 84165},
	{"CENSURE", 7, 84166},
	{"CARBINE", 7, 84167},
	{"KELLYSEARCH", 11, 84168},
	{"CRAWFISH", 8, 84169},
	{"CREDO", 5, 84170},
	{"SYMBOLIZES", 10, 84171},
	{"LIVERISHOME", 11, 84172},
	{"ROSF", 4, 84173},
	{"MEEC", 4, 84174},
	{"ECUADORIAN", 10, 84175},
	{"INJECTORS", 9, 84176},
	{"HEARTLESS", 9, 84177},
	{"NATICK", 6, 84178},
	{"MORNINGTON", 10, 84179},
	{"BOOKLIST", 8, 84180},
	{"UKTH", 4, 84181},
	{"SLIQ", 4, 84182},
	{"PDRA", 4, 84183},
	{"NGEJ", 4, 84184},
	{"CENTRIST", 8, 84185},
	{"INRIA", 5, 84186},
	{"CONTENTED", 9, 84187},
	{"TORBAY", 6, 84188},
	{"YAFL", 4, 84189},
	{"RVOC", 4, 84190},
	{"MHED", 4, 84191},
	{"ELTF", 4, 84192},
	{"FEMUR", 5, 84193},
	{"VULTURES", 8, 84194},
	{"METHOTREXATE", 12, 84195},
	{"LANDSLIDES", 10, 84196},
	{"SEPARATIST", 10, 84197},
	{"OMSR", 4, 84198},
	{"FEDC", 4, 84199},
	{"JELINEK", 7, 84200},
	{"DARWEN", 6, 84201},
	{"AUNG", 4, 84202},
	{"YGAY", 4, 84203},
	{"SROW", 4, 84204},
	{"OUTLOOKS", 8, 84205},
	{"MATRIMONIALS", 12, 84206},
	{"FORCIBLE", 8, 84207},
	{"BUSYBOX", 7, 84208},
	{"OPENVIEW", 8, 84209},
	{"LIFEBOAT", 8, 84210},
	{"ODKA", 4, 84211},
	{"MELR", 4, 84212},
	{"EKSM", 4, 84213},
	{"ASUK", 4, 84214},
	{"ABUB", 4, 84215},
	{"BUSHY", 5, 84216},
	{"TUSKEGEE", 8, 84217},
	{"THICKENING", 10, 84218},
	{"CIPROFLOXACIN", 13, 84219},
	{"GUL", 3, 84220},
	{"HJUD", 4, 84221},
	{"AWDO", 4, 84222},
	{"MOINS", 5, 84223},
	{"RECONFIGURE", 11, 84224},
	{"INSTANTIATION", 13, 84225},
	{"SPAMBAYES", 9, 84226},
	{"OULW", 4, 84227},
	{"SHELBURNE", 9, 84228},
	{"PROGRAMMA", 9, 84229},
	{"LBL", 3, 84230},
	{"ESCALATED", 9, 84231},
	{"LUCASARTS", 9, 84232},
	{"UGON", 4, 84233},
	{"LSKA", 4, 84234},
	{"EASTBOUND", 9, 84235},
	{"GRITS", 5, 84236},
	{"APOPTOTIC", 9, 84237},
	{"PULLDOWN", 8, 84238},
	{"REDDITCH", 8, 84239},
	{"TRENDNET", 8, 84240},
	{"PSOL", 4, 84241},
	{"NBYK", 4, 84242},
	{"IUPUI", 5, 84243},
	{"TREEHOUSE", 9, 84244},
	{"PAYSON", 6, 84245},
	{"PORCHES", 7, 84246},
	{"INOCULATION", 11, 84247},
	{"HEDRICK", 7, 84248},
	{"LUXURIES", 8, 84249},
	{"GLORIFY", 7, 84250},
	{"ABNER", 5, 84251},
	{"LINEMAN", 7, 84252},
	{"OKCL", 4, 84253},
	{"FDOG", 4, 84254},
	{"FATM", 4, 84255},
	{"ATUB", 4, 84256},
	{"STREAMLINES", 11, 84257},
	{"REENGINEERING", 13, 84258},
	{"CLEAVER", 7, 84259},
	{"PRODOTTI", 8, 84260},
	{"INFLIGHT", 8, 84261},
	{"LAYV", 4, 84262},
	{"EUBE", 4, 84263},
	{"TRACKSUIT", 9, 84264},
	{"POLYPHONICS", 11, 84265},
	{"SKIDMORE", 8, 84266},
	{"CATIA", 5, 84267},
	{"OVERUSE", 7, 84268},
	{"NEWSPRINT", 9, 84269},
	{"VISAKHAPATNAM", 13, 84270},
	{"MARIS", 5, 84271},
	{"ADMIXTURE", 9, 84272},
	{"MIKO", 4, 84273},
	{"YAKO", 4, 84274},
	{"UROI", 4, 84275},
	{"SLUS", 4, 84276},
	{"NZAG", 4, 84277},
	{"MLED", 4, 84278},
	{"LTSM", 4, 84279},
	{"GAYP", 4, 84280},
	{"HEMORRHOIDS", 11, 84281},
	{"HAULAGE", 7, 84282},
	{"TORRIE", 6, 84283},
	{"MDIA", 4, 84284},
	{"HEREDITY", 8, 84285},
	{"NOMINALLY", 9, 84286},
	{"USERGROUP", 9, 84287},
	{"POMS", 4, 84288},
	{"MOSTRAR", 7, 84289},
	{"CONVOLUTION", 11, 84290},
	{"FORZA", 5, 84291},
	{"CHLOROFORM", 10, 84292},
	{"ENDTIME", 7, 84293},
	{"YSVE", 4, 84294},
	{"IXFI", 4, 84295},
	{"NETTLE", 6, 84296},
	{"MISMANAGEMENT", 13, 84297},
	{"MAURA", 5, 84298},
	{"HEFCE", 5, 84299},
	{"CONVINCINGLY", 12, 84300},
	{"ABBIE", 5, 84301},
	{"MFP", 3, 84302},
	{"GALICIAN", 8, 84303},
	{"GOLEM", 5, 84304},
	{"XPUL", 4, 84305},
	{"UAPP", 4, 84306},
	{"REUD", 4, 84307},
	{"OOKK", 4, 84308},
	{"FULU", 4, 84309},
	{"ENMR", 4, 84310},
	{"EVANGELINE", 10, 84311},
	{"CONIFER", 7, 84312},
	{"PHENYLALANINE", 13, 84313},
	{"WAREHAM", 7, 84314},
	{"DESCENDS", 8, 84315},
	{"NONPUBLIC", 9, 84316},
	{"MISCHIEVOUS", 11, 84317},
	{"INVERSELY", 9, 84318},
	{"BEEBE", 5, 84319},
	{"LFIM", 4, 84320},
	{"FATEFUL", 7, 84321},
	{"DANCEFLOOR", 10, 84322},
	{"EYELET", 6, 84323},
	{"IMMUNOLOGIC", 11, 84324},
	{"COMPLACENCY", 11, 84325},
	{"NMCK", 4, 84326},
	{"GBOS", 4, 84327},
	{"EZCA", 4, 84328},
	{"CHENGDU", 7, 84329},
	{"BEESWAX", 7, 84330},
	{"LANHAM", 6, 84331},
	{"CROSSWALK", 9, 84332},
	{"LECKEN", 6, 84333},
	{"KITSCH", 6, 84334},
	{"SCAND", 5, 84335},
	{"RVEE", 4, 84336},
	{"EALJ", 4, 84337},
	{"SWEETENERS", 10, 84338},
	{"FARNBOROUGH", 11, 84339},
	{"JALANDHAR", 9, 84340},
	{"PUBLI", 5, 84341},
	{"VISIONEER", 9, 84342},
	{"SPRINTS", 7, 84343},
	{"REINHOLD", 8, 84344},
	{"IMPREGNATED", 11, 84345},
	{"INSULAR", 7, 84346},
	{"EMPTIVE", 7, 84347},
	{"COMPA", 5, 84348},
	{"NYAU", 4, 84349},
	{"JIMT", 4, 84350},
	{"AMOW", 4, 84351},
	{"LAGOONS", 7, 84352},
	{"SENSUALITY", 10, 84353},
	{"FAKED", 5, 84354},
	{"MANILOW", 7, 84355},
	{"VERE", 4, 84356},
	{"BURNSVILLE", 10, 84357},
	{"SFIC", 4, 84358},
	{"BANYAN", 6, 84359},
	{"AFFIX", 5, 84360},
	{"OPINIONATED", 11, 84361},
	{"QUIRK", 5, 84362},
	{"PROFESSED", 9, 84363},
	{"KSIG", 4, 84364},
	{"KLIF", 4, 84365},
	{"FYHI", 4, 84366},
	{"EKSD", 4, 84367},
	{"CWRI", 4, 84368},
	{"QBV", 3, 84369},
	{"LQL", 3, 84370},
	{"KPV", 3, 84371},
	{"FMQ", 3, 84372},
	{"UNRIVALLED", 10, 84373},
	{"CATERINA", 8, 84374},
	{"BLINKS", 6, 84375},
	{"SENSUOUS", 8, 84376},
	{"FIORE", 5, 84377},
	{"RATIONING", 9, 84378},
	{"UBLA", 4, 84379},
	{"RIEP", 4, 84380},
	{"OBUN", 4, 84381},
	{"SAWING", 6, 84382},
	{"TELLERS", 7, 84383},
	{"YELP", 4, 84384},
	{"JRNL", 4, 84385},
	{"HERDING", 7, 84386},
	{"WATERBORNE", 10, 84387},
	{"ASTRON", 6, 84388},
	{"MAMMALIA", 8, 84389},
	{"HOPPED", 6, 84390},
	{"SCEPTICAL", 9, 84391},
	{"RMPO", 4, 84392},
	{"RATY", 4, 84393},
	{"ARTK", 4, 84394},
	{"GREE", 4, 84395},
	{"TRADEOFFS", 9, 84396},
	{"GOLDENEYE", 9, 84397},
	{"OCCURING", 8, 84398},
	{"CALIENTES", 9, 84399},
	{"RECOMEND", 8, 84400},
	{"ZAPA", 4, 84401},
	{"UMTR", 4, 84402},
	{"OYFO", 4, 84403},
	{"ENDV", 4, 84404},
	{"BUMD", 4, 84405},
	{"FUNCTOR", 7, 84406},
	{"TROWBRIDGE", 10, 84407},
	{"ARMA", 4, 84408},
	{"MMVI", 4, 84409},
	{"INTERFERED", 10, 84410},
	{"HALCYON", 7, 84411},
	{"GYRO", 4, 84412},
	{"SMEW", 4, 84413},
	{"OALG", 4, 84414},
	{"DMDA", 4, 84415},
	{"TECHNEWS", 8, 84416},
	{"BOWING", 6, 84417},
	{"SHAMPOOS", 8, 84418},
	{"UNFILTERED", 10, 84419},
	{"SABHA", 5, 84420},
	{"COGENT", 6, 84421},
	{"PARISHIONERS", 12, 84422},
	{"BUNDESLIGA", 10, 84423},
	{"TRAVERSING", 10, 84424},
	{"SPOF", 4, 84425},
	{"OULM", 4, 84426},
	{"COMMUNIQUE", 10, 84427},
	{"UNINFORMED", 10, 84428},
	{"CANTINA", 7, 84429},
	{"CAFTA", 5, 84430},
	{"POLYAMIDE", 9, 84431},
	{"SELECTMEN", 9, 84432},
	{"LNCS", 4, 84433},
	{"LUGE", 4, 84434},
	{"NECROMANCER", 11, 84435},
	{"OWCE", 4, 84436},
	{"AYIC", 4, 84437},
	{"CARCINOMAS", 10, 84438},
	{"YORKE", 5, 84439},
	{"SUBCONTINENT", 12, 84440},
	{"DODDS", 5, 84441},
	{"TIRU", 4, 84442},
	{"CSFI", 4, 84443},
	{"SEATON", 6, 84444},
	{"TRANSCRIPTASE", 13, 84445},
	{"BALMORAL", 8, 84446},
	{"ABERRATION", 10, 84447},
	{"SPECIFIER", 9, 84448},
	{"MOLLIE", 6, 84449},
	{"LTIR", 4, 84450},
	{"SUBSIDIZE", 9, 84451},
	{"GALAXIE", 7, 84452},
	{"CONCLUSIVELY", 12, 84453},
	{"LDFLAGS", 7, 84454},
	{"CALCAREOUS", 10, 84455},
	{"NAPPIES", 7, 84456},
	{"CUSB", 4, 84457},
	{"CRIPPLING", 9, 84458},
	{"XUL", 3, 84459},
	{"ASPHERICAL", 10, 84460},
	{"MISHEARD", 8, 84461},
	{"UFLA", 4, 84462},
	{"SYLA", 4, 84463},
	{"MIFH", 4, 84464},
	{"SUNDIAL", 7, 84465},
	{"IAPU", 4, 84466},
	{"TUFTED", 6, 84467},
	{"ODOM", 4, 84468},
	{"FLAKY", 5, 84469},
	{"SCHLESINGER", 11, 84470},
	{"KRYPTONITE", 10, 84471},
	{"TYPOLOGY", 8, 84472},
	{"HYDRANGEA", 9, 84473},
	{"CHIEFTAIN", 9, 84474},
	{"PREAMPS", 7, 84475},
	{"AESTHETICALLY", 13, 84476},
	{"GESTALT", 7, 84477},
	{"ALVARO", 6, 84478},
	{"TUSL", 4, 84479},
	{"PAVL", 4, 84480},
	{"HESTON", 6, 84481},
	{"RUSR", 4, 84482},
	{"ORTK", 4, 84483},
	{"LLOL", 4, 84484},
	{"HONEYSUCKLE", 11, 84485},
	{"ALLREFER", 8, 84486},
	{"DCF", 3, 84487},
	{"SCARICA", 7, 84488},
	{"CHORALE", 7, 84489},
	{"YCES", 4, 84490},
	{"FLUF", 4, 84491},
	{"ZEITSCHRIFT", 11, 84492},
	{"UNSPOKEN", 8, 84493},
	{"ISHMAEL", 7, 84494},
	{"FREDONIA", 8, 84495},
	{"TIARAS", 6, 84496},
	{"OFGH", 4, 84497},
	{"APPREHENDED", 11, 84498},
	{"DISTR", 5, 84499},
	{"DSCP", 4, 84500},
	{"RHODA", 5, 84501},
	{"COGENERATION", 12, 84502},
	{"FLITE", 5, 84503},
	{"URGM", 4, 84504},
	{"UCTR", 4, 84505},
	{"HARDDISK", 8, 84506},
	{"JAMMER", 6, 84507},
	{"KENNEDYS", 8, 84508},
	{"TELEFONO", 8, 84509},
	{"SALEEN", 6, 84510},
	{"UPAH", 4, 84511},
	{"CMAY", 4, 84512},
	{"BOSCO", 5, 84513},
	{"CYCLASE", 7, 84514},
	{"UJAH", 4, 84515},
	{"SMAU", 4, 84516},
	{"RYID", 4, 84517},
	{"FORBIDDING", 10, 84518},
	{"SPARRING", 8, 84519},
	{"MINDANAO", 8, 84520},
	{"DREAMCATCHER", 12, 84521},
	{"UNGJ", 4, 84522},
	{"GWAV", 4, 84523},
	{"ADONIS", 6, 84524},
	{"DOMED", 5, 84525},
	{"DISTRESSING", 11, 84526},
	{"BRADDOCK", 8, 84527},
	{"ETHNICALLY", 10, 84528},
	{"MORRO", 5, 84529},
	{"SMURF", 5, 84530},
	{"OAGU", 4, 84531},
	{"MNEX", 4, 84532},
	{"KSMU", 4, 84533},
	{"FEVO", 4, 84534},
	{"CYHO", 4, 84535},
	{"BEEQ", 4, 84536},
	{"YEAGER", 6, 84537},
	{"GELDING", 7, 84538},
	{"BLURRING", 8, 84539},
	{"DEVA", 4, 84540},
	{"MASTECTOMY", 10, 84541},
	{"PRETTIEST", 9, 84542},
	{"CASSELL", 7, 84543},
	{"NYSD", 4, 84544},
	{"FYWH", 4, 84545},
	{"DOKN", 4, 84546},
	{"SARNIA", 6, 84547},
	{"JAUNDICE", 8, 84548},
	{"NZAC", 4, 84549},
	{"MYOL", 4, 84550},
	{"LJON", 4, 84551},
	{"LASTEST", 7, 84552},
	{"PANES", 5, 84553},
	{"ASTERISKS", 9, 84554},
	{"JEFFERS", 7, 84555},
	{"SJAR", 4, 84556},
	{"PSFA", 4, 84557},
	{"EBAM", 4, 84558},
	{"AUWA", 4, 84559},
	{"HYUN", 4, 84560},
	{"COOKTOP", 7, 84561},
	{"FDDI", 4, 84562},
	{"OGAC", 4, 84563},
	{"CUEO", 4, 84564},
	{"ASPERGILLUS", 11, 84565},
	{"AGRIC", 5, 84566},
	{"KDC", 3, 84567},
	{"MEDICS", 6, 84568},
	{"PHOTOSITE", 9, 84569},
	{"MRBE", 4, 84570},
	{"AFFIRMATIONS", 12, 84571},
	{"TESTIFIES", 9, 84572},
	{"KTOJ", 4, 84573},
	{"KCLI", 4, 84574},
	{"VARIATIONAL", 11, 84575},
	{"SOCIALIZING", 11, 84576},
	{"CRANKSHAFT", 10, 84577},
	{"FILIPINOS", 9, 84578},
	{"WAMO", 4, 84579},
	{"CBEN", 4, 84580},
	{"AUME", 4, 84581},
	{"MENSAJE", 7, 84582},
	{"TAGLINE", 7, 84583},
	{"CHAMBRE", 7, 84584},
	{"DAINTY", 6, 84585},
	{"AIRFRAME", 8, 84586},
	{"BEATER", 6, 84587},
	{"PREOWNED", 8, 84588},
	{"DIETETIC", 8, 84589},
	{"ULVI", 4, 84590},
	{"PSIM", 4, 84591},
	{"LWID", 4, 84592},
	{"ERKH", 4, 84593},
	{"CRACKLE", 7, 84594},
	{"WLEG", 4, 84595},
	{"PTBU", 4, 84596},
	{"CHMY", 4, 84597},
	{"STOREDGE", 8, 84598},
	{"REDACTED", 8, 84599},
	{"RITTENHOUSE", 11, 84600},
	{"ZMW", 3, 84601},
	{"RJZ", 3, 84602},
	{"GVV", 3, 84603},
	{"FYZ", 3, 84604},
	{"STEREOTYPICAL", 13, 84605},
	{"KLASS", 5, 84606},
	{"TREKS", 5, 84607},
	{"TMYA", 4, 84608},
	{"TALQ", 4, 84609},
	{"OGFO", 4, 84610},
	{"KREI", 4, 84611},
	{"KQUI", 4, 84612},
	{"VICTIMIZATION", 13, 84613},
	{"PARALLAX", 8, 84614},
	{"ZANTE", 5, 84615},
	{"SPLICES", 7, 84616},
	{"IMAGENES", 8, 84617},
	{"AKITA", 5, 84618},
	{"NONRESIDENTIAL", 14, 84619},
	{"HELLMAN", 7, 84620},
	{"DUREX", 5, 84621},
	{"ROBISON", 7, 84622},
	{"LPD", 3, 84623},
	{"UMWO", 4, 84624},
	{"RTGI", 4, 84625},
	{"RGAU", 4, 84626},
	{"MCMU", 4, 84627},
	{"IDUE", 4, 84628},
	{"CEMC", 4, 84629},
	{"THWARTED", 8, 84630},
	{"ALBAN", 5, 84631},
	{"TMYL", 4, 84632},
	{"RYLU", 4, 84633},
	{"LTAW", 4, 84634},
	{"KERV", 4, 84635},
	{"FREETYPE", 8, 84636},
	{"PLANKS", 6, 84637},
	{"NEXIS", 5, 84638},
	{"LDV", 3, 84639},
	{"LEXL", 4, 84640},
	{"MOLLOY", 6, 84641},
	{"CARCINOGEN", 10, 84642},
	{"ORVILLE", 7, 84643},
	{"CATALYZED", 9, 84644},
	{"HEATWAVE", 8, 84645},
	{"SIRW", 4, 84646},
	{"SPINDLES", 8, 84647},
	{"BELCHER", 7, 84648},
	{"HERRON", 6, 84649},
	{"SPIRALS", 7, 84650},
	{"SPECULATIONS", 12, 84651},
	{"SEDENTARY", 9, 84652},
	{"EXTERMINATION", 13, 84653},
	{"PLUMES", 6, 84654},
	{"WATCHTOWER", 10, 84655},
	{"FABRIZIO", 8, 84656},
	{"OUTWEIGHED", 10, 84657},
	{"UNMANAGED", 9, 84658},
	{"PRETEENS", 8, 84659},
	{"RENUMBERED", 10, 84660},
	{"OWLX", 4, 84661},
	{"FBED", 4, 84662},
	{"TRANSPOSITION", 13, 84663},
	{"COWELL", 6, 84664},
	{"HYIP", 4, 84665},
	{"CROSSBOW", 8, 84666},
	{"ACHETER", 7, 84667},
	{"SPECIATION", 10, 84668},
	{"ZEYO", 4, 84669},
	{"DKUR", 4, 84670},
	{"BEETS", 5, 84671},
	{"WHIDBEY", 7, 84672},
	{"BETTA", 5, 84673},
	{"UTPH", 4, 84674},
	{"ONKR", 4, 84675},
	{"REPEL", 5, 84676},
	{"ROKI", 4, 84677},
	{"LGAV", 4, 84678},
	{"EMMET", 5, 84679},
	{"JEWELERY", 8, 84680},
	{"YLLS", 4, 84681},
	{"LKFO", 4, 84682},
	{"CPUB", 4, 84683},
	{"APBO", 4, 84684},
	{"LUMINA", 6, 84685},
	{"PALI", 4, 84686},
	{"STATISTICIAN", 12, 84687},
	{"SYMMETRIES", 10, 84688},
	{"COLERIDGE", 9, 84689},
	{"OBSERVATORIES", 13, 84690},
	{"BUPROPION", 9, 84691},
	{"ANXIETIES", 9, 84692},
	{"ZEAB", 4, 84693},
	{"GMEL", 4, 84694},
	{"GJAN", 4, 84695},
	{"DOCR", 4, 84696},
	{"DDAW", 4, 84697},
	{"TELLIGENT", 9, 84698},
	{"FUNGICIDE", 9, 84699},
	{"AIPTEK", 6, 84700},
	{"POSTE", 5, 84701},
	{"CROSSTALK", 9, 84702},
	{"ONEROUS", 7, 84703},
	{"IGGU", 4, 84704},
	{"DOGH", 4, 84705},
	{"MELLO", 5, 84706},
	{"DEEPSAND", 8, 84707},
	{"LITAS", 5, 84708},
	{"HAART", 5, 84709},
	{"ZSCH", 4, 84710},
	{"OXSP", 4, 84711},
	{"BPRE", 4, 84712},
	{"WORX", 4, 84713},
	{"COYNE", 5, 84714},
	{"ADENOVIRUS", 10, 84715},
	{"HAKIM", 5, 84716},
	{"IRMB", 4, 84717},
	{"DYAP", 4, 84718},
	{"BASR", 4, 84719},
	{"COUNTYWIDE", 10, 84720},
	{"TENDERLY", 8, 84721},
	{"GNUCASH", 7, 84722},
	{"PUREE", 5, 84723},
	{"BONNY", 5, 84724},
	{"MANDEVILLE", 10, 84725},
	{"VIAM", 4, 84726},
	{"OGSP", 4, 84727},
	{"GSBR", 4, 84728},
	{"HADDOCK", 7, 84729},
	{"PORTUGESE", 9, 84730},
	{"MAURIZIO", 8, 84731},
	{"TACHYCARDIA", 11, 84732},
	{"DFAB", 4, 84733},
	{"VIRGINIAN", 9, 84734},
	{"WARRICK", 7, 84735},
	{"COSINE", 6, 84736},
	{"REYR", 4, 84737},
	{"IXCH", 4, 84738},
	{"APSD", 4, 84739},
	{"PATONG", 6, 84740},
	{"PYJAMAS", 7, 84741},
	{"BALLINA", 7, 84742},
	{"SUMMARISE", 9, 84743},
	{"ACCRINGTON", 10, 84744},
	{"FINNS", 5, 84745},
	{"HADDON", 6, 84746},
	{"OFTENTIMES", 10, 84747},
	{"ENTANGLEMENT", 12, 84748},
	{"XTGA", 4, 84749},
	{"MMYM", 4, 84750},
	{"DUNW", 4, 84751},
	{"DESJ", 4, 84752},
	{"XPC", 3, 84753},
	{"SWATH", 5, 84754},
	{"AZERI", 5, 84755},
	{"MFLA", 4, 84756},
	{"HAMY", 4, 84757},
	{"AHRU", 4, 84758},
	{"ULF", 3, 84759},
	{"KLEEN", 5, 84760},
	{"MISERABLY", 9, 84761},
	{"SAVOIR", 6, 84762},
	{"ROJAS", 5, 84763},
	{"CVM", 3, 84764},
	{"MEEHAN", 6, 84765},
	{"RJOY", 4, 84766},
	{"NUTC", 4, 84767},
	{"JENIFER", 7, 84768},
	{"INFILTRATE", 10, 84769},
	{"MAPINFO", 7, 84770},
	{"ARGOSY", 6, 84771},
	{"KNIGHTSBRIDGE", 13, 84772},
	{"RENOUNCE", 8, 84773},
	{"JESPER", 6, 84774},
	{"BLAIRSVILLE", 11, 84775},
	{"COPILOT", 7, 84776},
	{"SEGG", 4, 84777},
	{"NKMI", 4, 84778},
	{"HBOW", 4, 84779},
	{"GSRI", 4, 84780},
	{"GBYU", 4, 84781},
	{"FRAW", 4, 84782},
	{"KOONTZ", 6, 84783},
	{"ELBA", 4, 84784},
	{"NORTHGATE", 9, 84785},
	{"URII", 4, 84786},
	{"UNGN", 4, 84787},
	{"SOUV", 4, 84788},
	{"RAEU", 4, 84789},
	{"ECHD", 4, 84790},
	{"PHOBIAS", 7, 84791},
	{"METAFRAME", 9, 84792},
	{"STUMPS", 6, 84793},
	{"NUTRITIONIST", 12, 84794},
	{"CLOUDED", 7, 84795},
	{"EFFECTOR", 8, 84796},
	{"BUMSEN", 6, 84797},
	{"RCM", 3, 84798},
	{"DIVERTING", 9, 84799},
	{"HAIRSTYLE", 9, 84800},
	{"NESBITT", 7, 84801},
	{"BCIN", 4, 84802},
	{"DIURETICS", 9, 84803},
	{"CEMETARY", 8, 84804},
	{"REYD", 4, 84805},
	{"OPEJ", 4, 84806},
	{"HSYM", 4, 84807},
	{"DEROGATORY", 10, 84808},
	{"ESTEBAN", 7, 84809},
	{"DISCARDS", 8, 84810},
	{"BASIE", 5, 84811},
	{"XXIV", 4, 84812},
	{"DISCONTINUOUS", 13, 84813},
	{"IQBAL", 5, 84814},
	{"ORPC", 4, 84815},
	{"NFAU", 4, 84816},
	{"MSRO", 4, 84817},
	{"BBYC", 4, 84818},
	{"UNCORRECTED", 11, 84819},
	{"STILLMAN", 8, 84820},
	{"CHLORO", 6, 84821},
	{"ROUEN", 5, 84822},
	{"BIGHORN", 7, 84823},
	{"INACCURACY", 10, 84824},
	{"ASSIMILATE", 10, 84825},
	{"HEARTBREAKING", 13, 84826},
	{"LEITRIM", 7, 84827},
	{"MEDEA", 5, 84828},
	{"YLUN", 4, 84829},
	{"YCOI", 4, 84830},
	{"XDIS", 4, 84831},
	{"WSEL", 4, 84832},
	{"MREQ", 4, 84833},
	{"HUSL", 4, 84834},
	{"PRG", 3, 84835},
	{"JUSTIFICATIONS", 14, 84836},
	{"GIMMICK", 7, 84837},
	{"BRASILIA", 8, 84838},
	{"RECORDIN", 8, 84839},
	{"ABRA", 4, 84840},
	{"YUNU", 4, 84841},
	{"LMDE", 4, 84842},
	{"EPDA", 4, 84843},
	{"ACRYLICS", 8, 84844},
	{"REGENERATED", 11, 84845},
	{"RECENSIONE", 10, 84846},
	{"FOULED", 6, 84847},
	{"PROI", 4, 84848},
	{"EGLU", 4, 84849},
	{"DYDA", 4, 84850},
	{"DRJO", 4, 84851},
	{"BBYW", 4, 84852},
	{"WIRETAP", 7, 84853},
	{"DVRS", 4, 84854},
	{"VOCS", 4, 84855},
	{"POPM", 4, 84856},
	{"DDCO", 4, 84857},
	{"LAINE", 5, 84858},
	{"RZJ", 3, 84859},
	{"MKJ", 3, 84860},
	{"GXV", 3, 84861},
	{"GJY", 3, 84862},
	{"MONIKER", 7, 84863},
	{"GOTTFRIED", 9, 84864},
	{"RAPP", 4, 84865},
	{"CREDENCE", 8, 84866},
	{"ZILS", 4, 84867},
	{"RMRO", 4, 84868},
	{"RIDW", 4, 84869},
	{"OOLJ", 4, 84870},
	{"FFDO", 4, 84871},
	{"SCHOLES", 7, 84872},
	{"SHARPENERS", 10, 84873},
	{"WELLING", 7, 84874},
	{"CALIDA", 6, 84875},
	{"UELH", 4, 84876},
	{"RIML", 4, 84877},
	{"PAQU", 4, 84878},
	{"ORZA", 4, 84879},
	{"PATROLLED", 9, 84880},
	{"GEORGETTE", 9, 84881},
	{"CALLOWAY", 8, 84882},
	{"LOVELACE", 8, 84883},
	{"TPICD", 5, 84884},
	{"FMIG", 4, 84885},
	{"PRODS", 5, 84886},
	{"CONFERRING", 10, 84887},
	{"VIDK", 4, 84888},
	{"ERDM", 4, 84889},
	{"DSYR", 4, 84890},
	{"LTDA", 4, 84891},
	{"INCITE", 6, 84892},
	{"WAYPOINTS", 9, 84893},
	{"PRYO", 4, 84894},
	{"IRLH", 4, 84895},
	{"GYUS", 4, 84896},
	{"UNDERSCORED", 11, 84897},
	{"HERRICK", 7, 84898},
	{"DIVULGE", 7, 84899},
	{"VYTO", 4, 84900},
	{"MNEV", 4, 84901},
	{"WARDENS", 7, 84902},
	{"STARWARS", 8, 84903},
	{"SMBS", 4, 84904},
	{"UNREPORTED", 10, 84905},
	{"PHELAN", 6, 84906},
	{"GUARANI", 7, 84907},
	{"RNIK", 4, 84908},
	{"OCHL", 4, 84909},
	{"MPUP", 4, 84910},
	{"DIGU", 4, 84911},
	{"TAMPON", 6, 84912},
	{"EASELS", 6, 84913},
	{"SCRUBBING", 9, 84914},
	{"LAUGHABLE", 9, 84915},
	{"MOMENTOUS", 9, 84916},
	{"MRBA", 4, 84917},
	{"KEEB", 4, 84918},
	{"IROD", 4, 84919},
	{"GTIG", 4, 84920},
	{"FSTJ", 4, 84921},
	{"FOOTPATH", 8, 84922},
	{"SXGA", 4, 84923},
	{"ENTREPRISE", 10, 84924},
	{"WEBFORM", 7, 84925},
	{"ARTISTA", 7, 84926},
	{"LKOU", 4, 84927},
	{"FAFL", 4, 84928},
	{"ELKHORN", 7, 84929},
	{"VENTANA", 7, 84930},
	{"SUBLET", 6, 84931},
	{"CHILTERN", 8, 84932},
	{"ANTARES", 7, 84933},
	{"PEAKING", 7, 84934},
	{"STICHTING", 9, 84935},
	{"FORALL", 6, 84936},
	{"WNOW", 4, 84937},
	{"QUOH", 4, 84938},
	{"ODRY", 4, 84939},
	{"LMEW", 4, 84940},
	{"GBAB", 4, 84941},
	{"MENUITEM", 8, 84942},
	{"YVAC", 4, 84943},
	{"KPOO", 4, 84944},
	{"HAREM", 5, 84945},
	{"FUSSY", 5, 84946},
	{"MARSHMALLOW", 11, 84947},
	{"HAWAI", 5, 84948},
	{"CIVILITY", 8, 84949},
	{"CALS", 4, 84950},
	{"SELTZER", 7, 84951},
	{"UTEP", 4, 84952},
	{"HOMEOSTASIS", 11, 84953},
	{"BEYA", 4, 84954},
	{"DELUGE", 6, 84955},
	{"AKAMAI", 6, 84956},
	{"SQUADRONS", 9, 84957},
	{"WOVI", 4, 84958},
	{"UMNT", 4, 84959},
	{"VENTRICLE", 9, 84960},
	{"GOODIE", 6, 84961},
	{"MILKSHAKE", 9, 84962},
	{"THRASHER", 8, 84963},
	{"SWITCHERS", 9, 84964},
	{"BRUSSEL", 7, 84965},
	{"UTYF", 4, 84966},
	{"TDAW", 4, 84967},
	{"EWOV", 4, 84968},
	{"HARTWELL", 8, 84969},
	{"ELECTROLYTES", 12, 84970},
	{"MACHU", 5, 84971},
	{"UNSHAVED", 8, 84972},
	{"ILYA", 4, 84973},
	{"MANEUVERING", 11, 84974},
	{"WSBR", 4, 84975},
	{"PNEX", 4, 84976},
	{"LWAV", 4, 84977},
	{"GABY", 4, 84978},
	{"SOFTWOOD", 8, 84979},
	{"AJAY", 4, 84980},
	{"CROUPIER", 8, 84981},
	{"HAUSA", 5, 84982},
	{"FLUTED", 6, 84983},
	{"COMPACTS", 8, 84984},
	{"SYWH", 4, 84985},
	{"NVIG", 4, 84986},
	{"DOPH", 4, 84987},
	{"BECI", 4, 84988},
	{"SIMILIAR", 8, 84989},
	{"ELEV", 4, 84990},
	{"RHINITIS", 8, 84991},
	{"SWEETENED", 9, 84992},
	{"DREAMHACK", 9, 84993},
	{"REWG", 4, 84994},
	{"KYFO", 4, 84995},
	{"FHAP", 4, 84996},
	{"PRY", 3, 84997},
	{"WHEDON", 6, 84998},
	{"VENISON", 7, 84999},
	{"YBUN", 4, 85000},
	{"VREA", 4, 85001},
	{"NELK", 4, 85002},
	{"EWTW", 4, 85003},
	{"MICROCONTROLLERS", 16, 85004},
	{"DREAMHOST", 9, 85005},
	{"SHOAL", 5, 85006},
	{"OVERCROWDING", 12, 85007},
	{"BASKING", 7, 85008},
	{"RETRACTIONS", 11, 85009},
	{"XESB", 4, 85010},
	{"UELR", 4, 85011},
	{"NRYT", 4, 85012},
	{"PINGING", 7, 85013},
	{"CATHETERIZATION", 15, 85014},
	{"HOLTON", 6, 85015},
	{"SMEARS", 6, 85016},
	{"JMD", 3, 85017},
	{"MYQU", 4, 85018},
	{"PARE", 4, 85019},
	{"BLUSHING", 8, 85020},
	{"BREATHES", 8, 85021},
	{"MELO", 4, 85022},
	{"EXONS", 5, 85023},
	{"MARIACHI", 8, 85024},
	{"BDAY", 4, 85025},
	{"LECTURED", 8, 85026},
	{"ZENF", 4, 85027},
	{"OOBV", 4, 85028},
	{"IRJU", 4, 85029},
	{"EKMO", 4, 85030},
	{"RESEAL", 6, 85031},
	{"COMPOSITING", 11, 85032},
	{"OSKALOOSA", 9, 85033},
	{"COOPERS", 7, 85034},
	{"PSONE", 5, 85035},
	{"VERSIONE", 8, 85036},
	{"STORYS", 6, 85037},
	{"ESCHER", 6, 85038},
	{"TGOW", 4, 85039},
	{"HUNL", 4, 85040},
	{"HOTFIX", 6, 85041},
	{"RMP", 3, 85042},
	{"BABYLONIAN", 10, 85043},
	{"GAYNOR", 6, 85044},
	{"UORS", 4, 85045},
	{"SCEM", 4, 85046},
	{"RODH", 4, 85047},
	{"RILR", 4, 85048},
	{"MMYP", 4, 85049},
	{"JANP", 4, 85050},
	{"BIOTA", 5, 85051},
	{"DOSSIERS", 8, 85052},
	{"ARPT", 4, 85053},
	{"MSGE", 4, 85054},
	{"WINSOR", 6, 85055},
	{"HAIRDRYERS", 10, 85056},
	{"MORROWIND", 9, 85057},
	{"PUTER", 5, 85058},
	{"ANNONCE", 7, 85059},
	{"RZER", 4, 85060},
	{"PLYG", 4, 85061},
	{"CHUBBYLAND", 10, 85062},
	{"DEFLATION", 9, 85063},
	{"DREYFUS", 7, 85064},
	{"MORTE", 5, 85065},
	{"WORSENED", 8, 85066},
	{"DARLIN", 6, 85067},
	{"YCRY", 4, 85068},
	{"KLYL", 4, 85069},
	{"BORD", 4, 85070},
	{"TREME", 5, 85071},
	{"RECONSTITUTED", 13, 85072},
	{"SKILLFULLY", 10, 85073},
	{"AVEDA", 5, 85074},
	{"HEADY", 5, 85075},
	{"LEGGE", 5, 85076},
	{"KASPER", 6, 85077},
	{"MUGLER", 6, 85078},
	{"YORKS", 5, 85079},
	{"CONFUCIUS", 9, 85080},
	{"YSOB", 4, 85081},
	{"XOFS", 4, 85082},
	{"BOMBARDED", 9, 85083},
	{"BADLANDS", 8, 85084},
	{"DEPLOYS", 7, 85085},
	{"CELTS", 5, 85086},
	{"POLS", 4, 85087},
	{"INTERNETS", 9, 85088},
	{"BACKSTROKE", 10, 85089},
	{"BATHED", 6, 85090},
	{"ZENR", 4, 85091},
	{"TDPA", 4, 85092},
	{"RDUB", 4, 85093},
	{"MWRO", 4, 85094},
	{"CORTES", 6, 85095},
	{"RESULTADOS", 10, 85096},
	{"SPOONER", 7, 85097},
	{"INTRACTABLE", 11, 85098},
	{"CORRESPONDED", 12, 85099},
	{"MUSICMOZ", 8, 85100},
	{"TOOTHBRUSHES", 12, 85101},
	{"OSCL", 4, 85102},
	{"MHUR", 4, 85103},
	{"GGAI", 4, 85104},
	{"BUGATTI", 7, 85105},
	{"SPECKLED", 8, 85106},
	{"ABRAHAMS", 8, 85107},
	{"ENUMERATE", 9, 85108},
	{"EPME", 4, 85109},
	{"AFTL", 4, 85110},
	{"PERSUADING", 10, 85111},
	{"COMENTARIOS", 11, 85112},
	{"ONONDAGA", 8, 85113},
	{"PAYW", 4, 85114},
	{"MEJE", 4, 85115},
	{"DATJ", 4, 85116},
	{"BRANDYWINE", 10, 85117},
	{"CALLAGHAN", 9, 85118},
	{"DISKETTES", 9, 85119},
	{"RESONATE", 8, 85120},
	{"INTELLIVISION", 13, 85121},
	{"CASTELLE", 8, 85122},
	{"ADVERTISES", 10, 85123},
	{"NDIU", 4, 85124},
	{"FIVES", 5, 85125},
	{"TITUSVILLE", 10, 85126},
	{"PLAS", 4, 85127},
	{"RMYU", 4, 85128},
	{"GBYF", 4, 85129},
	{"FTME", 4, 85130},
	{"DKEI", 4, 85131},
	{"DIPHTHERIA", 10, 85132},
	{"ROYSTON", 7, 85133},
	{"WZK", 3, 85134},
	{"MMZ", 3, 85135},
	{"FJY", 3, 85136},
	{"DIGITALADVISOR", 14, 85137},
	{"ADESSO", 6, 85138},
	{"PICY", 4, 85139},
	{"MROU", 4, 85140},
	{"GEEKBUDDY", 9, 85141},
	{"LIPOIC", 6, 85142},
	{"HAZELWOOD", 9, 85143},
	{"GRAVATAR", 8, 85144},
	{"PLAINES", 7, 85145},
	{"OUTFIELD", 8, 85146},
	{"CARCINOGENESIS", 14, 85147},
	{"WUPS", 4, 85148},
	{"NOXF", 4, 85149},
	{"MTOV", 4, 85150},
	{"DOIF", 4, 85151},
	{"GDR", 3, 85152},
	{"PHENOLIC", 8, 85153},
	{"INCREMENTALLY", 13, 85154},
	{"UOYA", 4, 85155},
	{"OBCR", 4, 85156},
	{"LBID", 4, 85157},
	{"HOARD", 5, 85158},
	{"LENGHT", 6, 85159},
	{"ACOMPANHANTE", 12, 85160},
	{"OFFRE", 5, 85161},
	{"COURTING", 8, 85162},
	{"PETRIE", 6, 85163},
	{"TERRAPINS", 9, 85164},
	{"DARIA", 5, 85165},
	{"YEWE", 4, 85166},
	{"CTAW", 4, 85167},
	{"VANDER", 6, 85168},
	{"CCIE", 4, 85169},
	{"MATHML", 6, 85170},
	{"LEGALIZATION", 12, 85171},
	{"ALLENDALE", 9, 85172},
	{"LADING", 6, 85173},
	{"MODERNIZE", 9, 85174},
	{"WISM", 4, 85175},
	{"WOODCOCK", 8, 85176},
	{"GERT", 4, 85177},
	{"RESTARTS", 8, 85178},
	{"CHURNING", 8, 85179},
	{"JURIS", 5, 85180},
	{"OSBR", 4, 85181},
	{"BROOKSIDE", 9, 85182},
	{"CHARIOTS", 8, 85183},
	{"STREAMER", 8, 85184},
	{"ROLLEI", 6, 85185},
	{"YTAY", 4, 85186},
	{"IGHY", 4, 85187},
	{"BATTALIONS", 10, 85188},
	{"PICCHU", 6, 85189},
	{"UNQUESTIONABLY", 14, 85190},
	{"ABRIL", 5, 85191},
	{"GUSW", 4, 85192},
	{"CROCUS", 6, 85193},
	{"PRESQUE", 7, 85194},
	{"CITIZENRY", 9, 85195},
	{"URSR", 4, 85196},
	{"NUTB", 4, 85197},
	{"REPROACH", 8, 85198},
	{"ACCOUNTEMPS", 11, 85199},
	{"SWENSON", 7, 85200},
	{"UNFPA", 5, 85201},
	{"EWIDO", 5, 85202},
	{"CENTREVILLE", 11, 85203},
	{"ALISA", 5, 85204},
	{"URGB", 4, 85205},
	{"AFFN", 4, 85206},
	{"KINGSWAY", 8, 85207},
	{"ERLANGEN", 8, 85208},
	{"OFFTOPIC", 8, 85209},
	{"LAUNDROMAT", 10, 85210},
	{"TYAW", 4, 85211},
	{"REYL", 4, 85212},
	{"NMEG", 4, 85213},
	{"NGPS", 4, 85214},
	{"HPKW", 4, 85215},
	{"FASK", 4, 85216},
	{"REDEEMABLE", 10, 85217},
	{"ZELI", 4, 85218},
	{"MMUL", 4, 85219},
	{"GHIR", 4, 85220},
	{"EWVO", 4, 85221},
	{"MAXILLOFACIAL", 13, 85222},
	{"GLP", 3, 85223},
	{"BAUMANN", 7, 85224},
	{"UYWI", 4, 85225},
	{"UUND", 4, 85226},
	{"TLYY", 4, 85227},
	{"GIEW", 4, 85228},
	{"REVOLUTIONARIES", 15, 85229},
	{"VIOL", 4, 85230},
	{"CHILLIN", 7, 85231},
	{"CARDOMAIN", 9, 85232},
	{"CREAMED", 7, 85233},
	{"TARP", 4, 85234},
	{"MSNB", 4, 85235},
	{"MHUM", 4, 85236},
	{"ILFA", 4, 85237},
	{"HTGU", 4, 85238},
	{"VISHNU", 6, 85239},
	{"SCHERING", 8, 85240},
	{"BIKANER", 7, 85241},
	{"CHIMPANZEE", 10, 85242},
	{"PETCO", 5, 85243},
	{"ZLIE", 4, 85244},
	{"LGEA", 4, 85245},
	{"BTER", 4, 85246},
	{"ALKD", 4, 85247},
	{"FLURRIES", 8, 85248},
	{"MIKI", 4, 85249},
	{"MESON", 5, 85250},
	{"PARATHYROID", 11, 85251},
	{"YAFU", 4, 85252},
	{"CWEA", 4, 85253},
	{"CMB", 3, 85254},
	{"ANALGESIA", 9, 85255},
	{"CHERUB", 6, 85256},
	{"LIEDER", 6, 85257},
	{"TRUMPETER", 9, 85258},
	{"YNSK", 4, 85259},
	{"LWEC", 4, 85260},
	{"ICYB", 4, 85261},
	{"DMYE", 4, 85262},
	{"THEYRE", 6, 85263},
	{"STRAWS", 6, 85264},
	{"SERRATED", 8, 85265},
	{"ALTERA", 6, 85266},
	{"JEDDAH", 6, 85267},
	{"PUNY", 4, 85268},
	{"NANNIES", 7, 85269},
	{"EMPHATICALLY", 12, 85270},
	{"PAWTUCKET", 9, 85271},
	{"LTAD", 4, 85272},
	{"EWJA", 4, 85273},
	{"REASSURED", 9, 85274},
	{"BIMONTHLY", 9, 85275},
	{"PERCEIVING", 10, 85276},
	{"WARDROBES", 9, 85277},
	{"COMMENDATION", 12, 85278},
	{"SURGICALLY", 10, 85279},
	{"NONGOVERNMENTAL", 15, 85280},
	{"LEBEN", 5, 85281},
	{"UBPO", 4, 85282},
	{"AZYT", 4, 85283},
	{"AKSC", 4, 85284},
	{"RMDIR", 5, 85285},
	{"HYDROSTATIC", 11, 85286},
	{"ATTRIB", 6, 85287},
	{"YDUM", 4, 85288},
	{"RSNU", 4, 85289},
	{"FSYN", 4, 85290},
	{"CHEATERS", 8, 85291},
	{"CONTENDING", 10, 85292},
	{"PATRIARCHAL", 11, 85293},
	{"SPELT", 5, 85294},
	{"IGBL", 4, 85295},
	{"HAGAN", 5, 85296},
	{"CANLII", 6, 85297},
	{"LEONG", 5, 85298},
	{"KOEHLER", 7, 85299},
	{"BARKS", 5, 85300},
	{"CLOSTRIDIUM", 11, 85301},
	{"NERDY", 5, 85302},
	{"LLOQ", 4, 85303},
	{"HBYH", 4, 85304},
	{"GAGG", 4, 85305},
	{"MCNULTY", 7, 85306},
	{"MEGASTORES", 10, 85307},
	{"DODGING", 7, 85308},
	{"IMPERATIVES", 11, 85309},
	{"MLEN", 4, 85310},
	{"FBAG", 4, 85311},
	{"AWBU", 4, 85312},
	{"ASKB", 4, 85313},
	{"ACUB", 4, 85314},
	{"BPD", 3, 85315},
	{"ARCHETYPE", 9, 85316},
	{"KKK", 3, 85317},
	{"ANTISEPTIC", 10, 85318},
	{"HALSEY", 6, 85319},
	{"BROWNED", 7, 85320},
	{"ARTIC", 5, 85321},
	{"IPSY", 4, 85322},
	{"DEZA", 4, 85323},
	{"YTAU", 4, 85324},
	{"YKES", 4, 85325},
	{"TUNP", 4, 85326},
	{"OWVA", 4, 85327},
	{"LLGL", 4, 85328},
	{"HENDRIK", 7, 85329},
	{"HIGHLANDERS", 11, 85330},
	{"TECHWORLD", 9, 85331},
	{"SHAMANISM", 9, 85332},
	{"NUMARA", 6, 85333},
	{"LIGAMENTS", 9, 85334},
	{"UPBI", 4, 85335},
	{"ULKE", 4, 85336},
	{"OKKE", 4, 85337},
	{"ADVD", 4, 85338},
	{"ADCE", 4, 85339},
	{"REISERFS", 8, 85340},
	{"ROUSSILLON", 10, 85341},
	{"CHEADLE", 7, 85342},
	{"CREA", 4, 85343},
	{"ALCORN", 6, 85344},
	{"ENCES", 5, 85345},
	{"BOWSER", 6, 85346},
	{"WURDE", 5, 85347},
	{"FIZZ", 4, 85348},
	{"RSHL", 4, 85349},
	{"UPHEAVAL", 8, 85350},
	{"RATIONALIZE", 11, 85351},
	{"CRINGE", 6, 85352},
	{"KAROO", 5, 85353},
	{"UNEARTH", 7, 85354},
	{"BIOPSIES", 8, 85355},
	{"XEIR", 4, 85356},
	{"RGAY", 4, 85357},
	{"IFAF", 4, 85358},
	{"CTDU", 4, 85359},
	{"INCONCLUSIVE", 12, 85360},
	{"HOOKUPS", 7, 85361},
	{"HERRIN", 6, 85362},
	{"CRIMEA", 6, 85363},
	{"THERMOSTATS", 11, 85364},
	{"SUGARCANE", 9, 85365},
	{"CANOSCAN", 8, 85366},
	{"YAUN", 4, 85367},
	{"OVWA", 4, 85368},
	{"HFER", 4, 85369},
	{"MOLDOVAN", 8, 85370},
	{"JAMIROQUAI", 10, 85371},
	{"MOUTHFUL", 8, 85372},
	{"GAZELLE", 7, 85373},
	{"XERCES", 6, 85374},
	{"SUBCLAUSE", 9, 85375},
	{"NUEG", 4, 85376},
	{"KEIW", 4, 85377},
	{"CLASSNAME", 9, 85378},
	{"GAUCHE", 6, 85379},
	{"MINION", 6, 85380},
	{"MAKEFILES", 9, 85381},
	{"BETTIE", 6, 85382},
	{"SHEESH", 6, 85383},
	{"WOAC", 4, 85384},
	{"UEBI", 4, 85385},
	{"MPIE", 4, 85386},
	{"LYIH", 4, 85387},
	{"DOMD", 4, 85388},
	{"BIRDWATCHING", 12, 85389},
	{"SPEAKEASY", 9, 85390},
	{"HARPERS", 7, 85391},
	{"COMPLICITY", 10, 85392},
	{"HAYASHI", 7, 85393},
	{"EPITOPES", 8, 85394},
	{"UNSTRUNG", 8, 85395},
	{"DRIVEL", 6, 85396},
	{"XWOU", 4, 85397},
	{"UNKW", 4, 85398},
	{"UMPC", 4, 85399},
	{"ROGL", 4, 85400},
	{"FAJO", 4, 85401},
	{"BLANDFORD", 9, 85402},
	{"TENDONS", 7, 85403},
	{"FOCI", 4, 85404},
	{"TOPPINGS", 8, 85405},
	{"PPYC", 4, 85406},
	{"JAIM", 4, 85407},
	{"CANTILEVER", 10, 85408},
	{"THRIVES", 7, 85409},
	{"ZLR", 3, 85410},
	{"VDQ", 3, 85411},
	{"LQP", 3, 85412},
	{"CGJ", 3, 85413},
	{"BILOBA", 6, 85414},
	{"TWEETY", 6, 85415},
	{"GFUE", 4, 85416},
	{"DYGE", 4, 85417},
	{"CKNR", 4, 85418},
	{"INITIALIZES", 11, 85419},
	{"PENCHANT", 8, 85420},
	{"DRAB", 4, 85421},
	{"KECK", 4, 85422},
	{"ROARED", 6, 85423},
	{"FISICA", 6, 85424},
	{"PROSPECTOR", 10, 85425},
	{"UNWISE", 6, 85426},
	{"MACROMOLECULAR", 14, 85427},
	{"KUPB", 4, 85428},
	{"IDOK", 4, 85429},
	{"FINANCIER", 9, 85430},
	{"ALLEGORY", 8, 85431},
	{"SKAGIT", 6, 85432},
	{"HARBOURS", 8, 85433},
	{"KONSTANTIN", 10, 85434},
	{"ACROPOLIS", 9, 85435},
	{"YNEB", 4, 85436},
	{"KIMURA", 6, 85437},
	{"STIFLE", 6, 85438},
	{"BACA", 4, 85439},
	{"PARETO", 6, 85440},
	{"LYMPHOID", 8, 85441},
	{"APACER", 6, 85442},
	{"YPEM", 4, 85443},
	{"DUGA", 4, 85444},
	{"TIBERIUS", 8, 85445},
	{"PARADOXICAL", 11, 85446},
	{"FORKLIFTS", 9, 85447},
	{"KDEP", 4, 85448},
	{"FEYE", 4, 85449},
	{"BINM", 4, 85450},
	{"REFUGES", 7, 85451},
	{"HABANA", 6, 85452},
	{"STATELESS", 9, 85453},
	{"VIRTUA", 6, 85454},
	{"ROUSING", 7, 85455},
	{"CEREBELLUM", 10, 85456},
	{"XHAV", 4, 85457},
	{"MMEW", 4, 85458},
	{"MELU", 4, 85459},
	{"BREVILLE", 8, 85460},
	{"SEBASTOPOL", 10, 85461},
	{"STATEHOOD", 9, 85462},
	{"KNELT", 5, 85463},
	{"OWRY", 4, 85464},
	{"PALGRAVE", 8, 85465},
	{"RADIATING", 9, 85466},
	{"BLEDSOE", 7, 85467},
	{"DEVOUR", 6, 85468},
	{"XLEY", 4, 85469},
	{"SRAG", 4, 85470},
	{"LPHS", 4, 85471},
	{"FAGU", 4, 85472},
	{"ARUG", 4, 85473},
	{"INSANELY", 8, 85474},
	{"TREACHERY", 9, 85475},
	{"PETTING", 7, 85476},
	{"SCHK", 4, 85477},
	{"KRED", 4, 85478},
	{"DHRA", 4, 85479},
	{"INOCULATED", 10, 85480},
	{"INGLESE", 7, 85481},
	{"LUSY", 4, 85482},
	{"FHYD", 4, 85483},
	{"DPIS", 4, 85484},
	{"CPUR", 4, 85485},
	{"AIDABLE", 7, 85486},
	{"BUBBLEGUM", 9, 85487},
	{"APHEX", 5, 85488},
	{"PRINCESSES", 10, 85489},
	{"WROCLAW", 7, 85490},
	{"UBAA", 4, 85491},
	{"LIWO", 4, 85492},
	{"FMUT", 4, 85493},
	{"RAJKOT", 6, 85494},
	{"TAXIDERMY", 9, 85495},
	{"ROSSINI", 7, 85496},
	{"ESUBSCRIBE", 10, 85497},
	{"PORTRAITURE", 11, 85498},
	{"CARTAGENA", 9, 85499},
	{"INCAPACITATED", 13, 85500},
	{"OYRE", 4, 85501},
	{"OIDW", 4, 85502},
	{"GJEW", 4, 85503},
	{"CTHU", 4, 85504},
	{"JUERGEN", 7, 85505},
	{"ITRAVEL", 7, 85506},
	{"PASHMINA", 8, 85507},
	{"GUSTAFSON", 9, 85508},
	{"ATTESTED", 8, 85509},
	{"JACQUI", 6, 85510},
	{"OUDW", 4, 85511},
	{"MHUN", 4, 85512},
	{"LTLE", 4, 85513},
	{"BYIR", 4, 85514},
	{"SALIM", 5, 85515},
	{"BARNUM", 6, 85516},
	{"ANTHROPOLOGISTS", 15, 85517},
	{"GLUES", 5, 85518},
	{"UNDERCUT", 8, 85519},
	{"CSTV", 4, 85520},
	{"WATSONVILLE", 11, 85521},
	{"HODF", 4, 85522},
	{"DOXI", 4, 85523},
	{"NUESTRA", 7, 85524},
	{"ROASTER", 7, 85525},
	{"OVERCROWDED", 11, 85526},
	{"REDBRIDGE", 9, 85527},
	{"WARRING", 7, 85528},
	{"LUSD", 4, 85529},
	{"GEXI", 4, 85530},
	{"DASQ", 4, 85531},
	{"BENR", 4, 85532},
	{"HYPERTROPHY", 11, 85533},
	{"RAZA", 4, 85534},
	{"AROUSE", 6, 85535},
	{"DURON", 5, 85536},
	{"XSERVE", 6, 85537},
	{"WOBBLE", 6, 85538},
	{"IBEF", 4, 85539},
	{"DKAL", 4, 85540},
	{"FERGIE", 6, 85541},
	{"TICKED", 6, 85542},
	{"BOHR", 4, 85543},
	{"BOILERMAKERS", 12, 85544},
	{"COUNTERSTRIKE", 13, 85545},
	{"HINTERLAND", 10, 85546},
	{"WILC", 4, 85547},
	{"URSN", 4, 85548},
	{"POFY", 4, 85549},
	{"MVIR", 4, 85550},
	{"SUFI", 4, 85551},
	{"MILFCRUISER", 11, 85552},
	{"AFDC", 4, 85553},
	{"HOUSEWARMING", 12, 85554},
	{"REGENERATIVE", 12, 85555},
	{"CORRE", 5, 85556},
	{"PSIX", 4, 85557},
	{"PISP", 4, 85558},
	{"ILCR", 4, 85559},
	{"FMAH", 4, 85560},
	{"ANUG", 4, 85561},
	{"PURGED", 6, 85562},
	{"LIQUIDATORS", 11, 85563},
	{"CLEGG", 5, 85564},
	{"REPULSIVE", 9, 85565},
	{"BAGLESS", 7, 85566},
	{"WMOT", 4, 85567},
	{"UJIN", 4, 85568},
	{"HBAD", 4, 85569},
	{"BLEACHERS", 9, 85570},
	{"DEODORANTS", 10, 85571},
	{"BACTERIOPHAGE", 13, 85572},
	{"SHEENA", 6, 85573},
	{"PREZ", 4, 85574},
	{"SYAC", 4, 85575},
	{"SIKKIM", 6, 85576},
	{"SECLUSION", 9, 85577},
	{"BRASILEIROS", 11, 85578},
	{"TRANSECT", 8, 85579},
	{"THUMBSHOTS", 10, 85580},
	{"ELUCIDATE", 9, 85581},
	{"HEWY", 4, 85582},
	{"CHTY", 4, 85583},
	{"FATED", 5, 85584},
	{"SOLOISTS", 8, 85585},
	{"FRIGHTEN", 8, 85586},
	{"BORGES", 6, 85587},
	{"AMPUTATION", 10, 85588},
	{"SINUSOIDAL", 10, 85589},
	{"MANPAGE", 7, 85590},
	{"PATL", 4, 85591},
	{"KCOV", 4, 85592},
	{"DDOY", 4, 85593},
	{"LAZER", 5, 85594},
	{"BABYS", 5, 85595},
	{"CROSSOVERS", 10, 85596},
	{"YPON", 4, 85597},
	{"YETP", 4, 85598},
	{"WLEN", 4, 85599},
	{"AHUL", 4, 85600},
	{"PARSERS", 7, 85601},
	{"CHUAN", 5, 85602},
	{"HAULER", 6, 85603},
	{"TBAP", 4, 85604},
	{"CATALOGUING", 11, 85605},
	{"STORIA", 6, 85606},
	{"FOTOSEARCH", 10, 85607},
	{"USFS", 4, 85608},
	{"LEAPPAD", 7, 85609},
	{"INTERESDTING", 12, 85610},
	{"WVAL", 4, 85611},
	{"PICB", 4, 85612},
	{"OYOR", 4, 85613},
	{"LBYM", 4, 85614},
	{"EDKM", 4, 85615},
	{"HALTS", 5, 85616},
	{"HEADROOM", 8, 85617},
	{"FORTNIGHTLY", 11, 85618},
	{"YERBA", 5, 85619},
	{"KUTA", 4, 85620},
	{"SUBTLETY", 8, 85621},
	{"CREDITABLE", 10, 85622},
	{"CLEARFIELD", 10, 85623},
	{"RREO", 4, 85624},
	{"EPWH", 4, 85625},
	{"PROTRUDING", 10, 85626},
	{"HUGGINS", 7, 85627},
	{"FUCI", 4, 85628},
	{"WASHOE", 6, 85629},
	{"APPRECIABLE", 11, 85630},
	{"STABILISATION", 13, 85631},
	{"DELICACY", 8, 85632},
	{"SAYERS", 6, 85633},
	{"PARADIS", 7, 85634},
	{"URIR", 4, 85635},
	{"PALG", 4, 85636},
	{"ONCB", 4, 85637},
	{"KYRI", 4, 85638},
	{"HODD", 4, 85639},
	{"CINCH", 5, 85640},
	{"PUBLIS", 6, 85641},
	{"FUTILITY", 8, 85642},
	{"UKIA", 4, 85643},
	{"RKOP", 4, 85644},
	{"PBUS", 4, 85645},
	{"KATB", 4, 85646},
	{"EXHU", 4, 85647},
	{"INTANGIBLES", 11, 85648},
	{"DUMPLINGS", 9, 85649},
	{"TAMESIDE", 8, 85650},
	{"DIESEN", 6, 85651},
	{"SUMMERVILLE", 11, 85652},
	{"IFEU", 4, 85653},
	{"UVM", 3, 85654},
	{"WHALEN", 6, 85655},
	{"KUSADASI", 8, 85656},
	{"FLAK", 4, 85657},
	{"UITD", 4, 85658},
	{"UDOA", 4, 85659},
	{"LIJA", 4, 85660},
	{"GBYW", 4, 85661},
	{"AVYE", 4, 85662},
	{"CUBED", 5, 85663},
	{"YUCK", 4, 85664},
	{"CONCACAF", 8, 85665},
	{"UPHOLDS", 7, 85666},
	{"ENLISTMENT", 10, 85667},
	{"TEXTBOX", 7, 85668},
	{"INROADS", 7, 85669},
	{"BLISSFUL", 8, 85670},
	{"MEOC", 4, 85671},
	{"IDCU", 4, 85672},
	{"ERGB", 4, 85673},
	{"DUPU", 4, 85674},
	{"ERYTHROCYTES", 12, 85675},
	{"DINKY", 5, 85676},
	{"BOASTED", 7, 85677},
	{"ZEALANDERS", 10, 85678},
	{"DIVO", 4, 85679},
	{"STIRS", 5, 85680},
	{"ZBB", 3, 85681},
	{"RFZ", 3, 85682},
	{"PLATONIC", 8, 85683},
	{"DONKEYS", 7, 85684},
	{"INJUNCTIVE", 10, 85685},
	{"HONED", 5, 85686},
	{"COINCIDENTALLY", 14, 85687},
	{"UWIS", 4, 85688},
	{"USKO", 4, 85689},
	{"RNEF", 4, 85690},
	{"OIDL", 4, 85691},
	{"OGAU", 4, 85692},
	{"KOLB", 4, 85693},
	{"KRUSE", 5, 85694},
	{"MICROM", 6, 85695},
	{"BLEQ", 4, 85696},
	{"PORTUGUES", 9, 85697},
	{"DEATHMATCH", 10, 85698},
	{"NPIP", 4, 85699},
	{"KSJU", 4, 85700},
	{"BUME", 4, 85701},
	{"PUBLICA", 7, 85702},
	{"POLLINATION", 11, 85703},
	{"SYNCHRO", 7, 85704},
	{"OBUC", 4, 85705},
	{"NHYP", 4, 85706},
	{"MYHI", 4, 85707},
	{"LRAM", 4, 85708},
	{"ETOBICOKE", 9, 85709},
	{"MIDORI", 6, 85710},
	{"CHUTNEY", 7, 85711},
	{"AVERSE", 6, 85712},
	{"NATUROPATHIC", 12, 85713},
	{"SIEMPRE", 7, 85714},
	{"AFIELD", 6, 85715},
	{"DERMATOLOGIST", 13, 85716},
	{"THUMBNAILPOST", 13, 85717},
	{"CASEIN", 6, 85718},
	{"CHILLOUT", 8, 85719},
	{"ENDEARING", 9, 85720},
	{"MISHAP", 6, 85721},
	{"STEFANIE", 8, 85722},
	{"CHEWABLE", 8, 85723},
	{"LACKEY", 6, 85724},
	{"DIREC", 5, 85725},
	{"QUOD", 4, 85726},
	{"LABORS", 6, 85727},
	{"WDEP", 4, 85728},
	{"QUINTANA", 8, 85729},
	{"WHOOPING", 8, 85730},
	{"NORMALS", 7, 85731},
	{"SONNETS", 7, 85732},
	{"PSEY", 4, 85733},
	{"DYMU", 4, 85734},
	{"VILLENEUVE", 10, 85735},
	{"SCRUM", 5, 85736},
	{"EVERYMAN", 8, 85737},
	{"WCLE", 4, 85738},
	{"MMOB", 4, 85739},
	{"HOCU", 4, 85740},
	{"MUSING", 6, 85741},
	{"MASAI", 5, 85742},
	{"LOPES", 5, 85743},
	{"BARRICADE", 9, 85744},
	{"INQUEST", 7, 85745},
	{"SNIPE", 5, 85746},
	{"EASTLAND", 8, 85747},
	{"FOOTBALLERS", 11, 85748},
	{"XVIEWG", 6, 85749},
	{"METROPOLE", 9, 85750},
	{"SWARTHMORE", 10, 85751},
	{"OGWH", 4, 85752},
	{"BCCO", 4, 85753},
	{"MULTICENTER", 11, 85754},
	{"HAPLESS", 7, 85755},
	{"SAGEBRUSH", 9, 85756},
	{"CONVENOR", 8, 85757},
	{"CUENTA", 6, 85758},
	{"PROTEOME", 8, 85759},
	{"WARHEADS", 8, 85760},
	{"POLEN", 5, 85761},
	{"RADIOLOGIST", 11, 85762},
	{"ILYK", 4, 85763},
	{"ABLY", 4, 85764},
	{"MONTAGNE", 8, 85765},
	{"OFMT", 4, 85766},
	{"KDEV", 4, 85767},
	{"WESTVIEW", 8, 85768},
	{"BRUN", 4, 85769},
	{"MIRZA", 5, 85770},
	{"LABB", 4, 85771},
	{"OPTUS", 5, 85772},
	{"MEDICINENET", 11, 85773},
	{"HITCHES", 7, 85774},
	{"BRITTEN", 7, 85775},
	{"PALETTES", 8, 85776},
	{"OFFJ", 4, 85777},
	{"HFOC", 4, 85778},
	{"BEAUX", 5, 85779},
	{"DEPAUW", 6, 85780},
	{"GUNMAN", 6, 85781},
	{"TRAVERSED", 9, 85782},
	{"AGASSI", 6, 85783},
	{"SPARSELY", 8, 85784},
	{"WNJU", 4, 85785},
	{"SHRINKS", 7, 85786},
	{"CHANNING", 8, 85787},
	{"PANOZ", 5, 85788},
	{"UWB", 3, 85789},
	{"MOVI", 4, 85790},
	{"OFIB", 4, 85791},
	{"IREQ", 4, 85792},
	{"DBOI", 4, 85793},
	{"BSPR", 4, 85794},
	{"SCANLON", 7, 85795},
	{"NUTRI", 5, 85796},
	{"MITRA", 5, 85797},
	{"GUILDERS", 8, 85798},
	{"FILMPJE", 7, 85799},
	{"INDEXER", 7, 85800},
	{"OFDM", 4, 85801},
	{"INNKEEPER", 9, 85802},
	{"ULLMAN", 6, 85803},
	{"COACHELLA", 9, 85804},
	{"LOCALISED", 9, 85805},
	{"WFLO", 4, 85806},
	{"LPSM", 4, 85807},
	{"IDMY", 4, 85808},
	{"DEGI", 4, 85809},
	{"RECOM", 5, 85810},
	{"DOWNGRADED", 10, 85811},
	{"NCEP", 4, 85812},
	{"MISTRUST", 8, 85813},
	{"TCOC", 4, 85814},
	{"LIOF", 4, 85815},
	{"KECU", 4, 85816},
	{"IEMU", 4, 85817},
	{"OVERCOMES", 9, 85818},
	{"LORDSHIP", 8, 85819},
	{"LALIQUE", 7, 85820},
	{"WEILL", 5, 85821},
	{"JEEZ", 4, 85822},
	{"VARADERO", 8, 85823},
	{"CHICCO", 6, 85824},
	{"ATHABASCA", 9, 85825},
	{"ASKR", 4, 85826},
	{"REDD", 4, 85827},
	{"AZUSA", 5, 85828},
	{"UNBUFFERED", 10, 85829},
	{"PHONING", 7, 85830},
	{"RTTY", 4, 85831},
	{"TMYW", 4, 85832},
	{"EKSR", 4, 85833},
	{"EIDL", 4, 85834},
	{"SPACEY", 6, 85835},
	{"FMLA", 4, 85836},
	{"ALBATRON", 8, 85837},
	{"LJOR", 4, 85838},
	{"EKKE", 4, 85839},
	{"EGREGIOUS", 9, 85840},
	{"CUBANS", 6, 85841},
	{"UFMA", 4, 85842},
	{"TOPJ", 4, 85843},
	{"JOYF", 4, 85844},
	{"EMYN", 4, 85845},
	{"BREAKPOINTS", 11, 85846},
	{"SPERMA", 6, 85847},
	{"CIENCIAS", 8, 85848},
	{"MORTAGE", 7, 85849},
	{"LEGATO", 6, 85850},
	{"WYAT", 4, 85851},
	{"UGRA", 4, 85852},
	{"RGOP", 4, 85853},
	{"AGAROSE", 7, 85854},
	{"AVOCA", 5, 85855},
	{"RESERVADOS", 10, 85856},
	{"RUSSELLVILLE", 12, 85857},
	{"ONEONTA", 7, 85858},
	{"MRCO", 4, 85859},
	{"MOMW", 4, 85860},
	{"IFBO", 4, 85861},
	{"FVEH", 4, 85862},
	{"AJEC", 4, 85863},
	{"BADASS", 6, 85864},
	{"TRANSACTED", 10, 85865},
	{"WDEG", 4, 85866},
	{"ROWG", 4, 85867},
	{"NBYV", 4, 85868},
	{"MPHS", 4, 85869},
	{"PESCA", 5, 85870},
	{"BLAISE", 6, 85871},
	{"CARVALHO", 8, 85872},
	{"CHAPLAINS", 9, 85873},
	{"CONVENTIONALLY", 14, 85874},
	{"WANW", 4, 85875},
	{"PEVI", 4, 85876},
	{"MDRO", 4, 85877},
	{"CUPH", 4, 85878},
	{"NUESTRO", 7, 85879},
	{"MAINPAGE", 8, 85880},
	{"PERCEPTIVE", 10, 85881},
	{"MCCORD", 6, 85882},
	{"HABER", 5, 85883},
	{"KELLIE", 6, 85884},
	{"LARD", 4, 85885},
	{"ALLSTARS", 8, 85886},
	{"UPEX", 4, 85887},
	{"RFEN", 4, 85888},
	{"EBEV", 4, 85889},
	{"DARWINISM", 9, 85890},
	{"TARIQ", 5, 85891},
	{"WORKAROUNDS", 11, 85892},
	{"FLANNERY", 8, 85893},
	{"RJAY", 4, 85894},
	{"PSUC", 4, 85895},
	{"LLJE", 4, 85896},
	{"REDIFF", 6, 85897},
	{"LECITHIN", 8, 85898},
	{"DESTITUTE", 9, 85899},
	{"YEAG", 4, 85900},
	{"TPUM", 4, 85901},
	{"NPAD", 4, 85902},
	{"HYCH", 4, 85903},
	{"PLATZ", 5, 85904},
	{"OKMULGEE", 8, 85905},
	{"LATES", 5, 85906},
	{"DISBANDED", 9, 85907},
	{"SINGLY", 6, 85908},
	{"RECERTIFICATION", 15, 85909},
	{"YAGU", 4, 85910},
	{"HAMG", 4, 85911},
	{"FFCH", 4, 85912},
	{"ADCU", 4, 85913},
	{"PHOSPHORYLATED", 14, 85914},
	{"FUSING", 6, 85915},
	{"NERC", 4, 85916},
	{"AVERMEDIA", 9, 85917},
	{"ABUSER", 6, 85918},
	{"UPUL", 4, 85919},
	{"UKIL", 4, 85920},
	{"RKOZ", 4, 85921},
	{"HTRY", 4, 85922},
	{"SEVENS", 6, 85923},
	{"HEADLESS", 8, 85924},
	{"MUKHERJEE", 9, 85925},
	{"ANATOMIC", 8, 85926},
	{"WATERCOOLER", 11, 85927},
	{"PETRIFIED", 9, 85928},
	{"GATSBY", 6, 85929},
	{"RDYN", 4, 85930},
	{"EYEP", 4, 85931},
	{"LITHO", 5, 85932},
	{"MISCHA", 6, 85933},
	{"BANGLA", 6, 85934},
	{"MENARD", 6, 85935},
	{"EMIGRANTS", 9, 85936},
	{"RATTLING", 8, 85937},
	{"ARTES", 5, 85938},
	{"VACAVILLE", 9, 85939},
	{"UKEI", 4, 85940},
	{"RRUD", 4, 85941},
	{"MKIL", 4, 85942},
	{"KBEH", 4, 85943},
	{"ENERMAX", 7, 85944},
	{"HYPO", 4, 85945},
	{"SALVE", 5, 85946},
	{"HADRON", 6, 85947},
	{"HINDUSTAN", 9, 85948},
	{"MARSEILLES", 10, 85949},
	{"BEAUCHAMP", 9, 85950},
	{"GRATES", 6, 85951},
	{"GOSFORD", 7, 85952},
	{"RQUO", 4, 85953},
	{"AFAB", 4, 85954},
	{"ABDE", 4, 85955},
	{"ZLF", 3, 85956},
	{"WXX", 3, 85957},
	{"WWX", 3, 85958},
	{"FISSURE", 7, 85959},
	{"CURTAIL", 7, 85960},
	{"LEGALIZE", 8, 85961},
	{"WLYM", 4, 85962},
	{"PUEB", 4, 85963},
	{"MILLBROOK", 9, 85964},
	{"EPINEPHRINE", 11, 85965},
	{"TRANSOM", 7, 85966},
	{"LIEBHERR", 8, 85967},
	{"MWC", 3, 85968},
	{"TALKER", 6, 85969},
	{"BIEL", 4, 85970},
	{"VCU", 3, 85971},
	{"TCHK", 4, 85972},
	{"PROR", 4, 85973},
	{"LADJ", 4, 85974},
	{"GATY", 4, 85975},
	{"FAUD", 4, 85976},
	{"DIVORCES", 8, 85977},
	{"MILS", 4, 85978},
	{"OREAL", 5, 85979},
	{"PICAYUNE", 8, 85980},
	{"VITESSE", 7, 85981},
	{"WINKS", 5, 85982},
	{"RABANNE", 7, 85983},
	{"TAXM", 4, 85984},
	{"MYGE", 4, 85985},
	{"FLUK", 4, 85986},
	{"ELDV", 4, 85987},
	{"HARTE", 5, 85988},
	{"LOOPHOLES", 9, 85989},
	{"GORBACHEV", 9, 85990},
	{"NORELCO", 7, 85991},
	{"PLAYSET", 7, 85992},
	{"NOVELISTS", 9, 85993},
	{"MASSACRATION", 12, 85994},
	{"BESTOW", 6, 85995},
	{"POPR", 4, 85996},
	{"KLOW", 4, 85997},
	{"ALMP", 4, 85998},
	{"FRONTMAN", 8, 85999},
	{"GARVIN", 6, 86000},
	{"AUTOLOGOUS", 10, 86001},
	{"WIRETAPS", 8, 86002},
	{"HOMESPUN", 8, 86003},
	{"DUGGAN", 6, 86004},
	{"JRC", 3, 86005},
	{"CHANTELLE", 9, 86006},
	{"LIDDELL", 7, 86007},
	{"HULLS", 5, 86008},
	{"ENRAGED", 7, 86009},
	{"OOBJ", 4, 86010},
	{"MVAN", 4, 86011},
	{"MMYR", 4, 86012},
	{"ADRIEN", 6, 86013},
	{"BLOTTER", 7, 86014},
	{"MENUBAR", 7, 86015},
	{"SSUL", 4, 86016},
	{"IPUS", 4, 86017},
	{"FMPH", 4, 86018},
	{"GAGNON", 6, 86019},
	{"COMPLIMENTED", 12, 86020},
	{"SITTERS", 7, 86021},
	{"INTONATION", 10, 86022},
	{"PROCLAIMS", 9, 86023},
	{"RDC", 3, 86024},
	{"URYU", 4, 86025},
	{"UPKE", 4, 86026},
	{"RMDI", 4, 86027},
	{"METEO", 5, 86028},
	{"DISSECTING", 10, 86029},
	{"CEPT", 4, 86030},
	{"PROGRAMING", 10, 86031},
	{"HUMPBACK", 8, 86032},
	{"FOURNIER", 8, 86033},
	{"ALQUILER", 8, 86034},
	{"REPROCESSING", 12, 86035},
	{"CHAZ", 4, 86036},
	{"BARTENDING", 10, 86037},
	{"OPODO", 5, 86038},
	{"PATIALA", 7, 86039},
	{"CLAMPED", 7, 86040},
	{"JAQUES", 6, 86041},
	{"RETRACTED", 9, 86042},
	{"GLC", 3, 86043},
	{"PBEG", 4, 86044},
	{"ILAY", 4, 86045},
	{"FANTASTICO", 10, 86046},
	{"FRIAR", 5, 86047},
	{"HOSPITABLE", 10, 86048},
	{"SCHIFFER", 8, 86049},
	{"MELODRAMA", 9, 86050},
	{"PRECLINICAL", 11, 86051},
	{"CONKLIN", 7, 86052},
	{"WBOT", 4, 86053},
	{"ULFW", 4, 86054},
	{"NWAK", 4, 86055},
	{"MPTW", 4, 86056},
	{"CREASED", 7, 86057},
	{"WHEELERS", 8, 86058},
	{"PREPARER", 8, 86059},
	{"DEDUCTIVE", 9, 86060},
	{"POSTURES", 8, 86061},
	{"TRAPPER", 7, 86062},
	{"RYGL", 4, 86063},
	{"GHVI", 4, 86064},
	{"CUNARD", 6, 86065},
	{"MAKESHIFT", 9, 86066},
	{"PYGMY", 5, 86067},
	{"JEWETT", 6, 86068},
	{"TATTERED", 8, 86069},
	{"NGOK", 4, 86070},
	{"MCHU", 4, 86071},
	{"MCBR", 4, 86072},
	{"LPSU", 4, 86073},
	{"ENVIRONNEMENT", 13, 86074},
	{"BIDDLE", 6, 86075},
	{"BASU", 4, 86076},
	{"TACHOMETER", 10, 86077},
	{"EMBARRASS", 9, 86078},
	{"NONPROLIFERATION", 16, 86079},
	{"CACHAREL", 8, 86080},
	{"ELYSEES", 7, 86081},
	{"SLANTED", 7, 86082},
	{"PLAGUES", 7, 86083},
	{"KNRO", 4, 86084},
	{"ORCHESTRATION", 13, 86085},
	{"ADIPOSE", 7, 86086},
	{"HARVESTS", 8, 86087},
	{"FREESERVERS", 11, 86088},
	{"POTTING", 7, 86089},
	{"WMIS", 4, 86090},
	{"UNCOMPLICATED", 13, 86091},
	{"PROGS", 5, 86092},
	{"RMNO", 4, 86093},
	{"RKAV", 4, 86094},
	{"SURGED", 6, 86095},
	{"BLUME", 5, 86096},
	{"TOBEY", 5, 86097},
	{"WENZEL", 6, 86098},
	{"WNOP", 4, 86099},
	{"UBRA", 4, 86100},
	{"IPFI", 4, 86101},
	{"IFYS", 4, 86102},
	{"DEBI", 4, 86103},
	{"BAEZ", 4, 86104},
	{"NATURED", 7, 86105},
	{"CLEMENCY", 8, 86106},
	{"WOOLLY", 6, 86107},
	{"GEDCOM", 6, 86108},
	{"UVC", 3, 86109},
	{"YJEN", 4, 86110},
	{"WAGR", 4, 86111},
	{"VILO", 4, 86112},
	{"MGOD", 4, 86113},
	{"PUCCINI", 7, 86114},
	{"LIGATION", 8, 86115},
	{"BLEMISH", 7, 86116},
	{"WLYW", 4, 86117},
	{"SEDQ", 4, 86118},
	{"MCQU", 4, 86119},
	{"GFES", 4, 86120},
	{"AKCA", 4, 86121},
	{"DECONSTRUCTION", 14, 86122},
	{"INDUCTANCE", 10, 86123},
	{"TOPICPARENT", 11, 86124},
	{"ZANAFLEX", 8, 86125},
	{"MEDICUS", 7, 86126},
	{"DMITRI", 6, 86127},
	{"MNER", 4, 86128},
	{"EMSG", 4, 86129},
	{"EDOK", 4, 86130},
	{"AJOUTER", 7, 86131},
	{"REALLOCATION", 12, 86132},
	{"KALISPELL", 9, 86133},
	{"BUSHELS", 7, 86134},
	{"HAIGHT", 6, 86135},
	{"TAPERS", 6, 86136},
	{"YIFE", 4, 86137},
	{"RUSL", 4, 86138},
	{"HYFR", 4, 86139},
	{"TELEPORT", 8, 86140},
	{"SKYLIGHTS", 9, 86141},
	{"GENIUSES", 8, 86142},
	{"REHABILITATIVE", 14, 86143},
	{"TOCY", 4, 86144},
	{"RERP", 4, 86145},
	{"BBYB", 4, 86146},
	{"AXAB", 4, 86147},
	{"SWAB", 4, 86148},
	{"RIND", 4, 86149},
	{"LATIMER", 7, 86150},
	{"BOOMBOX", 7, 86151},
	{"PRORATED", 8, 86152},
	{"WHISKERS", 8, 86153},
	{"BBR", 3, 86154},
	{"PANSY", 5, 86155},
	{"REASSIGNMENT", 12, 86156},
	{"HYDRODYNAMIC", 12, 86157},
	{"PDEA", 4, 86158},
	{"EFUM", 4, 86159},
	{"CONB", 4, 86160},
	{"CONFIRMATIONS", 13, 86161},
	{"POSTULATED", 10, 86162},
	{"HUNTSMAN", 8, 86163},
	{"UNLABELED", 9, 86164},
	{"PERSONNE", 8, 86165},
	{"PERPETUALLY", 11, 86166},
	{"TOSCA", 5, 86167},
	{"BRENTFORD", 9, 86168},
	{"PSOV", 4, 86169},
	{"ELPK", 4, 86170},
	{"CKCU", 4, 86171},
	{"INTEGRIN", 8, 86172},
	{"SOUNDINGS", 9, 86173},
	{"EVICTED", 7, 86174},
	{"RANLIB", 6, 86175},
	{"DIFFERENTIATES", 14, 86176},
	{"RARA", 4, 86177},
	{"WTAL", 4, 86178},
	{"OWDY", 4, 86179},
	{"EPHC", 4, 86180},
	{"EMCK", 4, 86181},
	{"CALZ", 4, 86182},
	{"SKELAXIN", 8, 86183},
	{"VELO", 4, 86184},
	{"DIVISIBLE", 9, 86185},
	{"TTUB", 4, 86186},
	{"PIGM", 4, 86187},
	{"NFLH", 4, 86188},
	{"MSAW", 4, 86189},
	{"IDCE", 4, 86190},
	{"CUSR", 4, 86191},
	{"COCT", 4, 86192},
	{"CINP", 4, 86193},
	{"MULTIPROCESSOR", 14, 86194},
	{"TABLA", 5, 86195},
	{"CELLULOID", 9, 86196},
	{"IDENTICALLY", 11, 86197},
	{"LIGHTNESS", 9, 86198},
	{"YWRE", 4, 86199},
	{"GTHB", 4, 86200},
	{"DIPR", 4, 86201},
	{"DGOF", 4, 86202},
	{"SADDLERY", 8, 86203},
	{"AVOIR", 5, 86204},
	{"WHITESIDE", 9, 86205},
	{"YSBL", 4, 86206},
	{"YMUT", 4, 86207},
	{"SEYR", 4, 86208},
	{"EURAIL", 6, 86209},
	{"ENDICOTT", 8, 86210},
	{"QUELLE", 6, 86211},
	{"ADMIRERS", 8, 86212},
	{"DINGO", 5, 86213},
	{"MARCELLO", 8, 86214},
	{"SESSIONAL", 9, 86215},
	{"PAGINATION", 10, 86216},
	{"WEBTOPICLIST", 12, 86217},
	{"PPUR", 4, 86218},
	{"OLTW", 4, 86219},
	{"MFIV", 4, 86220},
	{"AYHU", 4, 86221},
	{"HARBINGER", 9, 86222},
	{"INFOPOP", 7, 86223},
	{"ACCC", 4, 86224},
	{"MUSTACHE", 8, 86225},
	{"OFMS", 4, 86226},
	{"EFDE", 4, 86227},
	{"BURL", 4, 86228},
	{"TRUNCATE", 8, 86229},
	{"HIGHTOWER", 9, 86230},
	{"IPLY", 4, 86231},
	{"GGAE", 4, 86232},
	{"POLYGRAPH", 9, 86233},
	{"ALLIANZ", 7, 86234},
	{"DIGRESS", 7, 86235},
	{"OVERSEEN", 8, 86236},
	{"THOTLIB", 7, 86237},
	{"BLUETAKE", 8, 86238},
	{"WISL", 4, 86239},
	{"DLIO", 4, 86240},
	{"COWES", 5, 86241},
	{"REVOLUTIONIZE", 13, 86242},
	{"XDW", 3, 86243},
	{"WBV", 3, 86244},
	{"LVJ", 3, 86245},
	{"DWINDLING", 9, 86246},
	{"BEAKER", 6, 86247},
	{"MAILORDER", 9, 86248},
	{"FETUSES", 7, 86249},
	{"LOWNDES", 7, 86250},
	{"WNFE", 4, 86251},
	{"RELW", 4, 86252},
	{"LKFR", 4, 86253},
	{"DAMR", 4, 86254},
	{"ARCADES", 7, 86255},
	{"BAGGY", 5, 86256},
	{"JEWELED", 7, 86257},
	{"CHILDBEARING", 12, 86258},
	{"CRAYFISH", 8, 86259},
	{"MINOTAUR", 8, 86260},
	{"REJOICING", 9, 86261},
	{"MAYNE", 5, 86262},
	{"REPAINT", 7, 86263},
	{"UOMO", 4, 86264},
	{"ARIADNE", 7, 86265},
	{"CONTR", 5, 86266},
	{"ZOOL", 4, 86267},
	{"SPASTIC", 7, 86268},
	{"DICKIE", 6, 86269},
	{"SUPRISED", 8, 86270},
	{"QUIVER", 6, 86271},
	{"ILLUMINATI", 10, 86272},
	{"VWIT", 4, 86273},
	{"USGU", 4, 86274},
	{"SOXF", 4, 86275},
	{"MLEG", 4, 86276},
	{"GSDU", 4, 86277},
	{"PIEZOELECTRIC", 13, 86278},
	{"RFPS", 4, 86279},
	{"CUTOUTS", 7, 86280},
	{"VINTON", 6, 86281},
	{"SYLVIE", 6, 86282},
	{"FREQUENTED", 10, 86283},
	{"CORONET", 7, 86284},
	{"MYAP", 4, 86285},
	{"BOSW", 4, 86286},
	{"AGNEW", 5, 86287},
	{"MEIR", 4, 86288},
	{"DISCREDITED", 11, 86289},
	{"TANITA", 6, 86290},
	{"TAVERNS", 7, 86291},
	{"PRODIGAL", 8, 86292},
	{"SUBSIDISED", 10, 86293},
	{"TCOW", 4, 86294},
	{"PISM", 4, 86295},
	{"FSEM", 4, 86296},
	{"ARCSEC", 6, 86297},
	{"WIELD", 5, 86298},
	{"ZESC", 4, 86299},
	{"WDUR", 4, 86300},
	{"TMUT", 4, 86301},
	{"SJOR", 4, 86302},
	{"RESOLUTE", 8, 86303},
	{"WRESTLEMANIA", 12, 86304},
	{"ADAGE", 5, 86305},
	{"GETTER", 6, 86306},
	{"MIMICS", 6, 86307},
	{"RDJE", 4, 86308},
	{"PUSF", 4, 86309},
	{"OPGO", 4, 86310},
	{"WATERMARKING", 12, 86311},
	{"AFTERCARE", 9, 86312},
	{"COOMBS", 6, 86313},
	{"WOLFSON", 7, 86314},
	{"SEFTON", 6, 86315},
	{"UBAD", 4, 86316},
	{"CYSI", 4, 86317},
	{"COMPU", 5, 86318},
	{"WETTER", 6, 86319},
	{"BONAVENTURE", 11, 86320},
	{"APPZ", 4, 86321},
	{"GVIEW", 5, 86322},
	{"TEMPERATURA", 11, 86323},
	{"DIASTOLIC", 9, 86324},
	{"DEFAULTED", 9, 86325},
	{"WNPU", 4, 86326},
	{"OGSB", 4, 86327},
	{"OCYT", 4, 86328},
	{"FGDP", 4, 86329},
	{"CESAREAN", 8, 86330},
	{"DIALLING", 8, 86331},
	{"RESCINDED", 9, 86332},
	{"CONJURE", 7, 86333},
	{"CHITIKA", 7, 86334},
	{"AMUD", 4, 86335},
	{"AFFP", 4, 86336},
	{"DISCOLORATION", 13, 86337},
	{"CHELAN", 6, 86338},
	{"RECITALS", 8, 86339},
	{"MOREL", 5, 86340},
	{"VDRE", 4, 86341},
	{"UFFB", 4, 86342},
	{"PFAT", 4, 86343},
	{"IZEY", 4, 86344},
	{"GIAW", 4, 86345},
	{"CUTR", 4, 86346},
	{"BBEL", 4, 86347},
	{"ADRIFT", 6, 86348},
	{"KASHMIRI", 8, 86349},
	{"CONFISCATION", 12, 86350},
	{"STACIE", 6, 86351},
	{"TARJ", 4, 86352},
	{"RDNU", 4, 86353},
	{"OXCA", 4, 86354},
	{"EXLE", 4, 86355},
	{"BUYC", 4, 86356},
	{"COLLAGES", 8, 86357},
	{"ENABLER", 7, 86358},
	{"MOWBRAY", 7, 86359},
	{"SCHULER", 7, 86360},
	{"UKEB", 4, 86361},
	{"UJIT", 4, 86362},
	{"OLSG", 4, 86363},
	{"OFZO", 4, 86364},
	{"GRYT", 4, 86365},
	{"FINLAY", 6, 86366},
	{"STINGS", 6, 86367},
	{"GEZONDHEID", 10, 86368},
	{"YLANG", 5, 86369},
	{"ORIK", 4, 86370},
	{"LKMA", 4, 86371},
	{"EXFE", 4, 86372},
	{"BUDGE", 5, 86373},
	{"LUFKIN", 6, 86374},
	{"TENGE", 5, 86375},
	{"ACOSTA", 6, 86376},
	{"TURBOTAX", 8, 86377},
	{"HERBALS", 7, 86378},
	{"MODERATES", 9, 86379},
	{"PIOTR", 5, 86380},
	{"CHAIRMANSHIP", 12, 86381},
	{"COVAD", 5, 86382},
	{"COMUNIDAD", 9, 86383},
	{"MOORES", 6, 86384},
	{"HURGHADA", 8, 86385},
	{"SILKS", 5, 86386},
	{"PPAB", 4, 86387},
	{"OFSR", 4, 86388},
	{"EHYB", 4, 86389},
	{"DPEE", 4, 86390},
	{"ABWO", 4, 86391},
	{"MALFORMED", 9, 86392},
	{"SEQUINS", 7, 86393},
	{"SEATBELT", 8, 86394},
	{"DUMBBELL", 8, 86395},
	{"CHASERS", 7, 86396},
	{"HAMER", 5, 86397},
	{"OKWO", 4, 86398},
	{"SHERWIN", 7, 86399},
	{"REDISSEMINATION", 15, 86400},
	{"MCMULLEN", 8, 86401},
	{"FRINGED", 7, 86402},
	{"RNKE", 4, 86403},
	{"SKOPJE", 6, 86404},
	{"GPX", 3, 86405},
	{"SUPPLEMENTING", 13, 86406},
	{"LOWRIDER", 8, 86407},
	{"LIAISE", 6, 86408},
	{"CITRIC", 6, 86409},
	{"RDTW", 4, 86410},
	{"PORP", 4, 86411},
	{"ANMP", 4, 86412},
	{"ADKE", 4, 86413},
	{"OPENTYPE", 8, 86414},
	{"JPMORGAN", 8, 86415},
	{"GOBLINS", 7, 86416},
	{"DELINEATE", 9, 86417},
	{"NITRIDE", 7, 86418},
	{"RKDU", 4, 86419},
	{"LOSM", 4, 86420},
	{"ORGANIST", 8, 86421},
	{"ACHIEVERS", 9, 86422},
	{"UNBONDED", 8, 86423},
	{"OGYL", 4, 86424},
	{"MOFU", 4, 86425},
	{"IROM", 4, 86426},
	{"GKEY", 4, 86427},
	{"COWEN", 5, 86428},
	{"SUBDIR", 6, 86429},
	{"REHEARING", 9, 86430},
	{"ILLUMINATIONS", 13, 86431},
	{"BALMAIN", 7, 86432},
	{"KHUR", 4, 86433},
	{"BYMC", 4, 86434},
	{"CHUCKLED", 8, 86435},
	{"TACITUS", 7, 86436},
	{"CRISSY", 6, 86437},
	{"MENDOTA", 7, 86438},
	{"ARMENIANS", 9, 86439},
	{"MAKOTO", 6, 86440},
	{"ALLOC", 5, 86441},
	{"ULTRADEV", 8, 86442},
	{"VIAGGIO", 7, 86443},
	{"EXCELS", 6, 86444},
	{"SCIPY", 5, 86445},
	{"DEPOSITARY", 10, 86446},
	{"PCOD", 4, 86447},
	{"CYBY", 4, 86448},
	{"REDHILL", 7, 86449},
	{"CAVEMAN", 7, 86450},
	{"NUNEZ", 5, 86451},
	{"STARFIRE", 8, 86452},
	{"WHITLOCK", 8, 86453},
	{"PELLETIER", 9, 86454},
	{"FURTHEST", 8, 86455},
	{"VIRULENT", 8, 86456},
	{"WEUN", 4, 86457},
	{"PJOH", 4, 86458},
	{"GLYG", 4, 86459},
	{"LANARK", 6, 86460},
	{"YADA", 4, 86461},
	{"SANDRO", 6, 86462},
	{"MASTS", 5, 86463},
	{"GARRET", 6, 86464},
	{"JERVIS", 6, 86465},
	{"TUMU", 4, 86466},
	{"LACU", 4, 86467},
	{"PLACEMATS", 9, 86468},
	{"PATHOLOGIC", 10, 86469},
	{"COMMENDABLE", 11, 86470},
	{"RNAW", 4, 86471},
	{"LMCR", 4, 86472},
	{"DARDEN", 6, 86473},
	{"BUNNYTEENS", 10, 86474},
	{"INADEQUACY", 10, 86475},
	{"BARBARIC", 8, 86476},
	{"GORDO", 5, 86477},
	{"OTITIS", 6, 86478},
	{"ORDINATORS", 10, 86479},
	{"GOLS", 4, 86480},
	{"DELICIOUSLY", 11, 86481},
	{"LENINGRAD", 9, 86482},
	{"HARKIN", 6, 86483},
	{"RUSE", 4, 86484},
	{"PERSEPHONE", 10, 86485},
	{"EATERY", 6, 86486},
	{"PEONY", 5, 86487},
	{"CUEP", 4, 86488},
	{"ECONOMIA", 8, 86489},
	{"CYTOSOLIC", 9, 86490},
	{"GLYCERIN", 8, 86491},
	{"TAILINGS", 8, 86492},
	{"SHIRTLESS", 9, 86493},
	{"DARLA", 5, 86494},
	{"LIFELIKE", 8, 86495},
	{"RAYMAN", 6, 86496},
	{"WAFE", 4, 86497},
	{"RSSM", 4, 86498},
	{"KELV", 4, 86499},
	{"GEEM", 4, 86500},
	{"FTHW", 4, 86501},
	{"BOARDHOST", 9, 86502},
	{"FRONTERA", 8, 86503},
	{"CRUMPLER", 8, 86504},
	{"HARGREAVES", 10, 86505},
	{"CULLED", 6, 86506},
	{"MKPORTAL", 8, 86507},
	{"NUCLEON", 7, 86508},
	{"PKC", 3, 86509},
	{"YKIT", 4, 86510},
	{"GIEB", 4, 86511},
	{"DIMG", 4, 86512},
	{"DHAK", 4, 86513},
	{"MUSS", 4, 86514},
	{"PRESBYTERY", 10, 86515},
	{"TUMBLERS", 8, 86516},
	{"RAGN", 4, 86517},
	{"MTEX", 4, 86518},
	{"MICY", 4, 86519},
	{"EFEU", 4, 86520},
	{"DUOU", 4, 86521},
	{"HIDEOUT", 7, 86522},
	{"CALCITE", 7, 86523},
	{"FPU", 3, 86524},
	{"GUNSHOT", 7, 86525},
	{"DESIREE", 7, 86526},
	{"GUCH", 4, 86527},
	{"SUPPOSING", 9, 86528},
	{"SCULPTORS", 9, 86529},
	{"SPUD", 4, 86530},
	{"MANG", 4, 86531},
	{"CHARME", 6, 86532},
	{"NOLOGY", 6, 86533},
	{"PMWI", 4, 86534},
	{"PESD", 4, 86535},
	{"KYBE", 4, 86536},
	{"IFCH", 4, 86537},
	{"EEKY", 4, 86538},
	{"CURW", 4, 86539},
	{"CURF", 4, 86540},
	{"LUIZ", 4, 86541},
	{"CALICUT", 7, 86542},
	{"YYL", 3, 86543},
	{"UXQ", 3, 86544},
	{"RVZ", 3, 86545},
	{"RVX", 3, 86546},
	{"QLU", 3, 86547},
	{"QBZ", 3, 86548},
	{"BELDEN", 6, 86549},
	{"LENSE", 5, 86550},
	{"HENDRICK", 8, 86551},
	{"TUNB", 4, 86552},
	{"OWEF", 4, 86553},
	{"NRYB", 4, 86554},
	{"NCIB", 4, 86555},
	{"PUBLICATI", 9, 86556},
	{"UNVERIFIED", 10, 86557},
	{"YBYN", 4, 86558},
	{"RORU", 4, 86559},
	{"HOMB", 4, 86560},
	{"ESMD", 4, 86561},
	{"CEXA", 4, 86562},
	{"UNTAPPED", 8, 86563},
	{"VARIO", 5, 86564},
	{"PMSA", 4, 86565},
	{"RECENSIONI", 10, 86566},
	{"BATTY", 5, 86567},
	{"CASTILLA", 8, 86568},
	{"BRISCOE", 7, 86569},
	{"DWR", 3, 86570},
	{"ZEALOUS", 7, 86571},
	{"ULCE", 4, 86572},
	{"ELOQ", 4, 86573},
	{"CTEM", 4, 86574},
	{"FINGERNAILS", 11, 86575},
	{"OCARINA", 7, 86576},
	{"CAMUS", 5, 86577},
	{"MACKINAC", 8, 86578},
	{"HAHAHAHA", 8, 86579},
	{"FTLI", 4, 86580},
	{"ROMENESKO", 9, 86581},
	{"CROC", 4, 86582},
	{"RATTLESNAKE", 11, 86583},
	{"KEYSPAN", 7, 86584},
	{"IRIDESCENT", 10, 86585},
	{"REPOSTED", 8, 86586},
	{"UIAL", 4, 86587},
	{"IRSD", 4, 86588},
	{"GPLU", 4, 86589},
	{"MODULI", 6, 86590},
	{"PAYOFFS", 7, 86591},
	{"ROBBERIES", 9, 86592},
	{"YSKA", 4, 86593},
	{"RKJE", 4, 86594},
	{"KNAC", 4, 86595},
	{"MAYWOOD", 7, 86596},
	{"BUCHAN", 6, 86597},
	{"ROBERSON", 8, 86598},
	{"DEFROST", 7, 86599},
	{"COLERAINE", 9, 86600},
	{"ARIANNA", 7, 86601},
	{"UBPL", 4, 86602},
	{"OMSY", 4, 86603},
	{"BIOMARKERS", 10, 86604},
	{"CONSECUTIVELY", 13, 86605},
	{"ELMS", 4, 86606},
	{"EXCELLED", 8, 86607},
	{"BONGS", 5, 86608},
	{"LOOX", 4, 86609},
	{"IDRC", 4, 86610},
	{"PRETZELS", 8, 86611},
	{"ANMELDEN", 8, 86612},
	{"VDD", 3, 86613},
	{"WMAD", 4, 86614},
	{"IODC", 4, 86615},
	{"HMYG", 4, 86616},
	{"UNDERDEVELOPED", 14, 86617},
	{"TWINE", 5, 86618},
	{"MKTG", 4, 86619},
	{"YANCEY", 6, 86620},
	{"METEORS", 7, 86621},
	{"PERES", 5, 86622},
	{"ASSEMBLYMAN", 11, 86623},
	{"ENFORCER", 8, 86624},
	{"IDVA", 4, 86625},
	{"GUEV", 4, 86626},
	{"EDYH", 4, 86627},
	{"JUDICIOUS", 9, 86628},
	{"UNALTERED", 9, 86629},
	{"CUSTOMARILY", 11, 86630},
	{"COLLATION", 9, 86631},
	{"UMEX", 4, 86632},
	{"OGPO", 4, 86633},
	{"NPOC", 4, 86634},
	{"CILLIN", 6, 86635},
	{"BILITY", 6, 86636},
	{"GEIST", 5, 86637},
	{"MINGW", 5, 86638},
	{"SILVIO", 6, 86639},
	{"CENU", 4, 86640},
	{"SAREES", 6, 86641},
	{"PARKE", 5, 86642},
	{"DICTION", 7, 86643},
	{"UNOCCUPIED", 10, 86644},
	{"BLOOPERS", 8, 86645},
	{"FRAMEMAKER", 10, 86646},
	{"TIGRIS", 6, 86647},
	{"PISCATAWAY", 10, 86648},
	{"PEDESTALS", 9, 86649},
	{"CYTOSKELETON", 12, 86650},
	{"WUHAN", 5, 86651},
	{"MAXIMISING", 10, 86652},
	{"IEWL", 4, 86653},
	{"GIMO", 4, 86654},
	{"BCAL", 4, 86655},
	{"TRIBULATIONS", 12, 86656},
	{"HOISTS", 6, 86657},
	{"FICHIER", 7, 86658},
	{"COLMAN", 6, 86659},
	{"AMITRIPTYLINE", 13, 86660},
	{"MIRK", 4, 86661},
	{"LKSS", 4, 86662},
	{"SCRUBBER", 8, 86663},
	{"GRATUITES", 9, 86664},
	{"REENTRY", 7, 86665},
	{"PLAYTEX", 7, 86666},
	{"COMMUNI", 7, 86667},
	{"SABINA", 6, 86668},
	{"RAWD", 4, 86669},
	{"OGCO", 4, 86670},
	{"LVAC", 4, 86671},
	{"MEILLEURS", 9, 86672},
	{"BUISNESS", 8, 86673},
	{"FREEPICS", 8, 86674},
	{"KBIT", 4, 86675},
	{"MARMARIS", 8, 86676},
	{"LOGARITHM", 9, 86677},
	{"UTUL", 4, 86678},
	{"RDGI", 4, 86679},
	{"KSFE", 4, 86680},
	{"FFDA", 4, 86681},
	{"GRANOLA", 7, 86682},
	{"INEFFICIENCIES", 14, 86683},
	{"MONOCULAR", 9, 86684},
	{"KANKAKEE", 8, 86685},
	{"IRUL", 4, 86686},
	{"TANDY", 5, 86687},
	{"FERRITE", 7, 86688},
	{"FORMATO", 7, 86689},
	{"BUCKWHEAT", 9, 86690},
	{"ENSHRINED", 9, 86691},
	{"SURPASSES", 9, 86692},
	{"YEARLING", 8, 86693},
	{"DBUS", 4, 86694},
	{"URBY", 4, 86695},
	{"UDWA", 4, 86696},
	{"FUSD", 4, 86697},
	{"FSTP", 4, 86698},
	{"AUTORUN", 7, 86699},
	{"NIVEL", 5, 86700},
	{"AYATOLLAH", 9, 86701},
	{"AGAPE", 5, 86702},
	{"UNDIFFERENTIATED", 16, 86703},
	{"FLOWERSHOP", 10, 86704},
	{"WRENCHING", 9, 86705},
	{"LBOM", 4, 86706},
	{"DGOW", 4, 86707},
	{"VAZQUEZ", 7, 86708},
	{"DAMNATION", 9, 86709},
	{"REAFFIRM", 8, 86710},
	{"DYNIX", 5, 86711},
	{"PICTUR", 6, 86712},
	{"RAPIDITY", 8, 86713},
	{"BAJO", 4, 86714},
	{"TGAP", 4, 86715},
	{"LPAB", 4, 86716},
	{"COLLETTE", 8, 86717},
	{"TEMPUS", 6, 86718},
	{"DOXYCYCLINE", 11, 86719},
	{"SOMY", 4, 86720},
	{"SMOP", 4, 86721},
	{"IGTR", 4, 86722},
	{"DELETERIOUS", 11, 86723},
	{"SELP", 4, 86724},
	{"EECC", 4, 86725},
	{"DWRA", 4, 86726},
	{"WEBLOGGING", 10, 86727},
	{"CLUTTERED", 9, 86728},
	{"SPORTSMANSHIP", 13, 86729},
	{"RELIEVERS", 9, 86730},
	{"INTERSECTING", 12, 86731},
	{"VIKRAM", 6, 86732},
	{"USWR", 4, 86733},
	{"LYPT", 4, 86734},
	{"JABI", 4, 86735},
	{"BOOKTOPIA", 9, 86736},
	{"LAMPOON", 7, 86737},
	{"PTUP", 4, 86738},
	{"GARIBALDI", 9, 86739},
	{"AIRTIGHT", 8, 86740},
	{"FIRMING", 7, 86741},
	{"MRTG", 4, 86742},
	{"SHOREHAM", 8, 86743},
	{"ANNULAR", 7, 86744},
	{"XWER", 4, 86745},
	{"UNTV", 4, 86746},
	{"GOBJ", 4, 86747},
	{"DWAK", 4, 86748},
	{"DRIO", 4, 86749},
	{"ARTJ", 4, 86750},
	{"HALLMARKS", 9, 86751},
	{"SPARKING", 8, 86752},
	{"ANALE", 5, 86753},
	{"ALLUVIAL", 8, 86754},
	{"LANL", 4, 86755},
	{"XXV", 3, 86756},
	{"GFDL", 4, 86757},
	{"INCISIVE", 8, 86758},
	{"CONCEALING", 10, 86759},
	{"COMMANDLINE", 11, 86760},
	{"LFRU", 4, 86761},
	{"HAYL", 4, 86762},
	{"CRUL", 4, 86763},
	{"CLUTCHING", 9, 86764},
	{"USFWS", 5, 86765},
	{"ADIC", 4, 86766},
	{"PMD", 3, 86767},
	{"GHDR", 4, 86768},
	{"CETY", 4, 86769},
	{"DRIFTS", 6, 86770},
	{"RFD", 3, 86771},
	{"TENEMENT", 8, 86772},
	{"IZED", 4, 86773},
	{"GUARDIANFILMS", 13, 86774},
	{"GRYFFINDOR", 10, 86775},
	{"DISCERNMENT", 11, 86776},
	{"CHALICE", 7, 86777},
	{"BLOGSPOT", 8, 86778},
	{"XFIN", 4, 86779},
	{"SMYM", 4, 86780},
	{"HOFV", 4, 86781},
	{"HYPOCRITE", 9, 86782},
	{"OBSOLESCENCE", 12, 86783},
	{"LINGUISTS", 9, 86784},
	{"BLOGADS", 7, 86785},
	{"XINJIANG", 8, 86786},
	{"RECODE", 6, 86787},
	{"HARROWING", 9, 86788},
	{"YNED", 4, 86789},
	{"CKQU", 4, 86790},
	{"PREFECT", 7, 86791},
	{"HEINLEIN", 8, 86792},
	{"KIMBLE", 6, 86793},
	{"RESERVISTS", 10, 86794},
	{"SWEETLY", 7, 86795},
	{"BLAUPUNKT", 9, 86796},
	{"CLEAVE", 6, 86797},
	{"FLIMSY", 6, 86798},
	{"STATINS", 7, 86799},
	{"STRADA", 6, 86800},
	{"DESCENDANCY", 11, 86801},
	{"KIVE", 4, 86802},
	{"ELCU", 4, 86803},
	{"OBSOLETED", 9, 86804},
	{"PHIM", 4, 86805},
	{"BETACAM", 7, 86806},
	{"MLP", 3, 86807},
	{"REARRANGEMENT", 13, 86808},
	{"DISULFIDE", 9, 86809},
	{"MYER", 4, 86810},
	{"BYPASSED", 8, 86811},
	{"ONEFIT", 6, 86812},
	{"INTERP", 6, 86813},
	{"NEUTRALIZING", 12, 86814},
	{"TIRANA", 6, 86815},
	{"OCCUPIERS", 9, 86816},
	{"DELILAH", 7, 86817},
	{"KINGPIN", 7, 86818},
	{"RGOB", 4, 86819},
	{"IERK", 4, 86820},
	{"ICIR", 4, 86821},
	{"RELAYING", 8, 86822},
	{"WPJ", 3, 86823},
	{"QUQ", 3, 86824},
	{"GDZ", 3, 86825},
	{"BEDDED", 6, 86826},
	{"SHIVERING", 9, 86827},
	{"WALF", 4, 86828},
	{"MYAG", 4, 86829},
	{"FTYS", 4, 86830},
	{"EYAV", 4, 86831},
	{"AMILO", 5, 86832},
	{"OVERLORD", 8, 86833},
	{"DAFFODIL", 8, 86834},
	{"UKIAH", 5, 86835},
	{"DEVOTIONALS", 11, 86836},
	{"FIGUEROA", 8, 86837},
	{"FORMALITY", 9, 86838},
	{"LTBA", 4, 86839},
	{"LEDZ", 4, 86840},
	{"KITR", 4, 86841},
	{"PRODUIT", 7, 86842},
	{"WARENKORB", 9, 86843},
	{"HABIB", 5, 86844},
	{"ARCHIVOS", 8, 86845},
	{"LDGL", 4, 86846},
	{"HDIC", 4, 86847},
	{"MANGROVES", 9, 86848},
	{"LYMPHOCYTIC", 11, 86849},
	{"KALA", 4, 86850},
	{"SUFFICES", 8, 86851},
	{"BINGLEY", 7, 86852},
	{"WHOSOEVER", 9, 86853},
	{"COMTE", 5, 86854},
	{"DEERING", 7, 86855},
	{"TIGRE", 5, 86856},
	{"WUNT", 4, 86857},
	{"WNSR", 4, 86858},
	{"CHAM", 4, 86859},
	{"UNDETECTABLE", 12, 86860},
	{"INFACT", 6, 86861},
	{"GRACED", 6, 86862},
	{"VERMEIL", 7, 86863},
	{"ULTIMO", 6, 86864},
	{"YMAP", 4, 86865},
	{"TALJ", 4, 86866},
	{"MSUI", 4, 86867},
	{"SILAGE", 6, 86868},
	{"STATUARY", 8, 86869},
	{"EJACULATE", 9, 86870},
	{"SMITHERS", 8, 86871},
	{"GAEILGE", 7, 86872},
	{"GOUDY", 5, 86873},
	{"INKL", 4, 86874},
	{"BILGE", 5, 86875},
	{"TEXTO", 5, 86876},
	{"MORAINE", 7, 86877},
	{"PIDG", 4, 86878},
	{"MOCC", 4, 86879},
	{"LGUY", 4, 86880},
	{"DPAV", 4, 86881},
	{"PROLACTIN", 9, 86882},
	{"BEJEWELED", 9, 86883},
	{"MORAVIAN", 8, 86884},
	{"BASTROP", 7, 86885},
	{"SUNBELT", 7, 86886},
	{"INTERMITTENTLY", 14, 86887},
	{"GOWO", 4, 86888},
	{"DITJ", 4, 86889},
	{"CHEWY", 5, 86890},
	{"PAGINAS", 7, 86891},
	{"ARMAMENTS", 9, 86892},
	{"DECIMATION", 10, 86893},
	{"GRINS", 5, 86894},
	{"CHEWED", 6, 86895},
	{"HYPOTENSION", 11, 86896},
	{"STATEFUL", 8, 86897},
	{"PYPY", 4, 86898},
	{"BUSBY", 5, 86899},
	{"YETU", 4, 86900},
	{"SMYH", 4, 86901},
	{"LPSI", 4, 86902},
	{"ACCOMPLISHES", 12, 86903},
	{"GAITHER", 7, 86904},
	{"PATTERNING", 10, 86905},
	{"RDP", 3, 86906},
	{"SFOX", 4, 86907},
	{"LEGW", 4, 86908},
	{"DSGI", 4, 86909},
	{"INAPPLICABLE", 12, 86910},
	{"CHEEP", 5, 86911},
	{"HJEF", 4, 86912},
	{"LDR", 3, 86913},
	{"DENBIGHSHIRE", 12, 86914},
	{"WITTGENSTEIN", 12, 86915},
	{"PREEXISTING", 11, 86916},
	{"COFFEEMAKER", 11, 86917},
	{"BRAVEHEART", 10, 86918},
	{"WLAB", 4, 86919},
	{"RVAE", 4, 86920},
	{"OKDI", 4, 86921},
	{"NKAD", 4, 86922},
	{"KSCE", 4, 86923},
	{"CTOL", 4, 86924},
	{"AUFM", 4, 86925},
	{"BLY", 3, 86926},
	{"VISR", 4, 86927},
	{"RDUC", 4, 86928},
	{"LADH", 4, 86929},
	{"CIFE", 4, 86930},
	{"PBR", 3, 86931},
	{"GINSBURG", 8, 86932},
	{"SUPERCONDUCTIVITY", 17, 86933},
	{"EUROSTAT", 8, 86934},
	{"PASHA", 5, 86935},
	{"AMYGDALA", 8, 86936},
	{"CORRIE", 6, 86937},
	{"WEMB", 4, 86938},
	{"WBLA", 4, 86939},
	{"MSGA", 4, 86940},
	{"KYRE", 4, 86941},
	{"SCOUR", 5, 86942},
	{"LONESTAR", 8, 86943},
	{"MOTIONLESS", 10, 86944},
	{"DUELING", 7, 86945},
	{"NGTV", 4, 86946},
	{"LJUR", 4, 86947},
	{"FEXA", 4, 86948},
	{"NOTARIES", 8, 86949},
	{"CHALLENGERS", 11, 86950},
	{"GALANT", 6, 86951},
	{"FALLOW", 6, 86952},
	{"RESHAPE", 7, 86953},
	{"INDICTMENTS", 11, 86954},
	{"AILEEN", 6, 86955},
	{"PHOTOSET", 8, 86956},
	{"ELECTROLYTIC", 12, 86957},
	{"LEAPT", 5, 86958},
	{"TZPA", 4, 86959},
	{"TGOF", 4, 86960},
	{"HASEGAWA", 8, 86961},
	{"GAINERS", 7, 86962},
	{"CALIDAD", 7, 86963},
	{"PELO", 4, 86964},
	{"TINKERBELL", 10, 86965},
	{"HEUB", 4, 86966},
	{"FTOK", 4, 86967},
	{"ALDARA", 6, 86968},
	{"POWAY", 5, 86969},
	{"WIDOWER", 7, 86970},
	{"QUAGMIRE", 8, 86971},
	{"PHYSIOLOGIC", 11, 86972},
	{"OPTIMALITY", 10, 86973},
	{"RIYAL", 5, 86974},
	{"TAFFY", 5, 86975},
	{"PURGING", 7, 86976},
	{"YSIF", 4, 86977},
	{"SEYP", 4, 86978},
	{"NKBY", 4, 86979},
	{"IMDA", 4, 86980},
	{"AYIL", 4, 86981},
	{"CLEANSED", 8, 86982},
	{"DREMEL", 6, 86983},
	{"CEREBELLAR", 10, 86984},
	{"DANCIN", 6, 86985},
	{"SUMMARISES", 10, 86986},
	{"FAINTING", 8, 86987},
	{"XFRE", 4, 86988},
	{"BEOK", 4, 86989},
	{"THEORIST", 8, 86990},
	{"SCARING", 7, 86991},
	{"CHOY", 4, 86992},
	{"SERVICEABLE", 11, 86993},
	{"HEARTWARMING", 12, 86994},
	{"UNWIN", 5, 86995},
	{"OBSTRUCTED", 10, 86996},
	{"YPLO", 4, 86997},
	{"WCHE", 4, 86998},
	{"URNY", 4, 86999},
	{"PMAL", 4, 87000},
	{"INCC", 4, 87001},
	{"DRHO", 4, 87002},
	{"CHKO", 4, 87003},
	{"STRIDER", 7, 87004},
	{"INDIGESTION", 11, 87005},
	{"EASTLAKE", 8, 87006},
	{"MHAM", 4, 87007},
	{"KORC", 4, 87008},
	{"FLAH", 4, 87009},
	{"CBAG", 4, 87010},
	{"ABYG", 4, 87011},
	{"JACKAL", 6, 87012},
	{"CANNONBALL", 10, 87013},
	{"SNOWFLAKES", 10, 87014},
	{"MASSACRES", 9, 87015},
	{"UNEG", 4, 87016},
	{"DCOH", 4, 87017},
	{"AELV", 4, 87018},
	{"ENTAILED", 8, 87019},
	{"CURATIVE", 8, 87020},
	{"BIER", 4, 87021},
	{"TRAITORS", 8, 87022},
	{"IGNEOUS", 7, 87023},
	{"MATHCAD", 7, 87024},
	{"CAMBIO", 6, 87025},
	{"LULL", 4, 87026},
	{"SKIPTON", 7, 87027},
	{"PFOL", 4, 87028},
	{"OLTD", 4, 87029},
	{"FSAD", 4, 87030},
	{"AMSK", 4, 87031},
	{"PATENTLY", 8, 87032},
	{"RINSED", 6, 87033},
	{"DELECTABLE", 10, 87034},
	{"BITMAPS", 7, 87035},
	{"PROLETARIAT", 11, 87036},
	{"BIOPHARMACEUTICAL", 17, 87037},
	{"ANALYTICALLY", 12, 87038},
	{"YCOC", 4, 87039},
	{"WPAC", 4, 87040},
	{"OXBO", 4, 87041},
	{"NRUI", 4, 87042},
	{"ALYM", 4, 87043},
	{"ARAMAIC", 7, 87044},
	{"BOGGED", 6, 87045},
	{"INCREMENTED", 11, 87046},
	{"HOMEM", 5, 87047},
	{"VALOREM", 7, 87048},
	{"MYVE", 4, 87049},
	{"PUBLICIST", 9, 87050},
	{"FOXI", 4, 87051},
	{"MUZIK", 5, 87052},
	{"FANCIFUL", 8, 87053},
	{"TEMPERA", 7, 87054},
	{"RECYCLERS", 9, 87055},
	{"PILLSBURY", 9, 87056},
	{"SEACH", 5, 87057},
	{"INTERMEDIATION", 14, 87058},
	{"LACING", 6, 87059},
	{"RVON", 4, 87060},
	{"NJAZ", 4, 87061},
	{"GUYL", 4, 87062},
	{"FVIN", 4, 87063},
	{"AGGREGATING", 11, 87064},
	{"MYSTICS", 7, 87065},
	{"SOUNDBOARD", 10, 87066},
	{"TEAPOTS", 7, 87067},
	{"PDEP", 4, 87068},
	{"OGUL", 4, 87069},
	{"NGYI", 4, 87070},
	{"EORJ", 4, 87071},
	{"ARCHIVO", 7, 87072},
	{"SMARTDISK", 9, 87073},
	{"FRESHER", 7, 87074},
	{"KCLU", 4, 87075},
	{"GIAL", 4, 87076},
	{"CONSUMMATE", 10, 87077},
	{"TITRATION", 9, 87078},
	{"TSCHECHIEN", 10, 87079},
	{"BONEY", 5, 87080},
	{"TYSG", 4, 87081},
	{"RTSJ", 4, 87082},
	{"RCAV", 4, 87083},
	{"INYC", 4, 87084},
	{"BROWS", 5, 87085},
	{"OXIDOREDUCTASE", 14, 87086},
	{"LCM", 3, 87087},
	{"SKIMMER", 7, 87088},
	{"TECHNIC", 7, 87089},
	{"ONMD", 4, 87090},
	{"OKGR", 4, 87091},
	{"MCCULLAGH", 9, 87092},
	{"EXTRINSIC", 9, 87093},
	{"ERLBAUM", 7, 87094},
	{"UMGA", 4, 87095},
	{"NOFQ", 4, 87096},
	{"GUPC", 4, 87097},
	{"ECHK", 4, 87098},
	{"SKETCHY", 7, 87099},
	{"VEDA", 4, 87100},
	{"GOOSENECK", 9, 87101},
	{"TIFFIN", 6, 87102},
	{"EPHESUS", 7, 87103},
	{"PACER", 5, 87104},
	{"VRON", 4, 87105},
	{"NKFI", 4, 87106},
	{"HGAL", 4, 87107},
	{"DOMESTICATED", 12, 87108},
	{"BATTERSEA", 9, 87109},
	{"NONAME", 6, 87110},
	{"GUNG", 4, 87111},
	{"SASAKI", 6, 87112},
	{"OUTBOARDS", 9, 87113},
	{"DISMAYED", 8, 87114},
	{"PICF", 4, 87115},
	{"OPIU", 4, 87116},
	{"GODM", 4, 87117},
	{"AMDR", 4, 87118},
	{"XWW", 3, 87119},
	{"UQW", 3, 87120},
	{"RQV", 3, 87121},
	{"KKV", 3, 87122},
	{"OWINGS", 6, 87123},
	{"STEERED", 7, 87124},
	{"INTERLAKEN", 10, 87125},
	{"RTBI", 4, 87126},
	{"RRAV", 4, 87127},
	{"LHAB", 4, 87128},
	{"KRIE", 4, 87129},
	{"KAMPALA", 7, 87130},
	{"JCC", 3, 87131},
	{"TENTEC", 6, 87132},
	{"KILPATRICK", 10, 87133},
	{"PIXMAP", 6, 87134},
	{"BITTY", 5, 87135},
	{"REMITTED", 8, 87136},
	{"DTMF", 4, 87137},
	{"UNGY", 4, 87138},
	{"GSUG", 4, 87139},
	{"CDUR", 4, 87140},
	{"ALOD", 4, 87141},
	{"PROSSER", 7, 87142},
	{"MIRACULOUSLY", 12, 87143},
	{"LAPSES", 6, 87144},
	{"STETHOSCOPE", 11, 87145},
	{"MONOTONIC", 9, 87146},
	{"ROMAGNA", 7, 87147},
	{"FREEMASONRY", 11, 87148},
	{"EBOOKMALL", 9, 87149},
	{"DWELLS", 6, 87150},
	{"GUPD", 4, 87151},
	{"PEROT", 5, 87152},
	{"PENITENTIARY", 12, 87153},
	{"MEDIEN", 6, 87154},
	{"KAHUNA", 6, 87155},
	{"DJIN", 4, 87156},
	{"SHREWD", 6, 87157},
	{"WASHROOM", 8, 87158},
	{"JACOBY", 6, 87159},
	{"NEUROTRANSMITTER", 16, 87160},
	{"INTERCITY", 9, 87161},
	{"BROADVIEW", 9, 87162},
	{"MICROS", 6, 87163},
	{"STRAUS", 6, 87164},
	{"FLACK", 5, 87165},
	{"YKIS", 4, 87166},
	{"XRUN", 4, 87167},
	{"RDTU", 4, 87168},
	{"IUSD", 4, 87169},
	{"FTBL", 4, 87170},
	{"AMORTISATION", 12, 87171},
	{"PFU", 3, 87172},
	{"TONITE", 6, 87173},
	{"VONNEGUT", 8, 87174},
	{"DISTROS", 7, 87175},
	{"OUDM", 4, 87176},
	{"TEETHING", 8, 87177},
	{"SUBSECTOR", 9, 87178},
	{"IMPATIENCE", 10, 87179},
	{"ITALIE", 6, 87180},
	{"MECHANISTIC", 11, 87181},
	{"ORBIS", 5, 87182},
	{"FLAWLESSLY", 10, 87183},
	{"LIDAR", 5, 87184},
	{"OUWR", 4, 87185},
	{"FRP", 3, 87186},
	{"WHATNOT", 7, 87187},
	{"TRIPARTITE", 10, 87188},
	{"STUDEBAKER", 10, 87189},
	{"CRASS", 5, 87190},
	{"SPAULDING", 9, 87191},
	{"CARTOGRAPHIC", 12, 87192},
	{"RWD", 3, 87193},
	{"UAGR", 4, 87194},
	{"PRECONDITIONS", 13, 87195},
	{"GARDENIA", 8, 87196},
	{"ADLAND", 6, 87197},
	{"MIEMBRO", 7, 87198},
	{"IRLAND", 6, 87199},
	{"YJEF", 4, 87200},
	{"GOFK", 4, 87201},
	{"LINWOOD", 7, 87202},
	{"BIOTIC", 6, 87203},
	{"KOWALSKI", 8, 87204},
	{"MARYMOUNT", 9, 87205},
	{"BENEVOLENCE", 11, 87206},
	{"ZATHURA", 7, 87207},
	{"HIGHGATE", 8, 87208},
	{"LANCELOT", 8, 87209},
	{"FUDFORUM", 8, 87210},
	{"TAKESHI", 7, 87211},
	{"SUSPICIOUSLY", 12, 87212},
	{"EUGENIA", 7, 87213},
	{"RIWE", 4, 87214},
	{"LYYA", 4, 87215},
	{"EOXY", 4, 87216},
	{"EMDU", 4, 87217},
	{"DJAK", 4, 87218},
	{"WLAT", 4, 87219},
	{"VYHA", 4, 87220},
	{"RDII", 4, 87221},
	{"FAWH", 4, 87222},
	{"DOZA", 4, 87223},
	{"REPRIMAND", 9, 87224},
	{"MPD", 3, 87225},
	{"CROWDER", 7, 87226},
	{"MANGLED", 7, 87227},
	{"STAUNCH", 7, 87228},
	{"YSEG", 4, 87229},
	{"URAK", 4, 87230},
	{"CSLE", 4, 87231},
	{"SOCIALIZE", 9, 87232},
	{"SCUNTHORPE", 10, 87233},
	{"DEEPWATER", 9, 87234},
	{"SHAVEN", 6, 87235},
	{"CLICKBANK", 9, 87236},
	{"RULESET", 7, 87237},
	{"VISCOSE", 7, 87238},
	{"PERSO", 5, 87239},
	{"SOXW", 4, 87240},
	{"PIOU", 4, 87241},
	{"NBYU", 4, 87242},
	{"FWON", 4, 87243},
	{"DSFL", 4, 87244},
	{"NOVICA", 6, 87245},
	{"MANHUNT", 7, 87246},
	{"PAVERS", 6, 87247},
	{"ELKS", 4, 87248},
	{"AALBORG", 7, 87249},
	{"OCCUPIER", 8, 87250},
	{"LUNCHBOX", 8, 87251},
	{"FELD", 4, 87252},
	{"YLEY", 4, 87253},
	{"PDID", 4, 87254},
	{"EUCHRE", 6, 87255},
	{"MOLESTATION", 11, 87256},
	{"PROPORTA", 8, 87257},
	{"QUARTS", 6, 87258},
	{"MITOSIS", 7, 87259},
	{"PAYCHECKS", 9, 87260},
	{"YELLS", 5, 87261},
	{"BELLAIRE", 8, 87262},
	{"SUITCASES", 9, 87263},
	{"TMEB", 4, 87264},
	{"ILGE", 4, 87265},
	{"HEMJ", 4, 87266},
	{"EEMC", 4, 87267},
	{"POSTEL", 6, 87268},
	{"MDG", 3, 87269},
	{"TUTU", 4, 87270},
	{"PAISA", 5, 87271},
	{"PELW", 4, 87272},
	{"EAMJ", 4, 87273},
	{"SLIDELL", 7, 87274},
	{"VOCAB", 5, 87275},
	{"MMHG", 4, 87276},
	{"LACS", 4, 87277},
	{"BLINDFOLDED", 11, 87278},
	{"CLOCKING", 8, 87279},
	{"ZZAS", 4, 87280},
	{"LBAI", 4, 87281},
	{"CMUR", 4, 87282},
	{"BYAK", 4, 87283},
	{"HEMORRHAGIC", 11, 87284},
	{"PREMIERS", 8, 87285},
	{"PLEIN", 5, 87286},
	{"WRAITH", 6, 87287},
	{"RLSR", 4, 87288},
	{"NCOB", 4, 87289},
	{"HITCHENS", 8, 87290},
	{"CRORES", 6, 87291},
	{"CLASSIFIERS", 11, 87292},
	{"NOVOSIBIRSK", 11, 87293},
	{"GREENWALD", 9, 87294},
	{"NIMBLE", 6, 87295},
	{"COPACABANA", 10, 87296},
	{"VIDEORECORDING", 14, 87297},
	{"KICKSTART", 9, 87298},
	{"HYACINTH", 8, 87299},
	{"YONGE", 5, 87300},
	{"BIGGIE", 6, 87301},
	{"WCOV", 4, 87302},
	{"FFAD", 4, 87303},
	{"NEUTRALIZATION", 14, 87304},
	{"PVM", 3, 87305},
	{"DURST", 5, 87306},
	{"NATURALISTS", 11, 87307},
	{"DERELICT", 8, 87308},
	{"WSBY", 4, 87309},
	{"IPAG", 4, 87310},
	{"GJAP", 4, 87311},
	{"PDL", 3, 87312},
	{"PREPROCESSING", 13, 87313},
	{"PARTICULATES", 12, 87314},
	{"YLOY", 4, 87315},
	{"OLIP", 4, 87316},
	{"LEUC", 4, 87317},
	{"HEDK", 4, 87318},
	{"CRYF", 4, 87319},
	{"SKYLARK", 7, 87320},
	{"SHROUDED", 8, 87321},
	{"CLARISSA", 8, 87322},
	{"UNBL", 4, 87323},
	{"MBIR", 4, 87324},
	{"ABYO", 4, 87325},
	{"LLANDUDNO", 9, 87326},
	{"SQUIRRELMAIL", 12, 87327},
	{"OVIEDO", 6, 87328},
	{"BRAZEN", 6, 87329},
	{"INUNDATED", 9, 87330},
	{"GHSW", 4, 87331},
	{"CTYP", 4, 87332},
	{"PAULY", 5, 87333},
	{"BRAHMA", 6, 87334},
	{"BROMSGROVE", 10, 87335},
	{"STARSKY", 7, 87336},
	{"PRION", 5, 87337},
	{"SIMFREE", 7, 87338},
	{"PENNYWISE", 9, 87339},
	{"GRIER", 5, 87340},
	{"UDDA", 4, 87341},
	{"DIPHOSPHATE", 11, 87342},
	{"LBJ", 3, 87343},
	{"VERACITY", 8, 87344},
	{"INTERSCAN", 9, 87345},
	{"PIPERS", 6, 87346},
	{"TRONIC", 6, 87347},
	{"SURFSIDE", 8, 87348},
	{"TSUNAMIS", 8, 87349},
	{"DORDOGNE", 8, 87350},
	{"HOTLINKS", 8, 87351},
	{"NEELY", 5, 87352},
	{"FJON", 4, 87353},
	{"EFPE", 4, 87354},
	{"JERI", 4, 87355},
	{"PROTEASOME", 10, 87356},
	{"TRANSL", 6, 87357},
	{"GOULBURN", 8, 87358},
	{"PINOCCHIO", 9, 87359},
	{"VTKUSERS", 8, 87360},
	{"ENERGIZING", 10, 87361},
	{"BUTANE", 6, 87362},
	{"ANGERS", 6, 87363},
	{"HOQU", 4, 87364},
	{"GUSTAVUS", 8, 87365},
	{"BLUEBONNET", 10, 87366},
	{"INKED", 5, 87367},
	{"NOVATECH", 8, 87368},
	{"WAYV", 4, 87369},
	{"RRUB", 4, 87370},
	{"FMIK", 4, 87371},
	{"RAPS", 4, 87372},
	{"ELEKTRONIK", 10, 87373},
	{"UNWITTINGLY", 11, 87374},
	{"MATURITIES", 10, 87375},
	{"NAMESERVER", 10, 87376},
	{"TOMLIN", 6, 87377},
	{"JIGSAWS", 7, 87378},
	{"DISTORTING", 10, 87379},
	{"KAMIKAZE", 8, 87380},
	{"COUNSELS", 8, 87381},
	{"BATTLEFIELDS", 12, 87382},
	{"RDCI", 4, 87383},
	{"MARP", 4, 87384},
	{"QUAID", 5, 87385},
	{"JUGGERNAUT", 10, 87386},
	{"GORDONII", 8, 87387},
	{"ANTECEDENT", 10, 87388},
	{"OSKY", 4, 87389},
	{"KCHR", 4, 87390},
	{"FFLY", 4, 87391},
	{"LATROBE", 7, 87392},
	{"BBOARD", 6, 87393},
	{"CONSULTANCIES", 13, 87394},
	{"HANDLEY", 7, 87395},
	{"GRAMERCY", 8, 87396},
	{"KMUC", 4, 87397},
	{"ALFG", 4, 87398},
	{"CCB", 3, 87399},
	{"DERRIDA", 7, 87400},
	{"MATTY", 5, 87401},
	{"DOROTHEA", 8, 87402},
	{"MGB", 3, 87403},
	{"BIOAVAILABILITY", 15, 87404},
	{"UCAS", 4, 87405},
	{"XTYF", 4, 87406},
	{"WVIS", 4, 87407},
	{"TUPG", 4, 87408},
	{"NOCHEX", 6, 87409},
	{"LICHT", 5, 87410},
	{"LILITH", 6, 87411},
	{"FOREPLAY", 8, 87412},
	{"MCCAFFREY", 9, 87413},
	{"PRIVATIZED", 10, 87414},
	{"UNCOVERS", 8, 87415},
	{"GARGOYLE", 8, 87416},
	{"SKAC", 4, 87417},
	{"GUYC", 4, 87418},
	{"EOWL", 4, 87419},
	{"ASYG", 4, 87420},
	{"STOCKISTS", 9, 87421},
	{"OSTREAM", 7, 87422},
	{"LEGISLATE", 9, 87423},
	{"LENMAR", 6, 87424},
	{"VOLUPTUOUS", 10, 87425},
	{"SRAB", 4, 87426},
	{"PPYM", 4, 87427},
	{"NWEV", 4, 87428},
	{"LOBU", 4, 87429},
	{"DPEL", 4, 87430},
	{"MAMIYA", 6, 87431},
	{"COMPLACENT", 10, 87432},
	{"MILDURA", 7, 87433},
	{"BODEGA", 6, 87434},
	{"BXX", 3, 87435},
	{"HARDWORKING", 11, 87436},
	{"LPSS", 4, 87437},
	{"DOMM", 4, 87438},
	{"DOCKETS", 7, 87439},
	{"DEDHAM", 6, 87440},
	{"ERED", 4, 87441},
	{"STOMPING", 8, 87442},
	{"KOTTAYAM", 8, 87443},
	{"CARLE", 5, 87444},
	{"GERMANIA", 8, 87445},
	{"GRANDMOTHERS", 12, 87446},
	{"PONDICHERRY", 11, 87447},
	{"EPDI", 4, 87448},
	{"MPR", 3, 87449},
	{"FIDDLING", 8, 87450},
	{"PANAMANIAN", 10, 87451},
	{"BUYITNOW", 8, 87452},
	{"DALLA", 5, 87453},
	{"BUNGIE", 6, 87454},
	{"OBJET", 5, 87455},
	{"GOYA", 4, 87456},
	{"UNACCOMPANIED", 13, 87457},
	{"SUPERCLASS", 10, 87458},
	{"CATEGORIA", 9, 87459},
	{"LBIS", 4, 87460},
	{"BUYBACK", 7, 87461},
	{"SCHOOLED", 8, 87462},
	{"GIGOLO", 6, 87463},
	{"VANGELIS", 8, 87464},
	{"KINGWOOD", 8, 87465},
	{"DORLING", 7, 87466},
	{"NLOP", 4, 87467},
	{"AJUL", 4, 87468},
	{"MAXIMIZATION", 12, 87469},
	{"PICTS", 5, 87470},
	{"FORESTERS", 9, 87471},
	{"AHYB", 4, 87472},
	{"ABSENTEEISM", 11, 87473},
	{"GUERRE", 6, 87474},
	{"QUANTIFIABLE", 12, 87475},
	{"DORN", 4, 87476},
	{"SLIVER", 6, 87477},
	{"LEPTIN", 6, 87478},
	{"SXSW", 4, 87479},
	{"BUMMER", 6, 87480},
	{"ISOMETRIC", 9, 87481},
	{"RETRACTION", 10, 87482},
	{"ORINOCO", 7, 87483},
	{"AMBOY", 5, 87484},
	{"DUNNING", 7, 87485},
	{"GRINCH", 6, 87486},
	{"LOVELESS", 8, 87487},
	{"BUSL", 4, 87488},
	{"OKEECHOBEE", 10, 87489},
	{"SHOULDNT", 8, 87490},
	{"SHARPENED", 9, 87491},
	{"TEENIEFILES", 11, 87492},
	{"GCJ", 3, 87493},
	{"WHATCOM", 7, 87494},
	{"NOSTRILS", 8, 87495},
	{"CAMBRIAN", 8, 87496},
	{"OTWR", 4, 87497},
	{"KIWO", 4, 87498},
	{"IREK", 4, 87499},
	{"FROD", 4, 87500},
	{"CIAD", 4, 87501},
	{"ARZO", 4, 87502},
	{"ULEP", 4, 87503},
	{"TWAK", 4, 87504},
	{"HYDROCORTISONE", 14, 87505},
	{"CEREBROSPINAL", 13, 87506},
	{"IMPURE", 6, 87507},
	{"GRIDIRON", 8, 87508},
	{"WSAM", 4, 87509},
	{"REHY", 4, 87510},
	{"DYCR", 4, 87511},
	{"CHEG", 4, 87512},
	{"INNERMOST", 9, 87513},
	{"SUSANA", 6, 87514},
	{"RUMBA", 5, 87515},
	{"BOUCHARD", 8, 87516},
	{"YESTERYEAR", 10, 87517},
	{"ORTHOTICS", 9, 87518},
	{"WRY", 3, 87519},
	{"SPUNK", 5, 87520},
	{"PILATE", 6, 87521},
	{"ZEBR", 4, 87522},
	{"RIRR", 4, 87523},
	{"AWSF", 4, 87524},
	{"AKTR", 4, 87525},
	{"PINNING", 7, 87526},
	{"SUPERDRIVE", 10, 87527},
	{"JOLENE", 6, 87528},
	{"JALAPENO", 8, 87529},
	{"PROPELLANT", 10, 87530},
	{"TOUCHPAD", 8, 87531},
	{"RAISERS", 7, 87532},
	{"UEBR", 4, 87533},
	{"TTFR", 4, 87534},
	{"BSUP", 4, 87535},
	{"MDMA", 4, 87536},
	{"CONFOCAL", 8, 87537},
	{"JOCHEN", 6, 87538},
	{"CADDO", 5, 87539},
	{"DCL", 3, 87540},
	{"EXPATICA", 8, 87541},
	{"ALMS", 4, 87542},
	{"STUNG", 5, 87543},
	{"KOKO", 4, 87544},
	{"PHANTOMS", 8, 87545},
	{"BITSTREAM", 9, 87546},
	{"UIND", 4, 87547},
	{"RETORT", 6, 87548},
	{"BARTENDERS", 10, 87549},
	{"CONGREGATE", 10, 87550},
	{"MEDITATIVE", 10, 87551},
	{"REFILLING", 9, 87552},
	{"MODELL", 6, 87553},
	{"MACW", 4, 87554},
	{"LDSY", 4, 87555},
	{"ECKR", 4, 87556},
	{"KEIGHLEY", 8, 87557},
	{"RANGEFINDER", 11, 87558},
	{"NOSTDINC", 8, 87559},
	{"SMIRKING", 8, 87560},
	{"SBIB", 4, 87561},
	{"RLIP", 4, 87562},
	{"IRYF", 4, 87563},
	{"GBIN", 4, 87564},
	{"FPLE", 4, 87565},
	{"OFICIAL", 7, 87566},
	{"CHESTNUTS", 9, 87567},
	{"LANPARTY", 8, 87568},
	{"MONZA", 5, 87569},
	{"SPORTFISHING", 12, 87570},
	{"RLC", 3, 87571},
	{"EXACERBATE", 10, 87572},
	{"EXPOSITIONS", 11, 87573},
	{"BEGOTTEN", 8, 87574},
	{"RPTO", 4, 87575},
	{"IUSU", 4, 87576},
	{"FSUI", 4, 87577},
	{"EYAW", 4, 87578},
	{"AGFO", 4, 87579},
	{"BECKWITH", 8, 87580},
	{"ANEMONE", 7, 87581},
	{"EQUIVALENTLY", 12, 87582},
	{"DUXBURY", 7, 87583},
	{"CORDELE", 7, 87584},
	{"EBEL", 4, 87585},
	{"NINJAS", 6, 87586},
	{"OHUG", 4, 87587},
	{"MILLA", 5, 87588},
	{"INCASE", 6, 87589},
	{"GAINSBOROUGH", 12, 87590},
	{"SPARKLES", 8, 87591},
	{"RMPE", 4, 87592},
	{"KGOL", 4, 87593},
	{"KFEA", 4, 87594},
	{"HWEC", 4, 87595},
	{"GIEM", 4, 87596},
	{"COMERCIAL", 9, 87597},
	{"COLLARED", 8, 87598},
	{"SEGFAULT", 8, 87599},
	{"WISDEN", 6, 87600},
	{"MAINGATE", 8, 87601},
	{"COSTNER", 7, 87602},
	{"STRINGED", 8, 87603},
	{"OFAZ", 4, 87604},
	{"LREB", 4, 87605},
	{"KDEM", 4, 87606},
	{"EROZ", 4, 87607},
	{"POWERPUFF", 9, 87608},
	{"BARNABAS", 8, 87609},
	{"GSFC", 4, 87610},
	{"LYCOMING", 8, 87611},
	{"WEEDING", 7, 87612},
	{"REGULA", 6, 87613},
	{"LASTMINUTE", 10, 87614},
	{"WINBOOK", 7, 87615},
	{"TALLADEGA", 9, 87616},
	{"OPTIPLEX", 8, 87617},
	{"EVASIVE", 7, 87618},
	{"SYRUPS", 6, 87619},
	{"SMIRK", 5, 87620},
	{"CHILES", 6, 87621},
	{"PDOE", 4, 87622},
	{"LFCH", 4, 87623},
	{"ANCORA", 6, 87624},
	{"ESTIMATIONS", 11, 87625},
	{"PAUSING", 7, 87626},
	{"JAXX", 4, 87627},
	{"CERCLA", 6, 87628},
	{"ABSOLUTLY", 9, 87629},
	{"GUESSWORK", 9, 87630},
	{"FAID", 4, 87631},
	{"AELK", 4, 87632},
	{"GRANDS", 6, 87633},
	{"TRADESHOWS", 10, 87634},
	{"JAVASCRIPTS", 11, 87635},
	{"REPLETE", 7, 87636},
	{"UROZ", 4, 87637},
	{"GYSU", 4, 87638},
	{"FMIA", 4, 87639},
	{"ELHU", 4, 87640},
	{"ECKU", 4, 87641},
	{"IRRITANT", 8, 87642},
	{"WARCRY", 6, 87643},
	{"INCONCEIVABLE", 13, 87644},
	{"OPTURA", 6, 87645},
	{"COMBINATORICS", 13, 87646},
	{"GRACELAND", 9, 87647},
	{"ENCINO", 6, 87648},
	{"DISCONNECTS", 11, 87649},
	{"CASTELLO", 8, 87650},
	{"RMGO", 4, 87651},
	{"KYBU", 4, 87652},
	{"DWEP", 4, 87653},
	{"MONOLITH", 8, 87654},
	{"ANTWORTEN", 9, 87655},
	{"PCLI", 4, 87656},
	{"CRUTCHES", 8, 87657},
	{"INTRUSIONS", 10, 87658},
	{"GLORIES", 7, 87659},
	{"APPORTIONED", 11, 87660},
	{"PRELIMS", 7, 87661},
	{"KANAWHA", 7, 87662},
	{"PAWNEE", 6, 87663},
	{"YGLESIAS", 8, 87664},
	{"SQUIBB", 6, 87665},
	{"FAILINGS", 8, 87666},
	{"MEMSET", 6, 87667},
	{"EDIROL", 6, 87668},
	{"OBDE", 4, 87669},
	{"MPDE", 4, 87670},
	{"HEZU", 4, 87671},
	{"DLUK", 4, 87672},
	{"MANDALA", 7, 87673},
	{"BRISTLE", 7, 87674},
	{"CLASSE", 6, 87675},
	{"TERRORS", 7, 87676},
	{"PPHI", 4, 87677},
	{"KLEC", 4, 87678},
	{"JARV", 4, 87679},
	{"URIAH", 5, 87680},
	{"ALEXEY", 6, 87681},
	{"HOMECARE", 8, 87682},
	{"DUGAN", 5, 87683},
	{"OBLIGE", 6, 87684},
	{"BBCT", 4, 87685},
	{"CALMODULIN", 10, 87686},
	{"AMERITECH", 9, 87687},
	{"UMAR", 4, 87688},
	{"TIMEPIECES", 10, 87689},
	{"NONFARM", 7, 87690},
	{"ANKLET", 6, 87691},
	{"BYRNES", 6, 87692},
	{"XONM", 4, 87693},
	{"NJAK", 4, 87694},
	{"IPDO", 4, 87695},
	{"EORV", 4, 87696},
	{"DGAB", 4, 87697},
	{"BUSF", 4, 87698},
	{"VISITE", 6, 87699},
	{"DETERMINISM", 11, 87700},
	{"PANACEA", 7, 87701},
	{"VIBRATE", 7, 87702},
	{"ADDAMS", 6, 87703},
	{"PENETRATES", 10, 87704},
	{"ULYN", 4, 87705},
	{"OXRE", 4, 87706},
	{"OOBL", 4, 87707},
	{"IYOU", 4, 87708},
	{"MAYHEW", 6, 87709},
	{"MOELLER", 7, 87710},
	{"NORMALITY", 9, 87711},
	{"CATHEDRALS", 10, 87712},
	{"TOXF", 4, 87713},
	{"KYAS", 4, 87714},
	{"TOADS", 5, 87715},
	{"WIESBADEN", 9, 87716},
	{"DEFLECT", 7, 87717},
	{"TAOISM", 6, 87718},
	{"IKEDA", 5, 87719},
	{"LIBER", 5, 87720},
	{"YINQ", 4, 87721},
	{"NEYY", 4, 87722},
	{"IMAV", 4, 87723},
	{"DUEF", 4, 87724},
	{"PERCEIVES", 9, 87725},
	{"CHAKRAS", 7, 87726},
	{"SAMARA", 6, 87727},
	{"UNSUNG", 6, 87728},
	{"SMAB", 4, 87729},
	{"GARGOYLES", 9, 87730},
	{"MASSAGING", 9, 87731},
	{"AJMER", 5, 87732},
	{"YYF", 3, 87733},
	{"YVK", 3, 87734},
	{"XVX", 3, 87735},
	{"WXK", 3, 87736},
	{"FZG", 3, 87737},
	{"FQM", 3, 87738},
	{"DUEP", 4, 87739},
	{"LOSSY", 5, 87740},
	{"MITOGEN", 7, 87741},
	{"HURWITZ", 7, 87742},
	{"GULLIVER", 8, 87743},
	{"BUL", 3, 87744},
	{"NUBIAN", 6, 87745},
	{"AERODROME", 9, 87746},
	{"DARKSIDE", 8, 87747},
	{"INTENSIFICATION", 15, 87748},
	{"STUMPED", 7, 87749},
	{"RAYA", 4, 87750},
	{"RUGER", 5, 87751},
	{"NUNM", 4, 87752},
	{"GYPO", 4, 87753},
	{"FSWH", 4, 87754},
	{"GENNAIO", 7, 87755},
	{"CRAMP", 5, 87756},
	{"SEAFORD", 7, 87757},
	{"UNGARN", 6, 87758},
	{"UDSP", 4, 87759},
	{"NCTP", 4, 87760},
	{"GGSI", 4, 87761},
	{"CTOG", 4, 87762},
	{"VINCENZO", 8, 87763},
	{"WARSZAWA", 8, 87764},
	{"SODOM", 5, 87765},
	{"IMITATIONS", 10, 87766},
	{"DILLINGER", 9, 87767},
	{"BANDON", 6, 87768},
	{"ODELL", 5, 87769},
	{"FECY", 4, 87770},
	{"MISTLETOE", 9, 87771},
	{"RIDDIM", 6, 87772},
	{"PERFORATION", 11, 87773},
	{"CIDA", 4, 87774},
	{"ANNIKA", 6, 87775},
	{"UART", 4, 87776},
	{"TRYOUT", 6, 87777},
	{"UAMA", 4, 87778},
	{"OYCA", 4, 87779},
	{"DAIG", 4, 87780},
	{"CHSF", 4, 87781},
	{"PROXIMA", 7, 87782},
	{"LLADRO", 6, 87783},
	{"HALLOWED", 8, 87784},
	{"UZZY", 4, 87785},
	{"OLKC", 4, 87786},
	{"MRMO", 4, 87787},
	{"KFIS", 4, 87788},
	{"GHUG", 4, 87789},
	{"PARAMETERIZED", 13, 87790},
	{"MANAGEABILITY", 13, 87791},
	{"CRYSTALSPACE", 12, 87792},
	{"UBEE", 4, 87793},
	{"TEPC", 4, 87794},
	{"TDUM", 4, 87795},
	{"RAWC", 4, 87796},
	{"OMOW", 4, 87797},
	{"MSIX", 4, 87798},
	{"PANDAS", 6, 87799},
	{"CHOICESHIRTS", 12, 87800},
	{"SERVERTIME", 10, 87801},
	{"FMII", 4, 87802},
	{"NEPEAN", 6, 87803},
	{"TRACKLIST", 9, 87804},
	{"INDIO", 5, 87805},
	{"APPEASE", 7, 87806},
	{"BERNAL", 6, 87807},
	{"YRGY", 4, 87808},
	{"TNUC", 4, 87809},
	{"IXDI", 4, 87810},
	{"FWET", 4, 87811},
	{"HAWES", 5, 87812},
	{"FURLONG", 7, 87813},
	{"POLICYHOLDER", 12, 87814},
	{"DISTRIBUTIONAL", 14, 87815},
	{"TIDEWATER", 9, 87816},
	{"NGFL", 4, 87817},
	{"ERLANG", 6, 87818},
	{"STARZ", 5, 87819},
	{"FOLLICULAR", 10, 87820},
	{"GRUPOS", 6, 87821},
	{"DNEL", 4, 87822},
	{"GONORRHEA", 9, 87823},
	{"BLAQBOARD", 9, 87824},
	{"LISTERIA", 8, 87825},
	{"AFAIK", 5, 87826},
	{"DATATYPES", 9, 87827},
	{"HERALDED", 8, 87828},
	{"QYOU", 4, 87829},
	{"OPEG", 4, 87830},
	{"FLAVORFUL", 9, 87831},
	{"LINDE", 5, 87832},
	{"CLEAREST", 8, 87833},
	{"SUPERSEDE", 9, 87834},
	{"TPSY", 4, 87835},
	{"KDIR", 4, 87836},
	{"KAGR", 4, 87837},
	{"HEWP", 4, 87838},
	{"FYROM", 5, 87839},
	{"SHOVELS", 7, 87840},
	{"REFUNDING", 9, 87841},
	{"SUBCONTRACTS", 12, 87842},
	{"MOISSANITE", 10, 87843},
	{"FINCHLEY", 8, 87844},
	{"RENAUD", 6, 87845},
	{"MEDIATES", 8, 87846},
	{"PHRASING", 8, 87847},
	{"POLYACRYLAMIDE", 14, 87848},
	{"XTPL", 4, 87849},
	{"RCIB", 4, 87850},
	{"POPI", 4, 87851},
	{"OWCU", 4, 87852},
	{"KCRO", 4, 87853},
	{"BELB", 4, 87854},
	{"BIZZARE", 7, 87855},
	{"STANDISH", 8, 87856},
	{"CONUS", 5, 87857},
	{"COMPETENCES", 11, 87858},
	{"QUARRIES", 8, 87859},
	{"SENSIBLY", 8, 87860},
	{"JTAG", 4, 87861},
	{"COMPATABILITY", 13, 87862},
	{"MILLVILLE", 9, 87863},
	{"COCHES", 6, 87864},
	{"BIATHLON", 8, 87865},
	{"YHEG", 4, 87866},
	{"MICO", 4, 87867},
	{"MOUTHED", 7, 87868},
	{"MOXIE", 5, 87869},
	{"BIFF", 4, 87870},
	{"UZON", 4, 87871},
	{"SLUD", 4, 87872},
	{"NDUG", 4, 87873},
	{"EADK", 4, 87874},
	{"GILLS", 5, 87875},
	{"WNSV", 4, 87876},
	{"PAULETTE", 8, 87877},
	{"CHANIA", 6, 87878},
	{"BACKSPACE", 9, 87879},
	{"BRAIDS", 6, 87880},
	{"AWAYS", 5, 87881},
	{"WWED", 4, 87882},
	{"UNEU", 4, 87883},
	{"LACL", 4, 87884},
	{"GUSC", 4, 87885},
	{"FSKY", 4, 87886},
	{"FUGUE", 5, 87887},
	{"DISSONANCE", 10, 87888},
	{"MILDER", 6, 87889},
	{"MEDICATED", 9, 87890},
	{"INEXPLICABLE", 12, 87891},
	{"INITIO", 6, 87892},
	{"COUNTERFEITING", 14, 87893},
	{"BESTALITY", 9, 87894},
	{"WICA", 4, 87895},
	{"PHWA", 4, 87896},
	{"ILTD", 4, 87897},
	{"DSOY", 4, 87898},
	{"HYPOTHERMIA", 11, 87899},
	{"EXPEDITIOUS", 11, 87900},
	{"CARMAN", 6, 87901},
	{"WOPU", 4, 87902},
	{"KWOM", 4, 87903},
	{"TIMBERLINE", 10, 87904},
	{"DEFENSELINK", 11, 87905},
	{"SUNFIRE", 7, 87906},
	{"INTENTLY", 8, 87907},
	{"MCKEAN", 6, 87908},
	{"CHRYSALIS", 9, 87909},
	{"SMITHVILLE", 10, 87910},
	{"YSFL", 4, 87911},
	{"WLWI", 4, 87912},
	{"RSRS", 4, 87913},
	{"PAGR", 4, 87914},
	{"ELUP", 4, 87915},
	{"ELIJ", 4, 87916},
	{"EKOL", 4, 87917},
	{"COGR", 4, 87918},
	{"REBOOTING", 9, 87919},
	{"STORYTELLERS", 12, 87920},
	{"LAMISIL", 7, 87921},
	{"MORPHING", 8, 87922},
	{"CHUA", 4, 87923},
	{"SEVENOAKS", 9, 87924},
	{"HAPLOTYPES", 10, 87925},
	{"FISKARS", 7, 87926},
	{"YBYO", 4, 87927},
	{"UKED", 4, 87928},
	{"LEXD", 4, 87929},
	{"HEPD", 4, 87930},
	{"GZHO", 4, 87931},
	{"SPEER", 5, 87932},
	{"UPGE", 4, 87933},
	{"TKEV", 4, 87934},
	{"ROSD", 4, 87935},
	{"GODR", 4, 87936},
	{"EURC", 4, 87937},
	{"EPUD", 4, 87938},
	{"LATHES", 6, 87939},
	{"REFILLABLE", 10, 87940},
	{"YEARBOOKS", 9, 87941},
	{"LFEB", 4, 87942},
	{"HPHR", 4, 87943},
	{"RECHERCHER", 10, 87944},
	{"HOARY", 5, 87945},
	{"ENGIN", 5, 87946},
	{"KYUSHU", 6, 87947},
	{"TRICYCLE", 8, 87948},
	{"TDED", 4, 87949},
	{"NBRY", 4, 87950},
	{"IOUX", 4, 87951},
	{"FBUC", 4, 87952},
	{"ALSV", 4, 87953},
	{"PENNE", 5, 87954},
	{"CORSE", 5, 87955},
	{"AMPHETAMINES", 12, 87956},
	{"SYSTEMWORKS", 11, 87957},
	{"KEELE", 5, 87958},
	{"AFFICHER", 8, 87959},
	{"TRILLIUM", 8, 87960},
	{"BULFINCH", 8, 87961},
	{"USID", 4, 87962},
	{"MRCH", 4, 87963},
	{"TRANSIENTS", 10, 87964},
	{"CONCEDES", 8, 87965},
	{"OVEJ", 4, 87966},
	{"FFTR", 4, 87967},
	{"HOWARTH", 7, 87968},
	{"ANDANTE", 7, 87969},
	{"FARMINGDALE", 11, 87970},
	{"CROCODILES", 10, 87971},
	{"OVERTLY", 7, 87972},
	{"RONDE", 5, 87973},
	{"KAUT", 4, 87974},
	{"RATEITALL", 9, 87975},
	{"DECEIVING", 9, 87976},
	{"OEDIPUS", 7, 87977},
	{"TUBULIN", 7, 87978},
	{"BEAMED", 6, 87979},
	{"LTIB", 4, 87980},
	{"FKER", 4, 87981},
	{"ECKD", 4, 87982},
	{"ATLL", 4, 87983},
	{"GMX", 3, 87984},
	{"BANNISTER", 9, 87985},
	{"OMER", 4, 87986},
	{"HUMANOID", 8, 87987},
	{"CHAGRIN", 7, 87988},
	{"YGIA", 4, 87989},
	{"OUNF", 4, 87990},
	{"OMUT", 4, 87991},
	{"MMAA", 4, 87992},
	{"IEFG", 4, 87993},
	{"GOLY", 4, 87994},
	{"DOEX", 4, 87995},
	{"INFRINGEMENTS", 13, 87996},
	{"PYIS", 4, 87997},
	{"PTAP", 4, 87998},
	{"NBEK", 4, 87999},
	{"LKSC", 4, 88000},
	{"FOBJ", 4, 88001},
	{"STYLEBOX", 8, 88002},
	{"TIREDNESS", 9, 88003},
	{"BRANDEN", 7, 88004},
	{"PANNING", 7, 88005},
	{"WASABI", 6, 88006},
	{"MORECAMBE", 9, 88007},
	{"HAWKESBURY", 10, 88008},
	{"VILL", 4, 88009},
	{"KILOBYTES", 9, 88010},
	{"BREATHER", 8, 88011},
	{"UROM", 4, 88012},
	{"LMWO", 4, 88013},
	{"GENY", 4, 88014},
	{"ADJUDICATED", 11, 88015},
	{"RONV", 4, 88016},
	{"HYPA", 4, 88017},
	{"METHYLENE", 9, 88018},
	{"WHOLENESS", 9, 88019},
	{"GNUE", 4, 88020},
	{"GYNECOL", 7, 88021},
	{"NACOGDOCHES", 11, 88022},
	{"TVCH", 4, 88023},
	{"OGOP", 4, 88024},
	{"HLUC", 4, 88025},
	{"ABUF", 4, 88026},
	{"TICKLED", 7, 88027},
	{"HINDRANCE", 9, 88028},
	{"SIMCITY", 7, 88029},
	{"DISCREETLY", 10, 88030},
	{"HUMMINGBIRDS", 12, 88031},
	{"GARNIER", 7, 88032},
	{"CPPFLAGS", 8, 88033},
	{"RSUD", 4, 88034},
	{"POTR", 4, 88035},
	{"EDUCAUSE", 8, 88036},
	{"COTSWOLDS", 9, 88037},
	{"SPARING", 7, 88038},
	{"HEIFERS", 7, 88039},
	{"EMERALDS", 8, 88040},
	{"SEPHORA", 7, 88041},
	{"TREMBLAY", 8, 88042},
	{"XYQ", 3, 88043},
	{"XUG", 3, 88044},
	{"WUQ", 3, 88045},
	{"VBJ", 3, 88046},
	{"WANDERS", 7, 88047},
	{"DISILLUSIONED", 13, 88048},
	{"RNSY", 4, 88049},
	{"OOFD", 4, 88050},
	{"PREOCCUPATION", 13, 88051},
	{"GYNAECOLOGY", 11, 88052},
	{"VERTEBRATA", 10, 88053},
	{"BLACKCOMB", 9, 88054},
	{"FFXI", 4, 88055},
	{"OTTOMANS", 8, 88056},
	{"RODIN", 5, 88057},
	{"ECAC", 4, 88058},
	{"ACTU", 4, 88059},
	{"LOCKABLE", 8, 88060},
	{"DSLR", 4, 88061},
	{"VIPE", 4, 88062},
	{"UEAG", 4, 88063},
	{"NULA", 4, 88064},
	{"KYDI", 4, 88065},
	{"IAFL", 4, 88066},
	{"EVAPORATOR", 10, 88067},
	{"ANTIHISTAMINES", 14, 88068},
	{"UNINSTALLER", 11, 88069},
	{"AIRLINER", 8, 88070},
	{"UNUN", 4, 88071},
	{"JAGG", 4, 88072},
	{"BIBDATE", 7, 88073},
	{"UNWRAPPED", 9, 88074},
	{"DUMBASS", 7, 88075},
	{"BRC", 3, 88076},
	{"ARRHYTHMIAS", 11, 88077},
	{"OLCE", 4, 88078},
	{"MUMC", 4, 88079},
	{"NETWEAVER", 9, 88080},
	{"SATEEN", 6, 88081},
	{"MOTEUR", 6, 88082},
	{"FOTOPAGE", 8, 88083},
	{"BIRR", 4, 88084},
	{"AUTOSOMAL", 9, 88085},
	{"RESTFUL", 7, 88086},
	{"PROTEC", 6, 88087},
	{"IFFH", 4, 88088},
	{"PURIM", 5, 88089},
	{"RHODODENDRON", 12, 88090},
	{"CANADIENNE", 10, 88091},
	{"GATD", 4, 88092},
	{"ARISTOCRATIC", 12, 88093},
	{"SCOURING", 8, 88094},
	{"PROFITABLY", 10, 88095},
	{"PROFES", 6, 88096},
	{"PJM", 3, 88097},
	{"DDL", 3, 88098},
	{"TMYO", 4, 88099},
	{"TKER", 4, 88100},
	{"RDUM", 4, 88101},
	{"OAMB", 4, 88102},
	{"PINCHED", 7, 88103},
	{"UNDERLAY", 8, 88104},
	{"GRANULE", 7, 88105},
	{"PURPORT", 7, 88106},
	{"SETFONT", 7, 88107},
	{"SBYK", 4, 88108},
	{"RTID", 4, 88109},
	{"NKDI", 4, 88110},
	{"MFER", 4, 88111},
	{"PLUNGING", 8, 88112},
	{"COOKIN", 6, 88113},
	{"SHAMBLES", 8, 88114},
	{"GILLETT", 7, 88115},
	{"JUILLET", 7, 88116},
	{"ROCKLIN", 7, 88117},
	{"YEDV", 4, 88118},
	{"RMBO", 4, 88119},
	{"WELLAND", 7, 88120},
	{"MARTEN", 6, 88121},
	{"ADMITTANCE", 10, 88122},
	{"AGELESS", 7, 88123},
	{"NUERNBERG", 9, 88124},
	{"BLEEP", 5, 88125},
	{"ZEGO", 4, 88126},
	{"UYSD", 4, 88127},
	{"URIW", 4, 88128},
	{"SKCO", 4, 88129},
	{"RRYV", 4, 88130},
	{"RLIL", 4, 88131},
	{"LUIN", 4, 88132},
	{"KABR", 4, 88133},
	{"DOTU", 4, 88134},
	{"EMEDIA", 6, 88135},
	{"REGENSBURG", 10, 88136},
	{"GAMA", 4, 88137},
	{"XFREE", 5, 88138},
	{"SILLS", 5, 88139},
	{"STINKING", 8, 88140},
	{"BERWYN", 6, 88141},
	{"HOWLER", 6, 88142},
	{"HARDTOP", 7, 88143},
	{"KHME", 4, 88144},
	{"CARDED", 6, 88145},
	{"LIPO", 4, 88146},
	{"ZANDT", 5, 88147},
	{"RLOY", 4, 88148},
	{"PRUC", 4, 88149},
	{"REFORMATTED", 11, 88150},
	{"INTERNMENT", 10, 88151},
	{"PORRIDGE", 8, 88152},
	{"DOMINICK", 8, 88153},
	{"SYMBOLIZE", 9, 88154},
	{"MAHMOOD", 7, 88155},
	{"STANDSTILL", 10, 88156},
	{"PONU", 4, 88157},
	{"PHYM", 4, 88158},
	{"MDAT", 4, 88159},
	{"KMIC", 4, 88160},
	{"IGSW", 4, 88161},
	{"EPCL", 4, 88162},
	{"AVENT", 5, 88163},
	{"SWAYING", 7, 88164},
	{"IGLOO", 5, 88165},
	{"AMBLER", 6, 88166},
	{"UNATTRACTIVE", 12, 88167},
	{"BACHMAN", 7, 88168},
	{"REFERENTIAL", 11, 88169},
	{"HYDRATING", 9, 88170},
	{"ADAWARE", 7, 88171},
	{"DEWPT", 5, 88172},
	{"REPRESSOR", 9, 88173},
	{"GALEGO", 6, 88174},
	{"SMYL", 4, 88175},
	{"LRYB", 4, 88176},
	{"DIFFUSED", 8, 88177},
	{"NEILSON", 7, 88178},
	{"SCORECARDS", 10, 88179},
	{"FIRMER", 6, 88180},
	{"YVEL", 4, 88181},
	{"WOGE", 4, 88182},
	{"UMUN", 4, 88183},
	{"UDSE", 4, 88184},
	{"PELB", 4, 88185},
	{"FOAK", 4, 88186},
	{"ARYY", 4, 88187},
	{"NEWLINES", 8, 88188},
	{"REPRODUCES", 10, 88189},
	{"ARCANA", 6, 88190},
	{"TRANSWORLD", 10, 88191},
	{"URNG", 4, 88192},
	{"DISCOIDEUM", 10, 88193},
	{"WAIRARAPA", 9, 88194},
	{"FOGERTY", 7, 88195},
	{"HEIDEGGER", 9, 88196},
	{"BACKHOE", 7, 88197},
	{"SNFL", 4, 88198},
	{"NPEL", 4, 88199},
	{"LEFTISTS", 8, 88200},
	{"QUINNIPIAC", 10, 88201},
	{"PROMULGATION", 12, 88202},
	{"MANNEQUIN", 9, 88203},
	{"RKBL", 4, 88204},
	{"MALLOY", 6, 88205},
	{"ENVIROMENT", 10, 88206},
	{"MAKO", 4, 88207},
	{"UNSHAVEN", 8, 88208},
	{"OWCI", 4, 88209},
	{"KTER", 4, 88210},
	{"GETJ", 4, 88211},
	{"FLIQ", 4, 88212},
	{"NOYES", 5, 88213},
	{"EPROM", 5, 88214},
	{"RAKES", 5, 88215},
	{"TRASHED", 7, 88216},
	{"RYANAIR", 7, 88217},
	{"BETSEY", 6, 88218},
	{"LOBBIES", 7, 88219},
	{"SILVERTONE", 10, 88220},
	{"INCOGNITO", 9, 88221},
	{"CUPCAKES", 8, 88222},
	{"SILLINESS", 9, 88223},
	{"ARTEST", 6, 88224},
	{"BURGH", 5, 88225},
	{"GIGGLING", 8, 88226},
	{"NETFILTER", 9, 88227},
	{"COLDEST", 7, 88228},
	{"GALH", 4, 88229},
	{"PROVISO", 7, 88230},
	{"VOLDEMORT", 9, 88231},
	{"OLDENBURG", 9, 88232},
	{"BAZOOKA", 7, 88233},
	{"GERBERA", 7, 88234},
	{"QUANDO", 6, 88235},
	{"CIENT", 5, 88236},
	{"MITTAL", 6, 88237},
	{"BARNYARD", 8, 88238},
	{"DIKES", 5, 88239},
	{"VENTO", 5, 88240},
	{"UPYA", 4, 88241},
	{"RJAR", 4, 88242},
	{"PSBO", 4, 88243},
	{"CAMELLIA", 8, 88244},
	{"PRONOUNCEMENTS", 14, 88245},
	{"FONSECA", 7, 88246},
	{"RESCIND", 7, 88247},
	{"DONAL", 5, 88248},
	{"ARTIFICE", 8, 88249},
	{"ASHERON", 7, 88250},
	{"MANCE", 5, 88251},
	{"VIGGO", 5, 88252},
	{"HEPATOCELLULAR", 14, 88253},
	{"UMSY", 4, 88254},
	{"RMOH", 4, 88255},
	{"REGM", 4, 88256},
	{"ICTJ", 4, 88257},
	{"GOPS", 4, 88258},
	{"STYROFOAM", 9, 88259},
	{"MALFUNCTIONS", 12, 88260},
	{"LINDNER", 7, 88261},
	{"LINC", 4, 88262},
	{"GLIDES", 6, 88263},
	{"SALIDA", 6, 88264},
	{"YENF", 4, 88265},
	{"FTYY", 4, 88266},
	{"FASY", 4, 88267},
	{"CLYT", 4, 88268},
	{"DUNWOODY", 8, 88269},
	{"DIOXINS", 7, 88270},
	{"EPMI", 4, 88271},
	{"EXCAVATOR", 9, 88272},
	{"ALLOT", 5, 88273},
	{"ADOLESCENTE", 11, 88274},
	{"REDCAR", 6, 88275},
	{"YBYG", 4, 88276},
	{"GDIG", 4, 88277},
	{"GDAI", 4, 88278},
	{"FWEN", 4, 88279},
	{"DYIT", 4, 88280},
	{"WITTE", 5, 88281},
	{"PROGENITOR", 10, 88282},
	{"URAC", 4, 88283},
	{"ABOMINATION", 11, 88284},
	{"ONCOLINK", 8, 88285},
	{"CARTOONSTOCK", 12, 88286},
	{"WHYE", 4, 88287},
	{"TIML", 4, 88288},
	{"KEID", 4, 88289},
	{"EYOV", 4, 88290},
	{"EUEF", 4, 88291},
	{"BYKN", 4, 88292},
	{"BUNI", 4, 88293},
	{"ERSTE", 5, 88294},
	{"CWM", 3, 88295},
	{"BIBB", 4, 88296},
	{"GYMNAST", 7, 88297},
	{"INEXPENSIVELY", 13, 88298},
	{"ISYSTEM", 7, 88299},
	{"EVOL", 4, 88300},
	{"SPAV", 4, 88301},
	{"GYMI", 4, 88302},
	{"NMDA", 4, 88303},
	{"HAZEN", 5, 88304},
	{"DAVIDE", 6, 88305},
	{"FORCEPS", 7, 88306},
	{"CCW", 3, 88307},
	{"ARGUMENTATION", 13, 88308},
	{"PASSIVELY", 9, 88309},
	{"MAINFRAMES", 10, 88310},
	{"RLSP", 4, 88311},
	{"EKSU", 4, 88312},
	{"AMSY", 4, 88313},
	{"HURLED", 6, 88314},
	{"SAPULPA", 7, 88315},
	{"COSTAS", 6, 88316},
	{"SEARCY", 6, 88317},
	{"LABELLE", 7, 88318},
	{"ADJOINT", 7, 88319},
	{"YLLH", 4, 88320},
	{"YDRY", 4, 88321},
	{"SKIB", 4, 88322},
	{"ERPP", 4, 88323},
	{"MCLENNAN", 8, 88324},
	{"KILLA", 5, 88325},
	{"VESTA", 5, 88326},
	{"JACKY", 5, 88327},
	{"LIPSCOMB", 8, 88328},
	{"WOLD", 4, 88329},
	{"MONOCYTES", 9, 88330},
	{"REQUESTOR", 9, 88331},
	{"NRUM", 4, 88332},
	{"SPLINT", 6, 88333},
	{"STRAIGHTENED", 12, 88334},
	{"DIGITECH", 8, 88335},
	{"MRNAS", 5, 88336},
	{"LLAMAS", 6, 88337},
	{"MULTIFACETED", 12, 88338},
	{"YNDO", 4, 88339},
	{"RUMH", 4, 88340},
	{"FOXB", 4, 88341},
	{"AWMO", 4, 88342},
	{"GAMEZ", 5, 88343},
	{"DERANGED", 8, 88344},
	{"VOORHEES", 8, 88345},
	{"CONTESTING", 10, 88346},
	{"PUSB", 4, 88347},
	{"IGWH", 4, 88348},
	{"SOLVAY", 6, 88349},
	{"THORSTEN", 8, 88350},
	{"DARWINIAN", 9, 88351},
	{"YVJ", 3, 88352},
	{"XWB", 3, 88353},
	{"WYJ", 3, 88354},
	{"MVJ", 3, 88355},
	{"FJV", 3, 88356},
	{"IMRU", 4, 88357},
	{"FFDI", 4, 88358},
	{"TOUCHY", 6, 88359},
	{"RAFTERS", 7, 88360},
	{"TERK", 4, 88361},
	{"COOLMAX", 7, 88362},
	{"OKIM", 4, 88363},
	{"FSAB", 4, 88364},
	{"REBOOTED", 8, 88365},
	{"UNINTELLIGIBLE", 14, 88366},
	{"TOSKANA", 7, 88367},
	{"UNIDIFF", 7, 88368},
	{"WENC", 4, 88369},
	{"OUUP", 4, 88370},
	{"CMAK", 4, 88371},
	{"WHITWORTH", 9, 88372},
	{"RADIONUCLIDES", 13, 88373},
	{"TILBURG", 7, 88374},
	{"DECOYS", 6, 88375},
	{"IECL", 4, 88376},
	{"CFAD", 4, 88377},
	{"PARIAH", 6, 88378},
	{"OFFERORS", 8, 88379},
	{"HINTEN", 6, 88380},
	{"DARNELL", 7, 88381},
	{"MEATY", 5, 88382},
	{"GAGES", 5, 88383},
	{"ZAPATA", 6, 88384},
	{"SUPT", 4, 88385},
	{"XTHP", 4, 88386},
	{"RCYL", 4, 88387},
	{"LKWH", 4, 88388},
	{"INFANTILE", 9, 88389},
	{"BARTLEBY", 8, 88390},
	{"VERMEER", 7, 88391},
	{"XREC", 4, 88392},
	{"ROUL", 4, 88393},
	{"PINSTRIPE", 9, 88394},
	{"UNSPEAKABLE", 11, 88395},
	{"HEMODIALYSIS", 12, 88396},
	{"YSJA", 4, 88397},
	{"VONB", 4, 88398},
	{"PBEH", 4, 88399},
	{"EFOP", 4, 88400},
	{"DRER", 4, 88401},
	{"CDRE", 4, 88402},
	{"ARTIS", 5, 88403},
	{"DAILEY", 6, 88404},
	{"EGRET", 5, 88405},
	{"CORNHUSKERS", 11, 88406},
	{"DEMOLISH", 8, 88407},
	{"RLUS", 4, 88408},
	{"OPCL", 4, 88409},
	{"CKIM", 4, 88410},
	{"FONTCONFIG", 10, 88411},
	{"JORDANS", 7, 88412},
	{"GUILDHALL", 9, 88413},
	{"HASSELBLAD", 10, 88414},
	{"PINEY", 5, 88415},
	{"UNBUNDLED", 9, 88416},
	{"KUSASTRO", 8, 88417},
	{"ONCLICK", 7, 88418},
	{"FUNCTIONED", 10, 88419},
	{"COMFORTED", 9, 88420},
	{"DISGRACEFUL", 11, 88421},
	{"WORSHIPPERS", 11, 88422},
	{"HOUSEWARE", 9, 88423},
	{"KDEBASE", 7, 88424},
	{"YSGOL", 5, 88425},
	{"RRUG", 4, 88426},
	{"PTBE", 4, 88427},
	{"GRIGGS", 6, 88428},
	{"NICD", 4, 88429},
	{"MDP", 3, 88430},
	{"FULLMETAL", 9, 88431},
	{"PAPPAS", 6, 88432},
	{"ARANSAS", 7, 88433},
	{"TACACS", 6, 88434},
	{"MOVEM", 5, 88435},
	{"ABUNDANCES", 10, 88436},
	{"YLOT", 4, 88437},
	{"WREF", 4, 88438},
	{"SERVITUDE", 9, 88439},
	{"OULU", 4, 88440},
	{"FRACTIONATION", 13, 88441},
	{"AQUEDUCT", 8, 88442},
	{"CDB", 3, 88443},
	{"BLITZER", 7, 88444},
	{"RUC", 3, 88445},
	{"FRAMERS", 7, 88446},
	{"KARTE", 5, 88447},
	{"CASHFLOW", 8, 88448},
	{"RETOUCHING", 10, 88449},
	{"NDCT", 4, 88450},
	{"FCUB", 4, 88451},
	{"BRATTLEBORO", 11, 88452},
	{"STREAMERS", 9, 88453},
	{"EPROPS", 6, 88454},
	{"UBUD", 4, 88455},
	{"YSVO", 4, 88456},
	{"TKIR", 4, 88457},
	{"SLAL", 4, 88458},
	{"NBIB", 4, 88459},
	{"IGSL", 4, 88460},
	{"EAWR", 4, 88461},
	{"HUMBLED", 7, 88462},
	{"FMRI", 4, 88463},
	{"INFOSYS", 7, 88464},
	{"DISPLACEMENTS", 13, 88465},
	{"JEREZ", 5, 88466},
	{"MARCELLA", 8, 88467},
	{"RADIATE", 7, 88468},
	{"IELTS", 5, 88469},
	{"FELLAS", 6, 88470},
	{"PICTUREMATE", 11, 88471},
	{"OYOL", 4, 88472},
	{"OMGL", 4, 88473},
	{"DVEB", 4, 88474},
	{"UNICORNS", 8, 88475},
	{"PLAYROOM", 8, 88476},
	{"DANDRUFF", 8, 88477},
	{"STIPULATE", 9, 88478},
	{"ALBERS", 6, 88479},
	{"DISCWORLD", 9, 88480},
	{"LEAVED", 6, 88481},
	{"EXISTANCE", 9, 88482},
	{"PROXIMATE", 9, 88483},
	{"UNIONISTS", 9, 88484},
	{"BLOODLINES", 10, 88485},
	{"UNLU", 4, 88486},
	{"RGLI", 4, 88487},
	{"MONV", 4, 88488},
	{"GPOU", 4, 88489},
	{"EPUE", 4, 88490},
	{"FOLLETT", 7, 88491},
	{"SECRETIONS", 10, 88492},
	{"ATTAINS", 7, 88493},
	{"LAHB", 4, 88494},
	{"GALLUS", 6, 88495},
	{"IDEM", 4, 88496},
	{"RAMSAR", 6, 88497},
	{"WOODBURN", 8, 88498},
	{"LOCKERGNOME", 11, 88499},
	{"YPEB", 4, 88500},
	{"OOCYTES", 7, 88501},
	{"ARMADILLO", 9, 88502},
	{"UYSB", 4, 88503},
	{"MVIC", 4, 88504},
	{"LSJO", 4, 88505},
	{"CAPTIVA", 7, 88506},
	{"HARK", 4, 88507},
	{"RINEHART", 8, 88508},
	{"BROM", 4, 88509},
	{"YMRS", 4, 88510},
	{"NYSR", 4, 88511},
	{"GENSAT", 6, 88512},
	{"FILERS", 6, 88513},
	{"PERTURBED", 9, 88514},
	{"RETRIEVERS", 10, 88515},
	{"ULGR", 4, 88516},
	{"PACIFIER", 8, 88517},
	{"CEMENTED", 8, 88518},
	{"THURMOND", 8, 88519},
	{"STROUDSBURG", 11, 88520},
	{"DISSOLVES", 9, 88521},
	{"CROWNING", 8, 88522},
	{"DOMINIK", 7, 88523},
	{"VIVEK", 5, 88524},
	{"INMARSAT", 8, 88525},
	{"WLYS", 4, 88526},
	{"SULP", 4, 88527},
	{"MBHA", 4, 88528},
	{"EKYL", 4, 88529},
	{"UNPROFESSIONAL", 14, 88530},
	{"BETTINA", 7, 88531},
	{"HYDROGRAPHIC", 12, 88532},
	{"MCADAMS", 7, 88533},
	{"SMUGGLED", 8, 88534},
	{"WAILEA", 6, 88535},
	{"NFORCE", 6, 88536},
	{"SCONES", 6, 88537},
	{"PUNCTUATED", 10, 88538},
	{"PAEDIATRICS", 11, 88539},
	{"NZDT", 4, 88540},
	{"YRYA", 4, 88541},
	{"UEID", 4, 88542},
	{"RNBL", 4, 88543},
	{"CISW", 4, 88544},
	{"ILOG", 4, 88545},
	{"FINKELSTEIN", 11, 88546},
	{"BLUNDER", 7, 88547},
	{"CANDYLIST", 9, 88548},
	{"APPALACHIA", 10, 88549},
	{"MARIST", 6, 88550},
	{"MUSGRAVE", 8, 88551},
	{"VAKANTIE", 8, 88552},
	{"VLIN", 4, 88553},
	{"PKNO", 4, 88554},
	{"VARANASI", 8, 88555},
	{"EUSTON", 6, 88556},
	{"YUSHCHENKO", 10, 88557},
	{"RELATIVISM", 10, 88558},
	{"JARDINE", 7, 88559},
	{"SCHUYLKILL", 10, 88560},
	{"WFUN", 4, 88561},
	{"PFUR", 4, 88562},
	{"DZAC", 4, 88563},
	{"AZIP", 4, 88564},
	{"ERICSON", 7, 88565},
	{"ZUCKER", 6, 88566},
	{"SCHWEIZER", 9, 88567},
	{"STRAVINSKY", 10, 88568},
	{"BELTED", 6, 88569},
	{"KEDS", 4, 88570},
	{"ANANDA", 6, 88571},
	{"MYPH", 4, 88572},
	{"JUD", 3, 88573},
	{"TRIPWIRE", 8, 88574},
	{"REDISCOVERED", 12, 88575},
	{"RTSK", 4, 88576},
	{"RIDR", 4, 88577},
	{"RAWP", 4, 88578},
	{"MPME", 4, 88579},
	{"EIMG", 4, 88580},
	{"BRYC", 4, 88581},
	{"HEADSTONE", 9, 88582},
	{"DEPLETING", 9, 88583},
	{"MGON", 4, 88584},
	{"JUNKYARD", 8, 88585},
	{"BAAL", 4, 88586},
	{"PERMA", 5, 88587},
	{"COPTHORNE", 9, 88588},
	{"MULTITASKING", 12, 88589},
	{"FELON", 5, 88590},
	{"DISTRIB", 7, 88591},
	{"BYOB", 4, 88592},
	{"TUNSTALL", 8, 88593},
	{"TILG", 4, 88594},
	{"MRPA", 4, 88595},
	{"BOWH", 4, 88596},
	{"HAGER", 5, 88597},
	{"SPEARHEADED", 11, 88598},
	{"NACHO", 5, 88599},
	{"THUD", 4, 88600},
	{"UNDERLINING", 11, 88601},
	{"HAGAR", 5, 88602},
	{"JCR", 3, 88603},
	{"CATALOGUED", 10, 88604},
	{"RSHW", 4, 88605},
	{"ANTLERS", 7, 88606},
	{"RAWLINS", 7, 88607},
	{"SPRINGVILLE", 11, 88608},
	{"DOUBTING", 8, 88609},
	{"DIFFERENTIALLY", 14, 88610},
	{"PHCO", 4, 88611},
	{"KSIL", 4, 88612},
	{"GGST", 4, 88613},
	{"FBOM", 4, 88614},
	{"DRAH", 4, 88615},
	{"POWWOWS", 7, 88616},
	{"INDUCTOR", 8, 88617},
	{"CHALABI", 7, 88618},
	{"ENCEPHALOPATHY", 14, 88619},
	{"GROTE", 5, 88620},
	{"RAIPUR", 6, 88621},
	{"CUSTODIANS", 10, 88622},
	{"SRAV", 4, 88623},
	{"PISL", 4, 88624},
	{"OGFI", 4, 88625},
	{"OFFV", 4, 88626},
	{"NMRS", 4, 88627},
	{"ILBI", 4, 88628},
	{"DYSM", 4, 88629},
	{"DCAD", 4, 88630},
	{"CTQU", 4, 88631},
	{"GUARDIA", 7, 88632},
	{"KHALIL", 6, 88633},
	{"OVERSTATED", 10, 88634},
	{"DUNKIRK", 7, 88635},
	{"WEBTV", 5, 88636},
	{"INSULATORS", 10, 88637},
	{"LIBRETTO", 8, 88638},
	{"WEDS", 4, 88639},
	{"DEBATABLE", 9, 88640},
	{"SERVIZI", 7, 88641},
	{"WNTW", 4, 88642},
	{"GHJO", 4, 88643},
	{"EGAG", 4, 88644},
	{"CINM", 4, 88645},
	{"REAPING", 7, 88646},
	{"ABORIGINES", 10, 88647},
	{"QUICKLINK", 9, 88648},
	{"DUMBEST", 7, 88649},
	{"PROWLER", 7, 88650},
	{"LOADINGS", 8, 88651},
	{"SIZZLE", 6, 88652},
	{"OWVO", 4, 88653},
	{"ELCI", 4, 88654},
	{"DESALINATION", 12, 88655},
	{"COPOLYMER", 9, 88656},
	{"DUPLO", 5, 88657},
	{"LAWNMOWER", 9, 88658},
	{"YVED", 4, 88659},
	{"YPTS", 4, 88660},
	{"UWAL", 4, 88661},
	{"UANM", 4, 88662},
	{"KSSC", 4, 88663},
	{"FBOL", 4, 88664},
	{"NONTRADITIONAL", 14, 88665},
	{"GHAZIABAD", 9, 88666},
	{"ZPW", 3, 88667},
	{"ZDY", 3, 88668},
	{"ESTRANGED", 9, 88669},
	{"DREDGED", 7, 88670},
	{"MARCASITE", 9, 88671},
	{"KAMP", 4, 88672},
	{"MERTHYR", 7, 88673},
	{"FJIM", 4, 88674},
	{"SCOLIOSIS", 9, 88675},
	{"ARWEN", 5, 88676},
	{"WNSD", 4, 88677},
	{"UMNW", 4, 88678},
	{"TAYU", 4, 88679},
	{"ARTIE", 5, 88680},
	{"DECISIVELY", 10, 88681},
	{"HIUM", 4, 88682},
	{"FIFTHS", 6, 88683},
	{"AUSTELL", 7, 88684},
	{"FERNIE", 6, 88685},
	{"CARPORT", 7, 88686},
	{"DUBBING", 7, 88687},
	{"WLIS", 4, 88688},
	{"UTLY", 4, 88689},
	{"FKAT", 4, 88690},
	{"CHYS", 4, 88691},
	{"WEBLIST", 7, 88692},
	{"MAXIMO", 6, 88693},
	{"SEARLS", 6, 88694},
	{"SCUK", 4, 88695},
	{"UIUC", 4, 88696},
	{"CRUSTACEANS", 11, 88697},
	{"YORKVILLE", 9, 88698},
	{"WAYBACK", 7, 88699},
	{"GCG", 3, 88700},
	{"URAL", 4, 88701},
	{"CALIBUR", 7, 88702},
	{"NELV", 4, 88703},
	{"LTOJ", 4, 88704},
	{"GIRONA", 6, 88705},
	{"SWIMS", 5, 88706},
	{"PERK", 4, 88707},
	{"UNDENIABLY", 10, 88708},
	{"ZANDER", 6, 88709},
	{"SPASM", 5, 88710},
	{"REKO", 4, 88711},
	{"LMAB", 4, 88712},
	{"EUCO", 4, 88713},
	{"SAMIR", 5, 88714},
	{"FREEE", 5, 88715},
	{"NOTABLES", 8, 88716},
	{"EMINENTLY", 9, 88717},
	{"PSGO", 4, 88718},
	{"HPAG", 4, 88719},
	{"SNORTING", 8, 88720},
	{"DEVELOPEMENT", 12, 88721},
	{"PPTP", 4, 88722},
	{"BEAC", 4, 88723},
	{"MERCILESSLY", 11, 88724},
	{"URBANIZED", 9, 88725},
	{"WNUS", 4, 88726},
	{"OKTW", 4, 88727},
	{"TRENTINO", 8, 88728},
	{"MARZO", 5, 88729},
	{"DFL", 3, 88730},
	{"JIRI", 4, 88731},
	{"MCCOLLUM", 8, 88732},
	{"AFFYMETRIX", 10, 88733},
	{"BEVAN", 5, 88734},
	{"ICHIRO", 6, 88735},
	{"UNSR", 4, 88736},
	{"PPYE", 4, 88737},
	{"MHIL", 4, 88738},
	{"MDUE", 4, 88739},
	{"EALK", 4, 88740},
	{"COFE", 4, 88741},
	{"LOYALIST", 8, 88742},
	{"VERMA", 5, 88743},
	{"DAYBED", 6, 88744},
	{"RIMES", 5, 88745},
	{"KTRO", 4, 88746},
	{"KMER", 4, 88747},
	{"BUIC", 4, 88748},
	{"QUIMBY", 6, 88749},
	{"BARONE", 6, 88750},
	{"THOMASNET", 9, 88751},
	{"FIRS", 4, 88752},
	{"KOELN", 5, 88753},
	{"ENDOCRINOL", 10, 88754},
	{"EVAPORATIVE", 11, 88755},
	{"VYCA", 4, 88756},
	{"OOPL", 4, 88757},
	{"GWYBODAETH", 10, 88758},
	{"PRESHRUNK", 9, 88759},
	{"HEZBOLLAH", 9, 88760},
	{"MMU", 3, 88761},
	{"FEBRUAR", 7, 88762},
	{"FINALIZING", 10, 88763},
	{"RPIA", 4, 88764},
	{"NDAZ", 4, 88765},
	{"LLAE", 4, 88766},
	{"APBU", 4, 88767},
	{"COBBLER", 7, 88768},
	{"PRINTHEAD", 9, 88769},
	{"BLANTON", 7, 88770},
	{"ZELLWEGER", 9, 88771},
	{"YMCG", 4, 88772},
	{"EUMN", 4, 88773},
	{"ARLD", 4, 88774},
	{"INVIGORATING", 12, 88775},
	{"HEINOUS", 7, 88776},
	{"DUSKY", 5, 88777},
	{"KULTUR", 6, 88778},
	{"MANHOLE", 7, 88779},
	{"LINNAEUS", 8, 88780},
	{"GNUT", 4, 88781},
	{"ERODING", 7, 88782},
	{"EMAP", 4, 88783},
	{"SEARCHGALS", 10, 88784},
	{"TYPEWRITERS", 11, 88785},
	{"TABASCO", 7, 88786},
	{"CPB", 3, 88787},
	{"COFFMAN", 7, 88788},
	{"RRYU", 4, 88789},
	{"RDHU", 4, 88790},
	{"RHODESIA", 8, 88791},
	{"HALPERN", 7, 88792},
	{"PUREBRED", 8, 88793},
	{"NETAPP", 6, 88794},
	{"MASOCHISM", 9, 88795},
	{"MILLINGTON", 10, 88796},
	{"BERGAMOT", 8, 88797},
	{"OMKO", 4, 88798},
	{"GBUC", 4, 88799},
	{"INFALLIBLE", 10, 88800},
	{"SHUTOUT", 7, 88801},
	{"WILLSON", 7, 88802},
	{"LOAVES", 6, 88803},
	{"CHOWN", 5, 88804},
	{"PROSTHETICS", 11, 88805},
	{"PROMS", 5, 88806},
	{"KAROL", 5, 88807},
	{"DIEU", 4, 88808},
	{"UNDERLINES", 10, 88809},
	{"HEELED", 6, 88810},
	{"USJA", 4, 88811},
	{"ROSK", 4, 88812},
	{"OWOB", 4, 88813},
	{"IOBU", 4, 88814},
	{"HPIL", 4, 88815},
	{"QUIBBLE", 7, 88816},
	{"MEANDERING", 10, 88817},
	{"BAKELITE", 8, 88818},
	{"KIRKBY", 6, 88819},
	{"INTERMOUNTAIN", 13, 88820},
	{"UBSU", 4, 88821},
	{"OFOM", 4, 88822},
	{"HOLTZ", 5, 88823},
	{"PRENSA", 6, 88824},
	{"INCESSANT", 9, 88825},
	{"VEGF", 4, 88826},
	{"YHAY", 4, 88827},
	{"KLONDIKE", 8, 88828},
	{"BAINES", 6, 88829},
	{"WEBSTAT", 7, 88830},
	{"BLICK", 5, 88831},
	{"REEDER", 6, 88832},
	{"NAMEN", 5, 88833},
	{"NEOPLASTIC", 10, 88834},
	{"APPLESAUCE", 10, 88835},
	{"FIBREGLASS", 10, 88836},
	{"SKAD", 4, 88837},
	{"NFKE", 4, 88838},
	{"IRLB", 4, 88839},
	{"ANMR", 4, 88840},
	{"KENJI", 5, 88841},
	{"CHEERY", 6, 88842},
	{"GLUON", 5, 88843},
	{"CURBING", 7, 88844},
	{"HARSHLY", 7, 88845},
	{"BETTERMENT", 10, 88846},
	{"FEISTY", 6, 88847},
	{"HYNES", 5, 88848},
	{"PISF", 4, 88849},
	{"NCYG", 4, 88850},
	{"IKAB", 4, 88851},
	{"EMOW", 4, 88852},
	{"RUMP", 4, 88853},
	{"CLOGGING", 8, 88854},
	{"SWEETHEARTS", 11, 88855},
	{"NONVERBAL", 9, 88856},
	{"RHOF", 4, 88857},
	{"OULF", 4, 88858},
	{"KBAI", 4, 88859},
	{"ETOILE", 6, 88860},
	{"ORANGEBURG", 10, 88861},
	{"LADYBIRD", 8, 88862},
	{"CONCAT", 6, 88863},
	{"MILLIKEN", 8, 88864},
	{"SLUSH", 5, 88865},
	{"BYPRODUCT", 9, 88866},
	{"SPECIALIZATIONS", 15, 88867},
	{"CHAINTECH", 9, 88868},
	{"MUTTON", 6, 88869},
	{"MUDI", 4, 88870},
	{"CTUP", 4, 88871},
	{"PORTERVILLE", 11, 88872},
	{"KBYTE", 5, 88873},
	{"BIZWIZ", 6, 88874},
	{"CONGRUENT", 9, 88875},
	{"BOEHM", 5, 88876},
	{"BLINKED", 7, 88877},
	{"SELVA", 5, 88878},
	{"RAINEY", 6, 88879},
	{"JOBR", 4, 88880},
	{"ALTRI", 5, 88881},
	{"APHIS", 5, 88882},
	{"TARANTULA", 9, 88883},
	{"LENORE", 6, 88884},
	{"EGOVERNMENT", 11, 88885},
	{"UDF", 3, 88886},
	{"SNUGGLE", 7, 88887},
	{"TOWNSHEND", 9, 88888},
	{"ZIGZAG", 6, 88889},
	{"OWKI", 4, 88890},
	{"NELG", 4, 88891},
	{"CYAC", 4, 88892},
	{"APAM", 4, 88893},
	{"SHANG", 5, 88894},
	{"BATTEN", 6, 88895},
	{"LESEN", 5, 88896},
	{"UNPE", 4, 88897},
	{"AMCE", 4, 88898},
	{"LOUGH", 5, 88899},
	{"VIGRX", 5, 88900},
	{"TRIOS", 5, 88901},
	{"UNALLOCATED", 11, 88902},
	{"YVII", 4, 88903},
	{"CONDICIONES", 11, 88904},
	{"DRAGOON", 7, 88905},
	{"MODI", 4, 88906},
	{"SYMPATHIES", 10, 88907},
	{"LEGGINGS", 8, 88908},
	{"BENEFACTOR", 10, 88909},
	{"COMPONENTARTSCSTAMP", 19, 88910},
	{"DYK", 3, 88911},
	{"YPTE", 4, 88912},
	{"RKFE", 4, 88913},
	{"IPDI", 4, 88914},
	{"THALES", 6, 88915},
	{"MALDON", 6, 88916},
	{"NACHT", 5, 88917},
	{"MERRILY", 7, 88918},
	{"XANTREX", 7, 88919},
	{"DLG", 3, 88920},
	{"VOUCH", 5, 88921},
	{"KARZAI", 6, 88922},
	{"BROCKPORT", 9, 88923},
	{"CORT", 4, 88924},
	{"POMPEY", 6, 88925},
	{"BLACKNESS", 9, 88926},
	{"SOFTGELS", 8, 88927},
	{"ENGRAVERS", 9, 88928},
	{"TRANSITORY", 10, 88929},
	{"WETHER", 6, 88930},
	{"MUKH", 4, 88931},
	{"LDJE", 4, 88932},
	{"GENJ", 4, 88933},
	{"AZEM", 4, 88934},
	{"HANGIN", 6, 88935},
	{"HANDICAPS", 9, 88936},
	{"GALES", 5, 88937},
	{"ASSOCIAZIONE", 12, 88938},
	{"HYPOCRITES", 10, 88939},
	{"LARYNX", 6, 88940},
	{"DOHC", 4, 88941},
	{"CLU", 3, 88942},
	{"CAPPS", 5, 88943},
	{"VIJAYAWADA", 10, 88944},
	{"GRIFFON", 7, 88945},
	{"BIOLOGICS", 9, 88946},
	{"SBYV", 4, 88947},
	{"MEEQ", 4, 88948},
	{"BBYH", 4, 88949},
	{"BLUESCRIPT", 10, 88950},
	{"INSTANTIATE", 11, 88951},
	{"PAPERWEIGHT", 11, 88952},
	{"DILATION", 8, 88953},
	{"IZZY", 4, 88954},
	{"DROUGHTS", 8, 88955},
	{"BEDSPREAD", 9, 88956},
	{"KVJ", 3, 88957},
	{"JCY", 3, 88958},
	{"KNUDSEN", 7, 88959},
	{"JABBERWACKY", 11, 88960},
	{"NFAB", 4, 88961},
	{"DUSF", 4, 88962},
	{"KIOWA", 5, 88963},
	{"OVERTONES", 9, 88964},
	{"ANCONA", 6, 88965},
	{"FAITHFULL", 9, 88966},
	{"QUEZON", 6, 88967},
	{"PRAGMATISM", 10, 88968},
	{"PIQU", 4, 88969},
	{"OUVI", 4, 88970},
	{"AFAU", 4, 88971},
	{"SPRINGING", 9, 88972},
	{"BETHUNE", 7, 88973},
	{"WIRETAPPING", 11, 88974},
	{"NOCTURNE", 8, 88975},
	{"LTYH", 4, 88976},
	{"GRYW", 4, 88977},
	{"FABRICATE", 9, 88978},
	{"EXABYTE", 7, 88979},
	{"PITTY", 5, 88980},
	{"PERDUE", 6, 88981},
	{"KCL", 3, 88982},
	{"RELB", 4, 88983},
	{"PBOT", 4, 88984},
	{"METP", 4, 88985},
	{"ECPU", 4, 88986},
	{"COOF", 4, 88987},
	{"CANQ", 4, 88988},
	{"PENDRAGON", 9, 88989},
	{"ALTRUISM", 8, 88990},
	{"OPMENT", 6, 88991},
	{"CEASING", 7, 88992},
	{"MEEKER", 6, 88993},
	{"BOOTLEGS", 8, 88994},
	{"RKOS", 4, 88995},
	{"NTYV", 4, 88996},
	{"ENGW", 4, 88997},
	{"JIMBO", 5, 88998},
	{"JARROW", 6, 88999},
	{"MULLIN", 6, 89000},
	{"DUTCHMAN", 8, 89001},
	{"CAPRICIOUS", 10, 89002},
	{"GRIDSPHERE", 10, 89003},
	{"ACTIVESYNC", 10, 89004},
	{"MACWAREHOUSE", 12, 89005},
	{"ANGELIQUE", 9, 89006},
	{"SGYM", 4, 89007},
	{"NJUG", 4, 89008},
	{"IFOB", 4, 89009},
	{"HARMONIZE", 9, 89010},
	{"VELA", 4, 89011},
	{"WIKIUSERNAME", 12, 89012},
	{"CRESCENDO", 9, 89013},
	{"HESSEN", 6, 89014},
	{"EYELASH", 7, 89015},
	{"GSVI", 4, 89016},
	{"AXFO", 4, 89017},
	{"ANTIFREEZE", 10, 89018},
	{"BEAMER", 6, 89019},
	{"FEEDBLITZ", 9, 89020},
	{"HARVICK", 7, 89021},
	{"CLICKER", 7, 89022},
	{"IMMOBILIZED", 11, 89023},
	{"UCTH", 4, 89024},
	{"OLNW", 4, 89025},
	{"NEYU", 4, 89026},
	{"LPIS", 4, 89027},
	{"DGOU", 4, 89028},
	{"BYGL", 4, 89029},
	{"DALMATIAN", 9, 89030},
	{"HEMODYNAMIC", 11, 89031},
	{"GIPSY", 5, 89032},
	{"RESHAPING", 9, 89033},
	{"FREDERIK", 8, 89034},
	{"CONTESSA", 8, 89035},
	{"WISF", 4, 89036},
	{"PHWI", 4, 89037},
	{"IGNY", 4, 89038},
	{"STAGECOACH", 10, 89039},
	{"GOOGLING", 8, 89040},
	{"MAXPREPS", 8, 89041},
	{"JESSUP", 6, 89042},
	{"FAISAL", 6, 89043},
	{"JOLS", 4, 89044},
	{"IRKY", 4, 89045},
	{"RUDDY", 5, 89046},
	{"MISERABLES", 10, 89047},
	{"MAGAZZINO", 9, 89048},
	{"JIPPII", 6, 89049},
	{"ACADEME", 7, 89050},
	{"FJORD", 5, 89051},
	{"AMALGAMATED", 11, 89052},
	{"FLYBASE", 7, 89053},
	{"ALPENA", 6, 89054},
	{"EWAW", 4, 89055},
	{"JUNEBUG", 7, 89056},
	{"OBEYING", 7, 89057},
	{"GUNNERS", 7, 89058},
	{"GRISSOM", 7, 89059},
	{"SHIKI", 5, 89060},
	{"KNOCKOFF", 8, 89061},
	{"KOMMENTAR", 9, 89062},
	{"WESTPAC", 7, 89063},
	{"GOSLING", 7, 89064},
	{"GAVO", 4, 89065},
	{"NOVOSTI", 7, 89066},
	{"MENDEL", 6, 89067},
	{"ADTRAN", 6, 89068},
	{"YERJ", 4, 89069},
	{"YELA", 4, 89070},
	{"ULYG", 4, 89071},
	{"PLYU", 4, 89072},
	{"EKIW", 4, 89073},
	{"WASSERMAN", 9, 89074},
	{"MISHAPS", 7, 89075},
	{"SUBSIDENCE", 10, 89076},
	{"PLASTERING", 10, 89077},
	{"UISF", 4, 89078},
	{"ODDB", 4, 89079},
	{"FCCH", 4, 89080},
	{"ASLAN", 5, 89081},
	{"PROMISCUOUS", 11, 89082},
	{"ASTURIAS", 8, 89083},
	{"FOULING", 7, 89084},
	{"GUYF", 4, 89085},
	{"ERPC", 4, 89086},
	{"CLEJ", 4, 89087},
	{"MACFARLANE", 10, 89088},
	{"HIDESHOW", 8, 89089},
	{"BASSO", 5, 89090},
	{"TRAILHEAD", 9, 89091},
	{"BAYSHORE", 8, 89092},
	{"DUSTED", 6, 89093},
	{"VEEQ", 4, 89094},
	{"NYJU", 4, 89095},
	{"KAID", 4, 89096},
	{"EVEK", 4, 89097},
	{"INLETS", 6, 89098},
	{"PREPRINTS", 9, 89099},
	{"FORDS", 5, 89100},
	{"PEKKA", 5, 89101},
	{"RNCL", 4, 89102},
	{"LYNM", 4, 89103},
	{"JOYW", 4, 89104},
	{"EMKN", 4, 89105},
	{"DUCTION", 7, 89106},
	{"ANESTHETICS", 11, 89107},
	{"NALGENE", 7, 89108},
	{"PARENTAGE", 9, 89109},
	{"BERHAD", 6, 89110},
	{"SAVEDROP", 8, 89111},
	{"LITTERS", 7, 89112},
	{"BROTHEL", 7, 89113},
	{"RIVE", 4, 89114},
	{"YZON", 4, 89115},
	{"OUNR", 4, 89116},
	{"CKMC", 4, 89117},
	{"MAGNIFIERS", 10, 89118},
	{"SHELLED", 7, 89119},
	{"OUTLANDISH", 10, 89120},
	{"CHITTY", 6, 89121},
	{"GOLDWATER", 9, 89122},
	{"RMSN", 4, 89123},
	{"HODW", 4, 89124},
	{"FFEW", 4, 89125},
	{"BATP", 4, 89126},
	{"SNEEZING", 8, 89127},
	{"JUMPIN", 6, 89128},
	{"PAYABLES", 8, 89129},
	{"VICTIMIZED", 10, 89130},
	{"TABU", 4, 89131},
	{"INACTIVATED", 11, 89132},
	{"RESPIRATORS", 11, 89133},
	{"ATAXIA", 6, 89134},
	{"MSSQL", 5, 89135},
	{"STORYLINES", 10, 89136},
	{"SANCHO", 6, 89137},
	{"CAMARADERIE", 11, 89138},
	{"UJOL", 4, 89139},
	{"RGAB", 4, 89140},
	{"NDND", 4, 89141},
	{"LIPW", 4, 89142},
	{"GTUE", 4, 89143},
	{"CARPARK", 7, 89144},
	{"INTERNETWORKING", 15, 89145},
	{"VARIEGATED", 10, 89146},
	{"GAWK", 4, 89147},
	{"PLANING", 7, 89148},
	{"ABYSMAL", 7, 89149},
	{"TERMINI", 7, 89150},
	{"AVALIABLE", 9, 89151},
	{"PERSONNES", 9, 89152},
	{"VEMC", 4, 89153},
	{"BUYSAFE", 7, 89154},
	{"BOURSE", 6, 89155},
	{"PLEASANTVILLE", 13, 89156},
	{"FABRICATIONS", 12, 89157},
	{"PHUS", 4, 89158},
	{"NPAV", 4, 89159},
	{"TENACITY", 8, 89160},
	{"PARTIR", 6, 89161},
	{"JAMSHEDPUR", 10, 89162},
	{"DENTURE", 7, 89163},
	{"SRUD", 4, 89164},
	{"FMYO", 4, 89165},
	{"GAUDI", 5, 89166},
	{"BLUEFIELD", 9, 89167},
	{"TELESALES", 9, 89168},
	{"MOSLEM", 6, 89169},
	{"FOURTHS", 7, 89170},
	{"VPC", 3, 89171},
	{"REVOLUTIONIZED", 14, 89172},
	{"PPR", 3, 89173},
	{"PERMANENCE", 10, 89174},
	{"JETSONS", 7, 89175},
	{"ZALS", 4, 89176},
	{"ALSJ", 4, 89177},
	{"PROTAGONISTS", 12, 89178},
	{"FJD", 3, 89179},
	{"ANOKA", 5, 89180},
	{"BOLIVIANO", 9, 89181},
	{"YEEW", 4, 89182},
	{"NJAV", 4, 89183},
	{"CAUD", 4, 89184},
	{"CURTISS", 7, 89185},
	{"WATL", 4, 89186},
	{"UNCU", 4, 89187},
	{"ULAU", 4, 89188},
	{"REWJ", 4, 89189},
	{"OYLI", 4, 89190},
	{"ONKL", 4, 89191},
	{"WAGONER", 7, 89192},
	{"STORYBOARD", 10, 89193},
	{"TROL", 4, 89194},
	{"COINCIDENT", 10, 89195},
	{"RAJIV", 5, 89196},
	{"XFCE", 4, 89197},
	{"AXONS", 5, 89198},
	{"DMSO", 4, 89199},
	{"IMMUNOTHERAPY", 13, 89200},
	{"NAMORADA", 8, 89201},
	{"AZAW", 4, 89202},
	{"ZAKYNTHOS", 9, 89203},
	{"WEITZ", 5, 89204},
	{"MINDING", 7, 89205},
	{"QUERCUS", 7, 89206},
	{"PERMIS", 6, 89207},
	{"UFFH", 4, 89208},
	{"DYAM", 4, 89209},
	{"BRAB", 4, 89210},
	{"AMARA", 5, 89211},
	{"MICROCOSM", 9, 89212},
	{"BIZARRO", 7, 89213},
	{"MEHMET", 6, 89214},
	{"ENVIABLE", 8, 89215},
	{"CHRISTOS", 8, 89216},
	{"ACCESSIONS", 10, 89217},
	{"CATEGORICALLY", 13, 89218},
	{"AUTORESPONDER", 13, 89219},
	{"ADOLFO", 6, 89220},
	{"YESL", 4, 89221},
	{"WLSA", 4, 89222},
	{"MOUD", 4, 89223},
	{"CARPETED", 8, 89224},
	{"WELWYN", 6, 89225},
	{"SAWD", 4, 89226},
	{"RBOH", 4, 89227},
	{"NKOB", 4, 89228},
	{"GYHE", 4, 89229},
	{"DOTR", 4, 89230},
	{"APAW", 4, 89231},
	{"AKLI", 4, 89232},
	{"NZLUG", 5, 89233},
	{"CATNIP", 6, 89234},
	{"ZEKE", 4, 89235},
	{"WHITTINGTON", 11, 89236},
	{"XASL", 4, 89237},
	{"KRIC", 4, 89238},
	{"SOREL", 5, 89239},
	{"BONED", 5, 89240},
	{"OXED", 4, 89241},
	{"EWSJ", 4, 89242},
	{"DJOA", 4, 89243},
	{"BSPA", 4, 89244},
	{"VITTORIO", 8, 89245},
	{"ELOQUENTLY", 10, 89246},
	{"TOMASZ", 6, 89247},
	{"TONKA", 5, 89248},
	{"MYPI", 4, 89249},
	{"JOEF", 4, 89250},
	{"JIMW", 4, 89251},
	{"GCYC", 4, 89252},
	{"EMCR", 4, 89253},
	{"DMCD", 4, 89254},
	{"ZCD", 3, 89255},
	{"XVL", 3, 89256},
	{"XGC", 3, 89257},
	{"WKQ", 3, 89258},
	{"KVG", 3, 89259},
	{"GUX", 3, 89260},
	{"OVERTAKEN", 9, 89261},
	{"HOCK", 4, 89262},
	{"OLKT", 4, 89263},
	{"OKFA", 4, 89264},
	{"TOMASO", 6, 89265},
	{"ASCAP", 5, 89266},
	{"LIVEDOOR", 8, 89267},
	{"SCHLAMPEN", 9, 89268},
	{"ALTAMONTE", 9, 89269},
	{"SUBHEADING", 10, 89270},
	{"LTSR", 4, 89271},
	{"IPOU", 4, 89272},
	{"SCOTWEB", 7, 89273},
	{"PILLOWCASES", 11, 89274},
	{"MEDLINEPLUS", 11, 89275},
	{"AMBIENTE", 8, 89276},
	{"MASTERSON", 9, 89277},
	{"BONM", 4, 89278},
	{"FIBONACCI", 9, 89279},
	{"BRIDGETON", 9, 89280},
	{"WMDS", 4, 89281},
	{"RENEWS", 6, 89282},
	{"TYRRELL", 7, 89283},
	{"JUNKY", 5, 89284},
	{"EXTINGUISH", 10, 89285},
	{"BALLASTS", 8, 89286},
	{"YESY", 4, 89287},
	{"RADP", 4, 89288},
	{"CSMI", 4, 89289},
	{"JBUILDER", 8, 89290},
	{"LOWING", 6, 89291},
	{"RREU", 4, 89292},
	{"GHJA", 4, 89293},
	{"EDKU", 4, 89294},
	{"ACIG", 4, 89295},
	{"NAGANO", 6, 89296},
	{"BULLIED", 7, 89297},
	{"ACCRUING", 8, 89298},
	{"HARDMAN", 7, 89299},
	{"ROADMATE", 8, 89300},
	{"DIRGE", 5, 89301},
	{"INTERLEAVED", 11, 89302},
	{"VISD", 4, 89303},
	{"MMOU", 4, 89304},
	{"DMYA", 4, 89305},
	{"AUSU", 4, 89306},
	{"PEIRCE", 6, 89307},
	{"ACTUATED", 8, 89308},
	{"BLUISH", 6, 89309},
	{"PUSHER", 6, 89310},
	{"TINGLE", 6, 89311},
	{"THETFORD", 8, 89312},
	{"GNOSTIC", 7, 89313},
	{"COREUTILS", 9, 89314},
	{"UNINSTALLING", 12, 89315},
	{"RDVE", 4, 89316},
	{"PIDR", 4, 89317},
	{"OLYW", 4, 89318},
	{"GFLU", 4, 89319},
	{"AMBIVALENT", 10, 89320},
	{"STARTPAGE", 9, 89321},
	{"CAPTIVATED", 10, 89322},
	{"DIFRANCO", 8, 89323},
	{"OBYP", 4, 89324},
	{"LBYH", 4, 89325},
	{"GSDA", 4, 89326},
	{"PARLORS", 7, 89327},
	{"TYPIST", 6, 89328},
	{"LAMENTED", 8, 89329},
	{"ESTUDIO", 7, 89330},
	{"WIFY", 4, 89331},
	{"DMAM", 4, 89332},
	{"MOISTURIZERS", 12, 89333},
	{"BRUISE", 6, 89334},
	{"CESARE", 6, 89335},
	{"PERFUMED", 8, 89336},
	{"CARDIOL", 7, 89337},
	{"LAMINATION", 10, 89338},
	{"BIBI", 4, 89339},
	{"CARPE", 5, 89340},
	{"SCOTTIE", 7, 89341},
	{"BLACKROCK", 9, 89342},
	{"FISTFUL", 7, 89343},
	{"SOMETHINGS", 10, 89344},
	{"YPAD", 4, 89345},
	{"EOUG", 4, 89346},
	{"STAFFER", 7, 89347},
	{"RHIANNON", 8, 89348},
	{"DAMES", 5, 89349},
	{"LINSPIRE", 8, 89350},
	{"OPYT", 4, 89351},
	{"MJAM", 4, 89352},
	{"IADD", 4, 89353},
	{"GSUF", 4, 89354},
	{"CORNUCOPIA", 10, 89355},
	{"NEWSFACTOR", 10, 89356},
	{"COUNTERING", 10, 89357},
	{"PPHO", 4, 89358},
	{"ITWR", 4, 89359},
	{"EZDE", 4, 89360},
	{"ERRH", 4, 89361},
	{"CENV", 4, 89362},
	{"WORLDPAY", 8, 89363},
	{"CATAN", 5, 89364},
	{"UNFETTERED", 10, 89365},
	{"IMOGEN", 6, 89366},
	{"ALMATY", 6, 89367},
	{"LEWD", 4, 89368},
	{"APPRAISE", 8, 89369},
	{"ONKU", 4, 89370},
	{"NWIK", 4, 89371},
	{"AVAJ", 4, 89372},
	{"ASPY", 4, 89373},
	{"RUNNY", 5, 89374},
	{"BRAUNFELS", 9, 89375},
	{"THITHER", 7, 89376},
	{"REBUKE", 6, 89377},
	{"COLLATED", 8, 89378},
	{"REORG", 5, 89379},
	{"OCCASIONED", 10, 89380},
	{"SWAYED", 6, 89381},
	{"JAVAX", 5, 89382},
	{"DUPE", 4, 89383},
	{"YMPO", 4, 89384},
	{"ALBUMLIST", 9, 89385},
	{"HERAKLION", 9, 89386},
	{"BOGS", 4, 89387},
	{"STRESSORS", 9, 89388},
	{"AFFORDING", 9, 89389},
	{"REKM", 4, 89390},
	{"OPEV", 4, 89391},
	{"HNFK", 4, 89392},
	{"COLLOCATION", 11, 89393},
	{"ASSUREDLY", 9, 89394},
	{"MCCAULEY", 8, 89395},
	{"VESICLE", 7, 89396},
	{"ALLUSIONS", 9, 89397},
	{"STUFFERS", 8, 89398},
	{"PREGO", 5, 89399},
	{"ICHAT", 5, 89400},
	{"SHADOWED", 8, 89401},
	{"LUBRICATED", 10, 89402},
	{"WLOW", 4, 89403},
	{"MROM", 4, 89404},
	{"PHARMACIA", 9, 89405},
	{"AGGIUNGI", 8, 89406},
	{"SHAKIN", 6, 89407},
	{"CYR", 3, 89408},
	{"VIGILANTE", 9, 89409},
	{"GAUGING", 7, 89410},
	{"LIPASE", 6, 89411},
	{"CONSTABULARY", 12, 89412},
	{"SEAMEN", 6, 89413},
	{"BIOCHIM", 7, 89414},
	{"MGUN", 4, 89415},
	{"GFUT", 4, 89416},
	{"EPSM", 4, 89417},
	{"EPCOT", 5, 89418},
	{"CRICKETER", 9, 89419},
	{"INTELLIGIBLE", 12, 89420},
	{"DEFIBRILLATOR", 13, 89421},
	{"WVOL", 4, 89422},
	{"DROOLING", 8, 89423},
	{"STOLL", 5, 89424},
	{"STAINES", 7, 89425},
	{"OVERLAID", 8, 89426},
	{"WTYP", 4, 89427},
	{"NOPY", 4, 89428},
	{"INYD", 4, 89429},
	{"FAER", 4, 89430},
	{"CENSORS", 7, 89431},
	{"ADVERSARIAL", 11, 89432},
	{"SOFTWA", 6, 89433},
	{"PBC", 3, 89434},
	{"SHAKESPEAREAN", 13, 89435},
	{"ULLV", 4, 89436},
	{"TOUM", 4, 89437},
	{"DEMONSTRATOR", 12, 89438},
	{"BOINGO", 6, 89439},
	{"EDICT", 5, 89440},
	{"OCTAVIA", 7, 89441},
	{"BANERJEE", 8, 89442},
	{"HONDO", 5, 89443},
	{"HYSTERESIS", 10, 89444},
	{"BOYHOOD", 7, 89445},
	{"SUSTENANCE", 10, 89446},
	{"WORKSPACES", 10, 89447},
	{"YECA", 4, 89448},
	{"XSPE", 4, 89449},
	{"RTHJ", 4, 89450},
	{"CAMPION", 7, 89451},
	{"LUGANO", 6, 89452},
	{"MOBILISATION", 12, 89453},
	{"SHREW", 5, 89454},
	{"PRUITT", 6, 89455},
	{"FOALS", 5, 89456},
	{"ACIPHEX", 7, 89457},
	{"UTWR", 4, 89458},
	{"ROYB", 4, 89459},
	{"LJUM", 4, 89460},
	{"SCULPT", 6, 89461},
	{"ISKIN", 5, 89462},
	{"FREYA", 5, 89463},
	{"SOLEDAD", 7, 89464},
	{"DISRESPECTFUL", 13, 89465},
	{"CONFOUNDING", 11, 89466},
	{"PISR", 4, 89467},
	{"INUL", 4, 89468},
	{"DISPENSATION", 12, 89469},
	{"BAGPIPES", 8, 89470},
	{"ARIAN", 5, 89471},
	{"DEVALUATION", 11, 89472},
	{"SEGWAY", 6, 89473},
	{"MINERALIZATION", 14, 89474},
	{"GRC", 3, 89475},
	{"DEPRECIATED", 11, 89476},
	{"TVUL", 4, 89477},
	{"PADU", 4, 89478},
	{"LUSR", 4, 89479},
	{"LKHE", 4, 89480},
	{"KEGI", 4, 89481},
	{"IPPU", 4, 89482},
	{"FONC", 4, 89483},
	{"CFLA", 4, 89484},
	{"TRAFFICKED", 10, 89485},
	{"DIAGONALLY", 10, 89486},
	{"CASED", 5, 89487},
	{"STEDMAN", 7, 89488},
	{"GURL", 4, 89489},
	{"LATERALLY", 9, 89490},
	{"MCGINNIS", 8, 89491},
	{"RPEL", 4, 89492},
	{"GAPT", 4, 89493},
	{"DVIPS", 5, 89494},
	{"PRAYS", 5, 89495},
	{"KLEE", 4, 89496},
	{"GARBER", 6, 89497},
	{"WIZARDRY", 8, 89498},
	{"NONCE", 5, 89499},
	{"FERVENT", 7, 89500},
	{"LEMME", 5, 89501},
	{"HEADREST", 8, 89502},
	{"DERMATOL", 8, 89503},
	{"TZSC", 4, 89504},
	{"LSHR", 4, 89505},
	{"ELEVATING", 9, 89506},
	{"CHAPERONE", 9, 89507},
	{"AUGUSTIN", 8, 89508},
	{"HUYGENS", 7, 89509},
	{"BERESFORD", 9, 89510},
	{"EURYTHMICS", 10, 89511},
	{"TRANSBOUNDARY", 13, 89512},
	{"RECLASSIFIED", 12, 89513},
	{"RPAK", 4, 89514},
	{"RCHV", 4, 89515},
	{"KGOT", 4, 89516},
	{"DELUSIONAL", 10, 89517},
	{"LOUP", 4, 89518},
	{"PIMPIN", 6, 89519},
	{"HUSQVARNA", 9, 89520},
	{"FAXPRESS", 8, 89521},
	{"TINKERING", 9, 89522},
	{"UNNEEDED", 8, 89523},
	{"BABAR", 5, 89524},
	{"PAGO", 4, 89525},
	{"HUSSEY", 6, 89526},
	{"LIKENED", 7, 89527},
	{"OFFICECONNECT", 13, 89528},
	{"MICKELSON", 9, 89529},
	{"SUSL", 4, 89530},
	{"LEUKOCYTES", 10, 89531},
	{"WESNOTH", 7, 89532},
	{"PHYD", 4, 89533},
	{"MOFJ", 4, 89534},
	{"KSVE", 4, 89535},
	{"FFBO", 4, 89536},
	{"HYDRIDE", 7, 89537},
	{"ZONDERVAN", 9, 89538},
	{"PELE", 4, 89539},
	{"BERICHT", 7, 89540},
	{"OPETH", 5, 89541},
	{"KOTTKE", 6, 89542},
	{"LJAZ", 4, 89543},
	{"DYFE", 4, 89544},
	{"AUDT", 4, 89545},
	{"HOMETWAT", 8, 89546},
	{"SKETCHED", 8, 89547},
	{"MAUNA", 5, 89548},
	{"KSGE", 4, 89549},
	{"HOWQ", 4, 89550},
	{"FEDR", 4, 89551},
	{"ERGP", 4, 89552},
	{"PLAGE", 5, 89553},
	{"FIRMNESS", 8, 89554},
	{"KILNS", 5, 89555},
	{"INJUSTICES", 10, 89556},
	{"LONGFELLOW", 10, 89557},
	{"HARBIN", 6, 89558},
	{"ASSEMBLERS", 10, 89559},
	{"KYRG", 4, 89560},
	{"GJUL", 4, 89561},
	{"UNEQUIVOCALLY", 13, 89562},
	{"KARST", 5, 89563},
	{"WADA", 4, 89564},
	{"SELFLESS", 8, 89565},
	{"GYNECOLOGISTS", 13, 89566},
	{"ENEWSLETTERS", 12, 89567},
	{"WILLI", 5, 89568},
	{"YPX", 3, 89569},
	{"VZF", 3, 89570},
	{"QWR", 3, 89571},
	{"KFV", 3, 89572},
	{"JYV", 3, 89573},
	{"GZD", 3, 89574},
	{"GQV", 3, 89575},
	{"FZZ", 3, 89576},
	{"FKZ", 3, 89577},
	{"FGQ", 3, 89578},
	{"GUESTBOOKS", 10, 89579},
	{"VAWH", 4, 89580},
	{"SHBL", 4, 89581},
	{"KIDT", 4, 89582},
	{"IODR", 4, 89583},
	{"CHLY", 4, 89584},
	{"AMCU", 4, 89585},
	{"SHARJAH", 7, 89586},
	{"AGUIRRE", 7, 89587},
	{"KRUG", 4, 89588},
	{"DONGS", 5, 89589},
	{"PERSPIRATION", 12, 89590},
	{"DRV", 3, 89591},
	{"SCHOOLERS", 9, 89592},
	{"KIDNAPPERS", 10, 89593},
	{"LEMMON", 6, 89594},
	{"OMYN", 4, 89595},
	{"FHEB", 4, 89596},
	{"CYMO", 4, 89597},
	{"GNUTELLA", 8, 89598},
	{"DEUTSCHES", 9, 89599},
	{"LIQUIDATOR", 10, 89600},
	{"MIRTH", 5, 89601},
	{"SERRE", 5, 89602},
	{"EVERS", 5, 89603},
	{"UNIROSS", 7, 89604},
	{"GRASSLEY", 8, 89605},
	{"WEVI", 4, 89606},
	{"UPDR", 4, 89607},
	{"RANV", 4, 89608},
	{"STOWAWAY", 8, 89609},
	{"BRAINER", 7, 89610},
	{"PAUPER", 6, 89611},
	{"ORGANIZA", 8, 89612},
	{"CELLOG", 6, 89613},
	{"CHANNELED", 9, 89614},
	{"TASTINGS", 8, 89615},
	{"DECCAN", 6, 89616},
	{"NEUROSCIENCES", 13, 89617},
	{"URJU", 4, 89618},
	{"SIGU", 4, 89619},
	{"RHAY", 4, 89620},
	{"MASY", 4, 89621},
	{"AWNU", 4, 89622},
	{"FACTORIAL", 9, 89623},
	{"LIBRARIANSHIP", 13, 89624},
	{"TEXMACS", 7, 89625},
	{"BROOMS", 6, 89626},
	{"UMBT", 4, 89627},
	{"GNAP", 4, 89628},
	{"HORUS", 5, 89629},
	{"SYOR", 4, 89630},
	{"MISK", 4, 89631},
	{"DWEF", 4, 89632},
	{"VOCABULARIES", 12, 89633},
	{"BLASTERS", 8, 89634},
	{"LIVABLE", 7, 89635},
	{"TYLU", 4, 89636},
	{"RMBY", 4, 89637},
	{"DMYO", 4, 89638},
	{"BDIS", 4, 89639},
	{"AGYM", 4, 89640},
	{"USHERED", 7, 89641},
	{"REMEDIED", 8, 89642},
	{"VOCATIONS", 9, 89643},
	{"DEPUIS", 6, 89644},
	{"UOTW", 4, 89645},
	{"EZAR", 4, 89646},
	{"LIBJAVA", 7, 89647},
	{"RAMBLERS", 8, 89648},
	{"COUNTERPRODUCTIVE", 17, 89649},
	{"CATSKILL", 8, 89650},
	{"NYWR", 4, 89651},
	{"IRLU", 4, 89652},
	{"ABUZ", 4, 89653},
	{"SCORCHED", 8, 89654},
	{"ENVIRONMENTALISM", 16, 89655},
	{"GWALIOR", 7, 89656},
	{"UBL", 3, 89657},
	{"VEGL", 4, 89658},
	{"LIWI", 4, 89659},
	{"FEAG", 4, 89660},
	{"KILTS", 5, 89661},
	{"BALENCIAGA", 10, 89662},
	{"INSTEP", 6, 89663},
	{"ALAMITOS", 8, 89664},
	{"NEWSBURST", 9, 89665},
	{"SEPTUM", 6, 89666},
	{"WILFRID", 7, 89667},
	{"ANIMATORS", 9, 89668},
	{"TAYB", 4, 89669},
	{"SIGNIFI", 7, 89670},
	{"NEOCLASSICAL", 12, 89671},
	{"MACHIAVELLI", 11, 89672},
	{"IVOR", 4, 89673},
	{"MEDIAEVAL", 9, 89674},
	{"PIEZO", 5, 89675},
	{"ESCUDO", 6, 89676},
	{"PINEVILLE", 9, 89677},
	{"BOTANICA", 8, 89678},
	{"HTMY", 4, 89679},
	{"FOKL", 4, 89680},
	{"DOOU", 4, 89681},
	{"DMYR", 4, 89682},
	{"CHKN", 4, 89683},
	{"PETTER", 6, 89684},
	{"ADENINE", 7, 89685},
	{"FREN", 4, 89686},
	{"LYSIS", 5, 89687},
	{"ROLU", 4, 89688},
	{"GNDI", 4, 89689},
	{"FIAM", 4, 89690},
	{"ECCI", 4, 89691},
	{"PASTAS", 6, 89692},
	{"HELICASE", 8, 89693},
	{"DREDD", 5, 89694},
	{"EFINANCIALCAREERS", 17, 89695},
	{"DIEHL", 5, 89696},
	{"KILEY", 5, 89697},
	{"KWD", 3, 89698},
	{"IHOUSING", 8, 89699},
	{"ZAMO", 4, 89700},
	{"RGYZ", 4, 89701},
	{"PICW", 4, 89702},
	{"LYNB", 4, 89703},
	{"CPAI", 4, 89704},
	{"YORUBA", 6, 89705},
	{"MALFORMATIONS", 13, 89706},
	{"EMBARASSED", 10, 89707},
	{"ALEXIA", 6, 89708},
	{"CHECKUP", 7, 89709},
	{"COMMITED", 8, 89710},
	{"NANOTUBE", 8, 89711},
	{"MIGNON", 6, 89712},
	{"HOUSEBOAT", 9, 89713},
	{"KRIEG", 5, 89714},
	{"BECTA", 5, 89715},
	{"TRADOS", 6, 89716},
	{"PORTOFINO", 9, 89717},
	{"LIFESAVING", 10, 89718},
	{"SCTP", 4, 89719},
	{"CLEMENTINE", 10, 89720},
	{"ULTG", 4, 89721},
	{"ENUD", 4, 89722},
	{"TAYSIDE", 7, 89723},
	{"SMOKELESS", 9, 89724},
	{"PLAYMOBIL", 9, 89725},
	{"STANHOPE", 8, 89726},
	{"TUALATIN", 8, 89727},
	{"RAZORBACKS", 10, 89728},
	{"RBRY", 4, 89729},
	{"INYP", 4, 89730},
	{"HSGR", 4, 89731},
	{"GICL", 4, 89732},
	{"FDEG", 4, 89733},
	{"IONIZED", 7, 89734},
	{"PERODUA", 7, 89735},
	{"SUBST", 5, 89736},
	{"CPAP", 4, 89737},
	{"MOLEX", 5, 89738},
	{"VITARA", 6, 89739},
	{"FOSTEX", 6, 89740},
	{"ZMK", 3, 89741},
	{"THORAX", 6, 89742},
	{"PLACENTAL", 9, 89743},
	{"RECHERCHES", 10, 89744},
	{"WARSHIP", 7, 89745},
	{"PARSES", 6, 89746},
	{"VELN", 4, 89747},
	{"TBEK", 4, 89748},
	{"EKAY", 4, 89749},
	{"EFEV", 4, 89750},
	{"NEWSMAKERS", 10, 89751},
	{"DSHIELD", 7, 89752},
	{"TEGL", 4, 89753},
	{"JUEGO", 5, 89754},
	{"METAMORPHIC", 11, 89755},
	{"CORINTHIAN", 10, 89756},
	{"RATTLES", 7, 89757},
	{"CLD", 3, 89758},
	{"OTCBB", 5, 89759},
	{"RADO", 4, 89760},
	{"WATCHGUARD", 10, 89761},
	{"WWAV", 4, 89762},
	{"PEIG", 4, 89763},
	{"LKHO", 4, 89764},
	{"LFFI", 4, 89765},
	{"SUGARLAND", 9, 89766},
	{"SINGULARITIES", 13, 89767},
	{"GARTEN", 6, 89768},
	{"TROPHIC", 7, 89769},
	{"DISLOCATED", 10, 89770},
	{"DACIA", 5, 89771},
	{"REVERSI", 7, 89772},
	{"MARVELS", 7, 89773},
	{"INSEMINATION", 12, 89774},
	{"BOOBY", 5, 89775},
	{"HOUMA", 5, 89776},
	{"CONCEIVABLY", 11, 89777},
	{"QUETZAL", 7, 89778},
	{"SHOSHONE", 8, 89779},
	{"PSEM", 4, 89780},
	{"ISKP", 4, 89781},
	{"LINDER", 6, 89782},
	{"HOMING", 6, 89783},
	{"WIDG", 4, 89784},
	{"VIDJ", 4, 89785},
	{"DOWF", 4, 89786},
	{"HIGHBURY", 8, 89787},
	{"PODIATRISTS", 11, 89788},
	{"PERSIANS", 8, 89789},
	{"VIAF", 4, 89790},
	{"RGEK", 4, 89791},
	{"NDKH", 4, 89792},
	{"MRRO", 4, 89793},
	{"LFID", 4, 89794},
	{"ELTP", 4, 89795},
	{"DVEL", 4, 89796},
	{"BEGL", 4, 89797},
	{"CONCH", 5, 89798},
	{"CROSSREF", 8, 89799},
	{"INJUNCTIONS", 11, 89800},
	{"POPPINS", 7, 89801},
	{"CHAIM", 5, 89802},
	{"CYTOTOXICITY", 12, 89803},
	{"XUGANA", 6, 89804},
	{"CRUNCHING", 9, 89805},
	{"WEEVIL", 6, 89806},
	{"INTEGRATIONS", 12, 89807},
	{"UROD", 4, 89808},
	{"TSYR", 4, 89809},
	{"IMIM", 4, 89810},
	{"IKAM", 4, 89811},
	{"GNSC", 4, 89812},
	{"EERV", 4, 89813},
	{"AIMM", 4, 89814},
	{"CLARKSTON", 9, 89815},
	{"RITEK", 5, 89816},
	{"MORGUE", 6, 89817},
	{"UNPATCHED", 9, 89818},
	{"KICKERS", 7, 89819},
	{"REFERERS", 8, 89820},
	{"EXUBERANT", 9, 89821},
	{"RATV", 4, 89822},
	{"ONKY", 4, 89823},
	{"HPLU", 4, 89824},
	{"DNAD", 4, 89825},
	{"BYUP", 4, 89826},
	{"SERVIZIO", 8, 89827},
	{"BIOSECURITY", 11, 89828},
	{"LEVITON", 7, 89829},
	{"JOED", 4, 89830},
	{"ELECTRIFICATION", 15, 89831},
	{"PENINSULAR", 10, 89832},
	{"JUGGLE", 6, 89833},
	{"MGOA", 4, 89834},
	{"COMPOSURE", 9, 89835},
	{"YESHIVA", 7, 89836},
	{"SOCIOLOGIST", 11, 89837},
	{"CONTRADICTED", 12, 89838},
	{"SARTRE", 6, 89839},
	{"FINITELY", 8, 89840},
	{"SPECT", 5, 89841},
	{"KATHIE", 6, 89842},
	{"ARDS", 4, 89843},
	{"VEYC", 4, 89844},
	{"ABEM", 4, 89845},
	{"BIRTHRIGHT", 10, 89846},
	{"CORNY", 5, 89847},
	{"BRAZILIANS", 10, 89848},
	{"LUNDY", 5, 89849},
	{"HISTOCOMPATIBILITY", 18, 89850},
	{"ERRANT", 6, 89851},
	{"PROOFREAD", 9, 89852},
	{"WOOLWICH", 8, 89853},
	{"REARRANGED", 10, 89854},
	{"OKOL", 4, 89855},
	{"NKFA", 4, 89856},
	{"EPIZ", 4, 89857},
	{"ARHY", 4, 89858},
	{"HEIFER", 6, 89859},
	{"HANDANGO", 8, 89860},
	{"EARTHEN", 7, 89861},
	{"COSGROVE", 8, 89862},
	{"SULFURIC", 8, 89863},
	{"UPLANDS", 7, 89864},
	{"ZBUR", 4, 89865},
	{"RLSD", 4, 89866},
	{"OXMA", 4, 89867},
	{"DYDR", 4, 89868},
	{"RENDERINGS", 10, 89869},
	{"LDCS", 4, 89870},
	{"PAGET", 5, 89871},
	{"LECT", 4, 89872},
	{"KOLLAM", 6, 89873},
	{"RABW", 4, 89874},
	{"OBSP", 4, 89875},
	{"NDYG", 4, 89876},
	{"KHEC", 4, 89877},
	{"EDGERTON", 8, 89878},
	{"BULLETED", 8, 89879},
	{"ACUPRESSURE", 11, 89880},
	{"THOTBOOL", 8, 89881},
	{"HIAWATHA", 8, 89882},
	{"NHFB", 4, 89883},
	{"REZH", 4, 89884},
	{"PBUR", 4, 89885},
	{"OOPW", 4, 89886},
	{"EXRA", 4, 89887},
	{"BEPH", 4, 89888},
	{"PORTCULLIS", 10, 89889},
	{"OPERON", 6, 89890},
	{"UGANDAN", 7, 89891},
	{"PATON", 5, 89892},
	{"SUSPENDS", 8, 89893},
	{"GEYS", 4, 89894},
	{"CLYS", 4, 89895},
	{"AZZF", 4, 89896},
	{"CATEGORIE", 9, 89897},
	{"STRATIGRAPHY", 12, 89898},
	{"XGY", 3, 89899},
	{"VWV", 3, 89900},
	{"VGY", 3, 89901},
	{"KWJ", 3, 89902},
	{"KQW", 3, 89903},
	{"RECUR", 5, 89904},
	{"HOWES", 5, 89905},
	{"SURFED", 6, 89906},
	{"STEINS", 6, 89907},
	{"UNTG", 4, 89908},
	{"MBSH", 4, 89909},
	{"CEYA", 4, 89910},
	{"BABU", 4, 89911},
	{"DESIROUS", 8, 89912},
	{"ANDRADE", 7, 89913},
	{"AGARWAL", 7, 89914},
	{"EXEMPLAR", 8, 89915},
	{"SHIVERS", 7, 89916},
	{"SUREFIRE", 8, 89917},
	{"CORI", 4, 89918},
	{"PLANETSIDE", 10, 89919},
	{"SNORKELLING", 11, 89920},
	{"SMITTEN", 7, 89921},
	{"WATERWORKS", 10, 89922},
	{"LUK", 3, 89923},
	{"OMNU", 4, 89924},
	{"LPOE", 4, 89925},
	{"GEJA", 4, 89926},
	{"DYJO", 4, 89927},
	{"HEADLAMPS", 9, 89928},
	{"ODSG", 4, 89929},
	{"FBOY", 4, 89930},
	{"ANAESTHETIC", 11, 89931},
	{"ISOMERASE", 9, 89932},
	{"FDISK", 5, 89933},
	{"DUNSTABLE", 9, 89934},
	{"HENDON", 6, 89935},
	{"ACCREDITATIONS", 14, 89936},
	{"RAREST", 6, 89937},
	{"DORAL", 5, 89938},
	{"YBEV", 4, 89939},
	{"NGOG", 4, 89940},
	{"ABYM", 4, 89941},
	{"MACADAMIA", 9, 89942},
	{"TAKIN", 5, 89943},
	{"MARRIOT", 7, 89944},
	{"DISQUALIFY", 10, 89945},
	{"QUIERO", 6, 89946},
	{"BEAZLEY", 7, 89947},
	{"RASHES", 6, 89948},
	{"AVERTED", 7, 89949},
	{"NAJAF", 5, 89950},
	{"PUBLIQUE", 8, 89951},
	{"RKEW", 4, 89952},
	{"DAMF", 4, 89953},
	{"AXOF", 4, 89954},
	{"BUKIT", 5, 89955},
	{"ANTIAGING", 9, 89956},
	{"PSYCHOL", 7, 89957},
	{"BEDINGFIELD", 11, 89958},
	{"DISSIPATED", 10, 89959},
	{"EQUATED", 7, 89960},
	{"SWIG", 4, 89961},
	{"LIGHTSCRIBE", 11, 89962},
	{"UNIONIST", 8, 89963},
	{"VESQ", 4, 89964},
	{"OMVO", 4, 89965},
	{"MRPR", 4, 89966},
	{"FEDH", 4, 89967},
	{"GREGORIO", 8, 89968},
	{"LYTHAM", 6, 89969},
	{"CLOCKED", 7, 89970},
	{"MASQUERADING", 12, 89971},
	{"DISCERNIBLE", 11, 89972},
	{"DUCED", 5, 89973},
	{"COMPLEMENTING", 13, 89974},
	{"ULIM", 4, 89975},
	{"UACH", 4, 89976},
	{"IXPR", 4, 89977},
	{"KEYCODE", 7, 89978},
	{"PENNANTS", 8, 89979},
	{"CAMAS", 5, 89980},
	{"EAMON", 5, 89981},
	{"ZAURUS", 6, 89982},
	{"LOOSER", 6, 89983},
	{"DELUX", 5, 89984},
	{"PALF", 4, 89985},
	{"EZRE", 4, 89986},
	{"BYKO", 4, 89987},
	{"AZZS", 4, 89988},
	{"GRRL", 4, 89989},
	{"BOOKIE", 6, 89990},
	{"BOGGLING", 8, 89991},
	{"PTOLEMY", 7, 89992},
	{"SKEWERS", 7, 89993},
	{"RICHMAN", 7, 89994},
	{"LAUDED", 6, 89995},
	{"PHOTODISC", 9, 89996},
	{"CONSONANTS", 10, 89997},
	{"UMBERTO", 7, 89998},
	{"BAUTISTA", 8, 89999},
	{"RLDJ", 4, 90000},
	{"HYBO", 4, 90001},
	{"DEMARCATION", 11, 90002},
	{"ZOOMS", 5, 90003},
	{"NEWSDESK", 8, 90004},
	{"ROADBLOCKS", 10, 90005},
	{"KLUM", 4, 90006},
	{"YWEV", 4, 90007},
	{"LEOM", 4, 90008},
	{"DUPN", 4, 90009},
	{"BEDL", 4, 90010},
	{"MIOCENE", 7, 90011},
	{"GOEBEL", 6, 90012},
	{"KSOP", 4, 90013},
	{"GFEM", 4, 90014},
	{"DIAMONDBACK", 11, 90015},
	{"STEEPLE", 7, 90016},
	{"FOOSBALL", 8, 90017},
	{"REPT", 4, 90018},
	{"SPURGEON", 8, 90019},
	{"LUMBERJACK", 10, 90020},
	{"MARV", 4, 90021},
	{"CONCUSSION", 10, 90022},
	{"NAILING", 7, 90023},
	{"EPIDERMIS", 9, 90024},
	{"UYAT", 4, 90025},
	{"MVIL", 4, 90026},
	{"LYEC", 4, 90027},
	{"LFEX", 4, 90028},
	{"GNOB", 4, 90029},
	{"MOBLEY", 6, 90030},
	{"OKTOBERFEST", 11, 90031},
	{"PHOTOSHOOT", 10, 90032},
	{"RHINOPLASTY", 11, 90033},
	{"XTHF", 4, 90034},
	{"NGIP", 4, 90035},
	{"ELIW", 4, 90036},
	{"CSBY", 4, 90037},
	{"PEPTIC", 6, 90038},
	{"BAUMAN", 6, 90039},
	{"TANNINS", 7, 90040},
	{"UBPA", 4, 90041},
	{"TDOD", 4, 90042},
	{"FTIG", 4, 90043},
	{"EBYK", 4, 90044},
	{"DEADLIEST", 9, 90045},
	{"SPARINGLY", 9, 90046},
	{"PENANCE", 7, 90047},
	{"PSYCHOTROPIC", 12, 90048},
	{"TILLEY", 6, 90049},
	{"MALAYA", 6, 90050},
	{"HYPOTHALAMUS", 12, 90051},
	{"SHOSTAKOVICH", 12, 90052},
	{"SCHERER", 7, 90053},
	{"PRIESTLY", 8, 90054},
	{"HWEW", 4, 90055},
	{"GTHC", 4, 90056},
	{"CURTAILED", 9, 90057},
	{"LOVEJOY", 7, 90058},
	{"MANIPULATOR", 11, 90059},
	{"CALABASAS", 9, 90060},
	{"COROMANDEL", 10, 90061},
	{"PLINER", 6, 90062},
	{"PAWI", 4, 90063},
	{"HYMI", 4, 90064},
	{"CPEN", 4, 90065},
	{"AYVO", 4, 90066},
	{"TIMESTAMPS", 10, 90067},
	{"PANGO", 5, 90068},
	{"ROLLO", 5, 90069},
	{"EDEXCEL", 7, 90070},
	{"CONSPICUOUSLY", 13, 90071},
	{"GWAITH", 6, 90072},
	{"RISKED", 6, 90073},
	{"HHUG", 4, 90074},
	{"EDAZ", 4, 90075},
	{"BOWLED", 6, 90076},
	{"BREASTSTROKE", 12, 90077},
	{"OROVILLE", 8, 90078},
	{"MITSUMI", 7, 90079},
	{"MODERNIZED", 10, 90080},
	{"MOBIUS", 6, 90081},
	{"MRBU", 4, 90082},
	{"BLEMISHES", 9, 90083},
	{"DEDUCTIBLES", 11, 90084},
	{"EAGERNESS", 9, 90085},
	{"NIKOLA", 6, 90086},
	{"BERRIEN", 7, 90087},
	{"PEACEMAKER", 10, 90088},
	{"PEARLY", 6, 90089},
	{"BOOKMARKED", 10, 90090},
	{"PATP", 4, 90091},
	{"IGSB", 4, 90092},
	{"LETTERBOX", 9, 90093},
	{"HALAL", 5, 90094},
	{"NOLL", 4, 90095},
	{"FILENET", 7, 90096},
	{"FREELAND", 8, 90097},
	{"KIRSCH", 6, 90098},
	{"EYAU", 4, 90099},
	{"CCOI", 4, 90100},
	{"ROADHOUSE", 9, 90101},
	{"RECKLESSLY", 10, 90102},
	{"CHARTED", 7, 90103},
	{"REMR", 4, 90104},
	{"KKAR", 4, 90105},
	{"FBES", 4, 90106},
	{"CTOV", 4, 90107},
	{"MICROTUBULE", 11, 90108},
	{"CUBICLES", 8, 90109},
	{"ISLETS", 6, 90110},
	{"APOTHECARY", 10, 90111},
	{"BLAU", 4, 90112},
	{"LADYSMITH", 9, 90113},
	{"GATTI", 5, 90114},
	{"ECTION", 6, 90115},
	{"GAGNE", 5, 90116},
	{"SWITCHABLE", 10, 90117},
	{"MCMINNVILLE", 11, 90118},
	{"UDYR", 4, 90119},
	{"EJAW", 4, 90120},
	{"DDMO", 4, 90121},
	{"INTERACTIVES", 12, 90122},
	{"ALTUS", 5, 90123},
	{"PHOSPHOLIPASE", 13, 90124},
	{"TRANSFORMATIVE", 14, 90125},
	{"SAMUELSON", 9, 90126},
	{"COMPLETLY", 9, 90127},
	{"ANHYDROUS", 9, 90128},
	{"OWLB", 4, 90129},
	{"LOOTED", 6, 90130},
	{"GERMPLASM", 9, 90131},
	{"PADUA", 5, 90132},
	{"GRADZONE", 8, 90133},
	{"GDANSK", 6, 90134},
	{"JENNER", 6, 90135},
	{"PARKIN", 6, 90136},
	{"UNMODERATED", 11, 90137},
	{"LITL", 4, 90138},
	{"EURT", 4, 90139},
	{"WAGERS", 6, 90140},
	{"BELIEFNET", 9, 90141},
	{"HOTBAR", 6, 90142},
	{"CANIS", 5, 90143},
	{"GSAU", 4, 90144},
	{"FAMB", 4, 90145},
	{"CEXC", 4, 90146},
	{"ACBE", 4, 90147},
	{"RAVIOLI", 7, 90148},
	{"ENROLMENTS", 10, 90149},
	{"WALLING", 7, 90150},
	{"MARBLEHEAD", 10, 90151},
	{"JOINTED", 7, 90152},
	{"WOFB", 4, 90153},
	{"RPMA", 4, 90154},
	{"IFGO", 4, 90155},
	{"GGSW", 4, 90156},
	{"FMOM", 4, 90157},
	{"FDUB", 4, 90158},
	{"ELYQ", 4, 90159},
	{"CDOE", 4, 90160},
	{"RIBOSOME", 8, 90161},
	{"CARNIVALS", 9, 90162},
	{"SPEEDMAN", 8, 90163},
	{"HEYDAY", 6, 90164},
	{"INSTRUME", 8, 90165},
	{"MOFFETT", 7, 90166},
	{"OBYS", 4, 90167},
	{"GHSM", 4, 90168},
	{"EEGU", 4, 90169},
	{"DTYL", 4, 90170},
	{"AUGUSTANA", 9, 90171},
	{"TOPSOIL", 7, 90172},
	{"LATIFAH", 7, 90173},
	{"ISOMERS", 7, 90174},
	{"PETTIT", 6, 90175},
	{"LEMANS", 6, 90176},
	{"VOCE", 4, 90177},
	{"TELESCOPING", 11, 90178},
	{"GAMEDESIRE", 10, 90179},
	{"PULSATING", 9, 90180},
	{"BEAMING", 7, 90181},
	{"YEWA", 4, 90182},
	{"NLOB", 4, 90183},
	{"FYES", 4, 90184},
	{"DORE", 4, 90185},
	{"BALANCER", 8, 90186},
	{"PICTON", 6, 90187},
	{"UNDERHILL", 9, 90188},
	{"DINGHIES", 8, 90189},
	{"CHOOSER", 7, 90190},
	{"ARGENTINIAN", 11, 90191},
	{"AHRQ", 4, 90192},
	{"PWAL", 4, 90193},
	{"LBYD", 4, 90194},
	{"DETU", 4, 90195},
	{"APPARELS", 8, 90196},
	{"TIMESCALES", 10, 90197},
	{"OCCH", 4, 90198},
	{"NRIQ", 4, 90199},
	{"ILML", 4, 90200},
	{"LOUNGING", 8, 90201},
	{"ATHENIAN", 8, 90202},
	{"PREDISPOSITION", 14, 90203},
	{"MCEWAN", 6, 90204},
	{"ZLER", 4, 90205},
	{"YARB", 4, 90206},
	{"RKSG", 4, 90207},
	{"LDYE", 4, 90208},
	{"CYSU", 4, 90209},
	{"ZERMATT", 7, 90210},
	{"GEERT", 5, 90211},
	{"BUGGING", 7, 90212},
	{"OUTWARDLY", 9, 90213},
	{"TRENTO", 6, 90214},
	{"TUMULTUOUS", 10, 90215},
	{"LYNDHURST", 9, 90216},
	{"WDC", 3, 90217},
	{"SYMBIOTIC", 9, 90218},
	{"TRUA", 4, 90219},
	{"KOFV", 4, 90220},
	{"IRKH", 4, 90221},
	{"DYSLEXIC", 8, 90222},
	{"NOMIC", 5, 90223},
	{"TECNICA", 7, 90224},
	{"YPQ", 3, 90225},
	{"XKC", 3, 90226},
	{"WXG", 3, 90227},
	{"FZC", 3, 90228},
	{"MMAP", 4, 90229},
	{"VETY", 4, 90230},
	{"NOJU", 4, 90231},
	{"LUNL", 4, 90232},
	{"IDQU", 4, 90233},
	{"WISHBONE", 8, 90234},
	{"OVERSEER", 8, 90235},
	{"CHINE", 5, 90236},
	{"MCAD", 4, 90237},
	{"CRIER", 5, 90238},
	{"PRM", 3, 90239},
	{"BASHIR", 6, 90240},
	{"LICENCED", 8, 90241},
	{"LARISSA", 7, 90242},
	{"COLLAB", 6, 90243},
	{"SQUIRTER", 8, 90244},
	{"INFECTING", 9, 90245},
	{"PENETRATIONS", 12, 90246},
	{"AUSD", 4, 90247},
	{"PROTEA", 6, 90248},
	{"ARGENTO", 7, 90249},
	{"POLYVINYL", 9, 90250},
	{"GANGLION", 8, 90251},
	{"RUUD", 4, 90252},
	{"BUNT", 4, 90253},
	{"DECOMPOSE", 9, 90254},
	{"SOLGAR", 6, 90255},
	{"PYWH", 4, 90256},
	{"LULT", 4, 90257},
	{"IGWE", 4, 90258},
	{"CYPA", 4, 90259},
	{"BEYI", 4, 90260},
	{"UNIMAGINABLE", 12, 90261},
	{"LIPPER", 6, 90262},
	{"CHIMPANZEES", 11, 90263},
	{"BRITON", 6, 90264},
	{"XASF", 4, 90265},
	{"WNKI", 4, 90266},
	{"RIMR", 4, 90267},
	{"ILOP", 4, 90268},
	{"DOAC", 4, 90269},
	{"DGEV", 4, 90270},
	{"GLISTENING", 10, 90271},
	{"TESTCASES", 9, 90272},
	{"HAMZA", 5, 90273},
	{"MOONSHINE", 9, 90274},
	{"MEEKS", 5, 90275},
	{"ATHOL", 5, 90276},
	{"VISF", 4, 90277},
	{"PITR", 4, 90278},
	{"ISKC", 4, 90279},
	{"IGPO", 4, 90280},
	{"EBOF", 4, 90281},
	{"DEZS", 4, 90282},
	{"CENTIMETER", 10, 90283},
	{"JURGEN", 6, 90284},
	{"EXCRETED", 8, 90285},
	{"PAROS", 5, 90286},
	{"LEURS", 5, 90287},
	{"UGHQ", 4, 90288},
	{"GNFR", 4, 90289},
	{"BYAJ", 4, 90290},
	{"AZZARO", 6, 90291},
	{"SCRIBBLE", 8, 90292},
	{"NAPPA", 5, 90293},
	{"ANSELM", 6, 90294},
	{"SIRNA", 5, 90295},
	{"PUERTA", 6, 90296},
	{"PECULIARITIES", 13, 90297},
	{"NONPRESCRIPTION", 15, 90298},
	{"LYD", 3, 90299},
	{"LICHTENSTEIN", 12, 90300},
	{"FIREWORK", 8, 90301},
	{"TDYN", 4, 90302},
	{"NGZE", 4, 90303},
	{"MIMM", 4, 90304},
	{"HFRU", 4, 90305},
	{"GETK", 4, 90306},
	{"ERCM", 4, 90307},
	{"CRLF", 4, 90308},
	{"LOCALIZE", 8, 90309},
	{"TABLATURES", 10, 90310},
	{"FAVOURABLY", 10, 90311},
	{"JNDI", 4, 90312},
	{"BESET", 5, 90313},
	{"ROMAIN", 6, 90314},
	{"VIGORISH", 8, 90315},
	{"YCIN", 4, 90316},
	{"SMYO", 4, 90317},
	{"FJOE", 4, 90318},
	{"DYUS", 4, 90319},
	{"ARCK", 4, 90320},
	{"DCD", 3, 90321},
	{"INVOLUNTARILY", 13, 90322},
	{"SCHULTE", 7, 90323},
	{"GIOCO", 5, 90324},
	{"CHESTED", 7, 90325},
	{"UNIVERSIT", 9, 90326},
	{"THRIVENT", 8, 90327},
	{"SWEDE", 5, 90328},
	{"YOBL", 4, 90329},
	{"RERD", 4, 90330},
	{"HYDROTHERMAL", 12, 90331},
	{"SMALLEY", 7, 90332},
	{"DISCOVERER", 10, 90333},
	{"RAMEN", 5, 90334},
	{"COLEOPTERA", 10, 90335},
	{"INTENSIFYING", 12, 90336},
	{"COPYLEFT", 8, 90337},
	{"LLB", 3, 90338},
	{"WLOF", 4, 90339},
	{"RAPB", 4, 90340},
	{"MBSI", 4, 90341},
	{"BYAY", 4, 90342},
	{"OUTFITTED", 9, 90343},
	{"KHTML", 5, 90344},
	{"CHATTERJEE", 10, 90345},
	{"ADOPTEE", 7, 90346},
	{"AUGUSTO", 7, 90347},
	{"RESNICK", 7, 90348},
	{"INTERSECTS", 10, 90349},
	{"GRANDMASTER", 11, 90350},
	{"LIVERS", 6, 90351},
	{"PDET", 4, 90352},
	{"GGAT", 4, 90353},
	{"DEADBALL", 8, 90354},
	{"CKSUM", 5, 90355},
	{"WOCR", 4, 90356},
	{"WNFU", 4, 90357},
	{"VSAR", 4, 90358},
	{"REPJ", 4, 90359},
	{"GMYF", 4, 90360},
	{"HISTORIOGRAPHY", 14, 90361},
	{"AMISTAD", 7, 90362},
	{"BELLACOR", 8, 90363},
	{"TRCDSEMBL", 9, 90364},
	{"CAMPAGNOLO", 10, 90365},
	{"DOWNGRADES", 10, 90366},
	{"SCRAPPING", 9, 90367},
	{"PDOC", 4, 90368},
	{"YJES", 4, 90369},
	{"RIIW", 4, 90370},
	{"PLOWING", 7, 90371},
	{"MILITARISM", 10, 90372},
	{"HASKINS", 7, 90373},
	{"GLASSY", 6, 90374},
	{"BULLHEAD", 8, 90375},
	{"RHETT", 5, 90376},
	{"RIDDLED", 7, 90377},
	{"MIMOSA", 6, 90378},
	{"YWIR", 4, 90379},
	{"PIDP", 4, 90380},
	{"HJAP", 4, 90381},
	{"FTLO", 4, 90382},
	{"DMCG", 4, 90383},
	{"WEALTHIEST", 10, 90384},
	{"WILDFIRES", 9, 90385},
	{"SHRILL", 6, 90386},
	{"ELLYN", 5, 90387},
	{"HRYVNIA", 7, 90388},
	{"HALVED", 6, 90389},
	{"CFML", 4, 90390},
	{"VATU", 4, 90391},
	{"ECADEMY", 7, 90392},
	{"DOLORE", 6, 90393},
	{"SHAUNA", 6, 90394},
	{"ZBAN", 4, 90395},
	{"XONW", 4, 90396},
	{"RMGR", 4, 90397},
	{"MJAP", 4, 90398},
	{"KFLA", 4, 90399},
	{"IUSF", 4, 90400},
	{"IGDO", 4, 90401},
	{"AEXC", 4, 90402},
	{"SWEDES", 6, 90403},
	{"HEADLAND", 8, 90404},
	{"MULTILINK", 9, 90405},
	{"FUNCHAL", 7, 90406},
	{"XIMIAN", 6, 90407},
	{"BERGAMO", 7, 90408},
	{"QUARTERFINALS", 13, 90409},
	{"HOBBYIST", 8, 90410},
	{"REARDON", 7, 90411},
	{"AGITATOR", 8, 90412},
	{"UKOV", 4, 90413},
	{"NKYA", 4, 90414},
	{"KUPR", 4, 90415},
	{"CUEH", 4, 90416},
	{"GLYN", 4, 90417},
	{"POPSET", 6, 90418},
	{"TORSTEN", 7, 90419},
	{"UPVI", 4, 90420},
	{"UGIS", 4, 90421},
	{"PYWA", 4, 90422},
	{"LTYK", 4, 90423},
	{"HJOU", 4, 90424},
	{"ABUG", 4, 90425},
	{"UTENSIL", 7, 90426},
	{"PULLER", 6, 90427},
	{"MATHWORKS", 9, 90428},
	{"VOLK", 4, 90429},
	{"SHEBA", 5, 90430},
	{"NAMM", 4, 90431},
	{"GLOWS", 5, 90432},
	{"MDKSA", 5, 90433},
	{"XESC", 4, 90434},
	{"PELM", 4, 90435},
	{"ISKD", 4, 90436},
	{"HEIGHTEN", 8, 90437},
	{"DCOM", 4, 90438},
	{"DANSKIN", 7, 90439},
	{"XABL", 4, 90440},
	{"LRIE", 4, 90441},
	{"LFIF", 4, 90442},
	{"BEXAR", 5, 90443},
	{"SURPASSING", 10, 90444},
	{"DINNING", 7, 90445},
	{"PFD", 3, 90446},
	{"MISFIT", 6, 90447},
	{"HAMDEN", 6, 90448},
	{"UBSB", 4, 90449},
	{"RGAP", 4, 90450},
	{"LADLE", 5, 90451},
	{"HARDIE", 6, 90452},
	{"REDFIELD", 8, 90453},
	{"SCOTUS", 6, 90454},
	{"QUOTABLE", 8, 90455},
	{"CRANFIELD", 9, 90456},
	{"ASIDES", 6, 90457},
	{"BEACUSE", 7, 90458},
	{"AKOB", 4, 90459},
	{"ADPM", 4, 90460},
	{"MUSICSTRANDS", 12, 90461},
	{"PINKS", 5, 90462},
	{"RUSTED", 6, 90463},
	{"UNTERNEHMEN", 11, 90464},
	{"ROSELAND", 8, 90465},
	{"YCYC", 4, 90466},
	{"OGAD", 4, 90467},
	{"HSUF", 4, 90468},
	{"AMGI", 4, 90469},
	{"PGBUILDFARM", 11, 90470},
	{"VOLO", 4, 90471},
	{"ZIRCONIUM", 9, 90472},
	{"NOELLE", 6, 90473},
	{"HTTPWWW", 7, 90474},
	{"AGEMENT", 7, 90475},
	{"NATURALISTIC", 12, 90476},
	{"WHOQ", 4, 90477},
	{"NRIK", 4, 90478},
	{"LBCO", 4, 90479},
	{"KONJ", 4, 90480},
	{"DOGMATIC", 8, 90481},
	{"GUAN", 4, 90482},
	{"OPENCUBE", 8, 90483},
	{"TRISTRAM", 8, 90484},
	{"MEARS", 5, 90485},
	{"RECTIFICATION", 13, 90486},
	{"DUISBURG", 8, 90487},
	{"POWS", 4, 90488},
	{"HSPHERE", 7, 90489},
	{"ENTERTAI", 8, 90490},
	{"XFAC", 4, 90491},
	{"LMOB", 4, 90492},
	{"FTKN", 4, 90493},
	{"AXEX", 4, 90494},
	{"BALLON", 6, 90495},
	{"KEELER", 6, 90496},
	{"SURLY", 5, 90497},
	{"HIGHPOINT", 9, 90498},
	{"STRATOSPHERIC", 13, 90499},
	{"NEWEGG", 6, 90500},
	{"TJOR", 4, 90501},
	{"IMGU", 4, 90502},
	{"HBOD", 4, 90503},
	{"FHEG", 4, 90504},
	{"PREEMINENT", 10, 90505},
	{"PRESENTE", 8, 90506},
	{"NONPARAMETRIC", 13, 90507},
	{"FERTILIZED", 10, 90508},
	{"OAFL", 4, 90509},
	{"FFSL", 4, 90510},
	{"EKOM", 4, 90511},
	{"MISTRAL", 7, 90512},
	{"PERCOCET", 8, 90513},
	{"ZEROES", 6, 90514},
	{"ADMIRER", 7, 90515},
	{"DIVISOR", 7, 90516},
	{"WANDERLUST", 10, 90517},
	{"GIBT", 4, 90518},
	{"UGC", 3, 90519},
	{"CLEAT", 5, 90520},
	{"MOTIONED", 8, 90521},
	{"DECENTRALISATION", 16, 90522},
	{"FOPI", 4, 90523},
	{"CATASTROPHES", 12, 90524},
	{"VERNA", 5, 90525},
	{"THICKENED", 9, 90526},
	{"IMMEDIACY", 9, 90527},
	{"INDRA", 5, 90528},
	{"TRAK", 4, 90529},
	{"SWINGIN", 7, 90530},
	{"VEYR", 4, 90531},
	{"TPEL", 4, 90532},
	{"RTFL", 4, 90533},
	{"PEWR", 4, 90534},
	{"NYOL", 4, 90535},
	{"GOGE", 4, 90536},
	{"FOFO", 4, 90537},
	{"ELRU", 4, 90538},
	{"ECKERT", 6, 90539},
	{"CANDOR", 6, 90540},
	{"CASCO", 5, 90541},
	{"OLIVET", 6, 90542},
	{"BERGERON", 8, 90543},
	{"FELONIES", 8, 90544},
	{"GASIFICATION", 12, 90545},
	{"VIBRIO", 6, 90546},
	{"DSVA", 4, 90547},
	{"DDUB", 4, 90548},
	{"ANIMALE", 7, 90549},
	{"LEDA", 4, 90550},
	{"ARTESIA", 7, 90551},
	{"CASEBOOK", 8, 90552},
	{"YDHA", 4, 90553},
	{"YCAV", 4, 90554},
	{"IEQU", 4, 90555},
	{"AHBU", 4, 90556},
	{"GRUPPO", 6, 90557},
	{"FOTOKASTEN", 10, 90558},
	{"SABIN", 5, 90559},
	{"SEARING", 7, 90560},
	{"DETONATION", 10, 90561},
	{"WIGWAM", 6, 90562},
	{"APPROXIMATING", 13, 90563},
	{"HOLLINGSWORTH", 13, 90564},
	{"ANIMALES", 8, 90565},
	{"RRHO", 4, 90566},
	{"EKGO", 4, 90567},
	{"OBASANJO", 8, 90568},
	{"BEHEADED", 8, 90569},
	{"POSTMARK", 8, 90570},
	{"PINEWOOD", 8, 90571},
	{"TANGENTIAL", 10, 90572},
	{"RIDGWAY", 7, 90573},
	{"HEADHUNTER", 10, 90574},
	{"HELGA", 5, 90575},
	{"SHARKEY", 7, 90576},
	{"CLWYD", 5, 90577},
	{"YNMA", 4, 90578},
	{"RUPG", 4, 90579},
	{"FGOT", 4, 90580},
	{"DFUM", 4, 90581},
	{"BEREAVED", 8, 90582},
	{"BRETTON", 7, 90583},
	{"MALIN", 5, 90584},
	{"BUSTIER", 7, 90585},
	{"APOLOGIZES", 10, 90586},
	{"DRUGGED", 7, 90587},
	{"MANOJ", 5, 90588},
	{"MUSKOGEE", 8, 90589},
	{"IKEZ", 4, 90590},
	{"HTPU", 4, 90591},
	{"PISMO", 5, 90592},
	{"RESORTQUEST", 11, 90593},
	{"XUJ", 3, 90594},
	{"UGQ", 3, 90595},
	{"DISKEEPER", 9, 90596},
	{"LATHROP", 7, 90597},
	{"PTPR", 4, 90598},
	{"IXPL", 4, 90599},
	{"DKAY", 4, 90600},
	{"PALA", 4, 90601},
	{"GLEBE", 5, 90602},
	{"XTERRA", 6, 90603},
	{"PML", 3, 90604},
	{"SEAHORSE", 8, 90605},
	{"GENEVE", 6, 90606},
	{"MOTTE", 5, 90607},
	{"VOLGA", 5, 90608},
	{"WPOINTER", 8, 90609},
	{"SOFTENER", 8, 90610},
	{"BREACHING", 9, 90611},
	{"LFNO", 4, 90612},
	{"CKGU", 4, 90613},
	{"MAELSTROM", 9, 90614},
	{"RIVALRIES", 9, 90615},
	{"GNOMES", 6, 90616},
	{"WEBT", 4, 90617},
	{"PDOI", 4, 90618},
	{"PRIORITIZING", 12, 90619},
	{"DENNE", 5, 90620},
	{"AFFECTIONATELY", 14, 90621},
	{"ANNUNCI", 7, 90622},
	{"MODELOS", 7, 90623},
	{"SERAPHIM", 8, 90624},
	{"RAYMARINE", 9, 90625},
	{"DODGEBALL", 9, 90626},
	{"UNEDUCATED", 10, 90627},
	{"NECESSITATES", 12, 90628},
	{"MUNITY", 6, 90629},
	{"ALOPECIA", 8, 90630},
	{"SINGAPOREAN", 11, 90631},
	{"URIL", 4, 90632},
	{"ROPW", 4, 90633},
	{"NOWAK", 5, 90634},
	{"KEYBOARDING", 11, 90635},
	{"BEACHSIDE", 9, 90636},
	{"SPARCO", 6, 90637},
	{"ROBESON", 7, 90638},
	{"BLUNDERS", 8, 90639},
	{"NAVBAR", 6, 90640},
	{"NRIP", 4, 90641},
	{"MOWA", 4, 90642},
	{"KGEN", 4, 90643},
	{"FICJ", 4, 90644},
	{"DNOU", 4, 90645},
	{"PROPORTIONATELY", 15, 90646},
	{"CONTRIBS", 8, 90647},
	{"LINEAGES", 8, 90648},
	{"SUMITOMO", 8, 90649},
	{"DERMATOLOGISTS", 14, 90650},
	{"MARBLED", 7, 90651},
	{"WODR", 4, 90652},
	{"UBEW", 4, 90653},
	{"MCLU", 4, 90654},
	{"LOSW", 4, 90655},
	{"AWSB", 4, 90656},
	{"PROBLEME", 8, 90657},
	{"BLACKMORE", 9, 90658},
	{"BOTHERSOME", 10, 90659},
	{"COREA", 5, 90660},
	{"DRACONIAN", 9, 90661},
	{"TROUP", 5, 90662},
	{"UTTG", 4, 90663},
	{"MVOT", 4, 90664},
	{"LDSK", 4, 90665},
	{"CAFI", 4, 90666},
	{"APPROVER", 8, 90667},
	{"PCGS", 4, 90668},
	{"SAVILLE", 7, 90669},
	{"SRINIVASAN", 10, 90670},
	{"UPFE", 4, 90671},
	{"POLDEK", 6, 90672},
	{"PERFOR", 6, 90673},
	{"ARTICULAR", 9, 90674},
	{"GWYNN", 5, 90675},
	{"TRACKBALL", 9, 90676},
	{"MANSELL", 7, 90677},
	{"WEREWOLVES", 10, 90678},
	{"MAGAZIN", 7, 90679},
	{"SIBLE", 5, 90680},
	{"PORQUE", 6, 90681},
	{"AUTOCORRELATION", 15, 90682},
	{"WALTRIP", 7, 90683},
	{"MOMBASA", 7, 90684},
	{"SCHRODER", 8, 90685},
	{"ALACHUA", 7, 90686},
	{"MOCKED", 6, 90687},
	{"WDOI", 4, 90688},
	{"SPEP", 4, 90689},
	{"ORGW", 4, 90690},
	{"ONJR", 4, 90691},
	{"HOLLER", 6, 90692},
	{"DUNS", 4, 90693},
	{"ORNL", 4, 90694},
	{"CABRIO", 6, 90695},
	{"GUANINE", 7, 90696},
	{"BRIDGETOWN", 10, 90697},
	{"PPES", 4, 90698},
	{"FUTE", 4, 90699},
	{"LUKA", 4, 90700},
	{"CPF", 3, 90701},
	{"ROADSTAR", 8, 90702},
	{"CREDITCARD", 10, 90703},
	{"DARRIN", 6, 90704},
	{"FRF", 3, 90705},
	{"MICHAELA", 8, 90706},
	{"WILLETT", 7, 90707},
	{"BREWS", 5, 90708},
	{"CRUELLY", 7, 90709},
	{"BASKIN", 6, 90710},
	{"HAMEL", 5, 90711},
	{"TAPIOCA", 7, 90712},
	{"XTUA", 4, 90713},
	{"LCOX", 4, 90714},
	{"FOFB", 4, 90715},
	{"FURROW", 6, 90716},
	{"ZOIDS", 5, 90717},
	{"SEMANTICALLY", 12, 90718},
	{"CAGLIARI", 8, 90719},
	{"ULGO", 4, 90720},
	{"SRUG", 4, 90721},
	{"FEEP", 4, 90722},
	{"AWIC", 4, 90723},
	{"FEWEST", 6, 90724},
	{"EGGERT", 6, 90725},
	{"PARABLES", 8, 90726},
	{"VALKYRIE", 8, 90727},
	{"WPRA", 4, 90728},
	{"GVOC", 4, 90729},
	{"AIRLIE", 6, 90730},
	{"SALAS", 5, 90731},
	{"DROWSY", 6, 90732},
	{"GNOMEMEETING", 12, 90733},
	{"BENJI", 5, 90734},
	{"CASHEW", 6, 90735},
	{"UNPROVEN", 8, 90736},
	{"BUSHEL", 6, 90737},
	{"MYOCARDIUM", 10, 90738},
	{"XTPO", 4, 90739},
	{"IFMY", 4, 90740},
	{"PREK", 4, 90741},
	{"CYPHER", 6, 90742},
	{"PARAISO", 7, 90743},
	{"NIGHTLINE", 9, 90744},
	{"BEHOLDER", 8, 90745},
	{"CURSIVE", 7, 90746},
	{"ORGANISES", 9, 90747},
	{"LFTR", 4, 90748},
	{"GPUL", 4, 90749},
	{"EZIM", 4, 90750},
	{"AMJA", 4, 90751},
	{"HYDRATED", 8, 90752},
	{"SCHWANZ", 7, 90753},
	{"MARTINSBURG", 11, 90754},
	{"LIGURIA", 7, 90755},
	{"FORTIES", 7, 90756},
	{"PGC", 3, 90757},
	{"UMAF", 4, 90758},
	{"TTBU", 4, 90759},
	{"RDFU", 4, 90760},
	{"MYKN", 4, 90761},
	{"DUSM", 4, 90762},
	{"SEDITION", 8, 90763},
	{"SAYRE", 5, 90764},
	{"PHOTOSYNTHETIC", 14, 90765},
	{"UTOK", 4, 90766},
	{"ODPU", 4, 90767},
	{"KORM", 4, 90768},
	{"GAMY", 4, 90769},
	{"LUTHERANS", 9, 90770},
	{"EXAMEN", 6, 90771},
	{"PIPS", 4, 90772},
	{"TONGUED", 7, 90773},
	{"GHASTLY", 7, 90774},
	{"LIFETIPS", 8, 90775},
	{"WALCOTT", 7, 90776},
	{"VAUDEVILLE", 10, 90777},
	{"CNAME", 5, 90778},
	{"UNAPPROVED", 10, 90779},
	{"NEMATODES", 9, 90780},
	{"WSPL", 4, 90781},
	{"ROPD", 4, 90782},
	{"JACLYN", 6, 90783},
	{"KELL", 4, 90784},
	{"GREMLINS", 8, 90785},
	{"BOLERO", 6, 90786},
	{"TOGETHERS", 9, 90787},
	{"DICOM", 5, 90788},
	{"PAROXETINE", 10, 90789},
	{"VIVIEN", 6, 90790},
	{"GPR", 3, 90791},
	{"BRU", 3, 90792},
	{"QUEV", 4, 90793},
	{"PYEA", 4, 90794},
	{"FJEA", 4, 90795},
	{"EZAL", 4, 90796},
	{"DRHE", 4, 90797},
	{"LISHED", 6, 90798},
	{"TORTOLA", 7, 90799},
	{"CRITICISE", 9, 90800},
	{"POWERTRAIN", 10, 90801},
	{"TELKOM", 6, 90802},
	{"IMMUNIZED", 9, 90803},
	{"NUNEATON", 8, 90804},
	{"FICA", 4, 90805},
	{"YBEJ", 4, 90806},
	{"OZAM", 4, 90807},
	{"OBWE", 4, 90808},
	{"TRULIA", 6, 90809},
	{"RICOCHET", 8, 90810},
	{"KUROSAWA", 8, 90811},
	{"ABERRANT", 8, 90812},
	{"TOMK", 4, 90813},
	{"LUMT", 4, 90814},
	{"FAUC", 4, 90815},
	{"DPHE", 4, 90816},
	{"INQUISITIVE", 11, 90817},
	{"UKR", 3, 90818},
	{"WYANDOTTE", 9, 90819},
	{"ODPM", 4, 90820},
	{"PGK", 3, 90821},
	{"DUMBER", 6, 90822},
	{"RUPTURED", 8, 90823},
	{"INSOLES", 7, 90824},
	{"STARLET", 7, 90825},
	{"STYF", 4, 90826},
	{"OROY", 4, 90827},
	{"MHEM", 4, 90828},
	{"LSPH", 4, 90829},
	{"AKBU", 4, 90830},
	{"EARNER", 6, 90831},
	{"DOORWAYS", 8, 90832},
	{"RADIOLOGISTS", 12, 90833},
	{"POLYDOR", 7, 90834},
	{"NUTRACEUTICALS", 14, 90835},
	{"OVERRULED", 9, 90836},
	{"MENAGERIE", 9, 90837},
	{"OSGOOD", 6, 90838},
	{"MRSQ", 4, 90839},
	{"MAYY", 4, 90840},
	{"GTIP", 4, 90841},
	{"FULJ", 4, 90842},
	{"ZOOMED", 6, 90843},
	{"TEAMSTERS", 9, 90844},
	{"GROUPIE", 7, 90845},
	{"BRINKMANN", 9, 90846},
	{"SEUL", 4, 90847},
	{"THROMBIN", 8, 90848},
	{"LAMINAR", 7, 90849},
	{"FORKED", 6, 90850},
	{"OUDY", 4, 90851},
	{"CDRO", 4, 90852},
	{"IMMUNOGLOBULINS", 15, 90853},
	{"JAMNAGAR", 8, 90854},
	{"APPREHENSIVE", 12, 90855},
	{"COWARDS", 7, 90856},
	{"CAMBER", 6, 90857},
	{"CIELO", 5, 90858},
	{"FBOB", 4, 90859},
	{"ARLC", 4, 90860},
	{"COLLIERY", 8, 90861},
	{"INCUBATORS", 10, 90862},
	{"PROCIMAGEM", 10, 90863},
	{"SWEETIES", 8, 90864},
	{"LANDFALL", 8, 90865},
	{"YVUL", 4, 90866},
	{"SPIG", 4, 90867},
	{"NIFR", 4, 90868},
	{"KWED", 4, 90869},
	{"DCNN", 4, 90870},
	{"BAGW", 4, 90871},
	{"SEANAD", 6, 90872},
	{"COWL", 4, 90873},
	{"INTRAMURALS", 11, 90874},
	{"KWOK", 4, 90875},
	{"BORDERLESS", 10, 90876},
	{"CAPTORS", 7, 90877},
	{"TOKR", 4, 90878},
	{"BIPO", 4, 90879},
	{"METHYLTRANSFERASE", 17, 90880},
	{"SUWANNEE", 8, 90881},
	{"FILS", 4, 90882},
	{"LAITY", 5, 90883},
	{"CJD", 3, 90884},
	{"HYPERLINKED", 11, 90885},
	{"BIRKENHEAD", 10, 90886},
	{"TORREVIEJA", 10, 90887},
	{"PREFIXED", 8, 90888},
	{"SUMN", 4, 90889},
	{"NKAW", 4, 90890},
	{"ITZC", 4, 90891},
	{"CDOC", 4, 90892},
	{"PURPOSEFULLY", 12, 90893},
	{"GUTTED", 6, 90894},
	{"ARMING", 6, 90895},
	{"SERVEUR", 7, 90896},
	{"GRR", 3, 90897},
	{"MORRELL", 7, 90898},
	{"ZARS", 4, 90899},
	{"UMCI", 4, 90900},
	{"UDAR", 4, 90901},
	{"RTUB", 4, 90902},
	{"QUOP", 4, 90903},
	{"OLKO", 4, 90904},
	{"NMYN", 4, 90905},
	{"LSBL", 4, 90906},
	{"LBYR", 4, 90907},
	{"GONQ", 4, 90908},
	{"FRAB", 4, 90909},
	{"CWAY", 4, 90910},
	{"AMASSED", 7, 90911},
	{"ITINERANT", 9, 90912},
	{"OUACHITA", 8, 90913},
	{"IMRAN", 5, 90914},
	{"FREEWAYS", 8, 90915},
	{"MULTITHREADED", 13, 90916},
	{"NEWLYWEDS", 9, 90917},
	{"VINJ", 4, 90918},
	{"PCLU", 4, 90919},
	{"XIANG", 5, 90920},
	{"BURNIN", 6, 90921},
	{"REELECTION", 10, 90922},
	{"HALES", 5, 90923},
	{"RUTTER", 6, 90924},
	{"LKLA", 4, 90925},
	{"DUNM", 4, 90926},
	{"UUNET", 5, 90927},
	{"VITREOUS", 8, 90928},
	{"NOORD", 5, 90929},
	{"CENTRELINK", 10, 90930},
	{"LEMPICKA", 8, 90931},
	{"YDX", 3, 90932},
	{"PPZ", 3, 90933},
	{"JDY", 3, 90934},
	{"FGJ", 3, 90935},
	{"MUMR", 4, 90936},
	{"DRYO", 4, 90937},
	{"COUNTABLE", 9, 90938},
	{"DOLOMITE", 8, 90939},
	{"FELONS", 6, 90940},
	{"SALVAGED", 8, 90941},
	{"SOYUZ", 5, 90942},
	{"FRICK", 5, 90943},
	{"LWP", 3, 90944},
	{"SMBY", 4, 90945},
	{"ORNG", 4, 90946},
	{"LTYE", 4, 90947},
	{"IRLN", 4, 90948},
	{"AFTERGLOW", 9, 90949},
	{"FERENT", 6, 90950},
	{"MANDI", 5, 90951},
	{"SECUNDERABAD", 12, 90952},
	{"DORMITORIES", 11, 90953},
	{"MILLWORK", 8, 90954},
	{"SAMPO", 5, 90955},
	{"TAKEDOWN", 8, 90956},
	{"COLOSTRUM", 9, 90957},
	{"URNN", 4, 90958},
	{"OLFL", 4, 90959},
	{"CFNM", 4, 90960},
	{"DEARTH", 6, 90961},
	{"JUDEO", 5, 90962},
	{"PALATABLE", 9, 90963},
	{"WISC", 4, 90964},
	{"UNMASKED", 8, 90965},
	{"HOMIES", 6, 90966},
	{"TARMAC", 6, 90967},
	{"CUSTOMISATION", 13, 90968},
	{"CONSERVATOR", 11, 90969},
	{"YOFQ", 4, 90970},
	{"SJAZ", 4, 90971},
	{"OPAF", 4, 90972},
	{"NSMY", 4, 90973},
	{"BSWO", 4, 90974},
	{"PIPETTES", 8, 90975},
	{"ARTEFACT", 8, 90976},
	{"EXPOSITORY", 10, 90977},
	{"COMPLEMENTARITY", 15, 90978},
	{"COSCO", 5, 90979},
	{"MERCOSUR", 8, 90980},
	{"INSTINCTIVE", 11, 90981},
	{"CORPO", 5, 90982},
	{"OXLI", 4, 90983},
	{"LOGB", 4, 90984},
	{"GHGU", 4, 90985},
	{"EZIP", 4, 90986},
	{"CDRU", 4, 90987},
	{"RESTLESSNESS", 12, 90988},
	{"BAPTISED", 8, 90989},
	{"BENZODIAZEPINES", 15, 90990},
	{"NETMASK", 7, 90991},
	{"STALLING", 8, 90992},
	{"WMAI", 4, 90993},
	{"KENV", 4, 90994},
	{"MOLNAR", 6, 90995},
	{"ALISO", 5, 90996},
	{"DECORS", 6, 90997},
	{"BURLESQUE", 9, 90998},
	{"OLDMAN", 6, 90999},
	{"RLDU", 4, 91000},
	{"HALG", 4, 91001},
	{"NUEVOS", 6, 91002},
	{"SOMTHING", 8, 91003},
	{"ZABASEARCH", 10, 91004},
	{"STEUBEN", 7, 91005},
	{"ODKI", 4, 91006},
	{"NRYF", 4, 91007},
	{"MEGH", 4, 91008},
	{"DRHY", 4, 91009},
	{"BAFR", 4, 91010},
	{"MINICOM", 7, 91011},
	{"REGAINING", 9, 91012},
	{"HAUSFRAU", 8, 91013},
	{"GOLDFIELDS", 10, 91014},
	{"RICKEY", 6, 91015},
	{"MINICHAMPS", 10, 91016},
	{"PERVERSION", 10, 91017},
	{"USAGI", 5, 91018},
	{"SWELLS", 6, 91019},
	{"ROTHMAN", 7, 91020},
	{"UGEG", 4, 91021},
	{"RUGL", 4, 91022},
	{"LLII", 4, 91023},
	{"EDYP", 4, 91024},
	{"SRIVASTAVA", 10, 91025},
	{"OEMIG", 5, 91026},
	{"BEEFY", 5, 91027},
	{"SUJET", 5, 91028},
	{"PICA", 4, 91029},
	{"PUCCI", 5, 91030},
	{"SKITS", 5, 91031},
	{"PGIV", 4, 91032},
	{"LPHU", 4, 91033},
	{"IEBL", 4, 91034},
	{"HLAC", 4, 91035},
	{"SHENYANG", 8, 91036},
	{"MUSSOLINI", 9, 91037},
	{"ACQUAINT", 8, 91038},
	{"KOOTENAY", 8, 91039},
	{"ETHNOLOGY", 9, 91040},
	{"DONOHUE", 7, 91041},
	{"CYC", 3, 91042},
	{"ALTRO", 5, 91043},
	{"CHILDERS", 8, 91044},
	{"HAVELOCK", 8, 91045},
	{"MAHJONGG", 8, 91046},
	{"IERJ", 4, 91047},
	{"DAVAO", 5, 91048},
	{"LENGTHENING", 11, 91049},
	{"TAJIK", 5, 91050},
	{"CODEMASTERS", 11, 91051},
	{"MYDD", 4, 91052},
	{"ROMULUS", 7, 91053},
	{"CHARADE", 7, 91054},
	{"ARNHEM", 6, 91055},
	{"ZEOR", 4, 91056},
	{"BOBBIN", 6, 91057},
	{"ISTUDY", 6, 91058},
	{"RUGRATS", 7, 91059},
	{"DANCEWEAR", 9, 91060},
	{"MECHANIZED", 10, 91061},
	{"SOMMERS", 7, 91062},
	{"JECT", 4, 91063},
	{"RINQ", 4, 91064},
	{"OLGO", 4, 91065},
	{"LIEJ", 4, 91066},
	{"KBOR", 4, 91067},
	{"EKYO", 4, 91068},
	{"DEXR", 4, 91069},
	{"AWLO", 4, 91070},
	{"MAYES", 5, 91071},
	{"CANMORE", 7, 91072},
	{"REASSIGNED", 10, 91073},
	{"CREMA", 5, 91074},
	{"DOINGS", 6, 91075},
	{"BURSA", 5, 91076},
	{"FINANCIERS", 10, 91077},
	{"CFU", 3, 91078},
	{"FOOLISHNESS", 11, 91079},
	{"RUPC", 4, 91080},
	{"MULD", 4, 91081},
	{"DBOG", 4, 91082},
	{"RICCARDO", 8, 91083},
	{"REALVIDEO", 9, 91084},
	{"LITES", 5, 91085},
	{"KRALL", 5, 91086},
	{"CENTRIFUGATION", 14, 91087},
	{"WELDS", 5, 91088},
	{"UNEQUIVOCAL", 11, 91089},
	{"BRAUNSCHWEIG", 12, 91090},
	{"COPTIC", 6, 91091},
	{"SECURITYFOCUS", 13, 91092},
	{"REORGANISATION", 14, 91093},
	{"CONGLOMERATES", 13, 91094},
	{"TEWR", 4, 91095},
	{"PTIZ", 4, 91096},
	{"DEHUMIDIFIERS", 13, 91097},
	{"DUMPER", 6, 91098},
	{"HAMILL", 6, 91099},
	{"NOIRE", 5, 91100},
	{"HALSTON", 7, 91101},
	{"ARRIBA", 6, 91102},
	{"WFC", 3, 91103},
	{"NTLU", 4, 91104},
	{"DPUP", 4, 91105},
	{"DBYQ", 4, 91106},
	{"SPINY", 5, 91107},
	{"AREZZO", 6, 91108},
	{"MBEKI", 5, 91109},
	{"INVISIONFREE", 12, 91110},
	{"DROPKICK", 8, 91111},
	{"SILKEN", 6, 91112},
	{"ELASTOMER", 9, 91113},
	{"WAHOO", 5, 91114},
	{"ANAGRAM", 7, 91115},
	{"WFIS", 4, 91116},
	{"HFLY", 4, 91117},
	{"EKAD", 4, 91118},
	{"FOGDOG", 6, 91119},
	{"STRINGING", 9, 91120},
	{"FINNEGAN", 8, 91121},
	{"BAZAR", 5, 91122},
	{"NEWSWORTHY", 10, 91123},
	{"DEFS", 4, 91124},
	{"SENSITIZATION", 13, 91125},
	{"HYPERACTIVE", 11, 91126},
	{"RYNU", 4, 91127},
	{"MSPU", 4, 91128},
	{"IFFB", 4, 91129},
	{"EGSW", 4, 91130},
	{"DRUF", 4, 91131},
	{"THRUSTING", 9, 91132},
	{"PAVILIONS", 9, 91133},
	{"ANTENATAL", 9, 91134},
	{"ELEKTRO", 7, 91135},
	{"MADDY", 5, 91136},
	{"NORDSEE", 7, 91137},
	{"YUNA", 4, 91138},
	{"PLUGGABLE", 9, 91139},
	{"HEMOPHILIA", 10, 91140},
	{"KOLA", 4, 91141},
	{"REVITALIZING", 12, 91142},
	{"CLUNG", 5, 91143},
	{"SEEPAGE", 7, 91144},
	{"ALITALIA", 8, 91145},
	{"ORALE", 5, 91146},
	{"WCRI", 4, 91147},
	{"SMPR", 4, 91148},
	{"PANM", 4, 91149},
	{"NDCB", 4, 91150},
	{"CWAT", 4, 91151},
	{"AFID", 4, 91152},
	{"BCF", 3, 91153},
	{"WOOTEN", 6, 91154},
	{"NONVIOLENCE", 11, 91155},
	{"BAUME", 5, 91156},
	{"BERKMAN", 7, 91157},
	{"ASHDOWN", 7, 91158},
	{"YAPU", 4, 91159},
	{"UPOP", 4, 91160},
	{"DICIEMBRE", 9, 91161},
	{"PURPORTS", 8, 91162},
	{"FCUK", 4, 91163},
	{"SHILLONG", 8, 91164},
	{"MONDIAL", 7, 91165},
	{"BRUSHLESS", 9, 91166},
	{"TECHNICOLOR", 11, 91167},
	{"NARRAGANSETT", 12, 91168},
	{"NEEDLESSLY", 10, 91169},
	{"PANDAGON", 8, 91170},
	{"YATK", 4, 91171},
	{"VEJE", 4, 91172},
	{"MLAK", 4, 91173},
	{"JIMR", 4, 91174},
	{"GOFY", 4, 91175},
	{"DRYT", 4, 91176},
	{"REHABILITATED", 13, 91177},
	{"SQUATTING", 9, 91178},
	{"CORDIALLY", 9, 91179},
	{"WILKIE", 6, 91180},
	{"OUTDOORLIVING", 13, 91181},
	{"EXPENDABLE", 10, 91182},
	{"PONCA", 5, 91183},
	{"TIGARD", 6, 91184},
	{"YIFN", 4, 91185},
	{"SOULMATE", 8, 91186},
	{"KAINE", 5, 91187},
	{"MAXIS", 5, 91188},
	{"POPPERS", 7, 91189},
	{"ALLPOSTERS", 10, 91190},
	{"COMMERCIO", 9, 91191},
	{"DODS", 4, 91192},
	{"VOLUSIA", 7, 91193},
	{"SEYG", 4, 91194},
	{"RUTC", 4, 91195},
	{"FNUR", 4, 91196},
	{"SUPERSTITIONS", 13, 91197},
	{"ELIBRARY", 8, 91198},
	{"DATEBOOK", 8, 91199},
	{"SPANGLED", 8, 91200},
	{"ULTRASPARC", 10, 91201},
	{"SEABED", 6, 91202},
	{"XCHI", 4, 91203},
	{"WKER", 4, 91204},
	{"ULCR", 4, 91205},
	{"FDOO", 4, 91206},
	{"ORLY", 4, 91207},
	{"COMPLICATING", 12, 91208},
	{"SUZI", 4, 91209},
	{"TEXTURING", 9, 91210},
	{"PTYO", 4, 91211},
	{"ODMU", 4, 91212},
	{"MSEM", 4, 91213},
	{"KBLO", 4, 91214},
	{"CORRESPONDENCES", 15, 91215},
	{"GROOMSMEN", 9, 91216},
	{"RECTORY", 7, 91217},
	{"LATOUR", 6, 91218},
	{"WDRA", 4, 91219},
	{"USSB", 4, 91220},
	{"UNKF", 4, 91221},
	{"ALLI", 4, 91222},
	{"MANIPUR", 7, 91223},
	{"ARNETT", 6, 91224},
	{"SUZHOU", 6, 91225},
	{"MULTUM", 6, 91226},
	{"HEADBOARDS", 10, 91227},
	{"PALOMINO", 8, 91228},
	{"UANW", 4, 91229},
	{"KLUS", 4, 91230},
	{"HTMU", 4, 91231},
	{"ELOL", 4, 91232},
	{"CSBO", 4, 91233},
	{"POMERANIAN", 10, 91234},
	{"DIPTERA", 7, 91235},
	{"ILIAD", 5, 91236},
	{"GRAZE", 5, 91237},
	{"GERICOM", 7, 91238},
	{"LOOPED", 6, 91239},
	{"STEIFF", 6, 91240},
	{"CORDIS", 6, 91241},
	{"GPAG", 4, 91242},
	{"FPAG", 4, 91243},
	{"DBUM", 4, 91244},
	{"ERYTHROCYTE", 11, 91245},
	{"UNOBTRUSIVE", 11, 91246},
	{"MYELIN", 6, 91247},
	{"FRAGILITY", 9, 91248},
	{"DRUCKEN", 7, 91249},
	{"WOVO", 4, 91250},
	{"EDYR", 4, 91251},
	{"ALKP", 4, 91252},
	{"JUDEA", 5, 91253},
	{"TSUKUBA", 7, 91254},
	{"KUSTOM", 6, 91255},
	{"INVOICED", 8, 91256},
	{"HANNIGAN", 8, 91257},
	{"HANGUL", 6, 91258},
	{"LYSQ", 4, 91259},
	{"CURRANT", 7, 91260},
	{"MONTAUK", 7, 91261},
	{"MODULATORS", 10, 91262},
	{"IRVINGTON", 9, 91263},
	{"TSANG", 5, 91264},
	{"BROWNIAN", 8, 91265},
	{"YEBA", 4, 91266},
	{"USSK", 4, 91267},
	{"SKYF", 4, 91268},
	{"OLGE", 4, 91269},
	{"FLUV", 4, 91270},
	{"ETQU", 4, 91271},
	{"DYRI", 4, 91272},
	{"MOUSEPADS", 9, 91273},
	{"SAML", 4, 91274},
	{"ARCHIVISTS", 10, 91275},
	{"UNDERLIES", 9, 91276},
	{"INTRICACIES", 11, 91277},
	{"UERQ", 4, 91278},
	{"MARH", 4, 91279},
	{"IRJA", 4, 91280},
	{"HERRINGBONE", 11, 91281},
	{"BODOM", 5, 91282},
	{"HARRAHS", 7, 91283},
	{"AFOOT", 5, 91284},
	{"DAIWA", 5, 91285},
	{"ODDITY", 6, 91286},
	{"JUANES", 6, 91287},
	{"SRAW", 4, 91288},
	{"MOORCOCK", 8, 91289},
	{"GERRIT", 6, 91290},
	{"CCU", 3, 91291},
	{"CORNERED", 8, 91292},
	{"EYELINER", 8, 91293},
	{"TOTALLED", 8, 91294},
	{"AUSPICIOUS", 10, 91295},
	{"WOKEN", 5, 91296},
	{"SPLASHING", 9, 91297},
	{"YOAK", 4, 91298},
	{"YGOS", 4, 91299},
	{"TWAF", 4, 91300},
	{"LKIR", 4, 91301},
	{"GMCC", 4, 91302},
	{"GKEN", 4, 91303},
	{"APHIDS", 6, 91304},
	{"HOTLY", 5, 91305},
	{"CUTTHROAT", 9, 91306},
	{"RZX", 3, 91307},
	{"MQF", 3, 91308},
	{"FQP", 3, 91309},
	{"DGZ", 3, 91310},
	{"DCQ", 3, 91311},
	{"COINCIDENTAL", 12, 91312},
	{"LEPIDOPTERA", 11, 91313},
	{"PUFFED", 6, 91314},
	{"DISAPPROVED", 11, 91315},
	{"BUDA", 4, 91316},
	{"PIDD", 4, 91317},
	{"NNUL", 4, 91318},
	{"INTERLACED", 10, 91319},
	{"TARRYTOWN", 9, 91320},
	{"VASELINE", 8, 91321},
	{"BLUEWATER", 9, 91322},
	{"INSTALMENTS", 11, 91323},
	{"STRONTIUM", 9, 91324},
	{"PRESUMPTIVE", 11, 91325},
	{"BURDICK", 7, 91326},
	{"CRUSTAL", 7, 91327},
	{"HACKMAN", 7, 91328},
	{"RYIE", 4, 91329},
	{"LSEQ", 4, 91330},
	{"LOLD", 4, 91331},
	{"KNEL", 4, 91332},
	{"BOWO", 4, 91333},
	{"ASMF", 4, 91334},
	{"SHOPNBC", 7, 91335},
	{"AICPA", 5, 91336},
	{"PSAL", 4, 91337},
	{"COMPREHENSIBLE", 14, 91338},
	{"ALBICANS", 8, 91339},
	{"SEDUCES", 7, 91340},
	{"TEMPORE", 7, 91341},
	{"EPPS", 4, 91342},
	{"GSYM", 4, 91343},
	{"EWVA", 4, 91344},
	{"KROLL", 5, 91345},
	{"FALLACIES", 9, 91346},
	{"THEODOR", 7, 91347},
	{"UNAMBIGUOUSLY", 13, 91348},
	{"STALEY", 6, 91349},
	{"YLUS", 4, 91350},
	{"HLAD", 4, 91351},
	{"EKRU", 4, 91352},
	{"CUTBACKS", 8, 91353},
	{"SAWDUST", 7, 91354},
	{"HEMET", 5, 91355},
	{"ARIANA", 6, 91356},
	{"METAPHORICAL", 12, 91357},
	{"LEAPED", 6, 91358},
	{"ALERTNESS", 9, 91359},
	{"UVAN", 4, 91360},
	{"TMCD", 4, 91361},
	{"OKLO", 4, 91362},
	{"EMMU", 4, 91363},
	{"EMBERS", 6, 91364},
	{"CGMP", 4, 91365},
	{"MCAS", 4, 91366},
	{"MULTIMETER", 10, 91367},
	{"ASSEMBLAGES", 11, 91368},
	{"ANUBIS", 6, 91369},
	{"ANALYTE", 7, 91370},
	{"ESMM", 4, 91371},
	{"PESETA", 6, 91372},
	{"GLITZ", 5, 91373},
	{"KEWL", 4, 91374},
	{"SEARCHLIGHT", 11, 91375},
	{"BIDI", 4, 91376},
	{"WINSOCK", 7, 91377},
	{"SWINTON", 7, 91378},
	{"MOLDINGS", 8, 91379},
	{"PELTIER", 7, 91380},
	{"HYMO", 4, 91381},
	{"EPHM", 4, 91382},
	{"TRACKMANIA", 10, 91383},
	{"BALLETS", 7, 91384},
	{"DOYLESTOWN", 10, 91385},
	{"SPACEFLIGHT", 11, 91386},
	{"QUICKLIST", 9, 91387},
	{"PROPORTIONALITY", 15, 91388},
	{"OVERRUNS", 8, 91389},
	{"YADAV", 5, 91390},
	{"TMEX", 4, 91391},
	{"ROGG", 4, 91392},
	{"FIOW", 4, 91393},
	{"STAVE", 5, 91394},
	{"VERTU", 5, 91395},
	{"SORDID", 6, 91396},
	{"QPF", 3, 91397},
	{"MENTORSHIP", 10, 91398},
	{"LYX", 3, 91399},
	{"SNOWING", 7, 91400},
	{"TAINED", 6, 91401},
	{"VEAJ", 4, 91402},
	{"OLIGONUCLEOTIDES", 16, 91403},
	{"BBCI", 4, 91404},
	{"SPIDEY", 6, 91405},
	{"KORW", 4, 91406},
	{"EIJU", 4, 91407},
	{"DLUM", 4, 91408},
	{"VIDEOTAPED", 10, 91409},
	{"REGNOW", 6, 91410},
	{"BLEEDS", 6, 91411},
	{"JUKEBOXES", 9, 91412},
	{"VEYB", 4, 91413},
	{"EYSG", 4, 91414},
	{"EMPU", 4, 91415},
	{"XPDF", 4, 91416},
	{"PORTISHEAD", 10, 91417},
	{"SPLUNK", 6, 91418},
	{"KOMMENTARE", 10, 91419},
	{"CITYWIRE", 8, 91420},
	{"CRUD", 4, 91421},
	{"YSPH", 4, 91422},
	{"TVGU", 4, 91423},
	{"DGUS", 4, 91424},
	{"ABYH", 4, 91425},
	{"FEBS", 4, 91426},
	{"IUSR", 4, 91427},
	{"ANGX", 4, 91428},
	{"CANARIES", 8, 91429},
	{"RIBEIRO", 7, 91430},
	{"ABRAHAMSSON", 11, 91431},
	{"SEMBLANCE", 9, 91432},
	{"UMCL", 4, 91433},
	{"LBAY", 4, 91434},
	{"BOFC", 4, 91435},
	{"EPIDEMIOL", 9, 91436},
	{"COMS", 4, 91437},
	{"OUTRO", 5, 91438},
	{"PNEUMOCOCCAL", 12, 91439},
	{"TILTON", 6, 91440},
	{"IPAP", 4, 91441},
	{"HELR", 4, 91442},
	{"APYR", 4, 91443},
	{"BROOKSTONE", 10, 91444},
	{"APIC", 4, 91445},
	{"AVENGE", 6, 91446},
	{"ALLEVIATING", 11, 91447},
	{"SPORTIF", 7, 91448},
	{"INSERVICE", 9, 91449},
	{"YUNN", 4, 91450},
	{"RIPU", 4, 91451},
	{"LUDG", 4, 91452},
	{"CTGE", 4, 91453},
	{"BTOF", 4, 91454},
	{"PUNTS", 5, 91455},
	{"TIVES", 5, 91456},
	{"DAUGHERTY", 9, 91457},
	{"YARROW", 6, 91458},
	{"FICKLE", 6, 91459},
	{"WAKEUP", 6, 91460},
	{"OUTNUMBERED", 11, 91461},
	{"MEATLOAF", 8, 91462},
	{"RECHT", 5, 91463},
	{"MUMFORD", 7, 91464},
	{"DATAFILE", 8, 91465},
	{"BUCHEN", 6, 91466},
	{"KSAV", 4, 91467},
	{"KANC", 4, 91468},
	{"IFWH", 4, 91469},
	{"GHDU", 4, 91470},
	{"GFEW", 4, 91471},
	{"GEMY", 4, 91472},
	{"DOTC", 4, 91473},
	{"ZZZZ", 4, 91474},
	{"OBJECTCLASS", 11, 91475},
	{"POLICES", 7, 91476},
	{"DOGGING", 7, 91477},
	{"CURSUS", 6, 91478},
	{"PLASMINOGEN", 11, 91479},
	{"LUKEWARM", 8, 91480},
	{"WADM", 4, 91481},
	{"QUAI", 4, 91482},
	{"ROTUNDA", 7, 91483},
	{"KINSELLA", 8, 91484},
	{"LINDGREN", 8, 91485},
	{"ZUNE", 4, 91486},
	{"UEYO", 4, 91487},
	{"TPED", 4, 91488},
	{"SJOY", 4, 91489},
	{"GUNH", 4, 91490},
	{"ASYMPTOTICALLY", 14, 91491},
	{"DUCE", 4, 91492},
	{"OBSERVANCES", 11, 91493},
	{"WONDERWALL", 10, 91494},
	{"CRICK", 5, 91495},
	{"PVD", 3, 91496},
	{"ENVELOPED", 9, 91497},
	{"FAINTLY", 7, 91498},
	{"MNFRS", 5, 91499},
	{"CASEIRO", 7, 91500},
	{"EZVO", 4, 91501},
	{"CYSO", 4, 91502},
	{"INSTABILITIES", 13, 91503},
	{"MUSKOKA", 7, 91504},
	{"ROGN", 4, 91505},
	{"PISU", 4, 91506},
	{"OLMU", 4, 91507},
	{"ICSV", 4, 91508},
	{"DEGY", 4, 91509},
	{"INDISCRIMINATE", 14, 91510},
	{"THALIA", 6, 91511},
	{"ALPHONSE", 8, 91512},
	{"APAC", 4, 91513},
	{"REFORESTATION", 13, 91514},
	{"OWIP", 4, 91515},
	{"MUZZ", 4, 91516},
	{"AUVI", 4, 91517},
	{"AGWI", 4, 91518},
	{"AGGY", 4, 91519},
	{"PARADOXICALLY", 13, 91520},
	{"DREN", 4, 91521},
	{"DUBBO", 5, 91522},
	{"INDUCTORS", 9, 91523},
	{"SYMLINKS", 8, 91524},
	{"WBUD", 4, 91525},
	{"UMEB", 4, 91526},
	{"NGJR", 4, 91527},
	{"CAJU", 4, 91528},
	{"GAMESTRACKER", 12, 91529},
	{"SECAM", 5, 91530},
	{"GATORADE", 8, 91531},
	{"CAVA", 4, 91532},
	{"RUPP", 4, 91533},
	{"WACKER", 6, 91534},
	{"LANTA", 5, 91535},
	{"XHAL", 4, 91536},
	{"VWHO", 4, 91537},
	{"UTHY", 4, 91538},
	{"SFAD", 4, 91539},
	{"PGAN", 4, 91540},
	{"OOBY", 4, 91541},
	{"CRES", 4, 91542},
	{"OLIGO", 5, 91543},
	{"CHAIRPERSONS", 12, 91544},
	{"SPCA", 4, 91545},
	{"YUNH", 4, 91546},
	{"RSSY", 4, 91547},
	{"MIBE", 4, 91548},
	{"ECIG", 4, 91549},
	{"ZAPPER", 6, 91550},
	{"MATERIALIZED", 12, 91551},
	{"ACCOLADE", 8, 91552},
	{"MEMORIZED", 9, 91553},
	{"SQUIDOO", 7, 91554},
	{"RAISON", 6, 91555},
	{"INTERPRETATIVE", 14, 91556},
	{"EYEBALLS", 8, 91557},
	{"ROPING", 6, 91558},
	{"WEQU", 4, 91559},
	{"VYLE", 4, 91560},
	{"IKOR", 4, 91561},
	{"FATP", 4, 91562},
	{"RAUCH", 5, 91563},
	{"BARRICADES", 10, 91564},
	{"DEVOTING", 8, 91565},
	{"UCID", 4, 91566},
	{"SKWI", 4, 91567},
	{"ROXA", 4, 91568},
	{"OPGA", 4, 91569},
	{"NHUB", 4, 91570},
	{"DYEV", 4, 91571},
	{"BAYD", 4, 91572},
	{"OXYMORON", 8, 91573},
	{"RECIEVER", 8, 91574},
	{"MARYANN", 7, 91575},
	{"PENTAGRAM", 9, 91576},
	{"IDOLATRY", 8, 91577},
	{"INFUSIONS", 9, 91578},
	{"DECKED", 6, 91579},
	{"SLVR", 4, 91580},
	{"RTEG", 4, 91581},
	{"NYMS", 4, 91582},
	{"CHOPPY", 6, 91583},
	{"ROBOTECH", 8, 91584},
	{"SERVIC", 6, 91585},
	{"UNIVERISTY", 10, 91586},
	{"YDOH", 4, 91587},
	{"WTHC", 4, 91588},
	{"TDIP", 4, 91589},
	{"RKTA", 4, 91590},
	{"GELF", 4, 91591},
	{"ECTK", 4, 91592},
	{"CYWE", 4, 91593},
	{"CDRA", 4, 91594},
	{"AVIB", 4, 91595},
	{"INTROSPECTIVE", 13, 91596},
	{"BAHAMIAN", 8, 91597},
	{"FWY", 3, 91598},
	{"AGGRAVATION", 11, 91599},
	{"SEDGE", 5, 91600},
	{"NOCD", 4, 91601},
	{"STIPENDS", 8, 91602},
	{"STIRLINGSHIRE", 13, 91603},
	{"CAERPHILLY", 10, 91604},
	{"PINCHING", 8, 91605},
	{"RIBOFLAVIN", 10, 91606},
	{"FPOV", 4, 91607},
	{"CTJO", 4, 91608},
	{"KALB", 4, 91609},
	{"UBIQUITY", 8, 91610},
	{"VANDAL", 6, 91611},
	{"ROMPER", 6, 91612},
	{"PRETENDERS", 10, 91613},
	{"INFIDELS", 8, 91614},
	{"DWELLER", 7, 91615},
	{"NKAF", 4, 91616},
	{"MRIT", 4, 91617},
	{"LISV", 4, 91618},
	{"EMFE", 4, 91619},
	{"BITUMEN", 7, 91620},
	{"DIABOLIC", 8, 91621},
	{"SHIMIZU", 7, 91622},
	{"DEMONSTRABLE", 12, 91623},
	{"LETZTE", 6, 91624},
	{"OPDR", 4, 91625},
	{"NCEQ", 4, 91626},
	{"HHUR", 4, 91627},
	{"PRIESTESS", 9, 91628},
	{"POSTPOST", 8, 91629},
	{"RUMMY", 5, 91630},
	{"PALEO", 5, 91631},
	{"UNRHYW", 6, 91632},
	{"NIMROD", 6, 91633},
	{"HSPL", 4, 91634},
	{"ACTJ", 4, 91635},
	{"PINSCHER", 8, 91636},
	{"CONSTRUCTIVELY", 14, 91637},
	{"IRRITATE", 8, 91638},
	{"SUFJAN", 6, 91639},
	{"CHRISTIANE", 10, 91640},
	{"SIGUIENTE", 9, 91641},
	{"SPLICED", 7, 91642},
	{"FINCA", 5, 91643},
	{"GPF", 3, 91644},
	{"BRECON", 6, 91645},
	{"ZWL", 3, 91646},
	{"ZML", 3, 91647},
	{"XYJ", 3, 91648},
	{"WYY", 3, 91649},
	{"LXY", 3, 91650},
	{"CJV", 3, 91651},
	{"KIRAN", 5, 91652},
	{"TREKEARTH", 9, 91653},
	{"REPEATABILITY", 13, 91654},
	{"UDYM", 4, 91655},
	{"RNCU", 4, 91656},
	{"OKAG", 4, 91657},
	{"IXRU", 4, 91658},
	{"GUNNING", 7, 91659},
	{"BEARDS", 6, 91660},
	{"CHURCHYARD", 10, 91661},
	{"BYBLOS", 6, 91662},
	{"TADPOLE", 7, 91663},
	{"DESPICABLE", 10, 91664},
	{"CANTER", 6, 91665},
	{"MITSUI", 6, 91666},
	{"REMINISCENCES", 13, 91667},
	{"SDUA", 4, 91668},
	{"ODAK", 4, 91669},
	{"LVEL", 4, 91670},
	{"ILKY", 4, 91671},
	{"STORYTIME", 9, 91672},
	{"BERSERK", 7, 91673},
	{"WELLMAN", 7, 91674},
	{"CARDIOLOGIST", 12, 91675},
	{"JAMMIN", 6, 91676},
	{"HIRST", 5, 91677},
	{"UADC", 4, 91678},
	{"RRUT", 4, 91679},
	{"RCIL", 4, 91680},
	{"PTRY", 4, 91681},
	{"OGLY", 4, 91682},
	{"FEMB", 4, 91683},
	{"CYBA", 4, 91684},
	{"GGC", 3, 91685},
	{"RACY", 4, 91686},
	{"RLOB", 4, 91687},
	{"DZIL", 4, 91688},
	{"TERRAN", 6, 91689},
	{"STOOP", 5, 91690},
	{"BREADCRUMBS", 11, 91691},
	{"LORENA", 6, 91692},
	{"REMASTER", 8, 91693},
	{"RENDU", 5, 91694},
	{"CIFRADA", 7, 91695},
	{"CURVY", 5, 91696},
	{"ENVISAGE", 8, 91697},
	{"BONECA", 6, 91698},
	{"UPRU", 4, 91699},
	{"ALTC", 4, 91700},
	{"SHARPTON", 8, 91701},
	{"CRUCIALLY", 9, 91702},
	{"FACILE", 6, 91703},
	{"CHRISTIANA", 10, 91704},
	{"ANTONIN", 7, 91705},
	{"SOUNDGARDEN", 11, 91706},
	{"CARRARA", 7, 91707},
	{"BRON", 4, 91708},
	{"RBYV", 4, 91709},
	{"MACG", 4, 91710},
	{"KEAU", 4, 91711},
	{"COERCED", 7, 91712},
	{"DECOUPLING", 10, 91713},
	{"BILLETS", 7, 91714},
	{"MONROEVILLE", 11, 91715},
	{"ENVIRONMENTALIST", 16, 91716},
	{"GELH", 4, 91717},
	{"EASTENDERS", 10, 91718},
	{"ADULTFRIENDFINDER", 17, 91719},
	{"FPGAS", 5, 91720},
	{"UBEG", 4, 91721},
	{"TNUR", 4, 91722},
	{"NYKN", 4, 91723},
	{"DTUB", 4, 91724},
	{"ALKC", 4, 91725},
	{"SNEEZE", 6, 91726},
	{"DIGNITARIES", 11, 91727},
	{"MISTREATMENT", 12, 91728},
	{"RBL", 3, 91729},
	{"QLOGIC", 6, 91730},
	{"SUTCLIFFE", 9, 91731},
	{"SOMBER", 6, 91732},
	{"PREVIOUSPREVIOUS", 16, 91733},
	{"INFECTIVE", 9, 91734},
	{"ESTRELLA", 8, 91735},
	{"SHARDS", 6, 91736},
	{"VAJO", 4, 91737},
	{"ULUT", 4, 91738},
	{"TYAV", 4, 91739},
	{"RKAI", 4, 91740},
	{"RGEQ", 4, 91741},
	{"LIPM", 4, 91742},
	{"HPOU", 4, 91743},
	{"FMIR", 4, 91744},
	{"ASKP", 4, 91745},
	{"VCDS", 4, 91746},
	{"ACADIAN", 7, 91747},
	{"KAHULUI", 7, 91748},
	{"OVERGROWN", 9, 91749},
	{"PHONETICS", 9, 91750},
	{"STATESMEN", 9, 91751},
	{"COMITTMENT", 10, 91752},
	{"BLIX", 4, 91753},
	{"XWIF", 4, 91754},
	{"ULBI", 4, 91755},
	{"OORU", 4, 91756},
	{"MMEO", 4, 91757},
	{"EPHB", 4, 91758},
	{"ALDP", 4, 91759},
	{"AGUT", 4, 91760},
	{"BIOCOMPARE", 10, 91761},
	{"ADVICES", 7, 91762},
	{"WHIMSY", 6, 91763},
	{"COFFERS", 7, 91764},
	{"FRAMESET", 8, 91765},
	{"NYACK", 5, 91766},
	{"LOLO", 4, 91767},
	{"EMGR", 4, 91768},
	{"DCAI", 4, 91769},
	{"CARBOXYLIC", 10, 91770},
	{"SIKHS", 5, 91771},
	{"PKGCONFIG", 9, 91772},
	{"DIPARTIMENTO", 12, 91773},
	{"TRACEBACK", 9, 91774},
	{"SVLUG", 5, 91775},
	{"MICRODERMABRASION", 17, 91776},
	{"WATERBODY", 9, 91777},
	{"JEEPS", 5, 91778},
	{"AWRY", 4, 91779},
	{"YNOC", 4, 91780},
	{"RSOD", 4, 91781},
	{"KLYH", 4, 91782},
	{"BBAL", 4, 91783},
	{"CELT", 4, 91784},
	{"TIVERTON", 8, 91785},
	{"LODE", 4, 91786},
	{"WUNDEF", 6, 91787},
	{"SPAY", 4, 91788},
	{"WCLI", 4, 91789},
	{"SYBE", 4, 91790},
	{"KEDK", 4, 91791},
	{"HYAP", 4, 91792},
	{"GILMER", 6, 91793},
	{"CEQA", 4, 91794},
	{"BODOG", 5, 91795},
	{"FOLLOWUPS", 9, 91796},
	{"INTERNAT", 8, 91797},
	{"BIARRITZ", 8, 91798},
	{"GURPS", 5, 91799},
	{"BESSEMER", 8, 91800},
	{"ZORA", 4, 91801},
	{"RAGES", 5, 91802},
	{"ICEMAN", 6, 91803},
	{"CLUMPS", 6, 91804},
	{"PSPI", 4, 91805},
	{"NLAG", 4, 91806},
	{"HTUB", 4, 91807},
	{"PEGGED", 6, 91808},
	{"LIBERATOR", 9, 91809},
	{"REDISCOVER", 10, 91810},
	{"SUBORDINATION", 13, 91811},
	{"LOVECRAFT", 9, 91812},
	{"WAVEFRONT", 9, 91813},
	{"FICTIONS", 8, 91814},
	{"MSKY", 4, 91815},
	{"GDER", 4, 91816},
	{"DZIN", 4, 91817},
	{"BHANGRA", 7, 91818},
	{"DEPOSED", 7, 91819},
	{"ZUNI", 4, 91820},
	{"MENINGOCOCCAL", 13, 91821},
	{"KETONE", 6, 91822},
	{"GLAZER", 6, 91823},
	{"YASHICA", 7, 91824},
	{"TRENDING", 8, 91825},
	{"GEODESIC", 8, 91826},
	{"DISINTERESTED", 13, 91827},
	{"FORSAKE", 7, 91828},
	{"CONGRUENCE", 10, 91829},
	{"CONSPIRATORS", 12, 91830},
	{"FNOB", 4, 91831},
	{"SWINBURNE", 9, 91832},
	{"UNRESPONSIVE", 12, 91833},
	{"BABOON", 6, 91834},
	{"ROMANI", 6, 91835},
	{"TENKAICHI", 9, 91836},
	{"SWAMPED", 7, 91837},
	{"ENSUES", 6, 91838},
	{"OMANI", 5, 91839},
	{"TENUOUS", 7, 91840},
	{"REUTER", 6, 91841},
	{"HABLA", 5, 91842},
	{"RKYL", 4, 91843},
	{"OYEL", 4, 91844},
	{"FUSM", 4, 91845},
	{"BKHA", 4, 91846},
	{"SURFACTANTS", 11, 91847},
	{"EPICENTER", 9, 91848},
	{"DWF", 3, 91849},
	{"SANTAS", 6, 91850},
	{"KUTCHER", 7, 91851},
	{"CHRISTO", 7, 91852},
	{"ELATED", 6, 91853},
	{"LUCIO", 5, 91854},
	{"PHENOMENOLOGICAL", 16, 91855},
	{"GHEF", 4, 91856},
	{"DEBRIEFING", 10, 91857},
	{"MINISKIRTS", 10, 91858},
	{"BUTTERED", 8, 91859},
	{"ANSMANN", 7, 91860},
	{"MFPS", 4, 91861},
	{"LENTIL", 6, 91862},
	{"SANGRE", 6, 91863},
	{"KANNUR", 6, 91864},
	{"BACKER", 6, 91865},
	{"ALBEDO", 6, 91866},
	{"FLSA", 4, 91867},
	{"TYKN", 4, 91868},
	{"SDVD", 4, 91869},
	{"RCHJ", 4, 91870},
	{"LHAU", 4, 91871},
	{"HLYH", 4, 91872},
	{"FOXH", 4, 91873},
	{"PAULI", 5, 91874},
	{"MCEWEN", 6, 91875},
	{"DANNER", 6, 91876},
	{"ANGORA", 6, 91877},
	{"REDSTONE", 8, 91878},
	{"SELFE", 5, 91879},
	{"LXWXH", 5, 91880},
	{"STUFFY", 6, 91881},
	{"INFORMACION", 11, 91882},
	{"PHYTO", 5, 91883},
	{"WROL", 4, 91884},
	{"UEEV", 4, 91885},
	{"LOSD", 4, 91886},
	{"GBOL", 4, 91887},
	{"LIBPAM", 6, 91888},
	{"COCKY", 5, 91889},
	{"PITCHFORK", 9, 91890},
	{"STRATOCASTER", 12, 91891},
	{"EEKU", 4, 91892},
	{"CVIS", 4, 91893},
	{"AGSF", 4, 91894},
	{"DEPRESS", 7, 91895},
	{"MOHEGAN", 7, 91896},
	{"BRAZZAVILLE", 11, 91897},
	{"BROUSSARD", 9, 91898},
	{"ECCENTRICITY", 12, 91899},
	{"BEANO", 5, 91900},
	{"YLOB", 4, 91901},
	{"WCHU", 4, 91902},
	{"IEDK", 4, 91903},
	{"ENPM", 4, 91904},
	{"CCOW", 4, 91905},
	{"INTERCONNECTIONS", 16, 91906},
	{"WILLA", 5, 91907},
	{"TOILETRY", 8, 91908},
	{"BEKO", 4, 91909},
	{"TRANSGRESSION", 13, 91910},
	{"IDEALIZED", 9, 91911},
	{"CLINGS", 6, 91912},
	{"FLAMBOYANT", 10, 91913},
	{"MEMORIA", 7, 91914},
	{"EXCHANGEABLE", 12, 91915},
	{"COLM", 4, 91916},
	{"ARABE", 5, 91917},
	{"STRETCHY", 8, 91918},
	{"YPOE", 4, 91919},
	{"WORG", 4, 91920},
	{"UANB", 4, 91921},
	{"SUMT", 4, 91922},
	{"KROU", 4, 91923},
	{"COFM", 4, 91924},
	{"NACHRICHT", 9, 91925},
	{"STARBURST", 9, 91926},
	{"DZD", 3, 91927},
	{"NEUROLOGIST", 11, 91928},
	{"LEONARDS", 8, 91929},
	{"MACHT", 5, 91930},
	{"KITTIES", 7, 91931},
	{"CLERGYMAN", 9, 91932},
	{"UKTO", 4, 91933},
	{"DOTTIE", 6, 91934},
	{"SOCIALES", 8, 91935},
	{"RSPB", 4, 91936},
	{"SCAPE", 5, 91937},
	{"FWRITE", 6, 91938},
	{"HOMICIDES", 9, 91939},
	{"FRANCIA", 7, 91940},
	{"FORDE", 5, 91941},
	{"TRAVELPRO", 9, 91942},
	{"MRSB", 4, 91943},
	{"HBUD", 4, 91944},
	{"ENYC", 4, 91945},
	{"HAEMOPHILUS", 11, 91946},
	{"RONNY", 5, 91947},
	{"PLEDGING", 8, 91948},
	{"DEPENDANTS", 10, 91949},
	{"RECHTE", 6, 91950},
	{"HUBRIS", 6, 91951},
	{"BOTTOMLINE", 10, 91952},
	{"KOSOVA", 6, 91953},
	{"NMCL", 4, 91954},
	{"LYNW", 4, 91955},
	{"HOPD", 4, 91956},
	{"NEUROPSYCHOLOGICAL", 18, 91957},
	{"PUDDINGS", 8, 91958},
	{"PARTISANS", 9, 91959},
	{"GENITALIA", 9, 91960},
	{"MAUSOLEUM", 9, 91961},
	{"IDLER", 5, 91962},
	{"WAIVING", 7, 91963},
	{"SWIRLS", 6, 91964},
	{"DAMPERS", 7, 91965},
	{"COMHAIRLE", 9, 91966},
	{"DAWNED", 6, 91967},
	{"SFYT", 4, 91968},
	{"CHEECH", 6, 91969},
	{"EIGENVECTORS", 12, 91970},
	{"GENERALE", 8, 91971},
	{"EXTRAPOLATED", 12, 91972},
	{"CHAINING", 8, 91973},
	{"CARELESSLY", 10, 91974},
	{"NBCT", 4, 91975},
	{"FLTE", 4, 91976},
	{"AYKN", 4, 91977},
	{"DEFECTED", 8, 91978},
	{"YURASOV", 7, 91979},
	{"GAKKAI", 6, 91980},
	{"JUSTIA", 6, 91981},
	{"CAMPYLOBACTER", 13, 91982},
	{"NORTHUMBRIA", 11, 91983},
	{"SEIDEL", 6, 91984},
	{"KENSETH", 7, 91985},
	{"PMR", 3, 91986},
	{"KARE", 4, 91987},
	{"DUMBO", 5, 91988},
	{"HOLOCENE", 8, 91989},
	{"JWIN", 4, 91990},
	{"YICE", 4, 91991},
	{"URKH", 4, 91992},
	{"AGPI", 4, 91993},
	{"NARCISSUS", 9, 91994},
	{"CRUSOE", 6, 91995},
	{"SUPERCONDUCTORS", 15, 91996},
	{"YEUNG", 5, 91997},
	{"POLYGRAM", 8, 91998},
	{"DISTILLATE", 10, 91999},
	{"URKA", 4, 92000},
	{"LVAS", 4, 92001},
	{"EFFC", 4, 92002},
	{"DLOD", 4, 92003},
	{"EINFACH", 7, 92004},
	{"UNWEIGHTED", 10, 92005},
	{"GRAMM", 5, 92006},
	{"SKIMMING", 8, 92007},
	{"SAFECO", 6, 92008},
	{"BENTONVILLE", 11, 92009},
	{"SUPM", 4, 92010},
	{"MBEY", 4, 92011},
	{"LNEC", 4, 92012},
	{"IODU", 4, 92013},
	{"STOMACHS", 8, 92014},
	{"ISHIKAWA", 8, 92015},
	{"VUV", 3, 92016},
	{"STRACHAN", 8, 92017},
	{"BAYARD", 6, 92018},
	{"ESCALATOR", 9, 92019},
	{"PERIWINKLE", 10, 92020},
	{"RLAG", 4, 92021},
	{"NAMESAKE", 8, 92022},
	{"BREAKIN", 7, 92023},
	{"RSMO", 4, 92024},
	{"PUBLISHI", 8, 92025},
	{"DARMOWY", 7, 92026},
	{"OUTFILE", 7, 92027},
	{"CHOREOGRAPHED", 13, 92028},
	{"OBRAZKI", 7, 92029},
	{"WALC", 4, 92030},
	{"VGUI", 4, 92031},
	{"GAYR", 4, 92032},
	{"SLAPS", 5, 92033},
	{"ACCROSS", 7, 92034},
	{"XMX", 3, 92035},
	{"XBP", 3, 92036},
	{"PKZ", 3, 92037},
	{"LRX", 3, 92038},
	{"KUX", 3, 92039},
	{"DPQ", 3, 92040},
	{"GRAVESEND", 9, 92041},
	{"BOUCHERON", 9, 92042},
	{"FARROW", 6, 92043},
	{"OOFU", 4, 92044},
	{"HGLA", 4, 92045},
	{"ATKU", 4, 92046},
	{"ANNULMENT", 9, 92047},
	{"KWAI", 4, 92048},
	{"MAXIMILIAN", 10, 92049},
	{"TUBBS", 5, 92050},
	{"GRATUITY", 8, 92051},
	{"BARTOW", 6, 92052},
	{"TONBRIDGE", 9, 92053},
	{"REORGANIZE", 10, 92054},
	{"PANERAI", 7, 92055},
	{"SPATE", 5, 92056},
	{"FOOTHOLD", 8, 92057},
	{"BELLADONNA", 10, 92058},
	{"UFFF", 4, 92059},
	{"TDRY", 4, 92060},
	{"ROFQ", 4, 92061},
	{"OWSX", 4, 92062},
	{"MMYL", 4, 92063},
	{"MDRE", 4, 92064},
	{"KGAR", 4, 92065},
	{"IFWA", 4, 92066},
	{"GVAN", 4, 92067},
	{"ABOB", 4, 92068},
	{"LEXI", 4, 92069},
	{"REGGIO", 6, 92070},
	{"SOBERING", 8, 92071},
	{"CARCINOGENICITY", 15, 92072},
	{"DJF", 3, 92073},
	{"SEMIS", 5, 92074},
	{"PCV", 3, 92075},
	{"SUPPRESSORS", 11, 92076},
	{"OACU", 4, 92077},
	{"AUGS", 4, 92078},
	{"ARNC", 4, 92079},
	{"LEACHATE", 8, 92080},
	{"DINGLE", 6, 92081},
	{"MBENDI", 6, 92082},
	{"USTED", 5, 92083},
	{"CELINA", 6, 92084},
	{"MADGE", 5, 92085},
	{"GLEAM", 5, 92086},
	{"HYDROPONIC", 10, 92087},
	{"YITF", 4, 92088},
	{"YFUE", 4, 92089},
	{"TBIK", 4, 92090},
	{"ROYM", 4, 92091},
	{"FURC", 4, 92092},
	{"FHEP", 4, 92093},
	{"HOYER", 5, 92094},
	{"KOVACS", 6, 92095},
	{"RECALCULATE", 11, 92096},
	{"MBSW", 4, 92097},
	{"MALTREATMENT", 12, 92098},
	{"RUDYARD", 7, 92099},
	{"HITCHIN", 7, 92100},
	{"MEDTRONIC", 9, 92101},
	{"MEERUT", 6, 92102},
	{"WHSMITH", 7, 92103},
	{"FONTSIZE", 8, 92104},
	{"RELAXES", 7, 92105},
	{"SUPPOSITION", 11, 92106},
	{"YTIL", 4, 92107},
	{"YRIT", 4, 92108},
	{"HALOS", 5, 92109},
	{"CRACOW", 6, 92110},
	{"WEBCOMICS", 9, 92111},
	{"SAUDER", 6, 92112},
	{"DIOCESES", 8, 92113},
	{"ISKL", 4, 92114},
	{"BYEU", 4, 92115},
	{"SPRINKLING", 10, 92116},
	{"BESIEGED", 8, 92117},
	{"MALAISE", 7, 92118},
	{"POSTDOC", 7, 92119},
	{"BICEPS", 6, 92120},
	{"OMLU", 4, 92121},
	{"OEMU", 4, 92122},
	{"BNER", 4, 92123},
	{"LEELA", 5, 92124},
	{"HYDRANT", 7, 92125},
	{"HAMSTRING", 9, 92126},
	{"DARROW", 6, 92127},
	{"TINDERBOX", 9, 92128},
	{"SIFY", 4, 92129},
	{"GANGULY", 7, 92130},
	{"STREETWISE", 10, 92131},
	{"NEWBY", 5, 92132},
	{"HEBP", 4, 92133},
	{"IMPRINTING", 10, 92134},
	{"DANDENONG", 9, 92135},
	{"COLECOVISION", 12, 92136},
	{"GNUPLOT", 7, 92137},
	{"ROCOCO", 6, 92138},
	{"UBCH", 4, 92139},
	{"RAIK", 4, 92140},
	{"OFMM", 4, 92141},
	{"NUCLEATION", 10, 92142},
	{"WERBUNG", 7, 92143},
	{"PRB", 3, 92144},
	{"BLR", 3, 92145},
	{"CROCE", 5, 92146},
	{"BRABANT", 7, 92147},
	{"NRAB", 4, 92148},
	{"LFEV", 4, 92149},
	{"CBAL", 4, 92150},
	{"SUPERLATIVE", 11, 92151},
	{"DEVIANCE", 8, 92152},
	{"PRESSER", 7, 92153},
	{"GOLDFRAPP", 9, 92154},
	{"TETRAHEDRON", 11, 92155},
	{"YBAI", 4, 92156},
	{"GUPR", 4, 92157},
	{"GSCL", 4, 92158},
	{"ESKR", 4, 92159},
	{"AZZB", 4, 92160},
	{"MATERIALIZE", 11, 92161},
	{"HOMEWORLD", 9, 92162},
	{"FOODBORNE", 9, 92163},
	{"BAIXAR", 6, 92164},
	{"STAGG", 5, 92165},
	{"SRBI", 4, 92166},
	{"RAJP", 4, 92167},
	{"FFTA", 4, 92168},
	{"DABY", 4, 92169},
	{"AXBA", 4, 92170},
	{"FONDNESS", 8, 92171},
	{"ELLICOTT", 8, 92172},
	{"CHAMOIS", 7, 92173},
	{"MERCHANDISER", 12, 92174},
	{"PIUM", 4, 92175},
	{"DJIA", 4, 92176},
	{"EASTLEIGH", 9, 92177},
	{"BLACKLISTED", 11, 92178},
	{"FREETEXT", 8, 92179},
	{"WXHXD", 5, 92180},
	{"MULTIPLICATIVE", 14, 92181},
	{"METIS", 5, 92182},
	{"URETHRA", 7, 92183},
	{"DALRYMPLE", 9, 92184},
	{"ZMUS", 4, 92185},
	{"MNUS", 4, 92186},
	{"IDSY", 4, 92187},
	{"RETROACTIVELY", 13, 92188},
	{"HARTNETT", 8, 92189},
	{"SEARED", 6, 92190},
	{"GCD", 3, 92191},
	{"TINGED", 6, 92192},
	{"KILOS", 5, 92193},
	{"PROFESSORSHIP", 13, 92194},
	{"MULTIVITAMIN", 12, 92195},
	{"DIAMANT", 7, 92196},
	{"VIENTIANE", 9, 92197},
	{"TGOU", 4, 92198},
	{"CSQU", 4, 92199},
	{"AMYE", 4, 92200},
	{"KOJI", 4, 92201},
	{"SCRAN", 5, 92202},
	{"BWP", 3, 92203},
	{"EMOTICON", 8, 92204},
	{"LEEWARD", 7, 92205},
	{"MERCATOR", 8, 92206},
	{"FRUITLESS", 9, 92207},
	{"TAMER", 5, 92208},
	{"LYRICIST", 8, 92209},
	{"MACROMOLECULES", 14, 92210},
	{"FUNGICIDES", 10, 92211},
	{"ZIPC", 4, 92212},
	{"YAMP", 4, 92213},
	{"AMINES", 6, 92214},
	{"TICKLISH", 8, 92215},
	{"KARCHER", 7, 92216},
	{"FREETOWN", 8, 92217},
	{"ALIENATE", 8, 92218},
	{"FLYH", 4, 92219},
	{"BSLE", 4, 92220},
	{"BENEFICIALLY", 12, 92221},
	{"TUGRIK", 6, 92222},
	{"MONOTYPE", 8, 92223},
	{"KEMPINSKI", 9, 92224},
	{"PIGMENTED", 9, 92225},
	{"MIPSEL", 6, 92226},
	{"RIDERSHIP", 9, 92227},
	{"ATHENAEUM", 9, 92228},
	{"TWIKIWEB", 8, 92229},
	{"MPM", 3, 92230},
	{"FAKING", 6, 92231},
	{"TVMO", 4, 92232},
	{"QUAB", 4, 92233},
	{"DRAJ", 4, 92234},
	{"DDYE", 4, 92235},
	{"CLSID", 5, 92236},
	{"KENOBI", 6, 92237},
	{"DISPLEASURE", 11, 92238},
	{"ENDOPLASMIC", 11, 92239},
	{"CONNOISSEURS", 12, 92240},
	{"KMIS", 4, 92241},
	{"FTOY", 4, 92242},
	{"MOTORISED", 9, 92243},
	{"LOMAX", 5, 92244},
	{"GERALDTON", 9, 92245},
	{"MUTILATED", 9, 92246},
	{"KMED", 4, 92247},
	{"IZOP", 4, 92248},
	{"IPZI", 4, 92249},
	{"EZWI", 4, 92250},
	{"CSSRULE", 7, 92251},
	{"AUERBACH", 8, 92252},
	{"METLIFE", 7, 92253},
	{"APOCALYPTICA", 12, 92254},
	{"USEFULLY", 8, 92255},
	{"RISOTTO", 7, 92256},
	{"FOLLICLES", 9, 92257},
	{"TCHV", 4, 92258},
	{"IRMF", 4, 92259},
	{"DVIG", 4, 92260},
	{"ASHTABULA", 9, 92261},
	{"SUSSMAN", 7, 92262},
	{"INSTITUTING", 11, 92263},
	{"BALZAC", 6, 92264},
	{"EXMOUTH", 7, 92265},
	{"MELUA", 5, 92266},
	{"CVSS", 4, 92267},
	{"STIMULATORS", 11, 92268},
	{"OWTW", 4, 92269},
	{"MOFV", 4, 92270},
	{"GMUR", 4, 92271},
	{"UVIC", 4, 92272},
	{"MOYEN", 5, 92273},
	{"ASUSTEK", 7, 92274},
	{"DIETA", 5, 92275},
	{"FAMVIR", 6, 92276},
	{"THREEFOLD", 9, 92277},
	{"CONFLICTED", 10, 92278},
	{"RETIREMENTS", 11, 92279},
	{"SIXERS", 6, 92280},
	{"METAB", 5, 92281},
	{"SGUT", 4, 92282},
	{"QUOO", 4, 92283},
	{"GREGOIRE", 8, 92284},
	{"INNOCENTLY", 10, 92285},
	{"BURRIS", 6, 92286},
	{"DEEPENED", 8, 92287},
	{"CLEF", 4, 92288},
	{"CREAT", 5, 92289},
	{"RAJAN", 5, 92290},
	{"GEAV", 4, 92291},
	{"BRAINWASHED", 11, 92292},
	{"BERENSTAIN", 10, 92293},
	{"CRITTENDEN", 10, 92294},
	{"ANTONI", 6, 92295},
	{"ASSOCI", 6, 92296},
	{"YONY", 4, 92297},
	{"LYKA", 4, 92298},
	{"YANKOVIC", 8, 92299},
	{"GNVQ", 4, 92300},
	{"PURA", 4, 92301},
	{"ROGAINE", 7, 92302},
	{"GRIDLOCK", 8, 92303},
	{"INTEGRABLE", 10, 92304},
	{"REGARDER", 8, 92305},
	{"CHALKBOARD", 10, 92306},
	{"DOPOD", 5, 92307},
	{"BDEL", 4, 92308},
	{"AMGL", 4, 92309},
	{"UNRANKED", 8, 92310},
	{"KARLSSON", 8, 92311},
	{"ANAEMIA", 7, 92312},
	{"TRICE", 5, 92313},
	{"PRETENSE", 8, 92314},
	{"JUNGLES", 7, 92315},
	{"NATUR", 5, 92316},
	{"PERMIAN", 7, 92317},
	{"BARTLEY", 7, 92318},
	{"UNAFFILIATED", 12, 92319},
	{"SLRS", 4, 92320},
	{"IMITATING", 9, 92321},
	{"MONTREUX", 8, 92322},
	{"PARTICI", 7, 92323},
	{"WNCU", 4, 92324},
	{"RGOW", 4, 92325},
	{"MPSB", 4, 92326},
	{"LDYN", 4, 92327},
	{"HKEL", 4, 92328},
	{"GSPU", 4, 92329},
	{"ALDN", 4, 92330},
	{"STARBUCK", 8, 92331},
	{"INFRACTIONS", 11, 92332},
	{"KARON", 5, 92333},
	{"SHREDS", 6, 92334},
	{"TREVISO", 7, 92335},
	{"IDUP", 4, 92336},
	{"HLAY", 4, 92337},
	{"FJAI", 4, 92338},
	{"EYOB", 4, 92339},
	{"DOGL", 4, 92340},
	{"BACKDROPS", 9, 92341},
	{"TURKMEN", 7, 92342},
	{"STANDUPS", 8, 92343},
	{"SOWELL", 6, 92344},
	{"AKTUELLE", 8, 92345},
	{"GLEESON", 7, 92346},
	{"VULC", 4, 92347},
	{"TSUZ", 4, 92348},
	{"EPCI", 4, 92349},
	{"GLOBULIN", 8, 92350},
	{"PETITIONED", 10, 92351},
	{"MIDOB", 5, 92352},
	{"VIOLATOR", 8, 92353},
	{"BOXCAR", 6, 92354},
	{"SAGAN", 5, 92355},
	{"AVISO", 5, 92356},
	{"POUNDER", 7, 92357},
	{"WTRU", 4, 92358},
	{"RRYY", 4, 92359},
	{"IEUR", 4, 92360},
	{"FWID", 4, 92361},
	{"VIEIRA", 6, 92362},
	{"KRONOR", 6, 92363},
	{"ARCHWAY", 7, 92364},
	{"TOCOPHEROL", 10, 92365},
	{"KEIKO", 5, 92366},
	{"NEWSRX", 6, 92367},
	{"PHARMACOKINETIC", 15, 92368},
	{"INTERCEPTS", 10, 92369},
	{"TIRELESSLY", 10, 92370},
	{"WQUE", 4, 92371},
	{"GHYE", 4, 92372},
	{"EFSU", 4, 92373},
	{"DYAH", 4, 92374},
	{"ADSORBED", 8, 92375},
	{"PLUNKETT", 8, 92376},
	{"GUENTHER", 8, 92377},
	{"PENTA", 5, 92378},
	{"PHOSPHOLIPID", 12, 92379},
	{"REITERATES", 10, 92380},
	{"WUC", 3, 92381},
	{"ULYU", 4, 92382},
	{"RMDO", 4, 92383},
	{"OORV", 4, 92384},
	{"LCOC", 4, 92385},
	{"EYVA", 4, 92386},
	{"OVERSAW", 7, 92387},
	{"DANSE", 5, 92388},
	{"LOUDEST", 7, 92389},
	{"ARRAYLIST", 9, 92390},
	{"ULTIMATUM", 9, 92391},
	{"OUTSOURCER", 10, 92392},
	{"EYESHADOW", 9, 92393},
	{"XXJ", 3, 92394},
	{"XVU", 3, 92395},
	{"WDQ", 3, 92396},
	{"QLQ", 3, 92397},
	{"PKJ", 3, 92398},
	{"MXK", 3, 92399},
	{"KLZ", 3, 92400},
	{"JYR", 3, 92401},
	{"GQF", 3, 92402},
	{"SHUFFLED", 8, 92403},
	{"PSAW", 4, 92404},
	{"LWEW", 4, 92405},
	{"KGIV", 4, 92406},
	{"GOCU", 4, 92407},
	{"EDRH", 4, 92408},
	{"PUSHBUTTON", 10, 92409},
	{"DOUJINSHI", 9, 92410},
	{"CATAGORIES", 10, 92411},
	{"SHELLING", 8, 92412},
	{"VISITA", 6, 92413},
	{"PILAR", 5, 92414},
	{"ZEITUNG", 7, 92415},
	{"OBSERVANT", 9, 92416},
	{"YQUO", 4, 92417},
	{"SEMM", 4, 92418},
	{"RGAD", 4, 92419},
	{"LGIF", 4, 92420},
	{"FMYA", 4, 92421},
	{"FKHA", 4, 92422},
	{"PALTZ", 5, 92423},
	{"UNHAPPINESS", 11, 92424},
	{"CINDER", 6, 92425},
	{"VIADUCT", 7, 92426},
	{"PUGSTER", 7, 92427},
	{"ELASTOMERS", 10, 92428},
	{"PELT", 4, 92429},
	{"LAURELS", 7, 92430},
	{"GEMB", 4, 92431},
	{"EPBY", 4, 92432},
	{"EBDE", 4, 92433},
	{"CHSB", 4, 92434},
	{"EVENFLO", 7, 92435},
	{"MMK", 3, 92436},
	{"METHODICAL", 10, 92437},
	{"WADI", 4, 92438},
	{"SECULARISM", 10, 92439},
	{"ENGULFED", 8, 92440},
	{"ZYNS", 4, 92441},
	{"UNDZ", 4, 92442},
	{"RWET", 4, 92443},
	{"OMBB", 4, 92444},
	{"KAYT", 4, 92445},
	{"GROE", 4, 92446},
	{"BEQUESTS", 8, 92447},
	{"CELLSPACING", 11, 92448},
	{"TREKKER", 7, 92449},
	{"LLM", 3, 92450},
	{"MONOTONOUS", 10, 92451},
	{"PAKISTANIS", 10, 92452},
	{"GLYPHS", 6, 92453},
	{"NEUROBLASTOMA", 13, 92454},
	{"WDSA", 4, 92455},
	{"IRKL", 4, 92456},
	{"IMSD", 4, 92457},
	{"LOFTUS", 6, 92458},
	{"GIGLI", 5, 92459},
	{"THORP", 5, 92460},
	{"SEELEY", 6, 92461},
	{"PRODUCTEN", 9, 92462},
	{"GLANDULAR", 9, 92463},
	{"PYTHAGORAS", 10, 92464},
	{"ALIGNS", 6, 92465},
	{"REJUVENATE", 10, 92466},
	{"NORTHANTS", 9, 92467},
	{"OPERATIC", 8, 92468},
	{"IFCONFIG", 8, 92469},
	{"RVEU", 4, 92470},
	{"ERUC", 4, 92471},
	{"BDEM", 4, 92472},
	{"MALEVOLENT", 10, 92473},
	{"LESSENED", 8, 92474},
	{"STILE", 5, 92475},
	{"SHERRILL", 8, 92476},
	{"RECITING", 8, 92477},
	{"WINTASKS", 8, 92478},
	{"MTWI", 4, 92479},
	{"FGUE", 4, 92480},
	{"EXQU", 4, 92481},
	{"XENIA", 5, 92482},
	{"WHANGAREI", 9, 92483},
	{"EXPRES", 6, 92484},
	{"NADIR", 5, 92485},
	{"RECOUP", 6, 92486},
	{"FYR", 3, 92487},
	{"FRANCHISED", 10, 92488},
	{"BATCHELOR", 9, 92489},
	{"RELOCATABLE", 11, 92490},
	{"USNU", 4, 92491},
	{"RYSG", 4, 92492},
	{"LUMW", 4, 92493},
	{"KSDR", 4, 92494},
	{"NAUGHT", 6, 92495},
	{"WARHEAD", 7, 92496},
	{"BACKFILL", 8, 92497},
	{"FASCISTS", 8, 92498},
	{"KEDAR", 5, 92499},
	{"ADJACENCY", 9, 92500},
	{"ANTAGONISM", 10, 92501},
	{"RLEB", 4, 92502},
	{"IORU", 4, 92503},
	{"EFFW", 4, 92504},
	{"PRISMS", 6, 92505},
	{"IBEROSTAR", 9, 92506},
	{"DEBBY", 5, 92507},
	{"MANCHA", 6, 92508},
	{"GORTON", 6, 92509},
	{"CELLPADDING", 11, 92510},
	{"XTWI", 4, 92511},
	{"WMOB", 4, 92512},
	{"UCCO", 4, 92513},
	{"UBEF", 4, 92514},
	{"RTVS", 4, 92515},
	{"LSOY", 4, 92516},
	{"DWAD", 4, 92517},
	{"DPIG", 4, 92518},
	{"COINAGE", 7, 92519},
	{"LARNACA", 7, 92520},
	{"CARMARTHEN", 10, 92521},
	{"ENDGAME", 7, 92522},
	{"STREAMLIGHT", 11, 92523},
	{"ULIP", 4, 92524},
	{"MKEE", 4, 92525},
	{"GURG", 4, 92526},
	{"GOLAN", 5, 92527},
	{"UNPRODUCTIVE", 12, 92528},
	{"THOMANN", 7, 92529},
	{"BANQUETING", 10, 92530},
	{"TOTTEN", 6, 92531},
	{"CURBSIDE", 8, 92532},
	{"SAMHSA", 6, 92533},
	{"HOWRAH", 6, 92534},
	{"RYJE", 4, 92535},
	{"KMAC", 4, 92536},
	{"PLANER", 6, 92537},
	{"HERMAPHRODITE", 13, 92538},
	{"GAVEL", 5, 92539},
	{"BASSINETS", 9, 92540},
	{"FOOTJOY", 7, 92541},
	{"NEFARIOUS", 9, 92542},
	{"FAIRTRADE", 9, 92543},
	{"PRESTWICK", 9, 92544},
	{"PAOLI", 5, 92545},
	{"RERM", 4, 92546},
	{"AGAC", 4, 92547},
	{"STOPPAGE", 8, 92548},
	{"DEFRAY", 6, 92549},
	{"ALBEN", 5, 92550},
	{"LACONIA", 7, 92551},
	{"BERKOWITZ", 9, 92552},
	{"INPUTTING", 9, 92553},
	{"UGOA", 4, 92554},
	{"OROK", 4, 92555},
	{"DIMMING", 7, 92556},
	{"ENDANGERING", 11, 92557},
	{"ZEALOTS", 7, 92558},
	{"INDIATIMES", 10, 92559},
	{"WEIGHTY", 7, 92560},
	{"ARCGIS", 6, 92561},
	{"VYTH", 4, 92562},
	{"OXFA", 4, 92563},
	{"ORTZ", 4, 92564},
	{"OMWR", 4, 92565},
	{"MMEX", 4, 92566},
	{"IPID", 4, 92567},
	{"CDEA", 4, 92568},
	{"BROG", 4, 92569},
	{"GOOF", 4, 92570},
	{"LANDMINE", 8, 92571},
	{"OEUVRE", 6, 92572},
	{"SUBSIDED", 8, 92573},
	{"BORACAY", 7, 92574},
	{"APPRO", 5, 92575},
	{"UFAN", 4, 92576},
	{"OLYB", 4, 92577},
	{"OBTR", 4, 92578},
	{"NAMY", 4, 92579},
	{"KOFK", 4, 92580},
	{"GHFU", 4, 92581},
	{"DBIC", 4, 92582},
	{"SAHIB", 5, 92583},
	{"NOTIFIER", 8, 92584},
	{"WIRTH", 5, 92585},
	{"GASPING", 7, 92586},
	{"VALERIAN", 8, 92587},
	{"IDIOCY", 6, 92588},
	{"BUCHER", 6, 92589},
	{"WPIT", 4, 92590},
	{"RKCR", 4, 92591},
	{"MYCE", 4, 92592},
	{"KYSH", 4, 92593},
	{"IUMN", 4, 92594},
	{"ANPM", 4, 92595},
	{"FRENZIED", 8, 92596},
	{"WEISZ", 5, 92597},
	{"POSTULATE", 9, 92598},
	{"ENROLLEE", 8, 92599},
	{"AUTHENTICATING", 14, 92600},
	{"WHEATLAND", 9, 92601},
	{"ZILDJIAN", 8, 92602},
	{"ZESP", 4, 92603},
	{"SHJU", 4, 92604},
	{"MBYH", 4, 92605},
	{"MBAG", 4, 92606},
	{"ERDT", 4, 92607},
	{"DCUN", 4, 92608},
	{"REVISOR", 7, 92609},
	{"SENOR", 5, 92610},
	{"FAAUTO", 6, 92611},
	{"TRESPASSING", 11, 92612},
	{"PROFS", 5, 92613},
	{"PHEONIX", 7, 92614},
	{"SEITZ", 5, 92615},
	{"XASM", 4, 92616},
	{"TOUD", 4, 92617},
	{"IACU", 4, 92618},
	{"ADMINISTRIVIA", 13, 92619},
	{"FOAMS", 5, 92620},
	{"ORBITALS", 8, 92621},
	{"HAMMERHEAD", 10, 92622},
	{"UEGI", 4, 92623},
	{"SUSG", 4, 92624},
	{"RPCO", 4, 92625},
	{"RKGA", 4, 92626},
	{"NUGL", 4, 92627},
	{"NLIL", 4, 92628},
	{"FTIC", 4, 92629},
	{"DUNU", 4, 92630},
	{"CHNU", 4, 92631},
	{"DOTCOM", 6, 92632},
	{"PENDENT", 7, 92633},
	{"KLEZMER", 7, 92634},
	{"PEEV", 4, 92635},
	{"ODCI", 4, 92636},
	{"CULV", 4, 92637},
	{"FOSGATE", 7, 92638},
	{"WALWORTH", 8, 92639},
	{"NIGUEL", 6, 92640},
	{"QUICKFIND", 9, 92641},
	{"ISAKMP", 6, 92642},
	{"EDIFICE", 7, 92643},
	{"FACIA", 5, 92644},
	{"VERMIN", 6, 92645},
	{"STALEMATE", 9, 92646},
	{"TTPR", 4, 92647},
	{"PUSP", 4, 92648},
	{"NCWH", 4, 92649},
	{"GUSF", 4, 92650},
	{"GFRU", 4, 92651},
	{"GESV", 4, 92652},
	{"DDYC", 4, 92653},
	{"CYEX", 4, 92654},
	{"MULTIMEDIACARD", 14, 92655},
	{"SMYD", 4, 92656},
	{"BSDE", 4, 92657},
	{"MOTRIN", 6, 92658},
	{"LOOSENING", 9, 92659},
	{"GLX", 3, 92660},
	{"CLASSIFIES", 10, 92661},
	{"ISCHIA", 6, 92662},
	{"MOHALI", 6, 92663},
	{"INCURS", 6, 92664},
	{"WADV", 4, 92665},
	{"VEOL", 4, 92666},
	{"AMSV", 4, 92667},
	{"FEIST", 5, 92668},
	{"DIALECTIC", 9, 92669},
	{"LDB", 3, 92670},
	{"NETZERO", 7, 92671},
	{"VOGU", 4, 92672},
	{"TUMW", 4, 92673},
	{"RAYG", 4, 92674},
	{"RATIONALIZATION", 15, 92675},
	{"BROKERING", 9, 92676},
	{"VIEWPORT", 8, 92677},
	{"UCIL", 4, 92678},
	{"UAWA", 4, 92679},
	{"MMYI", 4, 92680},
	{"HBED", 4, 92681},
	{"MASTERBATE", 10, 92682},
	{"TANTALIZING", 11, 92683},
	{"GENESEO", 7, 92684},
	{"GRAMMER", 7, 92685},
	{"RHINOCEROS", 10, 92686},
	{"GARANTIE", 8, 92687},
	{"XOFC", 4, 92688},
	{"RLAL", 4, 92689},
	{"GBYB", 4, 92690},
	{"ADJUTANT", 8, 92691},
	{"SANOFI", 6, 92692},
	{"MALIGNANCIES", 12, 92693},
	{"JPEGS", 5, 92694},
	{"SPITZ", 5, 92695},
	{"LIMASSOL", 8, 92696},
	{"LOBBIED", 7, 92697},
	{"WNPI", 4, 92698},
	{"MADB", 4, 92699},
	{"FSOP", 4, 92700},
	{"DOLB", 4, 92701},
	{"COWT", 4, 92702},
	{"SICKENING", 9, 92703},
	{"SPLAT", 5, 92704},
	{"NOSTRADAMUS", 11, 92705},
	{"PONDERED", 8, 92706},
	{"GALLIUM", 7, 92707},
	{"MOBB", 4, 92708},
	{"MANNERED", 8, 92709},
	{"DORADA", 6, 92710},
	{"WDRO", 4, 92711},
	{"SJAY", 4, 92712},
	{"RTJA", 4, 92713},
	{"NALIN", 5, 92714},
	{"SORBET", 6, 92715},
	{"LUNENBURG", 9, 92716},
	{"SNOWS", 5, 92717},
	{"STEEPER", 7, 92718},
	{"TDMA", 4, 92719},
	{"RANGOON", 7, 92720},
	{"DEPRIVING", 9, 92721},
	{"WARU", 4, 92722},
	{"CEPM", 4, 92723},
	{"BODYCARE", 8, 92724},
	{"JOBSEARCH", 9, 92725},
	{"STALWART", 8, 92726},
	{"SHARIA", 6, 92727},
	{"TOPIARY", 7, 92728},
	{"CATALOGED", 9, 92729},
	{"VERANDAH", 8, 92730},
	{"SCHREIBEN", 9, 92731},
	{"BUTTERY", 7, 92732},
	{"DEFORMITY", 9, 92733},
	{"UCIU", 4, 92734},
	{"KSRI", 4, 92735},
	{"CRONIES", 7, 92736},
	{"KIMBER", 6, 92737},
	{"EXTENDABLE", 10, 92738},
	{"AGER", 4, 92739},
	{"PELLA", 5, 92740},
	{"OPTOMETRIST", 11, 92741},
	{"UNDERVALUED", 11, 92742},
	{"BOGEY", 5, 92743},
	{"PIPETTE", 7, 92744},
	{"INVALIDITY", 10, 92745},
	{"COVERALLS", 9, 92746},
	{"SOUNDLY", 7, 92747},
	{"UVEL", 4, 92748},
	{"USOW", 4, 92749},
	{"EFWI", 4, 92750},
	{"BBYF", 4, 92751},
	{"STAYZ", 5, 92752},
	{"ISOLATOR", 8, 92753},
	{"WICKING", 7, 92754},
	{"DANK", 4, 92755},
	{"ZANY", 4, 92756},
	{"UMATILLA", 8, 92757},
	{"PINKERTON", 9, 92758},
	{"ULII", 4, 92759},
	{"SLLC", 4, 92760},
	{"NTUB", 4, 92761},
	{"MLAB", 4, 92762},
	{"LTSL", 4, 92763},
	{"IPEW", 4, 92764},
	{"IARF", 4, 92765},
	{"FUSB", 4, 92766},
	{"AUSTRAL", 7, 92767},
	{"CANVASES", 8, 92768},
	{"APPLAUDS", 8, 92769},
	{"WEAKENS", 7, 92770},
	{"INTERFEROMETER", 14, 92771},
	{"UYHE", 4, 92772},
	{"RMTE", 4, 92773},
	{"KKEE", 4, 92774},
	{"BARBICAN", 8, 92775},
	{"PAULUS", 6, 92776},
	{"EBCDIC", 6, 92777},
	{"REBS", 4, 92778},
	{"CERF", 4, 92779},
	{"POLITIK", 7, 92780},
	{"WVV", 3, 92781},
	{"WGV", 3, 92782},
	{"UKQ", 3, 92783},
	{"PMZ", 3, 92784},
	{"KZW", 3, 92785},
	{"KVV", 3, 92786},
	{"KGJ", 3, 92787},
	{"JXC", 3, 92788},
	{"GZB", 3, 92789},
	{"GXG", 3, 92790},
	{"CRIMINALLY", 10, 92791},
	{"MKV", 3, 92792},
	{"LARIAT", 6, 92793},
	{"PSYCHOPATHOLOGY", 15, 92794},
	{"LKR", 3, 92795},
	{"LEYTON", 6, 92796},
	{"CARTOONISTS", 11, 92797},
	{"NKYL", 4, 92798},
	{"LYMC", 4, 92799},
	{"IVYC", 4, 92800},
	{"HYBA", 4, 92801},
	{"GGSS", 4, 92802},
	{"FSTM", 4, 92803},
	{"BOWW", 4, 92804},
	{"APPELLEES", 9, 92805},
	{"INDIRA", 6, 92806},
	{"REDRAW", 6, 92807},
	{"PICTBRIDGE", 10, 92808},
	{"MAHESH", 6, 92809},
	{"PURSUANCE", 9, 92810},
	{"RKSV", 4, 92811},
	{"LYNT", 4, 92812},
	{"LFTE", 4, 92813},
	{"KSTY", 4, 92814},
	{"BENG", 4, 92815},
	{"NCAR", 4, 92816},
	{"SCAPEGOAT", 9, 92817},
	{"GORD", 4, 92818},
	{"NANOMETER", 9, 92819},
	{"FACELESS", 8, 92820},
	{"MOYERS", 6, 92821},
	{"OUIF", 4, 92822},
	{"KEJE", 4, 92823},
	{"IPAF", 4, 92824},
	{"EGAF", 4, 92825},
	{"DOAF", 4, 92826},
	{"BSDO", 4, 92827},
	{"OREGONIAN", 9, 92828},
	{"AFTERSHOCK", 10, 92829},
	{"LEGGETT", 7, 92830},
	{"RUEE", 4, 92831},
	{"RAFG", 4, 92832},
	{"NLUI", 4, 92833},
	{"LYUR", 4, 92834},
	{"WSDOT", 5, 92835},
	{"CLASSIQUE", 9, 92836},
	{"MENON", 5, 92837},
	{"SPIRO", 5, 92838},
	{"WHITEBOARDS", 11, 92839},
	{"ZLET", 4, 92840},
	{"WOGI", 4, 92841},
	{"NCOG", 4, 92842},
	{"LKOV", 4, 92843},
	{"HCAB", 4, 92844},
	{"STRATEGISTS", 11, 92845},
	{"HYDROTHERAPY", 12, 92846},
	{"MARIONETTE", 10, 92847},
	{"ANATHEMA", 8, 92848},
	{"ISLAY", 5, 92849},
	{"MYV", 3, 92850},
	{"TYPEOF", 6, 92851},
	{"NITTY", 5, 92852},
	{"SEGL", 4, 92853},
	{"NTMC", 4, 92854},
	{"DDB", 3, 92855},
	{"QUINTILE", 8, 92856},
	{"FREIGHTLINER", 12, 92857},
	{"MONKEES", 7, 92858},
	{"COMPTES", 7, 92859},
	{"UYWA", 4, 92860},
	{"OFIP", 4, 92861},
	{"EBTF", 4, 92862},
	{"LINDLEY", 7, 92863},
	{"DEHUMIDIFIER", 12, 92864},
	{"INDUSTRIALS", 11, 92865},
	{"BOUNCERS", 8, 92866},
	{"TRANSFERED", 10, 92867},
	{"MAGES", 5, 92868},
	{"DMB", 3, 92869},
	{"ROSEANNE", 8, 92870},
	{"SRER", 4, 92871},
	{"EPIM", 4, 92872},
	{"BELH", 4, 92873},
	{"TRIFLE", 6, 92874},
	{"TRIGRAPHS", 9, 92875},
	{"RMOP", 4, 92876},
	{"MTAR", 4, 92877},
	{"LSFL", 4, 92878},
	{"LBRU", 4, 92879},
	{"AZZM", 4, 92880},
	{"BETTIS", 6, 92881},
	{"FOREFATHERS", 11, 92882},
	{"CYBERLINK", 9, 92883},
	{"PIRAEUS", 7, 92884},
	{"BROWSABLE", 9, 92885},
	{"XXVI", 4, 92886},
	{"WORKHORSE", 9, 92887},
	{"TYNU", 4, 92888},
	{"GHCE", 4, 92889},
	{"EXBU", 4, 92890},
	{"DVOW", 4, 92891},
	{"DEZV", 4, 92892},
	{"CKCE", 4, 92893},
	{"ITERATED", 8, 92894},
	{"MCFLY", 5, 92895},
	{"KYD", 3, 92896},
	{"POOPING", 7, 92897},
	{"ERADICATED", 10, 92898},
	{"PREFERENTIALLY", 14, 92899},
	{"FRATERNITIES", 12, 92900},
	{"PTOV", 4, 92901},
	{"DIURETIC", 8, 92902},
	{"OCTUBRE", 7, 92903},
	{"CASTELL", 7, 92904},
	{"EMERG", 5, 92905},
	{"SAMPRAS", 7, 92906},
	{"GEPHARDT", 8, 92907},
	{"RMEB", 4, 92908},
	{"PZIG", 4, 92909},
	{"PURN", 4, 92910},
	{"LBUQ", 4, 92911},
	{"CKVO", 4, 92912},
	{"ZIMBABWEAN", 10, 92913},
	{"UNEXPIRED", 9, 92914},
	{"WESTMORLAND", 11, 92915},
	{"BISCOTTI", 8, 92916},
	{"MAVICA", 6, 92917},
	{"EVERYONES", 9, 92918},
	{"SHAIKH", 6, 92919},
	{"NAMPA", 5, 92920},
	{"SMCG", 4, 92921},
	{"PTEL", 4, 92922},
	{"LROT", 4, 92923},
	{"IODL", 4, 92924},
	{"FRAM", 4, 92925},
	{"YOUNGBLOOD", 10, 92926},
	{"PLANA", 5, 92927},
	{"REFRACTOR", 9, 92928},
	{"BOULDERING", 10, 92929},
	{"FLEMINGTON", 10, 92930},
	{"DYSPHAGIA", 9, 92931},
	{"INADMISSIBLE", 12, 92932},
	{"REDESIGNING", 11, 92933},
	{"MILKEN", 6, 92934},
	{"KIPA", 4, 92935},
	{"GELC", 4, 92936},
	{"BAPR", 4, 92937},
	{"XSEL", 4, 92938},
	{"ZOOPLANKTON", 11, 92939},
	{"STRASBURG", 9, 92940},
	{"YRUB", 4, 92941},
	{"TCYP", 4, 92942},
	{"LMTR", 4, 92943},
	{"IPOW", 4, 92944},
	{"IEPU", 4, 92945},
	{"GSJU", 4, 92946},
	{"CYTR", 4, 92947},
	{"PHILATELIC", 10, 92948},
	{"BERTHS", 6, 92949},
	{"MODULARITY", 10, 92950},
	{"INNOCUOUS", 9, 92951},
	{"PARKVIEW", 8, 92952},
	{"HEROINES", 8, 92953},
	{"RETAKE", 6, 92954},
	{"UNPACKED", 8, 92955},
	{"MARRONE", 7, 92956},
	{"WALLMOUNTING", 12, 92957},
	{"MARENGO", 7, 92958},
	{"FSIC", 4, 92959},
	{"GONZALO", 7, 92960},
	{"QUICHE", 6, 92961},
	{"EPOC", 4, 92962},
	{"RESALES", 7, 92963},
	{"CLENCHED", 8, 92964},
	{"MADURO", 6, 92965},
	{"MURRIETA", 8, 92966},
	{"FAIRPLAY", 8, 92967},
	{"DDP", 3, 92968},
	{"KSOC", 4, 92969},
	{"IALQ", 4, 92970},
	{"EDND", 4, 92971},
	{"DKAM", 4, 92972},
	{"DICP", 4, 92973},
	{"CYPL", 4, 92974},
	{"CKEM", 4, 92975},
	{"GROUPES", 7, 92976},
	{"EVAPORATE", 9, 92977},
	{"WOODINVILLE", 11, 92978},
	{"REGISTRO", 8, 92979},
	{"TRANSCRIBER", 11, 92980},
	{"MIDWINTER", 9, 92981},
	{"WNSY", 4, 92982},
	{"RORJ", 4, 92983},
	{"DIZA", 4, 92984},
	{"NOTARIZED", 9, 92985},
	{"NEOCONS", 7, 92986},
	{"FRANCHISOR", 10, 92987},
	{"COMPAGNIE", 9, 92988},
	{"BELLINI", 7, 92989},
	{"UNDOING", 7, 92990},
	{"DIAB", 4, 92991},
	{"VYING", 5, 92992},
	{"COMMUNES", 8, 92993},
	{"UGTE", 4, 92994},
	{"OUDN", 4, 92995},
	{"MPHY", 4, 92996},
	{"GNBE", 4, 92997},
	{"AUSW", 4, 92998},
	{"MOREHOUSE", 9, 92999},
	{"CASSAVA", 7, 93000},
	{"LAUPER", 6, 93001},
	{"BEDSPREADS", 10, 93002},
	{"POOCH", 5, 93003},
	{"MORPHISM", 8, 93004},
	{"GRIPPER", 7, 93005},
	{"TAVISTOCK", 9, 93006},
	{"DISAPPOINTMENTS", 15, 93007},
	{"GLACE", 5, 93008},
	{"NEGATED", 7, 93009},
	{"ELUK", 4, 93010},
	{"CTVA", 4, 93011},
	{"JAVABEANS", 9, 93012},
	{"NASHIK", 6, 93013},
	{"ATOMKI", 6, 93014},
	{"MUSICIANSHIP", 12, 93015},
	{"PUNS", 4, 93016},
	{"VIAGGI", 6, 93017},
	{"UNOB", 4, 93018},
	{"MUMF", 4, 93019},
	{"LGES", 4, 93020},
	{"CADY", 4, 93021},
	{"ADIOS", 5, 93022},
	{"PURVIEW", 7, 93023},
	{"BOSQUE", 6, 93024},
	{"DYFED", 5, 93025},
	{"DEVOURED", 8, 93026},
	{"BIOMATERIALS", 12, 93027},
	{"OVERPASS", 8, 93028},
	{"INWARDLY", 8, 93029},
	{"BERNERS", 7, 93030},
	{"GOALTENDER", 10, 93031},
	{"SPEEDOMETER", 11, 93032},
	{"UPOS", 4, 93033},
	{"PURV", 4, 93034},
	{"PAWH", 4, 93035},
	{"MGUE", 4, 93036},
	{"GBYI", 4, 93037},
	{"DIZI", 4, 93038},
	{"ADELINE", 7, 93039},
	{"MPAF", 4, 93040},
	{"SMOTHERED", 9, 93041},
	{"ULTRIUM", 7, 93042},
	{"CARTERET", 8, 93043},
	{"FATWA", 5, 93044},
	{"RATJ", 4, 93045},
	{"GHTQ", 4, 93046},
	{"AROG", 4, 93047},
	{"EULOGY", 6, 93048},
	{"BOTTOMED", 8, 93049},
	{"SUPERSCRIPT", 11, 93050},
	{"RWANDAN", 7, 93051},
	{"PROTEINASE", 10, 93052},
	{"WBAT", 4, 93053},
	{"MIXW", 4, 93054},
	{"EDKR", 4, 93055},
	{"ACYD", 4, 93056},
	{"COOLERMASTER", 12, 93057},
	{"MACA", 4, 93058},
	{"LOND", 4, 93059},
	{"FORSYTHE", 8, 93060},
	{"PERNICIOUS", 10, 93061},
	{"HAIRCUTS", 8, 93062},
	{"CREWNECK", 8, 93063},
	{"FENSTER", 7, 93064},
	{"UVEH", 4, 93065},
	{"EKBY", 4, 93066},
	{"DISCRIMINANT", 12, 93067},
	{"BAYFIELD", 8, 93068},
	{"CONTINUA", 8, 93069},
	{"MISHRA", 6, 93070},
	{"MOREY", 5, 93071},
	{"BABBITT", 7, 93072},
	{"REIMS", 5, 93073},
	{"SCRIMMAGE", 9, 93074},
	{"RIDP", 4, 93075},
	{"CISF", 4, 93076},
	{"MULTIPLEXERS", 12, 93077},
	{"PCGA", 4, 93078},
	{"STADE", 5, 93079},
	{"PRIVATES", 8, 93080},
	{"WHIMS", 5, 93081},
	{"CARNIVORE", 9, 93082},
	{"CODINGSEQUENCE", 14, 93083},
	{"KNOWLEDGEALERT", 14, 93084},
	{"EGALITARIAN", 11, 93085},
	{"POMBE", 5, 93086},
	{"YAMATO", 6, 93087},
	{"JENSON", 6, 93088},
	{"KEEG", 4, 93089},
	{"HLYL", 4, 93090},
	{"MORTGAGEE", 9, 93091},
	{"SKIRMISH", 8, 93092},
	{"MIDDLEFIELD", 11, 93093},
	{"IIYAMA", 6, 93094},
	{"SCHELL", 6, 93095},
	{"MIDLER", 6, 93096},
	{"YACU", 4, 93097},
	{"VYOF", 4, 93098},
	{"DYGI", 4, 93099},
	{"CPOR", 4, 93100},
	{"CAPLAN", 6, 93101},
	{"ANYPLACE", 8, 93102},
	{"HARIDWAR", 8, 93103},
	{"STERNBERG", 9, 93104},
	{"VENTILATING", 11, 93105},
	{"RETREATING", 10, 93106},
	{"SHOPSAFE", 8, 93107},
	{"MOHAVE", 6, 93108},
	{"NONSENSICAL", 11, 93109},
	{"BRION", 5, 93110},
	{"GALLOWS", 7, 93111},
	{"IMMUN", 5, 93112},
	{"ZAPF", 4, 93113},
	{"RHEUMATISM", 10, 93114},
	{"MTOY", 4, 93115},
	{"DEVOTEE", 7, 93116},
	{"NIEUW", 5, 93117},
	{"COWARDICE", 9, 93118},
	{"FABLED", 6, 93119},
	{"MINGUS", 6, 93120},
	{"PROLLY", 6, 93121},
	{"TRICHY", 6, 93122},
	{"MICROFORM", 9, 93123},
	{"FANGS", 5, 93124},
	{"OLSSON", 6, 93125},
	{"ANIMOSITY", 9, 93126},
	{"JDC", 3, 93127},
	{"DOSIMETRY", 9, 93128},
	{"SMELTER", 7, 93129},
	{"RAYOVAC", 7, 93130},
	{"TAKEDA", 6, 93131},
	{"TMYG", 4, 93132},
	{"POFV", 4, 93133},
	{"OIRR", 4, 93134},
	{"FEDM", 4, 93135},
	{"DYNAMISM", 8, 93136},
	{"WILY", 4, 93137},
	{"FILEATTACHMENT", 14, 93138},
	{"RABAT", 5, 93139},
	{"WILES", 5, 93140},
	{"UPAI", 4, 93141},
	{"SKBE", 4, 93142},
	{"LRON", 4, 93143},
	{"GVAC", 4, 93144},
	{"GSFE", 4, 93145},
	{"DEVS", 4, 93146},
	{"ENSUE", 5, 93147},
	{"MELLOR", 6, 93148},
	{"MANMADE", 7, 93149},
	{"SOMALILAND", 10, 93150},
	{"HASHTABLE", 9, 93151},
	{"CONTO", 5, 93152},
	{"JAFFA", 5, 93153},
	{"FURTADO", 7, 93154},
	{"SAGGING", 7, 93155},
	{"STATICS", 7, 93156},
	{"CHEMIN", 6, 93157},
	{"CRUMBLED", 8, 93158},
	{"WWEN", 4, 93159},
	{"UDEJ", 4, 93160},
	{"DSKN", 4, 93161},
	{"CURO", 4, 93162},
	{"BYPM", 4, 93163},
	{"SALEH", 5, 93164},
	{"PUJA", 4, 93165},
	{"KAMERA", 6, 93166},
	{"EPORT", 5, 93167},
	{"KILLIAN", 7, 93168},
	{"RUCKSACK", 8, 93169},
	{"JANETTE", 7, 93170},
	{"SYBIL", 5, 93171},
	{"POWERWARE", 9, 93172},
	{"YJZ", 3, 93173},
	{"VJR", 3, 93174},
	{"VJM", 3, 93175},
	{"PZW", 3, 93176},
	{"LVX", 3, 93177},
	{"FJZ", 3, 93178},
	{"PHENYLEPHRINE", 13, 93179},
	{"XAPP", 4, 93180},
	{"COGE", 4, 93181},
	{"CUPCAKE", 7, 93182},
	{"KARP", 4, 93183},
	{"PEKIN", 5, 93184},
	{"DEFIED", 6, 93185},
	{"YSLU", 4, 93186},
	{"XTHC", 4, 93187},
	{"EIPZ", 4, 93188},
	{"BODUM", 5, 93189},
	{"CELULAR", 7, 93190},
	{"ZAMORA", 6, 93191},
	{"HOPELESSNESS", 12, 93192},
	{"ERRAND", 6, 93193},
	{"YEOMAN", 6, 93194},
	{"PSIG", 4, 93195},
	{"POLYCYSTIC", 10, 93196},
	{"SLIMY", 5, 93197},
	{"KRZYSZTOF", 9, 93198},
	{"PARSIPPANY", 10, 93199},
	{"ZELS", 4, 93200},
	{"JIMD", 4, 93201},
	{"FMIX", 4, 93202},
	{"UNSER", 5, 93203},
	{"RAGGEDY", 7, 93204},
	{"COERCE", 6, 93205},
	{"PAYLOADS", 8, 93206},
	{"PPOP", 4, 93207},
	{"OWEG", 4, 93208},
	{"ODDU", 4, 93209},
	{"MMIK", 4, 93210},
	{"FGLE", 4, 93211},
	{"CEBIT", 5, 93212},
	{"OVERHANG", 8, 93213},
	{"WEDGEWOOD", 9, 93214},
	{"IHREN", 5, 93215},
	{"DATEN", 5, 93216},
	{"JEUNES", 6, 93217},
	{"ANNEXE", 6, 93218},
	{"CYCLEN", 6, 93219},
	{"CUSTOMIZATIONS", 14, 93220},
	{"CINW", 4, 93221},
	{"ADSY", 4, 93222},
	{"STUNNINGLY", 10, 93223},
	{"SOBBING", 7, 93224},
	{"MUSLIN", 6, 93225},
	{"HUGGER", 6, 93226},
	{"JUNIO", 5, 93227},
	{"XCD", 3, 93228},
	{"PREQUEL", 7, 93229},
	{"STRATHMORE", 10, 93230},
	{"DELIBERATIVE", 12, 93231},
	{"TKMN", 4, 93232},
	{"AGAU", 4, 93233},
	{"GUTE", 4, 93234},
	{"CHAMPLOO", 8, 93235},
	{"TATTOOING", 9, 93236},
	{"SHEKELS", 7, 93237},
	{"BILLERICA", 9, 93238},
	{"TALLEY", 6, 93239},
	{"ESTOPPEL", 8, 93240},
	{"EMIGRANT", 8, 93241},
	{"VWHI", 4, 93242},
	{"OYDE", 4, 93243},
	{"GJOI", 4, 93244},
	{"EAKG", 4, 93245},
	{"DUEO", 4, 93246},
	{"AMERITRADE", 10, 93247},
	{"DODO", 4, 93248},
	{"TORR", 4, 93249},
	{"CYTOMEGALOVIRUS", 15, 93250},
	{"BPEL", 4, 93251},
	{"DOMUS", 5, 93252},
	{"MADIGAN", 7, 93253},
	{"SUPERCOOL", 9, 93254},
	{"CONTAMINATE", 11, 93255},
	{"TIRL", 4, 93256},
	{"HYEL", 4, 93257},
	{"DKRA", 4, 93258},
	{"RXLIST", 6, 93259},
	{"SAILORMOON", 10, 93260},
	{"UBID", 4, 93261},
	{"PLOVDIV", 7, 93262},
	{"MCSWEENEY", 9, 93263},
	{"GOVIDEO", 7, 93264},
	{"BASSINET", 8, 93265},
	{"TAILLIGHTS", 10, 93266},
	{"TDBE", 4, 93267},
	{"RYIL", 4, 93268},
	{"OCOW", 4, 93269},
	{"AORM", 4, 93270},
	{"TYPHIMURIUM", 11, 93271},
	{"VISIONARIES", 11, 93272},
	{"SALESMEN", 8, 93273},
	{"JAHR", 4, 93274},
	{"THORNY", 6, 93275},
	{"NICKI", 5, 93276},
	{"SKAGEN", 6, 93277},
	{"HIBERNATION", 11, 93278},
	{"PONDERS", 7, 93279},
	{"RRSP", 4, 93280},
	{"MIDDLEBURG", 10, 93281},
	{"INNKEEPERS", 10, 93282},
	{"EPISTLES", 8, 93283},
	{"MCAULIFFE", 9, 93284},
	{"GARDASEE", 8, 93285},
	{"AROMATICS", 9, 93286},
	{"YTAM", 4, 93287},
	{"MSOW", 4, 93288},
	{"LRAY", 4, 93289},
	{"LEIV", 4, 93290},
	{"INTERPLANETARY", 14, 93291},
	{"LANDCARE", 8, 93292},
	{"TOWNEPLACE", 10, 93293},
	{"DOWNLOADEN", 10, 93294},
	{"DISCONTINUING", 13, 93295},
	{"BORK", 4, 93296},
	{"TRAMPLED", 8, 93297},
	{"SEALERS", 7, 93298},
	{"WEYBRIDGE", 9, 93299},
	{"YEDJ", 4, 93300},
	{"INCP", 4, 93301},
	{"BWER", 4, 93302},
	{"WUSTHOF", 7, 93303},
	{"INTERBANK", 9, 93304},
	{"HULLABALOO", 10, 93305},
	{"ERRATUM", 7, 93306},
	{"CONTRERAS", 9, 93307},
	{"SANDWELL", 8, 93308},
	{"RGWI", 4, 93309},
	{"KIEB", 4, 93310},
	{"DGRU", 4, 93311},
	{"ANTHRACITE", 10, 93312},
	{"NOVGOROD", 8, 93313},
	{"EARBUD", 6, 93314},
	{"COASTLINES", 10, 93315},
	{"MEDITATING", 10, 93316},
	{"ECHOLIST", 8, 93317},
	{"GUNTUR", 6, 93318},
	{"LMP", 3, 93319},
	{"TRUNKING", 8, 93320},
	{"FOXTROT", 7, 93321},
	{"ROSANNA", 7, 93322},
	{"PATCHOULI", 9, 93323},
	{"INEQUITIES", 10, 93324},
	{"SVOW", 4, 93325},
	{"PAPU", 4, 93326},
	{"PANP", 4, 93327},
	{"OPFA", 4, 93328},
	{"LGAU", 4, 93329},
	{"IAJU", 4, 93330},
	{"HPUN", 4, 93331},
	{"TESTES", 6, 93332},
	{"DEFAULTING", 10, 93333},
	{"ALPERT", 6, 93334},
	{"MERCILESS", 9, 93335},
	{"SECURITIZATION", 14, 93336},
	{"NSFW", 4, 93337},
	{"BORER", 5, 93338},
	{"ORIGINATORS", 11, 93339},
	{"POSTID", 6, 93340},
	{"OLDQ", 4, 93341},
	{"FBIN", 4, 93342},
	{"CENSORING", 9, 93343},
	{"HASHIMOTO", 9, 93344},
	{"ORIOLE", 6, 93345},
	{"CHIPOTLE", 8, 93346},
	{"IPEOPLE", 7, 93347},
	{"CLUMP", 5, 93348},
	{"RDG", 3, 93349},
	{"REUSING", 7, 93350},
	{"SAEED", 5, 93351},
	{"WETZEL", 6, 93352},
	{"TRYV", 4, 93353},
	{"RGHT", 4, 93354},
	{"KWAV", 4, 93355},
	{"EWTY", 4, 93356},
	{"ESLY", 4, 93357},
	{"CAPW", 4, 93358},
	{"MENSA", 5, 93359},
	{"SHINER", 6, 93360},
	{"CHAL", 4, 93361},
	{"RHESUS", 6, 93362},
	{"STREPTOMYCES", 12, 93363},
	{"TRANSCRIBE", 10, 93364},
	{"ODUT", 4, 93365},
	{"EIDF", 4, 93366},
	{"ACYN", 4, 93367},
	{"ABTR", 4, 93368},
	{"DATAGRAMS", 9, 93369},
	{"INVALIDATED", 11, 93370},
	{"SHENANIGANS", 11, 93371},
	{"ATROCITY", 8, 93372},
	{"ELINOR", 6, 93373},
	{"MKII", 4, 93374},
	{"SANDFORD", 8, 93375},
	{"LENNART", 7, 93376},
	{"PRACT", 5, 93377},
	{"PROPORTIONALLY", 14, 93378},
	{"UNTRAINED", 9, 93379},
	{"BEENE", 5, 93380},
	{"THRUSTS", 7, 93381},
	{"TRAVELGUIDE", 11, 93382},
	{"CHAMPIONED", 10, 93383},
	{"BIOSOLIDS", 9, 93384},
	{"BILLABLE", 8, 93385},
	{"UGTO", 4, 93386},
	{"OUDP", 4, 93387},
	{"AFFB", 4, 93388},
	{"TIRESOME", 8, 93389},
	{"SPLASHED", 8, 93390},
	{"GIVERS", 6, 93391},
	{"ANTONYMS", 8, 93392},
	{"TMDLS", 5, 93393},
	{"COCKROACHES", 11, 93394},
	{"TESTCASE", 8, 93395},
	{"FARAWAY", 7, 93396},
	{"LUNE", 4, 93397},
	{"CFENGINE", 8, 93398},
	{"UMBC", 4, 93399},
	{"YKOR", 4, 93400},
	{"UYSF", 4, 93401},
	{"SKAF", 4, 93402},
	{"COLC", 4, 93403},
	{"UNDERWRITTEN", 12, 93404},
	{"BIOFUELS", 8, 93405},
	{"CYBERHOME", 9, 93406},
	{"ZEGNA", 5, 93407},
	{"TARPS", 5, 93408},
	{"SOCIOLOGISTS", 12, 93409},
	{"ELLESMERE", 9, 93410},
	{"OSTOMY", 6, 93411},
	{"RDVA", 4, 93412},
	{"PEWO", 4, 93413},
	{"EULE", 4, 93414},
	{"INGEST", 6, 93415},
	{"GAZEBOS", 7, 93416},
	{"SIRLOIN", 7, 93417},
	{"MOCCASINS", 9, 93418},
	{"PARTHENON", 9, 93419},
	{"CYCLOPHOSPHAMIDE", 16, 93420},
	{"ABOUNDS", 7, 93421},
	{"BITDEFENDER", 11, 93422},
	{"YHYP", 4, 93423},
	{"UNKH", 4, 93424},
	{"ICTG", 4, 93425},
	{"EURW", 4, 93426},
	{"CGIN", 4, 93427},
	{"CATZ", 4, 93428},
	{"SALUTES", 7, 93429},
	{"COLLIDED", 8, 93430},
	{"BPP", 3, 93431},
	{"GIANCARLO", 9, 93432},
	{"KATEGORIE", 9, 93433},
	{"TILDE", 5, 93434},
	{"POTASH", 6, 93435},
	{"ARJAN", 5, 93436},
	{"VALERY", 6, 93437},
	{"KMC", 3, 93438},
	{"BOARDERS", 8, 93439},
	{"LAPPING", 7, 93440},
	{"RECOMENDED", 10, 93441},
	{"DATAPORT", 8, 93442},
	{"ZEBE", 4, 93443},
	{"MSAU", 4, 93444},
	{"PFAFF", 5, 93445},
	{"MANUALE", 7, 93446},
	{"CHIVALRY", 8, 93447},
	{"NIVEN", 5, 93448},
	{"ATSDR", 5, 93449},
	{"RANGELAND", 9, 93450},
	{"ZAGR", 4, 93451},
	{"ODJU", 4, 93452},
	{"DROX", 4, 93453},
	{"COMMONALITY", 11, 93454},
	{"MIDIS", 5, 93455},
	{"CWC", 3, 93456},
	{"REGRETTABLY", 11, 93457},
	{"NAVIDAD", 7, 93458},
	{"YAHOOGROUPS", 11, 93459},
	{"CORAZON", 7, 93460},
	{"PULAU", 5, 93461},
	{"PLAYBOOK", 8, 93462},
	{"DIGIPAK", 7, 93463},
	{"TKIM", 4, 93464},
	{"MCCH", 4, 93465},
	{"KFAN", 4, 93466},
	{"IFMI", 4, 93467},
	{"JETBLUE", 7, 93468},
	{"KAVANAGH", 8, 93469},
	{"EXHIBITIONISTS", 14, 93470},
	{"GNSU", 4, 93471},
	{"BIAP", 4, 93472},
	{"ARMIDALE", 8, 93473},
	{"SIDEBOARD", 9, 93474},
	{"ARQUETTE", 8, 93475},
	{"COPLAND", 7, 93476},
	{"NAMIB", 5, 93477},
	{"POACHING", 8, 93478},
	{"GAUC", 4, 93479},
	{"FICV", 4, 93480},
	{"CHEAPFLIGHTS", 12, 93481},
	{"WYVERN", 6, 93482},
	{"LUCENE", 6, 93483},
	{"MONTMARTRE", 10, 93484},
	{"MUFFLED", 7, 93485},
	{"VINCENNES", 9, 93486},
	{"INLAYS", 6, 93487},
	{"LOCKETS", 7, 93488},
	{"RGOC", 4, 93489},
	{"PTDE", 4, 93490},
	{"WHITEY", 6, 93491},
	{"FOILED", 6, 93492},
	{"BRIN", 4, 93493},
	{"WHARFEDALE", 10, 93494},
	{"GUYANESE", 8, 93495},
	{"LARYNGEAL", 9, 93496},
	{"OUTFIELDER", 10, 93497},
	{"NONATTAINMENT", 13, 93498},
	{"SOFTIMAGE", 9, 93499},
	{"CELLGROUPDATA", 13, 93500},
	{"LITERATURA", 10, 93501},
	{"KFIG", 4, 93502},
	{"HLYV", 4, 93503},
	{"FTHB", 4, 93504},
	{"AORB", 4, 93505},
	{"MYOPLEX", 7, 93506},
	{"YORBA", 5, 93507},
	{"FLOCKED", 7, 93508},
	{"SLAPSTICK", 9, 93509},
	{"COTTRELL", 8, 93510},
	{"CONNAUGHT", 9, 93511},
	{"DIALERS", 7, 93512},
	{"SUBCULTURE", 10, 93513},
	{"CMX", 3, 93514},
	{"MODDED", 6, 93515},
	{"SKIDS", 5, 93516},
	{"ROSELLE", 7, 93517},
	{"TETHER", 6, 93518},
	{"PEQU", 4, 93519},
	{"PADV", 4, 93520},
	{"OXWO", 4, 93521},
	{"LSVE", 4, 93522},
	{"KLUB", 4, 93523},
	{"HYPERBOLE", 9, 93524},
	{"MARATHONS", 9, 93525},
	{"WIMT", 4, 93526},
	{"UYHA", 4, 93527},
	{"RLSM", 4, 93528},
	{"PSAG", 4, 93529},
	{"JABB", 4, 93530},
	{"TOUCAN", 6, 93531},
	{"MASTERCLASS", 11, 93532},
	{"BORGHESE", 8, 93533},
	{"CALCIO", 6, 93534},
	{"OXIDIZING", 9, 93535},
	{"ORGT", 4, 93536},
	{"EELK", 4, 93537},
	{"CFAM", 4, 93538},
	{"KENNEBEC", 8, 93539},
	{"SCHRIEB", 7, 93540},
	{"INTERGALACTIC", 13, 93541},
	{"BIOMOLECULAR", 12, 93542},
	{"BRAHMAN", 7, 93543},
	{"POWWEB", 6, 93544},
	{"WOEL", 4, 93545},
	{"RTKE", 4, 93546},
	{"PICR", 4, 93547},
	{"ORBT", 4, 93548},
	{"IXSU", 4, 93549},
	{"FFEV", 4, 93550},
	{"DNTJ", 4, 93551},
	{"MCWILLIAMS", 10, 93552},
	{"PHOSPHOROUS", 11, 93553},
	{"CHARLEMAGNE", 11, 93554},
	{"PULSING", 7, 93555},
	{"PHOTOCOPIERS", 12, 93556},
	{"OBLIGOR", 7, 93557},
	{"MATCHER", 7, 93558},
	{"LISTBOX", 7, 93559},
	{"VOIGT", 5, 93560},
	{"YDUB", 4, 93561},
	{"VEOW", 4, 93562},
	{"MGAI", 4, 93563},
	{"EZAC", 4, 93564},
	{"FDL", 3, 93565},
	{"HERALDS", 7, 93566},
	{"STERILITY", 9, 93567},
	{"DAWLEY", 6, 93568},
	{"SCRIBUS", 7, 93569},
	{"YIRO", 4, 93570},
	{"UNGV", 4, 93571},
	{"RNHU", 4, 93572},
	{"OPWE", 4, 93573},
	{"NAKR", 4, 93574},
	{"GSEQ", 4, 93575},
	{"FTAG", 4, 93576},
	{"CFLE", 4, 93577},
	{"LESSORS", 7, 93578},
	{"ZLD", 3, 93579},
	{"YZX", 3, 93580},
	{"YYG", 3, 93581},
	{"GZR", 3, 93582},
	{"DYNASTIES", 9, 93583},
	{"PROWL", 5, 93584},
	{"LUMINARIES", 10, 93585},
	{"KARATS", 6, 93586},
	{"BRIDGER", 7, 93587},
	{"AMIABLE", 7, 93588},
	{"UGSC", 4, 93589},
	{"OOPC", 4, 93590},
	{"CEDK", 4, 93591},
	{"HADRONIC", 8, 93592},
	{"FAIRPORT", 8, 93593},
	{"PIECEWISE", 9, 93594},
	{"SITTINGS", 8, 93595},
	{"UNDULATING", 10, 93596},
	{"UOFI", 4, 93597},
	{"OILG", 4, 93598},
	{"DHEJ", 4, 93599},
	{"RECHARGING", 10, 93600},
	{"DMM", 3, 93601},
	{"THATCHED", 8, 93602},
	{"FELICE", 6, 93603},
	{"UNIONVILLE", 10, 93604},
	{"INTERMEDIA", 10, 93605},
	{"GOETZ", 5, 93606},
	{"URINAL", 6, 93607},
	{"JOYSTIQ", 7, 93608},
	{"GROSSO", 6, 93609},
	{"SOBAKA", 6, 93610},
	{"UBSM", 4, 93611},
	{"OMRS", 4, 93612},
	{"OGWI", 4, 93613},
	{"IRLC", 4, 93614},
	{"PAYPHONE", 8, 93615},
	{"ROCKFISH", 8, 93616},
	{"RODT", 4, 93617},
	{"OIRW", 4, 93618},
	{"KOWN", 4, 93619},
	{"FCOD", 4, 93620},
	{"CRIG", 4, 93621},
	{"ALTB", 4, 93622},
	{"DUODENAL", 8, 93623},
	{"UNINSTALLED", 11, 93624},
	{"LEITER", 6, 93625},
	{"IRREVOCABLY", 11, 93626},
	{"COWORKER", 8, 93627},
	{"ESCUELA", 7, 93628},
	{"CYCLADES", 8, 93629},
	{"LONGTERM", 8, 93630},
	{"TABER", 5, 93631},
	{"BUNYAN", 6, 93632},
	{"SCREENPLAYS", 11, 93633},
	{"SHIITES", 7, 93634},
	{"YUPF", 4, 93635},
	{"SOGL", 4, 93636},
	{"RTKI", 4, 93637},
	{"PINU", 4, 93638},
	{"IFTM", 4, 93639},
	{"AWKA", 4, 93640},
	{"FARCRY", 6, 93641},
	{"HINDERS", 7, 93642},
	{"JITSU", 5, 93643},
	{"TUBERS", 6, 93644},
	{"LACTOBACILLUS", 13, 93645},
	{"UNIONTOWN", 9, 93646},
	{"CLONER", 6, 93647},
	{"UNRELENTING", 11, 93648},
	{"OTAKU", 5, 93649},
	{"HOYAS", 5, 93650},
	{"KANDAHAR", 8, 93651},
	{"KERRVILLE", 9, 93652},
	{"ZERC", 4, 93653},
	{"RHEU", 4, 93654},
	{"PEXE", 4, 93655},
	{"AKERS", 5, 93656},
	{"NEUROPSYCHOLOGY", 15, 93657},
	{"MULTIMAP", 8, 93658},
	{"EXPEDITIOUSLY", 13, 93659},
	{"ANTIQUATED", 10, 93660},
	{"JERKED", 6, 93661},
	{"ALLSTON", 7, 93662},
	{"SPUTTERING", 10, 93663},
	{"FEMININITY", 10, 93664},
	{"PUJO", 4, 93665},
	{"PCIT", 4, 93666},
	{"ALIY", 4, 93667},
	{"OPULENT", 7, 93668},
	{"TRASK", 5, 93669},
	{"ACCUWEATHER", 11, 93670},
	{"DEFERMENT", 9, 93671},
	{"DIMLY", 5, 93672},
	{"FMP", 3, 93673},
	{"PORTLETS", 8, 93674},
	{"COCONUTS", 8, 93675},
	{"CONFUSES", 8, 93676},
	{"PTYP", 4, 93677},
	{"HEGD", 4, 93678},
	{"CBLO", 4, 93679},
	{"EXECUTORS", 9, 93680},
	{"GLSA", 4, 93681},
	{"WESTMONT", 8, 93682},
	{"WADERS", 6, 93683},
	{"SQUALL", 6, 93684},
	{"CELLULARE", 9, 93685},
	{"HOMEHOME", 8, 93686},
	{"FROGGER", 7, 93687},
	{"NOTHINGNESS", 11, 93688},
	{"SEQRES", 6, 93689},
	{"GIDD", 4, 93690},
	{"CEOW", 4, 93691},
	{"APOV", 4, 93692},
	{"HELLFIRE", 8, 93693},
	{"HEBRIDES", 8, 93694},
	{"HAVERING", 8, 93695},
	{"MONTFORT", 8, 93696},
	{"CHOKES", 6, 93697},
	{"EHARMONY", 8, 93698},
	{"KNOWSLEY", 8, 93699},
	{"DEMETER", 7, 93700},
	{"YSYE", 4, 93701},
	{"WESW", 4, 93702},
	{"LTYL", 4, 93703},
	{"IORQ", 4, 93704},
	{"FISM", 4, 93705},
	{"AFUS", 4, 93706},
	{"BORDELLCHAT", 11, 93707},
	{"CVSWEB", 6, 93708},
	{"HOUDINI", 7, 93709},
	{"MYGI", 4, 93710},
	{"MAMB", 4, 93711},
	{"LPAD", 4, 93712},
	{"FETR", 4, 93713},
	{"ERMN", 4, 93714},
	{"UMR", 3, 93715},
	{"CANARIAS", 8, 93716},
	{"BABYSHAMBLES", 12, 93717},
	{"BRIDGETTE", 9, 93718},
	{"ANTAGONISTIC", 12, 93719},
	{"SLYK", 4, 93720},
	{"RMAW", 4, 93721},
	{"RIXI", 4, 93722},
	{"AUPA", 4, 93723},
	{"CINQUE", 6, 93724},
	{"BOWERY", 6, 93725},
	{"IMMOVABLE", 9, 93726},
	{"DREZNER", 7, 93727},
	{"CATERPILLARS", 12, 93728},
	{"ALCAN", 5, 93729},
	{"OUTLIER", 7, 93730},
	{"NAIRA", 5, 93731},
	{"NEVERENDING", 11, 93732},
	{"XQUI", 4, 93733},
	{"PAGH", 4, 93734},
	{"OKPU", 4, 93735},
	{"NRYD", 4, 93736},
	{"CONSIGNED", 9, 93737},
	{"MASSON", 6, 93738},
	{"KHANNA", 6, 93739},
	{"RHEIN", 5, 93740},
	{"SYSTEME", 7, 93741},
	{"FERVOR", 6, 93742},
	{"PRET", 4, 93743},
	{"HILLSONG", 8, 93744},
	{"YTIR", 4, 93745},
	{"XONC", 4, 93746},
	{"LSLU", 4, 93747},
	{"HGOR", 4, 93748},
	{"FRUB", 4, 93749},
	{"CAMSHAFT", 8, 93750},
	{"EXOTICA", 7, 93751},
	{"MILBURN", 7, 93752},
	{"SCOOPED", 7, 93753},
	{"BIJOU", 5, 93754},
	{"DESTDIR", 7, 93755},
	{"INNERVATION", 11, 93756},
	{"URKN", 4, 93757},
	{"ULJO", 4, 93758},
	{"PEBY", 4, 93759},
	{"GHSL", 4, 93760},
	{"FETU", 4, 93761},
	{"DDYT", 4, 93762},
	{"CUNHA", 5, 93763},
	{"REEFER", 6, 93764},
	{"EXERTS", 6, 93765},
	{"TECHSPOT", 8, 93766},
	{"HIBERNIA", 8, 93767},
	{"ALPINA", 6, 93768},
	{"IARC", 4, 93769},
	{"CONSTRAINING", 12, 93770},
	{"LNOD", 4, 93771},
	{"CCOD", 4, 93772},
	{"AKAF", 4, 93773},
	{"IDLING", 6, 93774},
	{"DARD", 4, 93775},
	{"ESTEFAN", 7, 93776},
	{"FUSER", 5, 93777},
	{"LEPTON", 6, 93778},
	{"PERGAMON", 8, 93779},
	{"CURSORY", 7, 93780},
	{"WIKTIONARY", 10, 93781},
	{"TUPU", 4, 93782},
	{"RTZS", 4, 93783},
	{"GHCU", 4, 93784},
	{"RAZER", 5, 93785},
	{"POZNAN", 6, 93786},
	{"NETSCREEN", 9, 93787},
	{"MANDA", 5, 93788},
	{"XMB", 3, 93789},
	{"KINGSTOWN", 9, 93790},
	{"TOPIX", 5, 93791},
	{"DISSIPATE", 9, 93792},
	{"BATSMAN", 7, 93793},
	{"HYMEN", 5, 93794},
	{"RTZO", 4, 93795},
	{"LLIU", 4, 93796},
	{"FINR", 4, 93797},
	{"BIAF", 4, 93798},
	{"WAVELETS", 8, 93799},
	{"COGS", 4, 93800},
	{"ABFO", 4, 93801},
	{"BARNHART", 8, 93802},
	{"SCOFIELD", 8, 93803},
	{"EBRD", 4, 93804},
	{"DESORPTION", 10, 93805},
	{"REFUTED", 7, 93806},
	{"BELLFLOWER", 10, 93807},
	{"WATERTIGHT", 10, 93808},
	{"IONIAN", 6, 93809},
	{"STEVIA", 6, 93810},
	{"OOFG", 4, 93811},
	{"MUNR", 4, 93812},
	{"FHEF", 4, 93813},
	{"AMERICANISM", 11, 93814},
	{"PHOTOCOPIER", 11, 93815},
	{"HAVERFORD", 9, 93816},
	{"TALC", 4, 93817},
	{"PESSIMISM", 9, 93818},
	{"VEHEMENTLY", 10, 93819},
	{"GWENDOLYN", 9, 93820},
	{"BUYNOW", 6, 93821},
	{"RRSA", 4, 93822},
	{"ROYL", 4, 93823},
	{"NAIRN", 5, 93824},
	{"PROLAB", 6, 93825},
	{"LUNDBERG", 8, 93826},
	{"VELVETY", 7, 93827},
	{"BACKORDERED", 11, 93828},
	{"MONONUCLEAR", 11, 93829},
	{"VEDERE", 6, 93830},
	{"UNOCAL", 6, 93831},
	{"WHEEZING", 8, 93832},
	{"BRUNSON", 7, 93833},
	{"PAFO", 4, 93834},
	{"NUMP", 4, 93835},
	{"GREENLEE", 8, 93836},
	{"EMER", 4, 93837},
	{"TXDOT", 5, 93838},
	{"PRICHARD", 8, 93839},
	{"CONFEREES", 9, 93840},
	{"RENATA", 6, 93841},
	{"TERNARY", 7, 93842},
	{"FOOTBALLER", 10, 93843},
	{"SISYPHUS", 8, 93844},
	{"DIRECTFB", 8, 93845},
	{"FOOLPROOF", 9, 93846},
	{"CHASTAIN", 8, 93847},
	{"LAKSHMI", 7, 93848},
	{"USUF", 4, 93849},
	{"USHK", 4, 93850},
	{"TPLO", 4, 93851},
	{"RKUR", 4, 93852},
	{"OGOM", 4, 93853},
	{"LKBA", 4, 93854},
	{"TEEMING", 7, 93855},
	{"PARADOXES", 9, 93856},
	{"MEGANE", 6, 93857},
	{"LAMPE", 5, 93858},
	{"SOMEONES", 8, 93859},
	{"NRYM", 4, 93860},
	{"METD", 4, 93861},
	{"IELR", 4, 93862},
	{"ICLU", 4, 93863},
	{"FOOLISHLY", 9, 93864},
	{"ORDRE", 5, 93865},
	{"REBELDE", 7, 93866},
	{"MORRIGAN", 8, 93867},
	{"MYMOVIES", 8, 93868},
	{"RGHW", 4, 93869},
	{"PSGE", 4, 93870},
	{"TIANANMEN", 9, 93871},
	{"IMMUNOSUPPRESSIVE", 17, 93872},
	{"MCVEIGH", 7, 93873},
	{"EVWA", 4, 93874},
	{"EDYD", 4, 93875},
	{"CUPD", 4, 93876},
	{"STYLIN", 6, 93877},
	{"BROWER", 6, 93878},
	{"MPLTEXT", 7, 93879},
	{"INANIMATE", 9, 93880},
	{"PANTING", 7, 93881},
	{"PDD", 3, 93882},
	{"DEPOSITOR", 9, 93883},
	{"OFCOURSE", 8, 93884},
	{"COMERS", 6, 93885},
	{"URTV", 4, 93886},
	{"SIQU", 4, 93887},
	{"DRHA", 4, 93888},
	{"ECDL", 4, 93889},
	{"REDENVELOPE", 11, 93890},
	{"ACIDOPHILUS", 11, 93891},
	{"DECI", 4, 93892},
	{"TOKM", 4, 93893},
	{"FLSE", 4, 93894},
	{"EBYV", 4, 93895},
	{"DEFENSIVELY", 11, 93896},
	{"ROMAINE", 7, 93897},
	{"WULF", 4, 93898},
	{"ANALYTICA", 9, 93899},
	{"ZCON", 4, 93900},
	{"YESD", 4, 93901},
	{"KYEN", 4, 93902},
	{"BTCO", 4, 93903},
	{"AWBR", 4, 93904},
	{"TRYON", 5, 93905},
	{"PECKHAM", 7, 93906},
	{"FORGO", 5, 93907},
	{"BARCA", 5, 93908},
	{"PAHRUMP", 7, 93909},
	{"FOROS", 5, 93910},
	{"TACKS", 5, 93911},
	{"PICKABOOK", 9, 93912},
	{"VEILLE", 6, 93913},
	{"HELLRAISER", 10, 93914},
	{"LITHOGRAPHS", 11, 93915},
	{"EFFUSION", 8, 93916},
	{"EDUCATES", 8, 93917},
	{"YKIM", 4, 93918},
	{"NFLR", 4, 93919},
	{"EPEG", 4, 93920},
	{"CIDO", 4, 93921},
	{"EDIETS", 6, 93922},
	{"GOPAL", 5, 93923},
	{"LUNACY", 6, 93924},
	{"SIGNERS", 7, 93925},
	{"DIGEXT", 6, 93926},
	{"NETBACKUP", 9, 93927},
	{"DIMENSIONALITY", 14, 93928},
	{"TRIAX", 5, 93929},
	{"WNBI", 4, 93930},
	{"OPUM", 4, 93931},
	{"KMTO", 4, 93932},
	{"RNASE", 5, 93933},
	{"ANGELL", 6, 93934},
	{"LOATHE", 6, 93935},
	{"BOCHUM", 6, 93936},
	{"EYEPIECES", 9, 93937},
	{"EARBUDS", 7, 93938},
	{"AMERICABLOG", 11, 93939},
	{"MAKEOVERS", 9, 93940},
	{"PSCL", 4, 93941},
	{"OWAU", 4, 93942},
	{"NUBI", 4, 93943},
	{"LUVI", 4, 93944},
	{"FLCO", 4, 93945},
	{"UNPROCESSED", 11, 93946},
	{"WIDCTLPAR", 9, 93947},
	{"TOLC", 4, 93948},
	{"LFAW", 4, 93949},
	{"GFER", 4, 93950},
	{"FFYS", 4, 93951},
	{"CLAUSEN", 7, 93952},
	{"PUNBB", 5, 93953},
	{"NOTORIETY", 9, 93954},
	{"CENTRA", 6, 93955},
	{"MONSON", 6, 93956},
	{"INFOGRAMES", 10, 93957},
	{"XALAN", 5, 93958},
	{"HYDROXYL", 8, 93959},
	{"YQM", 3, 93960},
	{"UWY", 3, 93961},
	{"DVZ", 3, 93962},
	{"CXV", 3, 93963},
	{"MEDPIX", 6, 93964},
	{"SHOWERED", 8, 93965},
	{"INTERACTED", 10, 93966},
	{"POLISHES", 8, 93967},
	{"PFRI", 4, 93968},
	{"KVIS", 4, 93969},
	{"FSRE", 4, 93970},
	{"EUKW", 4, 93971},
	{"DOMR", 4, 93972},
	{"BRATS", 5, 93973},
	{"CANOGA", 6, 93974},
	{"HUDDLE", 6, 93975},
	{"NUMISMATIC", 10, 93976},
	{"AVOIDABLE", 9, 93977},
	{"BRANTLEY", 8, 93978},
	{"ADENOMA", 7, 93979},
	{"PROSTAGLANDINS", 14, 93980},
	{"POWERCOLOR", 10, 93981},
	{"SLIL", 4, 93982},
	{"NKBR", 4, 93983},
	{"LMSM", 4, 93984},
	{"IFBA", 4, 93985},
	{"GUPE", 4, 93986},
	{"APAV", 4, 93987},
	{"BEACONSFIELD", 12, 93988},
	{"LAKHS", 5, 93989},
	{"FLAMMABILITY", 12, 93990},
	{"WBYT", 4, 93991},
	{"UDIM", 4, 93992},
	{"UBOA", 4, 93993},
	{"TRUANCY", 7, 93994},
	{"TAXICAB", 7, 93995},
	{"JHARKHAND", 9, 93996},
	{"CHANNELWEB", 10, 93997},
	{"CONFOUNDED", 10, 93998},
	{"GIVN", 4, 93999},
	{"FLATIRON", 8, 94000},
	{"MIDLIFE", 7, 94001},
	{"ONGQ", 4, 94002},
	{"GPOE", 4, 94003},
	{"ALAJ", 4, 94004},
	{"GUERIN", 6, 94005},
	{"COUGHS", 6, 94006},
	{"INDIANOLA", 9, 94007},
	{"UNAVAILABILITY", 14, 94008},
	{"ROOTER", 6, 94009},
	{"WANAKA", 6, 94010},
	{"LOMPOC", 6, 94011},
	{"WIDENER", 7, 94012},
	{"CLL", 3, 94013},
	{"MRAL", 4, 94014},
	{"PRETENDS", 8, 94015},
	{"KMAIL", 5, 94016},
	{"WEBSENSE", 8, 94017},
	{"RESIDENCIES", 11, 94018},
	{"FAERY", 5, 94019},
	{"ELOISE", 6, 94020},
	{"CABLEVISION", 11, 94021},
	{"DISRUPTS", 8, 94022},
	{"NRUG", 4, 94023},
	{"HTQU", 4, 94024},
	{"ONETIME", 7, 94025},
	{"KENZIE", 6, 94026},
	{"GATING", 6, 94027},
	{"BOINGBOING", 10, 94028},
	{"SEVIER", 6, 94029},
	{"EBERHARD", 8, 94030},
	{"CHEK", 4, 94031},
	{"WIDENS", 6, 94032},
	{"KHARAGPUR", 9, 94033},
	{"OMNIPOTENT", 10, 94034},
	{"FOTZE", 5, 94035},
	{"YARU", 4, 94036},
	{"BYOL", 4, 94037},
	{"GAUTIER", 7, 94038},
	{"CVP", 3, 94039},
	{"DEFLATED", 8, 94040},
	{"INFESTATIONS", 12, 94041},
	{"POISE", 5, 94042},
	{"JUDGMENTAL", 10, 94043},
	{"MEIJI", 5, 94044},
	{"YSGU", 4, 94045},
	{"WWON", 4, 94046},
	{"TYUP", 4, 94047},
	{"RAFS", 4, 94048},
	{"OLYF", 4, 94049},
	{"LTPO", 4, 94050},
	{"GOPC", 4, 94051},
	{"FSCE", 4, 94052},
	{"ANTIPSYCHOTIC", 13, 94053},
	{"UWM", 3, 94054},
	{"ZEELAND", 7, 94055},
	{"RINGED", 6, 94056},
	{"SLAUGHTERHOUSE", 14, 94057},
	{"OFTF", 4, 94058},
	{"MRSS", 4, 94059},
	{"LDPH", 4, 94060},
	{"CIMA", 4, 94061},
	{"BAGGING", 7, 94062},
	{"HUDDLED", 7, 94063},
	{"UNSTEADY", 8, 94064},
	{"BRAINWASHING", 12, 94065},
	{"ZWISCHEN", 8, 94066},
	{"DUCHY", 5, 94067},
	{"OXLE", 4, 94068},
	{"ELWR", 4, 94069},
	{"DMP", 3, 94070},
	{"DISCONNECTING", 13, 94071},
	{"THERA", 5, 94072},
	{"MALACCA", 7, 94073},
	{"TMAU", 4, 94074},
	{"LYKM", 4, 94075},
	{"LTDU", 4, 94076},
	{"LFTA", 4, 94077},
	{"HADQ", 4, 94078},
	{"GAOF", 4, 94079},
	{"CSAY", 4, 94080},
	{"MCLELLAN", 8, 94081},
	{"RONG", 4, 94082},
	{"TELCOS", 6, 94083},
	{"WILMER", 6, 94084},
	{"MAGDA", 5, 94085},
	{"CARRION", 7, 94086},
	{"SUMMARILY", 9, 94087},
	{"SPHINCTER", 9, 94088},
	{"NEWSOM", 6, 94089},
	{"TMCG", 4, 94090},
	{"DSUE", 4, 94091},
	{"INFILL", 6, 94092},
	{"FAIRHAVEN", 9, 94093},
	{"LEOPARDS", 8, 94094},
	{"ETUDE", 5, 94095},
	{"STEREOTYPING", 12, 94096},
	{"TALIB", 5, 94097},
	{"OVAW", 4, 94098},
	{"KFUN", 4, 94099},
	{"BSLI", 4, 94100},
	{"AKAK", 4, 94101},
	{"ABSW", 4, 94102},
	{"DREAMSTIME", 10, 94103},
	{"REARRANGING", 11, 94104},
	{"GEOGRAPHIES", 11, 94105},
	{"TIPP", 4, 94106},
	{"PROGRAMMATICALLY", 16, 94107},
	{"DETTE", 5, 94108},
	{"SANCTIFIED", 10, 94109},
	{"HANDICAPPER", 11, 94110},
	{"RPUM", 4, 94111},
	{"ODCU", 4, 94112},
	{"DGUL", 4, 94113},
	{"PLANTAR", 7, 94114},
	{"OGAMING", 7, 94115},
	{"TRADESMEN", 9, 94116},
	{"EXCITEDLY", 9, 94117},
	{"ACADEMIE", 8, 94118},
	{"QUARRYING", 9, 94119},
	{"PENTRU", 6, 94120},
	{"APPROACHABLE", 12, 94121},
	{"BRACED", 6, 94122},
	{"SWEETENER", 9, 94123},
	{"BRAISED", 7, 94124},
	{"KNUT", 4, 94125},
	{"GAUNT", 5, 94126},
	{"TIBCO", 5, 94127},
	{"YFON", 4, 94128},
	{"WSRA", 4, 94129},
	{"UDAB", 4, 94130},
	{"SPYI", 4, 94131},
	{"OWEP", 4, 94132},
	{"LITP", 4, 94133},
	{"ERZI", 4, 94134},
	{"NOURISHED", 9, 94135},
	{"FSEEK", 5, 94136},
	{"VIDED", 5, 94137},
	{"BURK", 4, 94138},
	{"SPIGOT", 6, 94139},
	{"SKILLING", 8, 94140},
	{"HUNTERDON", 9, 94141},
	{"NAILER", 6, 94142},
	{"ROXETTE", 7, 94143},
	{"LMHE", 4, 94144},
	{"DDWI", 4, 94145},
	{"BLYK", 4, 94146},
	{"CORNSTARCH", 10, 94147},
	{"HEPATOCYTES", 11, 94148},
	{"DOCH", 4, 94149},
	{"COUPES", 6, 94150},
	{"UNIVERSITET", 11, 94151},
	{"EFFIE", 5, 94152},
	{"PAFI", 4, 94153},
	{"LMAH", 4, 94154},
	{"JOAQ", 4, 94155},
	{"MAURICIO", 8, 94156},
	{"ROSEBURG", 8, 94157},
	{"DAFFODILS", 9, 94158},
	{"BERLUSCONI", 10, 94159},
	{"ORYY", 4, 94160},
	{"LETTRE", 6, 94161},
	{"CHLOROPLAST", 11, 94162},
	{"BODEN", 5, 94163},
	{"POLLUTE", 7, 94164},
	{"CHARING", 7, 94165},
	{"KANSAI", 6, 94166},
	{"BUZZWORD", 8, 94167},
	{"NEPAD", 5, 94168},
	{"BARA", 4, 94169},
	{"PISTACHIO", 9, 94170},
	{"KAMEN", 5, 94171},
	{"NEUER", 5, 94172},
	{"RKNA", 4, 94173},
	{"IEGL", 4, 94174},
	{"LANVIN", 6, 94175},
	{"RIVERBANK", 9, 94176},
	{"LILYPOND", 8, 94177},
	{"PREDOMINATELY", 13, 94178},
	{"METALWARE", 9, 94179},
	{"SAUGUS", 6, 94180},
	{"NMAC", 4, 94181},
	{"POMP", 4, 94182},
	{"RGRU", 4, 94183},
	{"FTYO", 4, 94184},
	{"DHIK", 4, 94185},
	{"BICF", 4, 94186},
	{"BEBY", 4, 94187},
	{"GIZA", 4, 94188},
	{"LANCS", 5, 94189},
	{"CULPEPPER", 9, 94190},
	{"ROHM", 4, 94191},
	{"PRETZEL", 7, 94192},
	{"WARPING", 7, 94193},
	{"RAITT", 5, 94194},
	{"IYER", 4, 94195},
	{"CONNOTATIONS", 12, 94196},
	{"WILBER", 6, 94197},
	{"YARDSTICK", 9, 94198},
	{"NEUTROPHIL", 10, 94199},
	{"SUPERNATANT", 11, 94200},
	{"SOLU", 4, 94201},
	{"STORA", 5, 94202},
	{"SEGMENTAL", 9, 94203},
	{"MYEM", 4, 94204},
	{"JANB", 4, 94205},
	{"ETGU", 4, 94206},
	{"MULTITUDES", 10, 94207},
	{"IMPERIUM", 8, 94208},
	{"RADLEY", 6, 94209},
	{"SUPERCHARGER", 12, 94210},
	{"IMAGEN", 6, 94211},
	{"THICKNESSES", 11, 94212},
	{"BRK", 3, 94213},
	{"SPROUTING", 9, 94214},
	{"SPEW", 4, 94215},
	{"VESTIBULAR", 10, 94216},
	{"KLAUSNER", 8, 94217},
	{"RIBA", 4, 94218},
	{"WITTEN", 6, 94219},
	{"PFOO", 4, 94220},
	{"NGUM", 4, 94221},
	{"CTVE", 4, 94222},
	{"CALAVERAS", 9, 94223},
	{"DECELERATION", 12, 94224},
	{"SUMMONING", 9, 94225},
	{"CONSIGNEE", 9, 94226},
	{"ALDEHYDE", 8, 94227},
	{"PRONGED", 7, 94228},
	{"LIOW", 4, 94229},
	{"ICUP", 4, 94230},
	{"BARING", 6, 94231},
	{"JACKED", 6, 94232},
	{"BIGALOW", 7, 94233},
	{"GYD", 3, 94234},
	{"ANNABEL", 7, 94235},
	{"MRIV", 4, 94236},
	{"TARTAR", 6, 94237},
	{"CENTERFOLDS", 11, 94238},
	{"BROWNISH", 8, 94239},
	{"ORTOFON", 7, 94240},
	{"CROPLAND", 8, 94241},
	{"NAZISM", 6, 94242},
	{"KINGSWOOD", 9, 94243},
	{"OPERATIONALLY", 13, 94244},
	{"TRIX", 4, 94245},
	{"TESTICLE", 8, 94246},
	{"RIOJA", 5, 94247},
	{"UGCA", 4, 94248},
	{"RWWW", 4, 94249},
	{"RIAV", 4, 94250},
	{"MPSP", 4, 94251},
	{"MLIG", 4, 94252},
	{"HFLI", 4, 94253},
	{"FTFL", 4, 94254},
	{"AXWA", 4, 94255},
	{"REJOIN", 6, 94256},
	{"ROSETTES", 8, 94257},
	{"TECHNOLO", 8, 94258},
	{"LINDSTROM", 9, 94259},
	{"PINTER", 6, 94260},
	{"MINOX", 5, 94261},
	{"ILGI", 4, 94262},
	{"CRYA", 4, 94263},
	{"WOFFORD", 7, 94264},
	{"GUAIFENESIN", 11, 94265},
	{"BIFIDA", 6, 94266},
	{"STRATIGRAPHIC", 13, 94267},
	{"DUNDALK", 7, 94268},
	{"SNIPERS", 7, 94269},
	{"KSHIRSAGAR", 10, 94270},
	{"RIDGECREST", 10, 94271},
	{"PLACERVILLE", 11, 94272},
	{"GOSPORT", 7, 94273},
	{"UGLE", 4, 94274},
	{"IRCD", 4, 94275},
	{"RUBRICS", 7, 94276},
	{"KEROUAC", 7, 94277},
	{"HARKEN", 6, 94278},
	{"VOLITION", 8, 94279},
	{"COOPERATED", 10, 94280},
	{"PEBA", 4, 94281},
	{"NOVW", 4, 94282},
	{"CRAWLS", 6, 94283},
	{"KEARNY", 6, 94284},
	{"SHOPINFO", 8, 94285},
	{"SUAVE", 5, 94286},
	{"RIDDANCE", 8, 94287},
	{"TMYR", 4, 94288},
	{"ODDW", 4, 94289},
	{"GULP", 4, 94290},
	{"GREAVES", 7, 94291},
	{"LOTTIE", 6, 94292},
	{"LURK", 4, 94293},
	{"VERSITY", 7, 94294},
	{"AMOCO", 5, 94295},
	{"INZEST", 6, 94296},
	{"SMUDGE", 6, 94297},
	{"YMNS", 4, 94298},
	{"WKST", 4, 94299},
	{"UNYO", 4, 94300},
	{"QUEG", 4, 94301},
	{"NJOK", 4, 94302},
	{"LCAV", 4, 94303},
	{"DPAM", 4, 94304},
	{"DMOH", 4, 94305},
	{"BAGR", 4, 94306},
	{"TULLE", 5, 94307},
	{"MSDOS", 5, 94308},
	{"GABBY", 5, 94309},
	{"HELPLESSNESS", 12, 94310},
	{"DUMBBELLS", 9, 94311},
	{"NCAAF", 5, 94312},
	{"HODU", 4, 94313},
	{"GVES", 4, 94314},
	{"EEUC", 4, 94315},
	{"AWME", 4, 94316},
	{"XIMAGE", 6, 94317},
	{"MNIG", 4, 94318},
	{"MIWH", 4, 94319},
	{"DSVO", 4, 94320},
	{"DERMOT", 6, 94321},
	{"IRONWOOD", 8, 94322},
	{"ADIABATIC", 9, 94323},
	{"PEND", 4, 94324},
	{"NATURALISM", 10, 94325},
	{"LICZNIK", 7, 94326},
	{"CCK", 3, 94327},
	{"SABIAN", 6, 94328},
	{"SAXTON", 6, 94329},
	{"OSUD", 4, 94330},
	{"GHVE", 4, 94331},
	{"PATTIES", 7, 94332},
	{"PXY", 3, 94333},
	{"KRQ", 3, 94334},
	{"FGX", 3, 94335},
	{"HOPKINTON", 9, 94336},
	{"BIOTHERM", 8, 94337},
	{"VIDEOCHAT", 9, 94338},
	{"CANTWELL", 8, 94339},
	{"ACCELEROMETER", 13, 94340},
	{"FILIP", 5, 94341},
	{"XREB", 4, 94342},
	{"OPAB", 4, 94343},
	{"OGBA", 4, 94344},
	{"KBYS", 4, 94345},
	{"BPER", 4, 94346},
	{"ADAJ", 4, 94347},
	{"COLLE", 5, 94348},
	{"GALLOPING", 9, 94349},
	{"INDESTRUCTIBLE", 14, 94350},
	{"PRODUCTIO", 9, 94351},
	{"PRINCIPALITY", 12, 94352},
	{"MILLI", 5, 94353},
	{"BEDAVA", 6, 94354},
	{"GMYT", 4, 94355},
	{"EDYM", 4, 94356},
	{"PENOBSCOT", 9, 94357},
	{"GRAV", 4, 94358},
	{"LLCS", 4, 94359},
	{"FMR", 3, 94360},
	{"PIMSLEUR", 8, 94361},
	{"MICKY", 5, 94362},
	{"SETCL", 5, 94363},
	{"JOHNATHAN", 9, 94364},
	{"ALISHA", 6, 94365},
	{"ZVOU", 4, 94366},
	{"PAFE", 4, 94367},
	{"GEPH", 4, 94368},
	{"BUML", 4, 94369},
	{"GAMBIER", 7, 94370},
	{"ENTERTA", 7, 94371},
	{"CROSLEY", 7, 94372},
	{"USACE", 5, 94373},
	{"BYRDS", 5, 94374},
	{"INDULGING", 9, 94375},
	{"DARREL", 6, 94376},
	{"ALLUSION", 8, 94377},
	{"ISOLA", 5, 94378},
	{"LAMINATOR", 9, 94379},
	{"KRAZY", 5, 94380},
	{"DIARYLAND", 9, 94381},
	{"UTIB", 4, 94382},
	{"SKUR", 4, 94383},
	{"OLFU", 4, 94384},
	{"NYUA", 4, 94385},
	{"KYOS", 4, 94386},
	{"SAMARIA", 7, 94387},
	{"BHUBANESHWAR", 12, 94388},
	{"SMEARED", 7, 94389},
	{"QUADRATURE", 10, 94390},
	{"SUMMERLAND", 10, 94391},
	{"ALESSANDRA", 10, 94392},
	{"GOUVERNEMENT", 12, 94393},
	{"LIQUEURS", 8, 94394},
	{"TEMG", 4, 94395},
	{"RFOS", 4, 94396},
	{"MAYK", 4, 94397},
	{"HECW", 4, 94398},
	{"DENTRY", 6, 94399},
	{"CATSKILLS", 9, 94400},
	{"TABLECLOTHS", 11, 94401},
	{"HERDER", 6, 94402},
	{"CINEMATICAL", 11, 94403},
	{"OUTFALL", 7, 94404},
	{"UNZIPPED", 8, 94405},
	{"WINIFRED", 8, 94406},
	{"PARASOL", 7, 94407},
	{"PLCC", 4, 94408},
	{"INTERCHANGEABLY", 15, 94409},
	{"UEAK", 4, 94410},
	{"TVEG", 4, 94411},
	{"OKMI", 4, 94412},
	{"MYET", 4, 94413},
	{"KPEN", 4, 94414},
	{"ERVS", 4, 94415},
	{"ERDB", 4, 94416},
	{"COSF", 4, 94417},
	{"CONCURS", 7, 94418},
	{"DEFORMATIONS", 12, 94419},
	{"FARTING", 7, 94420},
	{"NONSPECIFIC", 11, 94421},
	{"XSCO", 4, 94422},
	{"WECR", 4, 94423},
	{"GPIP", 4, 94424},
	{"ATOPIC", 6, 94425},
	{"COLORATION", 10, 94426},
	{"HARKER", 6, 94427},
	{"CULLING", 7, 94428},
	{"STINGY", 6, 94429},
	{"LIMON", 5, 94430},
	{"MURATA", 6, 94431},
	{"ZEALOT", 6, 94432},
	{"ARCA", 4, 94433},
	{"JMC", 3, 94434},
	{"SUCCINCTLY", 10, 94435},
	{"XTOP", 4, 94436},
	{"UYAL", 4, 94437},
	{"UPYT", 4, 94438},
	{"TOYU", 4, 94439},
	{"DVIB", 4, 94440},
	{"DRRO", 4, 94441},
	{"CORZ", 4, 94442},
	{"SISLEY", 6, 94443},
	{"IVECO", 5, 94444},
	{"GOOEY", 5, 94445},
	{"BIELEFELD", 9, 94446},
	{"PARROTT", 7, 94447},
	{"VEILLARD", 8, 94448},
	{"LISINOPRIL", 10, 94449},
	{"NPRM", 4, 94450},
	{"DEVOTES", 7, 94451},
	{"XTBA", 4, 94452},
	{"OLRA", 4, 94453},
	{"LDRY", 4, 94454},
	{"HEYQ", 4, 94455},
	{"DSYE", 4, 94456},
	{"DLAV", 4, 94457},
	{"CYFI", 4, 94458},
	{"TOOKIE", 6, 94459},
	{"MANET", 5, 94460},
	{"SHANTI", 6, 94461},
	{"BURKETT", 7, 94462},
	{"WEMON", 5, 94463},
	{"TURMERIC", 8, 94464},
	{"CARNELIAN", 9, 94465},
	{"VIGOUR", 6, 94466},
	{"WWWN", 4, 94467},
	{"EFOG", 4, 94468},
	{"GEOM", 4, 94469},
	{"DORMAN", 6, 94470},
	{"HMAC", 4, 94471},
	{"ABSTRACTING", 11, 94472},
	{"SNARES", 6, 94473},
	{"PARIETAL", 8, 94474},
	{"GLYPHOSATE", 10, 94475},
	{"UNDERPANTS", 10, 94476},
	{"APPLESEED", 9, 94477},
	{"MANDATING", 9, 94478},
	{"PREQUALIFICATION", 16, 94479},
	{"MACROSS", 7, 94480},
	{"KONDO", 5, 94481},
	{"XORS", 4, 94482},
	{"EPIK", 4, 94483},
	{"DCEA", 4, 94484},
	{"BHAG", 4, 94485},
	{"AMQU", 4, 94486},
	{"SCHNELL", 7, 94487},
	{"MUZI", 4, 94488},
	{"BIDET", 5, 94489},
	{"GRUBB", 5, 94490},
	{"REDIF", 5, 94491},
	{"DOMENICI", 8, 94492},
	{"TRANSDERMAL", 11, 94493},
	{"ABRAMSON", 8, 94494},
	{"UYFO", 4, 94495},
	{"RDAH", 4, 94496},
	{"OBSM", 4, 94497},
	{"LUBN", 4, 94498},
	{"KIBE", 4, 94499},
	{"ILLEGIBLE", 9, 94500},
	{"RECREATING", 10, 94501},
	{"MORTARS", 7, 94502},
	{"DIDST", 5, 94503},
	{"DUCTILE", 7, 94504},
	{"DIMENSIONLESS", 13, 94505},
	{"CURIOSITIES", 11, 94506},
	{"CAREX", 5, 94507},
	{"WITHER", 6, 94508},
	{"RSSQ", 4, 94509},
	{"NDDW", 4, 94510},
	{"CONTRACTUALLY", 13, 94511},
	{"KIPPUR", 6, 94512},
	{"FIBROIDS", 8, 94513},
	{"COURTYARDS", 10, 94514},
	{"CALDERON", 8, 94515},
	{"DOGSTER", 7, 94516},
	{"FLATTENING", 10, 94517},
	{"STERILIZED", 10, 94518},
	{"PKCS", 4, 94519},
	{"UNFORMATTED", 11, 94520},
	{"UTSR", 4, 94521},
	{"PEDK", 4, 94522},
	{"EIMC", 4, 94523},
	{"DYAF", 4, 94524},
	{"DNIX", 4, 94525},
	{"AXMO", 4, 94526},
	{"CVR", 3, 94527},
	{"INSULATE", 8, 94528},
	{"SCHLOSS", 7, 94529},
	{"TUOLUMNE", 8, 94530},
	{"TCAF", 4, 94531},
	{"RKCU", 4, 94532},
	{"FSHR", 4, 94533},
	{"CDOU", 4, 94534},
	{"COBBLESTONE", 11, 94535},
	{"SHOWPLACE", 9, 94536},
	{"STOCKPILES", 10, 94537},
	{"MANDIR", 6, 94538},
	{"AUTORE", 6, 94539},
	{"ASHISH", 6, 94540},
	{"MEIJER", 6, 94541},
	{"SEAMED", 6, 94542},
	{"WGIR", 4, 94543},
	{"UKNE", 4, 94544},
	{"RBYJ", 4, 94545},
	{"MOSU", 4, 94546},
	{"KYOA", 4, 94547},
	{"CAMBERLEY", 9, 94548},
	{"BABSON", 6, 94549},
	{"FIENNES", 7, 94550},
	{"METEOROLOGIST", 13, 94551},
	{"COLONOSCOPY", 11, 94552},
	{"CALMED", 6, 94553},
	{"FLATTERED", 9, 94554},
	{"LOFI", 4, 94555},
	{"BABBLING", 8, 94556},
	{"TRYP", 4, 94557},
	{"DUROMINE", 8, 94558},
	{"EPHW", 4, 94559},
	{"ALKALOIDS", 9, 94560},
	{"QUESNEL", 7, 94561},
	{"INITRD", 6, 94562},
	{"CENTRALITY", 10, 94563},
	{"PISSES", 6, 94564},
	{"ROCH", 4, 94565},
	{"VIEG", 4, 94566},
	{"MEZO", 4, 94567},
	{"GEHU", 4, 94568},
	{"CAMPAIGNED", 10, 94569},
	{"ADMIRABLY", 9, 94570},
	{"VIPERS", 6, 94571},
	{"TWINNING", 8, 94572},
	{"IMAG", 4, 94573},
	{"TASTER", 6, 94574},
	{"GREENLIGHT", 10, 94575},
	{"MUSICBRAINZ", 11, 94576},
	{"NIGHTFALL", 9, 94577},
	{"SOURDOUGH", 9, 94578},
	{"XTBI", 4, 94579},
	{"REKK", 4, 94580},
	{"NKTW", 4, 94581},
	{"MWHY", 4, 94582},
	{"JOBG", 4, 94583},
	{"FATB", 4, 94584},
	{"ELQU", 4, 94585},
	{"CUPM", 4, 94586},
	{"WARRANTLESS", 11, 94587},
	{"MZM", 3, 94588},
	{"CROAT", 5, 94589},
	{"ARBORS", 6, 94590},
	{"CANWEST", 7, 94591},
	{"UBBS", 4, 94592},
	{"RMBR", 4, 94593},
	{"PBLA", 4, 94594},
	{"MDAL", 4, 94595},
	{"KAOR", 4, 94596},
	{"CATP", 4, 94597},
	{"HOMEDICS", 8, 94598},
	{"ANYDVD", 6, 94599},
	{"ASHTRAYS", 8, 94600},
	{"PUNTERS", 7, 94601},
	{"WNIM", 4, 94602},
	{"URLU", 4, 94603},
	{"CTFL", 4, 94604},
	{"DROPPER", 7, 94605},
	{"SARKAR", 6, 94606},
	{"MANOS", 5, 94607},
	{"SZABO", 5, 94608},
	{"WACK", 4, 94609},
	{"FETTE", 5, 94610},
	{"ROSR", 4, 94611},
	{"RGEJ", 4, 94612},
	{"GMIR", 4, 94613},
	{"EORK", 4, 94614},
	{"HURL", 4, 94615},
	{"LOYALISTS", 9, 94616},
	{"SPYRO", 5, 94617},
	{"KENDO", 5, 94618},
	{"SURINAM", 7, 94619},
	{"SUZE", 4, 94620},
	{"XENOPHOBIA", 10, 94621},
	{"DORY", 4, 94622},
	{"SHELTERING", 10, 94623},
	{"UEZO", 4, 94624},
	{"NRAW", 4, 94625},
	{"EXSC", 4, 94626},
	{"DRYL", 4, 94627},
	{"KRYPTON", 7, 94628},
	{"HEISENBERG", 10, 94629},
	{"DVCAM", 5, 94630},
	{"NARY", 4, 94631},
	{"RECONFIGURABLE", 14, 94632},
	{"SMIL", 4, 94633},
	{"COURCHEVEL", 10, 94634},
	{"KITTIE", 6, 94635},
	{"LIPMAN", 6, 94636},
	{"CHUCKY", 6, 94637},
	{"SCHLAMPE", 8, 94638},
	{"UBOT", 4, 94639},
	{"RSYI", 4, 94640},
	{"NKEM", 4, 94641},
	{"FTHY", 4, 94642},
	{"BIEB", 4, 94643},
	{"WEBDEV", 6, 94644},
	{"DOUBLECLICK", 11, 94645},
	{"BUSHMAN", 7, 94646},
	{"FOREGO", 6, 94647},
	{"CONEXANT", 8, 94648},
	{"HYDROXYLASE", 11, 94649},
	{"CASTILE", 7, 94650},
	{"QUOF", 4, 94651},
	{"CHYT", 4, 94652},
	{"BBES", 4, 94653},
	{"MULTIPASS", 9, 94654},
	{"WOODWINDS", 9, 94655},
	{"KLASSE", 6, 94656},
	{"TELEFOON", 8, 94657},
	{"RLSE", 4, 94658},
	{"PDEN", 4, 94659},
	{"PBAL", 4, 94660},
	{"OARU", 4, 94661},
	{"EXDE", 4, 94662},
	{"EDIK", 4, 94663},
	{"BLOCKQUOTE", 10, 94664},
	{"RICOTTA", 7, 94665},
	{"MOTORWAYS", 9, 94666},
	{"GANDHINAGAR", 11, 94667},
	{"EDELWEISS", 9, 94668},
	{"FRAMPTON", 8, 94669},
	{"TYROL", 5, 94670},
	{"HUMIDOR", 7, 94671},
	{"VACATIONING", 11, 94672},
	{"IRREPARABLE", 11, 94673},
	{"IMMUNITIES", 10, 94674},
	{"NATURALIZER", 11, 94675},
	{"DINESH", 6, 94676},
	{"TCUB", 4, 94677},
	{"BROILED", 7, 94678},
	{"SUPERSTITIOUS", 13, 94679},
	{"TECHASSIST", 10, 94680},
	{"AIRDRIE", 7, 94681},
	{"SCHIPHOL", 8, 94682},
	{"BRUNER", 6, 94683},
	{"TANGY", 5, 94684},
	{"EVANGELISTS", 11, 94685},
	{"YLYN", 4, 94686},
	{"ARLL", 4, 94687},
	{"INSIDES", 7, 94688},
	{"SEDATIVE", 8, 94689},
	{"GURNEE", 6, 94690},
	{"BOGDAN", 6, 94691},
	{"FARINA", 6, 94692},
	{"COKIN", 5, 94693},
	{"TRICITY", 7, 94694},
	{"CUTAWAY", 7, 94695},
	{"ZEWS", 4, 94696},
	{"MIAR", 4, 94697},
	{"DEFRAUD", 7, 94698},
	{"TOOTHED", 7, 94699},
	{"ARTSY", 5, 94700},
	{"SEVERABILITY", 12, 94701},
	{"TRANSFEROR", 10, 94702},
	{"BYGONE", 6, 94703},
	{"CLICHES", 7, 94704},
	{"NOSFERATU", 9, 94705},
	{"INDYCAR", 7, 94706},
	{"MWEI", 4, 94707},
	{"KBAT", 4, 94708},
	{"EJED", 4, 94709},
	{"CTCU", 4, 94710},
	{"KLIMT", 5, 94711},
	{"ONETOUCH", 8, 94712},
	{"DOONEY", 6, 94713},
	{"WILDS", 5, 94714},
	{"INTERCESSION", 12, 94715},
	{"COMPLET", 7, 94716},
	{"OCONEE", 6, 94717},
	{"SMARTBARGAINS", 13, 94718},
	{"PRL", 3, 94719},
	{"LETTERED", 8, 94720},
	{"MIRADA", 6, 94721},
	{"SACKVILLE", 9, 94722},
	{"CAMBERWELL", 10, 94723},
	{"HOTLINES", 8, 94724},
	{"YWAV", 4, 94725},
	{"OOLV", 4, 94726},
	{"FUPP", 4, 94727},
	{"HAZELTON", 8, 94728},
	{"REAFFIRMS", 9, 94729},
	{"ANLEITUNG", 9, 94730},
	{"WEBALIZER", 9, 94731},
	{"APRICOTS", 8, 94732},
	{"DARKENING", 9, 94733},
	{"LIBBOOST", 8, 94734},
	{"YIDD", 4, 94735},
	{"RIDB", 4, 94736},
	{"GOLDS", 5, 94737},
	{"DEPRESSIONS", 11, 94738},
	{"CORANTE", 7, 94739},
	{"RECIPESOURCE", 12, 94740},
	{"MACHE", 5, 94741},
	{"RANCHING", 8, 94742},
	{"SEGUIN", 6, 94743},
	{"YEFO", 4, 94744},
	{"LOSR", 4, 94745},
	{"IUMG", 4, 94746},
	{"EAMV", 4, 94747},
	{"TOASTING", 8, 94748},
	{"CALDERDALE", 10, 94749},
	{"ANZEIGE", 7, 94750},
	{"TOOTHPICK", 9, 94751},
	{"VOLSER", 6, 94752},
	{"EXHALE", 6, 94753},
	{"WESTCOAST", 9, 94754},
	{"VVJ", 3, 94755},
	{"JRQ", 3, 94756},
	{"JGF", 3, 94757},
	{"BZM", 3, 94758},
	{"FORWARDERS", 10, 94759},
	{"LIKABLE", 7, 94760},
	{"ASHBURTON", 9, 94761},
	{"NATROL", 6, 94762},
	{"SONSTIGES", 9, 94763},
	{"SHOESTRING", 10, 94764},
	{"MARKT", 5, 94765},
	{"BRADS", 5, 94766},
	{"WINSITE", 7, 94767},
	{"WHIRLING", 8, 94768},
	{"SVEL", 4, 94769},
	{"RWAK", 4, 94770},
	{"RHUB", 4, 94771},
	{"LIPC", 4, 94772},
	{"DOGHOUSE", 8, 94773},
	{"ALTARS", 6, 94774},
	{"DISPLAYTIME", 11, 94775},
	{"RANITIDINE", 10, 94776},
	{"ABOLISHING", 10, 94777},
	{"CHAUNCEY", 8, 94778},
	{"GREBE", 5, 94779},
	{"RYLS", 4, 94780},
	{"RUPU", 4, 94781},
	{"RKCE", 4, 94782},
	{"STANDUP", 7, 94783},
	{"PLAYGIRL", 8, 94784},
	{"FLEXION", 7, 94785},
	{"RECESSES", 8, 94786},
	{"KINSMAN", 7, 94787},
	{"IBEX", 4, 94788},
	{"GEOMAGNETIC", 11, 94789},
	{"REPC", 4, 94790},
	{"OEGY", 4, 94791},
	{"IRAV", 4, 94792},
	{"HYAC", 4, 94793},
	{"BEYS", 4, 94794},
	{"LOWESTOFT", 9, 94795},
	{"BLOBS", 5, 94796},
	{"FOOTERS", 7, 94797},
	{"REISS", 5, 94798},
	{"LEWISTOWN", 9, 94799},
	{"DROPPINGS", 9, 94800},
	{"DESIGNATOR", 10, 94801},
	{"CAUSATIVE", 9, 94802},
	{"MVOL", 4, 94803},
	{"FTGU", 4, 94804},
	{"EZCO", 4, 94805},
	{"WOOLRICH", 8, 94806},
	{"GWASANAETHAU", 12, 94807},
	{"KEEFE", 5, 94808},
	{"PAYED", 5, 94809},
	{"LOVESEAT", 8, 94810},
	{"DIETHYLPROPION", 14, 94811},
	{"WNGE", 4, 94812},
	{"RAHB", 4, 94813},
	{"ONPP", 4, 94814},
	{"ILYJ", 4, 94815},
	{"FSYD", 4, 94816},
	{"ATYR", 4, 94817},
	{"KARYN", 5, 94818},
	{"OVERWORKED", 10, 94819},
	{"HANDEDLY", 8, 94820},
	{"UNCONTESTED", 11, 94821},
	{"CECILE", 6, 94822},
	{"ORBS", 4, 94823},
	{"DOXORUBICIN", 11, 94824},
	{"NERJA", 5, 94825},
	{"VDAN", 4, 94826},
	{"EDZA", 4, 94827},
	{"CARDIOLOGISTS", 13, 94828},
	{"MUTABLE", 7, 94829},
	{"MILITARILY", 10, 94830},
	{"DELICACIES", 10, 94831},
	{"FSUS", 4, 94832},
	{"INFLATING", 9, 94833},
	{"SPUTNIK", 7, 94834},
	{"TOUJOURS", 8, 94835},
	{"YOLI", 4, 94836},
	{"PESR", 4, 94837},
	{"FEWK", 4, 94838},
	{"BAROMETRIC", 10, 94839},
	{"JOBURG", 6, 94840},
	{"ASSERTEQUALS", 12, 94841},
	{"GLADWELL", 8, 94842},
	{"REGROWTH", 8, 94843},
	{"LUSAKA", 6, 94844},
	{"LAMPWORK", 8, 94845},
	{"ADULTOS", 7, 94846},
	{"BANCA", 5, 94847},
	{"DOUGHNUT", 8, 94848},
	{"ZEFR", 4, 94849},
	{"OPPU", 4, 94850},
	{"MVPA", 4, 94851},
	{"GMIX", 4, 94852},
	{"FEIF", 4, 94853},
	{"MARTZ", 5, 94854},
	{"SCORCHING", 9, 94855},
	{"CRIBBAGE", 8, 94856},
	{"MELA", 4, 94857},
	{"RONDO", 5, 94858},
	{"COFFINS", 7, 94859},
	{"TIGR", 4, 94860},
	{"PERSONEL", 8, 94861},
	{"UNOC", 4, 94862},
	{"GYWO", 4, 94863},
	{"DTYR", 4, 94864},
	{"WCPO", 4, 94865},
	{"ACTIV", 5, 94866},
	{"UICONSTRAINTS", 13, 94867},
	{"TYPESCRIPT", 10, 94868},
	{"INETD", 5, 94869},
	{"SCUOLA", 6, 94870},
	{"PISTE", 5, 94871},
	{"PPPD", 4, 94872},
	{"JOVE", 4, 94873},
	{"CASHED", 6, 94874},
	{"USHERS", 6, 94875},
	{"ONDEMAND", 8, 94876},
	{"ALTAMONT", 8, 94877},
	{"ZESM", 4, 94878},
	{"TVRE", 4, 94879},
	{"OMBC", 4, 94880},
	{"STEUBENVILLE", 12, 94881},
	{"RUR", 3, 94882},
	{"DANIELSON", 9, 94883},
	{"JEWRY", 5, 94884},
	{"BARFLY", 6, 94885},
	{"VEGETARIANISM", 13, 94886},
	{"WSGR", 4, 94887},
	{"EXTRACTORS", 10, 94888},
	{"DICTAPHONE", 10, 94889},
	{"COPPERFIELD", 11, 94890},
	{"CHAPELLE", 8, 94891},
	{"MARTINIS", 8, 94892},
	{"ENVISIONS", 9, 94893},
	{"FLEXIBLY", 8, 94894},
	{"NAKD", 4, 94895},
	{"NATWEST", 7, 94896},
	{"WILSONS", 7, 94897},
	{"WHOOP", 5, 94898},
	{"VODK", 4, 94899},
	{"SKYM", 4, 94900},
	{"KFAM", 4, 94901},
	{"FSUD", 4, 94902},
	{"REPOSITION", 10, 94903},
	{"MSCI", 4, 94904},
	{"CACAO", 5, 94905},
	{"ORGINAL", 7, 94906},
	{"HOBBYISTS", 9, 94907},
	{"FLESHBOT", 8, 94908},
	{"SINDH", 5, 94909},
	{"PCF", 3, 94910},
	{"GLICK", 5, 94911},
	{"RIBR", 4, 94912},
	{"MIWO", 4, 94913},
	{"MBWA", 4, 94914},
	{"ILJO", 4, 94915},
	{"IDWR", 4, 94916},
	{"HJEW", 4, 94917},
	{"OBSOLETES", 9, 94918},
	{"MAMMOGRAM", 9, 94919},
	{"LHEF", 4, 94920},
	{"HIMV", 4, 94921},
	{"WEBCASTING", 10, 94922},
	{"SOGGY", 5, 94923},
	{"ECOLOGIST", 9, 94924},
	{"ARARAT", 6, 94925},
	{"NARROWBAND", 10, 94926},
	{"YTIP", 4, 94927},
	{"SMDE", 4, 94928},
	{"GPAU", 4, 94929},
	{"WEBSTORE", 8, 94930},
	{"MAUS", 4, 94931},
	{"REINSTALLING", 12, 94932},
	{"GENDERED", 8, 94933},
	{"RELATEDDIAGRAM", 14, 94934},
	{"ANDRA", 5, 94935},
	{"KINGSLAND", 9, 94936},
	{"ANNOYS", 6, 94937},
	{"XFIL", 4, 94938},
	{"RUBL", 4, 94939},
	{"ODDH", 4, 94940},
	{"RACKETS", 7, 94941},
	{"LITIGANTS", 9, 94942},
	{"SHIMON", 6, 94943},
	{"DUCTED", 6, 94944},
	{"EBSQ", 4, 94945},
	{"CRISPS", 6, 94946},
	{"MODELLE", 7, 94947},
	{"WRISTWATCHES", 12, 94948},
	{"OUDF", 4, 94949},
	{"XENADRINE", 9, 94950},
	{"HEIRESS", 7, 94951},
	{"LINAC", 5, 94952},
	{"IDENTIFICATIONS", 15, 94953},
	{"DRESSY", 6, 94954},
	{"AUTHENTICATOR", 13, 94955},
	{"ARASH", 5, 94956},
	{"VILN", 4, 94957},
	{"KLEH", 4, 94958},
	{"CYAD", 4, 94959},
	{"CRISTOBAL", 9, 94960},
	{"STEWIE", 6, 94961},
	{"DEPOSITORIES", 12, 94962},
	{"PCRE", 4, 94963},
	{"GODHEAD", 7, 94964},
	{"SETPOINT", 8, 94965},
	{"CANVASSING", 10, 94966},
	{"WNEL", 4, 94967},
	{"TZWH", 4, 94968},
	{"RSGL", 4, 94969},
	{"IMMC", 4, 94970},
	{"IGUN", 4, 94971},
	{"ROCKDALE", 8, 94972},
	{"EVITA", 5, 94973},
	{"BALLMER", 7, 94974},
	{"PORTIA", 6, 94975},
	{"SHYNESS", 7, 94976},
	{"HEMPHILL", 8, 94977},
	{"TAORMINA", 8, 94978},
	{"PLATH", 5, 94979},
	{"PICKERS", 7, 94980},
	{"BOARDGAMEGEEK", 13, 94981},
	{"OPFE", 4, 94982},
	{"KATF", 4, 94983},
	{"EUMH", 4, 94984},
	{"SERBO", 5, 94985},
	{"ANGELUS", 7, 94986},
	{"SUBJECTING", 10, 94987},
	{"NOVIEMBRE", 9, 94988},
	{"MAPPOINT", 8, 94989},
	{"SURN", 4, 94990},
	{"MOMENTO", 7, 94991},
	{"PTWE", 4, 94992},
	{"PPOC", 4, 94993},
	{"LAJA", 4, 94994},
	{"MINISD", 6, 94995},
	{"ESCORTE", 7, 94996},
	{"UNSIGHTLY", 9, 94997},
	{"MADMUMS", 7, 94998},
	{"MOSHER", 6, 94999},
	{"DIGITALLIFE", 11, 95000},
	{"GRAHAME", 7, 95001},
	{"FORECASTERS", 11, 95002},
	{"UEEY", 4, 95003},
	{"RTUT", 4, 95004},
	{"RMEW", 4, 95005},
	{"MWEE", 4, 95006},
	{"KLIG", 4, 95007},
	{"GAGN", 4, 95008},
	{"LINOLEUM", 8, 95009},
	{"SHEARLING", 9, 95010},
	{"STOCKSTER", 9, 95011},
	{"FRAYED", 6, 95012},
	{"CRIMINALITY", 11, 95013},
	{"FIRSTCALL", 9, 95014},
	{"DORINT", 6, 95015},
	{"WMC", 3, 95016},
	{"CULVERTS", 8, 95017},
	{"UBAK", 4, 95018},
	{"RMVI", 4, 95019},
	{"MPBU", 4, 95020},
	{"MKAR", 4, 95021},
	{"IKKA", 4, 95022},
	{"GHIF", 4, 95023},
	{"ENKR", 4, 95024},
	{"DSPH", 4, 95025},
	{"BOFR", 4, 95026},
	{"WOOLEN", 6, 95027},
	{"CUTICLE", 7, 95028},
	{"REPOS", 5, 95029},
	{"CODEBASE", 8, 95030},
	{"RDFS", 4, 95031},
	{"LEVELLING", 9, 95032},
	{"LTER", 4, 95033},
	{"PIMPLES", 7, 95034},
	{"TPIP", 4, 95035},
	{"SWIV", 4, 95036},
	{"BOBT", 4, 95037},
	{"SHORTED", 7, 95038},
	{"LOGHI", 5, 95039},
	{"SPUNKY", 6, 95040},
	{"RAZZ", 4, 95041},
	{"KOMATSU", 7, 95042},
	{"BIETET", 6, 95043},
	{"MADISONVILLE", 12, 95044},
	{"READIES", 7, 95045},
	{"SHRAPNEL", 8, 95046},
	{"JOVENES", 7, 95047},
	{"PBER", 4, 95048},
	{"OVEV", 4, 95049},
	{"HLYN", 4, 95050},
	{"EWIK", 4, 95051},
	{"ARTHURIAN", 9, 95052},
	{"BURGOS", 6, 95053},
	{"DEUTERIUM", 9, 95054},
	{"LITANY", 6, 95055},
	{"FAIREST", 7, 95056},
	{"TOTALITARIANISM", 15, 95057},
	{"TRIGONOMETRIC", 13, 95058},
	{"SELMER", 6, 95059},
	{"WEBL", 4, 95060},
	{"UTLU", 4, 95061},
	{"UMIA", 4, 95062},
	{"TGIB", 4, 95063},
	{"MCRU", 4, 95064},
	{"POPCAP", 6, 95065},
	{"NUTTER", 6, 95066},
	{"BRISTLES", 8, 95067},
	{"VERBOSITY", 9, 95068},
	{"AASHTO", 6, 95069},
	{"PAVAROTTI", 9, 95070},
	{"LARDER", 6, 95071},
	{"SYNCING", 7, 95072},
	{"GANGES", 6, 95073},
	{"VANDEN", 6, 95074},
	{"MAJEURE", 7, 95075},
	{"BERET", 5, 95076},
	{"TZKY", 4, 95077},
	{"KRSQ", 4, 95078},
	{"ILKC", 4, 95079},
	{"GBOM", 4, 95080},
	{"FSBU", 4, 95081},
	{"FALLBROOK", 9, 95082},
	{"AUDIOVIDEO", 10, 95083},
	{"MUAY", 4, 95084},
	{"LONGSHOT", 8, 95085},
	{"ROLLAWAY", 8, 95086},
	{"MACHEN", 6, 95087},
	{"UFOU", 4, 95088},
	{"EKME", 4, 95089},
	{"NONSTANDARD", 11, 95090},
	{"MANOA", 5, 95091},
	{"LAUNDRIES", 9, 95092},
	{"TRUTHFULNESS", 12, 95093},
	{"ATROCIOUS", 9, 95094},
	{"TEFAL", 5, 95095},
	{"OBELISK", 7, 95096},
	{"RWRA", 4, 95097},
	{"GKAR", 4, 95098},
	{"DMEF", 4, 95099},
	{"BOYM", 4, 95100},
	{"CRV", 3, 95101},
	{"VALERIA", 7, 95102},
	{"FALIGN", 6, 95103},
	{"GOLETA", 6, 95104},
	{"CLARET", 6, 95105},
	{"HOLST", 5, 95106},
	{"EBOLA", 5, 95107},
	{"REDBOOK", 7, 95108},
	{"RANGEL", 6, 95109},
	{"FRU", 3, 95110},
	{"SAMOS", 5, 95111},
	{"CONSOLIDATES", 12, 95112},
	{"CONSECRATION", 12, 95113},
	{"UYSG", 4, 95114},
	{"EEKV", 4, 95115},
	{"DISAGGREGATED", 13, 95116},
	{"FORBEARANCE", 11, 95117},
	{"CHROMATOGRAPHIC", 15, 95118},
	{"SUPERSPORT", 10, 95119},
	{"GOLLY", 5, 95120},
	{"FLUMOTION", 9, 95121},
	{"SEAGRASS", 8, 95122},
	{"CONGRATULATES", 13, 95123},
	{"GRIEVANT", 8, 95124},
	{"WNFL", 4, 95125},
	{"EPGR", 4, 95126},
	{"REINSTALLED", 11, 95127},
	{"ENTREPRISES", 11, 95128},
	{"ACERCA", 6, 95129},
	{"PLASTERED", 9, 95130},
	{"CLEMONS", 7, 95131},
	{"EUROVISION", 10, 95132},
	{"AIRPLUS", 7, 95133},
	{"PANCHKULA", 9, 95134},
	{"SHAHID", 6, 95135},
	{"PHOSPHOLIPIDS", 13, 95136},
	{"LEDQ", 4, 95137},
	{"GKAN", 4, 95138},
	{"ELSINORE", 8, 95139},
	{"APOSTROPHE", 10, 95140},
	{"ANKENY", 6, 95141},
	{"CANZONI", 7, 95142},
	{"WAKEMAN", 7, 95143},
	{"GIWO", 4, 95144},
	{"YQP", 3, 95145},
	{"QGL", 3, 95146},
	{"MOANA", 5, 95147},
	{"WOBBLY", 6, 95148},
	{"STEPMOTHER", 10, 95149},
	{"SEAGULLS", 8, 95150},
	{"RUF", 3, 95151},
	{"MEGAWATTS", 9, 95152},
	{"DENNING", 7, 95153},
	{"XASD", 4, 95154},
	{"PETF", 4, 95155},
	{"DRIZ", 4, 95156},
	{"LAPLAND", 7, 95157},
	{"TEMAS", 5, 95158},
	{"ILLUMINATOR", 11, 95159},
	{"MARYLEBONE", 10, 95160},
	{"SYMBOLICALLY", 12, 95161},
	{"EROTICO", 7, 95162},
	{"LINX", 4, 95163},
	{"RANDLE", 6, 95164},
	{"UNSUBSTANTIATED", 15, 95165},
	{"CENTROID", 8, 95166},
	{"MONOGRAMMED", 11, 95167},
	{"PUBLIUS", 7, 95168},
	{"GAMBIAN", 7, 95169},
	{"TAILGATING", 10, 95170},
	{"ZCAN", 4, 95171},
	{"LPSW", 4, 95172},
	{"COLVILLE", 8, 95173},
	{"JESUITS", 7, 95174},
	{"VPU", 3, 95175},
	{"RUSSISCHE", 9, 95176},
	{"VOLUMINOUS", 10, 95177},
	{"MOTTLED", 7, 95178},
	{"PLU", 3, 95179},
	{"SOCCERNET", 9, 95180},
	{"ZING", 4, 95181},
	{"PEFA", 4, 95182},
	{"GNBA", 4, 95183},
	{"FGIL", 4, 95184},
	{"AGGO", 4, 95185},
	{"DOWNUNDER", 9, 95186},
	{"SNIPS", 5, 95187},
	{"ALLAWI", 6, 95188},
	{"LOCKUP", 6, 95189},
	{"TOSSES", 6, 95190},
	{"CHOLINERGIC", 11, 95191},
	{"MANIFESTING", 11, 95192},
	{"BARTHELEMY", 10, 95193},
	{"BABYMINT", 8, 95194},
	{"ESTELLA", 7, 95195},
	{"SDWI", 4, 95196},
	{"OFOD", 4, 95197},
	{"HRYN", 4, 95198},
	{"HEKY", 4, 95199},
	{"FGAI", 4, 95200},
	{"BENNING", 7, 95201},
	{"IMPLANTABLE", 11, 95202},
	{"LIGO", 4, 95203},
	{"HADDAD", 6, 95204},
	{"UNIVARIATE", 10, 95205},
	{"KATIA", 5, 95206},
	{"WRIV", 4, 95207},
	{"WFOL", 4, 95208},
	{"QWAS", 4, 95209},
	{"MKAN", 4, 95210},
	{"FFMI", 4, 95211},
	{"EYIF", 4, 95212},
	{"DFUS", 4, 95213},
	{"DAWR", 4, 95214},
	{"AWOK", 4, 95215},
	{"MOTORCROSS", 10, 95216},
	{"SANGHA", 6, 95217},
	{"PUBLICS", 7, 95218},
	{"MYFONTS", 7, 95219},
	{"NORMANDIE", 9, 95220},
	{"USUARIOS", 8, 95221},
	{"CAML", 4, 95222},
	{"RESILIENCY", 10, 95223},
	{"BAROSSA", 7, 95224},
	{"ASTROBIOLOGY", 12, 95225},
	{"UGSF", 4, 95226},
	{"PDIV", 4, 95227},
	{"OCYC", 4, 95228},
	{"KOFY", 4, 95229},
	{"GEGU", 4, 95230},
	{"ELSV", 4, 95231},
	{"BETY", 4, 95232},
	{"SCRIP", 5, 95233},
	{"DISINFECTANTS", 13, 95234},
	{"KAWAI", 5, 95235},
	{"UKTV", 4, 95236},
	{"DREAMTIME", 9, 95237},
	{"BERKSHIRES", 10, 95238},
	{"INHUMANE", 8, 95239},
	{"ROCHER", 6, 95240},
	{"INADEQUATELY", 12, 95241},
	{"ARABELLA", 8, 95242},
	{"TROBE", 5, 95243},
	{"PSEW", 4, 95244},
	{"GARZ", 4, 95245},
	{"UNLOCKS", 7, 95246},
	{"AUCTEX", 6, 95247},
	{"POGUES", 6, 95248},
	{"PANICKED", 8, 95249},
	{"MATTI", 5, 95250},
	{"DEVELOPERWORKS", 14, 95251},
	{"BULLITT", 7, 95252},
	{"THRONG", 6, 95253},
	{"FLEMMING", 8, 95254},
	{"RBYU", 4, 95255},
	{"LEEU", 4, 95256},
	{"LAHW", 4, 95257},
	{"FKAL", 4, 95258},
	{"EBUK", 4, 95259},
	{"SMARTCARD", 9, 95260},
	{"KUSHNER", 7, 95261},
	{"CRUMP", 5, 95262},
	{"GUNDERSON", 9, 95263},
	{"PARAMUS", 7, 95264},
	{"CEPR", 4, 95265},
	{"OPBR", 4, 95266},
	{"EXLI", 4, 95267},
	{"DMUD", 4, 95268},
	{"POLITICA", 8, 95269},
	{"RANDOMIZATION", 13, 95270},
	{"RINSING", 7, 95271},
	{"RESCHEDULE", 10, 95272},
	{"HOSTAL", 6, 95273},
	{"PREEMPT", 7, 95274},
	{"SHUNNED", 7, 95275},
	{"ABANDONS", 8, 95276},
	{"RESOLD", 6, 95277},
	{"CYCLO", 5, 95278},
	{"PHOSPHOR", 8, 95279},
	{"ILKO", 4, 95280},
	{"CATB", 4, 95281},
	{"FRONTENAC", 9, 95282},
	{"WIPEOUT", 7, 95283},
	{"MAMBOTS", 7, 95284},
	{"APPETITES", 9, 95285},
	{"UNSCENTED", 9, 95286},
	{"IPFW", 4, 95287},
	{"ERGONOMICALLY", 13, 95288},
	{"ROOSTERS", 8, 95289},
	{"LORING", 6, 95290},
	{"UMSR", 4, 95291},
	{"ILMV", 4, 95292},
	{"DOXF", 4, 95293},
	{"IONOSPHERE", 10, 95294},
	{"BELVIDERE", 9, 95295},
	{"TROTSKY", 7, 95296},
	{"AIRWORTHINESS", 13, 95297},
	{"SISTEMAS", 8, 95298},
	{"DEVSOURCE", 9, 95299},
	{"TURNIP", 6, 95300},
	{"RETROVIRAL", 10, 95301},
	{"JUXTAPOSITION", 13, 95302},
	{"OWJE", 4, 95303},
	{"ODIP", 4, 95304},
	{"ILIW", 4, 95305},
	{"ERGF", 4, 95306},
	{"ARWR", 4, 95307},
	{"AKWO", 4, 95308},
	{"LLNL", 4, 95309},
	{"KEYLOGGERS", 10, 95310},
	{"AMGEN", 5, 95311},
	{"MARCI", 5, 95312},
	{"WILLEY", 6, 95313},
	{"GROUCHO", 7, 95314},
	{"CRUSHES", 7, 95315},
	{"FORESHORE", 9, 95316},
	{"MAXE", 4, 95317},
	{"CARNIVOROUS", 11, 95318},
	{"BERBER", 6, 95319},
	{"GUSSET", 6, 95320},
	{"DISSAPOINTED", 12, 95321},
	{"MINCE", 5, 95322},
	{"DTDS", 4, 95323},
	{"BANISH", 6, 95324},
	{"MIBS", 4, 95325},
	{"HLAM", 4, 95326},
	{"GROP", 4, 95327},
	{"METALWORK", 9, 95328},
	{"FLAPPING", 8, 95329},
	{"REFERING", 8, 95330},
	{"PUNTING", 7, 95331},
	{"FRETS", 5, 95332},
	{"TRIPHASIL", 9, 95333},
	{"SCAB", 4, 95334},
	{"BHAVNAGAR", 9, 95335},
	{"SCHISM", 6, 95336},
	{"CREEDENCE", 9, 95337},
	{"MUSEE", 5, 95338},
	{"PENY", 4, 95339},
	{"WELLSTONE", 9, 95340},
	{"SCULPTURED", 10, 95341},
	{"LLEOL", 5, 95342},
	{"GPIB", 4, 95343},
	{"TIDBIT", 6, 95344},
	{"SUIVANT", 7, 95345},
	{"WOEV", 4, 95346},
	{"EUKC", 4, 95347},
	{"BTWI", 4, 95348},
	{"ALLYSON", 7, 95349},
	{"TERIYAKI", 8, 95350},
	{"JEMIMA", 6, 95351},
	{"IMPOUNDMENT", 11, 95352},
	{"INTERRELATIONSHIPS", 18, 95353},
	{"GRES", 4, 95354},
	{"COFFEECUP", 9, 95355},
	{"MARU", 4, 95356},
	{"UEDL", 4, 95357},
	{"INYF", 4, 95358},
	{"JOSEPHUS", 8, 95359},
	{"ULONG", 5, 95360},
	{"MAPUTO", 6, 95361},
	{"HERETICS", 8, 95362},
	{"CHEV", 4, 95363},
	{"DOGGED", 6, 95364},
	{"KRISPY", 6, 95365},
	{"DOGTOWN", 7, 95366},
	{"APPARITION", 10, 95367},
	{"ABERNATHY", 9, 95368},
	{"MBRU", 4, 95369},
	{"GHKI", 4, 95370},
	{"EKPA", 4, 95371},
	{"BARRISTERS", 10, 95372},
	{"FERMION", 7, 95373},
	{"WELTWEIT", 8, 95374},
	{"FLUOR", 5, 95375},
	{"BERGSTROM", 9, 95376},
	{"INOPERABLE", 10, 95377},
	{"ESRC", 4, 95378},
	{"ASDF", 4, 95379},
	{"YURG", 4, 95380},
	{"UMSM", 4, 95381},
	{"RJAI", 4, 95382},
	{"PEDV", 4, 95383},
	{"LSIR", 4, 95384},
	{"CBLA", 4, 95385},
	{"ARUI", 4, 95386},
	{"GOLLUM", 6, 95387},
	{"SCRUTINIZED", 11, 95388},
	{"EARTHWORKS", 10, 95389},
	{"THRASHING", 9, 95390},
	{"CEUS", 4, 95391},
	{"SALOME", 6, 95392},
	{"MACINTYRE", 9, 95393},
	{"CYCLONIC", 8, 95394},
	{"TDUS", 4, 95395},
	{"FNOM", 4, 95396},
	{"UNSUBSCRIBING", 13, 95397},
	{"SHAWNA", 6, 95398},
	{"PINYIN", 6, 95399},
	{"IPAC", 4, 95400},
	{"RAMONE", 6, 95401},
	{"FETHIYE", 7, 95402},
	{"VARA", 4, 95403},
	{"MULTIPATH", 9, 95404},
	{"HAKUSHO", 7, 95405},
	{"TREEVIEW", 8, 95406},
	{"XALS", 4, 95407},
	{"FRYA", 4, 95408},
	{"EDYU", 4, 95409},
	{"WONDERSWAN", 10, 95410},
	{"EUGENICS", 8, 95411},
	{"DUSTJACKET", 10, 95412},
	{"QUENCHING", 9, 95413},
	{"EMMANUELLE", 10, 95414},
	{"DLOCALEDIR", 10, 95415},
	{"HUNCH", 5, 95416},
	{"OOGR", 4, 95417},
	{"HEWM", 4, 95418},
	{"EWGI", 4, 95419},
	{"AMKI", 4, 95420},
	{"MOLOTOV", 7, 95421},
	{"AMARYLLIS", 9, 95422},
	{"SANDPAPER", 9, 95423},
	{"MESSES", 6, 95424},
	{"PERDITION", 9, 95425},
	{"FANNIN", 6, 95426},
	{"INTERSCOPE", 10, 95427},
	{"ULSW", 4, 95428},
	{"MDIN", 4, 95429},
	{"IRTL", 4, 95430},
	{"EAMK", 4, 95431},
	{"BEDN", 4, 95432},
	{"WINTERING", 9, 95433},
	{"TOPPLE", 6, 95434},
	{"MELAYU", 6, 95435},
	{"HARDINESS", 9, 95436},
	{"PHEW", 4, 95437},
	{"FURUNO", 6, 95438},
	{"MOYNIHAN", 8, 95439},
	{"CHICKASAW", 9, 95440},
	{"JOHNSONS", 8, 95441},
	{"PUNGENT", 7, 95442},
	{"DISCONTINUANCE", 14, 95443},
	{"CARBONATED", 10, 95444},
	{"RZEG", 4, 95445},
	{"ORYK", 4, 95446},
	{"EUDE", 4, 95447},
	{"EKFI", 4, 95448},
	{"WAIVES", 6, 95449},
	{"WRAPAROUND", 10, 95450},
	{"EJACKULATION", 12, 95451},
	{"REBOOTS", 7, 95452},
	{"HEADLINER", 9, 95453},
	{"UNBRIDLED", 9, 95454},
	{"BUSTIN", 6, 95455},
	{"RTTW", 4, 95456},
	{"LYSD", 4, 95457},
	{"KSBI", 4, 95458},
	{"EAUP", 4, 95459},
	{"POWERNETWORKER", 14, 95460},
	{"VUL", 3, 95461},
	{"SUPERPOSITION", 13, 95462},
	{"SUPREMES", 8, 95463},
	{"INSITE", 6, 95464},
	{"FANZINE", 7, 95465},
	{"ASTROLOGER", 10, 95466},
	{"LANEY", 5, 95467},
	{"UBOU", 4, 95468},
	{"UALJ", 4, 95469},
	{"ADCI", 4, 95470},
	{"PURPORTEDLY", 11, 95471},
	{"ANTIGENIC", 9, 95472},
	{"RUROUNI", 7, 95473},
	{"DIETETICS", 9, 95474},
	{"ASSEMBLES", 9, 95475},
	{"VERACRUZ", 8, 95476},
	{"HAUSFRAUEN", 10, 95477},
	{"BENZO", 5, 95478},
	{"VIETCONG", 8, 95479},
	{"CHAIRWOMAN", 10, 95480},
	{"TRUF", 4, 95481},
	{"LFPE", 4, 95482},
	{"HMYC", 4, 95483},
	{"FVIT", 4, 95484},
	{"EZOF", 4, 95485},
	{"DPES", 4, 95486},
	{"PETROCHEMICALS", 14, 95487},
	{"CNTR", 4, 95488},
	{"NETTIME", 7, 95489},
	{"PEAF", 4, 95490},
	{"CBEL", 4, 95491},
	{"AMFL", 4, 95492},
	{"TECHIES", 7, 95493},
	{"BENTYXXO", 8, 95494},
	{"XANGO", 5, 95495},
	{"CANVASS", 7, 95496},
	{"RADISH", 6, 95497},
	{"GATTO", 5, 95498},
	{"BIAB", 4, 95499},
	{"MANIFESTLY", 10, 95500},
	{"CHECKMATE", 9, 95501},
	{"GANTT", 5, 95502},
	{"VALLI", 5, 95503},
	{"STARLETS", 8, 95504},
	{"EMPHATIC", 8, 95505},
	{"IGQU", 4, 95506},
	{"EKJE", 4, 95507},
	{"SUSY", 4, 95508},
	{"PLAVIX", 6, 95509},
	{"ROOMBA", 6, 95510},
	{"AFICIONADO", 10, 95511},
	{"MOTIVATOR", 9, 95512},
	{"BIJAN", 5, 95513},
	{"STORRS", 6, 95514},
	{"TABULA", 6, 95515},
	{"OUTGROWTH", 9, 95516},
	{"XBIL", 4, 95517},
	{"UPKI", 4, 95518},
	{"TLUK", 4, 95519},
	{"TKMS", 4, 95520},
	{"SBRY", 4, 95521},
	{"OXAR", 4, 95522},
	{"FALD", 4, 95523},
	{"DIAU", 4, 95524},
	{"REIGATE", 7, 95525},
	{"EMMONS", 6, 95526},
	{"HOMEWARD", 8, 95527},
	{"WITHERED", 8, 95528},
	{"SANDSTORM", 9, 95529},
	{"LACI", 4, 95530},
	{"TAOIST", 6, 95531},
	{"NAMEPLATE", 9, 95532},
	{"BAITING", 7, 95533},
	{"SURRENDERING", 12, 95534},
	{"WCB", 3, 95535},
	{"WUST", 4, 95536},
	{"WSPI", 4, 95537},
	{"LSKY", 4, 95538},
	{"KEAJ", 4, 95539},
	{"AUPT", 4, 95540},
	{"MOTHERING", 9, 95541},
	{"BILLARD", 7, 95542},
	{"CHRYSANTHEMUM", 13, 95543},
	{"RECONSTRUCTIONS", 15, 95544},
	{"INNODB", 6, 95545},
	{"SUNSPOT", 7, 95546},
	{"XXK", 3, 95547},
	{"VXM", 3, 95548},
	{"QUV", 3, 95549},
	{"JYD", 3, 95550},
	{"FZP", 3, 95551},
	{"FLUORINE", 8, 95552},
	{"HEALDSBURG", 10, 95553},
	{"RETYPE", 6, 95554},
	{"FORTIFICATION", 13, 95555},
	{"RKEM", 4, 95556},
	{"LHEP", 4, 95557},
	{"GFAV", 4, 95558},
	{"ELDY", 4, 95559},
	{"MINGO", 5, 95560},
	{"FISHIN", 6, 95561},
	{"LIKUD", 5, 95562},
	{"CYBERREAD", 9, 95563},
	{"ROTHWELL", 8, 95564},
	{"KYCA", 4, 95565},
	{"EWKE", 4, 95566},
	{"CEJE", 4, 95567},
	{"SPURT", 5, 95568},
	{"ELATION", 7, 95569},
	{"KMF", 3, 95570},
	{"CREATIONIST", 11, 95571},
	{"WAIL", 4, 95572},
	{"ARTISTICALLY", 12, 95573},
	{"SETLIST", 7, 95574},
	{"SCROLLBARS", 10, 95575},
	{"ROLG", 4, 95576},
	{"OFFK", 4, 95577},
	{"BOCELLI", 7, 95578},
	{"ZUCKERMAN", 9, 95579},
	{"AMPICILLIN", 10, 95580},
	{"ARCY", 4, 95581},
	{"COWBELL", 7, 95582},
	{"ELMA", 4, 95583},
	{"WLOS", 4, 95584},
	{"MMAH", 4, 95585},
	{"MCDE", 4, 95586},
	{"GMOO", 4, 95587},
	{"AYPH", 4, 95588},
	{"RATER", 5, 95589},
	{"EVERSON", 7, 95590},
	{"EPILEPTIC", 9, 95591},
	{"ANGEBOT", 7, 95592},
	{"CEZANNE", 7, 95593},
	{"CRAG", 4, 95594},
	{"FELLER", 6, 95595},
	{"TAMAGOTCHI", 10, 95596},
	{"EARPIECE", 8, 95597},
	{"YSVA", 4, 95598},
	{"MYCU", 4, 95599},
	{"FEPL", 4, 95600},
	{"FRANCA", 6, 95601},
	{"THYMIDINE", 9, 95602},
	{"GEARLOG", 7, 95603},
	{"TRANCHE", 7, 95604},
	{"ENMITY", 6, 95605},
	{"VOLUM", 5, 95606},
	{"SANCTUM", 7, 95607},
	{"YADH", 4, 95608},
	{"WCOO", 4, 95609},
	{"RFON", 4, 95610},
	{"RDUK", 4, 95611},
	{"RCIO", 4, 95612},
	{"PPUS", 4, 95613},
	{"IECU", 4, 95614},
	{"EZAM", 4, 95615},
	{"MAZES", 5, 95616},
	{"PRSP", 4, 95617},
	{"OPENVPN", 7, 95618},
	{"MCENTIRE", 8, 95619},
	{"LONDRA", 6, 95620},
	{"KAUR", 4, 95621},
	{"UNCONSTRAINED", 13, 95622},
	{"DATADIRECT", 10, 95623},
	{"SOUTER", 6, 95624},
	{"REDFERN", 7, 95625},
	{"TUCL", 4, 95626},
	{"RKHU", 4, 95627},
	{"RIFW", 4, 95628},
	{"ECUI", 4, 95629},
	{"ASKC", 4, 95630},
	{"TULUM", 5, 95631},
	{"PAGESIZE", 8, 95632},
	{"OSTEOPATHY", 10, 95633},
	{"STAVANGER", 9, 95634},
	{"JENKS", 5, 95635},
	{"CATED", 5, 95636},
	{"AUTRY", 5, 95637},
	{"SCHUTZ", 6, 95638},
	{"UFOL", 4, 95639},
	{"LMSL", 4, 95640},
	{"INDK", 4, 95641},
	{"MATERIALISTIC", 13, 95642},
	{"BOAZ", 4, 95643},
	{"ROOFTOPS", 8, 95644},
	{"FINDPAGE", 8, 95645},
	{"DISCOURAGES", 11, 95646},
	{"BENITEZ", 7, 95647},
	{"MMUR", 4, 95648},
	{"MJOI", 4, 95649},
	{"KFEE", 4, 95650},
	{"FFMY", 4, 95651},
	{"FDOE", 4, 95652},
	{"CJOU", 4, 95653},
	{"BOATER", 6, 95654},
	{"SHACKLETON", 10, 95655},
	{"WEIRDO", 6, 95656},
	{"CONGRESSWOMAN", 13, 95657},
	{"DALEK", 5, 95658},
	{"JAHRE", 5, 95659},
	{"ITRIP", 5, 95660},
	{"MYOB", 4, 95661},
	{"HELLOWEEN", 9, 95662},
	{"PTME", 4, 95663},
	{"OLLG", 4, 95664},
	{"LTUS", 4, 95665},
	{"REPERFUSION", 11, 95666},
	{"FIELDHOUSE", 10, 95667},
	{"MANUKAU", 7, 95668},
	{"LIBNAME", 7, 95669},
	{"EUCHARISTIC", 11, 95670},
	{"MONG", 4, 95671},
	{"HOMEWARE", 8, 95672},
	{"WINMX", 5, 95673},
	{"MOBIC", 5, 95674},
	{"PVIC", 4, 95675},
	{"EXTV", 4, 95676},
	{"EFFH", 4, 95677},
	{"DMEB", 4, 95678},
	{"BTHR", 4, 95679},
	{"BAGU", 4, 95680},
	{"AGBE", 4, 95681},
	{"FARTS", 5, 95682},
	{"ROURKE", 6, 95683},
	{"LACKAWANNA", 10, 95684},
	{"VILLIERS", 8, 95685},
	{"COMERCIO", 8, 95686},
	{"BROOKSVILLE", 11, 95687},
	{"ONCOMING", 8, 95688},
	{"FALWELL", 7, 95689},
	{"ZERF", 4, 95690},
	{"WNQU", 4, 95691},
	{"WCUS", 4, 95692},
	{"SBUM", 4, 95693},
	{"OYLA", 4, 95694},
	{"NYAK", 4, 95695},
	{"CVIC", 4, 95696},
	{"GWB", 3, 95697},
	{"RACKED", 6, 95698},
	{"DONWLOAD", 8, 95699},
	{"WRTH", 4, 95700},
	{"ATTRS", 5, 95701},
	{"KNOCKOFFS", 9, 95702},
	{"CLOISTER", 8, 95703},
	{"BIONICLE", 8, 95704},
	{"HYGIENIST", 9, 95705},
	{"NICHOLE", 7, 95706},
	{"QUIDDITCH", 9, 95707},
	{"WPAI", 4, 95708},
	{"WNIG", 4, 95709},
	{"REUL", 4, 95710},
	{"RCAI", 4, 95711},
	{"OWIK", 4, 95712},
	{"HRAG", 4, 95713},
	{"FENB", 4, 95714},
	{"BSPO", 4, 95715},
	{"DARTMOOR", 8, 95716},
	{"PROVINCIA", 9, 95717},
	{"ROWLETT", 7, 95718},
	{"STAPLED", 7, 95719},
	{"GARDENWEB", 9, 95720},
	{"BUTTERNUT", 9, 95721},
	{"NUMMER", 6, 95722},
	{"FANCIED", 7, 95723},
	{"WAPE", 4, 95724},
	{"GROBAN", 6, 95725},
	{"ARORA", 5, 95726},
	{"SPOILT", 6, 95727},
	{"YATSURA", 7, 95728},
	{"PREDISPOSED", 11, 95729},
	{"HYDROCHLORIC", 12, 95730},
	{"FILIPPO", 7, 95731},
	{"XCIS", 4, 95732},
	{"RLHE", 4, 95733},
	{"WARR", 4, 95734},
	{"HAINAN", 6, 95735},
	{"LOGOFF", 6, 95736},
	{"COCKROACH", 9, 95737},
	{"XANADU", 6, 95738},
	{"COMPUTABLE", 10, 95739},
	{"STRODE", 6, 95740},
	{"OCCUP", 5, 95741},
	{"PLAYGROUP", 9, 95742},
	{"NSGL", 4, 95743},
	{"MPPR", 4, 95744},
	{"MARCHAND", 8, 95745},
	{"TINTIN", 6, 95746},
	{"DISORGANIZED", 12, 95747},
	{"ETHNICITIES", 11, 95748},
	{"WEBPOSITION", 11, 95749},
	{"CRAFTER", 7, 95750},
	{"ROBY", 4, 95751},
	{"DISASSEMBLE", 11, 95752},
	{"SHAFTESBURY", 11, 95753},
	{"YNCO", 4, 95754},
	{"URYV", 4, 95755},
	{"PYLO", 4, 95756},
	{"MADT", 4, 95757},
	{"ILAV", 4, 95758},
	{"GHHU", 4, 95759},
	{"FDIN", 4, 95760},
	{"ERUA", 4, 95761},
	{"LITTORAL", 8, 95762},
	{"BOLTZMANN", 9, 95763},
	{"ABIDJAN", 7, 95764},
	{"GRAINY", 6, 95765},
	{"HOSPITALIZATIONS", 16, 95766},
	{"AGGRESSOR", 9, 95767},
	{"PSBR", 4, 95768},
	{"FLYD", 4, 95769},
	{"FJOI", 4, 95770},
	{"GIGGLED", 7, 95771},
	{"NOTIZIE", 7, 95772},
	{"ZOEK", 4, 95773},
	{"SEPULTURA", 9, 95774},
	{"WALKABOUT", 9, 95775},
	{"PEPPERONI", 9, 95776},
	{"OPTIMISING", 10, 95777},
	{"CITYREVIEW", 10, 95778},
	{"BOATHOUSE", 9, 95779},
	{"WEISSMAN", 8, 95780},
	{"CONSUMMATION", 12, 95781},
	{"TVCA", 4, 95782},
	{"OGLU", 4, 95783},
	{"MUPW", 4, 95784},
	{"EGOG", 4, 95785},
	{"HERKIMER", 8, 95786},
	{"NAMECITE", 8, 95787},
	{"FRONTING", 8, 95788},
	{"REFRESHINGLY", 12, 95789},
	{"RYLAND", 6, 95790},
	{"SCULPTURAL", 10, 95791},
	{"NEUROPHYSIOLOGY", 15, 95792},
	{"HERMANUS", 8, 95793},
	{"MOCLDY", 6, 95794},
	{"NGAGE", 5, 95795},
	{"YYEL", 4, 95796},
	{"ANNEXURE", 8, 95797},
	{"IPCHAINS", 8, 95798},
	{"YOSEF", 5, 95799},
	{"TLDS", 4, 95800},
	{"GOZO", 4, 95801},
	{"ZOLA", 4, 95802},
	{"HEUTE", 5, 95803},
	{"HELTON", 6, 95804},
	{"UNFAITHFUL", 10, 95805},
	{"OUTFLOWS", 8, 95806},
	{"EXECUTIONER", 11, 95807},
	{"ASTHMATIC", 9, 95808},
	{"URTG", 4, 95809},
	{"UEER", 4, 95810},
	{"OORJ", 4, 95811},
	{"ODUB", 4, 95812},
	{"KSUB", 4, 95813},
	{"GUILLEMOT", 9, 95814},
	{"REALIZATIONS", 12, 95815},
	{"LINGUISTICALLY", 14, 95816},
	{"JACO", 4, 95817},
	{"MCKINSEY", 8, 95818},
	{"DEZEMBER", 8, 95819},
	{"HYLAFAX", 7, 95820},
	{"RECONSTITUTION", 14, 95821},
	{"LUMBERTON", 9, 95822},
	{"ORKK", 4, 95823},
	{"NCUN", 4, 95824},
	{"GNUC", 4, 95825},
	{"DDOB", 4, 95826},
	{"INTERVIEWEE", 11, 95827},
	{"INTERECO", 8, 95828},
	{"PORTOLA", 7, 95829},
	{"HEMATOLOGIC", 11, 95830},
	{"TITULAR", 7, 95831},
	{"REBBE", 5, 95832},
	{"SWEARS", 6, 95833},
	{"PINUP", 5, 95834},
	{"DIMINUTIVE", 10, 95835},
	{"TRANSCENDENCE", 13, 95836},
	{"SURAH", 5, 95837},
	{"VEYF", 4, 95838},
	{"UIDC", 4, 95839},
	{"TPEP", 4, 95840},
	{"TARZ", 4, 95841},
	{"OWNQ", 4, 95842},
	{"LIPU", 4, 95843},
	{"BRENDON", 7, 95844},
	{"FARBERWARE", 10, 95845},
	{"STATISTICIANS", 13, 95846},
	{"SWATCHES", 8, 95847},
	{"PERIOPERATIVE", 13, 95848},
	{"MAOIST", 6, 95849},
	{"HENKEL", 6, 95850},
	{"LILANGENI", 9, 95851},
	{"LEMMINGS", 8, 95852},
	{"EXTENTS", 7, 95853},
	{"SPAMS", 5, 95854},
	{"OMAGH", 5, 95855},
	{"XONY", 4, 95856},
	{"UMPP", 4, 95857},
	{"PSQU", 4, 95858},
	{"MMYJ", 4, 95859},
	{"FTSB", 4, 95860},
	{"WORKCENTRE", 10, 95861},
	{"SUNBIRD", 7, 95862},
	{"CELLOPHANE", 10, 95863},
	{"PARING", 6, 95864},
	{"DELAND", 6, 95865},
	{"BLEVINS", 7, 95866},
	{"UEUS", 4, 95867},
	{"PYHO", 4, 95868},
	{"EMEU", 4, 95869},
	{"BDIC", 4, 95870},
	{"SACHA", 5, 95871},
	{"DAMNING", 7, 95872},
	{"CARDHOLDERS", 11, 95873},
	{"DDDD", 4, 95874},
	{"ACCESSORI", 9, 95875},
	{"SRUT", 4, 95876},
	{"RMIM", 4, 95877},
	{"PSUM", 4, 95878},
	{"COCR", 4, 95879},
	{"ADYV", 4, 95880},
	{"ARAUJO", 6, 95881},
	{"MYLIST", 6, 95882},
	{"PCU", 3, 95883},
	{"MATRIMONY", 9, 95884},
	{"ARMAS", 5, 95885},
	{"KLOCZEK", 7, 95886},
	{"HUMBUG", 6, 95887},
	{"SEPERATED", 9, 95888},
	{"CLUSTY", 6, 95889},
	{"OORK", 4, 95890},
	{"LCOW", 4, 95891},
	{"KONK", 4, 95892},
	{"GHUP", 4, 95893},
	{"FHAB", 4, 95894},
	{"EUNV", 4, 95895},
	{"ROLFE", 5, 95896},
	{"SIGNALLED", 9, 95897},
	{"CUTTACK", 7, 95898},
	{"PROVANTAGE", 10, 95899},
	{"DOMINIO", 7, 95900},
	{"HYPERBARIC", 10, 95901},
	{"GRANULATED", 10, 95902},
	{"NANNOFOSSIL", 11, 95903},
	{"LOGANSPORT", 10, 95904},
	{"BULLDOZER", 9, 95905},
	{"AILMENT", 7, 95906},
	{"MSDR", 4, 95907},
	{"HURW", 4, 95908},
	{"GYWE", 4, 95909},
	{"HOMELY", 6, 95910},
	{"BLACKSONBLONDES", 15, 95911},
	{"SUBPRIME", 8, 95912},
	{"OVERPAYMENTS", 12, 95913},
	{"SHARPIE", 7, 95914},
	{"MODUTILS", 8, 95915},
	{"WHITEHAVEN", 10, 95916},
	{"WHALEY", 6, 95917},
	{"PERPETUITY", 10, 95918},
	{"STEPFATHER", 10, 95919},
	{"CURRIER", 7, 95920},
	{"TAPROOT", 7, 95921},
	{"TOPSITE", 7, 95922},
	{"DELORME", 7, 95923},
	{"DISPROVE", 8, 95924},
	{"UQUA", 4, 95925},
	{"NDMM", 4, 95926},
	{"LSGI", 4, 95927},
	{"RAYNER", 6, 95928},
	{"ROSSUM", 6, 95929},
	{"URBANISM", 8, 95930},
	{"COLLOQUIA", 9, 95931},
	{"UBHE", 4, 95932},
	{"RNAK", 4, 95933},
	{"HBOM", 4, 95934},
	{"EURR", 4, 95935},
	{"DINERO", 6, 95936},
	{"BERNHARDT", 9, 95937},
	{"INCURABLE", 9, 95938},
	{"CAPILLARIES", 11, 95939},
	{"DIXIT", 5, 95940},
	{"WOCI", 4, 95941},
	{"OFOZ", 4, 95942},
	{"MUMD", 4, 95943},
	{"KLEP", 4, 95944},
	{"AKPR", 4, 95945},
	{"ACUN", 4, 95946},
	{"MOUNTAINSIDE", 12, 95947},
	{"SHOVING", 7, 95948},
	{"FURNISHES", 9, 95949},
	{"MENTHOL", 7, 95950},
	{"BLACKOUTS", 9, 95951},
	{"STARKEY", 7, 95952},
	{"HPUX", 4, 95953},
	{"CANBY", 5, 95954},
	{"DRAGONFLIES", 11, 95955},
	{"MONTRAIL", 8, 95956},
	{"FINDFONT", 8, 95957},
	{"ANOINTING", 9, 95958},
	{"AIGNER", 6, 95959},
	{"URUSEI", 6, 95960},
	{"SOUNDBLASTER", 12, 95961},
	{"BBCO", 4, 95962},
	{"BEATLE", 6, 95963},
	{"WEBZINE", 7, 95964},
	{"CORINNA", 7, 95965},
	{"PROPRANOLOL", 11, 95966},
	{"INESCAPABLE", 11, 95967},
	{"SWABS", 5, 95968},
	{"STRICTEST", 9, 95969},
	{"DOMICILED", 9, 95970},
	{"OPMM", 4, 95971},
	{"NUEU", 4, 95972},
	{"LIDM", 4, 95973},
	{"IGAP", 4, 95974},
	{"GYTE", 4, 95975},
	{"FOFL", 4, 95976},
	{"ZDX", 3, 95977},
	{"XCG", 3, 95978},
	{"WJX", 3, 95979},
	{"VXP", 3, 95980},
	{"QLM", 3, 95981},
	{"FPQ", 3, 95982},
	{"BZC", 3, 95983},
	{"ABSORBANCE", 10, 95984},
	{"MINX", 4, 95985},
	{"LBW", 3, 95986},
	{"AUDIOFILE", 9, 95987},
	{"ECLIPSES", 8, 95988},
	{"PRISE", 5, 95989},
	{"SIMBA", 5, 95990},
	{"MOHD", 4, 95991},
	{"MISDEMEANORS", 12, 95992},
	{"HADRIAN", 7, 95993},
	{"REDGOLDFISH", 11, 95994},
	{"YWRA", 4, 95995},
	{"UPCR", 4, 95996},
	{"SURC", 4, 95997},
	{"PBIG", 4, 95998},
	{"MELM", 4, 95999},
	{"GUSB", 4, 96000},
	{"CORNBREAD", 9, 96001},
	{"JCAHO", 5, 96002},
	{"APPENDIXES", 10, 96003},
	{"SUPREMELY", 9, 96004},
	{"CRESTVIEW", 9, 96005},
	{"KEYNOTES", 8, 96006},
	{"FOTOLIA", 7, 96007},
	{"SUBNETS", 7, 96008},
	{"ULKN", 4, 96009},
	{"SIMB", 4, 96010},
	{"AKDE", 4, 96011},
	{"MENSCH", 6, 96012},
	{"HASTENED", 8, 96013},
	{"ESPANOLA", 8, 96014},
	{"BUSNES", 6, 96015},
	{"PERPETUATING", 12, 96016},
	{"FROGGY", 6, 96017},
	{"DECARBOXYLASE", 13, 96018},
	{"ELFMAN", 6, 96019},
	{"THROUGHS", 8, 96020},
	{"PRIORITISE", 10, 96021},
	{"ORECK", 5, 96022},
	{"SCHOTTLAND", 10, 96023},
	{"WAWH", 4, 96024},
	{"LNUC", 4, 96025},
	{"AZYS", 4, 96026},
	{"AXWI", 4, 96027},
	{"AUXA", 4, 96028},
	{"BAGPIPE", 7, 96029},
	{"TERNS", 5, 96030},
	{"ERYTHEMATOSUS", 13, 96031},
	{"PROSTRATE", 9, 96032},
	{"FTRS", 4, 96033},
	{"EXCITATORY", 10, 96034},
	{"MCEVOY", 6, 96035},
	{"FUJITA", 6, 96036},
	{"NIAGRA", 6, 96037},
	{"IPMU", 4, 96038},
	{"GATG", 4, 96039},
	{"FBYA", 4, 96040},
	{"PROVISIONALLY", 13, 96041},
	{"COCKED", 6, 96042},
	{"DRIBBLE", 7, 96043},
	{"RAGED", 5, 96044},
	{"HARDWIRED", 9, 96045},
	{"GRAMBLING", 9, 96046},
	{"BOYNE", 5, 96047},
	{"EXTEN", 5, 96048},
	{"SEEGER", 6, 96049},
	{"RINGGOLD", 8, 96050},
	{"OJEW", 4, 96051},
	{"LPIP", 4, 96052},
	{"EUDI", 4, 96053},
	{"SONDHEIM", 8, 96054},
	{"INTERCONNECTING", 15, 96055},
	{"INKJETS", 7, 96056},
	{"SINGULARLY", 10, 96057},
	{"ELAM", 4, 96058},
	{"UNDERPINNINGS", 13, 96059},
	{"UFIR", 4, 96060},
	{"OAKR", 4, 96061},
	{"EFID", 4, 96062},
	{"AAFF", 4, 96063},
	{"GOBBLE", 6, 96064},
	{"PREPOSTEROUS", 12, 96065},
	{"LAZAR", 5, 96066},
	{"LAXATIVES", 9, 96067},
	{"MYTHOS", 6, 96068},
	{"SONAME", 6, 96069},
	{"COLLOID", 7, 96070},
	{"HIKED", 5, 96071},
	{"DEFRAG", 6, 96072},
	{"PHUR", 4, 96073},
	{"LOSG", 4, 96074},
	{"EYJR", 4, 96075},
	{"DSJA", 4, 96076},
	{"CCOT", 4, 96077},
	{"SYMBOLIZED", 10, 96078},
	{"ZANESVILLE", 10, 96079},
	{"BREECH", 6, 96080},
	{"RIPENING", 8, 96081},
	{"OXIDANT", 7, 96082},
	{"PYRAMIDAL", 9, 96083},
	{"OUPK", 4, 96084},
	{"GZON", 4, 96085},
	{"EKPE", 4, 96086},
	{"ANCK", 4, 96087},
	{"UMBRA", 5, 96088},
	{"POPPIN", 6, 96089},
	{"CHORUSES", 8, 96090},
	{"TREBUCHET", 9, 96091},
	{"PYRITE", 6, 96092},
	{"PARTIDO", 7, 96093},
	{"DRUNKS", 6, 96094},
	{"SUBMITTERS", 10, 96095},
	{"BRANES", 6, 96096},
	{"MAHDI", 5, 96097},
	{"AGOURA", 6, 96098},
	{"OBSTRUCTING", 11, 96099},
	{"YAMT", 4, 96100},
	{"UPPU", 4, 96101},
	{"FOXC", 4, 96102},
	{"DPIR", 4, 96103},
	{"MANCHESTERONLINE", 16, 96104},
	{"BLUNKETT", 8, 96105},
	{"LAPD", 4, 96106},
	{"KIDDER", 6, 96107},
	{"HOTKEY", 6, 96108},
	{"PHOSPHORIC", 10, 96109},
	{"TIRUPUR", 7, 96110},
	{"PARKVILLE", 9, 96111},
	{"CREDITING", 9, 96112},
	{"YROW", 4, 96113},
	{"WLYP", 4, 96114},
	{"PARQUET", 7, 96115},
	{"PASQUALE", 8, 96116},
	{"REPARATION", 10, 96117},
	{"OUOW", 4, 96118},
	{"GSKY", 4, 96119},
	{"GHBI", 4, 96120},
	{"BUDH", 4, 96121},
	{"AKDA", 4, 96122},
	{"PUBLISHIN", 9, 96123},
	{"AMPLY", 5, 96124},
	{"SLAZENGER", 9, 96125},
	{"CREATIONISTS", 12, 96126},
	{"HARNEY", 6, 96127},
	{"DAMASK", 6, 96128},
	{"BATTED", 6, 96129},
	{"VORF", 4, 96130},
	{"LDEZ", 4, 96131},
	{"LASJ", 4, 96132},
	{"KEOP", 4, 96133},
	{"IAQU", 4, 96134},
	{"REJOINED", 8, 96135},
	{"IVETE", 5, 96136},
	{"HOVERCRAFT", 10, 96137},
	{"ALVES", 5, 96138},
	{"NIGHTHAWK", 9, 96139},
	{"UROLOGIC", 8, 96140},
	{"IMPOTENT", 8, 96141},
	{"CHAKA", 5, 96142},
	{"UEMU", 4, 96143},
	{"RUWA", 4, 96144},
	{"OULP", 4, 96145},
	{"ILMG", 4, 96146},
	{"SPITS", 5, 96147},
	{"CFB", 3, 96148},
	{"EMOTIVE", 7, 96149},
	{"PAPACY", 6, 96150},
	{"BROADBENT", 9, 96151},
	{"CURMUDGEON", 10, 96152},
	{"FRESHENER", 9, 96153},
	{"CHEMOKINE", 9, 96154},
	{"STATELINE", 9, 96155},
	{"RTTU", 4, 96156},
	{"RKDR", 4, 96157},
	{"CKSV", 4, 96158},
	{"THIMBLE", 7, 96159},
	{"RACISTS", 7, 96160},
	{"WINTV", 5, 96161},
	{"BEYBLADE", 8, 96162},
	{"LACQUERED", 9, 96163},
	{"ABLAZE", 6, 96164},
	{"ASSASSINATIONS", 14, 96165},
	{"GRAMOPHONE", 10, 96166},
	{"NDCD", 4, 96167},
	{"LTME", 4, 96168},
	{"LEML", 4, 96169},
	{"IFUS", 4, 96170},
	{"FMIT", 4, 96171},
	{"SPOTTY", 6, 96172},
	{"LECH", 4, 96173},
	{"SIMMERING", 9, 96174},
	{"POLA", 4, 96175},
	{"CHITTENDEN", 10, 96176},
	{"TANNOY", 6, 96177},
	{"CYCLOSPORINE", 12, 96178},
	{"NETTIE", 6, 96179},
	{"GRASSHOPPERS", 12, 96180},
	{"INTERNATIONALISATION", 20, 96181},
	{"WEISER", 6, 96182},
	{"KRISHNAN", 8, 96183},
	{"TWISTA", 6, 96184},
	{"WMOM", 4, 96185},
	{"UKEH", 4, 96186},
	{"MTAX", 4, 96187},
	{"LEXN", 4, 96188},
	{"GYPA", 4, 96189},
	{"GONV", 4, 96190},
	{"GREIG", 5, 96191},
	{"PROBLEMA", 8, 96192},
	{"DAOC", 4, 96193},
	{"NETANYAHU", 9, 96194},
	{"MOFFITT", 7, 96195},
	{"ARTEC", 5, 96196},
	{"CRAWLERS", 8, 96197},
	{"SENATORIAL", 10, 96198},
	{"PBEM", 4, 96199},
	{"THAWED", 6, 96200},
	{"UNEXPLORED", 10, 96201},
	{"CHARACTERIZATIONS", 17, 96202},
	{"YIFS", 4, 96203},
	{"CTDR", 4, 96204},
	{"TRANSPIRED", 10, 96205},
	{"DIETITIANS", 10, 96206},
	{"TOULON", 6, 96207},
	{"JOVAN", 5, 96208},
	{"SANGALO", 7, 96209},
	{"DOTGNU", 6, 96210},
	{"MMYN", 4, 96211},
	{"LTZE", 4, 96212},
	{"HCAV", 4, 96213},
	{"FGAT", 4, 96214},
	{"VILAS", 5, 96215},
	{"BEECHWOOD", 9, 96216},
	{"EPISTEMOLOGICAL", 15, 96217},
	{"MENSAJES", 8, 96218},
	{"INFILTRATED", 11, 96219},
	{"UYAM", 4, 96220},
	{"TELG", 4, 96221},
	{"PGOA", 4, 96222},
	{"ALYC", 4, 96223},
	{"FORTIFICATIONS", 14, 96224},
	{"INTERGRAPH", 10, 96225},
	{"CLOAKING", 8, 96226},
	{"MIJAS", 5, 96227},
	{"UNANNOUNCED", 11, 96228},
	{"DEACTIVATION", 12, 96229},
	{"WIAM", 4, 96230},
	{"WECE", 4, 96231},
	{"KEED", 4, 96232},
	{"DICHROIC", 8, 96233},
	{"LOAFER", 6, 96234},
	{"SKYDIVE", 7, 96235},
	{"GRATINGS", 8, 96236},
	{"SMSG", 4, 96237},
	{"EMCN", 4, 96238},
	{"QUIN", 4, 96239},
	{"RETINOL", 7, 96240},
	{"SANUS", 5, 96241},
	{"INSURMOUNTABLE", 14, 96242},
	{"PRINTABLES", 10, 96243},
	{"FYLDE", 5, 96244},
	{"CULLUM", 6, 96245},
	{"KUNMING", 7, 96246},
	{"COUNTERVAILING", 14, 96247},
	{"FAIRING", 7, 96248},
	{"VYLO", 4, 96249},
	{"UMVI", 4, 96250},
	{"SAMF", 4, 96251},
	{"IEGU", 4, 96252},
	{"AXBI", 4, 96253},
	{"PRETTIER", 8, 96254},
	{"INVISIBILITY", 12, 96255},
	{"HAYSTACK", 8, 96256},
	{"WOBB", 4, 96257},
	{"WENW", 4, 96258},
	{"HARDCOR", 7, 96259},
	{"CHAFFEE", 7, 96260},
	{"COMPRA", 6, 96261},
	{"SWISHER", 7, 96262},
	{"SYNTHESIZING", 12, 96263},
	{"SUPERDOME", 9, 96264},
	{"APTOS", 5, 96265},
	{"WILSONVILLE", 11, 96266},
	{"PERALTA", 7, 96267},
	{"KOMEN", 5, 96268},
	{"HOTSPUR", 7, 96269},
	{"UITJ", 4, 96270},
	{"NCCO", 4, 96271},
	{"LUNR", 4, 96272},
	{"GNAD", 4, 96273},
	{"AHMU", 4, 96274},
	{"PHARE", 5, 96275},
	{"FJORDS", 6, 96276},
	{"NIGHTSTAND", 10, 96277},
	{"XMLNS", 5, 96278},
	{"CAYCE", 5, 96279},
	{"HELMHOLTZ", 9, 96280},
	{"CHAQUE", 6, 96281},
	{"CONFINING", 9, 96282},
	{"UVB", 3, 96283},
	{"LOONY", 5, 96284},
	{"NYOW", 4, 96285},
	{"MYYO", 4, 96286},
	{"LAWG", 4, 96287},
	{"HIGU", 4, 96288},
	{"BICM", 4, 96289},
	{"RAFE", 4, 96290},
	{"INFRINGES", 9, 96291},
	{"BOOKBAG", 7, 96292},
	{"ALINA", 5, 96293},
	{"LOYALTIES", 9, 96294},
	{"LOUVAIN", 7, 96295},
	{"ETCHINGS", 8, 96296},
	{"REVERSALS", 9, 96297},
	{"SLIPCOVERS", 10, 96298},
	{"DNAG", 4, 96299},
	{"IMPENETRABLE", 12, 96300},
	{"SQUIER", 6, 96301},
	{"COLLATE", 7, 96302},
	{"SIMILAIRES", 10, 96303},
	{"ENCAPSULATE", 11, 96304},
	{"KABEL", 5, 96305},
	{"RESPONSIBILTY", 13, 96306},
	{"NCSU", 4, 96307},
	{"GYMNASTIC", 9, 96308},
	{"SCREENERS", 9, 96309},
	{"YMEX", 4, 96310},
	{"RGIT", 4, 96311},
	{"ONYK", 4, 96312},
	{"MBYP", 4, 96313},
	{"LTPE", 4, 96314},
	{"TRIGLYCERIDE", 12, 96315},
	{"FRIPP", 5, 96316},
	{"UNDISTRIBUTED", 13, 96317},
	{"PURR", 4, 96318},
	{"INDUSTRIALISED", 14, 96319},
	{"GALVANISED", 10, 96320},
	{"DUPED", 5, 96321},
	{"NIGRA", 5, 96322},
	{"YESR", 4, 96323},
	{"WSXP", 4, 96324},
	{"PYCO", 4, 96325},
	{"EEDV", 4, 96326},
	{"CKTW", 4, 96327},
	{"BURC", 4, 96328},
	{"STIFLING", 8, 96329},
	{"TRIPLECALC", 10, 96330},
	{"REALISES", 8, 96331},
	{"RATEPAYERS", 10, 96332},
	{"CRYO", 4, 96333},
	{"VINDICATED", 10, 96334},
	{"BENNIE", 6, 96335},
	{"GABORONE", 8, 96336},
	{"BUND", 4, 96337},
	{"MATHERS", 7, 96338},
	{"INVADES", 7, 96339},
	{"WWRI", 4, 96340},
	{"VYCH", 4, 96341},
	{"BSSU", 4, 96342},
	{"NEUROTRANSMITTERS", 17, 96343},
	{"GZIPPED", 7, 96344},
	{"HABBO", 5, 96345},
	{"STMICROELECTRONICS", 18, 96346},
	{"JHANSI", 6, 96347},
	{"RUMPS", 5, 96348},
	{"LEUPOLD", 7, 96349},
	{"DIPPER", 6, 96350},
	{"OGYG", 4, 96351},
	{"LYPM", 4, 96352},
	{"LGYM", 4, 96353},
	{"IPUP", 4, 96354},
	{"FPUL", 4, 96355},
	{"FMYD", 4, 96356},
	{"LUMINESCENT", 11, 96357},
	{"PERCOLATION", 11, 96358},
	{"CMDE", 4, 96359},
	{"SIGNIFIED", 9, 96360},
	{"FREITAG", 7, 96361},
	{"TALKERS", 7, 96362},
	{"SOCKEYE", 7, 96363},
	{"MYIM", 4, 96364},
	{"IRSR", 4, 96365},
	{"HEVC", 4, 96366},
	{"EDRD", 4, 96367},
	{"BATD", 4, 96368},
	{"AUDH", 4, 96369},
	{"EXEMPLIFY", 9, 96370},
	{"WEBWATCH", 8, 96371},
	{"ATTRACTOR", 9, 96372},
	{"CLEEF", 5, 96373},
	{"MOZILLAZINE", 11, 96374},
	{"CONFORT", 7, 96375},
	{"BYWAYS", 6, 96376},
	{"IBSEN", 5, 96377},
	{"RGYH", 4, 96378},
	{"OZIL", 4, 96379},
	{"KOSU", 4, 96380},
	{"DDOS", 4, 96381},
	{"BECKET", 6, 96382},
	{"SMARTMONEY", 10, 96383},
	{"BELAFONTE", 9, 96384},
	{"ASCCM", 5, 96385},
	{"TOTALY", 6, 96386},
	{"RECLINERS", 9, 96387},
	{"HIKARU", 6, 96388},
	{"LOMBOK", 6, 96389},
	{"YTVS", 4, 96390},
	{"WIFA", 4, 96391},
	{"GMOB", 4, 96392},
	{"FHUG", 4, 96393},
	{"JUSTUS", 6, 96394},
	{"ZPB", 3, 96395},
	{"ZLK", 3, 96396},
	{"VVB", 3, 96397},
	{"LQM", 3, 96398},
	{"JWY", 3, 96399},
	{"BZY", 3, 96400},
	{"HOMECINEMASYSTEM", 16, 96401},
	{"HEADHUNTERS", 11, 96402},
	{"TAKARA", 6, 96403},
	{"BLUNTLY", 7, 96404},
	{"UMNF", 4, 96405},
	{"OYBA", 4, 96406},
	{"NDDV", 4, 96407},
	{"IZAL", 4, 96408},
	{"FLPL", 4, 96409},
	{"DORV", 4, 96410},
	{"RETRANSMITTED", 13, 96411},
	{"EASYJET", 7, 96412},
	{"ASSAYED", 7, 96413},
	{"RIBBLE", 6, 96414},
	{"WEBLINK", 7, 96415},
	{"BASK", 4, 96416},
	{"MERMAIDS", 8, 96417},
	{"CONTEMPLATES", 12, 96418},
	{"VILB", 4, 96419},
	{"SDUK", 4, 96420},
	{"HEFM", 4, 96421},
	{"BIGQ", 4, 96422},
	{"ALUI", 4, 96423},
	{"LIBCURL", 7, 96424},
	{"INGLIS", 6, 96425},
	{"XANDROS", 7, 96426},
	{"CORKY", 5, 96427},
	{"DEFENSIBLE", 10, 96428},
	{"BERK", 4, 96429},
	{"DERAIL", 6, 96430},
	{"CGCGG", 5, 96431},
	{"MIDGARD", 7, 96432},
	{"RDYI", 4, 96433},
	{"PTCH", 4, 96434},
	{"MVET", 4, 96435},
	{"ASKD", 4, 96436},
	{"GAMESHARK", 9, 96437},
	{"SPINSTER", 8, 96438},
	{"GOBLETS", 7, 96439},
	{"TOUTING", 7, 96440},
	{"INTERROGATED", 12, 96441},
	{"MICROGAMING", 11, 96442},
	{"CRAPPIE", 7, 96443},
	{"BIRTHSTONES", 11, 96444},
	{"KORE", 4, 96445},
	{"SUKHUMVIT", 9, 96446},
	{"CIRENCESTER", 11, 96447},
	{"YOLKS", 5, 96448},
	{"XORC", 4, 96449},
	{"XISC", 4, 96450},
	{"UERN", 4, 96451},
	{"UDSM", 4, 96452},
	{"OGSL", 4, 96453},
	{"MYTW", 4, 96454},
	{"LIVO", 4, 96455},
	{"GUMB", 4, 96456},
	{"DPOV", 4, 96457},
	{"CPOI", 4, 96458},
	{"AUSTRALIS", 9, 96459},
	{"CLONAL", 6, 96460},
	{"ENRIGHT", 7, 96461},
	{"SULAWESI", 8, 96462},
	{"AUGMENTIN", 9, 96463},
	{"FAMILLE", 7, 96464},
	{"PROGRAMY", 8, 96465},
	{"INSTALLATIONPARTS", 17, 96466},
	{"MARBURG", 7, 96467},
	{"ANTICANCER", 10, 96468},
	{"DIGOXIN", 7, 96469},
	{"XACT", 4, 96470},
	{"YULT", 4, 96471},
	{"UYFR", 4, 96472},
	{"RODB", 4, 96473},
	{"KITM", 4, 96474},
	{"IRTB", 4, 96475},
	{"GKEE", 4, 96476},
	{"GGSH", 4, 96477},
	{"OVERLAPPED", 10, 96478},
	{"KIDKRAFT", 8, 96479},
	{"DELLO", 5, 96480},
	{"SPOOK", 5, 96481},
	{"MODULATING", 10, 96482},
	{"MARIANAS", 8, 96483},
	{"NONINVASIVE", 11, 96484},
	{"BICYCLISTS", 10, 96485},
	{"PARADIESDE", 10, 96486},
	{"OGLETHORPE", 10, 96487},
	{"LEGB", 4, 96488},
	{"AMPED", 5, 96489},
	{"ASSOCIA", 7, 96490},
	{"DIVI", 4, 96491},
	{"NUKEM", 5, 96492},
	{"RKPU", 4, 96493},
	{"IPAB", 4, 96494},
	{"FALF", 4, 96495},
	{"BIAM", 4, 96496},
	{"GEOMETRICALLY", 13, 96497},
	{"MAGDEBURG", 9, 96498},
	{"OUTWEIGHS", 9, 96499},
	{"TARNISHED", 9, 96500},
	{"ALESSI", 6, 96501},
	{"SMARTDEALS", 10, 96502},
	{"DETOMASO", 8, 96503},
	{"DIORAMA", 7, 96504},
	{"DEDUCTING", 9, 96505},
	{"TRANSFLASH", 10, 96506},
	{"BEHRENS", 7, 96507},
	{"KYLA", 4, 96508},
	{"UYSE", 4, 96509},
	{"LFDA", 4, 96510},
	{"HFLU", 4, 96511},
	{"EPUG", 4, 96512},
	{"BDRI", 4, 96513},
	{"BAKH", 4, 96514},
	{"CARETAKERS", 10, 96515},
	{"AMAZES", 6, 96516},
	{"UNDAMAGED", 9, 96517},
	{"TOWLE", 5, 96518},
	{"SNOQUALMIE", 10, 96519},
	{"GORAKHPUR", 9, 96520},
	{"CONSOLIDATOR", 12, 96521},
	{"ADRIANO", 7, 96522},
	{"RIDICULED", 9, 96523},
	{"PARALEGALS", 10, 96524},
	{"SNAGS", 5, 96525},
	{"HOPPE", 5, 96526},
	{"UGOO", 4, 96527},
	{"SKFA", 4, 96528},
	{"NKPO", 4, 96529},
	{"NETFIRMS", 8, 96530},
	{"TELEFONICA", 10, 96531},
	{"THOMASON", 8, 96532},
	{"PRATER", 6, 96533},
	{"OLDEN", 5, 96534},
	{"FRIESEN", 7, 96535},
	{"TECHTALK", 8, 96536},
	{"REGO", 4, 96537},
	{"ANTICA", 6, 96538},
	{"CYCLOTRON", 9, 96539},
	{"YBYJ", 4, 96540},
	{"LAPW", 4, 96541},
	{"ISCY", 4, 96542},
	{"CKIA", 4, 96543},
	{"HERNE", 5, 96544},
	{"GROMMETS", 8, 96545},
	{"UNENDING", 8, 96546},
	{"ENDERS", 6, 96547},
	{"BRIDGWATER", 10, 96548},
	{"BLACKBOX", 8, 96549},
	{"ZERM", 4, 96550},
	{"YNEP", 4, 96551},
	{"WOPP", 4, 96552},
	{"UGWA", 4, 96553},
	{"IODD", 4, 96554},
	{"ENGG", 4, 96555},
	{"DISCONTINUITIES", 15, 96556},
	{"KEOB", 4, 96557},
	{"KBIL", 4, 96558},
	{"ILAK", 4, 96559},
	{"FBAK", 4, 96560},
	{"AURY", 4, 96561},
	{"GRIPES", 6, 96562},
	{"TATAR", 5, 96563},
	{"CLICKIT", 7, 96564},
	{"HEADQUARTER", 11, 96565},
	{"PROKOFIEV", 9, 96566},
	{"OSJU", 4, 96567},
	{"NGHW", 4, 96568},
	{"ESUV", 4, 96569},
	{"DANTZ", 5, 96570},
	{"NLUG", 4, 96571},
	{"IMPLEMENTORS", 12, 96572},
	{"PREVIEWING", 10, 96573},
	{"BUZZFLASH", 9, 96574},
	{"TOMBALL", 7, 96575},
	{"XALL", 4, 96576},
	{"WIPI", 4, 96577},
	{"MYRT", 4, 96578},
	{"INYW", 4, 96579},
	{"FGAY", 4, 96580},
	{"DRIX", 4, 96581},
	{"AYMC", 4, 96582},
	{"BACARDI", 7, 96583},
	{"SPIFFY", 6, 96584},
	{"SUBSCRIPTS", 10, 96585},
	{"CURIAE", 6, 96586},
	{"ACKER", 5, 96587},
	{"ONDERWIJS", 9, 96588},
	{"RODOLFO", 7, 96589},
	{"HRMS", 4, 96590},
	{"YAJU", 4, 96591},
	{"UYBA", 4, 96592},
	{"RYII", 4, 96593},
	{"OBYO", 4, 96594},
	{"NCWI", 4, 96595},
	{"LEAZ", 4, 96596},
	{"AIGR", 4, 96597},
	{"AAFR", 4, 96598},
	{"LYASE", 5, 96599},
	{"NUANCED", 7, 96600},
	{"ONCOLOGIST", 10, 96601},
	{"LLLP", 4, 96602},
	{"MADD", 4, 96603},
	{"ABOMINABLE", 10, 96604},
	{"RATTLED", 7, 96605},
	{"BASSE", 5, 96606},
	{"FARMHOUSES", 10, 96607},
	{"ALAMOSA", 7, 96608},
	{"DIRECTO", 7, 96609},
	{"DECNET", 6, 96610},
	{"DDYL", 4, 96611},
	{"CUSG", 4, 96612},
	{"DIAMONDMAX", 10, 96613},
	{"TAMBOURINE", 10, 96614},
	{"ROUGHING", 8, 96615},
	{"SCHLUMBERGER", 12, 96616},
	{"TRAMWAY", 7, 96617},
	{"RHIP", 4, 96618},
	{"GVIA", 4, 96619},
	{"GSDR", 4, 96620},
	{"FTMI", 4, 96621},
	{"EMJU", 4, 96622},
	{"COINSURANCE", 11, 96623},
	{"AGROFORESTRY", 12, 96624},
	{"STARTIME", 8, 96625},
	{"SLAYERS", 7, 96626},
	{"VENOMOUS", 8, 96627},
	{"FACEOFF", 7, 96628},
	{"IMPRESSIVELY", 12, 96629},
	{"BASELINES", 9, 96630},
	{"ADDRESSABLE", 11, 96631},
	{"REAPPLY", 7, 96632},
	{"ISPELL", 6, 96633},
	{"PATRIARCHY", 10, 96634},
	{"AIDEN", 5, 96635},
	{"INEXTRICABLY", 12, 96636},
	{"ARRINGTON", 9, 96637},
	{"ETEXTS", 6, 96638},
	{"WSBO", 4, 96639},
	{"TDUB", 4, 96640},
	{"MFAS", 4, 96641},
	{"GUSM", 4, 96642},
	{"EPFI", 4, 96643},
	{"EGGW", 4, 96644},
	{"DDEU", 4, 96645},
	{"TAPERING", 8, 96646},
	{"LABRADA", 7, 96647},
	{"ROASTERS", 8, 96648},
	{"AKANE", 5, 96649},
	{"MELODIE", 7, 96650},
	{"AFFORDABLY", 10, 96651},
	{"MINKA", 5, 96652},
	{"OTLU", 4, 96653},
	{"HOMELANDS", 9, 96654},
	{"PRINZ", 5, 96655},
	{"QWIDGET", 7, 96656},
	{"ALEUTIAN", 8, 96657},
	{"DAMPEN", 6, 96658},
	{"CASHMAN", 7, 96659},
	{"SNOWMEN", 7, 96660},
	{"LUMINESCENCE", 12, 96661},
	{"LANDSCAPERS", 11, 96662},
	{"LLANO", 5, 96663},
	{"INTERDEPARTMENTAL", 17, 96664},
	{"UGAW", 4, 96665},
	{"UAGA", 4, 96666},
	{"MRJO", 4, 96667},
	{"MRHO", 4, 96668},
	{"LAGL", 4, 96669},
	{"EWJU", 4, 96670},
	{"BEXP", 4, 96671},
	{"UNJUSTLY", 8, 96672},
	{"NEUTERED", 8, 96673},
	{"SINBAD", 6, 96674},
	{"MASTERWORKS", 11, 96675},
	{"YUK", 3, 96676},
	{"RHIZOME", 7, 96677},
	{"LEPRECHAUN", 10, 96678},
	{"FOKKER", 6, 96679},
	{"UNKNOWINGLY", 11, 96680},
	{"YNUR", 4, 96681},
	{"ULHI", 4, 96682},
	{"GNEL", 4, 96683},
	{"AKMO", 4, 96684},
	{"REHEARSE", 8, 96685},
	{"APERTURES", 9, 96686},
	{"ABUJA", 5, 96687},
	{"TAIYO", 5, 96688},
	{"POHL", 4, 96689},
	{"SEDUCING", 8, 96690},
	{"MMWR", 4, 96691},
	{"CADD", 4, 96692},
	{"CULPEPER", 8, 96693},
	{"SCREECHING", 10, 96694},
	{"RADER", 5, 96695},
	{"YRAS", 4, 96696},
	{"UTHJ", 4, 96697},
	{"RTZA", 4, 96698},
	{"KUPM", 4, 96699},
	{"FBOW", 4, 96700},
	{"DIGICAM", 7, 96701},
	{"REEDY", 5, 96702},
	{"CEDED", 5, 96703},
	{"REFORMULATED", 12, 96704},
	{"IMBUED", 6, 96705},
	{"ELCA", 4, 96706},
	{"CONSID", 6, 96707},
	{"RATZINGER", 9, 96708},
	{"BANGIN", 6, 96709},
	{"HAPPEND", 7, 96710},
	{"PIPH", 4, 96711},
	{"PFAC", 4, 96712},
	{"OLIW", 4, 96713},
	{"NPUM", 4, 96714},
	{"MADW", 4, 96715},
	{"GOAC", 4, 96716},
	{"FMYR", 4, 96717},
	{"TECHNORIDE", 10, 96718},
	{"AMIDE", 5, 96719},
	{"PUTFILE", 7, 96720},
	{"NETVIEW", 7, 96721},
	{"TIFP", 4, 96722},
	{"RALZ", 4, 96723},
	{"ORWW", 4, 96724},
	{"DKAI", 4, 96725},
	{"DUPREE", 6, 96726},
	{"FEARSOME", 8, 96727},
	{"PSYCHOMETRIC", 12, 96728},
	{"BUREAUX", 7, 96729},
	{"MEDIAMATIC", 10, 96730},
	{"BRUCKNER", 8, 96731},
	{"SAPP", 4, 96732},
	{"LIKEABLE", 8, 96733},
	{"SLEDS", 5, 96734},
	{"URYK", 4, 96735},
	{"UOPE", 4, 96736},
	{"OKRO", 4, 96737},
	{"KPHI", 4, 96738},
	{"AYKA", 4, 96739},
	{"APDE", 4, 96740},
	{"CHRISTENDOM", 11, 96741},
	{"OKCUPID", 7, 96742},
	{"EXPRESSIONISM", 13, 96743},
	{"GYDA", 4, 96744},
	{"BOOTP", 5, 96745},
	{"POSTCODES", 9, 96746},
	{"AISHWARYA", 9, 96747},
	{"LAUER", 5, 96748},
	{"BIOGRAPHER", 10, 96749},
	{"ZALES", 5, 96750},
	{"CPSR", 4, 96751},
	{"WREAK", 5, 96752},
	{"TARRAGONA", 9, 96753},
	{"PENULTIMATE", 11, 96754},
	{"PLANTA", 6, 96755},
	{"MAGICOLOR", 9, 96756},
	{"NDOX", 4, 96757},
	{"KIPT", 4, 96758},
	{"KCRI", 4, 96759},
	{"FLYM", 4, 96760},
	{"QATARI", 6, 96761},
	{"SILIGURI", 8, 96762},
	{"LEOTARD", 7, 96763},
	{"CONSTRUCTIVIST", 14, 96764},
	{"BRIDEGROOM", 10, 96765},
	{"UNDERPINNED", 11, 96766},
	{"SHULMAN", 7, 96767},
	{"CATCHMENTS", 10, 96768},
	{"EBUILD", 6, 96769},
	{"SEYL", 4, 96770},
	{"LONU", 4, 96771},
	{"SOLOGIRL", 8, 96772},
	{"SWARMING", 8, 96773},
	{"SHANNEN", 7, 96774},
	{"THREADLESS", 10, 96775},
	{"CAPOEIRA", 8, 96776},
	{"ACCOMPLICE", 10, 96777},
	{"VIVRE", 5, 96778},
	{"CESG", 4, 96779},
	{"CHUCKLES", 8, 96780},
	{"ESPYS", 5, 96781},
	{"FOSTORIA", 8, 96782},
	{"YKON", 4, 96783},
	{"UNBI", 4, 96784},
	{"TICY", 4, 96785},
	{"DGAZ", 4, 96786},
	{"MORRILL", 7, 96787},
	{"BROOKVILLE", 10, 96788},
	{"VAJPAYEE", 8, 96789},
	{"STRAIGHTENER", 12, 96790},
	{"CAPRA", 5, 96791},
	{"SHAKTI", 6, 96792},
	{"UFTW", 4, 96793},
	{"KDAV", 4, 96794},
	{"BOPE", 4, 96795},
	{"AMYR", 4, 96796},
	{"LOOPER", 6, 96797},
	{"MORPHOGENESIS", 13, 96798},
	{"SIDELINED", 9, 96799},
	{"FREECAMS", 8, 96800},
	{"SERVI", 5, 96801},
	{"EXTENDEDSTAY", 12, 96802},
	{"IRREGULARITY", 12, 96803},
	{"TUDD", 4, 96804},
	{"SCUF", 4, 96805},
	{"ROPC", 4, 96806},
	{"NKTR", 4, 96807},
	{"LDNU", 4, 96808},
	{"HDOL", 4, 96809},
	{"DOEU", 4, 96810},
	{"BOFM", 4, 96811},
	{"IMMIGRATED", 10, 96812},
	{"GRAYLING", 8, 96813},
	{"TROJ", 4, 96814},
	{"BLOAT", 5, 96815},
	{"IMPEDED", 7, 96816},
	{"ENTERASYS", 9, 96817},
	{"ENROUTE", 7, 96818},
	{"PROCE", 5, 96819},
	{"GRAVESTONE", 10, 96820},
	{"OBAF", 4, 96821},
	{"MYSL", 4, 96822},
	{"MMYO", 4, 96823},
	{"IKKO", 4, 96824},
	{"HOBL", 4, 96825},
	{"POMPOUS", 7, 96826},
	{"BACKWATER", 9, 96827},
	{"KIWIS", 5, 96828},
	{"MONOMERS", 8, 96829},
	{"SUBVERT", 7, 96830},
	{"VYWA", 4, 96831},
	{"TBYK", 4, 96832},
	{"EIDR", 4, 96833},
	{"DPEC", 4, 96834},
	{"CKYL", 4, 96835},
	{"OTSEGO", 6, 96836},
	{"SUMMATIVE", 9, 96837},
	{"FURSTENBERG", 11, 96838},
	{"ARPANET", 7, 96839},
	{"FEENEY", 6, 96840},
	{"ARTUR", 5, 96841},
	{"ADVIL", 5, 96842},
	{"SEDER", 5, 96843},
	{"KWEB", 4, 96844},
	{"ICAY", 4, 96845},
	{"ZWC", 3, 96846},
	{"YBZ", 3, 96847},
	{"MLZ", 3, 96848},
	{"KDZ", 3, 96849},
	{"JVD", 3, 96850},
	{"DGQ", 3, 96851},
	{"MUSCLED", 7, 96852},
	{"INSTRUMENTALITY", 15, 96853},
	{"INSOMNIAC", 9, 96854},
	{"YCOF", 4, 96855},
	{"TZKI", 4, 96856},
	{"SHYB", 4, 96857},
	{"MNOM", 4, 96858},
	{"MEYA", 4, 96859},
	{"LFFU", 4, 96860},
	{"IELG", 4, 96861},
	{"EYUA", 4, 96862},
	{"CKCI", 4, 96863},
	{"LINUXDEVICES", 12, 96864},
	{"WEBSERVICE", 10, 96865},
	{"VIDEOCLIPS", 10, 96866},
	{"COWICHAN", 8, 96867},
	{"DUCKWORTH", 9, 96868},
	{"BARNABY", 7, 96869},
	{"HEROCLIX", 8, 96870},
	{"ALDOUS", 6, 96871},
	{"ELTYPE", 6, 96872},
	{"DETONATED", 9, 96873},
	{"ADDIE", 5, 96874},
	{"ELECTROPHYSIOLOGY", 17, 96875},
	{"GOREY", 5, 96876},
	{"XPOL", 4, 96877},
	{"TYOB", 4, 96878},
	{"MMAM", 4, 96879},
	{"LBC", 3, 96880},
	{"ANTWORT", 7, 96881},
	{"ROSANNE", 7, 96882},
	{"IMPASSIONED", 11, 96883},
	{"DECREMENT", 9, 96884},
	{"MOUS", 4, 96885},
	{"SOREN", 5, 96886},
	{"RAXI", 4, 96887},
	{"HDUK", 4, 96888},
	{"PRODUCTIVELY", 12, 96889},
	{"THUMBSUCKER", 11, 96890},
	{"REIMER", 6, 96891},
	{"DESPERADO", 9, 96892},
	{"BERLIOZ", 7, 96893},
	{"LYTTON", 6, 96894},
	{"BUILDREQUIRES", 13, 96895},
	{"SOLIDIFY", 8, 96896},
	{"HADEN", 5, 96897},
	{"AUTHORSDEN", 10, 96898},
	{"QUIG", 4, 96899},
	{"OCTU", 4, 96900},
	{"JAYL", 4, 96901},
	{"AIMB", 4, 96902},
	{"CALLAS", 6, 96903},
	{"TAKINGS", 7, 96904},
	{"SITTIN", 6, 96905},
	{"TRIPLEX", 7, 96906},
	{"HANDPICKED", 10, 96907},
	{"FLAVORING", 9, 96908},
	{"BAREILLY", 8, 96909},
	{"RUMINATIONS", 11, 96910},
	{"PFP", 3, 96911},
	{"ANATOLIA", 8, 96912},
	{"NLEC", 4, 96913},
	{"LAGB", 4, 96914},
	{"AWPO", 4, 96915},
	{"EXTERIORS", 9, 96916},
	{"MOUTON", 6, 96917},
	{"CALLISTO", 8, 96918},
	{"PROBIOTICS", 10, 96919},
	{"CONTAGION", 9, 96920},
	{"CONFORMANT", 10, 96921},
	{"CAMEOS", 6, 96922},
	{"ARCHIMEDES", 10, 96923},
	{"HINGHAM", 7, 96924},
	{"JDCLYDE", 7, 96925},
	{"CASINGS", 7, 96926},
	{"ABUTTING", 8, 96927},
	{"DESECRATION", 11, 96928},
	{"PPUB", 4, 96929},
	{"MLOV", 4, 96930},
	{"LKSF", 4, 96931},
	{"APYO", 4, 96932},
	{"EQUALIZERS", 10, 96933},
	{"SYSV", 4, 96934},
	{"BUPA", 4, 96935},
	{"VENTURER", 8, 96936},
	{"LACKLUSTER", 10, 96937},
	{"EMBARCADERO", 11, 96938},
	{"WUPPERTAL", 9, 96939},
	{"ZISC", 4, 96940},
	{"TEGG", 4, 96941},
	{"IKWA", 4, 96942},
	{"CDET", 4, 96943},
	{"POWERPACK", 9, 96944},
	{"MASTERPRINT", 11, 96945},
	{"GUNMETAL", 8, 96946},
	{"PARAMETERIZATION", 16, 96947},
	{"WESTERVILLE", 11, 96948},
	{"JUNIATA", 7, 96949},
	{"BOLSTERED", 9, 96950},
	{"PSGR", 4, 96951},
	{"OBGR", 4, 96952},
	{"KRYP", 4, 96953},
	{"IKRA", 4, 96954},
	{"EXBE", 4, 96955},
	{"ECWA", 4, 96956},
	{"POCKETBOOK", 10, 96957},
	{"TOWNES", 6, 96958},
	{"MEXICALI", 8, 96959},
	{"ANSELMO", 7, 96960},
	{"INVERTING", 9, 96961},
	{"MISINTERPRETED", 14, 96962},
	{"TINLEY", 6, 96963},
	{"ROOG", 4, 96964},
	{"OGYU", 4, 96965},
	{"KIDM", 4, 96966},
	{"EUCI", 4, 96967},
	{"CMEN", 4, 96968},
	{"CIFU", 4, 96969},
	{"BLYJ", 4, 96970},
	{"BIDW", 4, 96971},
	{"GARLANDS", 8, 96972},
	{"VARMA", 5, 96973},
	{"SPARKLY", 7, 96974},
	{"CISNEROS", 8, 96975},
	{"AUTOMAKER", 9, 96976},
	{"SPUTUM", 6, 96977},
	{"ORNITHOLOGY", 11, 96978},
	{"XEDD", 4, 96979},
	{"UTYL", 4, 96980},
	{"UEIF", 4, 96981},
	{"TUCE", 4, 96982},
	{"RKJU", 4, 96983},
	{"GMYC", 4, 96984},
	{"ATRP", 4, 96985},
	{"MONGOL", 6, 96986},
	{"YADDA", 5, 96987},
	{"AUDACIOUS", 9, 96988},
	{"MIDSHIPMEN", 10, 96989},
	{"UGPR", 4, 96990},
	{"UDYD", 4, 96991},
	{"RSIW", 4, 96992},
	{"NDPC", 4, 96993},
	{"LMDO", 4, 96994},
	{"ICECAST", 7, 96995},
	{"STORTFORD", 9, 96996},
	{"PEELER", 6, 96997},
	{"ABRIR", 5, 96998},
	{"DEGRADES", 8, 96999},
	{"FOREFOOT", 8, 97000},
	{"PCLE", 4, 97001},
	{"JOGG", 4, 97002},
	{"GOBB", 4, 97003},
	{"DICL", 4, 97004},
	{"MAGGIORE", 8, 97005},
	{"PROTESTANTISM", 13, 97006},
	{"CALIBRATING", 11, 97007},
	{"WILLYS", 6, 97008},
	{"SORENESS", 8, 97009},
	{"SPEAKERSTANDS", 13, 97010},
	{"CEDARVILLE", 10, 97011},
	{"YITL", 4, 97012},
	{"LIRO", 4, 97013},
	{"BOLDNESS", 8, 97014},
	{"REPEALS", 7, 97015},
	{"CONFRONTATIONAL", 15, 97016},
	{"MUSCATINE", 9, 97017},
	{"SIMCA", 5, 97018},
	{"UBJU", 4, 97019},
	{"PYMA", 4, 97020},
	{"ENTRAPMENT", 10, 97021},
	{"BRECHT", 6, 97022},
	{"DEBUGGERS", 9, 97023},
	{"SCHIP", 5, 97024},
	{"ESCOBAR", 7, 97025},
	{"ADVECTION", 9, 97026},
	{"DUBS", 4, 97027},
	{"SURYA", 5, 97028},
	{"YAZOO", 5, 97029},
	{"KEOGH", 5, 97030},
	{"CORMIER", 7, 97031},
	{"NMYV", 4, 97032},
	{"KEEW", 4, 97033},
	{"CRAMPING", 8, 97034},
	{"KALGOORLIE", 10, 97035},
	{"SCREENWRITERS", 13, 97036},
	{"MINIMISATION", 12, 97037},
	{"PERTURBATIVE", 12, 97038},
	{"INHALT", 6, 97039},
	{"DUCTING", 7, 97040},
	{"CONFIGS", 7, 97041},
	{"OAKHURST", 8, 97042},
	{"VEAY", 4, 97043},
	{"RODW", 4, 97044},
	{"GODG", 4, 97045},
	{"EIBM", 4, 97046},
	{"AIRQ", 4, 97047},
	{"CHAGALL", 7, 97048},
	{"FODORS", 6, 97049},
	{"CHOPSTICKS", 10, 97050},
	{"HEFYD", 5, 97051},
	{"OPHTHALMOLOGISTS", 16, 97052},
	{"OTRAS", 5, 97053},
	{"ESSENDON", 8, 97054},
	{"ADJUDICATOR", 11, 97055},
	{"FANTOM", 6, 97056},
	{"MONTPARNASSE", 12, 97057},
	{"GENERALMENTE", 12, 97058},
	{"HOOLIGANS", 9, 97059},
	{"CASSIUS", 7, 97060},
	{"ALPACAS", 7, 97061},
	{"PCTS", 4, 97062},
	{"POWDERY", 7, 97063},
	{"GYSH", 4, 97064},
	{"EDIX", 4, 97065},
	{"TRIGUN", 6, 97066},
	{"BASTIAN", 7, 97067},
	{"LONGINES", 8, 97068},
	{"SIGMOD", 6, 97069},
	{"VLOG", 4, 97070},
	{"YOHJI", 5, 97071},
	{"EXPORTATION", 11, 97072},
	{"DIVERGE", 7, 97073},
	{"CURLEY", 6, 97074},
	{"LOOSENED", 8, 97075},
	{"GBYR", 4, 97076},
	{"FTBR", 4, 97077},
	{"WARFIELD", 8, 97078},
	{"OFFICETEAM", 10, 97079},
	{"UNCHARTED", 9, 97080},
	{"RADIAN", 6, 97081},
	{"ROCA", 4, 97082},
	{"VYMA", 4, 97083},
	{"PPYP", 4, 97084},
	{"LTYD", 4, 97085},
	{"MISUNDERSTAND", 13, 97086},
	{"INCIDENCES", 10, 97087},
	{"ONCOLOGISTS", 11, 97088},
	{"GENOTYPING", 10, 97089},
	{"VIRILITY", 8, 97090},
	{"JURIED", 6, 97091},
	{"ITESM", 5, 97092},
	{"GLAXO", 5, 97093},
	{"YDOB", 4, 97094},
	{"NKDO", 4, 97095},
	{"GSCU", 4, 97096},
	{"GEYSER", 6, 97097},
	{"LAVERNE", 7, 97098},
	{"INALIENABLE", 11, 97099},
	{"KYLIX", 5, 97100},
	{"SOUNDWORKS", 10, 97101},
	{"RECORDSET", 9, 97102},
	{"UNGARO", 6, 97103},
	{"NYSGXRC", 7, 97104},
	{"SNOWBIRD", 8, 97105},
	{"NORDEN", 6, 97106},
	{"CONTIN", 6, 97107},
	{"UBWO", 4, 97108},
	{"ROBV", 4, 97109},
	{"MSKE", 4, 97110},
	{"DMYG", 4, 97111},
	{"ADHY", 4, 97112},
	{"LECHE", 5, 97113},
	{"UNTAMED", 7, 97114},
	{"VISUALIZATIONS", 14, 97115},
	{"BUSA", 4, 97116},
	{"PAINSTAKINGLY", 13, 97117},
	{"IMBRUGLIA", 9, 97118},
	{"RSSK", 4, 97119},
	{"PEDJ", 4, 97120},
	{"FMD", 3, 97121},
	{"VIEL", 4, 97122},
	{"XXVIII", 6, 97123},
	{"HYFA", 4, 97124},
	{"DESCARGAS", 9, 97125},
	{"ANNABELLE", 9, 97126},
	{"ROBOCOP", 7, 97127},
	{"NIGHTSHADE", 10, 97128},
	{"LEGOLAND", 8, 97129},
	{"ROSEMOUNT", 9, 97130},
	{"SHLOMO", 6, 97131},
	{"GERARDO", 7, 97132},
	{"PYG", 3, 97133},
	{"DELUCA", 6, 97134},
	{"TASER", 5, 97135},
	{"RGOH", 4, 97136},
	{"MPBA", 4, 97137},
	{"IBAB", 4, 97138},
	{"GMYB", 4, 97139},
	{"EBTB", 4, 97140},
	{"MEDDLING", 8, 97141},
	{"EXCHG", 5, 97142},
	{"BOLO", 4, 97143},
	{"OBJECTING", 9, 97144},
	{"HYDROCHLOROTHIAZIDE", 19, 97145},
	{"WRITEUP", 7, 97146},
	{"SHODDY", 6, 97147},
	{"DECLEOR", 7, 97148},
	{"URBT", 4, 97149},
	{"OUNP", 4, 97150},
	{"MDOM", 4, 97151},
	{"MAXT", 4, 97152},
	{"GGUE", 4, 97153},
	{"GUNBOUND", 8, 97154},
	{"DECEPTIVELY", 11, 97155},
	{"JANEWAY", 7, 97156},
	{"LANGHAM", 7, 97157},
	{"INTELLIMOUSE", 12, 97158},
	{"FREELANDER", 10, 97159},
	{"MRF", 3, 97160},
	{"BELKNAP", 7, 97161},
	{"CONFRONTATIONS", 14, 97162},
	{"FREELANCING", 11, 97163},
	{"YIORG", 5, 97164},
	{"WOOLWORTHS", 10, 97165},
	{"ZPAT", 4, 97166},
	{"LAGF", 4, 97167},
	{"ARGL", 4, 97168},
	{"STONEHAM", 8, 97169},
	{"CALLIE", 6, 97170},
	{"NEWYDDION", 9, 97171},
	{"SALUTATION", 10, 97172},
	{"HEARTBEATS", 10, 97173},
	{"MERSEY", 6, 97174},
	{"ALTERCATION", 11, 97175},
	{"EXPRESSO", 8, 97176},
	{"TRUSTWORTHINESS", 15, 97177},
	{"WIPRO", 5, 97178},
	{"MTDNA", 5, 97179},
	{"LMLY", 4, 97180},
	{"ECHG", 4, 97181},
	{"CCOC", 4, 97182},
	{"OCTAGONAL", 9, 97183},
	{"PILLOWCASE", 10, 97184},
	{"MENDED", 6, 97185},
	{"ASSED", 5, 97186},
	{"HERVE", 5, 97187},
	{"NAVIGATORS", 10, 97188},
	{"INDOCHINA", 9, 97189},
	{"XMOR", 4, 97190},
	{"OERR", 4, 97191},
	{"LTTR", 4, 97192},
	{"KYHI", 4, 97193},
	{"KAJO", 4, 97194},
	{"BAGT", 4, 97195},
	{"NOTCHES", 7, 97196},
	{"ODYSSEUS", 8, 97197},
	{"UNLEASHING", 10, 97198},
	{"INFOCOM", 7, 97199},
	{"RECETTE", 7, 97200},
	{"UNFAVOURABLE", 12, 97201},
	{"KOPP", 4, 97202},
	{"CRYSTALLOGRAPHIC", 16, 97203},
	{"ABJECT", 6, 97204},
	{"LYMPHOMAS", 9, 97205},
	{"MORDEN", 6, 97206},
	{"OFFI", 4, 97207},
	{"YLIA", 4, 97208},
	{"OKKA", 4, 97209},
	{"LKSL", 4, 97210},
	{"GTOQ", 4, 97211},
	{"GSGA", 4, 97212},
	{"DJUA", 4, 97213},
	{"DREPPER", 7, 97214},
	{"GRATUITIES", 10, 97215},
	{"REGENERATING", 12, 97216},
	{"GRENVILLE", 9, 97217},
	{"HERETICAL", 9, 97218},
	{"ALLEXPERTS", 10, 97219},
	{"HYDROXYCUT", 10, 97220},
	{"CSCI", 4, 97221},
	{"MERVYN", 6, 97222},
	{"WTEL", 4, 97223},
	{"UKEC", 4, 97224},
	{"RIFU", 4, 97225},
	{"MWOM", 4, 97226},
	{"DUSP", 4, 97227},
	{"BDAL", 4, 97228},
	{"RIVETED", 7, 97229},
	{"COLSON", 6, 97230},
	{"HISTOLOGIC", 10, 97231},
	{"QUIESCENT", 9, 97232},
	{"STRANGENESS", 11, 97233},
	{"TELEWORK", 8, 97234},
	{"RIDEAU", 6, 97235},
	{"TINCTURE", 8, 97236},
	{"PROLIFERATIVE", 13, 97237},
	{"KISMET", 6, 97238},
	{"YLVE", 4, 97239},
	{"WDRE", 4, 97240},
	{"IPGR", 4, 97241},
	{"KUBUNTU", 7, 97242},
	{"TAKEOVERS", 9, 97243},
	{"ERECTING", 8, 97244},
	{"SIZEMORE", 8, 97245},
	{"DRAFTER", 7, 97246},
	{"CHAV", 4, 97247},
	{"CONGA", 5, 97248},
	{"BDL", 3, 97249},
	{"ROMANTIK", 8, 97250},
	{"TINYSOFA", 8, 97251},
	{"TENDERER", 8, 97252},
	{"URAO", 4, 97253},
	{"UBTW", 4, 97254},
	{"HUSG", 4, 97255},
	{"GLAI", 4, 97256},
	{"DEEJAY", 6, 97257},
	{"FAVORITOS", 9, 97258},
	{"AGAVE", 5, 97259},
	{"YASMINE", 7, 97260},
	{"WIRTSCHAFT", 10, 97261},
	{"SICILIA", 7, 97262},
	{"MAILLIST", 8, 97263},
	{"ZWY", 3, 97264},
	{"UVK", 3, 97265},
	{"QUZ", 3, 97266},
	{"JKY", 3, 97267},
	{"GZC", 3, 97268},
	{"FQX", 3, 97269},
	{"FQR", 3, 97270},
	{"CZV", 3, 97271},
	{"BWU", 3, 97272},
	{"SINEAD", 6, 97273},
	{"PEKI", 4, 97274},
	{"LYIA", 4, 97275},
	{"CKMY", 4, 97276},
	{"ADNAN", 5, 97277},
	{"ROKU", 4, 97278},
	{"COMPRESSES", 10, 97279},
	{"IMPELLER", 8, 97280},
	{"WELLINGBOROUGH", 14, 97281},
	{"KILLZONE", 8, 97282},
	{"GNBO", 4, 97283},
	{"PECL", 4, 97284},
	{"BOTULINUM", 9, 97285},
	{"PLAINVILLE", 10, 97286},
	{"HOOKAH", 6, 97287},
	{"SOUTHALL", 8, 97288},
	{"UMKC", 4, 97289},
	{"SINGIN", 6, 97290},
	{"YVEC", 4, 97291},
	{"VALN", 4, 97292},
	{"NIBR", 4, 97293},
	{"GMEI", 4, 97294},
	{"AXBU", 4, 97295},
	{"PROSTITUIERTE", 13, 97296},
	{"CAVANAUGH", 9, 97297},
	{"LUCIAN", 6, 97298},
	{"JAAR", 4, 97299},
	{"PITTING", 7, 97300},
	{"UJIA", 4, 97301},
	{"TBRY", 4, 97302},
	{"MICROPOLITAN", 12, 97303},
	{"BRADSTREET", 10, 97304},
	{"ENAMELED", 8, 97305},
	{"ETHERS", 6, 97306},
	{"NEGRAS", 6, 97307},
	{"PERSEVERE", 9, 97308},
	{"NICKERSON", 9, 97309},
	{"EXTRAMURAL", 10, 97310},
	{"YUPG", 4, 97311},
	{"TJOY", 4, 97312},
	{"RUML", 4, 97313},
	{"SHINJUKU", 8, 97314},
	{"NEARSHORE", 9, 97315},
	{"GCM", 3, 97316},
	{"CROFTON", 7, 97317},
	{"INFLUENZAE", 10, 97318},
	{"DETRACTORS", 10, 97319},
	{"ARABESQUE", 9, 97320},
	{"FITTEST", 7, 97321},
	{"VORTICES", 8, 97322},
	{"TARNISH", 7, 97323},
	{"UIDW", 4, 97324},
	{"RITG", 4, 97325},
	{"OPTF", 4, 97326},
	{"IRKW", 4, 97327},
	{"IPSK", 4, 97328},
	{"GUSU", 4, 97329},
	{"CUEM", 4, 97330},
	{"ISTHMUS", 7, 97331},
	{"GIULIANO", 8, 97332},
	{"AIRLINERS", 9, 97333},
	{"WORDT", 5, 97334},
	{"KLEIMAN", 7, 97335},
	{"SETRGBCOLOR", 11, 97336},
	{"MCNEESE", 7, 97337},
	{"VISHAY", 6, 97338},
	{"KIPR", 4, 97339},
	{"HILDEBRAND", 10, 97340},
	{"TWIKIROOT", 9, 97341},
	{"BDR", 3, 97342},
	{"THIEL", 5, 97343},
	{"PROYECTO", 8, 97344},
	{"UPMU", 4, 97345},
	{"UGGY", 4, 97346},
	{"UDOU", 4, 97347},
	{"RLSL", 4, 97348},
	{"PTAM", 4, 97349},
	{"MDAM", 4, 97350},
	{"HICW", 4, 97351},
	{"GBRU", 4, 97352},
	{"BUSP", 4, 97353},
	{"BSOU", 4, 97354},
	{"AVLI", 4, 97355},
	{"VERONIKA", 8, 97356},
	{"EATERIES", 8, 97357},
	{"HOLOGRAMS", 9, 97358},
	{"DRAWDOWN", 8, 97359},
	{"EXCEEDANCE", 10, 97360},
	{"TREADS", 6, 97361},
	{"GETING", 6, 97362},
	{"CLARINEX", 8, 97363},
	{"DROPSHIP", 8, 97364},
	{"SMCD", 4, 97365},
	{"POFU", 4, 97366},
	{"GNSB", 4, 97367},
	{"ASYD", 4, 97368},
	{"ENCRYPTS", 8, 97369},
	{"ZILLA", 5, 97370},
	{"FORWARDER", 9, 97371},
	{"LENGTHEN", 8, 97372},
	{"SOCIALIZED", 10, 97373},
	{"CITYVOX", 7, 97374},
	{"MAYDAY", 6, 97375},
	{"YGOU", 4, 97376},
	{"CHSG", 4, 97377},
	{"ABIP", 4, 97378},
	{"MOFFATT", 7, 97379},
	{"SCHOLZ", 6, 97380},
	{"ESPERANCE", 9, 97381},
	{"BARISTA", 7, 97382},
	{"HONING", 6, 97383},
	{"RKFL", 4, 97384},
	{"OKEX", 4, 97385},
	{"MSRU", 4, 97386},
	{"LNUR", 4, 97387},
	{"GHIW", 4, 97388},
	{"FSUL", 4, 97389},
	{"DRST", 4, 97390},
	{"CASD", 4, 97391},
	{"ROADTRIP", 8, 97392},
	{"BACTERIOLOGY", 12, 97393},
	{"OXBRIDGE", 8, 97394},
	{"USEC", 4, 97395},
	{"PRODIGIOUS", 10, 97396},
	{"REORDERING", 10, 97397},
	{"SPOONFUL", 8, 97398},
	{"BEEPS", 5, 97399},
	{"SAFCO", 5, 97400},
	{"HERPESVIRUS", 11, 97401},
	{"SOCIABLE", 8, 97402},
	{"LECLERC", 7, 97403},
	{"REQUISITIONS", 12, 97404},
	{"CALEXICO", 8, 97405},
	{"SCLERODERMA", 11, 97406},
	{"DEFTLY", 6, 97407},
	{"RAUCOUS", 7, 97408},
	{"GEOPOLITICS", 11, 97409},
	{"OPTIMIZERS", 10, 97410},
	{"CURIOS", 6, 97411},
	{"HAIRPIN", 7, 97412},
	{"ANTLR", 5, 97413},
	{"TOASTS", 6, 97414},
	{"LITMUS", 6, 97415},
	{"PBM", 3, 97416},
	{"COLLABORATES", 12, 97417},
	{"EQUUS", 5, 97418},
	{"TRACFONE", 8, 97419},
	{"WNUM", 4, 97420},
	{"REYG", 4, 97421},
	{"OKMY", 4, 97422},
	{"NYUP", 4, 97423},
	{"MRGR", 4, 97424},
	{"LSVA", 4, 97425},
	{"IPFU", 4, 97426},
	{"CDID", 4, 97427},
	{"GREYS", 5, 97428},
	{"STONINGTON", 10, 97429},
	{"EXAGGERATE", 10, 97430},
	{"INDEP", 5, 97431},
	{"SPECULUM", 8, 97432},
	{"NABISCO", 7, 97433},
	{"RAVENSWOOD", 10, 97434},
	{"TOOTSIE", 7, 97435},
	{"BLUSHED", 7, 97436},
	{"RCU", 3, 97437},
	{"SKSC", 4, 97438},
	{"HKIC", 4, 97439},
	{"POWERBOOKS", 10, 97440},
	{"SADDEST", 7, 97441},
	{"SPOOLS", 6, 97442},
	{"MEDICO", 6, 97443},
	{"GRINDS", 6, 97444},
	{"BIFFLE", 6, 97445},
	{"EXEMPTS", 7, 97446},
	{"TAYP", 4, 97447},
	{"NCYU", 4, 97448},
	{"LISZ", 4, 97449},
	{"CWEL", 4, 97450},
	{"QUADRUPOLE", 10, 97451},
	{"AMBLESIDE", 9, 97452},
	{"TIMEFRAMES", 10, 97453},
	{"CONOVER", 7, 97454},
	{"BATGIRL", 7, 97455},
	{"MOORESVILLE", 11, 97456},
	{"OSRAM", 5, 97457},
	{"MENOMINEE", 9, 97458},
	{"OUTPATIENTS", 11, 97459},
	{"IMMORALITY", 10, 97460},
	{"COULEE", 6, 97461},
	{"BUGGED", 6, 97462},
	{"YYAN", 4, 97463},
	{"NIXC", 4, 97464},
	{"MDOU", 4, 97465},
	{"GPP", 3, 97466},
	{"QEMU", 4, 97467},
	{"ETHNOLOGUE", 10, 97468},
	{"DASBLOG", 7, 97469},
	{"ADDINGTON", 9, 97470},
	{"MONSTERCOMMERCE", 15, 97471},
	{"MARCELLUS", 9, 97472},
	{"BLAKEY", 6, 97473},
	{"RDKN", 4, 97474},
	{"NRYP", 4, 97475},
	{"ILKT", 4, 97476},
	{"GEXH", 4, 97477},
	{"CBOM", 4, 97478},
	{"SEQEND", 6, 97479},
	{"GILDA", 5, 97480},
	{"SOJOURNER", 9, 97481},
	{"CIENCIA", 7, 97482},
	{"WENCH", 5, 97483},
	{"CELLE", 5, 97484},
	{"CDNAS", 5, 97485},
	{"ACCS", 4, 97486},
	{"SPONTANEITY", 11, 97487},
	{"ILLUSORY", 8, 97488},
	{"TIDL", 4, 97489},
	{"IODM", 4, 97490},
	{"REALBASIC", 9, 97491},
	{"ANNENBERG", 9, 97492},
	{"WEBBOARD", 8, 97493},
	{"RESCISSION", 10, 97494},
	{"PROFTPD", 7, 97495},
	{"GRAMMYS", 7, 97496},
	{"PERRIER", 7, 97497},
	{"BOLDED", 6, 97498},
	{"SYMPATHIZE", 10, 97499},
	{"RIBOSE", 6, 97500},
	{"MLYA", 4, 97501},
	{"IZEG", 4, 97502},
	{"GGAY", 4, 97503},
	{"FPED", 4, 97504},
	{"CYSP", 4, 97505},
	{"CTSV", 4, 97506},
	{"AMRS", 4, 97507},
	{"BACS", 4, 97508},
	{"INSPECTS", 8, 97509},
	{"LEFTIES", 7, 97510},
	{"SUGARLOAF", 9, 97511},
	{"KCC", 3, 97512},
	{"BLOOMER", 7, 97513},
	{"BARROWS", 7, 97514},
	{"YMFO", 4, 97515},
	{"VERZ", 4, 97516},
	{"NRAK", 4, 97517},
	{"LISJ", 4, 97518},
	{"KLEV", 4, 97519},
	{"EKAW", 4, 97520},
	{"CBSN", 4, 97521},
	{"ARBH", 4, 97522},
	{"AJIK", 4, 97523},
	{"YANKTON", 7, 97524},
	{"DYNAX", 5, 97525},
	{"KYAT", 4, 97526},
	{"TANTAMOUNT", 10, 97527},
	{"CAGNEY", 6, 97528},
	{"SARONG", 6, 97529},
	{"SLAUGHTERING", 12, 97530},
	{"RUSSERT", 7, 97531},
	{"TEWKESBURY", 10, 97532},
	{"SACHIN", 6, 97533},
	{"ENDOBJ", 6, 97534},
	{"MODELO", 6, 97535},
	{"YPTH", 4, 97536},
	{"NKOP", 4, 97537},
	{"MLYI", 4, 97538},
	{"AJAZ", 4, 97539},
	{"LUMPED", 6, 97540},
	{"STEPWISE", 8, 97541},
	{"SAKAMOTO", 8, 97542},
	{"OPHTHALMOL", 10, 97543},
	{"RAWSUGAR", 8, 97544},
	{"STRAIGHTENERS", 13, 97545},
	{"ISLAMORADA", 10, 97546},
	{"SCRIBED", 7, 97547},
	{"DISSECTED", 9, 97548},
	{"BORROWS", 7, 97549},
	{"FRIGID", 6, 97550},
	{"RTAV", 4, 97551},
	{"BUTTERS", 7, 97552},
	{"ROTHSTEIN", 9, 97553},
	{"HEMISPHERES", 11, 97554},
	{"ARMREST", 7, 97555},
	{"WOOLLEN", 7, 97556},
	{"VISCO", 5, 97557},
	{"VORTICITY", 9, 97558},
	{"MUSICK", 6, 97559},
	{"BRUTON", 6, 97560},
	{"ANCIENTWORLDS", 13, 97561},
	{"VENDA", 5, 97562},
	{"LUB", 3, 97563},
	{"HEADSHOTS", 9, 97564},
	{"WNCI", 4, 97565},
	{"WGIV", 4, 97566},
	{"SKSP", 4, 97567},
	{"PODO", 4, 97568},
	{"BEYT", 4, 97569},
	{"APPROXIMATES", 12, 97570},
	{"OVERWRITING", 11, 97571},
	{"RECIDIVISM", 10, 97572},
	{"ASHRAM", 6, 97573},
	{"SPECULATING", 11, 97574},
	{"OCDE", 4, 97575},
	{"PPUT", 4, 97576},
	{"NGKH", 4, 97577},
	{"KLING", 5, 97578},
	{"TGIF", 4, 97579},
	{"ROUNDERS", 8, 97580},
	{"IMPAIRS", 7, 97581},
	{"IMMOBILIZATION", 14, 97582},
	{"CARAFE", 6, 97583},
	{"ENTERIC", 7, 97584},
	{"GUNZ", 4, 97585},
	{"DPD", 3, 97586},
	{"ABELL", 5, 97587},
	{"PLACENTIA", 9, 97588},
	{"PAWNS", 5, 97589},
	{"EQUI", 4, 97590},
	{"OUTERMOST", 9, 97591},
	{"AFTERALL", 8, 97592},
	{"UERW", 4, 97593},
	{"RUPW", 4, 97594},
	{"MILLERSVILLE", 12, 97595},
	{"RUBENSTEIN", 10, 97596},
	{"BUCCANEER", 9, 97597},
	{"MARIMBA", 7, 97598},
	{"CASERO", 6, 97599},
	{"QUARTERBACKS", 12, 97600},
	{"VRET", 4, 97601},
	{"TUCC", 4, 97602},
	{"LMBU", 4, 97603},
	{"KBOU", 4, 97604},
	{"IELP", 4, 97605},
	{"GUEU", 4, 97606},
	{"ERCK", 4, 97607},
	{"EKEM", 4, 97608},
	{"EIMW", 4, 97609},
	{"DYQU", 4, 97610},
	{"PEACHY", 6, 97611},
	{"BLOOMSBURG", 10, 97612},
	{"SELWYN", 6, 97613},
	{"HOTLINK", 7, 97614},
	{"RECCOMEND", 9, 97615},
	{"YFUS", 4, 97616},
	{"XEDL", 4, 97617},
	{"UELG", 4, 97618},
	{"LYAK", 4, 97619},
	{"EDGM", 4, 97620},
	{"WEMEN", 5, 97621},
	{"SEAPLANE", 8, 97622},
	{"NEUTROGENA", 10, 97623},
	{"CCCC", 4, 97624},
	{"RECIPIES", 8, 97625},
	{"MABS", 4, 97626},
	{"CYNNWYS", 7, 97627},
	{"WESTPHALIA", 10, 97628},
	{"NVRAM", 5, 97629},
	{"AUGMENTING", 10, 97630},
	{"WANU", 4, 97631},
	{"UORA", 4, 97632},
	{"STMC", 4, 97633},
	{"SRUR", 4, 97634},
	{"ORZE", 4, 97635},
	{"ALDL", 4, 97636},
	{"WINDED", 6, 97637},
	{"PODER", 5, 97638},
	{"MYOPIA", 6, 97639},
	{"MANUKA", 6, 97640},
	{"METHINKS", 8, 97641},
	{"RAMBLES", 7, 97642},
	{"NAMUR", 5, 97643},
	{"TYNDALE", 7, 97644},
	{"MEMBRO", 6, 97645},
	{"WINEMAKING", 10, 97646},
	{"DIATOMS", 7, 97647},
	{"BLUNTS", 6, 97648},
	{"UXIN", 4, 97649},
	{"HKEV", 4, 97650},
	{"BBAC", 4, 97651},
	{"INTERNE", 7, 97652},
	{"DCPS", 4, 97653},
	{"FINASTERIDE", 11, 97654},
	{"BILLIONAIRES", 12, 97655},
	{"TYME", 4, 97656},
	{"RANTINGS", 8, 97657},
	{"ANGELINE", 8, 97658},
	{"SVENSSON", 8, 97659},
	{"DAWNING", 7, 97660},
	{"ASPX", 4, 97661},
	{"CAPACITIVE", 10, 97662},
	{"NATUROPATHY", 11, 97663},
	{"TRANY", 5, 97664},
	{"THEOCRACY", 9, 97665},
	{"ANDNOT", 6, 97666},
	{"INTELSAT", 8, 97667},
	{"CAPLETS", 7, 97668},
	{"QUINT", 5, 97669},
	{"CHEESEBURGER", 12, 97670},
	{"IRAK", 4, 97671},
	{"TARYN", 5, 97672},
	{"WINGERS", 7, 97673},
	{"MSBI", 4, 97674},
	{"MBEK", 4, 97675},
	{"LSKN", 4, 97676},
	{"FSYR", 4, 97677},
	{"EOCR", 4, 97678},
	{"POGUE", 5, 97679},
	{"MIDDLEMAN", 9, 97680},
	{"DERAILLEUR", 10, 97681},
	{"GIULIA", 6, 97682},
	{"KLANG", 5, 97683},
	{"CONGRATULATING", 14, 97684},
	{"SEMPRE", 6, 97685},
	{"DORKING", 7, 97686},
	{"FLAGRANT", 8, 97687},
	{"WDAR", 4, 97688},
	{"UYSP", 4, 97689},
	{"SDUG", 4, 97690},
	{"RKMU", 4, 97691},
	{"REGB", 4, 97692},
	{"NMYG", 4, 97693},
	{"LSFU", 4, 97694},
	{"DOAP", 4, 97695},
	{"CAWO", 4, 97696},
	{"TOUAREG", 7, 97697},
	{"MNRAS", 5, 97698},
	{"WESTFORD", 8, 97699},
	{"YUKOS", 5, 97700},
	{"TRACHEA", 7, 97701},
	{"SANDOWN", 7, 97702},
	{"PUIG", 4, 97703},
	{"LOINS", 5, 97704},
	{"UNEVENTFUL", 10, 97705},
	{"OBYN", 4, 97706},
	{"MOSW", 4, 97707},
	{"LKUP", 4, 97708},
	{"KMCC", 4, 97709},
	{"IMCU", 4, 97710},
	{"DORJ", 4, 97711},
	{"PIKACHU", 7, 97712},
	{"QUIS", 4, 97713},
	{"MENDON", 6, 97714},
	{"SCOUNDRELS", 10, 97715},
	{"JMU", 3, 97716},
	{"NUMBING", 7, 97717},
	{"DISTRAUGHT", 10, 97718},
	{"FORSCHUNG", 9, 97719},
	{"ASSASSINATE", 11, 97720},
	{"MOLDAVIA", 8, 97721},
	{"XYOU", 4, 97722},
	{"VMAR", 4, 97723},
	{"TOCM", 4, 97724},
	{"RYEC", 4, 97725},
	{"RKYE", 4, 97726},
	{"GYMO", 4, 97727},
	{"CYDO", 4, 97728},
	{"MOMA", 4, 97729},
	{"KXY", 3, 97730},
	{"FYX", 3, 97731},
	{"FPZ", 3, 97732},
	{"PIGUET", 6, 97733},
	{"MIDGE", 5, 97734},
	{"UNWAVERING", 10, 97735},
	{"SUBMITTALS", 10, 97736},
	{"GWLAD", 5, 97737},
	{"ASTRONAUTICS", 12, 97738},
	{"CONFIDENTIALLY", 14, 97739},
	{"PIECEMEAL", 9, 97740},
	{"COLLET", 6, 97741},
	{"ANHEUSER", 8, 97742},
	{"PITSTOP", 7, 97743},
	{"GLIAL", 5, 97744},
	{"SOLL", 4, 97745},
	{"VANK", 4, 97746},
	{"EUPN", 4, 97747},
	{"PUCKETT", 7, 97748},
	{"BIAGIOTTI", 9, 97749},
	{"BILIRUBIN", 9, 97750},
	{"FLIRTY", 6, 97751},
	{"MCGHEE", 6, 97752},
	{"HAPLOTYPE", 9, 97753},
	{"SONDRA", 6, 97754},
	{"FENNER", 6, 97755},
	{"MCCOOK", 6, 97756},
	{"CODIFICATION", 12, 97757},
	{"MAGICFILTER", 11, 97758},
	{"MCAB", 4, 97759},
	{"FFAW", 4, 97760},
	{"BAUC", 4, 97761},
	{"AIGU", 4, 97762},
	{"PROGRESSIONS", 12, 97763},
	{"INFERIORITY", 11, 97764},
	{"BELTRAN", 7, 97765},
	{"BURNISHED", 9, 97766},
	{"ACIDOSIS", 8, 97767},
	{"MAGICKAL", 8, 97768},
	{"NIPL", 4, 97769},
	{"LRYT", 4, 97770},
	{"REGALO", 6, 97771},
	{"LFP", 3, 97772},
	{"YASHA", 5, 97773},
	{"OSMOTIC", 7, 97774},
	{"REPOSITIONING", 13, 97775},
	{"EGGERS", 6, 97776},
	{"KNITTER", 7, 97777},
	{"CLOTHE", 6, 97778},
	{"DATEWISE", 8, 97779},
	{"ONDK", 4, 97780},
	{"MUPP", 4, 97781},
	{"ISKU", 4, 97782},
	{"BICL", 4, 97783},
	{"AGEQ", 4, 97784},
	{"SWELLED", 7, 97785},
	{"BELTING", 7, 97786},
	{"SNIPES", 6, 97787},
	{"VIDES", 5, 97788},
	{"TRANSLITERATION", 15, 97789},
	{"PGAC", 4, 97790},
	{"BUYP", 4, 97791},
	{"EASTGATE", 8, 97792},
	{"BREDA", 5, 97793},
	{"GENTLENESS", 10, 97794},
	{"EMITTERS", 8, 97795},
	{"STAKED", 6, 97796},
	{"DATACOM", 7, 97797},
	{"TILLAMOOK", 9, 97798},
	{"SANDWICHED", 10, 97799},
	{"RIGIDLY", 7, 97800},
	{"OYEZ", 4, 97801},
	{"SIMILE", 6, 97802},
	{"VIDIOS", 6, 97803},
	{"PHALANX", 7, 97804},
	{"HINDERING", 9, 97805},
	{"YWEM", 4, 97806},
	{"RFAB", 4, 97807},
	{"OAMP", 4, 97808},
	{"LKPR", 4, 97809},
	{"ILOL", 4, 97810},
	{"FWOL", 4, 97811},
	{"SLOPED", 6, 97812},
	{"CHECKMARK", 9, 97813},
	{"DASHBOARDS", 10, 97814},
	{"BZD", 3, 97815},
	{"CHRON", 5, 97816},
	{"ROUNDHOUSE", 10, 97817},
	{"UMGR", 4, 97818},
	{"ENCAPSULATES", 12, 97819},
	{"MELBA", 5, 97820},
	{"HASTERT", 7, 97821},
	{"PASCAGOULA", 10, 97822},
	{"BALLER", 6, 97823},
	{"DIMAS", 5, 97824},
	{"SOLTEK", 6, 97825},
	{"KINSTON", 7, 97826},
	{"SIFTING", 7, 97827},
	{"TEKST", 5, 97828},
	{"SATALITE", 8, 97829},
	{"FIXE", 4, 97830},
	{"GLUCAGON", 8, 97831},
	{"NICOLAI", 7, 97832},
	{"WEBWEAVER", 9, 97833},
	{"MILOS", 5, 97834},
	{"ISOBEL", 6, 97835},
	{"LPTE", 4, 97836},
	{"ICGI", 4, 97837},
	{"RIVAS", 5, 97838},
	{"UNTUK", 5, 97839},
	{"AMBIVALENCE", 11, 97840},
	{"PERRICONE", 9, 97841},
	{"LOUDNESS", 8, 97842},
	{"ERAILL", 6, 97843},
	{"GUILLOTINE", 10, 97844},
	{"FOTW", 4, 97845},
	{"OPEU", 4, 97846},
	{"GORU", 4, 97847},
	{"FIRR", 4, 97848},
	{"INTERTIDAL", 10, 97849},
	{"CHARTERING", 10, 97850},
	{"BREAM", 5, 97851},
	{"BLINDWRITE", 10, 97852},
	{"REVERTING", 9, 97853},
	{"DIONYSUS", 8, 97854},
	{"MEANDER", 7, 97855},
	{"LEANINGS", 8, 97856},
	{"GROANS", 6, 97857},
	{"HERBST", 6, 97858},
	{"VASW", 4, 97859},
	{"UYMO", 4, 97860},
	{"SBEM", 4, 97861},
	{"RGOM", 4, 97862},
	{"OFRY", 4, 97863},
	{"KSOW", 4, 97864},
	{"IDVO", 4, 97865},
	{"DDSI", 4, 97866},
	{"CUEE", 4, 97867},
	{"AMOG", 4, 97868},
	{"CANKER", 6, 97869},
	{"POOF", 4, 97870},
	{"PERKIN", 6, 97871},
	{"KEENER", 6, 97872},
	{"MONOFONICHE", 11, 97873},
	{"MEANINGFULLY", 12, 97874},
	{"AUDIOS", 6, 97875},
	{"EMBELLISHMENT", 13, 97876},
	{"WJOH", 4, 97877},
	{"KKAN", 4, 97878},
	{"IVOC", 4, 97879},
	{"HENTIA", 6, 97880},
	{"TURION", 6, 97881},
	{"TIENDA", 6, 97882},
	{"KNOWLEDGABLE", 12, 97883},
	{"CONFESSES", 9, 97884},
	{"GULLIBLE", 8, 97885},
	{"SUNCOAST", 8, 97886},
	{"BIOGENESIS", 10, 97887},
	{"BOBA", 4, 97888},
	{"MICHA", 5, 97889},
	{"UMSD", 4, 97890},
	{"PSOP", 4, 97891},
	{"NKAY", 4, 97892},
	{"LANJ", 4, 97893},
	{"MISTRESSES", 10, 97894},
	{"BREAKWATER", 10, 97895},
	{"SMUGGLER", 8, 97896},
	{"BELLUCCI", 8, 97897},
	{"BUSILY", 6, 97898},
	{"PAINKILLERS", 11, 97899},
	{"NOMURA", 6, 97900},
	{"SYNOVIAL", 8, 97901},
	{"INAUGURALS", 10, 97902},
	{"ALEKSANDR", 9, 97903},
	{"LCDTELEVISION", 13, 97904},
	{"NYEC", 4, 97905},
	{"FSHU", 4, 97906},
	{"LAMBTON", 7, 97907},
	{"POACHED", 7, 97908},
	{"ARAM", 4, 97909},
	{"SHOPKEEPER", 10, 97910},
	{"UNCIRCULATED", 12, 97911},
	{"HAILING", 7, 97912},
	{"NICU", 4, 97913},
	{"FAGO", 4, 97914},
	{"WSSP", 4, 97915},
	{"MSCU", 4, 97916},
	{"AYIR", 4, 97917},
	{"NADPH", 5, 97918},
	{"IMPARTED", 8, 97919},
	{"PFEIFER", 7, 97920},
	{"PROGRAMISTA", 11, 97921},
	{"SLUMPED", 7, 97922},
	{"TRADUCTION", 10, 97923},
	{"GLUING", 6, 97924},
	{"CHICOPEE", 8, 97925},
	{"RIJA", 4, 97926},
	{"RIDH", 4, 97927},
	{"CONTRADICTING", 13, 97928},
	{"HEADLONG", 8, 97929},
	{"CAPTOR", 6, 97930},
	{"FADS", 4, 97931},
	{"DHANBAD", 7, 97932},
	{"INDELIBLE", 9, 97933},
	{"IMAGO", 5, 97934},
	{"ALKALINITY", 10, 97935},
	{"HEFNER", 6, 97936},
	{"TETHERED", 8, 97937},
	{"ORCAS", 5, 97938},
	{"WHITENESS", 9, 97939},
	{"ROLLERBALL", 10, 97940},
	{"YELLOWKNIFE", 11, 97941},
	{"RRAJ", 4, 97942},
	{"FENR", 4, 97943},
	{"GRAZED", 6, 97944},
	{"IMMUNOHISTOCHEMICAL", 19, 97945},
	{"JOULES", 6, 97946},
	{"DERFLER", 7, 97947},
	{"MESMERIZING", 11, 97948},
	{"GOOCH", 5, 97949},
	{"JAKES", 5, 97950},
	{"THRIVED", 7, 97951},
	{"TBYV", 4, 97952},
	{"SBNP", 4, 97953},
	{"ODDC", 4, 97954},
	{"BAWH", 4, 97955},
	{"COLIBRI", 7, 97956},
	{"AIRTOURS", 8, 97957},
	{"UNFULFILLED", 11, 97958},
	{"ACQUITTAL", 9, 97959},
	{"PERVERTS", 8, 97960},
	{"INTENTIONED", 11, 97961},
	{"MAXLIM", 6, 97962},
	{"MEILLEUR", 8, 97963},
	{"GLENDORA", 8, 97964},
	{"FLUENTLY", 8, 97965},
	{"PIGTAILED", 9, 97966},
	{"FAZER", 5, 97967},
	{"GIROUX", 6, 97968},
	{"YBUF", 4, 97969},
	{"UTYH", 4, 97970},
	{"UMTI", 4, 97971},
	{"PUGE", 4, 97972},
	{"NUPL", 4, 97973},
	{"LIEBERT", 7, 97974},
	{"NYLUG", 5, 97975},
	{"ASCRIBE", 7, 97976},
	{"MURCHISON", 9, 97977},
	{"SARABAND", 8, 97978},
	{"STALKED", 7, 97979},
	{"HYLTON", 6, 97980},
	{"YRUM", 4, 97981},
	{"UOTG", 4, 97982},
	{"TCYA", 4, 97983},
	{"SKQU", 4, 97984},
	{"SJAK", 4, 97985},
	{"FPUE", 4, 97986},
	{"ERKW", 4, 97987},
	{"CRUP", 4, 97988},
	{"BPOR", 4, 97989},
	{"DELUDED", 7, 97990},
	{"LISBURN", 7, 97991},
	{"EMULEX", 6, 97992},
	{"OUTSTRETCHED", 12, 97993},
	{"TREMBLED", 8, 97994},
	{"NITRILE", 7, 97995},
	{"KYU", 3, 97996},
	{"DENMAN", 6, 97997},
	{"OPED", 4, 97998},
	{"NMEY", 4, 97999},
	{"LZER", 4, 98000},
	{"KRUL", 4, 98001},
	{"DHAZ", 4, 98002},
	{"BLAR", 4, 98003},
	{"AJAL", 4, 98004},
	{"ABKH", 4, 98005},
	{"SMYTHE", 6, 98006},
	{"SAMP", 4, 98007},
	{"PRV", 3, 98008},
	{"JANITORS", 8, 98009},
	{"UNOBSERVED", 10, 98010},
	{"MICROMETER", 10, 98011},
	{"LABORED", 7, 98012},
	{"PFEA", 4, 98013},
	{"IXAL", 4, 98014},
	{"SEPERATELY", 10, 98015},
	{"GAMESTOP", 8, 98016},
	{"RONSTADT", 8, 98017},
	{"INTERFAX", 8, 98018},
	{"TWITCHING", 9, 98019},
	{"SMACKS", 6, 98020},
	{"SILBER", 6, 98021},
	{"TROUGHS", 7, 98022},
	{"ANAGRAMS", 8, 98023},
	{"JONSSON", 7, 98024},
	{"IEBY", 4, 98025},
	{"STRIKEOUTS", 10, 98026},
	{"PALME", 5, 98027},
	{"UNBELIEVERS", 11, 98028},
	{"TAFF", 4, 98029},
	{"POLARIZER", 9, 98030},
	{"GDC", 3, 98031},
	{"NEWBERY", 7, 98032},
	{"HUNGERFORD", 10, 98033},
	{"WEIGEL", 6, 98034},
	{"EXEGESIS", 8, 98035},
	{"CRANFORD", 8, 98036},
	{"WSJU", 4, 98037},
	{"ISUK", 4, 98038},
	{"ELNU", 4, 98039},
	{"DIAK", 4, 98040},
	{"PISCINE", 7, 98041},
	{"QUEENSRYCHE", 11, 98042},
	{"SENTED", 6, 98043},
	{"BETAS", 5, 98044},
	{"SCITUATE", 8, 98045},
	{"CBB", 3, 98046},
	{"SEITENANFANG", 12, 98047},
	{"DIRNAME", 7, 98048},
	{"BROTHELS", 8, 98049},
	{"INTRAOCULAR", 11, 98050},
	{"SKILFUL", 7, 98051},
	{"XOFA", 4, 98052},
	{"WSQU", 4, 98053},
	{"PRIU", 4, 98054},
	{"PRAV", 4, 98055},
	{"MBAK", 4, 98056},
	{"LYOK", 4, 98057},
	{"DANX", 4, 98058},
	{"LEDUC", 5, 98059},
	{"ACDC", 4, 98060},
	{"SPROCKETS", 9, 98061},
	{"WERK", 4, 98062},
	{"BASTA", 5, 98063},
	{"THELONIOUS", 10, 98064},
	{"ASSISTANTSHIPS", 14, 98065},
	{"FUTURIST", 8, 98066},
	{"BIOFUEL", 7, 98067},
	{"MUHLENBERG", 10, 98068},
	{"INVOCATIONS", 11, 98069},
	{"VALEO", 5, 98070},
	{"COLUSA", 6, 98071},
	{"IOCL", 4, 98072},
	{"CUEC", 4, 98073},
	{"BOLDER", 6, 98074},
	{"VIPS", 4, 98075},
	{"OPENCMS", 7, 98076},
	{"PALTALK", 7, 98077},
	{"WEBKIT", 6, 98078},
	{"ROCCA", 5, 98079},
	{"OMITS", 5, 98080},
	{"ENDURES", 7, 98081},
	{"VELASQUEZ", 9, 98082},
	{"HEEFT", 5, 98083},
	{"ALAMOGORDO", 10, 98084},
	{"HARMONISED", 10, 98085},
	{"SILENCIO", 8, 98086},
	{"ROWLANDS", 8, 98087},
	{"MGOE", 4, 98088},
	{"EKMI", 4, 98089},
	{"LASKI", 5, 98090},
	{"CYTODYNE", 8, 98091},
	{"XYLENE", 6, 98092},
	{"SELLE", 5, 98093},
	{"PUEDEN", 6, 98094},
	{"ANTICIPATORY", 12, 98095},
	{"RIORDAN", 7, 98096},
	{"RATCLIFFE", 9, 98097},
	{"SEABOURN", 8, 98098},
	{"ZELD", 4, 98099},
	{"MSHU", 4, 98100},
	{"KIMC", 4, 98101},
	{"CFLI", 4, 98102},
	{"ASIATICAS", 9, 98103},
	{"STOURBRIDGE", 11, 98104},
	{"IMPERSONATION", 13, 98105},
	{"COMMER", 6, 98106},
	{"SWEETY", 6, 98107},
	{"LYCOPENE", 8, 98108},
	{"MAPPA", 5, 98109},
	{"PLATTEVILLE", 11, 98110},
	{"ASSIGNABLE", 10, 98111},
	{"INTERFACIAL", 11, 98112},
	{"ZEBRAFISH", 9, 98113},
	{"CTYPE", 5, 98114},
	{"IDSK", 4, 98115},
	{"ERZH", 4, 98116},
	{"EFAP", 4, 98117},
	{"BOBG", 4, 98118},
	{"GIRDER", 6, 98119},
	{"FRANKSTON", 9, 98120},
	{"JULLIARD", 8, 98121},
	{"RENORMALIZATION", 15, 98122},
	{"EWELL", 5, 98123},
	{"RESEARCHINDEX", 13, 98124},
	{"INTERNATION", 11, 98125},
	{"GRAPHIX", 7, 98126},
	{"DECENTRALISED", 13, 98127},
	{"BISMUTH", 7, 98128},
	{"LAVINIA", 7, 98129},
	{"LIFH", 4, 98130},
	{"EPHD", 4, 98131},
	{"NATIVELY", 8, 98132},
	{"MOLLER", 6, 98133},
	{"INTENTS", 7, 98134},
	{"UNCONNECTED", 11, 98135},
	{"KEHOE", 5, 98136},
	{"MRD", 3, 98137},
	{"YNCR", 4, 98138},
	{"OGDA", 4, 98139},
	{"NGMP", 4, 98140},
	{"MUNL", 4, 98141},
	{"OVUM", 4, 98142},
	{"BACKGROUNDER", 12, 98143},
	{"PRUNED", 6, 98144},
	{"RUSTON", 6, 98145},
	{"LANTANA", 7, 98146},
	{"TCHJ", 4, 98147},
	{"AYSQ", 4, 98148},
	{"ARUK", 4, 98149},
	{"MAHWAH", 6, 98150},
	{"WEDDED", 6, 98151},
	{"SEASONALITY", 11, 98152},
	{"TECHEXCEL", 9, 98153},
	{"SUBLEASE", 8, 98154},
	{"LASHED", 6, 98155},
	{"XTTP", 4, 98156},
	{"IDENTI", 6, 98157},
	{"GAIDEN", 6, 98158},
	{"SHRIVER", 7, 98159},
	{"PENNA", 5, 98160},
	{"STANDARDIZING", 13, 98161},
	{"SMAL", 4, 98162},
	{"WAYK", 4, 98163},
	{"WATF", 4, 98164},
	{"UZAK", 4, 98165},
	{"RLSG", 4, 98166},
	{"COGI", 4, 98167},
	{"RETELLING", 9, 98168},
	{"SFGATE", 6, 98169},
	{"SANDBERG", 8, 98170},
	{"VALLADOLID", 10, 98171},
	{"CONTENTIONS", 11, 98172},
	{"CORTO", 5, 98173},
	{"BICKERING", 9, 98174},
	{"WHALER", 6, 98175},
	{"WTEM", 4, 98176},
	{"SIPR", 4, 98177},
	{"UNOBSTRUCTED", 12, 98178},
	{"HYDROGENATED", 12, 98179},
	{"MENSCHEN", 8, 98180},
	{"KARWAR", 6, 98181},
	{"FONDLING", 8, 98182},
	{"GLD", 3, 98183},
	{"WFY", 3, 98184},
	{"FXK", 3, 98185},
	{"BGJ", 3, 98186},
	{"CREF", 4, 98187},
	{"LAISSEZ", 7, 98188},
	{"RICKS", 5, 98189},
	{"HEALD", 5, 98190},
	{"HAVIN", 5, 98191},
	{"ZABO", 4, 98192},
	{"MEIV", 4, 98193},
	{"GNBY", 4, 98194},
	{"AWSR", 4, 98195},
	{"SPENSER", 7, 98196},
	{"ASTOUNDED", 9, 98197},
	{"KIRCHNER", 8, 98198},
	{"PERMANENCY", 10, 98199},
	{"SMACKED", 7, 98200},
	{"TRUSSES", 7, 98201},
	{"PERSONEN", 8, 98202},
	{"PALLAS", 6, 98203},
	{"ANATOLE", 7, 98204},
	{"SLEET", 5, 98205},
	{"ADSG", 4, 98206},
	{"DISGRACED", 9, 98207},
	{"PHILIPPA", 8, 98208},
	{"ZOSTER", 6, 98209},
	{"ROYAUME", 7, 98210},
	{"KEELEY", 6, 98211},
	{"SURVIVABILITY", 13, 98212},
	{"YRAB", 4, 98213},
	{"NYJA", 4, 98214},
	{"MPAP", 4, 98215},
	{"LLIZ", 4, 98216},
	{"AWWE", 4, 98217},
	{"JALGAON", 7, 98218},
	{"AICHI", 5, 98219},
	{"GROOVED", 7, 98220},
	{"TRANSCONTINENTAL", 16, 98221},
	{"TEIXEIRA", 8, 98222},
	{"RSMY", 4, 98223},
	{"KWHY", 4, 98224},
	{"IFRI", 4, 98225},
	{"CIOP", 4, 98226},
	{"BISW", 4, 98227},
	{"PLAYAS", 6, 98228},
	{"RESIGNING", 9, 98229},
	{"AVIVA", 5, 98230},
	{"CAGLE", 5, 98231},
	{"INSTORE", 7, 98232},
	{"YKEV", 4, 98233},
	{"SGAZ", 4, 98234},
	{"LVEG", 4, 98235},
	{"LAXATIVE", 8, 98236},
	{"SMALLWOOD", 9, 98237},
	{"APPAREIL", 8, 98238},
	{"INTITLE", 7, 98239},
	{"ALCOVE", 6, 98240},
	{"WOOLSEY", 7, 98241},
	{"WALE", 4, 98242},
	{"VYFI", 4, 98243},
	{"SUTR", 4, 98244},
	{"MPLU", 4, 98245},
	{"MBSU", 4, 98246},
	{"KANK", 4, 98247},
	{"IFEY", 4, 98248},
	{"IEMP", 4, 98249},
	{"GYME", 4, 98250},
	{"TERMINE", 7, 98251},
	{"TRIPPLE", 7, 98252},
	{"EURONEXT", 8, 98253},
	{"UNGODLY", 7, 98254},
	{"ENLARGEMENTS", 12, 98255},
	{"FELLING", 7, 98256},
	{"SPIZ", 4, 98257},
	{"RNYA", 4, 98258},
	{"GOVJ", 4, 98259},
	{"FTDO", 4, 98260},
	{"EKBA", 4, 98261},
	{"ATGM", 4, 98262},
	{"MARINADES", 9, 98263},
	{"JDOM", 4, 98264},
	{"FUNHOUSE", 8, 98265},
	{"PARISC", 6, 98266},
	{"FISIO", 5, 98267},
	{"ARIANE", 6, 98268},
	{"WINEMAKER", 9, 98269},
	{"PCLINUXOS", 9, 98270},
	{"LUZERNE", 7, 98271},
	{"XBOR", 4, 98272},
	{"RYTY", 4, 98273},
	{"OPJO", 4, 98274},
	{"MPPL", 4, 98275},
	{"EGCO", 4, 98276},
	{"CBOA", 4, 98277},
	{"AARG", 4, 98278},
	{"ZOLTAN", 6, 98279},
	{"GRENDEL", 7, 98280},
	{"RATTLERS", 8, 98281},
	{"LANDES", 6, 98282},
	{"HAZING", 6, 98283},
	{"CARBONYL", 8, 98284},
	{"SORIANO", 7, 98285},
	{"XBEC", 4, 98286},
	{"HNBU", 4, 98287},
	{"APIX", 4, 98288},
	{"CHELATION", 9, 98289},
	{"TELECAST", 8, 98290},
	{"BERMUDIAN", 9, 98291},
	{"VILLARREAL", 10, 98292},
	{"RELISYS", 7, 98293},
	{"NEWTEK", 6, 98294},
	{"KEEPALIVE", 9, 98295},
	{"DISCLAIMED", 10, 98296},
	{"DAHYABHAI", 9, 98297},
	{"AUCUN", 5, 98298},
	{"FITC", 4, 98299},
	{"UPP", 3, 98300},
	{"IEXPLORE", 8, 98301},
	{"SPECTACULARLY", 13, 98302},
	{"XTUP", 4, 98303},
	{"WOCC", 4, 98304},
	{"RCIE", 4, 98305},
	{"EEDJ", 4, 98306},
	{"BINR", 4, 98307},
	{"ABOF", 4, 98308},
	{"ELYRIA", 6, 98309},
	{"APPARTEMENT", 11, 98310},
	{"FRIENDEMAIL", 11, 98311},
	{"POSTALES", 8, 98312},
	{"PERROS", 6, 98313},
	{"HOARE", 5, 98314},
	{"COULEUR", 7, 98315},
	{"BROWNLEE", 8, 98316},
	{"MONTAGU", 7, 98317},
	{"RTGU", 4, 98318},
	{"GORK", 4, 98319},
	{"MINDEDNESS", 10, 98320},
	{"CARMELO", 7, 98321},
	{"LADAKH", 6, 98322},
	{"NOVUS", 5, 98323},
	{"CLEANROOM", 9, 98324},
	{"YILO", 4, 98325},
	{"LABT", 4, 98326},
	{"BATL", 4, 98327},
	{"DISCRETIZATION", 14, 98328},
	{"CAMACHO", 7, 98329},
	{"HYDROLASES", 10, 98330},
	{"STEAMSHIP", 9, 98331},
	{"ZABAWEB", 7, 98332},
	{"DAVIESS", 7, 98333},
	{"PBK", 3, 98334},
	{"CONDESCENDING", 13, 98335},
	{"TIDR", 4, 98336},
	{"OLFM", 4, 98337},
	{"FSRI", 4, 98338},
	{"RECOUNTING", 10, 98339},
	{"BREECHES", 8, 98340},
	{"PROMAX", 6, 98341},
	{"REDUNDANCIES", 12, 98342},
	{"SEASHELL", 8, 98343},
	{"PACIFIST", 8, 98344},
	{"REDKEN", 6, 98345},
	{"PERCE", 5, 98346},
	{"APPELLATION", 11, 98347},
	{"RIXT", 4, 98348},
	{"KWEV", 4, 98349},
	{"EKIF", 4, 98350},
	{"MITGLIED", 8, 98351},
	{"TRADUZIDAS", 10, 98352},
	{"BRASSICA", 8, 98353},
	{"MWK", 3, 98354},
	{"DORI", 4, 98355},
	{"NETOPIA", 7, 98356},
	{"DRIPS", 5, 98357},
	{"YIRI", 4, 98358},
	{"OLCR", 4, 98359},
	{"MUPO", 4, 98360},
	{"MPMO", 4, 98361},
	{"EGGP", 4, 98362},
	{"DHARWAD", 7, 98363},
	{"FIBRINOGEN", 10, 98364},
	{"CREEKSIDE", 9, 98365},
	{"HAGEL", 5, 98366},
	{"ABBE", 4, 98367},
	{"LUCI", 4, 98368},
	{"SAREE", 5, 98369},
	{"BANANASTOCK", 11, 98370},
	{"MACRUMORS", 9, 98371},
	{"URNV", 4, 98372},
	{"SPNC", 4, 98373},
	{"RVAI", 4, 98374},
	{"NWIF", 4, 98375},
	{"EYUK", 4, 98376},
	{"EFFF", 4, 98377},
	{"DEZW", 4, 98378},
	{"VIAJEROS", 8, 98379},
	{"FOGARTY", 7, 98380},
	{"MONTES", 6, 98381},
	{"EXEMPLE", 7, 98382},
	{"CEPHALEXIN", 10, 98383},
	{"HANDSOMELY", 10, 98384},
	{"SKYWAY", 6, 98385},
	{"POLIS", 5, 98386},
	{"ACHIEVER", 8, 98387},
	{"BOTCHED", 7, 98388},
	{"MULTIRACIAL", 11, 98389},
	{"WMIC", 4, 98390},
	{"NODU", 4, 98391},
	{"KCUT", 4, 98392},
	{"ICIF", 4, 98393},
	{"FWEG", 4, 98394},
	{"STUFFIT", 7, 98395},
	{"POLITBURO", 9, 98396},
	{"GIRLZ", 5, 98397},
	{"RESOURCED", 9, 98398},
	{"IINCLUDE", 8, 98399},
	{"FILLE", 5, 98400},
	{"HOPKINSON", 9, 98401},
	{"FRESHENERS", 10, 98402},
	{"CHISWICK", 8, 98403},
	{"NETAYA", 6, 98404},
	{"CORTICOSTEROID", 14, 98405},
	{"SOAPY", 5, 98406},
	{"SAVIN", 5, 98407},
	{"GOODSHOOT", 9, 98408},
	{"REVISIONIST", 11, 98409},
	{"THROUGHT", 8, 98410},
	{"PARRIS", 6, 98411},
	{"SEGOVIA", 7, 98412},
	{"RRBI", 4, 98413},
	{"NREY", 4, 98414},
	{"MULG", 4, 98415},
	{"ILVO", 4, 98416},
	{"BISF", 4, 98417},
	{"UNTENABLE", 9, 98418},
	{"PINOUTS", 7, 98419},
	{"WARFIGHTER", 10, 98420},
	{"MICROBE", 7, 98421},
	{"PLED", 4, 98422},
	{"MESSER", 6, 98423},
	{"TOTALMENTE", 10, 98424},
	{"LONGO", 5, 98425},
	{"SERIALIZE", 9, 98426},
	{"COLDFIELD", 9, 98427},
	{"VIEV", 4, 98428},
	{"UOTR", 4, 98429},
	{"UMHI", 4, 98430},
	{"SRHY", 4, 98431},
	{"NKUP", 4, 98432},
	{"AZZE", 4, 98433},
	{"DEFORMITIES", 11, 98434},
	{"KEYSER", 6, 98435},
	{"WEATHERVANES", 12, 98436},
	{"NECKTIE", 7, 98437},
	{"CUNG", 4, 98438},
	{"XXVII", 5, 98439},
	{"GRUELING", 8, 98440},
	{"MEMORIZING", 10, 98441},
	{"CORUM", 5, 98442},
	{"ZENTRUM", 7, 98443},
	{"STRCAT", 6, 98444},
	{"YUNB", 4, 98445},
	{"URUP", 4, 98446},
	{"TMCK", 4, 98447},
	{"OCOF", 4, 98448},
	{"JOYH", 4, 98449},
	{"ILKW", 4, 98450},
	{"EGFO", 4, 98451},
	{"DOWNWIND", 8, 98452},
	{"LIBELOUS", 8, 98453},
	{"PAMPOROVO", 9, 98454},
	{"EVERCLEAR", 9, 98455},
	{"DEPOSITORS", 10, 98456},
	{"INCR", 4, 98457},
	{"PANY", 4, 98458},
	{"BAHR", 4, 98459},
	{"YSUL", 4, 98460},
	{"YJUR", 4, 98461},
	{"WNJO", 4, 98462},
	{"PAFL", 4, 98463},
	{"LUSL", 4, 98464},
	{"HYSU", 4, 98465},
	{"GBIO", 4, 98466},
	{"DESNUDA", 7, 98467},
	{"PHPMYVISITES", 12, 98468},
	{"TARDY", 5, 98469},
	{"TORREMOLINOS", 12, 98470},
	{"DISREGARDING", 12, 98471},
	{"HOHNER", 6, 98472},
	{"MATRON", 6, 98473},
	{"SEAWARD", 7, 98474},
	{"UPPERMOST", 9, 98475},
	{"CRUNK", 5, 98476},
	{"THOMASTON", 9, 98477},
	{"GAMEARENA", 9, 98478},
	{"WAZI", 4, 98479},
	{"OKAJ", 4, 98480},
	{"GUPL", 4, 98481},
	{"ADOLPHUS", 8, 98482},
	{"SOLARA", 6, 98483},
	{"CIPHERS", 7, 98484},
	{"REBOUNDED", 9, 98485},
	{"CORRADO", 7, 98486},
	{"NIBBLE", 6, 98487},
	{"STRATICS", 8, 98488},
	{"HERMETIC", 8, 98489},
	{"TINSLEY", 7, 98490},
	{"VACACIONES", 10, 98491},
	{"YDIP", 4, 98492},
	{"TOFZ", 4, 98493},
	{"TKAL", 4, 98494},
	{"TBUM", 4, 98495},
	{"RLIQ", 4, 98496},
	{"OGGA", 4, 98497},
	{"CORW", 4, 98498},
	{"BERGMANN", 8, 98499},
	{"ALLTHEWEB", 9, 98500},
	{"NAVARRA", 7, 98501},
	{"ALBUTEROL", 9, 98502},
	{"KARABAKH", 8, 98503},
	{"CANADENSIS", 10, 98504},
	{"RZAC", 4, 98505},
	{"LYTY", 4, 98506},
	{"EURM", 4, 98507},
	{"EMVE", 4, 98508},
	{"DLUX", 4, 98509},
	{"MARAUDER", 8, 98510},
	{"RENEGADES", 9, 98511},
	{"FOGG", 4, 98512},
	{"THEOR", 5, 98513},
	{"POWERPLAY", 9, 98514},
	{"SHOWINGS", 8, 98515},
	{"KCAU", 4, 98516},
	{"EYAK", 4, 98517},
	{"EIDW", 4, 98518},
	{"VOLVER", 6, 98519},
	{"CARDAMOM", 8, 98520},
	{"YNEM", 4, 98521},
	{"RYSV", 4, 98522},
	{"MFOC", 4, 98523},
	{"LUON", 4, 98524},
	{"KIFO", 4, 98525},
	{"FBLI", 4, 98526},
	{"COSU", 4, 98527},
	{"SHING", 5, 98528},
	{"WEBRSS", 6, 98529},
	{"UNTOUCHABLE", 11, 98530},
	{"EXERTING", 8, 98531},
	{"SWISSOTEL", 9, 98532},
	{"SITEMAPS", 8, 98533},
	{"NATALE", 6, 98534},
	{"MULTICOLORED", 12, 98535},
	{"UTILISATEURS", 12, 98536},
	{"FLEECES", 7, 98537},
	{"BIRDLIFE", 8, 98538},
	{"PECKER", 6, 98539},
	{"INDUSTRIOUS", 11, 98540},
	{"TAVARES", 7, 98541},
	{"TEMPORALLY", 10, 98542},
	{"ZEPR", 4, 98543},
	{"YPTT", 4, 98544},
	{"TUSG", 4, 98545},
	{"RPSC", 4, 98546},
	{"RKRU", 4, 98547},
	{"MISJ", 4, 98548},
	{"MBLU", 4, 98549},
	{"DRSA", 4, 98550},
	{"REAPPOINTMENT", 13, 98551},
	{"ONSOURCE", 8, 98552},
	{"ATTRACTIVELY", 12, 98553},
	{"SYMONDS", 7, 98554},
	{"TAZEWELL", 8, 98555},
	{"CANUCK", 6, 98556},
	{"MALDIVE", 7, 98557},
	{"ADOPTER", 7, 98558},
	{"NICOTINIC", 9, 98559},
	{"ZEFI", 4, 98560},
	{"PTYA", 4, 98561},
	{"NOZZ", 4, 98562},
	{"IKID", 4, 98563},
	{"CTPU", 4, 98564},
	{"BSFI", 4, 98565},
	{"DECAYED", 7, 98566},
	{"STETHOSCOPES", 12, 98567},
	{"LOMO", 4, 98568},
	{"CRACKZ", 6, 98569},
	{"SHIPYARDS", 9, 98570},
	{"ANGLIAN", 7, 98571},
	{"KERIO", 5, 98572},
	{"FOOTPATHS", 9, 98573},
	{"WHYG", 4, 98574},
	{"HMYT", 4, 98575},
	{"GFOC", 4, 98576},
	{"DVDP", 4, 98577},
	{"KAOHSIUNG", 9, 98578},
	{"TAMARACK", 8, 98579},
	{"SAUTEED", 7, 98580},
	{"PANINI", 6, 98581},
	{"QQQQ", 4, 98582},
	{"DHAMMA", 6, 98583},
	{"BACKFIRE", 8, 98584},
	{"LOCUSLINK", 9, 98585},
	{"VOOD", 4, 98586},
	{"NEYK", 4, 98587},
	{"MIRP", 4, 98588},
	{"MBOI", 4, 98589},
	{"IMDR", 4, 98590},
	{"HWRO", 4, 98591},
	{"CROSSDRESSING", 13, 98592},
	{"NARCISSISM", 10, 98593},
	{"DOMME", 5, 98594},
	{"DISARRAY", 8, 98595},
	{"TRUCKLOAD", 9, 98596},
	{"PROPRIETORSHIP", 14, 98597},
	{"BLAZIN", 6, 98598},
	{"ESSERE", 6, 98599},
	{"CRONTAB", 7, 98600},
	{"ALLGEMEINE", 10, 98601},
	{"VOLP", 4, 98602},
	{"SHGU", 4, 98603},
	{"FEUN", 4, 98604},
	{"CHSD", 4, 98605},
	{"SHULTZ", 6, 98606},
	{"UMSONST", 7, 98607},
	{"ODDBALL", 7, 98608},
	{"HARPS", 5, 98609},
	{"HEDGED", 6, 98610},
	{"ANTIHYPERTENSIVE", 16, 98611},
	{"DARUDE", 6, 98612},
	{"PETTIGREW", 9, 98613},
	{"PTSU", 4, 98614},
	{"LIXI", 4, 98615},
	{"IFYP", 4, 98616},
	{"FVEG", 4, 98617},
	{"FIGN", 4, 98618},
	{"VERAPAMIL", 9, 98619},
	{"MOVABLETYPE", 11, 98620},
	{"USAR", 4, 98621},
	{"CLEANEST", 8, 98622},
	{"MINTER", 6, 98623},
	{"STATPOWER", 9, 98624},
	{"SELON", 5, 98625},
	{"MIYAGI", 6, 98626},
	{"YENL", 4, 98627},
	{"SSYC", 4, 98628},
	{"ISBNS", 5, 98629},
	{"TEUTONIC", 8, 98630},
	{"APML", 4, 98631},
	{"TAPETA", 6, 98632},
	{"DUTTA", 5, 98633},
	{"MEDSCAPE", 8, 98634},
	{"VICEROY", 7, 98635},
	{"MOVIEMAIL", 9, 98636},
	{"XDR", 3, 98637},
	{"VPQ", 3, 98638},
	{"MGZ", 3, 98639},
	{"KQR", 3, 98640},
	{"GZF", 3, 98641},
	{"BIGJ", 4, 98642},
	{"CHABOT", 6, 98643},
	{"MAINTENANT", 10, 98644},
	{"INGRAINED", 9, 98645},
	{"CASPAR", 6, 98646},
	{"SLAW", 4, 98647},
	{"COLLATING", 9, 98648},
	{"BASKETVIEW", 10, 98649},
	{"MIROSLAV", 8, 98650},
	{"UIDF", 4, 98651},
	{"GHRU", 4, 98652},
	{"SWORDSMAN", 9, 98653},
	{"RINGSIGNALER", 12, 98654},
	{"PRELOADED", 9, 98655},
	{"MAGNUSON", 8, 98656},
	{"COMMISSARY", 10, 98657},
	{"IPLANET", 7, 98658},
	{"GEOMORPHOLOGY", 13, 98659},
	{"POWTER", 6, 98660},
	{"REPL", 4, 98661},
	{"WBIL", 4, 98662},
	{"RRUM", 4, 98663},
	{"NOFZ", 4, 98664},
	{"MYFU", 4, 98665},
	{"KOMB", 4, 98666},
	{"HFEB", 4, 98667},
	{"CKAU", 4, 98668},
	{"YELLOWS", 7, 98669},
	{"YOYO", 4, 98670},
	{"HABITUALLY", 10, 98671},
	{"PURVIS", 6, 98672},
	{"IMAGELINE", 9, 98673},
	{"NAMAN", 5, 98674},
	{"ASTROPHOTOGRAPHY", 16, 98675},
	{"RLUD", 4, 98676},
	{"RGUL", 4, 98677},
	{"KARC", 4, 98678},
	{"GEYA", 4, 98679},
	{"DUQU", 4, 98680},
	{"ASDY", 4, 98681},
	{"MAXIME", 6, 98682},
	{"KNUTH", 5, 98683},
	{"MAJORITIES", 10, 98684},
	{"ARJUN", 5, 98685},
	{"VOICEOVER", 9, 98686},
	{"JACQUE", 6, 98687},
	{"SRINAGAR", 8, 98688},
	{"HEBEI", 5, 98689},
	{"DIVESTITURE", 11, 98690},
	{"ACCIDENTLY", 10, 98691},
	{"RENDUS", 6, 98692},
	{"ARCHETYPAL", 10, 98693},
	{"OAKBROOK", 8, 98694},
	{"DRILLER", 7, 98695},
	{"MUMMIES", 7, 98696},
	{"CONQUESTS", 9, 98697},
	{"UMRO", 4, 98698},
	{"ODYU", 4, 98699},
	{"KFAL", 4, 98700},
	{"POLICYMAKING", 12, 98701},
	{"BRIMSTONE", 9, 98702},
	{"BALB", 4, 98703},
	{"COPPA", 5, 98704},
	{"PRETEST", 7, 98705},
	{"QUAND", 5, 98706},
	{"LIBICONV", 8, 98707},
	{"EXCERCISE", 9, 98708},
	{"TROWEL", 6, 98709},
	{"MAND", 4, 98710},
	{"YIFW", 4, 98711},
	{"HICU", 4, 98712},
	{"NAVISION", 8, 98713},
	{"FERTILISERS", 11, 98714},
	{"TYNDALL", 7, 98715},
	{"PROFITING", 9, 98716},
	{"CHYNA", 5, 98717},
	{"BESEECH", 7, 98718},
	{"BOULOGNE", 8, 98719},
	{"DEPS", 4, 98720},
	{"WELLE", 5, 98721},
	{"TANTALUM", 8, 98722},
	{"HITCHED", 7, 98723},
	{"EDMONDSON", 9, 98724},
	{"APROX", 5, 98725},
	{"NEWSWIRES", 9, 98726},
	{"YAJA", 4, 98727},
	{"UGAI", 4, 98728},
	{"KMIG", 4, 98729},
	{"KIMW", 4, 98730},
	{"CDRECORD", 8, 98731},
	{"MUCHA", 5, 98732},
	{"KOMODO", 6, 98733},
	{"FLIPSIDE", 8, 98734},
	{"DOOBIE", 6, 98735},
	{"UNKC", 4, 98736},
	{"GKNI", 4, 98737},
	{"FUSF", 4, 98738},
	{"CWAN", 4, 98739},
	{"ABAU", 4, 98740},
	{"CBF", 3, 98741},
	{"MAIR", 4, 98742},
	{"SMELT", 5, 98743},
	{"POTD", 4, 98744},
	{"FATALE", 6, 98745},
	{"TELETUBBIES", 11, 98746},
	{"RENIN", 5, 98747},
	{"NONMETALLIC", 11, 98748},
	{"UNDERSECRETARY", 14, 98749},
	{"XEXE", 4, 98750},
	{"PMWH", 4, 98751},
	{"LHIR", 4, 98752},
	{"MARGERY", 7, 98753},
	{"YEARN", 5, 98754},
	{"MISMO", 5, 98755},
	{"BENZYL", 6, 98756},
	{"NABOKOV", 7, 98757},
	{"CULPRITS", 8, 98758},
	{"STIFFS", 6, 98759},
	{"TRINKETS", 8, 98760},
	{"XYAN", 4, 98761},
	{"ULCI", 4, 98762},
	{"LTMI", 4, 98763},
	{"EERK", 4, 98764},
	{"WHIG", 4, 98765},
	{"ENCHANT", 7, 98766},
	{"AUSTERE", 7, 98767},
	{"BRITA", 5, 98768},
	{"YIWI", 4, 98769},
	{"XHIL", 4, 98770},
	{"LHUS", 4, 98771},
	{"FEEV", 4, 98772},
	{"EARTHS", 6, 98773},
	{"SELBST", 6, 98774},
	{"STOREHOUSE", 10, 98775},
	{"SAECO", 5, 98776},
	{"COWHIDE", 7, 98777},
	{"PLUMAGE", 7, 98778},
	{"ANTECEDENTS", 11, 98779},
	{"PEBL", 4, 98780},
	{"TENORS", 6, 98781},
	{"HARGROVE", 8, 98782},
	{"ONSALE", 6, 98783},
	{"YOGU", 4, 98784},
	{"VYRE", 4, 98785},
	{"ITGU", 4, 98786},
	{"DYSG", 4, 98787},
	{"DIABOLICAL", 10, 98788},
	{"FEINBERG", 8, 98789},
	{"TUGS", 4, 98790},
	{"CULLMAN", 7, 98791},
	{"WHITEMAN", 8, 98792},
	{"RAPIER", 6, 98793},
	{"UNSPOILED", 9, 98794},
	{"ANTIBES", 7, 98795},
	{"DASSAULT", 8, 98796},
	{"EQUALITIES", 10, 98797},
	{"HAUGHTY", 7, 98798},
	{"OVERLYING", 9, 98799},
	{"ZWD", 3, 98800},
	{"WSFE", 4, 98801},
	{"UZER", 4, 98802},
	{"RUSG", 4, 98803},
	{"OMOK", 4, 98804},
	{"OLJU", 4, 98805},
	{"LEXG", 4, 98806},
	{"EFFM", 4, 98807},
	{"AWCE", 4, 98808},
	{"RELINQUISHED", 12, 98809},
	{"NETIQUETTE", 10, 98810},
	{"VODACOM", 7, 98811},
	{"OPIATES", 7, 98812},
	{"SALAMI", 6, 98813},
	{"BEAUTIFULL", 10, 98814},
	{"UPGRADEABLE", 11, 98815},
	{"NARCISSISTIC", 12, 98816},
	{"MULTIDRUG", 9, 98817},
	{"ASSAULTING", 10, 98818},
	{"ADMIRALS", 8, 98819},
	{"OWSJ", 4, 98820},
	{"KITD", 4, 98821},
	{"ILOB", 4, 98822},
	{"BALN", 4, 98823},
	{"MUC", 3, 98824},
	{"MEISJES", 7, 98825},
	{"KILBURN", 7, 98826},
	{"AGARTALA", 8, 98827},
	{"CADAVER", 7, 98828},
	{"ESMERALDA", 9, 98829},
	{"BROKERAGES", 10, 98830},
	{"OFFICINALIS", 11, 98831},
	{"LIBERI", 6, 98832},
	{"CREATIVES", 9, 98833},
	{"MUSICOLOGY", 10, 98834},
	{"POLITICO", 8, 98835},
	{"PAULING", 7, 98836},
	{"CAPTIVATE", 9, 98837},
	{"HLYW", 4, 98838},
	{"EKCH", 4, 98839},
	{"EDNC", 4, 98840},
	{"DRWA", 4, 98841},
	{"ASKQ", 4, 98842},
	{"CASSEL", 6, 98843},
	{"TERUG", 5, 98844},
	{"STREEP", 6, 98845},
	{"KYRA", 4, 98846},
	{"FDF", 3, 98847},
	{"SEMIANNUAL", 10, 98848},
	{"MAPSTATS", 8, 98849},
	{"DETERRED", 8, 98850},
	{"RICKMAN", 7, 98851},
	{"AGOSTINO", 8, 98852},
	{"MELD", 4, 98853},
	{"OPENPKG", 7, 98854},
	{"UINV", 4, 98855},
	{"UDAD", 4, 98856},
	{"UALK", 4, 98857},
	{"GOGR", 4, 98858},
	{"FFSM", 4, 98859},
	{"LOYD", 4, 98860},
	{"APATHETIC", 9, 98861},
	{"POLYFONE", 8, 98862},
	{"KARR", 4, 98863},
	{"UNINTERESTING", 13, 98864},
	{"LYRE", 4, 98865},
	{"RELH", 4, 98866},
	{"NRHY", 4, 98867},
	{"EQUITABLY", 9, 98868},
	{"PIAGET", 6, 98869},
	{"YAWNING", 7, 98870},
	{"HINKLE", 6, 98871},
	{"CENTRALIZATION", 14, 98872},
	{"PAGED", 5, 98873},
	{"PRUNES", 6, 98874},
	{"MANUFAC", 7, 98875},
	{"CLICKAJOB", 9, 98876},
	{"BULLER", 6, 98877},
	{"HYDROPHILIC", 11, 98878},
	{"RAMEY", 5, 98879},
	{"ERUPT", 5, 98880},
	{"REDONE", 6, 98881},
	{"BIENNALE", 8, 98882},
	{"PTAW", 4, 98883},
	{"PDEM", 4, 98884},
	{"ONUL", 4, 98885},
	{"MBYM", 4, 98886},
	{"HBAG", 4, 98887},
	{"MALLOW", 6, 98888},
	{"DURESS", 6, 98889},
	{"BHILAI", 6, 98890},
	{"COSSACKS", 8, 98891},
	{"MRL", 3, 98892},
	{"PROFESIONAL", 11, 98893},
	{"VERGLEICHEN", 11, 98894},
	{"PEDERSON", 8, 98895},
	{"SKAGGS", 6, 98896},
	{"UBBU", 4, 98897},
	{"RAHC", 4, 98898},
	{"NIXW", 4, 98899},
	{"FKAS", 4, 98900},
	{"MARGAO", 6, 98901},
	{"AIRSHOW", 7, 98902},
	{"HARDEE", 6, 98903},
	{"KODA", 4, 98904},
	{"BLUEFISH", 8, 98905},
	{"BUB", 3, 98906},
	{"ATTUNED", 7, 98907},
	{"UROL", 4, 98908},
	{"DOWNLOADNEW", 11, 98909},
	{"HERONS", 6, 98910},
	{"UIGI", 4, 98911},
	{"TLOY", 4, 98912},
	{"SAWG", 4, 98913},
	{"PHID", 4, 98914},
	{"EIFP", 4, 98915},
	{"RENTALNEW", 9, 98916},
	{"COULDN", 6, 98917},
	{"RAIDING", 7, 98918},
	{"DEFT", 4, 98919},
	{"BANGER", 6, 98920},
	{"INICIAL", 7, 98921},
	{"KIRKHAM", 7, 98922},
	{"BAILE", 5, 98923},
	{"FICS", 4, 98924},
	{"KWANZA", 6, 98925},
	{"DECLASSIFIED", 12, 98926},
	{"DOABLE", 6, 98927},
	{"SEETHING", 8, 98928},
	{"GROKSTER", 8, 98929},
	{"YVOC", 4, 98930},
	{"RJOA", 4, 98931},
	{"RIMW", 4, 98932},
	{"REKH", 4, 98933},
	{"OXOR", 4, 98934},
	{"LWEG", 4, 98935},
	{"KUPD", 4, 98936},
	{"XDSL", 4, 98937},
	{"CARNE", 5, 98938},
	{"BERKLEE", 7, 98939},
	{"STRON", 5, 98940},
	{"BEAUTYHOME", 10, 98941},
	{"BURRITOS", 8, 98942},
	{"INGELHEIM", 9, 98943},
	{"JARDINS", 7, 98944},
	{"RAMMING", 7, 98945},
	{"CARIBOO", 7, 98946},
	{"WLCH", 4, 98947},
	{"OBAP", 4, 98948},
	{"JPUT", 4, 98949},
	{"BONW", 4, 98950},
	{"AXWH", 4, 98951},
	{"DIRECTATHLETICS", 15, 98952},
	{"ALLIGATORS", 10, 98953},
	{"LORIS", 5, 98954},
	{"INSTIGATED", 10, 98955},
	{"KANDY", 5, 98956},
	{"SHARECHAT", 9, 98957},
	{"FINCHER", 7, 98958},
	{"FARMALL", 7, 98959},
	{"SUPERSTRUCTURE", 14, 98960},
	{"YFAU", 4, 98961},
	{"XTFR", 4, 98962},
	{"NKMY", 4, 98963},
	{"LNEU", 4, 98964},
	{"KDRE", 4, 98965},
	{"GWIS", 4, 98966},
	{"ERMV", 4, 98967},
	{"HUSK", 4, 98968},
	{"HYGIENISTS", 10, 98969},
	{"LODZ", 4, 98970},
	{"FIEDLER", 7, 98971},
	{"ACETYLTRANSFERASE", 17, 98972},
	{"GRANDIOSE", 9, 98973},
	{"CLERKSHIP", 9, 98974},
	{"CROTCHLESS", 10, 98975},
	{"VGEN", 4, 98976},
	{"UMAH", 4, 98977},
	{"SCYT", 4, 98978},
	{"OVWH", 4, 98979},
	{"AIGW", 4, 98980},
	{"WORLDSTOCK", 10, 98981},
	{"PLP", 3, 98982},
	{"STRAPPY", 7, 98983},
	{"CLASSIFIABLE", 12, 98984},
	{"ELITEGROUP", 10, 98985},
	{"SODAS", 5, 98986},
	{"CONCISELY", 9, 98987},
	{"LIBERTINES", 10, 98988},
	{"NORRISTOWN", 10, 98989},
	{"NASACORT", 8, 98990},
	{"QOSMIO", 6, 98991},
	{"VSCO", 4, 98992},
	{"RORX", 4, 98993},
	{"RGCA", 4, 98994},
	{"MPHW", 4, 98995},
	{"EHRL", 4, 98996},
	{"AUTR", 4, 98997},
	{"APYT", 4, 98998},
	{"DEFLECTOR", 9, 98999},
	{"DANBY", 5, 99000},
	{"REENTER", 7, 99001},
	{"INBOARD", 7, 99002},
	{"KURTIS", 6, 99003},
	{"DARVOCET", 8, 99004},
	{"EMEDICINE", 9, 99005},
	{"ULAE", 4, 99006},
	{"LDNI", 4, 99007},
	{"KESV", 4, 99008},
	{"AXIC", 4, 99009},
	{"AGWH", 4, 99010},
	{"SYMBIOSIS", 9, 99011},
	{"DOBRO", 5, 99012},
	{"PERA", 4, 99013},
	{"MALDONADO", 9, 99014},
	{"SCEPTICISM", 10, 99015},
	{"LAPAROSCOPY", 11, 99016},
	{"CABOOSE", 7, 99017},
	{"QUATRE", 6, 99018},
	{"ESTRECHO", 8, 99019},
	{"FITTERS", 7, 99020},
	{"RNAZ", 4, 99021},
	{"NGYM", 4, 99022},
	{"AMSJ", 4, 99023},
	{"ROCKMAN", 7, 99024},
	{"BALHAM", 6, 99025},
	{"CONCATENATED", 12, 99026},
	{"GRADUATIONS", 11, 99027},
	{"LAWNDALE", 8, 99028},
	{"GERMANIUM", 9, 99029},
	{"CONSTANCY", 9, 99030},
	{"SCREWFIX", 8, 99031},
	{"PLATS", 5, 99032},
	{"COUNTRYMAN", 10, 99033},
	{"STOKED", 6, 99034},
	{"WINGSPAN", 8, 99035},
	{"ALLERGENIC", 10, 99036},
	{"MACHINISTS", 10, 99037},
	{"AIRFIX", 6, 99038},
	{"CORRY", 5, 99039},
	{"UEFU", 4, 99040},
	{"REVJ", 4, 99041},
	{"CYIT", 4, 99042},
	{"ARMN", 4, 99043},
	{"BUNCOMBE", 8, 99044},
	{"INSUFFICIENTLY", 14, 99045},
	{"CEMENTS", 7, 99046},
	{"REAPPEAR", 8, 99047},
	{"MOFK", 4, 99048},
	{"EFSP", 4, 99049},
	{"DOWELL", 6, 99050},
	{"HICK", 4, 99051},
	{"BOUDOIR", 7, 99052},
	{"AFFINITIES", 10, 99053},
	{"XPLORE", 6, 99054},
	{"DIGITALES", 9, 99055},
	{"AQUINO", 6, 99056},
	{"PENSKE", 6, 99057},
	{"REPELLENTS", 10, 99058},
	{"GLADES", 6, 99059},
	{"DAMAN", 5, 99060},
	{"CRUTCH", 6, 99061},
	{"PLAYBILL", 8, 99062},
	{"RINALDI", 7, 99063},
	{"RIOTING", 7, 99064},
	{"FAMER", 5, 99065},
	{"ESPOUSED", 8, 99066},
	{"KFEL", 4, 99067},
	{"DVUL", 4, 99068},
	{"DVON", 4, 99069},
	{"CKSJ", 4, 99070},
	{"BREP", 4, 99071},
	{"AZQU", 4, 99072},
	{"APIV", 4, 99073},
	{"RMON", 4, 99074},
	{"CGR", 3, 99075},
	{"SYNTHROID", 9, 99076},
	{"MICROSATELLITE", 14, 99077},
	{"JCP", 3, 99078},
	{"NEWNAN", 6, 99079},
	{"LKRE", 4, 99080},
	{"HFIF", 4, 99081},
	{"CTBI", 4, 99082},
	{"COLV", 4, 99083},
	{"ARLP", 4, 99084},
	{"SARANAC", 7, 99085},
	{"EUROSPORT", 9, 99086},
	{"AMYLASE", 7, 99087},
	{"LEMS", 4, 99088},
	{"BUCKLING", 8, 99089},
	{"SONGBIRD", 8, 99090},
	{"TELEMARKETERS", 13, 99091},
	{"PREMIO", 6, 99092},
	{"VYDE", 4, 99093},
	{"EDZI", 4, 99094},
	{"ALTP", 4, 99095},
	{"PCTECHTALK", 10, 99096},
	{"MAMIE", 5, 99097},
	{"FRISCH", 6, 99098},
	{"UPPED", 5, 99099},
	{"CYBERCRIME", 10, 99100},
	{"ARENAL", 6, 99101},
	{"WARMINSTER", 10, 99102},
	{"PADGETT", 7, 99103},
	{"AMESBURY", 8, 99104},
	{"MIEM", 4, 99105},
	{"MBYC", 4, 99106},
	{"DISCURSIVE", 10, 99107},
	{"MMIII", 5, 99108},
	{"GMRS", 4, 99109},
	{"DISPUTING", 9, 99110},
	{"UNPAVED", 7, 99111},
	{"FAURE", 5, 99112},
	{"LIEBER", 6, 99113},
	{"WLYO", 4, 99114},
	{"KASF", 4, 99115},
	{"EPMY", 4, 99116},
	{"BAUERNHOF", 9, 99117},
	{"DEFINETLY", 9, 99118},
	{"VASECTOMY", 9, 99119},
	{"ROSTOCK", 7, 99120},
	{"AREQUIPA", 8, 99121},
	{"YKZ", 3, 99122},
	{"XRK", 3, 99123},
	{"XJC", 3, 99124},
	{"VXJ", 3, 99125},
	{"KBV", 3, 99126},
	{"GQC", 3, 99127},
	{"REPUDIATION", 11, 99128},
	{"ALTHOUSE", 8, 99129},
	{"ADMINIS", 7, 99130},
	{"TRPM", 4, 99131},
	{"PENV", 4, 99132},
	{"NASONEX", 7, 99133},
	{"INNATEIMMUNITY", 14, 99134},
	{"WORRISOME", 9, 99135},
	{"KEENSPOT", 8, 99136},
	{"NONCONFORMING", 13, 99137},
	{"SEAFRONT", 8, 99138},
	{"RUSHDIE", 7, 99139},
	{"SALAH", 5, 99140},
	{"HANDCUFFED", 10, 99141},
	{"REPUBLICA", 9, 99142},
	{"MARSHMALLOWS", 12, 99143},
	{"TURNERS", 7, 99144},
	{"DINETTE", 7, 99145},
	{"TDIL", 4, 99146},
	{"SGOF", 4, 99147},
	{"KPHO", 4, 99148},
	{"FEWV", 4, 99149},
	{"FEPE", 4, 99150},
	{"MORMONISM", 9, 99151},
	{"CLARICE", 7, 99152},
	{"CASCADIA", 8, 99153},
	{"SUNBLOCK", 8, 99154},
	{"CLEARLAKE", 9, 99155},
	{"FREIGHTER", 9, 99156},
	{"BYTHE", 5, 99157},
	{"PBYP", 4, 99158},
	{"OWIV", 4, 99159},
	{"JETB", 4, 99160},
	{"RUP", 3, 99161},
	{"DIMPLES", 7, 99162},
	{"VANDALIA", 8, 99163},
	{"TURD", 4, 99164},
	{"BANDAR", 6, 99165},
	{"INHABITANT", 10, 99166},
	{"REPRINTING", 10, 99167},
	{"DERIVATIONS", 11, 99168},
	{"UTGL", 4, 99169},
	{"TLAG", 4, 99170},
	{"NFLW", 4, 99171},
	{"JOER", 4, 99172},
	{"GNWE", 4, 99173},
	{"ABAF", 4, 99174},
	{"FLOURISHES", 10, 99175},
	{"COLONIZED", 9, 99176},
	{"VELEZ", 5, 99177},
	{"TRINE", 5, 99178},
	{"BENICIA", 7, 99179},
	{"REDWOODS", 8, 99180},
	{"MEADOWLANDS", 11, 99181},
	{"THERAPIE", 8, 99182},
	{"HESSIAN", 7, 99183},
	{"PAYG", 4, 99184},
	{"TATUNG", 6, 99185},
	{"RODM", 4, 99186},
	{"KUGA", 4, 99187},
	{"HAWR", 4, 99188},
	{"GYIT", 4, 99189},
	{"RENTCLICKS", 10, 99190},
	{"CARRIAGEWAY", 11, 99191},
	{"FEDER", 5, 99192},
	{"ARDOUR", 6, 99193},
	{"ARBEIT", 6, 99194},
	{"LEVANT", 6, 99195},
	{"KALININGRAD", 11, 99196},
	{"EINVAL", 6, 99197},
	{"BANACH", 6, 99198},
	{"HOGARTH", 7, 99199},
	{"WAFO", 4, 99200},
	{"SLEX", 4, 99201},
	{"PLEQ", 4, 99202},
	{"MRLE", 4, 99203},
	{"FITU", 4, 99204},
	{"EWYA", 4, 99205},
	{"CSPL", 4, 99206},
	{"AKUL", 4, 99207},
	{"SAURON", 6, 99208},
	{"ZORAN", 5, 99209},
	{"FINAN", 5, 99210},
	{"GODARD", 6, 99211},
	{"DISTRIBUTABLE", 13, 99212},
	{"TRIMSPA", 7, 99213},
	{"BABYFACE", 8, 99214},
	{"HILLER", 6, 99215},
	{"IMITATORS", 9, 99216},
	{"INITIALIZER", 11, 99217},
	{"ZEAG", 4, 99218},
	{"RYEP", 4, 99219},
	{"RGYU", 4, 99220},
	{"REGH", 4, 99221},
	{"OGAB", 4, 99222},
	{"ILCE", 4, 99223},
	{"HMIX", 4, 99224},
	{"EGBE", 4, 99225},
	{"SIONAL", 6, 99226},
	{"MOTORI", 6, 99227},
	{"PATHOGENICITY", 13, 99228},
	{"TALKATIVE", 9, 99229},
	{"DESELECT", 8, 99230},
	{"DEBENHAMS", 9, 99231},
	{"DEALSNEW", 8, 99232},
	{"PEICE", 5, 99233},
	{"PHONOGRAPH", 10, 99234},
	{"HUMMINBIRD", 10, 99235},
	{"SPECULATORS", 11, 99236},
	{"LIEUT", 5, 99237},
	{"YMYF", 4, 99238},
	{"UYYO", 4, 99239},
	{"URIV", 4, 99240},
	{"PFAR", 4, 99241},
	{"NACY", 4, 99242},
	{"FAVS", 4, 99243},
	{"AFICIONADOS", 11, 99244},
	{"ADDYSG", 6, 99245},
	{"STATLER", 7, 99246},
	{"KDF", 3, 99247},
	{"LIGIER", 6, 99248},
	{"GNUNET", 6, 99249},
	{"UBEV", 4, 99250},
	{"PPYO", 4, 99251},
	{"BROMPTON", 8, 99252},
	{"PAYKEL", 6, 99253},
	{"TOPICA", 6, 99254},
	{"GAGGIA", 6, 99255},
	{"BELAY", 5, 99256},
	{"PETUNIA", 7, 99257},
	{"ZSAY", 4, 99258},
	{"YAPH", 4, 99259},
	{"OWLR", 4, 99260},
	{"LPKE", 4, 99261},
	{"LCOI", 4, 99262},
	{"QUELQUES", 8, 99263},
	{"TUAW", 4, 99264},
	{"INGRES", 6, 99265},
	{"SLEAZE", 6, 99266},
	{"MATRICULATION", 13, 99267},
	{"SMELTING", 8, 99268},
	{"CORRECTOR", 9, 99269},
	{"UMAW", 4, 99270},
	{"GUYN", 4, 99271},
	{"GRYF", 4, 99272},
	{"GCOC", 4, 99273},
	{"FGAZ", 4, 99274},
	{"CKJE", 4, 99275},
	{"ARUC", 4, 99276},
	{"CUSS", 4, 99277},
	{"NATURSEKT", 9, 99278},
	{"EMULATING", 9, 99279},
	{"SLIPPAGE", 8, 99280},
	{"DRAKENSBERG", 11, 99281},
	{"LOMAS", 5, 99282},
	{"CRANIATA", 8, 99283},
	{"GREMLIN", 7, 99284},
	{"SLATS", 5, 99285},
	{"DOVETAIL", 8, 99286},
	{"TRANSCRIBING", 12, 99287},
	{"SUNDAE", 6, 99288},
	{"TWEJ", 4, 99289},
	{"RMCG", 4, 99290},
	{"RIAK", 4, 99291},
	{"OUKA", 4, 99292},
	{"IDGU", 4, 99293},
	{"FVAC", 4, 99294},
	{"FTYT", 4, 99295},
	{"LOGIT", 5, 99296},
	{"KIRKCALDY", 9, 99297},
	{"SHORELINES", 10, 99298},
	{"REPORTAGE", 9, 99299},
	{"MANOEUVRE", 9, 99300},
	{"LIFTERS", 7, 99301},
	{"INTUBATION", 10, 99302},
	{"RHINOS", 6, 99303},
	{"SPARTACUS", 9, 99304},
	{"MRWI", 4, 99305},
	{"KMOT", 4, 99306},
	{"HRSQ", 4, 99307},
	{"AKOW", 4, 99308},
	{"EPISTEMIC", 9, 99309},
	{"MAJA", 4, 99310},
	{"APPREHEND", 9, 99311},
	{"NEOSEEKER", 9, 99312},
	{"RDM", 3, 99313},
	{"LEEWAY", 6, 99314},
	{"VORBEHALTEN", 11, 99315},
	{"MIURA", 5, 99316},
	{"PIGMENTATION", 12, 99317},
	{"OFFENDS", 7, 99318},
	{"QUAYLE", 6, 99319},
	{"WTHB", 4, 99320},
	{"FISP", 4, 99321},
	{"EZOM", 4, 99322},
	{"ELUF", 4, 99323},
	{"LUMPY", 5, 99324},
	{"LANDLOCKED", 10, 99325},
	{"PHOTOELECTRIC", 13, 99326},
	{"EMBATTLED", 9, 99327},
	{"WISEST", 6, 99328},
	{"INOVA", 5, 99329},
	{"SHACKLE", 7, 99330},
	{"FORAMINIFERA", 12, 99331},
	{"GIULIO", 6, 99332},
	{"CABRILLO", 8, 99333},
	{"DULWICH", 7, 99334},
	{"LODD", 4, 99335},
	{"HMYB", 4, 99336},
	{"FRUR", 4, 99337},
	{"AZZC", 4, 99338},
	{"ALDG", 4, 99339},
	{"KABUKI", 6, 99340},
	{"ITEMIZE", 7, 99341},
	{"RIVERBED", 8, 99342},
	{"DIMINUTION", 10, 99343},
	{"CHIARA", 6, 99344},
	{"GING", 4, 99345},
	{"RENCONTRES", 10, 99346},
	{"KOLAB", 5, 99347},
	{"SIOBHAN", 7, 99348},
	{"SOUTHERNMOST", 12, 99349},
	{"UOMA", 4, 99350},
	{"UNKM", 4, 99351},
	{"ULKH", 4, 99352},
	{"HURG", 4, 99353},
	{"FRECKLES", 8, 99354},
	{"EMBEZZLEMENT", 12, 99355},
	{"CASTEL", 6, 99356},
	{"CHIPMUNK", 8, 99357},
	{"ENSEIGNEMENT", 12, 99358},
	{"BILLITON", 8, 99359},
	{"SPLINTS", 7, 99360},
	{"POSITIVITY", 10, 99361},
	{"CIVILISED", 9, 99362},
	{"PACLITAXEL", 10, 99363},
	{"AIRSHIP", 7, 99364},
	{"WEBBBS", 6, 99365},
	{"CAMELBACK", 9, 99366},
	{"TRUSSARDI", 9, 99367},
	{"SCRAPPLEFACE", 12, 99368},
	{"YATY", 4, 99369},
	{"RKSK", 4, 99370},
	{"RDUO", 4, 99371},
	{"OYSU", 4, 99372},
	{"MDRU", 4, 99373},
	{"JETF", 4, 99374},
	{"EZMA", 4, 99375},
	{"EOBR", 4, 99376},
	{"EXPER", 5, 99377},
	{"MARSALIS", 8, 99378},
	{"DESTRUCT", 8, 99379},
	{"BEAUTIFICATION", 14, 99380},
	{"ALDERSON", 8, 99381},
	{"FISCALLY", 8, 99382},
	{"GALLS", 5, 99383},
	{"CESIUM", 6, 99384},
	{"CROSCILL", 8, 99385},
	{"YIPPEE", 6, 99386},
	{"IVYL", 4, 99387},
	{"DDYR", 4, 99388},
	{"BRIGHTMAN", 9, 99389},
	{"AMMON", 5, 99390},
	{"UNARY", 5, 99391},
	{"IMITATED", 8, 99392},
	{"INFLICTING", 10, 99393},
	{"BEDE", 4, 99394},
	{"INDUCEMENT", 10, 99395},
	{"MOBI", 4, 99396},
	{"HEAVE", 5, 99397},
	{"OPTICIAN", 8, 99398},
	{"GAUGUIN", 7, 99399},
	{"ALTAIR", 6, 99400},
	{"KANDI", 5, 99401},
	{"ULBY", 4, 99402},
	{"NORML", 5, 99403},
	{"FANTASIE", 8, 99404},
	{"BLOATING", 8, 99405},
	{"GEGEN", 5, 99406},
	{"EMPIREPOKER", 11, 99407},
	{"PROCLAMATIONS", 13, 99408},
	{"SIPHON", 6, 99409},
	{"GOVE", 4, 99410},
	{"SIJU", 4, 99411},
	{"LMSD", 4, 99412},
	{"HOPG", 4, 99413},
	{"BAYN", 4, 99414},
	{"SCANDIC", 7, 99415},
	{"COMPLICATES", 11, 99416},
	{"AVIARY", 6, 99417},
	{"RARER", 5, 99418},
	{"BEACHWOOD", 9, 99419},
	{"WCHR", 4, 99420},
	{"NBUE", 4, 99421},
	{"LVOC", 4, 99422},
	{"EGWH", 4, 99423},
	{"POWERBOAT", 9, 99424},
	{"TRUNDLE", 7, 99425},
	{"SLOWNESS", 8, 99426},
	{"BRAGA", 5, 99427},
	{"TALKLEFT", 8, 99428},
	{"ELSES", 5, 99429},
	{"SATISH", 6, 99430},
	{"WRONGFULLY", 10, 99431},
	{"HUSHED", 6, 99432},
	{"CADRES", 6, 99433},
	{"RDEW", 4, 99434},
	{"LMEX", 4, 99435},
	{"LEWU", 4, 99436},
	{"FMEG", 4, 99437},
	{"LESSENING", 9, 99438},
	{"VPR", 3, 99439},
	{"TAGGART", 7, 99440},
	{"BACKROOM", 8, 99441},
	{"DEPTFORD", 8, 99442},
	{"FISKE", 5, 99443},
	{"WASHTENAW", 9, 99444},
	{"POWERFULL", 9, 99445},
	{"AURELIUS", 8, 99446},
	{"WEBCOMIC", 8, 99447},
	{"LIMBURG", 7, 99448},
	{"YSYA", 4, 99449},
	{"TIFM", 4, 99450},
	{"RAKW", 4, 99451},
	{"EVRE", 4, 99452},
	{"DRAGSTER", 8, 99453},
	{"IDLEWILD", 8, 99454},
	{"COMPOSTELA", 10, 99455},
	{"REINVESTED", 10, 99456},
	{"GODADDY", 7, 99457},
	{"AHOLD", 5, 99458},
	{"KNOWL", 5, 99459},
	{"SPIRULINA", 9, 99460},
	{"MIMEDEFANG", 10, 99461},
	{"DOBRA", 5, 99462},
	{"POUT", 4, 99463},
	{"MIDP", 4, 99464},
	{"NPOK", 4, 99465},
	{"NLYQ", 4, 99466},
	{"SNELLING", 8, 99467},
	{"THEOPHYLLINE", 12, 99468},
	{"SNOOK", 5, 99469},
	{"COGNATE", 7, 99470},
	{"INFINIBAND", 10, 99471},
	{"MIRE", 4, 99472},
	{"AUSGABE", 7, 99473},
	{"COVEN", 5, 99474},
	{"NIELSON", 7, 99475},
	{"SUFFERER", 8, 99476},
	{"URGD", 4, 99477},
	{"RTEF", 4, 99478},
	{"RKPI", 4, 99479},
	{"RIPD", 4, 99480},
	{"PTMO", 4, 99481},
	{"LOGH", 4, 99482},
	{"JANC", 4, 99483},
	{"IMEZ", 4, 99484},
	{"AULV", 4, 99485},
	{"MARKKA", 6, 99486},
	{"COLEGIO", 7, 99487},
	{"ETHERFAST", 9, 99488},
	{"LIVINGROOM", 10, 99489},
	{"RUMI", 4, 99490},
	{"MORES", 5, 99491},
	{"EMPRESAS", 8, 99492},
	{"PREORDERS", 9, 99493},
	{"FLUSHES", 7, 99494},
	{"UVEE", 4, 99495},
	{"SMYE", 4, 99496},
	{"SKOP", 4, 99497},
	{"MLAM", 4, 99498},
	{"IRDV", 4, 99499},
	{"HMOM", 4, 99500},
	{"RAINDROPS", 9, 99501},
	{"RESTATE", 7, 99502},
	{"PESHAWAR", 8, 99503},
	{"NORDISK", 7, 99504},
	{"BICE", 4, 99505},
	{"NORAD", 5, 99506},
	{"ELEGY", 5, 99507},
	{"SANCTIFICATION", 14, 99508},
	{"SANDED", 6, 99509},
	{"PDOG", 4, 99510},
	{"SHAMANIC", 8, 99511},
	{"KANDINSKY", 9, 99512},
	{"INDIGNANT", 9, 99513},
	{"BOUVIER", 7, 99514},
	{"GODLESS", 7, 99515},
	{"DONTSTAYIN", 10, 99516},
	{"SHOPGIRL", 8, 99517},
	{"HAVANT", 6, 99518},
	{"LIMI", 4, 99519},
	{"SLOOP", 5, 99520},
	{"SERVICER", 8, 99521},
	{"PROULX", 6, 99522},
	{"MIFL", 4, 99523},
	{"DAUP", 4, 99524},
	{"FPD", 3, 99525},
	{"BLUNDELL", 8, 99526},
	{"RINPOCHE", 8, 99527},
	{"ENESCO", 6, 99528},
	{"POLITENESS", 10, 99529},
	{"BAFFLING", 8, 99530},
	{"ZIONSVILLE", 10, 99531},
	{"LVW", 3, 99532},
	{"MECHANICSBURG", 13, 99533},
	{"REFRESHES", 9, 99534},
	{"HURRIEDLY", 9, 99535},
	{"AMPERSAND", 9, 99536},
	{"HOPEFULS", 8, 99537},
	{"XEDE", 4, 99538},
	{"RTOQ", 4, 99539},
	{"OPQU", 4, 99540},
	{"FTYF", 4, 99541},
	{"DPSR", 4, 99542},
	{"CONSERVATIVELY", 14, 99543},
	{"EFFEC", 5, 99544},
	{"NFORMATION", 10, 99545},
	{"REWORKING", 9, 99546},
	{"BIRDERS", 7, 99547},
	{"CONGOLESE", 9, 99548},
	{"CHARACTERISE", 12, 99549},
	{"PURPORTING", 10, 99550},
	{"FINGERTIP", 9, 99551},
	{"WHOL", 4, 99552},
	{"VAMA", 4, 99553},
	{"PATD", 4, 99554},
	{"ODDM", 4, 99555},
	{"LFIX", 4, 99556},
	{"IWEL", 4, 99557},
	{"IDAK", 4, 99558},
	{"EPPU", 4, 99559},
	{"CBEH", 4, 99560},
	{"RAIMI", 5, 99561},
	{"OLED", 4, 99562},
	{"BRAZING", 7, 99563},
	{"QUARANTINED", 11, 99564},
	{"HEDLEY", 6, 99565},
	{"WILLPOWER", 9, 99566},
	{"INFOMINE", 8, 99567},
	{"MEDIAS", 6, 99568},
	{"PASSO", 5, 99569},
	{"DUALIT", 6, 99570},
	{"WANR", 4, 99571},
	{"TAMY", 4, 99572},
	{"PEGR", 4, 99573},
	{"MTIR", 4, 99574},
	{"EDYL", 4, 99575},
	{"MAMMOGRAMS", 10, 99576},
	{"BABYSITTERS", 11, 99577},
	{"CHANDLERY", 9, 99578},
	{"ICEBREAKER", 10, 99579},
	{"TAUNT", 5, 99580},
	{"APHID", 5, 99581},
	{"ELURA", 5, 99582},
	{"HINTING", 7, 99583},
	{"VENTER", 6, 99584},
	{"OMICRON", 7, 99585},
	{"MAGGOT", 6, 99586},
	{"KALENDER", 8, 99587},
	{"URCY", 4, 99588},
	{"KMLO", 4, 99589},
	{"CYUN", 4, 99590},
	{"SCHOOLBOY", 9, 99591},
	{"PERCHLORATE", 11, 99592},
	{"DWP", 3, 99593},
	{"BAILIFF", 7, 99594},
	{"LABORIOUS", 9, 99595},
	{"CAUCHY", 6, 99596},
	{"ROETHLISBERGER", 14, 99597},
	{"OUTPOURING", 10, 99598},
	{"RACHELLE", 8, 99599},
	{"INSECTA", 7, 99600},
	{"DEFLECTED", 9, 99601},
	{"PSERIES", 7, 99602},
	{"SAFEGUARDED", 11, 99603},
	{"BREAUX", 6, 99604},
	{"OCKJ", 4, 99605},
	{"OAGG", 4, 99606},
	{"IGBI", 4, 99607},
	{"GEAW", 4, 99608},
	{"ATROPINE", 8, 99609},
	{"ACGIH", 5, 99610},
	{"CORDELL", 7, 99611},
	{"HOUSER", 6, 99612},
	{"INFLECTION", 10, 99613},
	{"SASSER", 6, 99614},
	{"LETTRES", 7, 99615},
	{"ORIGEN", 6, 99616},
	{"ELDRED", 6, 99617},
	{"MYRRH", 5, 99618},
	{"NEUMAN", 6, 99619},
	{"EQUATING", 8, 99620},
	{"INFUSE", 6, 99621},
	{"XWU", 3, 99622},
	{"MZG", 3, 99623},
	{"KXD", 3, 99624},
	{"ZZAA", 4, 99625},
	{"MEGL", 4, 99626},
	{"CHAFF", 5, 99627},
	{"DEFACED", 7, 99628},
	{"MIMICKING", 9, 99629},
	{"DECISIONMAKING", 14, 99630},
	{"COUNSELED", 9, 99631},
	{"PAMPERS", 7, 99632},
	{"SHOWY", 5, 99633},
	{"KMFDM", 5, 99634},
	{"GAMESWINE", 9, 99635},
	{"YJAS", 4, 99636},
	{"SFAK", 4, 99637},
	{"IMWR", 4, 99638},
	{"FSWO", 4, 99639},
	{"EIPL", 4, 99640},
	{"ABOG", 4, 99641},
	{"CESKY", 5, 99642},
	{"WOODRIDGE", 9, 99643},
	{"ALTRUISTIC", 10, 99644},
	{"WISTAR", 6, 99645},
	{"SALTI", 5, 99646},
	{"JACEK", 5, 99647},
	{"TAMU", 4, 99648},
	{"JEWELLERYKIDS", 13, 99649},
	{"CHAPLAINCY", 10, 99650},
	{"BACKFLOW", 8, 99651},
	{"TYRWHITT", 8, 99652},
	{"RPR", 3, 99653},
	{"WDSO", 4, 99654},
	{"PRAK", 4, 99655},
	{"NIGU", 4, 99656},
	{"IPEM", 4, 99657},
	{"EUFC", 4, 99658},
	{"RECETAS", 7, 99659},
	{"ALDERMEN", 8, 99660},
	{"COMMENDS", 8, 99661},
	{"EMCEE", 5, 99662},
	{"MOORISH", 7, 99663},
	{"STATESIDE", 9, 99664},
	{"KINNEAR", 7, 99665},
	{"RATNER", 6, 99666},
	{"IMMUNOFLUORESCENCE", 18, 99667},
	{"BOBBING", 7, 99668},
	{"DEFIANTLY", 9, 99669},
	{"XESP", 4, 99670},
	{"ODBI", 4, 99671},
	{"HLAP", 4, 99672},
	{"AMYW", 4, 99673},
	{"COLONELS", 8, 99674},
	{"MACHETE", 7, 99675},
	{"VAPI", 4, 99676},
	{"GASTROENTEROL", 13, 99677},
	{"AMOXIL", 6, 99678},
	{"XDM", 3, 99679},
	{"READMISSION", 11, 99680},
	{"POSIBLE", 7, 99681},
	{"BELLYDANCE", 10, 99682},
	{"MADDIE", 6, 99683},
	{"AWCH", 4, 99684},
	{"FUKING", 6, 99685},
	{"CUALQUIER", 9, 99686},
	{"PATHOS", 6, 99687},
	{"BATTLESHIPS", 11, 99688},
	{"SQUASHED", 8, 99689},
	{"SMARTLY", 7, 99690},
	{"KATES", 5, 99691},
	{"CCJ", 3, 99692},
	{"LAMENTS", 7, 99693},
	{"SPIED", 5, 99694},
	{"NEPHROPATHY", 11, 99695},
	{"MENORAH", 7, 99696},
	{"PLAYTHINGS", 10, 99697},
	{"EXFOLIATING", 11, 99698},
	{"ARGUMENTATIVE", 13, 99699},
	{"WISTERIA", 8, 99700},
	{"LGOB", 4, 99701},
	{"HMOB", 4, 99702},
	{"FLEH", 4, 99703},
	{"ELKN", 4, 99704},
	{"DBIB", 4, 99705},
	{"DIRECTORIAL", 11, 99706},
	{"CONDIMENT", 9, 99707},
	{"PICTUERS", 8, 99708},
	{"ROUSED", 6, 99709},
	{"SOCIALITE", 9, 99710},
	{"ALOOF", 5, 99711},
	{"ANSYS", 5, 99712},
	{"USENIX", 6, 99713},
	{"SAMFORD", 7, 99714},
	{"NEWBURYPORT", 11, 99715},
	{"GALLIPOLI", 9, 99716},
	{"BDC", 3, 99717},
	{"CONCEALER", 9, 99718},
	{"AZUREUS", 7, 99719},
	{"USEQ", 4, 99720},
	{"LORJ", 4, 99721},
	{"GOGG", 4, 99722},
	{"FBAI", 4, 99723},
	{"ELKH", 4, 99724},
	{"BBET", 4, 99725},
	{"SCHIZOSACCHAROMYCES", 19, 99726},
	{"SNORE", 5, 99727},
	{"SENDAI", 6, 99728},
	{"CAPITALISATION", 14, 99729},
	{"JANSON", 6, 99730},
	{"CHARRED", 7, 99731},
	{"REASSESS", 8, 99732},
	{"PHUNK", 5, 99733},
	{"INDUSTRIA", 9, 99734},
	{"SUPERCAR", 8, 99735},
	{"MYRNA", 5, 99736},
	{"CONECTIVA", 9, 99737},
	{"CHARLY", 6, 99738},
	{"YTOQ", 4, 99739},
	{"UTYB", 4, 99740},
	{"UDDS", 4, 99741},
	{"LIWE", 4, 99742},
	{"FJEF", 4, 99743},
	{"AMBH", 4, 99744},
	{"SUBPARAGRAPHS", 13, 99745},
	{"IHRER", 5, 99746},
	{"HEIMDAL", 7, 99747},
	{"KILBRIDE", 8, 99748},
	{"ELIM", 4, 99749},
	{"DUNSTAN", 7, 99750},
	{"EJOC", 4, 99751},
	{"BIOREMEDIATION", 14, 99752},
	{"IFILM", 5, 99753},
	{"VALIDLY", 7, 99754},
	{"WATTERS", 7, 99755},
	{"REMATCH", 7, 99756},
	{"ROLLOVERS", 9, 99757},
	{"WYRE", 4, 99758},
	{"NAVIER", 6, 99759},
	{"STANFIELD", 9, 99760},
	{"INSTRUMENTED", 12, 99761},
	{"RMSG", 4, 99762},
	{"FUSP", 4, 99763},
	{"YEHUDA", 6, 99764},
	{"LYTLE", 5, 99765},
	{"FIJIAN", 6, 99766},
	{"CHUTES", 6, 99767},
	{"LESSTIF", 7, 99768},
	{"FABERGE", 7, 99769},
	{"BOLSHEVIK", 9, 99770},
	{"UVED", 4, 99771},
	{"UERU", 4, 99772},
	{"TUBU", 4, 99773},
	{"PCOV", 4, 99774},
	{"OOQU", 4, 99775},
	{"OMKN", 4, 99776},
	{"NDUD", 4, 99777},
	{"NBOG", 4, 99778},
	{"GOPU", 4, 99779},
	{"GWYN", 4, 99780},
	{"UNSOUND", 7, 99781},
	{"HATTER", 6, 99782},
	{"MCKEOWN", 7, 99783},
	{"CHARMAINE", 9, 99784},
	{"CREEPERS", 8, 99785},
	{"POWERSPORTS", 11, 99786},
	{"KANDA", 5, 99787},
	{"WAGENINGEN", 10, 99788},
	{"SPLATTER", 8, 99789},
	{"LINSEY", 6, 99790},
	{"STENTS", 6, 99791},
	{"QUILTERS", 8, 99792},
	{"TAKEOUT", 7, 99793},
	{"SYWO", 4, 99794},
	{"OPAV", 4, 99795},
	{"OLLN", 4, 99796},
	{"CKGI", 4, 99797},
	{"BOYP", 4, 99798},
	{"BOJA", 4, 99799},
	{"UNISA", 5, 99800},
	{"SILTY", 5, 99801},
	{"RECREATIONS", 11, 99802},
	{"PROFUSELY", 9, 99803},
	{"KAITLYN", 7, 99804},
	{"DUMBARTON", 9, 99805},
	{"TOPTOP", 6, 99806},
	{"VOGELS", 6, 99807},
	{"KARTEN", 6, 99808},
	{"BEARISH", 7, 99809},
	{"INTELLIGENCES", 13, 99810},
	{"LEFEBVRE", 8, 99811},
	{"SORREL", 6, 99812},
	{"NYSY", 4, 99813},
	{"NLAF", 4, 99814},
	{"CURITIBA", 8, 99815},
	{"REVERIE", 7, 99816},
	{"JACKSONS", 8, 99817},
	{"PHONON", 6, 99818},
	{"COLLOQUIAL", 10, 99819},
	{"THIEVERY", 8, 99820},
	{"MACHINA", 7, 99821},
	{"INAPPROP", 8, 99822},
	{"UEVO", 4, 99823},
	{"OIDG", 4, 99824},
	{"AWWO", 4, 99825},
	{"CALLOUS", 7, 99826},
	{"ULLRICH", 7, 99827},
	{"JINGLES", 7, 99828},
	{"EUROCUP", 7, 99829},
	{"RECONNECTION", 12, 99830},
	{"MISMATCHED", 10, 99831},
	{"NOGALES", 7, 99832},
	{"MIMEOLE", 7, 99833},
	{"PERPLEXING", 10, 99834},
	{"UEOV", 4, 99835},
	{"UDOM", 4, 99836},
	{"IBDE", 4, 99837},
	{"EEMR", 4, 99838},
	{"BOYG", 4, 99839},
	{"SPLASHES", 8, 99840},
	{"WWWBOARD", 8, 99841},
	{"HOMESICK", 8, 99842},
	{"DUPER", 5, 99843},
	{"PLUMAS", 6, 99844},
	{"MALFOY", 6, 99845},
	{"MACHI", 5, 99846},
	{"GAINER", 6, 99847},
	{"OCHRE", 5, 99848},
	{"HEARTBREAKER", 12, 99849},
	{"BYSTANDER", 9, 99850},
	{"INMAGINE", 8, 99851},
	{"HEMOLYTIC", 9, 99852},
	{"DILATATION", 10, 99853},
	{"YURB", 4, 99854},
	{"XUSE", 4, 99855},
	{"RSOY", 4, 99856},
	{"HWAG", 4, 99857},
	{"FFGU", 4, 99858},
	{"ACTUATION", 9, 99859},
	{"VALSAD", 6, 99860},
	{"CHAMBERLIN", 10, 99861},
	{"WALKEN", 6, 99862},
	{"COMMEMORATES", 12, 99863},
	{"TEAMSPEAK", 9, 99864},
	{"TARIFS", 6, 99865},
	{"CWB", 3, 99866},
	{"USHG", 4, 99867},
	{"TRUR", 4, 99868},
	{"SGUL", 4, 99869},
	{"RGSC", 4, 99870},
	{"NHUL", 4, 99871},
	{"HRUT", 4, 99872},
	{"CKID", 4, 99873},
	{"CHSK", 4, 99874},
	{"AMPY", 4, 99875},
	{"RAINWEAR", 8, 99876},
	{"MORNIN", 6, 99877},
	{"BEACHCOMBER", 11, 99878},
	{"AKADEMIE", 8, 99879},
	{"DISTILLER", 9, 99880},
	{"ENCYCLOPEDIC", 12, 99881},
	{"YGLE", 4, 99882},
	{"TOPV", 4, 99883},
	{"RUTL", 4, 99884},
	{"RMEH", 4, 99885},
	{"LHEG", 4, 99886},
	{"HROG", 4, 99887},
	{"DDUA", 4, 99888},
	{"GROGAN", 6, 99889},
	{"PRK", 3, 99890},
	{"VARICELLA", 9, 99891},
	{"MAVIC", 5, 99892},
	{"XPM", 3, 99893},
	{"GOTTI", 5, 99894},
	{"GREENOCK", 8, 99895},
	{"RVWS", 4, 99896},
	{"SARL", 4, 99897},
	{"QUELL", 5, 99898},
	{"ULRU", 4, 99899},
	{"FUKR", 4, 99900},
	{"FFGR", 4, 99901},
	{"BCOR", 4, 99902},
	{"REPULSION", 9, 99903},
	{"KARAS", 5, 99904},
	{"WEBQUEST", 8, 99905},
	{"LIBERTYVILLE", 12, 99906},
	{"PARACHUTES", 10, 99907},
	{"CAPITAN", 7, 99908},
	{"SHEBOY", 6, 99909},
	{"BALK", 4, 99910},
	{"TWINMOS", 7, 99911},
	{"IMPRECISE", 9, 99912},
	{"SWWW", 4, 99913},
	{"RKIE", 4, 99914},
	{"OFBH", 4, 99915},
	{"LIOP", 4, 99916},
	{"NORTHWOODS", 10, 99917},
	{"DIANNA", 6, 99918},
	{"BEDSKIRT", 8, 99919},
	{"IMAGINES", 8, 99920},
	{"RESURRECT", 9, 99921},
	{"TOURETTE", 8, 99922},
	{"SOFTENS", 7, 99923},
	{"REDHAWKS", 8, 99924},
	{"HARNESSED", 9, 99925},
	{"FARIS", 5, 99926},
	{"UNFILLED", 8, 99927},
	{"FLANGED", 7, 99928},
	{"POSIT", 5, 99929},
	{"SINUSES", 7, 99930},
	{"VIKT", 4, 99931},
	{"NYTU", 4, 99932},
	{"NKFE", 4, 99933},
	{"LFFA", 4, 99934},
	{"EIPR", 4, 99935},
	{"MORPETH", 7, 99936},
	{"CLEARVIEW", 9, 99937},
	{"AMPUTEE", 7, 99938},
	{"EXUBERANCE", 10, 99939},
	{"OBLIGATE", 8, 99940},
	{"GAMEPLANET", 10, 99941},
	{"ENDOTOXIN", 9, 99942},
	{"FLOCKING", 8, 99943},
	{"SUPERBIT", 8, 99944},
	{"CENTAURI", 8, 99945},
	{"UNNUMBERED", 10, 99946},
	{"BLANKENSHIP", 11, 99947},
	{"PAIZO", 5, 99948},
	{"XEVE", 4, 99949},
	{"SYOV", 4, 99950},
	{"GBYO", 4, 99951},
	{"CLARY", 5, 99952},
	{"DESELECTED", 10, 99953},
	{"CHARLEROI", 9, 99954},
	{"COMPLETOS", 9, 99955},
	{"GARNISHMENT", 11, 99956},
	{"RFIA", 4, 99957},
	{"OBSR", 4, 99958},
	{"MBYR", 4, 99959},
	{"FANM", 4, 99960},
	{"AUTHORTRACKER", 13, 99961},
	{"CHECKERBOARD", 12, 99962},
	{"ARUBAN", 6, 99963},
	{"FASTIN", 6, 99964},
	{"OUTBURSTS", 9, 99965},
	{"HUMIDORS", 8, 99966},
	{"POSTGRAD", 8, 99967},
	{"UNDYING", 7, 99968},
	{"PROTEASES", 9, 99969},
	{"MCLOUGHLIN", 10, 99970},
	{"STUBBLE", 7, 99971},
	{"NETCDF", 6, 99972},
	{"VACH", 4, 99973},
	{"USIG", 4, 99974},
	{"ODNU", 4, 99975},
	{"EIBU", 4, 99976},
	{"CADDIES", 7, 99977},
	{"BAMBERG", 7, 99978},
	{"BANDE", 5, 99979},
	{"BROWNIZ", 7, 99980},
	{"APPENDICITIS", 12, 99981},
	{"TRADEWINDS", 10, 99982},
	{"ENVIE", 5, 99983},
	{"COLLIDING", 9, 99984},
	{"KNESSET", 7, 99985},
	{"DEMOPOLIS", 9, 99986},
	{"MUGHAL", 6, 99987},
	{"EBEM", 4, 99988},
	{"ENUMERATOR", 10, 99989},
	{"SPLINES", 7, 99990},
	{"MARVELL", 7, 99991},
	{"FUNPAGES", 8, 99992},
	{"FERENCE", 7, 99993},
	{"EXISTENTIALISM", 14, 99994},
	{"DEFENSEMAN", 10, 99995},
	{"KAANAPALI", 9, 99996},
	{"QUIVERING", 9, 99997},
	{"CROSSBAR", 8, 99998},
	{"TOASTMASTER", 11, 99999},
	{"TIBR", 4, 100000},
	{"SYFI", 4, 100001},
	{"PETW", 4, 100002},
	{"PADT", 4, 100003},
	{"NGKR", 4, 100004},
	{"KPIN", 4, 100005},
	{"CINB", 4, 100006},
	{"ESTERO", 6, 100007},
	{"COORDS", 6, 100008},
	{"NETLINK", 7, 100009},
	{"GTPASE", 6, 100010},
	{"UPTIGHT", 7, 100011},
	{"VRF", 3, 100012},
	{"LLANELLI", 8, 100013},
	{"PLATTS", 6, 100014},
	{"ACTIVES", 7, 100015},
	{"PMES", 4, 100016},
	{"KCHU", 4, 100017},
	{"FRAL", 4, 100018},
	{"DGIB", 4, 100019},
	{"COWN", 4, 100020},
	{"KINGSIZE", 8, 100021},
	{"DOODLES", 7, 100022},
	{"CHIMERIC", 8, 100023},
	{"MALKOVICH", 9, 100024},
	{"DEFCON", 6, 100025},
	{"HATTERS", 7, 100026},
	{"COCHISE", 7, 100027},
	{"GENICOM", 7, 100028},
	{"EUERY", 5, 100029},
	{"SEVERUS", 7, 100030},
	{"RCOH", 4, 100031},
	{"CBEF", 4, 100032},
	{"AZAC", 4, 100033},
	{"SARK", 4, 100034},
	{"PEACETIME", 9, 100035},
	{"SHIPP", 5, 100036},
	{"GRINGO", 6, 100037},
	{"INFOSEEK", 8, 100038},
	{"COMMENDING", 10, 100039},
	{"SOFORT", 6, 100040},
	{"FLATTERY", 8, 100041},
	{"ACOUSTICA", 9, 100042},
	{"WKES", 4, 100043},
	{"RYUK", 4, 100044},
	{"BOCO", 4, 100045},
	{"USUARIO", 7, 100046},
	{"GENFORUM", 8, 100047},
	{"SOOTHES", 7, 100048},
	{"WINANS", 6, 100049},
	{"EXPROPRIATION", 13, 100050},
	{"MILLSTONE", 9, 100051},
	{"DEVICEFORGE", 11, 100052},
	{"BADIA", 5, 100053},
	{"PAYROLLS", 8, 100054},
	{"MORTGAGED", 9, 100055},
	{"CONTENIDO", 9, 100056},
	{"ELANTRA", 7, 100057},
	{"INSTREAM", 8, 100058},
	{"IMPOSSIBLY", 10, 100059},
	{"EWDU", 4, 100060},
	{"CTMY", 4, 100061},
	{"RESELLING", 9, 100062},
	{"GIORNO", 6, 100063},
	{"COCTEAU", 7, 100064},
	{"BELUGA", 6, 100065},
	{"LEPAGE", 6, 100066},
	{"EPODUNK", 7, 100067},
	{"ZOGBY", 5, 100068},
	{"COMPELS", 7, 100069},
	{"ALTERNA", 7, 100070},
	{"PRODUCTO", 8, 100071},
	{"HOUSEWIFES", 10, 100072},
	{"TIFFEN", 6, 100073},
	{"SUCCES", 6, 100074},
	{"TPIR", 4, 100075},
	{"HRAB", 4, 100076},
	{"YYY", 3, 100077},
	{"WWSYMPA", 7, 100078},
	{"DRUNKENNESS", 11, 100079},
	{"HARRISVILLE", 11, 100080},
	{"KANCHEEPURAM", 12, 100081},
	{"INDULGED", 8, 100082},
	{"HABITABLE", 9, 100083},
	{"DWNLDS", 6, 100084},
	{"LAURYN", 6, 100085},
	{"UNRAVELING", 10, 100086},
	{"RENNER", 6, 100087},
	{"WERJ", 4, 100088},
	{"UOMI", 4, 100089},
	{"IMGA", 4, 100090},
	{"HYSC", 4, 100091},
	{"EXMO", 4, 100092},
	{"DIATOM", 6, 100093},
	{"BOBSLED", 7, 100094},
	{"YONEX", 5, 100095},
	{"SUBTLETIES", 10, 100096},
	{"ZCF", 3, 100097},
	{"VGV", 3, 100098},
	{"KZM", 3, 100099},
	{"JBV", 3, 100100},
	{"BLALOCK", 7, 100101},
	{"INCARNATIONS", 12, 100102},
	{"MINISTRE", 8, 100103},
	{"OSCILLOSCOPES", 13, 100104},
	{"TRAPPINGS", 9, 100105},
	{"AFTERTHOUGHT", 12, 100106},
	{"LEGUME", 6, 100107},
	{"OBAK", 4, 100108},
	{"MTYP", 4, 100109},
	{"MCUT", 4, 100110},
	{"JANF", 4, 100111},
	{"ILKP", 4, 100112},
	{"EJAK", 4, 100113},
	{"BISB", 4, 100114},
	{"REDIAL", 6, 100115},
	{"HILLBILLIES", 11, 100116},
	{"COUNTFILES", 10, 100117},
	{"HONORE", 6, 100118},
	{"SUMA", 4, 100119},
	{"UYAC", 4, 100120},
	{"NGQI", 4, 100121},
	{"MMLE", 4, 100122},
	{"KVAN", 4, 100123},
	{"DFON", 4, 100124},
	{"ZIONISTS", 8, 100125},
	{"STOREFRONTS", 11, 100126},
	{"DAMSEL", 6, 100127},
	{"EUPHRATES", 9, 100128},
	{"SCHOEN", 6, 100129},
	{"UACA", 4, 100130},
	{"LIKN", 4, 100131},
	{"LAMF", 4, 100132},
	{"LADB", 4, 100133},
	{"ETYG", 4, 100134},
	{"ROSSA", 5, 100135},
	{"DUOMO", 5, 100136},
	{"JOSEPHSON", 9, 100137},
	{"PALGHAT", 7, 100138},
	{"ZSERIES", 7, 100139},
	{"BYNUM", 5, 100140},
	{"DECORUM", 7, 100141},
	{"REMEBER", 7, 100142},
	{"HOMMES", 6, 100143},
	{"FOTOGRAFIE", 10, 100144},
	{"CONECT", 6, 100145},
	{"RKAY", 4, 100146},
	{"NLEX", 4, 100147},
	{"GODU", 4, 100148},
	{"DHAG", 4, 100149},
	{"CDIF", 4, 100150},
	{"NONDURABLE", 10, 100151},
	{"TAFFETA", 7, 100152},
	{"BARBELLS", 8, 100153},
	{"SPOILING", 8, 100154},
	{"IUPAC", 5, 100155},
	{"ATIONS", 6, 100156},
	{"CROSSLEY", 8, 100157},
	{"SYNDICATES", 10, 100158},
	{"DETRITUS", 8, 100159},
	{"GALACTOSE", 9, 100160},
	{"SIGNIN", 6, 100161},
	{"LAGUARDIA", 9, 100162},
	{"YELLOWING", 9, 100163},
	{"XSCALE", 6, 100164},
	{"SUBMARINER", 10, 100165},
	{"ANACORTES", 9, 100166},
	{"VYDU", 4, 100167},
	{"OXBE", 4, 100168},
	{"MLOR", 4, 100169},
	{"IFFF", 4, 100170},
	{"EWOB", 4, 100171},
	{"DBOE", 4, 100172},
	{"ADZI", 4, 100173},
	{"ROBS", 4, 100174},
	{"BUSTIERS", 8, 100175},
	{"ASSORTMENTS", 11, 100176},
	{"FOTOLOG", 7, 100177},
	{"GISELLE", 7, 100178},
	{"EARTHENWARE", 11, 100179},
	{"DUBE", 4, 100180},
	{"IMPLEMENTERS", 12, 100181},
	{"KUAN", 4, 100182},
	{"PROUST", 6, 100183},
	{"LJAVA", 5, 100184},
	{"VMOV", 4, 100185},
	{"SKSB", 4, 100186},
	{"OGBO", 4, 100187},
	{"MDAI", 4, 100188},
	{"LPAU", 4, 100189},
	{"GAGL", 4, 100190},
	{"EXWO", 4, 100191},
	{"DHOG", 4, 100192},
	{"DAEM", 4, 100193},
	{"PERMLINK", 8, 100194},
	{"INCENDIARY", 10, 100195},
	{"SELINA", 6, 100196},
	{"PICKWICK", 8, 100197},
	{"LENIENT", 7, 100198},
	{"MANF", 4, 100199},
	{"POMPINO", 7, 100200},
	{"DINED", 5, 100201},
	{"SCHLESWIG", 9, 100202},
	{"GRADEBOOK", 9, 100203},
	{"VARM", 4, 100204},
	{"TJAY", 4, 100205},
	{"IDLY", 4, 100206},
	{"FRESHERS", 8, 100207},
	{"POLYSACCHARIDES", 15, 100208},
	{"GMINI", 5, 100209},
	{"ZUID", 4, 100210},
	{"SPORADICALLY", 12, 100211},
	{"SENSU", 5, 100212},
	{"DVDRIP", 6, 100213},
	{"NONTRIVIAL", 10, 100214},
	{"DISINFECTED", 11, 100215},
	{"WCLU", 4, 100216},
	{"UBCU", 4, 100217},
	{"SDAW", 4, 100218},
	{"LAZZ", 4, 100219},
	{"KITB", 4, 100220},
	{"ECFL", 4, 100221},
	{"BOHY", 4, 100222},
	{"AUWH", 4, 100223},
	{"ALUL", 4, 100224},
	{"FREDA", 5, 100225},
	{"ERGEBNISSE", 10, 100226},
	{"ORGANI", 6, 100227},
	{"MBYTE", 5, 100228},
	{"DEVILISH", 8, 100229},
	{"STATIN", 6, 100230},
	{"CFCS", 4, 100231},
	{"RIMMED", 6, 100232},
	{"ASHLEIGH", 8, 100233},
	{"NOLTE", 5, 100234},
	{"MAURESMO", 8, 100235},
	{"SOLOMONS", 8, 100236},
	{"REACHABILITY", 12, 100237},
	{"EMMERSON", 8, 100238},
	{"YSTC", 4, 100239},
	{"ATKR", 4, 100240},
	{"FEEDSTOCK", 9, 100241},
	{"REDISTRIBUTIONS", 15, 100242},
	{"NANOMATERIALS", 13, 100243},
	{"HAEMATOLOGY", 11, 100244},
	{"PROTEOLYTIC", 11, 100245},
	{"ARISTOCRAT", 10, 100246},
	{"JEWLERY", 7, 100247},
	{"SCATHING", 8, 100248},
	{"ZEAR", 4, 100249},
	{"YDWE", 4, 100250},
	{"TJUR", 4, 100251},
	{"OEDB", 4, 100252},
	{"KEGU", 4, 100253},
	{"GVET", 4, 100254},
	{"ARLA", 4, 100255},
	{"MENENDEZ", 8, 100256},
	{"ADDEWID", 7, 100257},
	{"TWINKLING", 9, 100258},
	{"KETAMINE", 8, 100259},
	{"IBARAKI", 7, 100260},
	{"NICHTS", 6, 100261},
	{"PANTOMIME", 9, 100262},
	{"BYPRODUCTS", 10, 100263},
	{"DAMNIT", 6, 100264},
	{"HYPHENS", 7, 100265},
	{"AUTOBAHN", 8, 100266},
	{"FALLUJA", 7, 100267},
	{"WEBSHOP", 7, 100268},
	{"SAUB", 4, 100269},
	{"DRMI", 4, 100270},
	{"ALYB", 4, 100271},
	{"BULGARI", 7, 100272},
	{"EFFLUX", 6, 100273},
	{"CATEYE", 6, 100274},
	{"VARTA", 5, 100275},
	{"FAMILIE", 7, 100276},
	{"POWERLITE", 9, 100277},
	{"LARIMER", 7, 100278},
	{"FMF", 3, 100279},
	{"WANDERINGS", 10, 100280},
	{"ORANG", 5, 100281},
	{"ARNDT", 5, 100282},
	{"TUMC", 4, 100283},
	{"SBEP", 4, 100284},
	{"PARG", 4, 100285},
	{"FFFA", 4, 100286},
	{"BELV", 4, 100287},
	{"WHITCHURCH", 10, 100288},
	{"DISLOCATIONS", 12, 100289},
	{"CAPETOWN", 8, 100290},
	{"ASTAIRE", 7, 100291},
	{"SPORTSCAR", 9, 100292},
	{"COLLEC", 6, 100293},
	{"ARUSHA", 6, 100294},
	{"DECIMATED", 9, 100295},
	{"HIJAB", 5, 100296},
	{"DICKENSON", 9, 100297},
	{"OVERTHROWN", 10, 100298},
	{"PCHO", 4, 100299},
	{"LAMH", 4, 100300},
	{"ICSQ", 4, 100301},
	{"HUGA", 4, 100302},
	{"FTFA", 4, 100303},
	{"CTNU", 4, 100304},
	{"MATSON", 6, 100305},
	{"MAGUS", 5, 100306},
	{"DFX", 3, 100307},
	{"MEDULLA", 7, 100308},
	{"REGRESSIVE", 10, 100309},
	{"MOORED", 6, 100310},
	{"SOCIETE", 7, 100311},
	{"BURKS", 5, 100312},
	{"HORVATH", 7, 100313},
	{"ARCTERYX", 8, 100314},
	{"DALEKS", 6, 100315},
	{"PEERED", 6, 100316},
	{"CORZINE", 7, 100317},
	{"CEDI", 4, 100318},
	{"STEARATE", 8, 100319},
	{"UNINTERRUPTIBLE", 15, 100320},
	{"SUBB", 4, 100321},
	{"REBB", 4, 100322},
	{"OYAD", 4, 100323},
	{"DTUT", 4, 100324},
	{"MICROSITE", 9, 100325},
	{"BORES", 5, 100326},
	{"POOJA", 5, 100327},
	{"TOKAI", 5, 100328},
	{"REGRETTABLE", 11, 100329},
	{"SUPERSYMMETRY", 13, 100330},
	{"WHITTEN", 7, 100331},
	{"PDRO", 4, 100332},
	{"BSLO", 4, 100333},
	{"BAGL", 4, 100334},
	{"STRANGLED", 9, 100335},
	{"BONITO", 6, 100336},
	{"MERI", 4, 100337},
	{"ALLOWTOPICCHANGE", 16, 100338},
	{"DOWNLAOD", 8, 100339},
	{"LIKEPAGES", 9, 100340},
	{"MGLO", 4, 100341},
	{"PPXP", 4, 100342},
	{"DELOREAN", 8, 100343},
	{"POSITANO", 8, 100344},
	{"ALLWAYS", 7, 100345},
	{"UNDERTONES", 10, 100346},
	{"ZEOLITE", 7, 100347},
	{"OBOP", 4, 100348},
	{"LKSP", 4, 100349},
	{"HEXF", 4, 100350},
	{"CASG", 4, 100351},
	{"SUCC", 4, 100352},
	{"SCRAPPY", 7, 100353},
	{"FGDC", 4, 100354},
	{"VLADIVOSTOK", 11, 100355},
	{"PULLEN", 6, 100356},
	{"MAXIMS", 6, 100357},
	{"MARKEY", 6, 100358},
	{"DML", 3, 100359},
	{"CAMISOLES", 9, 100360},
	{"MUYO", 4, 100361},
	{"LEYBOLD", 7, 100362},
	{"XROD", 4, 100363},
	{"PUTL", 4, 100364},
	{"NDEK", 4, 100365},
	{"MOPT", 4, 100366},
	{"MAVO", 4, 100367},
	{"GGIF", 4, 100368},
	{"AWDI", 4, 100369},
	{"STROMAL", 7, 100370},
	{"CAMA", 4, 100371},
	{"SYSUTILS", 8, 100372},
	{"SILEX", 5, 100373},
	{"JMX", 3, 100374},
	{"ENGROSSING", 10, 100375},
	{"FERE", 4, 100376},
	{"JEZEBEL", 7, 100377},
	{"VIREO", 5, 100378},
	{"LETHARGY", 8, 100379},
	{"JIMA", 4, 100380},
	{"KOMM", 4, 100381},
	{"YSKY", 4, 100382},
	{"XIAL", 4, 100383},
	{"WEFF", 4, 100384},
	{"WCUR", 4, 100385},
	{"VIUS", 4, 100386},
	{"UPIF", 4, 100387},
	{"RUZA", 4, 100388},
	{"NALZ", 4, 100389},
	{"FEDG", 4, 100390},
	{"DARH", 4, 100391},
	{"CFOL", 4, 100392},
	{"NAGALAND", 8, 100393},
	{"GYNECOLOGICAL", 13, 100394},
	{"BARRATT", 7, 100395},
	{"CLYDESDALE", 10, 100396},
	{"REXX", 4, 100397},
	{"MAXG", 4, 100398},
	{"LGB", 3, 100399},
	{"PRESCRIBER", 10, 100400},
	{"REVERTS", 7, 100401},
	{"PTYC", 4, 100402},
	{"GJON", 4, 100403},
	{"COSL", 4, 100404},
	{"PURINE", 6, 100405},
	{"COUNTERPUNCH", 12, 100406},
	{"FROLIC", 6, 100407},
	{"NORVASC", 7, 100408},
	{"TRANSFUSIONS", 12, 100409},
	{"MYSQLD", 6, 100410},
	{"LIGHTYEAR", 9, 100411},
	{"AIRTRAN", 7, 100412},
	{"VALLETTA", 8, 100413},
	{"GITES", 5, 100414},
	{"CASEWORK", 8, 100415},
	{"CASSIA", 6, 100416},
	{"LWET", 4, 100417},
	{"FSTL", 4, 100418},
	{"BENM", 4, 100419},
	{"ROYER", 5, 100420},
	{"PAINSTAKING", 11, 100421},
	{"FFIXED", 6, 100422},
	{"LAMINA", 6, 100423},
	{"MITCHAM", 7, 100424},
	{"UMBER", 5, 100425},
	{"SOLARAY", 7, 100426},
	{"ROHDE", 5, 100427},
	{"GOTHS", 5, 100428},
	{"FINALITY", 8, 100429},
	{"BIMINI", 6, 100430},
	{"TOPPLED", 7, 100431},
	{"PAPI", 4, 100432},
	{"MENDING", 7, 100433},
	{"EXCAVATORS", 10, 100434},
	{"AGRESSIVE", 9, 100435},
	{"IXFE", 4, 100436},
	{"GLAP", 4, 100437},
	{"EPFU", 4, 100438},
	{"AKPE", 4, 100439},
	{"WRESTLED", 8, 100440},
	{"HOMECENTER", 10, 100441},
	{"GALLARDO", 8, 100442},
	{"HALLER", 6, 100443},
	{"SCIATICA", 8, 100444},
	{"CZY", 3, 100445},
	{"AREAL", 5, 100446},
	{"SHAKEDOWN", 9, 100447},
	{"ANEURYSMS", 9, 100448},
	{"REZT", 4, 100449},
	{"OGOG", 4, 100450},
	{"CAUCUSES", 8, 100451},
	{"RERUNS", 6, 100452},
	{"SIMMONDS", 8, 100453},
	{"ROMSEY", 6, 100454},
	{"NONLINEARITY", 12, 100455},
	{"PLAZAS", 6, 100456},
	{"HURTFUL", 7, 100457},
	{"OOOPS", 5, 100458},
	{"CHIVAS", 6, 100459},
	{"ALTERNATION", 11, 100460},
	{"TSYL", 4, 100461},
	{"HNGR", 4, 100462},
	{"CUPG", 4, 100463},
	{"BRODERBUND", 10, 100464},
	{"TECHN", 5, 100465},
	{"ASTIGMATISM", 11, 100466},
	{"TURLOCK", 7, 100467},
	{"SEMANA", 6, 100468},
	{"WITNEY", 6, 100469},
	{"RECEDING", 8, 100470},
	{"ATHLONE", 7, 100471},
	{"RUIDOSO", 7, 100472},
	{"KREMER", 6, 100473},
	{"LABAN", 5, 100474},
	{"YDIL", 4, 100475},
	{"WSCL", 4, 100476},
	{"WMOO", 4, 100477},
	{"RYRS", 4, 100478},
	{"PMAI", 4, 100479},
	{"LGOU", 4, 100480},
	{"CONJUGATES", 10, 100481},
	{"RFK", 3, 100482},
	{"NEUEN", 5, 100483},
	{"SALVAR", 6, 100484},
	{"PAIX", 4, 100485},
	{"ANTIDUMPING", 11, 100486},
	{"BOMBERMAN", 9, 100487},
	{"CANDELABRA", 10, 100488},
	{"LEVITTOWN", 9, 100489},
	{"WOFD", 4, 100490},
	{"WDWA", 4, 100491},
	{"BUYW", 4, 100492},
	{"MALFUNCTIONING", 14, 100493},
	{"OUTPOSTS", 8, 100494},
	{"POLYUNSATURATED", 15, 100495},
	{"MILLENNIAL", 10, 100496},
	{"IPASS", 5, 100497},
	{"ROASTS", 6, 100498},
	{"HEMISPHERIC", 11, 100499},
	{"ASYMMETRIES", 11, 100500},
	{"REMI", 4, 100501},
	{"UBOI", 4, 100502},
	{"RAVY", 4, 100503},
	{"IEUP", 4, 100504},
	{"HPUL", 4, 100505},
	{"EWIW", 4, 100506},
	{"DEDQ", 4, 100507},
	{"TREADING", 8, 100508},
	{"HEDWIG", 6, 100509},
	{"DOWNY", 5, 100510},
	{"QUANTITATION", 12, 100511},
	{"ROSSETTI", 8, 100512},
	{"CONFORMED", 9, 100513},
	{"TUMI", 4, 100514},
	{"MICROTUBULES", 12, 100515},
	{"KUDZU", 5, 100516},
	{"BARTS", 5, 100517},
	{"CHARACTERISTICALLY", 18, 100518},
	{"ARIMA", 5, 100519},
	{"EUTELEOSTOMI", 12, 100520},
	{"WEXLER", 6, 100521},
	{"STRAYER", 7, 100522},
	{"VTEC", 4, 100523},
	{"UYCO", 4, 100524},
	{"DSTJ", 4, 100525},
	{"BYSY", 4, 100526},
	{"CANADIEN", 8, 100527},
	{"BABS", 4, 100528},
	{"TREATABLE", 9, 100529},
	{"GEEKZONE", 8, 100530},
	{"BUKOWSKI", 8, 100531},
	{"GOLDSMITHS", 10, 100532},
	{"DEVE", 4, 100533},
	{"ERUPTS", 6, 100534},
	{"COLBURN", 7, 100535},
	{"LISSA", 5, 100536},
	{"WAUT", 4, 100537},
	{"VOCO", 4, 100538},
	{"RNPH", 4, 100539},
	{"PMUC", 4, 100540},
	{"SWARMS", 6, 100541},
	{"COMMUNICA", 9, 100542},
	{"TOROIDAL", 8, 100543},
	{"CARTMAN", 7, 100544},
	{"PUGLIA", 6, 100545},
	{"GEOGRAPHERS", 11, 100546},
	{"WATAUGA", 7, 100547},
	{"SCROLLER", 8, 100548},
	{"SPINNAKER", 9, 100549},
	{"TEMPLATING", 10, 100550},
	{"XTSC", 4, 100551},
	{"RIMH", 4, 100552},
	{"MUML", 4, 100553},
	{"EPHP", 4, 100554},
	{"DDAF", 4, 100555},
	{"AKWE", 4, 100556},
	{"INCINERATORS", 12, 100557},
	{"MOORPARK", 8, 100558},
	{"SOMOS", 5, 100559},
	{"DOCTOROW", 8, 100560},
	{"BIXBY", 5, 100561},
	{"MEGAWATT", 8, 100562},
	{"SUPERUSER", 9, 100563},
	{"NAKAMICHI", 9, 100564},
	{"EVOLUTIONS", 10, 100565},
	{"MINIMISED", 9, 100566},
	{"ESCORTING", 9, 100567},
	{"IRREGULARLY", 11, 100568},
	{"MALMO", 5, 100569},
	{"WPIE", 4, 100570},
	{"SRAF", 4, 100571},
	{"RMGA", 4, 100572},
	{"RDIW", 4, 100573},
	{"IAGU", 4, 100574},
	{"FSOW", 4, 100575},
	{"POITOU", 6, 100576},
	{"CHIVES", 6, 100577},
	{"ORATORY", 7, 100578},
	{"FUSETALK", 8, 100579},
	{"BDB", 3, 100580},
	{"HARVESTERS", 10, 100581},
	{"CONDYLOX", 8, 100582},
	{"WINGNUT", 7, 100583},
	{"SCRUGGS", 7, 100584},
	{"UKEF", 4, 100585},
	{"SSYL", 4, 100586},
	{"NRAJ", 4, 100587},
	{"NDGH", 4, 100588},
	{"KREU", 4, 100589},
	{"KITF", 4, 100590},
	{"CKAV", 4, 100591},
	{"BHER", 4, 100592},
	{"TALKABOUT", 9, 100593},
	{"ALTEZZA", 7, 100594},
	{"MARCIN", 6, 100595},
	{"VELMA", 5, 100596},
	{"EXCITATIONS", 11, 100597},
	{"SHARPEST", 8, 100598},
	{"FCAT", 4, 100599},
	{"PALISADE", 8, 100600},
	{"WLEF", 4, 100601},
	{"SKMI", 4, 100602},
	{"RKSY", 4, 100603},
	{"MBEE", 4, 100604},
	{"ARRW", 4, 100605},
	{"APLY", 4, 100606},
	{"SEPTAL", 6, 100607},
	{"HELGE", 5, 100608},
	{"SPRAINS", 7, 100609},
	{"CORVETTES", 9, 100610},
	{"SLOVENE", 7, 100611},
	{"MOCCASIN", 8, 100612},
	{"CHUANG", 6, 100613},
	{"BURFORD", 7, 100614},
	{"INTRAOPERATIVE", 14, 100615},
	{"CANNOCK", 7, 100616},
	{"HANDER", 6, 100617},
	{"POSTALE", 7, 100618},
	{"YWX", 3, 100619},
	{"LBQ", 3, 100620},
	{"JPV", 3, 100621},
	{"JJV", 3, 100622},
	{"DWZ", 3, 100623},
	{"CORETTA", 7, 100624},
	{"ZZBA", 4, 100625},
	{"XICI", 4, 100626},
	{"WRID", 4, 100627},
	{"RTUM", 4, 100628},
	{"POBO", 4, 100629},
	{"ONRD", 4, 100630},
	{"NCUI", 4, 100631},
	{"EFFT", 4, 100632},
	{"DLYK", 4, 100633},
	{"AWPE", 4, 100634},
	{"LEMUR", 5, 100635},
	{"DAHLGREN", 8, 100636},
	{"GROWLED", 7, 100637},
	{"HUGGIES", 7, 100638},
	{"CGG", 3, 100639},
	{"AUXILIARIES", 11, 100640},
	{"PDUS", 4, 100641},
	{"MICHAUD", 7, 100642},
	{"CIDR", 4, 100643},
	{"ALGOMA", 6, 100644},
	{"USGA", 4, 100645},
	{"DPW", 3, 100646},
	{"APHRODISIAC", 11, 100647},
	{"IVINS", 5, 100648},
	{"WKSH", 4, 100649},
	{"USIR", 4, 100650},
	{"RSUT", 4, 100651},
	{"NZAR", 4, 100652},
	{"REISER", 6, 100653},
	{"BENEFACTORS", 11, 100654},
	{"SAXOPHONIST", 11, 100655},
	{"RESENTED", 8, 100656},
	{"PACM", 4, 100657},
	{"NUXA", 4, 100658},
	{"LPCA", 4, 100659},
	{"GIDA", 4, 100660},
	{"DDYO", 4, 100661},
	{"REPR", 4, 100662},
	{"YNGWIE", 6, 100663},
	{"SCALEFONT", 9, 100664},
	{"OEDD", 4, 100665},
	{"TERSE", 5, 100666},
	{"EGREP", 5, 100667},
	{"WARNOCK", 7, 100668},
	{"MASJID", 6, 100669},
	{"INSISTENT", 9, 100670},
	{"CLIJSTERS", 9, 100671},
	{"ROIX", 4, 100672},
	{"ALMW", 4, 100673},
	{"PEPPERED", 8, 100674},
	{"NEBULAE", 7, 100675},
	{"ABSTENTIONS", 11, 100676},
	{"LIDOCAINE", 9, 100677},
	{"MONOHYDRATE", 11, 100678},
	{"AUTOLOADER", 10, 100679},
	{"STERNE", 6, 100680},
	{"AVEZ", 4, 100681},
	{"INDOMETHACIN", 12, 100682},
	{"VESTAX", 6, 100683},
	{"UTILE", 5, 100684},
	{"BRAK", 4, 100685},
	{"SMILIE", 6, 100686},
	{"DIGITIZER", 9, 100687},
	{"FRIGHTFUL", 9, 100688},
	{"WILLIAMSVILLE", 13, 100689},
	{"TECHMENTOR", 10, 100690},
	{"XMET", 4, 100691},
	{"RNIM", 4, 100692},
	{"REZE", 4, 100693},
	{"PSPU", 4, 100694},
	{"NAMR", 4, 100695},
	{"MSUF", 4, 100696},
	{"LTGR", 4, 100697},
	{"IMKE", 4, 100698},
	{"HLEC", 4, 100699},
	{"ADYJ", 4, 100700},
	{"SUNPAK", 6, 100701},
	{"WAXY", 4, 100702},
	{"TRITE", 5, 100703},
	{"FISTED", 6, 100704},
	{"GENTLER", 7, 100705},
	{"CYSTITIS", 8, 100706},
	{"AUDIOBAHN", 9, 100707},
	{"EDITEUR", 7, 100708},
	{"ANISOU", 6, 100709},
	{"PROFORMA", 8, 100710},
	{"SHARD", 5, 100711},
	{"SUPERCRITICAL", 13, 100712},
	{"INFECTS", 7, 100713},
	{"DILAPIDATED", 11, 100714},
	{"LONGMEADOW", 10, 100715},
	{"QMIK", 4, 100716},
	{"ACFO", 4, 100717},
	{"MAPSERVER", 9, 100718},
	{"SAMIZDATA", 9, 100719},
	{"SCHERRER", 8, 100720},
	{"AVANCE", 6, 100721},
	{"COROA", 5, 100722},
	{"HANKY", 5, 100723},
	{"ZWEMBAD", 7, 100724},
	{"WOLLEN", 6, 100725},
	{"WDW", 3, 100726},
	{"SQUATS", 6, 100727},
	{"GUANAJUATO", 10, 100728},
	{"YRIE", 4, 100729},
	{"XPRI", 4, 100730},
	{"TPAV", 4, 100731},
	{"NKUS", 4, 100732},
	{"GBLI", 4, 100733},
	{"AMPN", 4, 100734},
	{"CAZUZA", 6, 100735},
	{"LIBERTARIANISM", 14, 100736},
	{"NEENAH", 6, 100737},
	{"HALIBURTON", 10, 100738},
	{"TEWKSBURY", 9, 100739},
	{"NICAD", 5, 100740},
	{"NAVSARI", 7, 100741},
	{"PRIJS", 5, 100742},
	{"WYNE", 4, 100743},
	{"VIDY", 4, 100744},
	{"OOPD", 4, 100745},
	{"AULU", 4, 100746},
	{"OPPENHEIM", 9, 100747},
	{"PROLAPSE", 8, 100748},
	{"DELA", 4, 100749},
	{"STUBBY", 6, 100750},
	{"KILLSWITCH", 10, 100751},
	{"EVANGELISTIC", 12, 100752},
	{"MDK", 3, 100753},
	{"LUGO", 4, 100754},
	{"XFIRE", 5, 100755},
	{"SIXPENCE", 8, 100756},
	{"ENERGETICS", 10, 100757},
	{"YBIK", 4, 100758},
	{"WAGI", 4, 100759},
	{"SMEF", 4, 100760},
	{"KUNK", 4, 100761},
	{"VISTO", 5, 100762},
	{"IMPALED", 7, 100763},
	{"FORAYS", 6, 100764},
	{"CHARON", 6, 100765},
	{"CONIFEROUS", 10, 100766},
	{"FWIW", 4, 100767},
	{"PHOSPHATIDYLINOSITOL", 20, 100768},
	{"TASCO", 5, 100769},
	{"SIZZIX", 6, 100770},
	{"SICKLY", 6, 100771},
	{"FLANKS", 6, 100772},
	{"LBYB", 4, 100773},
	{"FYWI", 4, 100774},
	{"FTTR", 4, 100775},
	{"GRIFFEY", 7, 100776},
	{"NANETTE", 7, 100777},
	{"WHITBREAD", 9, 100778},
	{"PAVIA", 5, 100779},
	{"SERVERNAME", 10, 100780},
	{"ANGLOINFO", 9, 100781},
	{"BITWISE", 7, 100782},
	{"VOLUSION", 8, 100783},
	{"STRATOS", 7, 100784},
	{"BLOSXOM", 7, 100785},
	{"INEXPLICABLY", 12, 100786},
	{"WALDMAN", 7, 100787},
	{"SMUM", 4, 100788},
	{"HUPI", 4, 100789},
	{"FMRA", 4, 100790},
	{"BYYA", 4, 100791},
	{"BELR", 4, 100792},
	{"KLV", 3, 100793},
	{"CANANDAIGUA", 11, 100794},
	{"CURBED", 6, 100795},
	{"RETEST", 6, 100796},
	{"EFFICACIOUS", 11, 100797},
	{"PHILANTHROPIST", 14, 100798},
	{"CHLORAMPHENICOL", 15, 100799},
	{"THADDEUS", 8, 100800},
	{"PAYSITES", 8, 100801},
	{"REPAIRER", 8, 100802},
	{"DIESELS", 7, 100803},
	{"ARGENTINEAN", 11, 100804},
	{"JOOST", 5, 100805},
	{"YLIZ", 4, 100806},
	{"ETCB", 4, 100807},
	{"AJPU", 4, 100808},
	{"CONVINCES", 9, 100809},
	{"KEIL", 4, 100810},
	{"BANJOS", 6, 100811},
	{"MYREGALO", 8, 100812},
	{"EXPERTPAGES", 11, 100813},
	{"GEODESY", 7, 100814},
	{"PFISTER", 7, 100815},
	{"KIDDY", 5, 100816},
	{"BIRCHWOOD", 9, 100817},
	{"FORMANCE", 8, 100818},
	{"VALUERS", 7, 100819},
	{"YAKUMO", 6, 100820},
	{"XTCH", 4, 100821},
	{"INNUENDO", 8, 100822},
	{"BABADO", 6, 100823},
	{"ASANTE", 6, 100824},
	{"KASPAROV", 8, 100825},
	{"PITFALL", 7, 100826},
	{"ATTENUATOR", 10, 100827},
	{"REDE", 4, 100828},
	{"HERSTELLER", 10, 100829},
	{"IMMUNO", 6, 100830},
	{"POLYSACCHARIDE", 14, 100831},
	{"SUNTRUST", 8, 100832},
	{"SYMPLECTIC", 10, 100833},
	{"OUIL", 4, 100834},
	{"LRYI", 4, 100835},
	{"LOSL", 4, 100836},
	{"KKEI", 4, 100837},
	{"SELIGMAN", 8, 100838},
	{"SUPERHIGHWAY", 12, 100839},
	{"LOMBARDO", 8, 100840},
	{"DISSERVICE", 10, 100841},
	{"MINDER", 6, 100842},
	{"ORATOR", 6, 100843},
	{"CLELAND", 7, 100844},
	{"HOSTWAY", 7, 100845},
	{"MBITS", 5, 100846},
	{"GROVELAND", 9, 100847},
	{"PIEL", 4, 100848},
	{"PICKARD", 7, 100849},
	{"ASSESSABLE", 10, 100850},
	{"PINATA", 6, 100851},
	{"PHOTOCOPIED", 11, 100852},
	{"MOPEDS", 6, 100853},
	{"LMBA", 4, 100854},
	{"LAIC", 4, 100855},
	{"FFTI", 4, 100856},
	{"BOXH", 4, 100857},
	{"BUMBLEBEE", 9, 100858},
	{"MCCLOSKEY", 9, 100859},
	{"DIGICAMS", 8, 100860},
	{"BIOMECHANICAL", 13, 100861},
	{"SOUTHWELL", 9, 100862},
	{"WESTVILLE", 9, 100863},
	{"CERRITO", 7, 100864},
	{"YRTL", 4, 100865},
	{"SSKU", 4, 100866},
	{"RDGU", 4, 100867},
	{"HMYP", 4, 100868},
	{"FCEA", 4, 100869},
	{"DNTQ", 4, 100870},
	{"ROPA", 4, 100871},
	{"FARRINGTON", 10, 100872},
	{"MAJESCO", 7, 100873},
	{"HARLAND", 7, 100874},
	{"FRIENDE", 7, 100875},
	{"HIGHLIGHTER", 11, 100876},
	{"SENCE", 5, 100877},
	{"MALACHITE", 9, 100878},
	{"TALBOTT", 7, 100879},
	{"KIRKLEES", 8, 100880},
	{"YUPP", 4, 100881},
	{"RAOU", 4, 100882},
	{"ODKN", 4, 100883},
	{"NCAF", 4, 100884},
	{"KAYW", 4, 100885},
	{"JOPL", 4, 100886},
	{"STEPPE", 6, 100887},
	{"WAYLON", 6, 100888},
	{"THORNDIKE", 9, 100889},
	{"PLOWED", 6, 100890},
	{"SIRES", 5, 100891},
	{"FEATHERWEIGHT", 13, 100892},
	{"SHISHI", 6, 100893},
	{"TARY", 4, 100894},
	{"INTRICATELY", 11, 100895},
	{"TRANSGRESSIONS", 14, 100896},
	{"LINGERS", 7, 100897},
	{"BCB", 3, 100898},
	{"QUITMAN", 7, 100899},
	{"SHATTUCK", 8, 100900},
	{"URKM", 4, 100901},
	{"TLOB", 4, 100902},
	{"SUGL", 4, 100903},
	{"RBUG", 4, 100904},
	{"ORGM", 4, 100905},
	{"OGAZ", 4, 100906},
	{"NUMC", 4, 100907},
	{"MRDA", 4, 100908},
	{"MBOJ", 4, 100909},
	{"LYUT", 4, 100910},
	{"LBYW", 4, 100911},
	{"FFJO", 4, 100912},
	{"DIGITIZE", 8, 100913},
	{"ROTHENBERG", 10, 100914},
	{"BLOCKBUSTERS", 12, 100915},
	{"TANGLEWOOD", 10, 100916},
	{"SUPERGRASS", 10, 100917},
	{"KERB", 4, 100918},
	{"EULESS", 6, 100919},
	{"SEMIOTICS", 9, 100920},
	{"ELLY", 4, 100921},
	{"PUBURL", 6, 100922},
	{"VILH", 4, 100923},
	{"UIZZ", 4, 100924},
	{"NAUB", 4, 100925},
	{"DYPI", 4, 100926},
	{"SMOTHERING", 10, 100927},
	{"TOMORROWS", 9, 100928},
	{"ONLIN", 5, 100929},
	{"KDM", 3, 100930},
	{"FUTURO", 6, 100931},
	{"VERSAND", 7, 100932},
	{"RISULTATI", 9, 100933},
	{"GUYD", 4, 100934},
	{"GNEU", 4, 100935},
	{"EZEB", 4, 100936},
	{"ATTACHURL", 9, 100937},
	{"DRIFTERS", 8, 100938},
	{"MCCUTCHEON", 10, 100939},
	{"ENCAMPMENT", 10, 100940},
	{"BIOWARE", 7, 100941},
	{"CALAMARI", 8, 100942},
	{"LEMPIRA", 7, 100943},
	{"ROQUE", 5, 100944},
	{"WORDFAST", 8, 100945},
	{"PROPHESY", 8, 100946},
	{"SONGTEXTE", 9, 100947},
	{"RECAST", 6, 100948},
	{"MASSAPEQUA", 10, 100949},
	{"VONW", 4, 100950},
	{"UITU", 4, 100951},
	{"PBLO", 4, 100952},
	{"OAKW", 4, 100953},
	{"LWAG", 4, 100954},
	{"LTFA", 4, 100955},
	{"ELPN", 4, 100956},
	{"EBEW", 4, 100957},
	{"BURSAR", 6, 100958},
	{"ZAAR", 4, 100959},
	{"MISREPRESENTATIONS", 18, 100960},
	{"DOWEL", 5, 100961},
	{"INTERDICTION", 12, 100962},
	{"PERCENTS", 8, 100963},
	{"CHASTE", 6, 100964},
	{"BARDS", 5, 100965},
	{"BURGAS", 6, 100966},
	{"HRYA", 4, 100967},
	{"AFTG", 4, 100968},
	{"BESTIAL", 7, 100969},
	{"RESTOCK", 7, 100970},
	{"KEEPIN", 6, 100971},
	{"TORX", 4, 100972},
	{"MONTBLANC", 9, 100973},
	{"JARROD", 6, 100974},
	{"EXPN", 4, 100975},
	{"PANR", 4, 100976},
	{"KINU", 4, 100977},
	{"AORP", 4, 100978},
	{"ADENYLATE", 9, 100979},
	{"NEUF", 4, 100980},
	{"LINEUPS", 7, 100981},
	{"IRRADIANCE", 10, 100982},
	{"CULP", 4, 100983},
	{"EXEL", 4, 100984},
	{"HINKLEY", 7, 100985},
	{"CROWTHER", 8, 100986},
	{"BUDDHAS", 7, 100987},
	{"OOZING", 6, 100988},
	{"MUNROE", 6, 100989},
	{"GSKE", 4, 100990},
	{"FTGR", 4, 100991},
	{"ERDD", 4, 100992},
	{"DERZ", 4, 100993},
	{"JETDIRECT", 9, 100994},
	{"IMMOBILIER", 10, 100995},
	{"POLARIZING", 10, 100996},
	{"SEVIERVILLE", 11, 100997},
	{"VICENZA", 7, 100998},
	{"RICHELIEU", 9, 100999},
	{"CURD", 4, 101000},
	{"BOOKISH", 7, 101001},
	{"SUBDUE", 6, 101002},
	{"RAKING", 6, 101003},
	{"SEGER", 5, 101004},
	{"MAGL", 4, 101005},
	{"AKIW", 4, 101006},
	{"DENOUNCING", 10, 101007},
	{"TRAUMATIZED", 11, 101008},
	{"ALLRED", 6, 101009},
	{"SUCCESFUL", 9, 101010},
	{"ASCERTAINING", 12, 101011},
	{"MYTHOMAS", 8, 101012},
	{"GILLIES", 7, 101013},
	{"TCPIP", 5, 101014},
	{"PEPIN", 5, 101015},
	{"HANNES", 6, 101016},
	{"SYMONS", 6, 101017},
	{"ZBUT", 4, 101018},
	{"VEAK", 4, 101019},
	{"OXAL", 4, 101020},
	{"LUGU", 4, 101021},
	{"FISHFINDER", 10, 101022},
	{"SCIM", 4, 101023},
	{"ALLIANT", 7, 101024},
	{"PREVIEWED", 9, 101025},
	{"STAGS", 5, 101026},
	{"MODACO", 6, 101027},
	{"HOGUE", 5, 101028},
	{"MEADOWBROOK", 11, 101029},
	{"BEAUREGARD", 10, 101030},
	{"MENTATION", 9, 101031},
	{"CHATTAHOOCHEE", 13, 101032},
	{"UADF", 4, 101033},
	{"TYKA", 4, 101034},
	{"RTVO", 4, 101035},
	{"CROG", 4, 101036},
	{"BOWYER", 6, 101037},
	{"VOLUNTEERMATCH", 14, 101038},
	{"VITTORIA", 8, 101039},
	{"CAPI", 4, 101040},
	{"JJJ", 3, 101041},
	{"SOLDERED", 8, 101042},
	{"XPOWER", 6, 101043},
	{"PYLON", 5, 101044},
	{"COMMISION", 9, 101045},
	{"PRIVATEER", 9, 101046},
	{"OFICINA", 7, 101047},
	{"NUCH", 4, 101048},
	{"AMWR", 4, 101049},
	{"ALTF", 4, 101050},
	{"MILLY", 5, 101051},
	{"RATLIFF", 7, 101052},
	{"GROMMET", 7, 101053},
	{"MINICLIP", 8, 101054},
	{"KIRKUK", 6, 101055},
	{"WAYNESVILLE", 11, 101056},
	{"MANIPULATIVES", 13, 101057},
	{"NEONATES", 8, 101058},
	{"HELLENISTIC", 11, 101059},
	{"UXHA", 4, 101060},
	{"MRWA", 4, 101061},
	{"VICARIOUS", 9, 101062},
	{"RWY", 3, 101063},
	{"RUCKUS", 6, 101064},
	{"TRAVERSES", 9, 101065},
	{"BELVOIR", 7, 101066},
	{"SEEDY", 5, 101067},
	{"CENTIMETRES", 11, 101068},
	{"BOARDGAME", 9, 101069},
	{"SPASS", 5, 101070},
	{"ASSERTIVENESS", 13, 101071},
	{"RAINCOAT", 8, 101072},
	{"BARF", 4, 101073},
	{"URLAUB", 6, 101074},
	{"BOOKMARKLET", 11, 101075},
	{"PERSONABLE", 10, 101076},
	{"XTCA", 4, 101077},
	{"IMYE", 4, 101078},
	{"GMAA", 4, 101079},
	{"VIDEOCONFERENCE", 15, 101080},
	{"IMPLOSION", 9, 101081},
	{"MESSAGELABS", 11, 101082},
	{"VIDEOLAN", 8, 101083},
	{"BELTSVILLE", 10, 101084},
	{"ADAP", 4, 101085},
	{"RKTW", 4, 101086},
	{"OLTM", 4, 101087},
	{"IDJI", 4, 101088},
	{"DHEY", 4, 101089},
	{"CUEW", 4, 101090},
	{"CHYW", 4, 101091},
	{"BOFP", 4, 101092},
	{"SCAMMERS", 8, 101093},
	{"JEANINE", 7, 101094},
	{"USERMIN", 7, 101095},
	{"STURT", 5, 101096},
	{"XCODE", 5, 101097},
	{"WETNESS", 7, 101098},
	{"LEXICO", 6, 101099},
	{"MEGALITHIC", 10, 101100},
	{"STAUFFER", 8, 101101},
	{"PTYH", 4, 101102},
	{"OPOM", 4, 101103},
	{"INMM", 4, 101104},
	{"CBEG", 4, 101105},
	{"STRADDLE", 8, 101106},
	{"BINDERY", 7, 101107},
	{"IMBEDDED", 8, 101108},
	{"EHUD", 4, 101109},
	{"COUNTERPARTY", 12, 101110},
	{"PONTING", 7, 101111},
	{"BYCATCH", 7, 101112},
	{"ELYSIUM", 7, 101113},
	{"QUENCHED", 8, 101114},
	{"TANTRUM", 7, 101115},
	{"MUME", 4, 101116},
	{"MATD", 4, 101117},
	{"EUMF", 4, 101118},
	{"CUTU", 4, 101119},
	{"AHUB", 4, 101120},
	{"INFILE", 6, 101121},
	{"CONIFERS", 8, 101122},
	{"MPICH", 5, 101123},
	{"MENEZES", 7, 101124},
	{"JUICED", 6, 101125},
	{"ANTITHESIS", 10, 101126},
	{"ARTHROPODS", 10, 101127},
	{"ROBBEN", 6, 101128},
	{"MCCLOUD", 7, 101129},
	{"UFUS", 4, 101130},
	{"OWGL", 4, 101131},
	{"KOSC", 4, 101132},
	{"KOPT", 4, 101133},
	{"GSYN", 4, 101134},
	{"GEKE", 4, 101135},
	{"AKDI", 4, 101136},
	{"FLEXING", 7, 101137},
	{"ENVOYER", 7, 101138},
	{"WQX", 3, 101139},
	{"RVQ", 3, 101140},
	{"JDZ", 3, 101141},
	{"GZL", 3, 101142},
	{"FWX", 3, 101143},
	{"FQD", 3, 101144},
	{"ENDCHAR", 7, 101145},
	{"TRACERS", 7, 101146},
	{"MAZUR", 5, 101147},
	{"GAUTAM", 6, 101148},
	{"TIMBUKTU", 8, 101149},
	{"NONNEGATIVE", 11, 101150},
	{"YKEI", 4, 101151},
	{"YGOB", 4, 101152},
	{"UISG", 4, 101153},
	{"TIFC", 4, 101154},
	{"SHMY", 4, 101155},
	{"OPMF", 4, 101156},
	{"IPEV", 4, 101157},
	{"DTUM", 4, 101158},
	{"DRCH", 4, 101159},
	{"MLDONKEY", 8, 101160},
	{"COULSON", 7, 101161},
	{"WARBURG", 7, 101162},
	{"POLYCHLORINATED", 15, 101163},
	{"AWAKENS", 7, 101164},
	{"AMOEBA", 6, 101165},
	{"CPIO", 4, 101166},
	{"WUTHERING", 9, 101167},
	{"SONORAN", 7, 101168},
	{"ACCENTUATE", 10, 101169},
	{"UTIJ", 4, 101170},
	{"URIK", 4, 101171},
	{"FFOS", 4, 101172},
	{"DOSB", 4, 101173},
	{"VPX", 3, 101174},
	{"DUVETS", 6, 101175},
	{"CASEIROS", 8, 101176},
	{"LIBPNG", 6, 101177},
	{"BACHARACH", 9, 101178},
	{"NEODYMIUM", 9, 101179},
	{"DSPS", 4, 101180},
	{"SQUANDERED", 10, 101181},
	{"SORTIE", 6, 101182},
	{"CHARLEVOIX", 10, 101183},
	{"MALCOM", 6, 101184},
	{"YNNW", 4, 101185},
	{"XTHW", 4, 101186},
	{"TGAZ", 4, 101187},
	{"EPWE", 4, 101188},
	{"ARLU", 4, 101189},
	{"EVISU", 5, 101190},
	{"ALTERNATORS", 11, 101191},
	{"CARET", 5, 101192},
	{"SHIPWRECKS", 10, 101193},
	{"MJD", 3, 101194},
	{"WITHAL", 6, 101195},
	{"LWB", 3, 101196},
	{"CVB", 3, 101197},
	{"STATISTIQUES", 12, 101198},
	{"UPEL", 4, 101199},
	{"EYELASHES", 9, 101200},
	{"COLLIERS", 8, 101201},
	{"LOOKALIKE", 9, 101202},
	{"LAILA", 5, 101203},
	{"COREQUISITE", 11, 101204},
	{"GEHRIG", 6, 101205},
	{"MINUTEN", 7, 101206},
	{"METHOXY", 7, 101207},
	{"NEOPLASIA", 9, 101208},
	{"SHIBUYA", 7, 101209},
	{"BARMAN", 6, 101210},
	{"TILDEN", 6, 101211},
	{"WISG", 4, 101212},
	{"UYLI", 4, 101213},
	{"RDYC", 4, 101214},
	{"LKEP", 4, 101215},
	{"DYBL", 4, 101216},
	{"DREX", 4, 101217},
	{"ADIW", 4, 101218},
	{"PLETTENBERG", 11, 101219},
	{"CKY", 3, 101220},
	{"WEITZMAN", 8, 101221},
	{"BLINDFOLD", 9, 101222},
	{"BROMINE", 7, 101223},
	{"TCLUG", 5, 101224},
	{"RAMPART", 7, 101225},
	{"POSSESSIVE", 10, 101226},
	{"IMMUNOASSAY", 11, 101227},
	{"EUSTATIUS", 9, 101228},
	{"FELDSPAR", 8, 101229},
	{"FACADES", 7, 101230},
	{"UTTARANCHAL", 11, 101231},
	{"SSYD", 4, 101232},
	{"RBOI", 4, 101233},
	{"IXLA", 4, 101234},
	{"FSQM", 4, 101235},
	{"BBSW", 4, 101236},
	{"MAHARAJA", 8, 101237},
	{"IDEALIST", 8, 101238},
	{"VECTREX", 7, 101239},
	{"GLUCOCORTICOID", 14, 101240},
	{"COMPENSATES", 11, 101241},
	{"CONSTABLES", 10, 101242},
	{"PUSM", 4, 101243},
	{"PCRI", 4, 101244},
	{"NLEM", 4, 101245},
	{"MOURNS", 6, 101246},
	{"SOLIDIFIED", 10, 101247},
	{"CURA", 4, 101248},
	{"JOHANSON", 8, 101249},
	{"FERRIC", 6, 101250},
	{"CONCEIT", 7, 101251},
	{"NEEDFUL", 7, 101252},
	{"TOPICLIST", 9, 101253},
	{"LFC", 3, 101254},
	{"CAMPAIGNER", 10, 101255},
	{"AIRCON", 6, 101256},
	{"LOCUSTS", 7, 101257},
	{"ROUNDTABLES", 11, 101258},
	{"THATCH", 6, 101259},
	{"KLUN", 4, 101260},
	{"JIMF", 4, 101261},
	{"ILMN", 4, 101262},
	{"DEUC", 4, 101263},
	{"CHMC", 4, 101264},
	{"MARTIJN", 7, 101265},
	{"BAMBINI", 7, 101266},
	{"CAIXA", 5, 101267},
	{"EMBOSS", 6, 101268},
	{"DRB", 3, 101269},
	{"CLARIDGE", 8, 101270},
	{"STRATE", 6, 101271},
	{"MEIOSIS", 7, 101272},
	{"DIVERSIFYING", 12, 101273},
	{"UGWI", 4, 101274},
	{"OWLF", 4, 101275},
	{"MYTU", 4, 101276},
	{"LUMC", 4, 101277},
	{"KELB", 4, 101278},
	{"ARYQ", 4, 101279},
	{"ACWI", 4, 101280},
	{"REBATEREBATE", 12, 101281},
	{"COELHO", 6, 101282},
	{"INADEQUACIES", 12, 101283},
	{"ESPECIALES", 10, 101284},
	{"CAPPADOCIA", 10, 101285},
	{"WEATHERS", 8, 101286},
	{"CYTOSPORT", 9, 101287},
	{"BACKENDS", 8, 101288},
	{"ZENL", 4, 101289},
	{"RRUR", 4, 101290},
	{"OBYD", 4, 101291},
	{"MPDO", 4, 101292},
	{"LLKA", 4, 101293},
	{"LIOL", 4, 101294},
	{"IDIU", 4, 101295},
	{"DUMI", 4, 101296},
	{"INSEAD", 6, 101297},
	{"PARRA", 5, 101298},
	{"RIVERHEAD", 9, 101299},
	{"BODENSEE", 8, 101300},
	{"DOTY", 4, 101301},
	{"SUVA", 4, 101302},
	{"GRUNTS", 6, 101303},
	{"THICKET", 7, 101304},
	{"SPLENDA", 7, 101305},
	{"PILKINGTON", 10, 101306},
	{"MARANATHA", 9, 101307},
	{"DEPRAVED", 8, 101308},
	{"YODO", 4, 101309},
	{"SYPH", 4, 101310},
	{"NROV", 4, 101311},
	{"LIKH", 4, 101312},
	{"HUTCHINGS", 9, 101313},
	{"RESPIR", 6, 101314},
	{"CONTINENCE", 10, 101315},
	{"CHAMBERSBURG", 12, 101316},
	{"LECS", 4, 101317},
	{"PUPPETRY", 8, 101318},
	{"HYPOTHALAMIC", 12, 101319},
	{"HMUN", 4, 101320},
	{"HAUP", 4, 101321},
	{"TREATISES", 9, 101322},
	{"RENSEIGNEMENTS", 14, 101323},
	{"PRAGA", 5, 101324},
	{"MELTZER", 7, 101325},
	{"KOMPLETT", 8, 101326},
	{"SAUVAGE", 7, 101327},
	{"POLYGONAL", 9, 101328},
	{"NORCENT", 7, 101329},
	{"PRYING", 6, 101330},
	{"RASCALS", 7, 101331},
	{"LILLEY", 6, 101332},
	{"STOPOVER", 8, 101333},
	{"WOFN", 4, 101334},
	{"UKSI", 4, 101335},
	{"SGIG", 4, 101336},
	{"OUAF", 4, 101337},
	{"KMEE", 4, 101338},
	{"BCTE", 4, 101339},
	{"AMWAY", 5, 101340},
	{"UDC", 3, 101341},
	{"KOPPEL", 6, 101342},
	{"BLIP", 4, 101343},
	{"BAGWELL", 7, 101344},
	{"MULTIVITAMINS", 13, 101345},
	{"VOYAGEURS", 9, 101346},
	{"BOXSCORE", 8, 101347},
	{"LIBIBERTY", 9, 101348},
	{"MAEDA", 5, 101349},
	{"UGIA", 4, 101350},
	{"RDPH", 4, 101351},
	{"RBAH", 4, 101352},
	{"STOCKER", 7, 101353},
	{"DREYER", 6, 101354},
	{"POTHOLES", 8, 101355},
	{"NANKING", 7, 101356},
	{"RUDELY", 6, 101357},
	{"APPARTMENTS", 11, 101358},
	{"RENDITIONS", 10, 101359},
	{"VICHY", 5, 101360},
	{"HAMMERSTEIN", 11, 101361},
	{"RIMF", 4, 101362},
	{"NYOC", 4, 101363},
	{"EVYI", 4, 101364},
	{"BLOEMFONTEIN", 12, 101365},
	{"WEATHERBUG", 10, 101366},
	{"GASTROESOPHAGEAL", 16, 101367},
	{"ICKY", 4, 101368},
	{"WEEPS", 5, 101369},
	{"SONNENSTUDIO", 12, 101370},
	{"KICHLER", 7, 101371},
	{"MACIEJ", 6, 101372},
	{"BERLITZ", 7, 101373},
	{"DEPLORABLE", 10, 101374},
	{"SMACKING", 8, 101375},
	{"WOAP", 4, 101376},
	{"UEJU", 4, 101377},
	{"PTPA", 4, 101378},
	{"GNAV", 4, 101379},
	{"CITD", 4, 101380},
	{"ANKJ", 4, 101381},
	{"NOZZE", 5, 101382},
	{"REINTRODUCED", 12, 101383},
	{"KATAMARI", 8, 101384},
	{"AGGRAVATE", 9, 101385},
	{"PORTOBELLO", 10, 101386},
	{"GRAU", 4, 101387},
	{"ARIZ", 4, 101388},
	{"PRODUTOS", 8, 101389},
	{"BROADLEAF", 9, 101390},
	{"QUOTH", 5, 101391},
	{"TAMPATOWERSHOTEL", 16, 101392},
	{"GRETEL", 6, 101393},
	{"CRAS", 4, 101394},
	{"ICONOGRAPHY", 11, 101395},
	{"TYMERS", 6, 101396},
	{"OBBO", 4, 101397},
	{"LUIG", 4, 101398},
	{"GYEN", 4, 101399},
	{"EJUG", 4, 101400},
	{"USCA", 4, 101401},
	{"TRYPANOSOMA", 11, 101402},
	{"SUKI", 4, 101403},
	{"AMERIHOST", 9, 101404},
	{"SNOWSTORM", 9, 101405},
	{"EUSTIS", 6, 101406},
	{"NEWBERG", 7, 101407},
	{"VATR", 4, 101408},
	{"PEEW", 4, 101409},
	{"LACUNA", 6, 101410},
	{"FREEONES", 8, 101411},
	{"LUTEIN", 6, 101412},
	{"POSTGRADUATES", 13, 101413},
	{"CHIM", 4, 101414},
	{"DOANE", 5, 101415},
	{"SOLVABLE", 8, 101416},
	{"GARRARD", 7, 101417},
	{"DKOCHER", 7, 101418},
	{"FKP", 3, 101419},
	{"COMBE", 5, 101420},
	{"XPF", 3, 101421},
	{"INTENSIFIES", 11, 101422},
	{"BIRDIES", 7, 101423},
	{"OEBU", 4, 101424},
	{"LPHW", 4, 101425},
	{"DSYL", 4, 101426},
	{"ARAMARK", 7, 101427},
	{"QUEERS", 6, 101428},
	{"PATRIK", 6, 101429},
	{"NECKTIES", 8, 101430},
	{"STRIKETHROUGH", 13, 101431},
	{"CHAMBRES", 8, 101432},
	{"RAWSON", 6, 101433},
	{"LEVELLED", 8, 101434},
	{"INCESSANTLY", 11, 101435},
	{"SORPTION", 8, 101436},
	{"SYLI", 4, 101437},
	{"NKMU", 4, 101438},
	{"MAGM", 4, 101439},
	{"GMIK", 4, 101440},
	{"BOONVILLE", 9, 101441},
	{"DEPRESSANT", 10, 101442},
	{"DEGRASSI", 8, 101443},
	{"ALLAAH", 6, 101444},
	{"AFSCME", 6, 101445},
	{"COCINA", 6, 101446},
	{"LEGRAND", 7, 101447},
	{"APRES", 5, 101448},
	{"DISMUTASE", 9, 101449},
	{"LIBAPACHE", 9, 101450},
	{"RADIANS", 7, 101451},
	{"BALCH", 5, 101452},
	{"BARSTOOLS", 9, 101453},
	{"TPOC", 4, 101454},
	{"SGAB", 4, 101455},
	{"POTP", 4, 101456},
	{"OAKP", 4, 101457},
	{"MBOM", 4, 101458},
	{"KYSP", 4, 101459},
	{"IELF", 4, 101460},
	{"HLUN", 4, 101461},
	{"GBYE", 4, 101462},
	{"FEDD", 4, 101463},
	{"DMCK", 4, 101464},
	{"AYOL", 4, 101465},
	{"FLARING", 7, 101466},
	{"CORMORANT", 9, 101467},
	{"BLILEY", 6, 101468},
	{"PEDIGREES", 9, 101469},
	{"SEAFARERS", 9, 101470},
	{"YANKED", 6, 101471},
	{"WAIMEA", 6, 101472},
	{"MICROTECH", 9, 101473},
	{"NEUES", 5, 101474},
	{"TVSC", 4, 101475},
	{"LOPL", 4, 101476},
	{"KVOT", 4, 101477},
	{"IBEM", 4, 101478},
	{"BONB", 4, 101479},
	{"LANGTON", 7, 101480},
	{"NATCHITOCHES", 12, 101481},
	{"PSERVER", 7, 101482},
	{"MBP", 3, 101483},
	{"DEMPSTER", 8, 101484},
	{"SWITCHGEAR", 10, 101485},
	{"SUSQ", 4, 101486},
	{"PSUB", 4, 101487},
	{"OPGE", 4, 101488},
	{"FCAV", 4, 101489},
	{"EEKJ", 4, 101490},
	{"DYTI", 4, 101491},
	{"AQCO", 4, 101492},
	{"ACWH", 4, 101493},
	{"BORDELLE", 8, 101494},
	{"STEPHENVILLE", 12, 101495},
	{"MATTINGLY", 9, 101496},
	{"CHEMOTHER", 9, 101497},
	{"STARGAZER", 9, 101498},
	{"CYTOGENETIC", 11, 101499},
	{"PRELOAD", 7, 101500},
	{"NUTRITIONALS", 12, 101501},
	{"CDK", 3, 101502},
	{"TERRATEC", 8, 101503},
	{"TKOR", 4, 101504},
	{"OLLL", 4, 101505},
	{"OIDU", 4, 101506},
	{"HIRR", 4, 101507},
	{"EKBO", 4, 101508},
	{"DVDC", 4, 101509},
	{"MINTED", 6, 101510},
	{"GERSHON", 7, 101511},
	{"MIDNITE", 7, 101512},
	{"BASEBALLS", 9, 101513},
	{"DITTY", 5, 101514},
	{"KULA", 4, 101515},
	{"KIRTLAND", 8, 101516},
	{"DFC", 3, 101517},
	{"JEVO", 4, 101518},
	{"FYAL", 4, 101519},
	{"PESTILENCE", 10, 101520},
	{"ANTHRO", 6, 101521},
	{"RAPIDE", 6, 101522},
	{"COPPELL", 7, 101523},
	{"THOROUGHFARE", 12, 101524},
	{"SKIFF", 5, 101525},
	{"BUDE", 4, 101526},
	{"TRIPURA", 7, 101527},
	{"SPREADERS", 9, 101528},
	{"JDEV", 4, 101529},
	{"YDUC", 4, 101530},
	{"WSGO", 4, 101531},
	{"WNEM", 4, 101532},
	{"UBUS", 4, 101533},
	{"TGLI", 4, 101534},
	{"REPB", 4, 101535},
	{"NYOV", 4, 101536},
	{"HCOW", 4, 101537},
	{"BELLIGERENT", 11, 101538},
	{"LOWCOST", 7, 101539},
	{"IMPEACHED", 9, 101540},
	{"MMD", 3, 101541},
	{"FINGERBOARD", 11, 101542},
	{"DEACONESS", 9, 101543},
	{"MOOSEJAW", 8, 101544},
	{"KOJIMA", 6, 101545},
	{"LECTIN", 6, 101546},
	{"VANF", 4, 101547},
	{"PTPO", 4, 101548},
	{"PSIF", 4, 101549},
	{"PEPL", 4, 101550},
	{"NRUT", 4, 101551},
	{"LKNI", 4, 101552},
	{"HPIR", 4, 101553},
	{"GAJU", 4, 101554},
	{"GUMMY", 5, 101555},
	{"BIODEGRADATION", 14, 101556},
	{"TARTU", 5, 101557},
	{"WARBURTON", 9, 101558},
	{"HIGHT", 5, 101559},
	{"GLOMERULAR", 10, 101560},
	{"ECLIPSED", 8, 101561},
	{"PRESCHOOLER", 11, 101562},
	{"CONSPIRED", 9, 101563},
	{"YLLO", 4, 101564},
	{"UYOR", 4, 101565},
	{"UWRI", 4, 101566},
	{"UORO", 4, 101567},
	{"UMPM", 4, 101568},
	{"LBUC", 4, 101569},
	{"DANJ", 4, 101570},
	{"AUCTIONING", 10, 101571},
	{"CATIONIC", 8, 101572},
	{"SCHULMAN", 8, 101573},
	{"VARIA", 5, 101574},
	{"REBAR", 5, 101575},
	{"CATACOMBS", 9, 101576},
	{"PAPERWEIGHTS", 12, 101577},
	{"PROXIM", 6, 101578},
	{"AGONIZING", 9, 101579},
	{"YNDE", 4, 101580},
	{"UXIS", 4, 101581},
	{"GSEG", 4, 101582},
	{"EIGU", 4, 101583},
	{"DCOB", 4, 101584},
	{"EVEREADY", 8, 101585},
	{"BOTTOMLESS", 10, 101586},
	{"KREME", 5, 101587},
	{"GOLDSTAR", 8, 101588},
	{"ATTRIBUTING", 11, 101589},
	{"TONEY", 5, 101590},
	{"LONDONERS", 9, 101591},
	{"CALISTOGA", 9, 101592},
	{"MOUTHPIECES", 11, 101593},
	{"ZUKA", 4, 101594},
	{"PEZA", 4, 101595},
	{"SNAGLESS", 8, 101596},
	{"TILAPIA", 7, 101597},
	{"FAUT", 4, 101598},
	{"LENEXA", 6, 101599},
	{"TWINHEAD", 8, 101600},
	{"ROGAN", 5, 101601},
	{"SARDIS", 6, 101602},
	{"CANDLEHOLDERS", 13, 101603},
	{"SLOVENSKO", 9, 101604},
	{"NAKANO", 6, 101605},
	{"WNIC", 4, 101606},
	{"RWIV", 4, 101607},
	{"IJAP", 4, 101608},
	{"FYET", 4, 101609},
	{"EXAD", 4, 101610},
	{"AKKE", 4, 101611},
	{"INTERFEROMETRY", 14, 101612},
	{"RHONDDA", 7, 101613},
	{"SATOSHI", 7, 101614},
	{"PRINTPRINT", 10, 101615},
	{"CONCENTRA", 9, 101616},
	{"RAYNE", 5, 101617},
	{"LULLABIES", 9, 101618},
	{"SLASHER", 7, 101619},
	{"DESKTOPLINUX", 12, 101620},
	{"CRITIQUING", 10, 101621},
	{"POLYPEPTIDES", 12, 101622},
	{"ALLEGHANY", 9, 101623},
	{"RTQU", 4, 101624},
	{"POFJ", 4, 101625},
	{"NYMC", 4, 101626},
	{"HYAB", 4, 101627},
	{"EFBU", 4, 101628},
	{"DYRU", 4, 101629},
	{"DDAP", 4, 101630},
	{"ARDQ", 4, 101631},
	{"POUL", 4, 101632},
	{"LIHUE", 5, 101633},
	{"HTMLAREA", 8, 101634},
	{"OXFORDS", 7, 101635},
	{"EXCRUCIATING", 12, 101636},
	{"BROUGH", 6, 101637},
	{"MUNCHKIN", 8, 101638},
	{"PUNCTUAL", 8, 101639},
	{"AUDIOTAPE", 9, 101640},
	{"FUTBOL", 6, 101641},
	{"YDOD", 4, 101642},
	{"UNWR", 4, 101643},
	{"RETROSPECTIVELY", 15, 101644},
	{"TOKIO", 5, 101645},
	{"SLOBODAN", 8, 101646},
	{"SANDEEP", 7, 101647},
	{"RUNAWAYS", 8, 101648},
	{"BONIFACE", 8, 101649},
	{"XPK", 3, 101650},
	{"CONJUNCTIVITIS", 14, 101651},
	{"WACR", 4, 101652},
	{"NGRH", 4, 101653},
	{"LEZO", 4, 101654},
	{"IUSL", 4, 101655},
	{"ASKG", 4, 101656},
	{"WITTER", 6, 101657},
	{"FORKUM", 6, 101658},
	{"DIRECTIONSDIRECTIONS", 20, 101659},
	{"GRAFTED", 7, 101660},
	{"WATERCOURSE", 11, 101661},
	{"CLIMATOLOGICAL", 14, 101662},
	{"COURIC", 6, 101663},
	{"PROPPED", 7, 101664},
	{"BEATON", 6, 101665},
	{"MARGINALISED", 12, 101666},
	{"PROSTHESES", 10, 101667},
	{"BANKSTOWN", 9, 101668},
	{"TELEGRAMS", 9, 101669},
	{"MAUE", 4, 101670},
	{"KFES", 4, 101671},
	{"IRYP", 4, 101672},
	{"PRIVATIZE", 9, 101673},
	{"INTERPHASE", 10, 101674},
	{"FLORSHEIM", 9, 101675},
	{"STAKING", 7, 101676},
	{"PHENYTOIN", 9, 101677},
	{"CONVERSING", 10, 101678},
	{"TURLEY", 6, 101679},
	{"CHIRURGIE", 9, 101680},
	{"TESTABLE", 8, 101681},
	{"BACKTRACKING", 12, 101682},
	{"DIFFERENTIABLE", 14, 101683},
	{"RFUS", 4, 101684},
	{"LKDO", 4, 101685},
	{"KMYT", 4, 101686},
	{"KIMJ", 4, 101687},
	{"BARP", 4, 101688},
	{"SISAL", 5, 101689},
	{"GOODFELLAS", 10, 101690},
	{"CHIX", 4, 101691},
	{"ACETYLENE", 9, 101692},
	{"CALAMITIES", 10, 101693},
	{"BEDOUIN", 7, 101694},
	{"UTEQ", 4, 101695},
	{"UDLO", 4, 101696},
	{"TKRI", 4, 101697},
	{"PHRI", 4, 101698},
	{"OAKB", 4, 101699},
	{"NHUD", 4, 101700},
	{"CMAD", 4, 101701},
	{"YUMI", 4, 101702},
	{"VIENNESE", 8, 101703},
	{"FANCIES", 7, 101704},
	{"PEEVES", 6, 101705},
	{"ACCUSER", 7, 101706},
	{"BALLYMENA", 9, 101707},
	{"COPOLYMERS", 10, 101708},
	{"HEPATOLOGY", 10, 101709},
	{"CLM", 3, 101710},
	{"WSTY", 4, 101711},
	{"KETK", 4, 101712},
	{"HAWW", 4, 101713},
	{"AIMBOT", 6, 101714},
	{"BYSTANDERS", 10, 101715},
	{"MCDATA", 6, 101716},
	{"MAGN", 4, 101717},
	{"CONNOTATION", 11, 101718},
	{"MINOS", 5, 101719},
	{"BOOKABLE", 8, 101720},
	{"NUTONE", 6, 101721},
	{"ALASDAIR", 8, 101722},
	{"YIFO", 4, 101723},
	{"XISP", 4, 101724},
	{"QUIF", 4, 101725},
	{"PEYE", 4, 101726},
	{"MYOT", 4, 101727},
	{"MBOB", 4, 101728},
	{"KEIG", 4, 101729},
	{"IXSP", 4, 101730},
	{"BIEW", 4, 101731},
	{"ALIENATING", 10, 101732},
	{"JAPANEESE", 9, 101733},
	{"FISHERMANS", 10, 101734},
	{"BROKAW", 6, 101735},
	{"ANIMAS", 6, 101736},
	{"CHIPPENHAM", 10, 101737},
	{"ZZIS", 4, 101738},
	{"VEZA", 4, 101739},
	{"OYYO", 4, 101740},
	{"FEJA", 4, 101741},
	{"GANYMEDE", 8, 101742},
	{"DTML", 4, 101743},
	{"YAGI", 4, 101744},
	{"NORMALIZING", 11, 101745},
	{"LETCHWORTH", 10, 101746},
	{"SULTANS", 7, 101747},
	{"ENJOINED", 8, 101748},
	{"XOFP", 4, 101749},
	{"UNIZ", 4, 101750},
	{"ULUA", 4, 101751},
	{"RJAK", 4, 101752},
	{"NKFL", 4, 101753},
	{"LRIO", 4, 101754},
	{"KTRU", 4, 101755},
	{"CYNE", 4, 101756},
	{"HARBORING", 9, 101757},
	{"BELAIR", 6, 101758},
	{"MCPS", 4, 101759},
	{"TOOMEY", 6, 101760},
	{"REZEPT", 6, 101761},
	{"ARONSON", 7, 101762},
	{"BANKNOTE", 8, 101763},
	{"KPW", 3, 101764},
	{"NORTHBRIDGE", 11, 101765},
	{"ECHL", 4, 101766},
	{"ZWOR", 4, 101767},
	{"XTSP", 4, 101768},
	{"NCAG", 4, 101769},
	{"IKMA", 4, 101770},
	{"HIPV", 4, 101771},
	{"BCTO", 4, 101772},
	{"MAPSMAPS", 8, 101773},
	{"FINCHES", 7, 101774},
	{"BASQUES", 7, 101775},
	{"ULLK", 4, 101776},
	{"PFAL", 4, 101777},
	{"NEZW", 4, 101778},
	{"HEFW", 4, 101779},
	{"ZENON", 5, 101780},
	{"ANIMATING", 9, 101781},
	{"REWRITABLE", 10, 101782},
	{"LEZS", 4, 101783},
	{"GGOR", 4, 101784},
	{"FEGO", 4, 101785},
	{"MERCURIAL", 9, 101786},
	{"BARGAINED", 9, 101787},
	{"REPUGNANT", 9, 101788},
	{"JYTHON", 6, 101789},
	{"SILC", 4, 101790},
	{"HALLETT", 7, 101791},
	{"MULLAHS", 7, 101792},
	{"LOWBALL", 7, 101793},
	{"REPOSSESSED", 11, 101794},
	{"CITRON", 6, 101795},
	{"METRONIDAZOLE", 13, 101796},
	{"CLAVE", 5, 101797},
	{"PAGEANTS", 8, 101798},
	{"YVEE", 4, 101799},
	{"RDUA", 4, 101800},
	{"KHOV", 4, 101801},
	{"GROSSES", 7, 101802},
	{"FEBUARY", 7, 101803},
	{"TACKED", 6, 101804},
	{"BROADENS", 8, 101805},
	{"ZEIGEN", 6, 101806},
	{"REINHART", 8, 101807},
	{"CHOBITS", 7, 101808},
	{"SUPPLANT", 8, 101809},
	{"FRAMEBUFFER", 11, 101810},
	{"OILSEED", 7, 101811},
	{"STIFFER", 7, 101812},
	{"ERASERHEAD", 10, 101813},
	{"POKES", 5, 101814},
	{"YRIP", 4, 101815},
	{"UINW", 4, 101816},
	{"UECE", 4, 101817},
	{"DYAG", 4, 101818},
	{"BYSK", 4, 101819},
	{"FUSARIUM", 8, 101820},
	{"SAXOPHONES", 10, 101821},
	{"SLATES", 6, 101822},
	{"PRUE", 4, 101823},
	{"CORROBORATED", 12, 101824},
	{"CAMARAS", 7, 101825},
	{"ANDROS", 6, 101826},
	{"MWY", 3, 101827},
	{"FOUNDLAND", 9, 101828},
	{"DANIA", 5, 101829},
	{"BESTIARY", 8, 101830},
	{"KDEPIM", 6, 101831},
	{"FREECAM", 7, 101832},
	{"PRIVATECAM", 10, 101833},
	{"ACOUSTIK", 8, 101834},
	{"RGWE", 4, 101835},
	{"PASU", 4, 101836},
	{"MGUA", 4, 101837},
	{"IXBA", 4, 101838},
	{"AUSK", 4, 101839},
	{"RULEBOOK", 8, 101840},
	{"ALLELIC", 7, 101841},
	{"MAGNETICALLY", 12, 101842},
	{"ARTERIOSCLEROSIS", 16, 101843},
	{"PERMAFROST", 10, 101844},
	{"HUNKY", 5, 101845},
	{"EROTIKCAM", 9, 101846},
	{"VORB", 4, 101847},
	{"EMMAUS", 6, 101848},
	{"CRANKING", 8, 101849},
	{"BLACKFIVE", 9, 101850},
	{"FRG", 3, 101851},
	{"SOUTHLAKE", 9, 101852},
	{"CARRBORO", 8, 101853},
	{"SOUNDSYSTEM", 11, 101854},
	{"KANAGAWA", 8, 101855},
	{"ROYP", 4, 101856},
	{"LHYP", 4, 101857},
	{"GDAU", 4, 101858},
	{"MULTIPLEXED", 11, 101859},
	{"BIRDMAN", 7, 101860},
	{"ACTIONTEC", 9, 101861},
	{"GINUWINE", 8, 101862},
	{"MICROCHIPS", 10, 101863},
	{"INFERTILE", 9, 101864},
	{"TIPSY", 5, 101865},
	{"CRYPTOSPORIDIUM", 15, 101866},
	{"BEALL", 5, 101867},
	{"ATRIA", 5, 101868},
	{"BERNALILLO", 10, 101869},
	{"TABAC", 5, 101870},
	{"LAYETTE", 7, 101871},
	{"BLAGOJEVICH", 11, 101872},
	{"ZAWH", 4, 101873},
	{"YLLC", 4, 101874},
	{"WPHO", 4, 101875},
	{"WITM", 4, 101876},
	{"RBEP", 4, 101877},
	{"MUAN", 4, 101878},
	{"HEGC", 4, 101879},
	{"EYGU", 4, 101880},
	{"ACYE", 4, 101881},
	{"FACTUALLY", 9, 101882},
	{"WORSLEY", 7, 101883},
	{"SAGAS", 5, 101884},
	{"AMINOTRANSFERASE", 16, 101885},
	{"CELS", 4, 101886},
	{"LIDE", 4, 101887},
	{"CRESS", 5, 101888},
	{"GUITARE", 7, 101889},
	{"RECOGNISABLE", 12, 101890},
	{"MGETTY", 6, 101891},
	{"RPSS", 4, 101892},
	{"KVIC", 4, 101893},
	{"GHOV", 4, 101894},
	{"CEEF", 4, 101895},
	{"BCOC", 4, 101896},
	{"GSASL", 5, 101897},
	{"KRISSY", 6, 101898},
	{"UPMYSTREET", 10, 101899},
	{"NEURALGIA", 9, 101900},
	{"TIMBRE", 6, 101901},
	{"XDEC", 4, 101902},
	{"MACN", 4, 101903},
	{"GIZI", 4, 101904},
	{"ENKU", 4, 101905},
	{"TRANSGENE", 9, 101906},
	{"ALDA", 4, 101907},
	{"SCROTUM", 7, 101908},
	{"CLASPED", 7, 101909},
	{"PECKING", 7, 101910},
	{"LEGISLATED", 10, 101911},
	{"WOMANHOOD", 9, 101912},
	{"SKATEPARK", 9, 101913},
	{"CONDITIONALS", 12, 101914},
	{"CRIMEAN", 7, 101915},
	{"INHOUSE", 7, 101916},
	{"PHOTOWORKS", 10, 101917},
	{"EXORBITANT", 10, 101918},
	{"VALENTI", 7, 101919},
	{"IMESH", 5, 101920},
	{"ANHUI", 5, 101921},
	{"ULOP", 4, 101922},
	{"PELV", 4, 101923},
	{"NYMP", 4, 101924},
	{"LIML", 4, 101925},
	{"HMUD", 4, 101926},
	{"DALK", 4, 101927},
	{"ACAG", 4, 101928},
	{"GRIEVED", 7, 101929},
	{"CERWIN", 6, 101930},
	{"BROWNELL", 8, 101931},
	{"WILLOWBROOK", 11, 101932},
	{"EXPERIMENTER", 12, 101933},
	{"REIFE", 5, 101934},
	{"PURVEYORS", 9, 101935},
	{"TALLIES", 7, 101936},
	{"SERPENTS", 8, 101937},
	{"SNIPING", 7, 101938},
	{"MAPLETON", 8, 101939},
	{"GRACA", 5, 101940},
	{"ENTERAL", 7, 101941},
	{"LANNY", 5, 101942},
	{"ZLEA", 4, 101943},
	{"MSVE", 4, 101944},
	{"LKOM", 4, 101945},
	{"AXBE", 4, 101946},
	{"OTLEY", 5, 101947},
	{"CUDA", 4, 101948},
	{"ENDOCARDITIS", 12, 101949},
	{"RESULTSET", 9, 101950},
	{"CYBERSECURITY", 13, 101951},
	{"TAMPERED", 8, 101952},
	{"SEVERALLY", 9, 101953},
	{"SIAMO", 5, 101954},
	{"MADIAQ", 6, 101955},
	{"WEAG", 4, 101956},
	{"UYCA", 4, 101957},
	{"GNCU", 4, 101958},
	{"FIWO", 4, 101959},
	{"CLIQ", 4, 101960},
	{"WWRITE", 6, 101961},
	{"DUNMORE", 7, 101962},
	{"WOODWORKERS", 11, 101963},
	{"LUMPKIN", 7, 101964},
	{"FICUS", 5, 101965},
	{"RAYE", 4, 101966},
	{"SAWTOOTH", 8, 101967},
	{"CARMODY", 7, 101968},
	{"GOODWOOD", 8, 101969},
	{"STIHL", 5, 101970},
	{"MPHIL", 5, 101971},
	{"KIPL", 4, 101972},
	{"INGRAHAM", 8, 101973},
	{"BCENTRAL", 8, 101974},
	{"RIDGEBACK", 9, 101975},
	{"DIBUJOS", 7, 101976},
	{"BEDSTEAD", 8, 101977},
	{"PRAVDA", 6, 101978},
	{"SUPERSTOCK", 10, 101979},
	{"BOYKIN", 6, 101980},
	{"ACQUIS", 6, 101981},
	{"RUNY", 4, 101982},
	{"PUBI", 4, 101983},
	{"PSGA", 4, 101984},
	{"OUNW", 4, 101985},
	{"NGWW", 4, 101986},
	{"LEBS", 4, 101987},
	{"IFAG", 4, 101988},
	{"GYTR", 4, 101989},
	{"BONP", 4, 101990},
	{"LUNDGREN", 8, 101991},
	{"ASTROPHYS", 9, 101992},
	{"NORWEGEN", 8, 101993},
	{"MATCHBOOK", 9, 101994},
	{"WIMP", 4, 101995},
	{"BOSTONIAN", 9, 101996},
	{"WHIRLPOOLS", 10, 101997},
	{"EUTHERIA", 8, 101998},
	{"CARESSING", 9, 101999},
	{"RELIEFS", 7, 102000},
	{"MCDBA", 5, 102001},
	{"BATHTUBS", 8, 102002},
	{"YLLG", 4, 102003},
	{"TJAR", 4, 102004},
	{"DIFP", 4, 102005},
	{"TASSELS", 7, 102006},
	{"CULPA", 5, 102007},
	{"APOLIPOPROTEIN", 14, 102008},
	{"DELCO", 5, 102009},
	{"WHITER", 6, 102010},
	{"CARRE", 5, 102011},
	{"GWEATHER", 8, 102012},
	{"FERRERO", 7, 102013},
	{"YFAB", 4, 102014},
	{"WIWO", 4, 102015},
	{"SKSM", 4, 102016},
	{"PWON", 4, 102017},
	{"PEUN", 4, 102018},
	{"OWIG", 4, 102019},
	{"OKOM", 4, 102020},
	{"MWEH", 4, 102021},
	{"HFUE", 4, 102022},
	{"DWIP", 4, 102023},
	{"MAPK", 4, 102024},
	{"DALMATIANS", 10, 102025},
	{"WESTOVER", 8, 102026},
	{"FROTH", 5, 102027},
	{"MRM", 3, 102028},
	{"OBLITERATED", 11, 102029},
	{"HAMMETT", 7, 102030},
	{"REGALIA", 7, 102031},
	{"HARDBOUND", 9, 102032},
	{"PEERAGE", 7, 102033},
	{"DERMA", 5, 102034},
	{"LEAFNODE", 8, 102035},
	{"DECEITFUL", 9, 102036},
	{"VFP", 3, 102037},
	{"YZET", 4, 102038},
	{"RYIR", 4, 102039},
	{"GUZM", 4, 102040},
	{"DLIZ", 4, 102041},
	{"CTCI", 4, 102042},
	{"CEYS", 4, 102043},
	{"AWBO", 4, 102044},
	{"ONDERZOEK", 9, 102045},
	{"MCCOURT", 7, 102046},
	{"TABOOS", 6, 102047},
	{"STORIED", 7, 102048},
	{"MAMADAS", 7, 102049},
	{"DISENFRANCHISED", 15, 102050},
	{"VERBENA", 7, 102051},
	{"MANDIBULAR", 10, 102052},
	{"WALTHAMSTOW", 11, 102053},
	{"RIMG", 4, 102054},
	{"OGSD", 4, 102055},
	{"NLIQ", 4, 102056},
	{"MITU", 4, 102057},
	{"LTGE", 4, 102058},
	{"GEMC", 4, 102059},
	{"FUNDER", 6, 102060},
	{"INFRONT", 7, 102061},
	{"UNPROFITABLE", 12, 102062},
	{"WORKPLAN", 8, 102063},
	{"ELVIN", 5, 102064},
	{"DISTRI", 6, 102065},
	{"FAULK", 5, 102066},
	{"OKANOGAN", 8, 102067},
	{"ASTONISHINGLY", 13, 102068},
	{"TVSP", 4, 102069},
	{"TLIP", 4, 102070},
	{"RUSN", 4, 102071},
	{"MBUN", 4, 102072},
	{"LATG", 4, 102073},
	{"KDAR", 4, 102074},
	{"KANJ", 4, 102075},
	{"FBEG", 4, 102076},
	{"CANNIBALISM", 11, 102077},
	{"ANTIQUED", 8, 102078},
	{"MARGRET", 7, 102079},
	{"MENOS", 5, 102080},
	{"POPULARIZED", 11, 102081},
	{"TGIRL", 5, 102082},
	{"TYPESET", 7, 102083},
	{"MERA", 4, 102084},
	{"CHITOSAN", 8, 102085},
	{"SMRA", 4, 102086},
	{"KESJ", 4, 102087},
	{"JAKO", 4, 102088},
	{"PRETENDER", 9, 102089},
	{"MESOSCALE", 9, 102090},
	{"MOSSES", 6, 102091},
	{"BONING", 6, 102092},
	{"BUTTERSCOTCH", 12, 102093},
	{"GUNSLINGER", 10, 102094},
	{"NNRP", 4, 102095},
	{"IWILL", 5, 102096},
	{"ABRUZZO", 7, 102097},
	{"RSHM", 4, 102098},
	{"RLUK", 4, 102099},
	{"ORAX", 4, 102100},
	{"MOFY", 4, 102101},
	{"EKAU", 4, 102102},
	{"BYTY", 4, 102103},
	{"LIVORNO", 7, 102104},
	{"TIMEPORT", 8, 102105},
	{"MARL", 4, 102106},
	{"SUBSIDE", 7, 102107},
	{"VEGETA", 6, 102108},
	{"SYLPHEED", 8, 102109},
	{"XALT", 4, 102110},
	{"UMDA", 4, 102111},
	{"AIRJ", 4, 102112},
	{"BURNEY", 6, 102113},
	{"ANNICK", 6, 102114},
	{"FALSIFICATION", 13, 102115},
	{"POLTERGEIST", 11, 102116},
	{"MODERNIZING", 11, 102117},
	{"RXR", 3, 102118},
	{"CONSPIRING", 10, 102119},
	{"IECHYD", 6, 102120},
	{"SEATBELTS", 9, 102121},
	{"ARSCHFICKEN", 11, 102122},
	{"ANKLESHWAR", 10, 102123},
	{"POWERGEN", 8, 102124},
	{"SCHEER", 6, 102125},
	{"YNWA", 4, 102126},
	{"FCOW", 4, 102127},
	{"DITK", 4, 102128},
	{"OFFICIANTS", 10, 102129},
	{"RESPON", 6, 102130},
	{"NOSTRA", 6, 102131},
	{"SEABIRDS", 8, 102132},
	{"GLLUG", 5, 102133},
	{"RETALIATE", 9, 102134},
	{"DYIM", 4, 102135},
	{"DJAV", 4, 102136},
	{"CKYG", 4, 102137},
	{"TOHOKU", 6, 102138},
	{"VINOD", 5, 102139},
	{"DEAFENING", 9, 102140},
	{"COHABITATION", 12, 102141},
	{"ARLO", 4, 102142},
	{"UMFA", 4, 102143},
	{"UICY", 4, 102144},
	{"UCKG", 4, 102145},
	{"PELF", 4, 102146},
	{"GUPN", 4, 102147},
	{"CEXE", 4, 102148},
	{"KBC", 3, 102149},
	{"DEUTCH", 6, 102150},
	{"COFACTOR", 8, 102151},
	{"FROSTBITE", 9, 102152},
	{"APPARTAMENTI", 12, 102153},
	{"OBEROI", 6, 102154},
	{"YPZ", 3, 102155},
	{"QGU", 3, 102156},
	{"KZY", 3, 102157},
	{"GPQ", 3, 102158},
	{"GMQ", 3, 102159},
	{"BKJ", 3, 102160},
	{"SANDHILL", 8, 102161},
	{"HASSELHOFF", 10, 102162},
	{"UUID", 4, 102163},
	{"FASTTRACK", 9, 102164},
	{"BELEAGUERED", 11, 102165},
	{"JARRING", 7, 102166},
	{"WATTLE", 6, 102167},
	{"GSOB", 4, 102168},
	{"ELVO", 4, 102169},
	{"DGLU", 4, 102170},
	{"GEEKLISTS", 9, 102171},
	{"OLMSTEAD", 8, 102172},
	{"TREC", 4, 102173},
	{"BAPTISMAL", 9, 102174},
	{"MAAC", 4, 102175},
	{"APPARTMENT", 10, 102176},
	{"TIMARU", 6, 102177},
	{"OTERO", 5, 102178},
	{"STOLES", 6, 102179},
	{"AXELROD", 7, 102180},
	{"SWITZER", 7, 102181},
	{"MABRY", 5, 102182},
	{"ULHU", 4, 102183},
	{"UBUL", 4, 102184},
	{"ROKL", 4, 102185},
	{"NKSY", 4, 102186},
	{"LJOS", 4, 102187},
	{"IRYC", 4, 102188},
	{"FSBE", 4, 102189},
	{"CPHO", 4, 102190},
	{"BIFO", 4, 102191},
	{"MARITIM", 7, 102192},
	{"HAZLETON", 8, 102193},
	{"PORTALES", 8, 102194},
	{"MAGDALEN", 8, 102195},
	{"MANAGUA", 7, 102196},
	{"REGULARIZATION", 14, 102197},
	{"SPILLAGE", 8, 102198},
	{"EXPERTCARE", 10, 102199},
	{"UNIVERSITA", 10, 102200},
	{"UABB", 4, 102201},
	{"SMYA", 4, 102202},
	{"PTAF", 4, 102203},
	{"BSMO", 4, 102204},
	{"ARPW", 4, 102205},
	{"CANISIUS", 8, 102206},
	{"BRACKISH", 8, 102207},
	{"DIREKT", 6, 102208},
	{"BESSEL", 6, 102209},
	{"DORO", 4, 102210},
	{"TUBBY", 5, 102211},
	{"GUAR", 4, 102212},
	{"GLIOMA", 6, 102213},
	{"MANOWAR", 7, 102214},
	{"LADBROKES", 9, 102215},
	{"RYMY", 4, 102216},
	{"POIG", 4, 102217},
	{"OLYL", 4, 102218},
	{"CYAG", 4, 102219},
	{"ARLJ", 4, 102220},
	{"DATEOUT", 7, 102221},
	{"ORYX", 4, 102222},
	{"POSEN", 5, 102223},
	{"COMPAL", 6, 102224},
	{"SEDATIVES", 9, 102225},
	{"MAYSVILLE", 9, 102226},
	{"YISRAEL", 7, 102227},
	{"HENNESSEY", 9, 102228},
	{"ZHAOPIN", 7, 102229},
	{"HYPERTHYROIDISM", 15, 102230},
	{"EUROPEA", 7, 102231},
	{"PREMENSTRUAL", 12, 102232},
	{"HYPHENATED", 10, 102233},
	{"WHUM", 4, 102234},
	{"FCRY", 4, 102235},
	{"TINSEL", 6, 102236},
	{"EDEL", 4, 102237},
	{"PHARRELL", 8, 102238},
	{"COBURG", 6, 102239},
	{"SCRUTINIZE", 10, 102240},
	{"BANDPASS", 8, 102241},
	{"ADVERB", 6, 102242},
	{"MUMBLED", 7, 102243},
	{"COMMIS", 6, 102244},
	{"MIRED", 5, 102245},
	{"BISHKEK", 7, 102246},
	{"YAMS", 4, 102247},
	{"BREVE", 5, 102248},
	{"ISOPROPYL", 9, 102249},
	{"PENPAL", 6, 102250},
	{"KYSE", 4, 102251},
	{"KUNS", 4, 102252},
	{"IGNV", 4, 102253},
	{"POTENTIOMETER", 13, 102254},
	{"MODIGLIANI", 10, 102255},
	{"DATEDUE", 7, 102256},
	{"BRICKSHELF", 10, 102257},
	{"SCHWERIN", 8, 102258},
	{"TWEEZERMAN", 10, 102259},
	{"PRUNUS", 6, 102260},
	{"HOANG", 5, 102261},
	{"SWEATSHOP", 9, 102262},
	{"PROSPECTUSES", 12, 102263},
	{"SEBAGO", 6, 102264},
	{"WORTHINESS", 10, 102265},
	{"LAZILY", 6, 102266},
	{"BIOLOGIE", 8, 102267},
	{"CATTERY", 7, 102268},
	{"YPAV", 4, 102269},
	{"UTAQ", 4, 102270},
	{"JEEPERS", 7, 102271},
	{"FOLIAR", 6, 102272},
	{"CARNARVON", 9, 102273},
	{"TROPOSPHERE", 11, 102274},
	{"VELBON", 6, 102275},
	{"RINKS", 5, 102276},
	{"REVOKING", 8, 102277},
	{"ANESTHESIOLOGISTS", 17, 102278},
	{"JAILHOUSE", 9, 102279},
	{"VORH", 4, 102280},
	{"TBUB", 4, 102281},
	{"RABM", 4, 102282},
	{"NMAM", 4, 102283},
	{"IERZ", 4, 102284},
	{"HABRA", 5, 102285},
	{"DORGAN", 6, 102286},
	{"RUCKSACKS", 9, 102287},
	{"TRIPPIN", 7, 102288},
	{"NUMAN", 5, 102289},
	{"GCONV", 5, 102290},
	{"RAVER", 5, 102291},
	{"CUESTA", 6, 102292},
	{"POSTURING", 9, 102293},
	{"RHOADS", 6, 102294},
	{"WPOP", 4, 102295},
	{"GISV", 4, 102296},
	{"DYSB", 4, 102297},
	{"NARITA", 6, 102298},
	{"MARKOWITZ", 9, 102299},
	{"CENDANT", 7, 102300},
	{"COLNE", 5, 102301},
	{"CANTATA", 7, 102302},
	{"MUHAMMED", 8, 102303},
	{"SOULFLY", 7, 102304},
	{"HAKEEM", 6, 102305},
	{"DISARMING", 9, 102306},
	{"CONCENTRATORS", 13, 102307},
	{"YMAU", 4, 102308},
	{"ACTIVESTATE", 11, 102309},
	{"NETFLOW", 7, 102310},
	{"CASTRATION", 10, 102311},
	{"THIAMINE", 8, 102312},
	{"WOEFULLY", 8, 102313},
	{"NEGOTIATES", 10, 102314},
	{"AFLAC", 5, 102315},
	{"BAMA", 4, 102316},
	{"ORGA", 4, 102317},
	{"TITIES", 6, 102318},
	{"PROMONTORY", 10, 102319},
	{"SHANNA", 6, 102320},
	{"UDHO", 4, 102321},
	{"RTUI", 4, 102322},
	{"LHAZ", 4, 102323},
	{"LDMC", 4, 102324},
	{"IMOL", 4, 102325},
	{"HBYP", 4, 102326},
	{"FSIZ", 4, 102327},
	{"FMYE", 4, 102328},
	{"BISR", 4, 102329},
	{"TURBOGRAFX", 10, 102330},
	{"LOWVELD", 7, 102331},
	{"ITEMID", 6, 102332},
	{"PSICOLOGIA", 10, 102333},
	{"TROND", 5, 102334},
	{"NACHOS", 6, 102335},
	{"JURIDICAL", 9, 102336},
	{"HILLIER", 7, 102337},
	{"PAYE", 4, 102338},
	{"SHANDY", 6, 102339},
	{"ELASTANE", 8, 102340},
	{"GRRR", 4, 102341},
	{"MUDVILLE", 8, 102342},
	{"KCOO", 4, 102343},
	{"ETZK", 4, 102344},
	{"GTKWIDGET", 9, 102345},
	{"SMOTE", 5, 102346},
	{"OLYMPIANS", 9, 102347},
	{"DIPLOID", 7, 102348},
	{"MOUNTINGS", 9, 102349},
	{"ILONA", 5, 102350},
	{"GOOGLED", 7, 102351},
	{"VDIN", 4, 102352},
	{"LRIT", 4, 102353},
	{"FOFE", 4, 102354},
	{"EUIL", 4, 102355},
	{"DCTH", 4, 102356},
	{"CAMPERVAN", 9, 102357},
	{"MAGGIO", 6, 102358},
	{"PIVOTING", 8, 102359},
	{"NEUROIMAGING", 12, 102360},
	{"CMTS", 4, 102361},
	{"REKR", 4, 102362},
	{"ORGF", 4, 102363},
	{"JANM", 4, 102364},
	{"GSOD", 4, 102365},
	{"BERNANKE", 8, 102366},
	{"TOGGLES", 7, 102367},
	{"SUPERTRAMP", 10, 102368},
	{"ADRESSEN", 8, 102369},
	{"MODPROBE", 8, 102370},
	{"TAUNTING", 8, 102371},
	{"RAHIM", 5, 102372},
	{"ETRUSCAN", 8, 102373},
	{"DAVANGERE", 9, 102374},
	{"OUTWARDS", 8, 102375},
	{"REND", 4, 102376},
	{"HEZEKIAH", 8, 102377},
	{"VOLPE", 5, 102378},
	{"DEPRAVITY", 9, 102379},
	{"AXION", 5, 102380},
	{"WEALTHIER", 9, 102381},
	{"HUAWEI", 6, 102382},
	{"RLBE", 4, 102383},
	{"RGPA", 4, 102384},
	{"PMIC", 4, 102385},
	{"NDCM", 4, 102386},
	{"DSUT", 4, 102387},
	{"MAPSOURCE", 9, 102388},
	{"DIALOGIC", 8, 102389},
	{"SCIENTIFIQUE", 12, 102390},
	{"ALLCHIN", 7, 102391},
	{"PERMEASE", 8, 102392},
	{"LXF", 3, 102393},
	{"BOLUS", 5, 102394},
	{"CALVING", 7, 102395},
	{"JUMPDRIVE", 9, 102396},
	{"PTSP", 4, 102397},
	{"OKEG", 4, 102398},
	{"IMQU", 4, 102399},
	{"AVAP", 4, 102400},
	{"DISAGREEABLE", 12, 102401},
	{"BLOODLINE", 9, 102402},
	{"REARVIEW", 8, 102403},
	{"OFFSIDE", 7, 102404},
	{"ELAVIL", 6, 102405},
	{"IVANA", 5, 102406},
	{"RECERTIFIED", 11, 102407},
	{"INTRAUTERINE", 12, 102408},
	{"SPRINKLES", 9, 102409},
	{"SHORTCOMING", 11, 102410},
	{"XBRO", 4, 102411},
	{"DITV", 4, 102412},
	{"DREAMGIRLS", 10, 102413},
	{"DREI", 4, 102414},
	{"BRAINCHILD", 10, 102415},
	{"CASTES", 6, 102416},
	{"SMMO", 4, 102417},
	{"RNDU", 4, 102418},
	{"NUKA", 4, 102419},
	{"KEDQ", 4, 102420},
	{"IFIX", 4, 102421},
	{"LEONI", 5, 102422},
	{"CORRUPTING", 10, 102423},
	{"DOCSIS", 6, 102424},
	{"MASSIF", 6, 102425},
	{"IDIOMA", 6, 102426},
	{"POLLO", 5, 102427},
	{"SHRIKE", 6, 102428},
	{"BALLOTING", 9, 102429},
	{"YKRA", 4, 102430},
	{"PESK", 4, 102431},
	{"ORMV", 4, 102432},
	{"DGYM", 4, 102433},
	{"AZEB", 4, 102434},
	{"LEDERER", 7, 102435},
	{"MURAT", 5, 102436},
	{"ITALIANE", 8, 102437},
	{"PEDIC", 5, 102438},
	{"CAYO", 4, 102439},
	{"PETROV", 6, 102440},
	{"DIXIELAND", 9, 102441},
	{"DAIRIES", 7, 102442},
	{"CONRAN", 6, 102443},
	{"ANNALES", 7, 102444},
	{"UNADJUSTED", 10, 102445},
	{"VIDN", 4, 102446},
	{"SDOB", 4, 102447},
	{"ODHU", 4, 102448},
	{"HMYM", 4, 102449},
	{"GEWR", 4, 102450},
	{"EXDI", 4, 102451},
	{"CUPQ", 4, 102452},
	{"COPU", 4, 102453},
	{"ACTK", 4, 102454},
	{"SECAUCUS", 8, 102455},
	{"LIONHEART", 9, 102456},
	{"RAMSGATE", 8, 102457},
	{"POIROT", 6, 102458},
	{"SCARSDALE", 9, 102459},
	{"BIOGAS", 6, 102460},
	{"PONYTAIL", 8, 102461},
	{"DVDUPGRADES", 11, 102462},
	{"TEDZ", 4, 102463},
	{"ORPW", 4, 102464},
	{"MMAW", 4, 102465},
	{"FTYA", 4, 102466},
	{"EFUC", 4, 102467},
	{"CGOO", 4, 102468},
	{"AULN", 4, 102469},
	{"ANGELOU", 7, 102470},
	{"CAPEL", 5, 102471},
	{"OVERTURES", 9, 102472},
	{"UNTRUSTED", 9, 102473},
	{"ALCOTT", 6, 102474},
	{"DWARVEN", 7, 102475},
	{"PHARAOHS", 8, 102476},
	{"FRAUDULENTLY", 12, 102477},
	{"CALENDULA", 9, 102478},
	{"MUSHY", 5, 102479},
	{"RESTCAMP", 8, 102480},
	{"PLUNGES", 7, 102481},
	{"DBTEL", 5, 102482},
	{"PARTENAIRES", 11, 102483},
	{"MJOB", 4, 102484},
	{"GAYB", 4, 102485},
	{"GIBBERISH", 9, 102486},
	{"SERVOS", 6, 102487},
	{"ARBITRAL", 8, 102488},
	{"INTRAMUSCULAR", 13, 102489},
	{"AMARI", 5, 102490},
	{"PAPILLOMAVIRUS", 14, 102491},
	{"DOZER", 5, 102492},
	{"SUMER", 5, 102493},
	{"NUMER", 5, 102494},
	{"CELA", 4, 102495},
	{"INDUST", 6, 102496},
	{"WAITIN", 6, 102497},
	{"DREADNOUGHT", 11, 102498},
	{"YATV", 4, 102499},
	{"WUPF", 4, 102500},
	{"VICW", 4, 102501},
	{"THYU", 4, 102502},
	{"ONGZ", 4, 102503},
	{"LTCL", 4, 102504},
	{"IFYB", 4, 102505},
	{"GTUN", 4, 102506},
	{"EVLI", 4, 102507},
	{"OCCITANE", 8, 102508},
	{"KRESS", 5, 102509},
	{"SCHALLER", 8, 102510},
	{"MANTECA", 7, 102511},
	{"TAMMANY", 7, 102512},
	{"ASEPTIC", 7, 102513},
	{"IMMAGINE", 8, 102514},
	{"BOULEVARDS", 10, 102515},
	{"BARTELS", 7, 102516},
	{"FEEDPARK", 8, 102517},
	{"SYSTEMROOT", 10, 102518},
	{"REDESIGNATED", 12, 102519},
	{"REDISTRIBUTING", 14, 102520},
	{"XHOL", 4, 102521},
	{"VHAD", 4, 102522},
	{"UBED", 4, 102523},
	{"TOLW", 4, 102524},
	{"SMYG", 4, 102525},
	{"PEFF", 4, 102526},
	{"OGAP", 4, 102527},
	{"KANW", 4, 102528},
	{"IXGO", 4, 102529},
	{"CSYM", 4, 102530},
	{"NEUROLOGISTS", 12, 102531},
	{"DARKEN", 6, 102532},
	{"MAZZA", 5, 102533},
	{"GETVALUE", 8, 102534},
	{"DEFAMER", 7, 102535},
	{"SUPERCOMPUTERS", 14, 102536},
	{"DOWRY", 5, 102537},
	{"INKTOMI", 7, 102538},
	{"COMMENTAIRE", 11, 102539},
	{"HARTMUT", 7, 102540},
	{"SHAPERS", 7, 102541},
	{"JWAS", 4, 102542},
	{"DEGL", 4, 102543},
	{"BTRO", 4, 102544},
	{"CHATEAUX", 8, 102545},
	{"GASTRITIS", 9, 102546},
	{"HYMENOPTERA", 11, 102547},
	{"MONTI", 5, 102548},
	{"MILLENIA", 8, 102549},
	{"JERZY", 5, 102550},
	{"SEUNG", 5, 102551},
	{"NTYU", 4, 102552},
	{"LGOS", 4, 102553},
	{"GJER", 4, 102554},
	{"ERBP", 4, 102555},
	{"DWDM", 4, 102556},
	{"LANGHORNE", 9, 102557},
	{"QUAM", 4, 102558},
	{"PHARYNGULA", 10, 102559},
	{"SKIRTING", 8, 102560},
	{"DIAPERING", 9, 102561},
	{"UMUP", 4, 102562},
	{"LFUS", 4, 102563},
	{"KYBA", 4, 102564},
	{"FWRO", 4, 102565},
	{"CEIG", 4, 102566},
	{"AULJ", 4, 102567},
	{"BEATRIZ", 7, 102568},
	{"FUBU", 4, 102569},
	{"GOUGING", 7, 102570},
	{"ADIEU", 5, 102571},
	{"GATHERER", 8, 102572},
	{"SLACKERS", 8, 102573},
	{"KINDLING", 8, 102574},
	{"KAMCHATKA", 9, 102575},
	{"SEROTYPE", 8, 102576},
	{"SHORTLISTED", 11, 102577},
	{"VILLANUEVA", 10, 102578},
	{"SCOREBOOK", 9, 102579},
	{"SOWETO", 6, 102580},
	{"RETRANSMIT", 10, 102581},
	{"NONDESTRUCTIVE", 14, 102582},
	{"SPINOZA", 7, 102583},
	{"CHEKHOV", 7, 102584},
	{"AFFLUENCE", 9, 102585},
	{"PHOSPHO", 7, 102586},
	{"TECNOLOGIA", 10, 102587},
	{"YODE", 4, 102588},
	{"YHAB", 4, 102589},
	{"WWWR", 4, 102590},
	{"ULJA", 4, 102591},
	{"UGSM", 4, 102592},
	{"UEFL", 4, 102593},
	{"PEMP", 4, 102594},
	{"LSIU", 4, 102595},
	{"HNFL", 4, 102596},
	{"FYEL", 4, 102597},
	{"FEPO", 4, 102598},
	{"EPAF", 4, 102599},
	{"EIMD", 4, 102600},
	{"SALINGER", 8, 102601},
	{"ACYCLIC", 7, 102602},
	{"SYNCHRONICITY", 13, 102603},
	{"PASSABLE", 8, 102604},
	{"SHOULDERED", 10, 102605},
	{"TUMBLEWEED", 10, 102606},
	{"MILLIGRAM", 9, 102607},
	{"MONAHAN", 7, 102608},
	{"DISPATCHERS", 11, 102609},
	{"RYKIEL", 6, 102610},
	{"MAIDA", 5, 102611},
	{"WOOTTON", 7, 102612},
	{"CRANIOFACIAL", 12, 102613},
	{"UTEY", 4, 102614},
	{"SELR", 4, 102615},
	{"EUDW", 4, 102616},
	{"DTHW", 4, 102617},
	{"HILARITY", 8, 102618},
	{"PAWEL", 5, 102619},
	{"REVELSTOKE", 10, 102620},
	{"FULFILS", 7, 102621},
	{"NEISSERIA", 9, 102622},
	{"CLB", 3, 102623},
	{"PREDOMINANCE", 12, 102624},
	{"SNUCK", 5, 102625},
	{"RUFIYAA", 7, 102626},
	{"POSTCOLONIAL", 12, 102627},
	{"MITTEN", 6, 102628},
	{"FANUC", 5, 102629},
	{"DARJEELING", 10, 102630},
	{"RECIRCULATION", 13, 102631},
	{"SODY", 4, 102632},
	{"RXIA", 4, 102633},
	{"MIWI", 4, 102634},
	{"KMWE", 4, 102635},
	{"EMIZ", 4, 102636},
	{"DOWP", 4, 102637},
	{"AMKA", 4, 102638},
	{"ONSLOW", 6, 102639},
	{"BLASTX", 6, 102640},
	{"SCSU", 4, 102641},
	{"CAMPY", 5, 102642},
	{"OGILVIE", 7, 102643},
	{"CONQUERORS", 10, 102644},
	{"MAURITANIAN", 11, 102645},
	{"ILKLEY", 6, 102646},
	{"XLINK", 5, 102647},
	{"NYMEX", 5, 102648},
	{"VREW", 4, 102649},
	{"UDYL", 4, 102650},
	{"SIFP", 4, 102651},
	{"RAPN", 4, 102652},
	{"LUSG", 4, 102653},
	{"ECYN", 4, 102654},
	{"DUSR", 4, 102655},
	{"BCHE", 4, 102656},
	{"TAMARIND", 8, 102657},
	{"LAXMAN", 6, 102658},
	{"CONCEPTUALIZATION", 17, 102659},
	{"DALASI", 6, 102660},
	{"ADMONITION", 10, 102661},
	{"RATLAM", 6, 102662},
	{"STRAFFORD", 9, 102663},
	{"FERDINANDO", 10, 102664},
	{"FORMAZIONE", 10, 102665},
	{"PERCHANCE", 9, 102666},
	{"OLEAN", 5, 102667},
	{"KURSK", 5, 102668},
	{"YDMA", 4, 102669},
	{"TNFL", 4, 102670},
	{"LMFR", 4, 102671},
	{"FTHD", 4, 102672},
	{"DGUT", 4, 102673},
	{"MVL", 3, 102674},
	{"TONKIN", 6, 102675},
	{"AWASH", 5, 102676},
	{"HERIOT", 6, 102677},
	{"DEMETRIUS", 9, 102678},
	{"PRECOCIOUS", 10, 102679},
	{"ANMELDUNG", 9, 102680},
	{"ROOD", 4, 102681},
	{"NCTUM", 5, 102682},
	{"MARSHALLS", 9, 102683},
	{"ORONO", 5, 102684},
	{"VOETBAL", 7, 102685},
	{"SACHSEN", 7, 102686},
	{"ODSK", 4, 102687},
	{"ILDY", 4, 102688},
	{"LUZON", 5, 102689},
	{"MORAVIA", 7, 102690},
	{"VIDEOCLIP", 9, 102691},
	{"FACIALIZED", 10, 102692},
	{"CENTEX", 6, 102693},
	{"BYZANTIUM", 9, 102694},
	{"BARBS", 5, 102695},
	{"MAPAS", 5, 102696},
	{"HETEROZYGOUS", 12, 102697},
	{"SPECTROMETERS", 13, 102698},
	{"PRINCEVILLE", 11, 102699},
	{"ALTRE", 5, 102700},
	{"SINHALA", 7, 102701},
	{"ZXC", 3, 102702},
	{"XMK", 3, 102703},
	{"XKP", 3, 102704},
	{"VRJ", 3, 102705},
	{"UYX", 3, 102706},
	{"MZZ", 3, 102707},
	{"GZM", 3, 102708},
	{"GGX", 3, 102709},
	{"RAPW", 4, 102710},
	{"LCOF", 4, 102711},
	{"KPEA", 4, 102712},
	{"HIFY", 4, 102713},
	{"INTERSCIENCE", 12, 102714},
	{"VOIGHT", 6, 102715},
	{"PLAYSKOOL", 9, 102716},
	{"REPRESS", 7, 102717},
	{"SURABAYA", 8, 102718},
	{"DOMINI", 6, 102719},
	{"DANILO", 6, 102720},
	{"LORO", 4, 102721},
	{"OUTSTATION", 10, 102722},
	{"NIAID", 5, 102723},
	{"HOMEGAIN", 8, 102724},
	{"AFRICANA", 8, 102725},
	{"ZEPA", 4, 102726},
	{"YERK", 4, 102727},
	{"WNVO", 4, 102728},
	{"SUDE", 4, 102729},
	{"RLOI", 4, 102730},
	{"BILB", 4, 102731},
	{"WINNETKA", 8, 102732},
	{"MOIETY", 6, 102733},
	{"CLIFT", 5, 102734},
	{"SCHNEIER", 8, 102735},
	{"DOBLE", 5, 102736},
	{"SLAPD", 5, 102737},
	{"GENPEPT", 7, 102738},
	{"LANDFORMS", 9, 102739},
	{"STEEPLY", 7, 102740},
	{"URIH", 4, 102741},
	{"PAUG", 4, 102742},
	{"ILGU", 4, 102743},
	{"GFIX", 4, 102744},
	{"DEBUNKING", 9, 102745},
	{"RADHA", 5, 102746},
	{"REPUB", 5, 102747},
	{"CONNECTEDNESS", 13, 102748},
	{"BENALMADENA", 11, 102749},
	{"CALIBRATOR", 10, 102750},
	{"TYPOGRAPHIC", 11, 102751},
	{"GRAPHVIZ", 8, 102752},
	{"DARNED", 6, 102753},
	{"AMPERE", 6, 102754},
	{"NYKE", 4, 102755},
	{"CMUL", 4, 102756},
	{"POWERPLANT", 10, 102757},
	{"PEEKING", 7, 102758},
	{"UNDERWEIGHT", 11, 102759},
	{"NORCAL", 6, 102760},
	{"DENSER", 6, 102761},
	{"DUD", 3, 102762},
	{"FLAMINGOS", 9, 102763},
	{"NUDG", 4, 102764},
	{"LRYS", 4, 102765},
	{"IEUX", 4, 102766},
	{"FUGEES", 6, 102767},
	{"MOORLAND", 8, 102768},
	{"LIGNIN", 6, 102769},
	{"CATTLEMEN", 9, 102770},
	{"BULLFROG", 8, 102771},
	{"EVDO", 4, 102772},
	{"GUSHERS", 7, 102773},
	{"PHARMACOLOGIC", 13, 102774},
	{"RHAZ", 4, 102775},
	{"ODEY", 4, 102776},
	{"GIAF", 4, 102777},
	{"COINCIDENCES", 12, 102778},
	{"RASHI", 5, 102779},
	{"DIVINELY", 8, 102780},
	{"RIKER", 5, 102781},
	{"LAURIN", 6, 102782},
	{"GOLDENROD", 9, 102783},
	{"DEBITS", 6, 102784},
	{"SKIMMED", 7, 102785},
	{"ANIMALIA", 8, 102786},
	{"PAIEMENT", 8, 102787},
	{"EXTENTION", 9, 102788},
	{"ACCESO", 6, 102789},
	{"RFET", 4, 102790},
	{"PAYU", 4, 102791},
	{"OWLH", 4, 102792},
	{"LJER", 4, 102793},
	{"FRYI", 4, 102794},
	{"DSGU", 4, 102795},
	{"ARLF", 4, 102796},
	{"LASSIE", 6, 102797},
	{"SPEWING", 7, 102798},
	{"MADS", 4, 102799},
	{"HEDONISM", 8, 102800},
	{"CONGRATULATION", 14, 102801},
	{"GNUMED", 6, 102802},
	{"MARINETTE", 9, 102803},
	{"ERASERS", 7, 102804},
	{"SEMINARIES", 10, 102805},
	{"MICROCAR", 8, 102806},
	{"TERABYTES", 9, 102807},
	{"LOREAL", 6, 102808},
	{"SARW", 4, 102809},
	{"KUPG", 4, 102810},
	{"HICB", 4, 102811},
	{"FAMY", 4, 102812},
	{"DDAB", 4, 102813},
	{"HOTCHKISS", 9, 102814},
	{"EXCELL", 6, 102815},
	{"BERNESE", 7, 102816},
	{"LEITCH", 6, 102817},
	{"PREPACKAGED", 11, 102818},
	{"STILWELL", 8, 102819},
	{"PUMICE", 6, 102820},
	{"WEID", 4, 102821},
	{"UOCO", 4, 102822},
	{"PISW", 4, 102823},
	{"IPAY", 4, 102824},
	{"DTDR", 4, 102825},
	{"AMJE", 4, 102826},
	{"FACTIVA", 7, 102827},
	{"SAWMILLS", 8, 102828},
	{"TROTTING", 8, 102829},
	{"RESIGNATIONS", 12, 102830},
	{"STATOR", 6, 102831},
	{"AMBUSHED", 8, 102832},
	{"COMBING", 7, 102833},
	{"PIXBUF", 6, 102834},
	{"WOODLEY", 7, 102835},
	{"PIANISTS", 8, 102836},
	{"DOVECOT", 7, 102837},
	{"MENDENHALL", 10, 102838},
	{"BIGGIRLS", 8, 102839},
	{"SUBF", 4, 102840},
	{"MAXO", 4, 102841},
	{"GNMO", 4, 102842},
	{"BBLY", 4, 102843},
	{"INWOOD", 6, 102844},
	{"PAYOR", 5, 102845},
	{"BUSAN", 5, 102846},
	{"INDIUM", 6, 102847},
	{"BASILE", 6, 102848},
	{"MOLEY", 5, 102849},
	{"INTERNAZIONALE", 14, 102850},
	{"WOODCRAFT", 9, 102851},
	{"TRAVESTY", 8, 102852},
	{"XTOU", 4, 102853},
	{"UGAM", 4, 102854},
	{"ODDP", 4, 102855},
	{"LTAV", 4, 102856},
	{"LHAW", 4, 102857},
	{"LBUN", 4, 102858},
	{"IVOF", 4, 102859},
	{"IPDU", 4, 102860},
	{"GJOK", 4, 102861},
	{"EXLO", 4, 102862},
	{"DIBO", 4, 102863},
	{"CCUT", 4, 102864},
	{"ZEMIN", 5, 102865},
	{"PSYCHOPHARMACOLOGY", 18, 102866},
	{"SODERBERGH", 10, 102867},
	{"UNCOATED", 8, 102868},
	{"GUMBALL", 7, 102869},
	{"MUNDY", 5, 102870},
	{"BEWILDERING", 11, 102871},
	{"POLARISATION", 12, 102872},
	{"WILLITS", 7, 102873},
	{"HUNCHBACK", 9, 102874},
	{"NACKED", 6, 102875},
	{"ABACK", 5, 102876},
	{"PNEUMATICS", 10, 102877},
	{"OCCURENCE", 9, 102878},
	{"DEEPENS", 7, 102879},
	{"UPNA", 4, 102880},
	{"OVEK", 4, 102881},
	{"OGOC", 4, 102882},
	{"MFLE", 4, 102883},
	{"HGIL", 4, 102884},
	{"FUNH", 4, 102885},
	{"HOLCOMBE", 8, 102886},
	{"BLATHER", 7, 102887},
	{"CARRUTHERS", 10, 102888},
	{"GRIFF", 5, 102889},
	{"ENACTMENTS", 10, 102890},
	{"CASTAWAY", 8, 102891},
	{"SCALY", 5, 102892},
	{"HEAPED", 6, 102893},
	{"MCGRADY", 7, 102894},
	{"CORREA", 6, 102895},
	{"ESKER", 5, 102896},
	{"MINEFIELD", 9, 102897},
	{"WDEE", 4, 102898},
	{"UCIB", 4, 102899},
	{"UBSL", 4, 102900},
	{"ERUK", 4, 102901},
	{"TIBETANS", 8, 102902},
	{"GIANG", 5, 102903},
	{"YAHYA", 5, 102904},
	{"COOKEVILLE", 10, 102905},
	{"AMNIOTIC", 8, 102906},
	{"DEROGATION", 10, 102907},
	{"RUGW", 4, 102908},
	{"PMUN", 4, 102909},
	{"NLAV", 4, 102910},
	{"LYEU", 4, 102911},
	{"LKBE", 4, 102912},
	{"IFTP", 4, 102913},
	{"BDUR", 4, 102914},
	{"REPOSTING", 9, 102915},
	{"DIMMS", 5, 102916},
	{"SPECSEARCH", 10, 102917},
	{"WEBHOST", 7, 102918},
	{"FANTASTICALLY", 13, 102919},
	{"DYCK", 4, 102920},
	{"COBHAM", 6, 102921},
	{"ORACLES", 7, 102922},
	{"TASCHENGELD", 11, 102923},
	{"OPRY", 4, 102924},
	{"OLKW", 4, 102925},
	{"OEDG", 4, 102926},
	{"IDIG", 4, 102927},
	{"GFIF", 4, 102928},
	{"RPGNET", 6, 102929},
	{"NDSU", 4, 102930},
	{"UNTIED", 6, 102931},
	{"SCARIEST", 8, 102932},
	{"SUPERSYMMETRIC", 14, 102933},
	{"ONLYMOVIES", 10, 102934},
	{"ABSOLUTEHOME", 12, 102935},
	{"QUINCE", 6, 102936},
	{"STATISTIK", 9, 102937},
	{"SATYA", 5, 102938},
	{"FENIX", 5, 102939},
	{"LAGE", 4, 102940},
	{"ZUMI", 4, 102941},
	{"WPAY", 4, 102942},
	{"URGG", 4, 102943},
	{"SPBE", 4, 102944},
	{"HVEZ", 4, 102945},
	{"DLYV", 4, 102946},
	{"BYSN", 4, 102947},
	{"ARIY", 4, 102948},
	{"PALMTOP", 7, 102949},
	{"PROFUSION", 9, 102950},
	{"GONADOTROPIN", 12, 102951},
	{"UNORDERED", 9, 102952},
	{"DROS", 4, 102953},
	{"LEJEUNE", 7, 102954},
	{"REDEFINES", 9, 102955},
	{"WDOC", 4, 102956},
	{"TYID", 4, 102957},
	{"OPKE", 4, 102958},
	{"NYJE", 4, 102959},
	{"NMCM", 4, 102960},
	{"IIMM", 4, 102961},
	{"AGGS", 4, 102962},
	{"CONJECTURES", 11, 102963},
	{"GLINT", 5, 102964},
	{"INCITEMENT", 10, 102965},
	{"BATHROBE", 8, 102966},
	{"AFTERSCHOOL", 11, 102967},
	{"LYNWOOD", 7, 102968},
	{"HANSEL", 6, 102969},
	{"FIGURATIVELY", 12, 102970},
	{"PALACIOS", 8, 102971},
	{"DAYLILY", 7, 102972},
	{"YSUD", 4, 102973},
	{"COSD", 4, 102974},
	{"LIBGNOME", 8, 102975},
	{"NGULTRUM", 8, 102976},
	{"TRICKSTER", 9, 102977},
	{"SUPERSTORES", 11, 102978},
	{"SORCERESS", 9, 102979},
	{"CRANKED", 7, 102980},
	{"WGAR", 4, 102981},
	{"LPWH", 4, 102982},
	{"GRYP", 4, 102983},
	{"HARTSFIELD", 10, 102984},
	{"MERZ", 4, 102985},
	{"ONESTAT", 7, 102986},
	{"LAWRENCEBURG", 12, 102987},
	{"DAVENTRY", 8, 102988},
	{"SUMMERLIN", 9, 102989},
	{"WHITEPAGES", 10, 102990},
	{"STOIC", 5, 102991},
	{"SANGO", 5, 102992},
	{"ENGELHARD", 9, 102993},
	{"MEDELA", 6, 102994},
	{"WWWI", 4, 102995},
	{"PTOJ", 4, 102996},
	{"OPSG", 4, 102997},
	{"FTPL", 4, 102998},
	{"DRYF", 4, 102999},
	{"AUPH", 4, 103000},
	{"RESONATES", 9, 103001},
	{"FASTCOUNTER", 11, 103002},
	{"DRUGSTORES", 10, 103003},
	{"AGGRESSIVENESS", 14, 103004},
	{"OSCILLATORY", 11, 103005},
	{"EUKARYOTES", 10, 103006},
	{"FOOTWORK", 8, 103007},
	{"BARGER", 6, 103008},
	{"MONTANE", 7, 103009},
	{"MALMSTEEN", 9, 103010},
	{"FATIGUED", 8, 103011},
	{"RAILTRACK", 9, 103012},
	{"DYMATIZE", 8, 103013},
	{"UNCONSCIOUSNESS", 15, 103014},
	{"MINEOLA", 7, 103015},
	{"PANOS", 5, 103016},
	{"SKLE", 4, 103017},
	{"PABU", 4, 103018},
	{"IGGR", 4, 103019},
	{"GHYA", 4, 103020},
	{"FURG", 4, 103021},
	{"BBYM", 4, 103022},
	{"AXCA", 4, 103023},
	{"LEXX", 4, 103024},
	{"NETCOMM", 7, 103025},
	{"PREOB", 5, 103026},
	{"ASHTECH", 7, 103027},
	{"BONNEY", 6, 103028},
	{"SCCA", 4, 103029},
	{"VIDEOCASSETTE", 13, 103030},
	{"RADA", 4, 103031},
	{"GUACAMOLE", 9, 103032},
	{"HIPC", 4, 103033},
	{"CHUB", 4, 103034},
	{"ZERD", 4, 103035},
	{"ZALI", 4, 103036},
	{"UIDT", 4, 103037},
	{"RDTY", 4, 103038},
	{"PHWH", 4, 103039},
	{"PAMM", 4, 103040},
	{"BLIQ", 4, 103041},
	{"GLUTAMIC", 8, 103042},
	{"PIECING", 7, 103043},
	{"ALUMS", 5, 103044},
	{"DELEGATING", 10, 103045},
	{"MODOC", 5, 103046},
	{"QUARTO", 6, 103047},
	{"FREEFALL", 8, 103048},
	{"REACTIVATION", 12, 103049},
	{"DESIGNTECHNICA", 14, 103050},
	{"PSAD", 4, 103051},
	{"FPTOOLS", 7, 103052},
	{"STRAUB", 6, 103053},
	{"HEARTWOOD", 9, 103054},
	{"NEWHALL", 7, 103055},
	{"ZWHI", 4, 103056},
	{"RGUT", 4, 103057},
	{"RELR", 4, 103058},
	{"PLOV", 4, 103059},
	{"OWOC", 4, 103060},
	{"MPAU", 4, 103061},
	{"LBAB", 4, 103062},
	{"ADNU", 4, 103063},
	{"VALDES", 6, 103064},
	{"OCHOA", 5, 103065},
	{"IMPROVISE", 9, 103066},
	{"VANG", 4, 103067},
	{"INCIPIENT", 9, 103068},
	{"BOOTLOADER", 10, 103069},
	{"OMEPRAZOLE", 10, 103070},
	{"UNDERDOGS", 9, 103071},
	{"MEHDI", 5, 103072},
	{"VWIL", 4, 103073},
	{"SMCL", 4, 103074},
	{"KIEP", 4, 103075},
	{"GTRY", 4, 103076},
	{"GMYH", 4, 103077},
	{"EYKA", 4, 103078},
	{"SCINTILLATION", 13, 103079},
	{"COLONIALS", 9, 103080},
	{"AVALANCHES", 10, 103081},
	{"CHAFEE", 6, 103082},
	{"HELICES", 7, 103083},
	{"ILTP", 4, 103084},
	{"GMDA", 4, 103085},
	{"CKOL", 4, 103086},
	{"AFOX", 4, 103087},
	{"CHEVAL", 6, 103088},
	{"EXCLUSIONARY", 12, 103089},
	{"CRACKLING", 9, 103090},
	{"OBJECTOR", 8, 103091},
	{"POWERDVD", 8, 103092},
	{"FRANKFURTER", 11, 103093},
	{"ROHNERT", 7, 103094},
	{"SEPTIEMBRE", 10, 103095},
	{"BRINDLE", 7, 103096},
	{"PCANYWHERE", 10, 103097},
	{"CREEDS", 6, 103098},
	{"PPOW", 4, 103099},
	{"MGRI", 4, 103100},
	{"CABY", 4, 103101},
	{"HOMESCHOOLERS", 13, 103102},
	{"LUNESTA", 7, 103103},
	{"VIBS", 4, 103104},
	{"OUTRUN", 6, 103105},
	{"EXTENUATING", 11, 103106},
	{"MOESE", 5, 103107},
	{"TROPOSPHERIC", 12, 103108},
	{"BLACKBERRIES", 12, 103109},
	{"AMISS", 5, 103110},
	{"LEMONGRASS", 10, 103111},
	{"ZIPA", 4, 103112},
	{"ULMC", 4, 103113},
	{"UBSY", 4, 103114},
	{"SPYR", 4, 103115},
	{"GIFH", 4, 103116},
	{"DPOK", 4, 103117},
	{"ARPP", 4, 103118},
	{"CAVERNOUS", 9, 103119},
	{"SNODGRASS", 9, 103120},
	{"SAINSBURYS", 10, 103121},
	{"MMOG", 4, 103122},
	{"NAPOLITANO", 10, 103123},
	{"MINTZ", 5, 103124},
	{"ZAND", 4, 103125},
	{"PUTA", 4, 103126},
	{"BIENVENUE", 9, 103127},
	{"BRUBECK", 7, 103128},
	{"CLEESE", 6, 103129},
	{"BENDERS", 7, 103130},
	{"SATYAJIT", 8, 103131},
	{"UGPA", 4, 103132},
	{"MPEY", 4, 103133},
	{"ECOX", 4, 103134},
	{"BASP", 4, 103135},
	{"SCORELESS", 9, 103136},
	{"DARLINGS", 8, 103137},
	{"ALCO", 4, 103138},
	{"REPRIEVE", 8, 103139},
	{"SEISMOLOGY", 10, 103140},
	{"ROWELL", 6, 103141},
	{"RADIOMETER", 10, 103142},
	{"TAURINE", 7, 103143},
	{"WEYERHAEUSER", 12, 103144},
	{"YONV", 4, 103145},
	{"XLEA", 4, 103146},
	{"SGAU", 4, 103147},
	{"LURB", 4, 103148},
	{"HYPERSPACE", 10, 103149},
	{"MANISTEE", 8, 103150},
	{"SHANTY", 6, 103151},
	{"LEMAY", 5, 103152},
	{"SURVIVORSHIP", 12, 103153},
	{"CLACKMANNANSHIRE", 16, 103154},
	{"PLURALISTIC", 11, 103155},
	{"LAMY", 4, 103156},
	{"MCPU", 4, 103157},
	{"ENFORCEABILITY", 14, 103158},
	{"FORMALIZE", 9, 103159},
	{"UERB", 4, 103160},
	{"TLIQ", 4, 103161},
	{"RILN", 4, 103162},
	{"KKIL", 4, 103163},
	{"KIAL", 4, 103164},
	{"ECWH", 4, 103165},
	{"DAMG", 4, 103166},
	{"SILVERDALE", 10, 103167},
	{"DANIELLA", 8, 103168},
	{"VOIDED", 6, 103169},
	{"MATTIAS", 7, 103170},
	{"RAPPING", 7, 103171},
	{"RELAUNCH", 8, 103172},
	{"OVERCLOCK", 9, 103173},
	{"PROFFERED", 9, 103174},
	{"PROTECTIONISM", 13, 103175},
	{"IERR", 4, 103176},
	{"VILU", 4, 103177},
	{"PFAN", 4, 103178},
	{"OBBR", 4, 103179},
	{"ECDS", 4, 103180},
	{"BLANKING", 8, 103181},
	{"RESIZABLE", 9, 103182},
	{"CHUMSCRUBBER", 12, 103183},
	{"CIFS", 4, 103184},
	{"HAWTIN", 6, 103185},
	{"MSDE", 4, 103186},
	{"ROWENA", 6, 103187},
	{"PHENOBARBITAL", 13, 103188},
	{"RAVENSBURGER", 12, 103189},
	{"DIEHARD", 7, 103190},
	{"CHICKENPOX", 10, 103191},
	{"PHOTOCHEMICAL", 13, 103192},
	{"UXTO", 4, 103193},
	{"TCAK", 4, 103194},
	{"RNVE", 4, 103195},
	{"MMEF", 4, 103196},
	{"APYI", 4, 103197},
	{"CARBO", 5, 103198},
	{"INTERAC", 7, 103199},
	{"OGAWA", 5, 103200},
	{"FLAGPOLE", 8, 103201},
	{"LIVID", 5, 103202},
	{"DISTASTEFUL", 11, 103203},
	{"DELORES", 7, 103204},
	{"DISTINCTIVELY", 13, 103205},
	{"LUFT", 4, 103206},
	{"GEEZER", 6, 103207},
	{"VYFO", 4, 103208},
	{"URJA", 4, 103209},
	{"AWSD", 4, 103210},
	{"HARES", 5, 103211},
	{"SURGEMASTER", 11, 103212},
	{"JORIS", 5, 103213},
	{"ESCAMBIA", 8, 103214},
	{"OVERTURNING", 11, 103215},
	{"ILLEGALS", 8, 103216},
	{"VANDENBERG", 10, 103217},
	{"KOBLENZ", 7, 103218},
	{"TWIM", 4, 103219},
	{"PHMA", 4, 103220},
	{"PBAT", 4, 103221},
	{"NEUG", 4, 103222},
	{"KIOF", 4, 103223},
	{"INUC", 4, 103224},
	{"GWIC", 4, 103225},
	{"EKSG", 4, 103226},
	{"DRJA", 4, 103227},
	{"DDSU", 4, 103228},
	{"CTID", 4, 103229},
	{"SWIVELS", 7, 103230},
	{"POKEY", 5, 103231},
	{"TYDFIL", 6, 103232},
	{"TOOELE", 6, 103233},
	{"ZDL", 3, 103234},
	{"YLQ", 3, 103235},
	{"KJZ", 3, 103236},
	{"ORTHOTIC", 8, 103237},
	{"RINGLING", 8, 103238},
	{"CHIBI", 5, 103239},
	{"ATTESTATION", 11, 103240},
	{"SEIFERT", 7, 103241},
	{"BRAVADO", 7, 103242},
	{"OVERPOWERING", 12, 103243},
	{"RAVINGS", 7, 103244},
	{"TIPPMANN", 8, 103245},
	{"METROPLEX", 9, 103246},
	{"BESTILL", 7, 103247},
	{"HYATTSVILLE", 11, 103248},
	{"CRUM", 4, 103249},
	{"UNKL", 4, 103250},
	{"UMOP", 4, 103251},
	{"RMIO", 4, 103252},
	{"RKAH", 4, 103253},
	{"NNYK", 4, 103254},
	{"NDGY", 4, 103255},
	{"CHTV", 4, 103256},
	{"CHILDLESS", 9, 103257},
	{"ANNECY", 6, 103258},
	{"VOIX", 4, 103259},
	{"TAMILNADU", 9, 103260},
	{"ANTILLIAN", 9, 103261},
	{"WINBACKUP", 9, 103262},
	{"HOLMGREN", 8, 103263},
	{"ALERTNET", 8, 103264},
	{"SEDGEFIELD", 10, 103265},
	{"LYMPHEDEMA", 10, 103266},
	{"ELECTRIFYING", 12, 103267},
	{"BELGRAVIA", 9, 103268},
	{"YROI", 4, 103269},
	{"XIDR", 4, 103270},
	{"MSFU", 4, 103271},
	{"IMSY", 4, 103272},
	{"IGAW", 4, 103273},
	{"IEFU", 4, 103274},
	{"ABEW", 4, 103275},
	{"TOLLAND", 7, 103276},
	{"GRECIAN", 7, 103277},
	{"PROPORTIONED", 12, 103278},
	{"LAVISHLY", 8, 103279},
	{"MOSTRA", 6, 103280},
	{"SMITE", 5, 103281},
	{"NUKER", 5, 103282},
	{"HULME", 5, 103283},
	{"FORTHRIGHT", 10, 103284},
	{"ALIST", 5, 103285},
	{"WANESSA", 7, 103286},
	{"SARIN", 5, 103287},
	{"COURTLAND", 9, 103288},
	{"ITALIANI", 8, 103289},
	{"ARIAT", 5, 103290},
	{"KRITIK", 6, 103291},
	{"XUBE", 4, 103292},
	{"URKY", 4, 103293},
	{"SELK", 4, 103294},
	{"RARN", 4, 103295},
	{"MYAB", 4, 103296},
	{"MNIP", 4, 103297},
	{"KIBB", 4, 103298},
	{"GYUN", 4, 103299},
	{"GCUP", 4, 103300},
	{"DIPU", 4, 103301},
	{"CVEH", 4, 103302},
	{"AILJ", 4, 103303},
	{"FORETOLD", 8, 103304},
	{"DADO", 4, 103305},
	{"MEIGS", 5, 103306},
	{"ENGRAVER", 8, 103307},
	{"SEDALIA", 7, 103308},
	{"SADDLED", 7, 103309},
	{"NUMS", 4, 103310},
	{"EMPHASISING", 11, 103311},
	{"CHUMP", 5, 103312},
	{"UYSM", 4, 103313},
	{"MIEJ", 4, 103314},
	{"LOAC", 4, 103315},
	{"KBED", 4, 103316},
	{"FKEL", 4, 103317},
	{"MONSTERMARKETPLACE", 18, 103318},
	{"TORTURES", 8, 103319},
	{"GALLEN", 6, 103320},
	{"CRUSTS", 6, 103321},
	{"TIBIAL", 6, 103322},
	{"FLAXSEED", 8, 103323},
	{"TRAWLER", 7, 103324},
	{"GUIS", 4, 103325},
	{"BELGIE", 6, 103326},
	{"THEMEN", 6, 103327},
	{"CHARAC", 6, 103328},
	{"PERVEZ", 6, 103329},
	{"REGISTRED", 9, 103330},
	{"MPHT", 4, 103331},
	{"GNGO", 4, 103332},
	{"FHIR", 4, 103333},
	{"GVC", 3, 103334},
	{"BIFOCAL", 7, 103335},
	{"LITTLEST", 8, 103336},
	{"NEWLAND", 7, 103337},
	{"CADASTRE", 8, 103338},
	{"SCHUH", 5, 103339},
	{"JADMIN", 6, 103340},
	{"OBSCURA", 7, 103341},
	{"VAMOS", 5, 103342},
	{"PRU", 3, 103343},
	{"LOGE", 4, 103344},
	{"SACY", 4, 103345},
	{"PYAS", 4, 103346},
	{"MRBO", 4, 103347},
	{"KAYI", 4, 103348},
	{"WDECLARATION", 12, 103349},
	{"PRESUPPOSES", 11, 103350},
	{"SPOTLOCK", 8, 103351},
	{"JALISCO", 7, 103352},
	{"TIMEKEEPING", 11, 103353},
	{"TRICKERY", 8, 103354},
	{"WPC", 3, 103355},
	{"EXTON", 5, 103356},
	{"STATESVILLE", 11, 103357},
	{"TRAPP", 5, 103358},
	{"WESTBOROUGH", 11, 103359},
	{"SABATO", 6, 103360},
	{"ADHERENT", 8, 103361},
	{"KIERKEGAARD", 11, 103362},
	{"VBUT", 4, 103363},
	{"UDYE", 4, 103364},
	{"RCYO", 4, 103365},
	{"MUSW", 4, 103366},
	{"MOKY", 4, 103367},
	{"SOLITAMENTE", 11, 103368},
	{"LINOLEIC", 8, 103369},
	{"TESORO", 6, 103370},
	{"FRAGEN", 6, 103371},
	{"BOHM", 4, 103372},
	{"TESTZUGANG", 10, 103373},
	{"SBUG", 4, 103374},
	{"NDUF", 4, 103375},
	{"FAJA", 4, 103376},
	{"AKSB", 4, 103377},
	{"POPULI", 6, 103378},
	{"ASTROLOGERS", 11, 103379},
	{"WUZ", 3, 103380},
	{"LECCE", 5, 103381},
	{"VETTE", 5, 103382},
	{"AKER", 4, 103383},
	{"NETSTAT", 7, 103384},
	{"RECIEVING", 9, 103385},
	{"UNSOLD", 6, 103386},
	{"UYBU", 4, 103387},
	{"UFFC", 4, 103388},
	{"KABB", 4, 103389},
	{"ISUC", 4, 103390},
	{"CEER", 4, 103391},
	{"AWDR", 4, 103392},
	{"AUGMENTAION", 11, 103393},
	{"VINDICATION", 11, 103394},
	{"MACALESTER", 10, 103395},
	{"BELANGER", 8, 103396},
	{"OPINED", 6, 103397},
	{"SCOOT", 5, 103398},
	{"BINNING", 7, 103399},
	{"BOOTSTRAPPING", 13, 103400},
	{"FALTER", 6, 103401},
	{"CHATTY", 6, 103402},
	{"AUVERGNE", 8, 103403},
	{"INVESCO", 7, 103404},
	{"FRANTZ", 6, 103405},
	{"RHEOLOGY", 8, 103406},
	{"PHILISTINES", 11, 103407},
	{"DOSTOEVSKY", 10, 103408},
	{"MIYAMOTO", 8, 103409},
	{"RLIO", 4, 103410},
	{"NVAU", 4, 103411},
	{"BYEW", 4, 103412},
	{"RETAINERS", 9, 103413},
	{"TENER", 5, 103414},
	{"CALLIN", 6, 103415},
	{"CARDIOTHORACIC", 14, 103416},
	{"PREFETCH", 8, 103417},
	{"FOREHAND", 8, 103418},
	{"CHERBOURG", 9, 103419},
	{"IMPERFECTION", 12, 103420},
	{"BOLSTERS", 8, 103421},
	{"ELASTICITIES", 12, 103422},
	{"RSYR", 4, 103423},
	{"ILSG", 4, 103424},
	{"FPON", 4, 103425},
	{"BAYLEY", 6, 103426},
	{"SURA", 4, 103427},
	{"PATACA", 6, 103428},
	{"SORROWFUL", 9, 103429},
	{"BASKETRECOVER", 13, 103430},
	{"SACHETS", 7, 103431},
	{"CUNE", 4, 103432},
	{"CELEBRATORY", 11, 103433},
	{"ZENG", 4, 103434},
	{"RASHEED", 7, 103435},
	{"TIMEPIECE", 9, 103436},
	{"LIPOSOMES", 9, 103437},
	{"MANHEIM", 7, 103438},
	{"MISMATCHES", 10, 103439},
	{"GREENBUSH", 9, 103440},
	{"LOVEABLE", 8, 103441},
	{"YGUT", 4, 103442},
	{"LHUB", 4, 103443},
	{"LALC", 4, 103444},
	{"IGPE", 4, 103445},
	{"FNEB", 4, 103446},
	{"EYKO", 4, 103447},
	{"ERBT", 4, 103448},
	{"BESB", 4, 103449},
	{"SUPERCONDUCTOR", 14, 103450},
	{"UNCHANGING", 10, 103451},
	{"BESTBUY", 7, 103452},
	{"ROTEL", 5, 103453},
	{"PREDOMINATE", 11, 103454},
	{"TORTUGA", 7, 103455},
	{"CRISSCROSS", 10, 103456},
	{"WSCE", 4, 103457},
	{"URETHRAL", 8, 103458},
	{"AMAROK", 6, 103459},
	{"KAISERSLAUTERN", 14, 103460},
	{"GLYCOSYLATION", 13, 103461},
	{"DETONATOR", 9, 103462},
	{"IONOSPHERIC", 11, 103463},
	{"VENDOME", 7, 103464},
	{"LOUSIANA", 8, 103465},
	{"WODEHOUSE", 9, 103466},
	{"BYBLOCK", 7, 103467},
	{"RPSP", 4, 103468},
	{"LMAA", 4, 103469},
	{"LLIQ", 4, 103470},
	{"IRKO", 4, 103471},
	{"IPUB", 4, 103472},
	{"EWEU", 4, 103473},
	{"SNOWDEN", 7, 103474},
	{"PINOUT", 6, 103475},
	{"ARISTON", 7, 103476},
	{"TOEIC", 5, 103477},
	{"MOLESTED", 8, 103478},
	{"PAULDING", 8, 103479},
	{"SURV", 4, 103480},
	{"MULTIMILLION", 12, 103481},
	{"FMU", 3, 103482},
	{"INGLE", 5, 103483},
	{"SLAVA", 5, 103484},
	{"TITRES", 6, 103485},
	{"MOLSON", 6, 103486},
	{"SCALPEL", 7, 103487},
	{"FAERIES", 7, 103488},
	{"VILF", 4, 103489},
	{"TTUM", 4, 103490},
	{"OHYP", 4, 103491},
	{"LHID", 4, 103492},
	{"SMARTWOOL", 9, 103493},
	{"BANDUNG", 7, 103494},
	{"FASCIAS", 7, 103495},
	{"OCCAM", 5, 103496},
	{"HYENA", 5, 103497},
	{"REIP", 4, 103498},
	{"PUCC", 4, 103499},
	{"LLLU", 4, 103500},
	{"WEDLOCK", 7, 103501},
	{"YELLO", 5, 103502},
	{"YNYSOEDD", 8, 103503},
	{"JUDAIC", 6, 103504},
	{"COWLES", 6, 103505},
	{"LORIE", 5, 103506},
	{"ERSTWHILE", 9, 103507},
	{"DAFFY", 5, 103508},
	{"STYLER", 6, 103509},
	{"INTERNETWORK", 12, 103510},
	{"DOOCE", 5, 103511},
	{"LINQ", 4, 103512},
	{"LEXAN", 5, 103513},
	{"BABYLISS", 8, 103514},
	{"BRITAINS", 8, 103515},
	{"WNPH", 4, 103516},
	{"UEZC", 4, 103517},
	{"RRIP", 4, 103518},
	{"DHUD", 4, 103519},
	{"OBTUSE", 6, 103520},
	{"TAPPAN", 6, 103521},
	{"CAUDAL", 6, 103522},
	{"WHITEFIELD", 10, 103523},
	{"STERNLY", 7, 103524},
	{"FREETDS", 7, 103525},
	{"CHANTED", 7, 103526},
	{"MSWORD", 6, 103527},
	{"KLIV", 4, 103528},
	{"COLLABNET", 9, 103529},
	{"BLURS", 5, 103530},
	{"JONSON", 6, 103531},
	{"SPIRALING", 9, 103532},
	{"MSUG", 4, 103533},
	{"BUYL", 4, 103534},
	{"KLUG", 4, 103535},
	{"SAVOUR", 6, 103536},
	{"NUTTE", 5, 103537},
	{"FRIULI", 6, 103538},
	{"STABS", 5, 103539},
	{"BLACKLIGHT", 10, 103540},
	{"CHLORPHENIRAMINE", 16, 103541},
	{"CHOWDHURY", 9, 103542},
	{"KRSNA", 5, 103543},
	{"SYSU", 4, 103544},
	{"OLIL", 4, 103545},
	{"MEXA", 4, 103546},
	{"KOOTENAI", 8, 103547},
	{"DERICK", 6, 103548},
	{"MODELLER", 8, 103549},
	{"DELIMITERS", 10, 103550},
	{"SILVERCHAIR", 11, 103551},
	{"LUCHTZAK", 8, 103552},
	{"STURBRIDGE", 10, 103553},
	{"SCIENCEDAILY", 12, 103554},
	{"BLINKO", 6, 103555},
	{"INDECENCY", 9, 103556},
	{"LUPINE", 6, 103557},
	{"LINGERED", 8, 103558},
	{"LAGP", 4, 103559},
	{"HAUC", 4, 103560},
	{"DYSW", 4, 103561},
	{"DFIB", 4, 103562},
	{"ELKE", 4, 103563},
	{"NITROGLYCERIN", 13, 103564},
	{"FEASTING", 8, 103565},
	{"BODA", 4, 103566},
	{"EMINIMALLS", 10, 103567},
	{"DECAPITATED", 11, 103568},
	{"GOURDE", 6, 103569},
	{"LANSDALE", 8, 103570},
	{"GELATO", 6, 103571},
	{"WLL", 3, 103572},
	{"ROADBLOCK", 9, 103573},
	{"SUFFOCATION", 11, 103574},
	{"INDEMNIFIED", 11, 103575},
	{"LOLLIPOPS", 9, 103576},
	{"GENENTECH", 9, 103577},
	{"ROEV", 4, 103578},
	{"FSOD", 4, 103579},
	{"FMYG", 4, 103580},
	{"DEWATERING", 10, 103581},
	{"STRUCTION", 9, 103582},
	{"LUSK", 4, 103583},
	{"GILSON", 6, 103584},
	{"TELEPATHY", 9, 103585},
	{"MICROSECONDS", 12, 103586},
	{"SOFTEST", 7, 103587},
	{"SNIFFED", 7, 103588},
	{"LUFTWAFFE", 9, 103589},
	{"DFM", 3, 103590},
	{"VOLKL", 5, 103591},
	{"LURKS", 5, 103592},
	{"LIQUIDATE", 9, 103593},
	{"STALLINGS", 9, 103594},
	{"GORDAS", 6, 103595},
	{"SHOPLIFTING", 11, 103596},
	{"YSEQ", 4, 103597},
	{"WOEF", 4, 103598},
	{"POFK", 4, 103599},
	{"FWRE", 4, 103600},
	{"MAYBERRY", 8, 103601},
	{"KLICK", 5, 103602},
	{"BABBLER", 7, 103603},
	{"RETINOIC", 8, 103604},
	{"HANLON", 6, 103605},
	{"MEEDIO", 6, 103606},
	{"BAYAREA", 7, 103607},
	{"PEFI", 4, 103608},
	{"ILIU", 4, 103609},
	{"HEVF", 4, 103610},
	{"TENSES", 6, 103611},
	{"LAWLESSNESS", 11, 103612},
	{"CATALOGO", 8, 103613},
	{"EEYORE", 6, 103614},
	{"HOTELL", 6, 103615},
	{"TIGHTENS", 8, 103616},
	{"SPOOKS", 6, 103617},
	{"PERRIS", 6, 103618},
	{"CLONIDINE", 9, 103619},
	{"CHWILIO", 7, 103620},
	{"NTHUM", 5, 103621},
	{"PYRENE", 6, 103622},
	{"BERNOULLI", 9, 103623},
	{"PREFAB", 6, 103624},
	{"BEADWORK", 8, 103625},
	{"RECOLLECT", 9, 103626},
	{"POSTMORTEM", 10, 103627},
	{"BRICKELL", 8, 103628},
	{"WSOV", 4, 103629},
	{"OUTNUMBER", 9, 103630},
	{"ERNMENT", 7, 103631},
	{"PROVOCATEUR", 11, 103632},
	{"ALORS", 5, 103633},
	{"ROSENKRAENZER", 13, 103634},
	{"REWROTE", 7, 103635},
	{"ULOW", 4, 103636},
	{"OVCO", 4, 103637},
	{"NFLF", 4, 103638},
	{"LIFS", 4, 103639},
	{"LDIW", 4, 103640},
	{"EPSD", 4, 103641},
	{"EFME", 4, 103642},
	{"DOAD", 4, 103643},
	{"HYNIX", 5, 103644},
	{"RECONFIGURED", 12, 103645},
	{"GREDDY", 6, 103646},
	{"UNIONIZED", 9, 103647},
	{"ZENIT", 5, 103648},
	{"TEJADA", 6, 103649},
	{"PROJECTILES", 11, 103650},
	{"HEURES", 6, 103651},
	{"LARCH", 5, 103652},
	{"WSMS", 4, 103653},
	{"UHEL", 4, 103654},
	{"NMTV", 4, 103655},
	{"BOVI", 4, 103656},
	{"AIKU", 4, 103657},
	{"YEASTS", 6, 103658},
	{"TECHED", 6, 103659},
	{"FLORIDIAN", 9, 103660},
	{"PRATHER", 7, 103661},
	{"INTERROGATORIES", 15, 103662},
	{"CONANT", 6, 103663},
	{"INTERROGATIONS", 14, 103664},
	{"MUTTERING", 9, 103665},
	{"SEAFLOOR", 8, 103666},
	{"ALDI", 4, 103667},
	{"SLIK", 4, 103668},
	{"JAVALOBBY", 9, 103669},
	{"LAFFERTY", 8, 103670},
	{"PREFRONTAL", 10, 103671},
	{"HADDAWAY", 8, 103672},
	{"SCUN", 4, 103673},
	{"PTUO", 4, 103674},
	{"POVA", 4, 103675},
	{"MRDE", 4, 103676},
	{"BBYR", 4, 103677},
	{"ICCPR", 5, 103678},
	{"HITCHHIKERS", 11, 103679},
	{"KENKO", 5, 103680},
	{"TRANE", 5, 103681},
	{"PROLIFERATING", 13, 103682},
	{"ACCEPTANCES", 11, 103683},
	{"BATTISTA", 8, 103684},
	{"DISCUSSANT", 10, 103685},
	{"SITUS", 5, 103686},
	{"IMPATIENTLY", 11, 103687},
	{"SHASHI", 6, 103688},
	{"NAGLE", 5, 103689},
	{"CLUBWEAR", 8, 103690},
	{"PIMLICO", 7, 103691},
	{"GATEKEEPERS", 11, 103692},
	{"YEER", 4, 103693},
	{"VASQ", 4, 103694},
	{"UKKA", 4, 103695},
	{"SAWK", 4, 103696},
	{"RUHA", 4, 103697},
	{"RAKT", 4, 103698},
	{"MLOA", 4, 103699},
	{"LULO", 4, 103700},
	{"LUHA", 4, 103701},
	{"BUFFING", 7, 103702},
	{"SUSPECTING", 10, 103703},
	{"SIBSAGAR", 8, 103704},
	{"PHYSIO", 6, 103705},
	{"BOLES", 5, 103706},
	{"VOYUSER", 7, 103707},
	{"BUSSINESS", 9, 103708},
	{"DESSOUS", 7, 103709},
	{"RECIFE", 6, 103710},
	{"RECHARGED", 9, 103711},
	{"ANWR", 4, 103712},
	{"ETTER", 5, 103713},
	{"ALINE", 5, 103714},
	{"DISJOINTED", 10, 103715},
	{"COMPATABLE", 10, 103716},
	{"YEWH", 4, 103717},
	{"RABN", 4, 103718},
	{"PNAM", 4, 103719},
	{"LKEL", 4, 103720},
	{"INUU", 4, 103721},
	{"HBYR", 4, 103722},
	{"PHAR", 4, 103723},
	{"LIRC", 4, 103724},
	{"SEIZES", 6, 103725},
	{"VIRGINA", 7, 103726},
	{"PAGANINI", 8, 103727},
	{"RUBBERIZED", 10, 103728},
	{"CALEDONIANEW", 12, 103729},
	{"REINE", 5, 103730},
	{"INEQUITY", 8, 103731},
	{"SIMULINK", 8, 103732},
	{"VACATIONERS", 11, 103733},
	{"VARESE", 6, 103734},
	{"UMDU", 4, 103735},
	{"MEAK", 4, 103736},
	{"IFYE", 4, 103737},
	{"GTIR", 4, 103738},
	{"GCOW", 4, 103739},
	{"FPRU", 4, 103740},
	{"AMIY", 4, 103741},
	{"LUANG", 5, 103742},
	{"ZAWAHIRI", 8, 103743},
	{"TRIOMPHE", 8, 103744},
	{"GRIL", 4, 103745},
	{"EUGENIO", 7, 103746},
	{"THEBES", 6, 103747},
	{"ARCHIVIO", 8, 103748},
	{"REALMEDIA", 9, 103749},
	{"ZGB", 3, 103750},
	{"YCQ", 3, 103751},
	{"XVG", 3, 103752},
	{"WVK", 3, 103753},
	{"KZR", 3, 103754},
	{"JYP", 3, 103755},
	{"JXX", 3, 103756},
	{"JFY", 3, 103757},
	{"JENIN", 5, 103758},
	{"YSSM", 4, 103759},
	{"RYEO", 4, 103760},
	{"CAJO", 4, 103761},
	{"HENRICO", 7, 103762},
	{"DOER", 4, 103763},
	{"PANDEMONIUM", 11, 103764},
	{"CLOISONNE", 9, 103765},
	{"CJC", 3, 103766},
	{"DOWNPAYMENT", 11, 103767},
	{"PRABHUPADA", 10, 103768},
	{"VYTR", 4, 103769},
	{"UMOS", 4, 103770},
	{"UDEK", 4, 103771},
	{"REUB", 4, 103772},
	{"LVEE", 4, 103773},
	{"IPEB", 4, 103774},
	{"GNLE", 4, 103775},
	{"BYWAY", 5, 103776},
	{"EDITORE", 7, 103777},
	{"GAETANO", 7, 103778},
	{"MRAZ", 4, 103779},
	{"TAICHUNG", 8, 103780},
	{"MVM", 3, 103781},
	{"BAYWATCH", 8, 103782},
	{"RDTS", 4, 103783},
	{"PYAT", 4, 103784},
	{"PHEU", 4, 103785},
	{"MHEB", 4, 103786},
	{"LUMD", 4, 103787},
	{"KEIC", 4, 103788},
	{"EFTV", 4, 103789},
	{"DYDU", 4, 103790},
	{"ADUB", 4, 103791},
	{"LEGE", 4, 103792},
	{"LOTHAR", 6, 103793},
	{"PLEAT", 5, 103794},
	{"LUCIASAINT", 10, 103795},
	{"THORENS", 7, 103796},
	{"REINVENTED", 10, 103797},
	{"WETHERBY", 8, 103798},
	{"IWEB", 4, 103799},
	{"SWEEPERS", 8, 103800},
	{"WTOK", 4, 103801},
	{"TVOR", 4, 103802},
	{"PGOV", 4, 103803},
	{"PAYY", 4, 103804},
	{"MBUY", 4, 103805},
	{"LIMF", 4, 103806},
	{"KSJO", 4, 103807},
	{"GPLO", 4, 103808},
	{"APHASIA", 7, 103809},
	{"RAVISHED", 8, 103810},
	{"AIXAM", 5, 103811},
	{"COHOSH", 6, 103812},
	{"MECHWARRIOR", 11, 103813},
	{"EREADER", 7, 103814},
	{"DISCERNED", 9, 103815},
	{"SCISSORHANDS", 12, 103816},
	{"DEHRADOON", 9, 103817},
	{"SEULEMENT", 9, 103818},
	{"MAOISTS", 7, 103819},
	{"IRREPLACEABLE", 13, 103820},
	{"WAITRESSES", 10, 103821},
	{"ICICLES", 7, 103822},
	{"FANATICISM", 10, 103823},
	{"YPOG", 4, 103824},
	{"PWRI", 4, 103825},
	{"OFGM", 4, 103826},
	{"MLOU", 4, 103827},
	{"DTUC", 4, 103828},
	{"DSAK", 4, 103829},
	{"DANSKE", 6, 103830},
	{"LITEM", 5, 103831},
	{"FESCUE", 6, 103832},
	{"TITOLO", 6, 103833},
	{"BELGRAVE", 8, 103834},
	{"MAROOCHYDORE", 12, 103835},
	{"RTSP", 4, 103836},
	{"SPEARMAN", 8, 103837},
	{"FOOMATIC", 8, 103838},
	{"BUSLINK", 7, 103839},
	{"FLAMED", 6, 103840},
	{"ELENCO", 6, 103841},
	{"SOFTPHONE", 9, 103842},
	{"SMVP", 4, 103843},
	{"PDON", 4, 103844},
	{"MFIT", 4, 103845},
	{"LEKT", 4, 103846},
	{"DVDI", 4, 103847},
	{"GODSEND", 7, 103848},
	{"PEDS", 4, 103849},
	{"DOORMAN", 7, 103850},
	{"COUNTERCLOCKWISE", 16, 103851},
	{"OXYGENATED", 10, 103852},
	{"ISLANDNORTHERN", 14, 103853},
	{"RUBBERS", 7, 103854},
	{"EDER", 4, 103855},
	{"SWOOSH", 6, 103856},
	{"PACIFIQUE", 9, 103857},
	{"ANDEREN", 7, 103858},
	{"ORDINATEUR", 10, 103859},
	{"TREASURERS", 10, 103860},
	{"DPL", 3, 103861},
	{"ERADICATING", 11, 103862},
	{"EASTHAM", 7, 103863},
	{"REHEARSED", 9, 103864},
	{"OLYI", 4, 103865},
	{"EWNU", 4, 103866},
	{"EERJ", 4, 103867},
	{"BOYR", 4, 103868},
	{"UTERO", 5, 103869},
	{"OBSERVABLES", 11, 103870},
	{"ALIX", 4, 103871},
	{"BIGBOOBS", 8, 103872},
	{"IMPLAUSIBLE", 11, 103873},
	{"IFIP", 4, 103874},
	{"OYBO", 4, 103875},
	{"IPGO", 4, 103876},
	{"DPMA", 4, 103877},
	{"LOCKLEAR", 8, 103878},
	{"WMU", 3, 103879},
	{"OUTRAGEOUSLY", 12, 103880},
	{"XLIB", 4, 103881},
	{"POSTGIS", 7, 103882},
	{"KNEBEL", 6, 103883},
	{"BAZZILL", 7, 103884},
	{"BAGDAD", 6, 103885},
	{"FENTANYL", 8, 103886},
	{"CREAMERY", 8, 103887},
	{"ISLANDSVIRGIN", 13, 103888},
	{"PETTICOAT", 9, 103889},
	{"TOBAGOTURKS", 11, 103890},
	{"VERDECENTRAL", 12, 103891},
	{"MIQUELONUNITED", 14, 103892},
	{"RADIOGRAPHS", 11, 103893},
	{"INHABITING", 10, 103894},
	{"ARVIND", 6, 103895},
	{"SUBSEA", 6, 103896},
	{"SVIG", 4, 103897},
	{"MELW", 4, 103898},
	{"JOIC", 4, 103899},
	{"AMVA", 4, 103900},
	{"ISLANDSCHILECOLOMBIACOSTA", 25, 103901},
	{"RICOSAINT", 9, 103902},
	{"REPUBLICECUADOREL", 17, 103903},
	{"NORSTAR", 7, 103904},
	{"UNRESTRAINED", 12, 103905},
	{"CADHERIN", 8, 103906},
	{"LEONESOMALIASOUTH", 17, 103907},
	{"AFRICAST", 8, 103908},
	{"RICACUBADOMINICADOMINICAN", 25, 103909},
	{"SAMOAAUSTRALIACOOK", 18, 103910},
	{"SALVADORFALKLAND", 16, 103911},
	{"ZEALANDNIUENORFOLK", 18, 103912},
	{"KINGDOMVATICAN", 14, 103913},
	{"FASOBURUNDICAMEROONCAPE", 23, 103914},
	{"ANGUILLASURINAMETRINIDAD", 24, 103915},
	{"ISLANDSMICRONESIANAURUNEW", 25, 103916},
	{"ARABIASINGAPORESRI", 18, 103917},
	{"TIMORHONG", 9, 103918},
	{"MARINOSLOVAKIA", 14, 103919},
	{"FEDERATIONSAN", 13, 103920},
	{"BISSAUIVORY", 11, 103921},
	{"PYGTK", 5, 103922},
	{"GUINEAPITCAIRNPOLYNESIA", 23, 103923},
	{"SAMOASOLOMON", 12, 103924},
	{"INJURES", 7, 103925},
	{"TRIENNIAL", 9, 103926},
	{"KUWAITKYRGYZ", 12, 103927},
	{"EMIRATESUZBEKISTANVIET", 22, 103928},
	{"BOTHA", 5, 103929},
	{"PIGTAIL", 7, 103930},
	{"ANGUILLAANTIGUA", 15, 103931},
	{"NITROX", 6, 103932},
	{"CONSTRICTION", 12, 103933},
	{"APPRAISING", 10, 103934},
	{"ENTHRALLED", 10, 103935},
	{"DANKO", 5, 103936},
	{"SAHARAZAMBIAZIMBABWE", 20, 103937},
	{"NAMYEMEN", 8, 103938},
	{"STATEYUGOSLAVIA", 15, 103939},
	{"SKRU", 4, 103940},
	{"PTEC", 4, 103941},
	{"PAFR", 4, 103942},
	{"CRYL", 4, 103943},
	{"RELOADS", 7, 103944},
	{"STRAYS", 6, 103945},
	{"WEISMAN", 7, 103946},
	{"PLACA", 5, 103947},
	{"FOETUS", 6, 103948},
	{"PHILLIPINES", 11, 103949},
	{"ASTERACEAE", 10, 103950},
	{"ANYWHO", 6, 103951},
	{"DATTA", 5, 103952},
	{"CGM", 3, 103953},
	{"DUFOUR", 6, 103954},
	{"PUNTER", 6, 103955},
	{"BYPASSES", 8, 103956},
	{"WARRNAMBOOL", 11, 103957},
	{"YOBE", 4, 103958},
	{"SLYV", 4, 103959},
	{"RIFN", 4, 103960},
	{"MLEE", 4, 103961},
	{"HYPH", 4, 103962},
	{"DOAW", 4, 103963},
	{"CKAI", 4, 103964},
	{"BSYS", 4, 103965},
	{"ATRAZINE", 8, 103966},
	{"DOLLIES", 7, 103967},
	{"APPROXI", 7, 103968},
	{"STREETSCAPE", 11, 103969},
	{"INDICIA", 7, 103970},
	{"EMBROILED", 9, 103971},
	{"HEADRESTS", 9, 103972},
	{"EXCISED", 7, 103973},
	{"GROUNDFISH", 10, 103974},
	{"TOUSSAINT", 9, 103975},
	{"JEFFERIES", 9, 103976},
	{"COMMITTERS", 10, 103977},
	{"YMBA", 4, 103978},
	{"WHYR", 4, 103979},
	{"OWDC", 4, 103980},
	{"LRUG", 4, 103981},
	{"KJON", 4, 103982},
	{"IMVI", 4, 103983},
	{"HIBB", 4, 103984},
	{"DAUC", 4, 103985},
	{"SWASH", 5, 103986},
	{"ARMISTICE", 9, 103987},
	{"UDELL", 5, 103988},
	{"ELLERY", 6, 103989},
	{"AMBROSIO", 8, 103990},
	{"STEINBACH", 9, 103991},
	{"SYNOPSYS", 8, 103992},
	{"CLICCA", 6, 103993},
	{"BTNG", 4, 103994},
	{"MATTESON", 8, 103995},
	{"XTBE", 4, 103996},
	{"RLDY", 4, 103997},
	{"ONWW", 4, 103998},
	{"DAMPED", 6, 103999},
	{"CLAPP", 5, 104000},
	{"FRRE", 4, 104001},
	{"MARZOCCHI", 9, 104002},
	{"STRATEGO", 8, 104003},
	{"SOUTHERNERS", 11, 104004},
	{"AUBUSSON", 8, 104005},
	{"FISSURES", 8, 104006},
	{"BORGATA", 7, 104007},
	{"UGRO", 4, 104008},
	{"TRYY", 4, 104009},
	{"OFUC", 4, 104010},
	{"LIPL", 4, 104011},
	{"DEZO", 4, 104012},
	{"CTVS", 4, 104013},
	{"AWUN", 4, 104014},
	{"CLINCHED", 8, 104015},
	{"ASTRAGALUS", 10, 104016},
	{"COPAYMENT", 9, 104017},
	{"WILMETTE", 8, 104018},
	{"INOPERATIVE", 11, 104019},
	{"EGGLESTON", 9, 104020},
	{"RIVERINE", 8, 104021},
	{"FORLORN", 7, 104022},
	{"APOLOGETIC", 10, 104023},
	{"ABSOLUTION", 10, 104024},
	{"RMTA", 4, 104025},
	{"RMOC", 4, 104026},
	{"IXBU", 4, 104027},
	{"CCOV", 4, 104028},
	{"VANCOMYCIN", 10, 104029},
	{"FLUIDITY", 8, 104030},
	{"CARNELL", 7, 104031},
	{"INORDINATE", 10, 104032},
	{"TANGA", 5, 104033},
	{"CROSSVILLE", 10, 104034},
	{"FOXWOODS", 8, 104035},
	{"BIRDY", 5, 104036},
	{"BURDETT", 7, 104037},
	{"LVEW", 4, 104038},
	{"DRCA", 4, 104039},
	{"CLITHEROE", 9, 104040},
	{"DATAPRODUCTS", 12, 104041},
	{"PHOTOBLOGS", 10, 104042},
	{"CLANK", 5, 104043},
	{"WHACKED", 7, 104044},
	{"CREASING", 8, 104045},
	{"AUTOMATICA", 10, 104046},
	{"INDIVIDUALISTIC", 15, 104047},
	{"CABOCHON", 8, 104048},
	{"RLOP", 4, 104049},
	{"RGYG", 4, 104050},
	{"GONK", 4, 104051},
	{"CTCE", 4, 104052},
	{"LADYS", 5, 104053},
	{"METICAL", 7, 104054},
	{"CONSEILS", 8, 104055},
	{"MARTS", 5, 104056},
	{"MUNCHEN", 7, 104057},
	{"LEANER", 6, 104058},
	{"OBRA", 4, 104059},
	{"TISDALE", 7, 104060},
	{"BRACKETED", 9, 104061},
	{"BROKERED", 8, 104062},
	{"UMASK", 5, 104063},
	{"KNOWLTON", 8, 104064},
	{"ASHBURY", 7, 104065},
	{"ZEWE", 4, 104066},
	{"UCHJ", 4, 104067},
	{"SYGO", 4, 104068},
	{"NDWY", 4, 104069},
	{"MIFO", 4, 104070},
	{"LYIE", 4, 104071},
	{"ESCM", 4, 104072},
	{"RUBBERTITE", 10, 104073},
	{"BARNSTAPLE", 10, 104074},
	{"ALIPHATIC", 9, 104075},
	{"KEIZER", 6, 104076},
	{"MONOCHROMATIC", 13, 104077},
	{"HEADLEY", 7, 104078},
	{"KCONTROL", 8, 104079},
	{"NEXTLINE", 8, 104080},
	{"ARTEMISIA", 9, 104081},
	{"TKAM", 4, 104082},
	{"RYOG", 4, 104083},
	{"PPHA", 4, 104084},
	{"OWLP", 4, 104085},
	{"DABC", 4, 104086},
	{"GNUMERIC", 8, 104087},
	{"SLIMMER", 7, 104088},
	{"FERMIONS", 8, 104089},
	{"EVERMORE", 8, 104090},
	{"FLYFISHING", 10, 104091},
	{"ZILW", 4, 104092},
	{"PLAW", 4, 104093},
	{"PEBR", 4, 104094},
	{"MRMI", 4, 104095},
	{"GOWS", 4, 104096},
	{"SAUBER", 6, 104097},
	{"BROOKER", 7, 104098},
	{"LOCOS", 5, 104099},
	{"TRATTORIA", 9, 104100},
	{"KATEGORI", 8, 104101},
	{"BATONS", 6, 104102},
	{"INTERWORKING", 12, 104103},
	{"ENGENDERED", 10, 104104},
	{"WXPYTHON", 8, 104105},
	{"XTREMEMAC", 9, 104106},
	{"MANCHU", 6, 104107},
	{"TECHNEWSWORLD", 13, 104108},
	{"NEWSHOUR", 8, 104109},
	{"FLAVA", 5, 104110},
	{"RUBLE", 5, 104111},
	{"YJOK", 4, 104112},
	{"WNID", 4, 104113},
	{"ULBL", 4, 104114},
	{"MMYG", 4, 104115},
	{"KBYH", 4, 104116},
	{"FCOT", 4, 104117},
	{"DISCONCERTING", 13, 104118},
	{"PRIESTLEY", 9, 104119},
	{"MARGARITAS", 10, 104120},
	{"APPROPRIATING", 13, 104121},
	{"SYDENHAM", 8, 104122},
	{"VITICULTURE", 11, 104123},
	{"PRAGER", 6, 104124},
	{"PICPOST", 7, 104125},
	{"MOTORCOACH", 10, 104126},
	{"WEASLEY", 7, 104127},
	{"SOCIALS", 7, 104128},
	{"CUENCA", 6, 104129},
	{"REMERON", 7, 104130},
	{"VREP", 4, 104131},
	{"PTHU", 4, 104132},
	{"ALYF", 4, 104133},
	{"DETALLES", 8, 104134},
	{"SHINTO", 6, 104135},
	{"ATTENTIONS", 10, 104136},
	{"YOHIMBE", 7, 104137},
	{"SOURCEWARE", 10, 104138},
	{"IPSOS", 5, 104139},
	{"RRDS", 4, 104140},
	{"PLANTFILES", 10, 104141},
	{"ABDUCTIONS", 10, 104142},
	{"AGRAWAL", 7, 104143},
	{"GBUY", 4, 104144},
	{"FJOY", 4, 104145},
	{"DWEJ", 4, 104146},
	{"PATTISON", 8, 104147},
	{"SPANGLER", 8, 104148},
	{"BEHR", 4, 104149},
	{"CRYIN", 5, 104150},
	{"CLACTON", 7, 104151},
	{"REGNO", 5, 104152},
	{"GAWD", 4, 104153},
	{"DIFFUSERS", 9, 104154},
	{"VILG", 4, 104155},
	{"RICY", 4, 104156},
	{"MANQ", 4, 104157},
	{"GNAB", 4, 104158},
	{"INHALING", 8, 104159},
	{"ARTHOUSE", 8, 104160},
	{"STIGLITZ", 8, 104161},
	{"HARKNESS", 8, 104162},
	{"ECONOLINE", 9, 104163},
	{"KICKASS", 7, 104164},
	{"PARKLANDS", 9, 104165},
	{"ELLIPSOID", 9, 104166},
	{"BACKREST", 8, 104167},
	{"CALMER", 6, 104168},
	{"ANDERTON", 8, 104169},
	{"DRX", 3, 104170},
	{"XORA", 4, 104171},
	{"NGEK", 4, 104172},
	{"NDCW", 4, 104173},
	{"LUBG", 4, 104174},
	{"DDYD", 4, 104175},
	{"PASSERS", 7, 104176},
	{"CARNIVORES", 10, 104177},
	{"FLUTTERING", 10, 104178},
	{"IRISHMAN", 8, 104179},
	{"PLAYSETS", 8, 104180},
	{"CALLABLE", 8, 104181},
	{"CHERTOFF", 8, 104182},
	{"ALNWICK", 7, 104183},
	{"KELLERMAN", 9, 104184},
	{"CHARTREUSE", 10, 104185},
	{"BAUMGARTNER", 11, 104186},
	{"TURPIN", 6, 104187},
	{"BRIER", 5, 104188},
	{"RMR", 3, 104189},
	{"CANDLEHOLDER", 12, 104190},
	{"PHOENICIAN", 10, 104191},
	{"DYKI", 4, 104192},
	{"DYFL", 4, 104193},
	{"DUBU", 4, 104194},
	{"CKEI", 4, 104195},
	{"BSLA", 4, 104196},
	{"DDF", 3, 104197},
	{"HUNDREDTH", 9, 104198},
	{"FIRSTBORN", 9, 104199},
	{"MGCP", 4, 104200},
	{"ANALY", 5, 104201},
	{"ALTERMAN", 8, 104202},
	{"READE", 5, 104203},
	{"COVES", 5, 104204},
	{"IMDBPRO", 7, 104205},
	{"CLAXTON", 7, 104206},
	{"ARMES", 5, 104207},
	{"XMPP", 4, 104208},
	{"LIFEHACKER", 10, 104209},
	{"BODIE", 5, 104210},
	{"YRUR", 4, 104211},
	{"XOFH", 4, 104212},
	{"TUMF", 4, 104213},
	{"PAHR", 4, 104214},
	{"OEDW", 4, 104215},
	{"OBDY", 4, 104216},
	{"EBOC", 4, 104217},
	{"EAFP", 4, 104218},
	{"AUDC", 4, 104219},
	{"BETRAYING", 9, 104220},
	{"BAREBOAT", 8, 104221},
	{"RALL", 4, 104222},
	{"WITHAM", 6, 104223},
	{"STAYAMERICA", 11, 104224},
	{"PAMPLONA", 8, 104225},
	{"RHYL", 4, 104226},
	{"MOVILES", 7, 104227},
	{"CDU", 3, 104228},
	{"EMULSIONS", 9, 104229},
	{"PADW", 4, 104230},
	{"OGAW", 4, 104231},
	{"IDDH", 4, 104232},
	{"JAVASERVER", 10, 104233},
	{"BACKWATERS", 10, 104234},
	{"CHAIRING", 8, 104235},
	{"BIRDHOUSES", 10, 104236},
	{"BONEPRONE", 9, 104237},
	{"SCREECH", 7, 104238},
	{"WENDT", 5, 104239},
	{"ZAGH", 4, 104240},
	{"PTGO", 4, 104241},
	{"LAYJ", 4, 104242},
	{"DULO", 4, 104243},
	{"CADU", 4, 104244},
	{"APPW", 4, 104245},
	{"ALYH", 4, 104246},
	{"POPULA", 6, 104247},
	{"TELCOM", 6, 104248},
	{"FETCHES", 7, 104249},
	{"MIKEMANNIX", 10, 104250},
	{"TRADABLE", 8, 104251},
	{"DAMME", 5, 104252},
	{"JAMI", 4, 104253},
	{"MXPX", 4, 104254},
	{"AXILLARY", 8, 104255},
	{"GSXR", 4, 104256},
	{"PERRI", 5, 104257},
	{"LSGU", 4, 104258},
	{"DICW", 4, 104259},
	{"MELB", 4, 104260},
	{"RAAF", 4, 104261},
	{"MAXIMALLY", 9, 104262},
	{"SHAQUILLE", 9, 104263},
	{"USERDATA", 8, 104264},
	{"REGIONALISM", 11, 104265},
	{"SWEEPSTAKE", 10, 104266},
	{"UDALL", 5, 104267},
	{"CLOBBER", 7, 104268},
	{"ENCAPSULATING", 13, 104269},
	{"NODDY", 5, 104270},
	{"CARRILLO", 8, 104271},
	{"YKIR", 4, 104272},
	{"WNYE", 4, 104273},
	{"UDRO", 4, 104274},
	{"DOLM", 4, 104275},
	{"PALTRY", 6, 104276},
	{"ANCHORMAN", 9, 104277},
	{"ANUAL", 5, 104278},
	{"HORROCKS", 8, 104279},
	{"YACC", 4, 104280},
	{"COLONNA", 7, 104281},
	{"BERMUDACANADAGREENLANDST", 24, 104282},
	{"CHABAD", 6, 104283},
	{"MISADVENTURES", 13, 104284},
	{"UGFO", 4, 104285},
	{"SKMF", 4, 104286},
	{"NUSL", 4, 104287},
	{"MBEZ", 4, 104288},
	{"FLUA", 4, 104289},
	{"DIMT", 4, 104290},
	{"DISTRIBU", 8, 104291},
	{"CARELESSNESS", 12, 104292},
	{"THREES", 6, 104293},
	{"BROADSIDE", 9, 104294},
	{"MERITLINE", 9, 104295},
	{"IGURE", 5, 104296},
	{"KAMEO", 5, 104297},
	{"COOKTOPS", 8, 104298},
	{"IMPORTANTE", 10, 104299},
	{"LARGEMOUTH", 10, 104300},
	{"FANFICS", 7, 104301},
	{"MIDS", 4, 104302},
	{"APPSERVER", 9, 104303},
	{"MCCUE", 5, 104304},
	{"ANTICOAGULANT", 13, 104305},
	{"YBUG", 4, 104306},
	{"WHYF", 4, 104307},
	{"DPRU", 4, 104308},
	{"DERQ", 4, 104309},
	{"CIAF", 4, 104310},
	{"DOERS", 5, 104311},
	{"TBLOOD", 6, 104312},
	{"TRAVELSUGGEST", 13, 104313},
	{"TREMOLO", 7, 104314},
	{"TECHNICALITIES", 14, 104315},
	{"GOULASH", 7, 104316},
	{"PHOTOFILE", 9, 104317},
	{"CRAZINESS", 9, 104318},
	{"GROANING", 8, 104319},
	{"PRIZM", 5, 104320},
	{"UMGO", 4, 104321},
	{"PVOT", 4, 104322},
	{"NEDQ", 4, 104323},
	{"LKBU", 4, 104324},
	{"IGOD", 4, 104325},
	{"HJAZ", 4, 104326},
	{"FPIP", 4, 104327},
	{"EDPM", 4, 104328},
	{"BIRE", 4, 104329},
	{"TRAILBLAZERS", 12, 104330},
	{"CREMATORIUM", 11, 104331},
	{"GREENCINE", 9, 104332},
	{"ZVU", 3, 104333},
	{"ZKC", 3, 104334},
	{"VFV", 3, 104335},
	{"UJL", 3, 104336},
	{"QUJ", 3, 104337},
	{"DFZ", 3, 104338},
	{"BECKONS", 7, 104339},
	{"REJOICED", 8, 104340},
	{"SCRUMPTIOUS", 11, 104341},
	{"MILLBRAE", 8, 104342},
	{"VACUUMING", 9, 104343},
	{"ORFORD", 6, 104344},
	{"THROMBOCYTOPENIA", 16, 104345},
	{"PYEN", 4, 104346},
	{"MRLA", 4, 104347},
	{"MAXB", 4, 104348},
	{"KPUT", 4, 104349},
	{"KOWH", 4, 104350},
	{"ITZR", 4, 104351},
	{"SUSPENDER", 9, 104352},
	{"NAKAJIMA", 8, 104353},
	{"IMPRIMER", 8, 104354},
	{"KDEVELOP", 8, 104355},
	{"FILO", 4, 104356},
	{"VALLEE", 6, 104357},
	{"MUNIN", 5, 104358},
	{"HINSON", 6, 104359},
	{"PALPITATIONS", 12, 104360},
	{"TTUL", 4, 104361},
	{"JIMO", 4, 104362},
	{"HYGO", 4, 104363},
	{"DEIC", 4, 104364},
	{"CSEV", 4, 104365},
	{"BCLI", 4, 104366},
	{"CORDURA", 7, 104367},
	{"BLIMP", 5, 104368},
	{"QUICKNESS", 9, 104369},
	{"CELLEX", 6, 104370},
	{"JEUNESSE", 8, 104371},
	{"ALLAPUZHA", 9, 104372},
	{"ENTERTAINS", 10, 104373},
	{"ELTHAM", 6, 104374},
	{"YPEH", 4, 104375},
	{"UINF", 4, 104376},
	{"NYMF", 4, 104377},
	{"NDGM", 4, 104378},
	{"HGUE", 4, 104379},
	{"HDUB", 4, 104380},
	{"FLYP", 4, 104381},
	{"LOOPY", 5, 104382},
	{"LARNE", 5, 104383},
	{"LEAL", 4, 104384},
	{"TURBAN", 6, 104385},
	{"CAPITOLA", 8, 104386},
	{"FREIE", 5, 104387},
	{"INSTITU", 7, 104388},
	{"CECE", 4, 104389},
	{"RITCHEY", 7, 104390},
	{"WCM", 3, 104391},
	{"GOONIES", 7, 104392},
	{"RUFFLES", 7, 104393},
	{"RLOD", 4, 104394},
	{"OYMO", 4, 104395},
	{"OYAC", 4, 104396},
	{"IKAZ", 4, 104397},
	{"GNOC", 4, 104398},
	{"EDCC", 4, 104399},
	{"DYAW", 4, 104400},
	{"CENZ", 4, 104401},
	{"ANKV", 4, 104402},
	{"MARSHALLTOWN", 12, 104403},
	{"SEROLOGICAL", 11, 104404},
	{"RODALE", 6, 104405},
	{"REDISCOVERING", 13, 104406},
	{"INFATUATION", 11, 104407},
	{"ANTENNAACCESSORY", 16, 104408},
	{"GAITERS", 7, 104409},
	{"EDGWARE", 7, 104410},
	{"FUG", 3, 104411},
	{"GETOPT", 6, 104412},
	{"KEISER", 6, 104413},
	{"DUALDISC", 8, 104414},
	{"CARSGUIDE", 9, 104415},
	{"MEISJE", 6, 104416},
	{"XTWA", 4, 104417},
	{"UDOE", 4, 104418},
	{"OULC", 4, 104419},
	{"OTUB", 4, 104420},
	{"LATK", 4, 104421},
	{"IUSX", 4, 104422},
	{"HAJU", 4, 104423},
	{"EKNU", 4, 104424},
	{"COUK", 4, 104425},
	{"GEBEN", 5, 104426},
	{"ZEBRAS", 6, 104427},
	{"NULLA", 5, 104428},
	{"BAIR", 4, 104429},
	{"DISAPPEARANCES", 14, 104430},
	{"BEARDSLEY", 9, 104431},
	{"TRANSP", 6, 104432},
	{"CLEVE", 5, 104433},
	{"CHOMP", 5, 104434},
	{"NEOSHO", 6, 104435},
	{"ZARU", 4, 104436},
	{"YESG", 4, 104437},
	{"TAWR", 4, 104438},
	{"KSFU", 4, 104439},
	{"KASB", 4, 104440},
	{"HEBJ", 4, 104441},
	{"SCOPED", 6, 104442},
	{"ANTISTATIC", 10, 104443},
	{"PLUTARCH", 8, 104444},
	{"CURVING", 7, 104445},
	{"FRENETIC", 8, 104446},
	{"HEATSINKS", 9, 104447},
	{"ALLIUM", 6, 104448},
	{"MISREPRESENT", 12, 104449},
	{"HUMPTY", 6, 104450},
	{"NDTD", 4, 104451},
	{"GGSO", 4, 104452},
	{"MILLWOOD", 8, 104453},
	{"POSTURAL", 8, 104454},
	{"TECMO", 5, 104455},
	{"CONSERVATIONISTS", 16, 104456},
	{"CIPHERTRUST", 11, 104457},
	{"TANKARD", 7, 104458},
	{"STACI", 5, 104459},
	{"JOSLIN", 6, 104460},
	{"FEMAIL", 6, 104461},
	{"MIRRA", 5, 104462},
	{"TOASTY", 6, 104463},
	{"WATP", 4, 104464},
	{"RASV", 4, 104465},
	{"OBOC", 4, 104466},
	{"LIAK", 4, 104467},
	{"CUEF", 4, 104468},
	{"ARPF", 4, 104469},
	{"RPL", 3, 104470},
	{"LOZANO", 6, 104471},
	{"KAMEHAMEHA", 10, 104472},
	{"SETUID", 6, 104473},
	{"MINISTERIO", 10, 104474},
	{"GEILER", 6, 104475},
	{"SHIMONGA", 8, 104476},
	{"HELMA", 5, 104477},
	{"GREINER", 7, 104478},
	{"MANDURAH", 8, 104479},
	{"BUDOKAI", 7, 104480},
	{"CULMINATES", 10, 104481},
	{"LEATHERHEAD", 11, 104482},
	{"AMOROUS", 7, 104483},
	{"SUNGARD", 7, 104484},
	{"NOTIFIABLE", 10, 104485},
	{"KURZ", 4, 104486},
	{"CROOKSTON", 9, 104487},
	{"SHADERS", 7, 104488},
	{"MULTIREGION", 11, 104489},
	{"CONTACTEZ", 9, 104490},
	{"MONDIALE", 8, 104491},
	{"UKSE", 4, 104492},
	{"UFRE", 4, 104493},
	{"RCEV", 4, 104494},
	{"MMOO", 4, 104495},
	{"JOYB", 4, 104496},
	{"HYRI", 4, 104497},
	{"HBUC", 4, 104498},
	{"FYTO", 4, 104499},
	{"ELSQ", 4, 104500},
	{"OVERFLOWED", 10, 104501},
	{"CORRUPTS", 8, 104502},
	{"CRUISIN", 7, 104503},
	{"JESU", 4, 104504},
	{"EXTRAPOLATE", 11, 104505},
	{"WEANED", 6, 104506},
	{"SCENICS", 7, 104507},
	{"ARMCHAIRS", 9, 104508},
	{"DRYLAND", 7, 104509},
	{"APPARTEMENTS", 12, 104510},
	{"URQUHART", 8, 104511},
	{"TERMINFO", 8, 104512},
	{"INCOMPATIBILITIES", 17, 104513},
	{"TANJA", 5, 104514},
	{"TKUR", 4, 104515},
	{"PCOO", 4, 104516},
	{"HYTR", 4, 104517},
	{"GBYD", 4, 104518},
	{"FFAU", 4, 104519},
	{"DWYA", 4, 104520},
	{"DIBR", 4, 104521},
	{"CCAW", 4, 104522},
	{"ABCT", 4, 104523},
	{"PHOTOBUCKET", 11, 104524},
	{"EDSEL", 5, 104525},
	{"PECTIN", 6, 104526},
	{"XARAYA", 6, 104527},
	{"CHIR", 4, 104528},
	{"NODERIVS", 8, 104529},
	{"MERENGUE", 8, 104530},
	{"PUDI", 4, 104531},
	{"FTHF", 4, 104532},
	{"FADJ", 4, 104533},
	{"EUCA", 4, 104534},
	{"DBEQ", 4, 104535},
	{"AGOY", 4, 104536},
	{"VAGUENESS", 9, 104537},
	{"GRUMBLE", 7, 104538},
	{"WRONGED", 7, 104539},
	{"DETTAGLI", 8, 104540},
	{"POLITIQUES", 10, 104541},
	{"FIREFLIES", 9, 104542},
	{"ODENSE", 6, 104543},
	{"RBUM", 4, 104544},
	{"RAAP", 4, 104545},
	{"MSJU", 4, 104546},
	{"HBOL", 4, 104547},
	{"GISK", 4, 104548},
	{"EPEW", 4, 104549},
	{"EGWI", 4, 104550},
	{"CDEL", 4, 104551},
	{"UNDERGARMENTS", 13, 104552},
	{"CONSOLIDATIONS", 14, 104553},
	{"LAPIDUS", 7, 104554},
	{"ENERGIA", 7, 104555},
	{"HOISTING", 8, 104556},
	{"MALEK", 5, 104557},
	{"TAPWAVE", 7, 104558},
	{"SBDC", 4, 104559},
	{"FALSIFIED", 9, 104560},
	{"DIALECTICAL", 11, 104561},
	{"PROSPECTIVELY", 13, 104562},
	{"YWAK", 4, 104563},
	{"YGAG", 4, 104564},
	{"UKUN", 4, 104565},
	{"SKFR", 4, 104566},
	{"MRHE", 4, 104567},
	{"LMSU", 4, 104568},
	{"EKPO", 4, 104569},
	{"BBRA", 4, 104570},
	{"TENNESSEAN", 10, 104571},
	{"REVOCABLE", 9, 104572},
	{"ENTHALPY", 8, 104573},
	{"AWSTATS", 7, 104574},
	{"REFERED", 7, 104575},
	{"TANKLESS", 8, 104576},
	{"WAUS", 4, 104577},
	{"TLIL", 4, 104578},
	{"RNCE", 4, 104579},
	{"RIIB", 4, 104580},
	{"REGY", 4, 104581},
	{"PMCO", 4, 104582},
	{"OWDB", 4, 104583},
	{"NRIB", 4, 104584},
	{"LIFW", 4, 104585},
	{"GWET", 4, 104586},
	{"SCHATZ", 6, 104587},
	{"GENWEB", 6, 104588},
	{"JAVANESE", 8, 104589},
	{"THIRUVANANTHAPURAM", 18, 104590},
	{"ROSIN", 5, 104591},
	{"MUSICS", 6, 104592},
	{"MICROSOUND", 10, 104593},
	{"CYPRIOTS", 8, 104594},
	{"IMPERSONATORS", 13, 104595},
	{"YETL", 4, 104596},
	{"XOPE", 4, 104597},
	{"PHSW", 4, 104598},
	{"KSHM", 4, 104599},
	{"EMKI", 4, 104600},
	{"EDGW", 4, 104601},
	{"HAMLINE", 7, 104602},
	{"LABOURS", 7, 104603},
	{"WEBAPPS", 7, 104604},
	{"MIMS", 4, 104605},
	{"ESPAGNE", 7, 104606},
	{"FLATLY", 6, 104607},
	{"XPP", 3, 104608},
	{"HARSHER", 7, 104609},
	{"TIPPER", 6, 104610},
	{"TSENG", 5, 104611},
	{"INCITING", 8, 104612},
	{"RAFFERTY", 8, 104613},
	{"DIFFSERV", 8, 104614},
	{"PASSPHRASE", 10, 104615},
	{"WCRA", 4, 104616},
	{"RBSW", 4, 104617},
	{"PTBA", 4, 104618},
	{"MYSM", 4, 104619},
	{"MAFU", 4, 104620},
	{"DPIO", 4, 104621},
	{"DALQ", 4, 104622},
	{"RAGA", 4, 104623},
	{"MALLEABLE", 9, 104624},
	{"HYDROCEPHALUS", 13, 104625},
	{"COLSPAN", 7, 104626},
	{"ECRU", 4, 104627},
	{"MITZI", 5, 104628},
	{"SKIPPERS", 8, 104629},
	{"CAVANAGH", 8, 104630},
	{"INDECISION", 10, 104631},
	{"CANDIDIASIS", 11, 104632},
	{"BATHROBES", 9, 104633},
	{"AULT", 4, 104634},
	{"FESSEL", 6, 104635},
	{"SPOKENSOUNDTRACKS", 17, 104636},
	{"SANDPOINT", 9, 104637},
	{"WNVA", 4, 104638},
	{"PDAV", 4, 104639},
	{"OCHW", 4, 104640},
	{"OBYL", 4, 104641},
	{"UNSELFISH", 9, 104642},
	{"MULTITRACK", 10, 104643},
	{"PICKIN", 6, 104644},
	{"WHETSTONE", 9, 104645},
	{"SECU", 4, 104646},
	{"WINDOWBLINDS", 12, 104647},
	{"KELLEHER", 8, 104648},
	{"DONNELL", 7, 104649},
	{"YHAU", 4, 104650},
	{"OKSV", 4, 104651},
	{"NMOW", 4, 104652},
	{"HMAP", 4, 104653},
	{"AMKN", 4, 104654},
	{"WILTS", 5, 104655},
	{"MICROCOMPUTERS", 14, 104656},
	{"WATERCOLOURS", 12, 104657},
	{"STARKE", 6, 104658},
	{"WELLSPRING", 10, 104659},
	{"GULAG", 5, 104660},
	{"OUTLANDER", 9, 104661},
	{"MACAW", 5, 104662},
	{"OPPORTUNITES", 12, 104663},
	{"TWIKIFORMS", 10, 104664},
	{"ARYL", 4, 104665},
	{"ESCENTUALS", 10, 104666},
	{"ALIGHT", 6, 104667},
	{"EPOCHS", 6, 104668},
	{"BARENTS", 7, 104669},
	{"UZHA", 4, 104670},
	{"PSIZ", 4, 104671},
	{"MNFO", 4, 104672},
	{"EWTU", 4, 104673},
	{"TAYLORSVILLE", 12, 104674},
	{"VIEWTIFUL", 9, 104675},
	{"PUBLICALLY", 10, 104676},
	{"SKIATHOS", 8, 104677},
	{"CHEESECAKES", 11, 104678},
	{"FRANCOISE", 9, 104679},
	{"PRIO", 4, 104680},
	{"NOSOTROS", 8, 104681},
	{"GENIAL", 6, 104682},
	{"LANGUES", 7, 104683},
	{"MASSENA", 7, 104684},
	{"MATG", 4, 104685},
	{"HDUN", 4, 104686},
	{"ECFO", 4, 104687},
	{"AIGB", 4, 104688},
	{"BRAUER", 6, 104689},
	{"REVOLVED", 8, 104690},
	{"ISAAK", 5, 104691},
	{"IFAD", 4, 104692},
	{"SILVERSEA", 9, 104693},
	{"SNOWED", 6, 104694},
	{"NORTHWICH", 9, 104695},
	{"JAGER", 5, 104696},
	{"CACHET", 6, 104697},
	{"STEEPLECHASE", 12, 104698},
	{"FORTIFY", 7, 104699},
	{"TEXTRON", 7, 104700},
	{"MONOCYTOGENES", 13, 104701},
	{"MOUSEOVER", 9, 104702},
	{"XMAX", 4, 104703},
	{"NIIGATA", 7, 104704},
	{"VEIG", 4, 104705},
	{"ULCL", 4, 104706},
	{"UEPU", 4, 104707},
	{"RMCR", 4, 104708},
	{"LSJA", 4, 104709},
	{"HUAR", 4, 104710},
	{"EUBI", 4, 104711},
	{"SCHOENBERG", 10, 104712},
	{"FORESTVILLE", 11, 104713},
	{"VERIFICATIONS", 13, 104714},
	{"UNSURPRISINGLY", 14, 104715},
	{"LANGMUIR", 8, 104716},
	{"FLC", 3, 104717},
	{"CHERUBS", 7, 104718},
	{"SOFTWAR", 7, 104719},
	{"ARMATURE", 8, 104720},
	{"YMEG", 4, 104721},
	{"OLPI", 4, 104722},
	{"MUJA", 4, 104723},
	{"KSHU", 4, 104724},
	{"NEWBRIDGE", 9, 104725},
	{"CANZONE", 7, 104726},
	{"NANOWRIMO", 9, 104727},
	{"OPENPGP", 7, 104728},
	{"MURTHY", 6, 104729},
	{"IMPLICATE", 9, 104730},
	{"OPALS", 5, 104731},
	{"SALIX", 5, 104732},
	{"GATEFOLD", 8, 104733},
	{"PRISTINA", 8, 104734},
	{"WLOR", 4, 104735},
	{"TRUP", 4, 104736},
	{"SYPA", 4, 104737},
	{"RGSO", 4, 104738},
	{"OFEY", 4, 104739},
	{"GKAT", 4, 104740},
	{"GIAB", 4, 104741},
	{"EHRM", 4, 104742},
	{"DUKR", 4, 104743},
	{"DNDA", 4, 104744},
	{"AFLC", 4, 104745},
	{"ACUE", 4, 104746},
	{"NUTRITIONALLY", 13, 104747},
	{"JACOBIAN", 8, 104748},
	{"TOLLING", 7, 104749},
	{"GERLACH", 7, 104750},
	{"OFFEREDSERVICES", 15, 104751},
	{"WARTBURG", 8, 104752},
	{"FLEURY", 6, 104753},
	{"UPCE", 4, 104754},
	{"HYIM", 4, 104755},
	{"AVYU", 4, 104756},
	{"PROVISIONED", 11, 104757},
	{"KOOKS", 5, 104758},
	{"SYRIAC", 6, 104759},
	{"PUMPER", 6, 104760},
	{"DIVED", 5, 104761},
	{"WEIMARANER", 10, 104762},
	{"FEHB", 4, 104763},
	{"BUCKING", 7, 104764},
	{"BAFFLES", 7, 104765},
	{"OBVERSE", 7, 104766},
	{"INFAMY", 6, 104767},
	{"DAPPER", 6, 104768},
	{"CDRH", 4, 104769},
	{"TIGL", 4, 104770},
	{"OWEK", 4, 104771},
	{"MUMN", 4, 104772},
	{"IFYC", 4, 104773},
	{"CHTC", 4, 104774},
	{"IPANEMA", 7, 104775},
	{"KEEPMEDIA", 9, 104776},
	{"TWOCHANNEL", 10, 104777},
	{"BELFRY", 6, 104778},
	{"USAC", 4, 104779},
	{"DURABLES", 8, 104780},
	{"ELYSIAN", 7, 104781},
	{"CARBAMAZEPINE", 13, 104782},
	{"WHOOPI", 6, 104783},
	{"PAIGNTON", 8, 104784},
	{"BALDY", 5, 104785},
	{"LINGUS", 6, 104786},
	{"DOWLOADS", 8, 104787},
	{"DNDEBUG", 7, 104788},
	{"AGEXPORTER", 10, 104789},
	{"ZEPO", 4, 104790},
	{"RUFU", 4, 104791},
	{"RRWA", 4, 104792},
	{"LPHR", 4, 104793},
	{"IBBI", 4, 104794},
	{"BTOD", 4, 104795},
	{"ALMR", 4, 104796},
	{"TROUBLESHOOTER", 14, 104797},
	{"TURFGRASS", 9, 104798},
	{"ASHBOURNE", 9, 104799},
	{"ANDORRAN", 8, 104800},
	{"ODIOUS", 6, 104801},
	{"CROCS", 5, 104802},
	{"PLIER", 5, 104803},
	{"SPORTSCENTER", 12, 104804},
	{"LONER", 5, 104805},
	{"LISTSERVE", 9, 104806},
	{"REHEARSING", 10, 104807},
	{"LATENCIES", 9, 104808},
	{"RAQB", 4, 104809},
	{"PSFE", 4, 104810},
	{"ANMB", 4, 104811},
	{"FARRAH", 6, 104812},
	{"SINICA", 6, 104813},
	{"ELLIPSIS", 8, 104814},
	{"WHERES", 6, 104815},
	{"MARQUEES", 8, 104816},
	{"SUTURES", 7, 104817},
	{"REGISTRIEREN", 12, 104818},
	{"PRAGMATICS", 10, 104819},
	{"BROWNSTONE", 10, 104820},
	{"PHAIR", 5, 104821},
	{"HAWKWIND", 8, 104822},
	{"FABRICATOR", 10, 104823},
	{"COMOX", 5, 104824},
	{"INVACARE", 8, 104825},
	{"NTMR", 4, 104826},
	{"MRMU", 4, 104827},
	{"KUPL", 4, 104828},
	{"DIWH", 4, 104829},
	{"TBOGG", 5, 104830},
	{"MCKENDRICK", 10, 104831},
	{"CLYMER", 6, 104832},
	{"BERGERAC", 8, 104833},
	{"DELBERT", 7, 104834},
	{"VAMOSI", 6, 104835},
	{"TRANSFLECTIVE", 13, 104836},
	{"NEWHOUSE", 8, 104837},
	{"NICOLSON", 8, 104838},
	{"OUTPERFORMS", 11, 104839},
	{"AUTOANTIBODIES", 14, 104840},
	{"DECOMPILER", 10, 104841},
	{"SCANIA", 6, 104842},
	{"MACNEIL", 7, 104843},
	{"CYCLED", 6, 104844},
	{"YSOD", 4, 104845},
	{"RGBE", 4, 104846},
	{"NUUM", 4, 104847},
	{"LRAL", 4, 104848},
	{"KATD", 4, 104849},
	{"ITALO", 5, 104850},
	{"PROFI", 5, 104851},
	{"OUTHOUSE", 8, 104852},
	{"AUTOPLAY", 8, 104853},
	{"COBBLED", 7, 104854},
	{"KOMO", 4, 104855},
	{"MONOPHOSPHATE", 13, 104856},
	{"COLUMBA", 7, 104857},
	{"ROMANESQUE", 10, 104858},
	{"MILLEN", 6, 104859},
	{"GENGHIS", 7, 104860},
	{"GOBIERNO", 8, 104861},
	{"VANQUISH", 8, 104862},
	{"VOCALSCOMEDY", 12, 104863},
	{"BARNWELL", 8, 104864},
	{"PHARMACYS", 9, 104865},
	{"STYD", 4, 104866},
	{"NUGA", 4, 104867},
	{"ESCY", 4, 104868},
	{"EIGL", 4, 104869},
	{"XDOCLET", 7, 104870},
	{"GELDOF", 6, 104871},
	{"IMPARTS", 7, 104872},
	{"DANICA", 6, 104873},
	{"DEXTROSE", 8, 104874},
	{"JOGGERS", 7, 104875},
	{"PARAPSYCHOLOGY", 14, 104876},
	{"QUILTER", 7, 104877},
	{"DATADIR", 7, 104878},
	{"ORGIAS", 6, 104879},
	{"LAUNCHPAD", 9, 104880},
	{"ZOUK", 4, 104881},
	{"YBYU", 4, 104882},
	{"TOLP", 4, 104883},
	{"NKAZ", 4, 104884},
	{"IFTG", 4, 104885},
	{"GYEX", 4, 104886},
	{"FNOC", 4, 104887},
	{"EXUB", 4, 104888},
	{"CJOH", 4, 104889},
	{"CINJ", 4, 104890},
	{"CEGL", 4, 104891},
	{"LAUDABLE", 8, 104892},
	{"CATABOLISM", 10, 104893},
	{"ALISSA", 6, 104894},
	{"PRITCHETT", 9, 104895},
	{"ENSENADA", 8, 104896},
	{"LUMINAL", 7, 104897},
	{"INSTITUTIONALIZATION", 20, 104898},
	{"KAHNE", 5, 104899},
	{"PERMEATE", 8, 104900},
	{"THAWING", 7, 104901},
	{"MARTELL", 7, 104902},
	{"VIOLONCELLO", 11, 104903},
	{"TIENEN", 6, 104904},
	{"GUAYAQUIL", 9, 104905},
	{"WRITS", 5, 104906},
	{"VWHE", 4, 104907},
	{"UTSQ", 4, 104908},
	{"RYLL", 4, 104909},
	{"NBEQ", 4, 104910},
	{"ITZB", 4, 104911},
	{"GODP", 4, 104912},
	{"ELMW", 4, 104913},
	{"OMNIPRESENT", 11, 104914},
	{"MATHGROUP", 9, 104915},
	{"TOFINO", 6, 104916},
	{"GESUNDHEIT", 10, 104917},
	{"INCONSEQUENTIAL", 15, 104918},
	{"STRANG", 6, 104919},
	{"INSENSITIVITY", 13, 104920},
	{"DEVIANTS", 8, 104921},
	{"LUMLEY", 6, 104922},
	{"HOVERED", 7, 104923},
	{"DEVOURING", 9, 104924},
	{"IMACS", 5, 104925},
	{"SAMHAIN", 7, 104926},
	{"RENUNCIATION", 12, 104927},
	{"STUNTED", 7, 104928},
	{"RETURNEES", 9, 104929},
	{"AYMAN", 5, 104930},
	{"HEADSHOT", 8, 104931},
	{"FALLSVIEW", 9, 104932},
	{"RSYW", 4, 104933},
	{"FVOI", 4, 104934},
	{"EUMD", 4, 104935},
	{"PERRO", 5, 104936},
	{"ROYALTON", 8, 104937},
	{"REFORMIST", 9, 104938},
	{"PANCHO", 6, 104939},
	{"KEMPTON", 7, 104940},
	{"PVCS", 4, 104941},
	{"MUNCHING", 8, 104942},
	{"FWZ", 3, 104943},
	{"JOBE", 4, 104944},
	{"FUMBLING", 8, 104945},
	{"LCL", 3, 104946},
	{"SERVICEABILITY", 14, 104947},
	{"SOUTHWICK", 9, 104948},
	{"ZDM", 3, 104949},
	{"VZU", 3, 104950},
	{"KXJ", 3, 104951},
	{"JVV", 3, 104952},
	{"JKV", 3, 104953},
	{"FVJ", 3, 104954},
	{"FQF", 3, 104955},
	{"DXZ", 3, 104956},
	{"BQD", 3, 104957},
	{"INOUYE", 6, 104958},
	{"USTAR", 5, 104959},
	{"WRIE", 4, 104960},
	{"WOOC", 4, 104961},
	{"RIXW", 4, 104962},
	{"NRYO", 4, 104963},
	{"LWIC", 4, 104964},
	{"LAWJ", 4, 104965},
	{"EZOR", 4, 104966},
	{"CTUM", 4, 104967},
	{"PREMARIN", 8, 104968},
	{"PURL", 4, 104969},
	{"LASSE", 5, 104970},
	{"FIREPROOF", 9, 104971},
	{"RPF", 3, 104972},
	{"BANAL", 5, 104973},
	{"DEPLOYABLE", 10, 104974},
	{"SOJOURNERS", 10, 104975},
	{"GLENELG", 7, 104976},
	{"RWC", 3, 104977},
	{"LORETO", 6, 104978},
	{"DEVFS", 5, 104979},
	{"TOOLE", 5, 104980},
	{"ADIRONDACKS", 11, 104981},
	{"REARS", 5, 104982},
	{"PORTICO", 7, 104983},
	{"HOLME", 5, 104984},
	{"ITERATORS", 9, 104985},
	{"RGAZ", 4, 104986},
	{"ITYQ", 4, 104987},
	{"ILIL", 4, 104988},
	{"DUEC", 4, 104989},
	{"CVOL", 4, 104990},
	{"HORLOGE", 7, 104991},
	{"BROADS", 6, 104992},
	{"CRNA", 4, 104993},
	{"NAMASTE", 7, 104994},
	{"SERVIS", 6, 104995},
	{"TRANSPORTABLE", 13, 104996},
	{"EXCITES", 7, 104997},
	{"WEASELS", 7, 104998},
	{"PLACARD", 7, 104999},
	{"ARCHI", 5, 105000},
	{"VELLA", 5, 105001},
	{"UNCOOKED", 8, 105002},
	{"KWONG", 5, 105003},
	{"LOLLY", 5, 105004},
	{"QUARTERMASTER", 13, 105005},
	{"URIBE", 5, 105006},
	{"FIELDBUS", 8, 105007},
	{"FEDERLINE", 9, 105008},
	{"WINTERGREEN", 11, 105009},
	{"GUILIN", 6, 105010},
	{"PECULIARLY", 10, 105011},
	{"YSUE", 4, 105012},
	{"WWID", 4, 105013},
	{"RBOE", 4, 105014},
	{"OWGU", 4, 105015},
	{"IFUG", 4, 105016},
	{"CITYGUIDES", 10, 105017},
	{"KYM", 3, 105018},
	{"SEWON", 5, 105019},
	{"SHOUTCAST", 9, 105020},
	{"ERIKSON", 7, 105021},
	{"GRINSTEAD", 9, 105022},
	{"HERMON", 6, 105023},
	{"WEINTRAUB", 9, 105024},
	{"PLACARDS", 8, 105025},
	{"DEPORT", 6, 105026},
	{"TRANSPOSED", 10, 105027},
	{"LEMMAS", 6, 105028},
	{"SLAMMER", 7, 105029},
	{"GLUCK", 5, 105030},
	{"THEOSOPHY", 9, 105031},
	{"GANGA", 5, 105032},
	{"KARMIC", 6, 105033},
	{"INKING", 6, 105034},
	{"RSHC", 4, 105035},
	{"RFOW", 4, 105036},
	{"OGSM", 4, 105037},
	{"KDUE", 4, 105038},
	{"HEWU", 4, 105039},
	{"CAYU", 4, 105040},
	{"SLOVENSKY", 9, 105041},
	{"JITTERS", 7, 105042},
	{"PETSUPPLIES", 11, 105043},
	{"COIMBRA", 7, 105044},
	{"MARIAM", 6, 105045},
	{"THRACE", 6, 105046},
	{"SKBU", 4, 105047},
	{"NYTW", 4, 105048},
	{"IXBE", 4, 105049},
	{"HRAR", 4, 105050},
	{"GOVM", 4, 105051},
	{"FKIR", 4, 105052},
	{"ESPD", 4, 105053},
	{"SYMPATICO", 9, 105054},
	{"NONFATAL", 8, 105055},
	{"SPONG", 5, 105056},
	{"BRM", 3, 105057},
	{"WAISTCOAT", 9, 105058},
	{"VIER", 4, 105059},
	{"MULAN", 5, 105060},
	{"TESTAMENTS", 10, 105061},
	{"VONL", 4, 105062},
	{"SMSP", 4, 105063},
	{"RKIF", 4, 105064},
	{"KFLI", 4, 105065},
	{"EILM", 4, 105066},
	{"DNOG", 4, 105067},
	{"ACPH", 4, 105068},
	{"DOBBINS", 7, 105069},
	{"PERUSAL", 7, 105070},
	{"PETRUS", 6, 105071},
	{"DELVES", 6, 105072},
	{"BILLINGTON", 10, 105073},
	{"CHILDLIKE", 9, 105074},
	{"MML", 3, 105075},
	{"BACKUS", 6, 105076},
	{"SHAMELESSLY", 11, 105077},
	{"NMOL", 4, 105078},
	{"GUAVA", 5, 105079},
	{"SAISON", 6, 105080},
	{"ZYIN", 4, 105081},
	{"UGOB", 4, 105082},
	{"TDUC", 4, 105083},
	{"OMBP", 4, 105084},
	{"LJOK", 4, 105085},
	{"EMSY", 4, 105086},
	{"DIML", 4, 105087},
	{"ENDONUCLEASE", 12, 105088},
	{"HOLOMORPHIC", 11, 105089},
	{"BANDICOOT", 9, 105090},
	{"PERSIMMON", 9, 105091},
	{"BORSA", 5, 105092},
	{"ATTRIBUTIONS", 12, 105093},
	{"BOSONS", 6, 105094},
	{"PAYSCALE", 8, 105095},
	{"PETEY", 5, 105096},
	{"CALLAN", 6, 105097},
	{"CLOAKED", 7, 105098},
	{"MIKEL", 5, 105099},
	{"CLADE", 5, 105100},
	{"CRONULLA", 8, 105101},
	{"DECRYPTED", 9, 105102},
	{"LICHENS", 7, 105103},
	{"WOPH", 4, 105104},
	{"OWDH", 4, 105105},
	{"OVRE", 4, 105106},
	{"MPNE", 4, 105107},
	{"ASKL", 4, 105108},
	{"AIPU", 4, 105109},
	{"SUPPOSITORIES", 13, 105110},
	{"BROTHERLY", 9, 105111},
	{"CZECHS", 6, 105112},
	{"JORDON", 6, 105113},
	{"FRESNEL", 7, 105114},
	{"UNINHABITED", 11, 105115},
	{"RECOGNITIONS", 12, 105116},
	{"DECOUPAGE", 9, 105117},
	{"SUBPACKAGE", 10, 105118},
	{"DEMONSTRABLY", 12, 105119},
	{"CARTERS", 7, 105120},
	{"MBUC", 4, 105121},
	{"EFTJ", 4, 105122},
	{"DSNU", 4, 105123},
	{"DDYH", 4, 105124},
	{"CEYL", 4, 105125},
	{"ABIZ", 4, 105126},
	{"STOCKDALE", 9, 105127},
	{"TITLING", 7, 105128},
	{"BAILLIE", 7, 105129},
	{"SUNFISH", 7, 105130},
	{"TECHMARKET", 10, 105131},
	{"UNBELIEF", 8, 105132},
	{"FACIES", 6, 105133},
	{"POINSETTIA", 10, 105134},
	{"INTERCOOLER", 11, 105135},
	{"AIRSTRIP", 8, 105136},
	{"UEZI", 4, 105137},
	{"OSLU", 4, 105138},
	{"EPHL", 4, 105139},
	{"PLANETA", 7, 105140},
	{"REPROD", 6, 105141},
	{"DONATO", 6, 105142},
	{"WREKIN", 6, 105143},
	{"OVERTAKING", 10, 105144},
	{"LAMAZE", 6, 105145},
	{"BELLMAN", 7, 105146},
	{"EUPHONIUM", 9, 105147},
	{"URINALYSIS", 10, 105148},
	{"TREVI", 5, 105149},
	{"MAINTAINABILITY", 15, 105150},
	{"ANGEN", 5, 105151},
	{"NRIF", 4, 105152},
	{"NNYV", 4, 105153},
	{"MYIP", 4, 105154},
	{"IVUL", 4, 105155},
	{"GFIT", 4, 105156},
	{"EUKO", 4, 105157},
	{"CDIN", 4, 105158},
	{"EXTUTILS", 8, 105159},
	{"COUNCILWOMAN", 12, 105160},
	{"DESIG", 5, 105161},
	{"SEIBEL", 6, 105162},
	{"HOLED", 5, 105163},
	{"GRIEG", 5, 105164},
	{"GALLE", 5, 105165},
	{"YONK", 4, 105166},
	{"URSG", 4, 105167},
	{"TGIG", 4, 105168},
	{"REKF", 4, 105169},
	{"PCOA", 4, 105170},
	{"FCOI", 4, 105171},
	{"DRAZ", 4, 105172},
	{"LOGICIELS", 9, 105173},
	{"OKADA", 5, 105174},
	{"ARNETTE", 7, 105175},
	{"MPIO", 4, 105176},
	{"COMMENTBLOG", 11, 105177},
	{"TRANSFERENCE", 12, 105178},
	{"ARJUNA", 6, 105179},
	{"PLIABLE", 7, 105180},
	{"KIRKSVILLE", 10, 105181},
	{"SCORM", 5, 105182},
	{"GAROFALO", 8, 105183},
	{"KANEOHE", 7, 105184},
	{"MAHAN", 5, 105185},
	{"BACULA", 6, 105186},
	{"MANTUA", 6, 105187},
	{"RBIB", 4, 105188},
	{"ICHQ", 4, 105189},
	{"RESPONSABLE", 11, 105190},
	{"INEVITABILITY", 13, 105191},
	{"WIMPY", 5, 105192},
	{"DUPUIS", 6, 105193},
	{"SARDINES", 8, 105194},
	{"GUILLEN", 7, 105195},
	{"DICTATING", 9, 105196},
	{"BFME", 4, 105197},
	{"CHUCKS", 6, 105198},
	{"SIDEWALL", 8, 105199},
	{"RAQH", 4, 105200},
	{"NDYJ", 4, 105201},
	{"MYPU", 4, 105202},
	{"DUCKLING", 8, 105203},
	{"STUDIEN", 7, 105204},
	{"JEFFREYS", 8, 105205},
	{"DECOMMISSIONED", 14, 105206},
	{"CRYSTALLIZED", 12, 105207},
	{"REPRISAL", 8, 105208},
	{"WALGREEN", 8, 105209},
	{"TRANH", 5, 105210},
	{"RKVE", 4, 105211},
	{"ORPG", 4, 105212},
	{"OEFU", 4, 105213},
	{"MLBC", 4, 105214},
	{"LUBU", 4, 105215},
	{"LOPC", 4, 105216},
	{"FJAZ", 4, 105217},
	{"BIVA", 4, 105218},
	{"AMEZ", 4, 105219},
	{"TYVEK", 5, 105220},
	{"BLIGHTED", 8, 105221},
	{"LUCITE", 6, 105222},
	{"OPELIKA", 7, 105223},
	{"PLAYABILITY", 11, 105224},
	{"MUDS", 4, 105225},
	{"KUNZ", 4, 105226},
	{"RAFTER", 6, 105227},
	{"WARBLERS", 8, 105228},
	{"SHINCO", 6, 105229},
	{"DISSECT", 7, 105230},
	{"PCNATION", 8, 105231},
	{"SKPR", 4, 105232},
	{"PCUT", 4, 105233},
	{"MSTY", 4, 105234},
	{"LFME", 4, 105235},
	{"KUMB", 4, 105236},
	{"EDMP", 4, 105237},
	{"EBOK", 4, 105238},
	{"BICB", 4, 105239},
	{"TARRAGON", 8, 105240},
	{"RUMBLING", 8, 105241},
	{"HEXANE", 6, 105242},
	{"DACS", 4, 105243},
	{"RECHARGABLE", 11, 105244},
	{"PERCEPTIBLE", 11, 105245},
	{"BLAZES", 6, 105246},
	{"APRA", 4, 105247},
	{"RUNYAN", 6, 105248},
	{"AIRSTATION", 10, 105249},
	{"KOLBE", 5, 105250},
	{"WEKI", 4, 105251},
	{"UEZH", 4, 105252},
	{"HBAB", 4, 105253},
	{"EDKH", 4, 105254},
	{"HYPNOTIST", 9, 105255},
	{"ESCARPMENT", 10, 105256},
	{"OLIVINE", 7, 105257},
	{"LINEARIZED", 10, 105258},
	{"FAMICOM", 7, 105259},
	{"BOOKBAGMY", 9, 105260},
	{"INSTANCEOF", 10, 105261},
	{"KSRU", 4, 105262},
	{"GUPG", 4, 105263},
	{"FDUE", 4, 105264},
	{"CKOW", 4, 105265},
	{"LANDOVER", 8, 105266},
	{"REGU", 4, 105267},
	{"ENCIRCLED", 9, 105268},
	{"TRINITRON", 9, 105269},
	{"ODETTE", 6, 105270},
	{"SAXONS", 6, 105271},
	{"TRANSCENDING", 12, 105272},
	{"DESEGREGATION", 13, 105273},
	{"MEGAHERTZ", 9, 105274},
	{"SNOUT", 5, 105275},
	{"GOODLY", 6, 105276},
	{"ACTOS", 5, 105277},
	{"PHILOSOPHICALLY", 15, 105278},
	{"OFKY", 4, 105279},
	{"MTIC", 4, 105280},
	{"DSSL", 4, 105281},
	{"CGEO", 4, 105282},
	{"DIRECTEUR", 9, 105283},
	{"BIGOT", 5, 105284},
	{"PROTESTER", 9, 105285},
	{"UPVC", 4, 105286},
	{"GESTAPO", 7, 105287},
	{"CALENDARING", 11, 105288},
	{"BRAMBLE", 7, 105289},
	{"PERSISTING", 10, 105290},
	{"DALLES", 6, 105291},
	{"CORO", 4, 105292},
	{"HOLLIES", 7, 105293},
	{"ELURSREBMEM", 11, 105294},
	{"UCCH", 4, 105295},
	{"RSHY", 4, 105296},
	{"RPSB", 4, 105297},
	{"EIFC", 4, 105298},
	{"DOPL", 4, 105299},
	{"DMEY", 4, 105300},
	{"SWISSCOM", 8, 105301},
	{"FREUDIAN", 8, 105302},
	{"RIMMER", 6, 105303},
	{"SASQUATCH", 9, 105304},
	{"ENACTS", 6, 105305},
	{"ELIZ", 4, 105306},
	{"YAVAPAI", 7, 105307},
	{"KAIKOURA", 8, 105308},
	{"GOONS", 5, 105309},
	{"BOUILLON", 8, 105310},
	{"RRHY", 4, 105311},
	{"RDKA", 4, 105312},
	{"ODSY", 4, 105313},
	{"GXIA", 4, 105314},
	{"SCRIBBLED", 9, 105315},
	{"LUCASFILM", 9, 105316},
	{"TITER", 5, 105317},
	{"HICKSVILLE", 10, 105318},
	{"BELUSHI", 7, 105319},
	{"GRANTMAKING", 11, 105320},
	{"GEOTRUST", 8, 105321},
	{"CANASTA", 7, 105322},
	{"AXIOMATIC", 9, 105323},
	{"WARHOLS", 7, 105324},
	{"CELIBACY", 8, 105325},
	{"NKIV", 4, 105326},
	{"JIMP", 4, 105327},
	{"HORJ", 4, 105328},
	{"ETVC", 4, 105329},
	{"CDAV", 4, 105330},
	{"BEAUCOUP", 8, 105331},
	{"BLACKIE", 7, 105332},
	{"COMPARATORS", 11, 105333},
	{"TOOTING", 7, 105334},
	{"SEATAC", 6, 105335},
	{"BORGO", 5, 105336},
	{"BARROS", 6, 105337},
	{"MCGUINNESS", 10, 105338},
	{"MDER", 4, 105339},
	{"HMYH", 4, 105340},
	{"EKMY", 4, 105341},
	{"CKKA", 4, 105342},
	{"RECYCLENET", 10, 105343},
	{"ADENA", 5, 105344},
	{"GRUPPE", 6, 105345},
	{"SCALARS", 7, 105346},
	{"GUZZI", 5, 105347},
	{"DISPLEASED", 10, 105348},
	{"SYNGENTA", 8, 105349},
	{"CORNERBACK", 10, 105350},
	{"SIRG", 4, 105351},
	{"RIXS", 4, 105352},
	{"PFIE", 4, 105353},
	{"PEBO", 4, 105354},
	{"LKLI", 4, 105355},
	{"GSIZ", 4, 105356},
	{"ELOK", 4, 105357},
	{"APHW", 4, 105358},
	{"PORTANT", 7, 105359},
	{"MIZORAM", 7, 105360},
	{"DECATHLON", 9, 105361},
	{"ESPINOSA", 8, 105362},
	{"ANTHILL", 7, 105363},
	{"FINALISE", 8, 105364},
	{"BRIGID", 6, 105365},
	{"LATHER", 6, 105366},
	{"BALDING", 7, 105367},
	{"QUASARS", 7, 105368},
	{"EXTRACTIVE", 10, 105369},
	{"MIXTAPES", 8, 105370},
	{"FALSTAFF", 8, 105371},
	{"LCSW", 4, 105372},
	{"BUREAUCRAT", 10, 105373},
	{"SLUX", 4, 105374},
	{"RURY", 4, 105375},
	{"RBOG", 4, 105376},
	{"PUSL", 4, 105377},
	{"OOMG", 4, 105378},
	{"OAJU", 4, 105379},
	{"NGIK", 4, 105380},
	{"CJAM", 4, 105381},
	{"GENERICALLY", 11, 105382},
	{"UNCHALLENGED", 12, 105383},
	{"COMUNICAZIONE", 13, 105384},
	{"STRAYED", 7, 105385},
	{"OCCASSION", 9, 105386},
	{"QUAKES", 6, 105387},
	{"CLASSICISM", 10, 105388},
	{"STANISLAV", 9, 105389},
	{"SHAYKH", 6, 105390},
	{"COMBOBOX", 8, 105391},
	{"COMMUTATION", 11, 105392},
	{"MODBUS", 6, 105393},
	{"RECYCLABLES", 11, 105394},
	{"SPIRITUALISM", 12, 105395},
	{"XONL", 4, 105396},
	{"LMRO", 4, 105397},
	{"EURU", 4, 105398},
	{"AXWO", 4, 105399},
	{"PAVES", 5, 105400},
	{"GAPPED", 6, 105401},
	{"BBX", 3, 105402},
	{"GRACIA", 6, 105403},
	{"OMNIA", 5, 105404},
	{"ENGENDER", 8, 105405},
	{"ACTUALIZADO", 11, 105406},
	{"PASTES", 6, 105407},
	{"EIBACH", 6, 105408},
	{"VMD", 3, 105409},
	{"GERBIL", 6, 105410},
	{"QUANDARY", 8, 105411},
	{"WEBWORK", 7, 105412},
	{"PATF", 4, 105413},
	{"ABWH", 4, 105414},
	{"RWIKI", 5, 105415},
	{"LUMINOX", 7, 105416},
	{"STREATHAM", 9, 105417},
	{"MAGILL", 6, 105418},
	{"PLUCKER", 7, 105419},
	{"FMV", 3, 105420},
	{"HICCUPS", 7, 105421},
	{"SILVERS", 7, 105422},
	{"FRIENDPRINT", 11, 105423},
	{"LOOPNET", 7, 105424},
	{"JURISTS", 7, 105425},
	{"SPORTIVA", 8, 105426},
	{"CLOAKS", 6, 105427},
	{"MORITA", 6, 105428},
	{"XIDI", 4, 105429},
	{"MSGI", 4, 105430},
	{"LMVE", 4, 105431},
	{"GKOR", 4, 105432},
	{"FTHM", 4, 105433},
	{"EARQ", 4, 105434},
	{"SPERLING", 8, 105435},
	{"PREFORMED", 9, 105436},
	{"FGF", 3, 105437},
	{"GLAZES", 6, 105438},
	{"FINIAL", 6, 105439},
	{"STREAKED", 8, 105440},
	{"DOWNE", 5, 105441},
	{"PHTHALATE", 9, 105442},
	{"PNCO", 4, 105443},
	{"NNYJ", 4, 105444},
	{"IDGL", 4, 105445},
	{"POSSES", 6, 105446},
	{"PCHARDWARE", 10, 105447},
	{"GILPIN", 6, 105448},
	{"CLAUDINE", 8, 105449},
	{"CHIEFTAINS", 10, 105450},
	{"DEXTROMETHORPHAN", 16, 105451},
	{"FLAGR", 5, 105452},
	{"FSCK", 4, 105453},
	{"SAYU", 4, 105454},
	{"NLUX", 4, 105455},
	{"NCHK", 4, 105456},
	{"LIMR", 4, 105457},
	{"CBYT", 4, 105458},
	{"EMPHASES", 8, 105459},
	{"MICROGRAVITY", 12, 105460},
	{"ARBY", 4, 105461},
	{"PRATO", 5, 105462},
	{"KYOSHO", 6, 105463},
	{"WEBCALENDAR", 11, 105464},
	{"XYLOPHONE", 9, 105465},
	{"FACIL", 5, 105466},
	{"VALJ", 4, 105467},
	{"SBAU", 4, 105468},
	{"GYLA", 4, 105469},
	{"CKIW", 4, 105470},
	{"BHAGAVAD", 8, 105471},
	{"GOOLE", 5, 105472},
	{"HERMITIAN", 9, 105473},
	{"HERMENEUTICS", 12, 105474},
	{"GARRICK", 7, 105475},
	{"PERCHES", 7, 105476},
	{"ARTISTI", 7, 105477},
	{"CANDLER", 7, 105478},
	{"VYLI", 4, 105479},
	{"FHIP", 4, 105480},
	{"ETWR", 4, 105481},
	{"EGEV", 4, 105482},
	{"DOFQ", 4, 105483},
	{"AZEW", 4, 105484},
	{"HEALTHNOTES", 11, 105485},
	{"ANDRETTI", 8, 105486},
	{"LEATHERETTE", 11, 105487},
	{"SILHOUETTED", 11, 105488},
	{"POLISHER", 8, 105489},
	{"CROUCHED", 8, 105490},
	{"JUANA", 5, 105491},
	{"GRADATION", 9, 105492},
	{"TELECASTER", 10, 105493},
	{"HARTWICK", 8, 105494},
	{"WEGR", 4, 105495},
	{"WDRU", 4, 105496},
	{"ULTV", 4, 105497},
	{"SAMD", 4, 105498},
	{"RLNA", 4, 105499},
	{"RKEC", 4, 105500},
	{"OKTR", 4, 105501},
	{"NRYL", 4, 105502},
	{"LEIK", 4, 105503},
	{"IEJU", 4, 105504},
	{"EVGE", 4, 105505},
	{"AGPA", 4, 105506},
	{"UNANIMITY", 9, 105507},
	{"BIOGEOGRAPHY", 12, 105508},
	{"YERSINIA", 8, 105509},
	{"WARTHOG", 7, 105510},
	{"VETTING", 7, 105511},
	{"FIFI", 4, 105512},
	{"WINDOWSXP", 9, 105513},
	{"SPEL", 4, 105514},
	{"RADNOR", 6, 105515},
	{"FRUM", 4, 105516},
	{"EDUCATIONALLY", 13, 105517},
	{"LRP", 3, 105518},
	{"YJOR", 4, 105519},
	{"SIZZ", 4, 105520},
	{"EYSK", 4, 105521},
	{"EHUC", 4, 105522},
	{"DOSM", 4, 105523},
	{"TYCHO", 5, 105524},
	{"LISTSERVS", 9, 105525},
	{"GOALIES", 7, 105526},
	{"ZDJ", 3, 105527},
	{"YYX", 3, 105528},
	{"YRX", 3, 105529},
	{"VKD", 3, 105530},
	{"PXG", 3, 105531},
	{"LZJ", 3, 105532},
	{"KXU", 3, 105533},
	{"KLQ", 3, 105534},
	{"IMPEDING", 8, 105535},
	{"BURGE", 5, 105536},
	{"DIJK", 4, 105537},
	{"JOINERS", 7, 105538},
	{"INFOPATH", 8, 105539},
	{"UCOA", 4, 105540},
	{"RUVA", 4, 105541},
	{"NZAM", 4, 105542},
	{"IFFN", 4, 105543},
	{"BALMS", 5, 105544},
	{"SRPSKI", 6, 105545},
	{"MANTRAS", 7, 105546},
	{"EXPLOITABLE", 11, 105547},
	{"REINO", 5, 105548},
	{"NBPTS", 5, 105549},
	{"STARTCHAR", 9, 105550},
	{"REMADE", 6, 105551},
	{"ERYTHEMA", 8, 105552},
	{"SQUAMISH", 8, 105553},
	{"NONSAMPLING", 11, 105554},
	{"GRISLY", 6, 105555},
	{"FORNICATION", 11, 105556},
	{"PINCKNEY", 8, 105557},
	{"VEAQ", 4, 105558},
	{"UDEU", 4, 105559},
	{"RCOB", 4, 105560},
	{"PONJ", 4, 105561},
	{"GHOB", 4, 105562},
	{"EURP", 4, 105563},
	{"EBIP", 4, 105564},
	{"FIGURAL", 7, 105565},
	{"THUNDERCATS", 11, 105566},
	{"CONTRO", 6, 105567},
	{"CALOUNDRA", 9, 105568},
	{"SASSAFRAS", 9, 105569},
	{"HANTSWEB", 8, 105570},
	{"SURREALIST", 10, 105571},
	{"CONTAMINATING", 13, 105572},
	{"DPED", 4, 105573},
	{"HISPANO", 7, 105574},
	{"ORNITHINE", 9, 105575},
	{"SMYW", 4, 105576},
	{"PCIN", 4, 105577},
	{"GGYS", 4, 105578},
	{"DWAC", 4, 105579},
	{"COSG", 4, 105580},
	{"CMAI", 4, 105581},
	{"LENCO", 5, 105582},
	{"GLORIOSO", 8, 105583},
	{"EGFR", 4, 105584},
	{"POWHATAN", 8, 105585},
	{"ESEARCH", 7, 105586},
	{"HEURE", 5, 105587},
	{"WISHLISTS", 9, 105588},
	{"AGRONOMIC", 9, 105589},
	{"ACWORTH", 7, 105590},
	{"DISTUTILS", 9, 105591},
	{"AZAD", 4, 105592},
	{"FLUOROURACIL", 12, 105593},
	{"SPEEDUPMYPC", 11, 105594},
	{"YJAY", 4, 105595},
	{"LBLI", 4, 105596},
	{"GSTW", 4, 105597},
	{"GOBR", 4, 105598},
	{"DLEU", 4, 105599},
	{"CAPH", 4, 105600},
	{"BTOP", 4, 105601},
	{"FIBRONECTIN", 11, 105602},
	{"PISCINA", 7, 105603},
	{"JENOPTIK", 8, 105604},
	{"PIMS", 4, 105605},
	{"DEBARMENT", 9, 105606},
	{"STARTECH", 8, 105607},
	{"AUTORESPONDERS", 14, 105608},
	{"JUMPSUIT", 8, 105609},
	{"TRAMPS", 6, 105610},
	{"YEMENI", 6, 105611},
	{"KLEENEX", 7, 105612},
	{"DENSO", 5, 105613},
	{"OVERPAID", 8, 105614},
	{"HEXHAM", 6, 105615},
	{"YUNW", 4, 105616},
	{"SLUK", 4, 105617},
	{"OPCR", 4, 105618},
	{"OMBH", 4, 105619},
	{"NKAU", 4, 105620},
	{"LPEL", 4, 105621},
	{"JRWA", 4, 105622},
	{"ILTL", 4, 105623},
	{"SHIGELLA", 8, 105624},
	{"BIOENERGY", 9, 105625},
	{"JAVAONE", 7, 105626},
	{"NUFFIELD", 8, 105627},
	{"WINKLE", 6, 105628},
	{"TRACHEAL", 8, 105629},
	{"BLOSSOMING", 10, 105630},
	{"DREAMIN", 7, 105631},
	{"MESONS", 6, 105632},
	{"WOOLY", 5, 105633},
	{"STORMFRONT", 10, 105634},
	{"JAMEY", 5, 105635},
	{"YUSS", 4, 105636},
	{"UDBA", 4, 105637},
	{"LYNH", 4, 105638},
	{"LBAK", 4, 105639},
	{"HEGB", 4, 105640},
	{"GOCT", 4, 105641},
	{"EBMW", 4, 105642},
	{"BBYJ", 4, 105643},
	{"RIGHTWING", 9, 105644},
	{"BARBARY", 7, 105645},
	{"KICKBACK", 8, 105646},
	{"BAHRU", 5, 105647},
	{"EPSRC", 5, 105648},
	{"STIFTUNG", 8, 105649},
	{"IRATE", 5, 105650},
	{"PARTISANSHIP", 12, 105651},
	{"SCHRODINGER", 11, 105652},
	{"VYCR", 4, 105653},
	{"PIAD", 4, 105654},
	{"LOCR", 4, 105655},
	{"IFYM", 4, 105656},
	{"GNPA", 4, 105657},
	{"GJOE", 4, 105658},
	{"KANADA", 6, 105659},
	{"SITAR", 5, 105660},
	{"PUSHY", 5, 105661},
	{"NEESON", 6, 105662},
	{"CERTIFICAT", 10, 105663},
	{"MATHEMATIK", 10, 105664},
	{"VENTRICLES", 10, 105665},
	{"KOGAN", 5, 105666},
	{"BRAZORIA", 8, 105667},
	{"MINAMI", 6, 105668},
	{"WITB", 4, 105669},
	{"URTZ", 4, 105670},
	{"NLOD", 4, 105671},
	{"NCYV", 4, 105672},
	{"MAFL", 4, 105673},
	{"IXLE", 4, 105674},
	{"FMYW", 4, 105675},
	{"BCUL", 4, 105676},
	{"BOLDFACE", 8, 105677},
	{"BROGAN", 6, 105678},
	{"OMELET", 6, 105679},
	{"JCU", 3, 105680},
	{"SUPA", 4, 105681},
	{"STUBHUB", 7, 105682},
	{"ALBERTS", 7, 105683},
	{"HEARTWORM", 9, 105684},
	{"SHEAF", 5, 105685},
	{"QUIRED", 6, 105686},
	{"CAMPBELLTOWN", 12, 105687},
	{"DIMITRIS", 8, 105688},
	{"BICHON", 6, 105689},
	{"SADB", 4, 105690},
	{"NDRM", 4, 105691},
	{"MIFY", 4, 105692},
	{"FOLIOS", 6, 105693},
	{"JUJU", 4, 105694},
	{"PEACEMAKING", 11, 105695},
	{"LAZULI", 6, 105696},
	{"GORA", 4, 105697},
	{"DICTUM", 6, 105698},
	{"NIHILISM", 8, 105699},
	{"SRINIVAS", 8, 105700},
	{"STOCKBYTE", 9, 105701},
	{"UKRAINIANS", 10, 105702},
	{"KNOTTS", 6, 105703},
	{"BAGHDATIS", 9, 105704},
	{"APPLIQUES", 9, 105705},
	{"CAULKING", 8, 105706},
	{"THORIUM", 7, 105707},
	{"REFUTATION", 10, 105708},
	{"POSTHUMOUS", 10, 105709},
	{"SCRAMBLER", 9, 105710},
	{"DANZA", 5, 105711},
	{"LORRIES", 7, 105712},
	{"ZERH", 4, 105713},
	{"XITP", 4, 105714},
	{"WAIK", 4, 105715},
	{"TOLR", 4, 105716},
	{"TILU", 4, 105717},
	{"RILU", 4, 105718},
	{"PEGF", 4, 105719},
	{"EPJO", 4, 105720},
	{"INCLINATIONS", 12, 105721},
	{"TOOLCHAIN", 9, 105722},
	{"LEDGES", 6, 105723},
	{"OVERESTIMATE", 12, 105724},
	{"BATHYMETRY", 10, 105725},
	{"WENIG", 5, 105726},
	{"CERTANCE", 8, 105727},
	{"MUCHAS", 6, 105728},
	{"GURION", 6, 105729},
	{"ENLISTING", 9, 105730},
	{"WYET", 4, 105731},
	{"WITD", 4, 105732},
	{"ULYJ", 4, 105733},
	{"TWAD", 4, 105734},
	{"TLDQ", 4, 105735},
	{"ODFU", 4, 105736},
	{"LAJU", 4, 105737},
	{"FLYL", 4, 105738},
	{"NOSEARCHALL", 11, 105739},
	{"ROARS", 5, 105740},
	{"SKAGWAY", 7, 105741},
	{"LUCIFERASE", 10, 105742},
	{"CATLIN", 6, 105743},
	{"URINATING", 9, 105744},
	{"SWINDLE", 7, 105745},
	{"SARY", 4, 105746},
	{"BILBO", 5, 105747},
	{"PATUXENT", 8, 105748},
	{"INVERCARGILL", 12, 105749},
	{"MUPI", 4, 105750},
	{"MRSW", 4, 105751},
	{"LSIC", 4, 105752},
	{"LFSP", 4, 105753},
	{"IJUM", 4, 105754},
	{"FNUT", 4, 105755},
	{"FCYC", 4, 105756},
	{"ERDH", 4, 105757},
	{"ELMH", 4, 105758},
	{"SAWUBONA", 8, 105759},
	{"INDOCTRINATION", 14, 105760},
	{"DISAGREEING", 11, 105761},
	{"DATENSCHUTZ", 11, 105762},
	{"REVOLTING", 9, 105763},
	{"FORNEY", 6, 105764},
	{"CANDIED", 7, 105765},
	{"CROWES", 6, 105766},
	{"PLAINE", 6, 105767},
	{"LIVECD", 6, 105768},
	{"RICKETTS", 8, 105769},
	{"JOBCENTRE", 9, 105770},
	{"MIDDLEWEIGHT", 12, 105771},
	{"RYLEX", 5, 105772},
	{"YDOP", 4, 105773},
	{"GCOF", 4, 105774},
	{"FTPE", 4, 105775},
	{"CEXT", 4, 105776},
	{"SCALER", 6, 105777},
	{"MACEDON", 7, 105778},
	{"BIRNBAUM", 8, 105779},
	{"DINGY", 5, 105780},
	{"SHAPEFILE", 9, 105781},
	{"GABBER", 6, 105782},
	{"FRIEZE", 6, 105783},
	{"STAIRCASES", 10, 105784},
	{"MEDIZIN", 7, 105785},
	{"COMPACTOR", 9, 105786},
	{"LATY", 4, 105787},
	{"KVIE", 4, 105788},
	{"IRLG", 4, 105789},
	{"HOLW", 4, 105790},
	{"HCOD", 4, 105791},
	{"MASTERPLAN", 10, 105792},
	{"DINK", 4, 105793},
	{"NOBLESVILLE", 11, 105794},
	{"MACKINAW", 8, 105795},
	{"UNDESIRED", 9, 105796},
	{"TMDA", 4, 105797},
	{"CLUNKY", 6, 105798},
	{"NEURODEGENERATIVE", 17, 105799},
	{"HORAS", 5, 105800},
	{"NIVEA", 5, 105801},
	{"MULTIPLIES", 10, 105802},
	{"REACTIVATE", 10, 105803},
	{"CATEGORIAS", 10, 105804},
	{"INFOLINE", 8, 105805},
	{"UPSN", 4, 105806},
	{"MYBY", 4, 105807},
	{"HYFI", 4, 105808},
	{"FFPL", 4, 105809},
	{"ECBA", 4, 105810},
	{"DZHA", 4, 105811},
	{"AFEU", 4, 105812},
	{"POODLES", 7, 105813},
	{"EUPHORIC", 8, 105814},
	{"YUPPIE", 6, 105815},
	{"IMPRESSING", 10, 105816},
	{"TWIRLING", 8, 105817},
	{"COASTGUARD", 10, 105818},
	{"REDEPLOYMENT", 12, 105819},
	{"KINSLEY", 7, 105820},
	{"MERKUR", 6, 105821},
	{"EIRCOM", 6, 105822},
	{"LOTTE", 5, 105823},
	{"LACHLAN", 7, 105824},
	{"WOIM", 4, 105825},
	{"UGFR", 4, 105826},
	{"DDJO", 4, 105827},
	{"BTRI", 4, 105828},
	{"DUALS", 5, 105829},
	{"PROPAGATES", 10, 105830},
	{"DEVIATES", 8, 105831},
	{"BAREWALLS", 9, 105832},
	{"TOPSY", 5, 105833},
	{"CONTOURING", 10, 105834},
	{"HAFAN", 5, 105835},
	{"AZIDE", 5, 105836},
	{"SUBBASIN", 8, 105837},
	{"SEYK", 4, 105838},
	{"KPIE", 4, 105839},
	{"HBYC", 4, 105840},
	{"FEIM", 4, 105841},
	{"BOXP", 4, 105842},
	{"RECALCULATED", 12, 105843},
	{"ANTIMICROB", 10, 105844},
	{"SCHECHTER", 9, 105845},
	{"VALS", 4, 105846},
	{"EMPLACEMENT", 11, 105847},
	{"SKYROCKETING", 12, 105848},
	{"WDOT", 4, 105849},
	{"VYON", 4, 105850},
	{"UMIO", 4, 105851},
	{"HRAW", 4, 105852},
	{"GTAG", 4, 105853},
	{"EFWO", 4, 105854},
	{"DBHA", 4, 105855},
	{"MODUL", 5, 105856},
	{"LEDBETTER", 9, 105857},
	{"ENTWICKLUNG", 11, 105858},
	{"SERGEANTS", 9, 105859},
	{"RANDS", 5, 105860},
	{"ENQUIRES", 8, 105861},
	{"MAHARISHI", 9, 105862},
	{"TAKOMA", 6, 105863},
	{"BARYON", 6, 105864},
	{"STROKERS", 8, 105865},
	{"GMR", 3, 105866},
	{"OVERCOAT", 8, 105867},
	{"CONFEDERATIONS", 14, 105868},
	{"MBL", 3, 105869},
	{"PRAB", 4, 105870},
	{"OYBU", 4, 105871},
	{"GLIQ", 4, 105872},
	{"GBID", 4, 105873},
	{"NUTREX", 6, 105874},
	{"CAROTENOIDS", 11, 105875},
	{"WHITESNAKE", 10, 105876},
	{"EVOLT", 5, 105877},
	{"BLIB", 4, 105878},
	{"METROLOGIC", 10, 105879},
	{"SDSL", 4, 105880},
	{"SUNNAH", 6, 105881},
	{"EXPE", 4, 105882},
	{"CHIPPENDALE", 11, 105883},
	{"PICTU", 5, 105884},
	{"BDM", 3, 105885},
	{"UENJ", 4, 105886},
	{"IGWO", 4, 105887},
	{"DTWA", 4, 105888},
	{"DLAG", 4, 105889},
	{"COQU", 4, 105890},
	{"BYEC", 4, 105891},
	{"BSRA", 4, 105892},
	{"TYRANNICAL", 10, 105893},
	{"EDVARD", 6, 105894},
	{"INFINITESIMAL", 13, 105895},
	{"GILLMAN", 7, 105896},
	{"LANAS", 5, 105897},
	{"TUGJOBS", 7, 105898},
	{"UMDS", 4, 105899},
	{"SCHARF", 6, 105900},
	{"YBUM", 4, 105901},
	{"UNBOXED", 7, 105902},
	{"FSTAB", 5, 105903},
	{"KPC", 3, 105904},
	{"FISHBOWL", 8, 105905},
	{"BRODSKY", 7, 105906},
	{"DUFFIELD", 8, 105907},
	{"HARMONIA", 8, 105908},
	{"SPOUTING", 8, 105909},
	{"ORIGINE", 7, 105910},
	{"FEBRERO", 7, 105911},
	{"HUMBLING", 8, 105912},
	{"WROX", 4, 105913},
	{"UTENTI", 6, 105914},
	{"WILLINGHAM", 10, 105915},
	{"TRUER", 5, 105916},
	{"WLST", 4, 105917},
	{"OPGU", 4, 105918},
	{"OALU", 4, 105919},
	{"LFPU", 4, 105920},
	{"IUMV", 4, 105921},
	{"GBIS", 4, 105922},
	{"COFH", 4, 105923},
	{"LIMES", 5, 105924},
	{"BARU", 4, 105925},
	{"GLENBROOK", 9, 105926},
	{"MENTORED", 8, 105927},
	{"DEVORE", 6, 105928},
	{"BURGLARIES", 10, 105929},
	{"WRECKER", 7, 105930},
	{"WYCLEF", 6, 105931},
	{"EFFLUENTS", 9, 105932},
	{"KATHARINA", 9, 105933},
	{"POLIFONICHE", 11, 105934},
	{"YCUB", 4, 105935},
	{"WTHM", 4, 105936},
	{"UPTP", 4, 105937},
	{"TAFG", 4, 105938},
	{"OBYE", 4, 105939},
	{"LDUL", 4, 105940},
	{"FHID", 4, 105941},
	{"DIGY", 4, 105942},
	{"ARCB", 4, 105943},
	{"MINISKIRT", 9, 105944},
	{"DESCHUTES", 9, 105945},
	{"MARTIANS", 8, 105946},
	{"OUTPERFORMED", 12, 105947},
	{"UNACCOUNTED", 11, 105948},
	{"GIRAFFES", 8, 105949},
	{"PRESSURING", 10, 105950},
	{"TELOMERASE", 10, 105951},
	{"TJAZ", 4, 105952},
	{"STCY", 4, 105953},
	{"OYDC", 4, 105954},
	{"MIAB", 4, 105955},
	{"LSVO", 4, 105956},
	{"IFFD", 4, 105957},
	{"BDYL", 4, 105958},
	{"MARINI", 6, 105959},
	{"SULLEN", 6, 105960},
	{"MACHIN", 6, 105961},
	{"PROLONGING", 10, 105962},
	{"BATTERING", 9, 105963},
	{"OCCASSIONS", 10, 105964},
	{"TABLESPACE", 10, 105965},
	{"NUMVERTS", 8, 105966},
	{"KRAUT", 5, 105967},
	{"YWEP", 4, 105968},
	{"XOVE", 4, 105969},
	{"UFIG", 4, 105970},
	{"RNVA", 4, 105971},
	{"PEVA", 4, 105972},
	{"MGAN", 4, 105973},
	{"MARF", 4, 105974},
	{"LTAU", 4, 105975},
	{"LMYF", 4, 105976},
	{"IPYO", 4, 105977},
	{"IDIB", 4, 105978},
	{"EPMS", 4, 105979},
	{"ELZE", 4, 105980},
	{"SUPERFICIALLY", 13, 105981},
	{"CARBONE", 7, 105982},
	{"KOSMOS", 6, 105983},
	{"COEF", 4, 105984},
	{"THOMSEN", 7, 105985},
	{"UPSTART", 7, 105986},
	{"MISHAWAKA", 9, 105987},
	{"UHAP", 4, 105988},
	{"LKRO", 4, 105989},
	{"FUEN", 4, 105990},
	{"DULK", 4, 105991},
	{"REFOCUS", 7, 105992},
	{"MOSKOWITZ", 9, 105993},
	{"GIMLI", 5, 105994},
	{"CROUSE", 6, 105995},
	{"VIKKI", 5, 105996},
	{"GENERIF", 7, 105997},
	{"SOFTAIL", 7, 105998},
	{"FIGHTIN", 7, 105999},
	{"REAMS", 5, 106000},
	{"TECHNISAT", 9, 106001},
	{"BEEPER", 6, 106002},
	{"CUEB", 4, 106003},
	{"AMGU", 4, 106004},
	{"REMAKES", 7, 106005},
	{"MOLTON", 6, 106006},
	{"INFEASIBLE", 10, 106007},
	{"IMPS", 4, 106008},
	{"WOLFORD", 7, 106009},
	{"THALIDOMIDE", 11, 106010},
	{"LANDROVER", 9, 106011},
	{"DIVULGED", 8, 106012},
	{"VELIKO", 6, 106013},
	{"WHOLESALING", 11, 106014},
	{"SHRUNKEN", 8, 106015},
	{"PUPA", 4, 106016},
	{"COFFE", 5, 106017},
	{"CAPRESSO", 8, 106018},
	{"RRAK", 4, 106019},
	{"PMNO", 4, 106020},
	{"OLCI", 4, 106021},
	{"MOMT", 4, 106022},
	{"LUJA", 4, 106023},
	{"BOUQ", 4, 106024},
	{"TANABE", 6, 106025},
	{"LORRIE", 6, 106026},
	{"VIEQUES", 7, 106027},
	{"QUAYS", 5, 106028},
	{"SUBFIELD", 8, 106029},
	{"VIDOES", 6, 106030},
	{"REPREHENSIBLE", 13, 106031},
	{"WHEELOCK", 8, 106032},
	{"NCHUM", 5, 106033},
	{"CORNERSTONES", 12, 106034},
	{"SEQUENT", 7, 106035},
	{"RETRIES", 7, 106036},
	{"RCL", 3, 106037},
	{"FALLIN", 6, 106038},
	{"DONNAS", 6, 106039},
	{"HORIZ", 5, 106040},
	{"PWAN", 4, 106041},
	{"FTIB", 4, 106042},
	{"FOFN", 4, 106043},
	{"DESQ", 4, 106044},
	{"ABREU", 5, 106045},
	{"PROVOKES", 8, 106046},
	{"DISTANCIA", 9, 106047},
	{"SUDS", 4, 106048},
	{"DEDICATING", 10, 106049},
	{"FELA", 4, 106050},
	{"GAMS", 4, 106051},
	{"DARKSTAR", 8, 106052},
	{"ONMOUSEOVER", 11, 106053},
	{"CHEATHAM", 8, 106054},
	{"RALLYE", 6, 106055},
	{"KNITTERS", 8, 106056},
	{"SYPR", 4, 106057},
	{"PPYL", 4, 106058},
	{"EYOC", 4, 106059},
	{"ECWI", 4, 106060},
	{"AZAB", 4, 106061},
	{"STAPLERS", 8, 106062},
	{"WAILERS", 7, 106063},
	{"SILENTNIGHT", 11, 106064},
	{"PROCITE", 7, 106065},
	{"BALLANTYNE", 10, 106066},
	{"HOLLINS", 7, 106067},
	{"AKHTAR", 6, 106068},
	{"CONFESSING", 10, 106069},
	{"FORBADE", 7, 106070},
	{"INCURSIONS", 10, 106071},
	{"HOUSEBOATS", 10, 106072},
	{"GITMO", 5, 106073},
	{"WOOFERS", 7, 106074},
	{"XROS", 4, 106075},
	{"WAWO", 4, 106076},
	{"OUVO", 4, 106077},
	{"KIDF", 4, 106078},
	{"CTVO", 4, 106079},
	{"AZYB", 4, 106080},
	{"VIELE", 5, 106081},
	{"REFERENT", 8, 106082},
	{"PIECED", 6, 106083},
	{"SKAL", 4, 106084},
	{"OOCYTE", 6, 106085},
	{"TECHNION", 8, 106086},
	{"ARCHING", 7, 106087},
	{"SPECULAR", 8, 106088},
	{"OKRA", 4, 106089},
	{"SATRIANI", 8, 106090},
	{"IMPERSONATE", 11, 106091},
	{"WNAU", 4, 106092},
	{"UXTA", 4, 106093},
	{"TKOW", 4, 106094},
	{"HILC", 4, 106095},
	{"GLORIOUSLY", 10, 106096},
	{"TEDESCHI", 8, 106097},
	{"ADHESIONS", 9, 106098},
	{"VMC", 3, 106099},
	{"HOMESEARCH", 10, 106100},
	{"GOURDS", 6, 106101},
	{"WORSTED", 7, 106102},
	{"NEVERMORE", 9, 106103},
	{"WALR", 4, 106104},
	{"VONM", 4, 106105},
	{"RYEQ", 4, 106106},
	{"OKDA", 4, 106107},
	{"MHEP", 4, 106108},
	{"GGYB", 4, 106109},
	{"CRTTELEVISION", 13, 106110},
	{"POZO", 4, 106111},
	{"ENDORSERS", 9, 106112},
	{"MATTSON", 7, 106113},
	{"SANGUINE", 8, 106114},
	{"ACORNS", 6, 106115},
	{"DOMINATOR", 9, 106116},
	{"GMB", 3, 106117},
	{"AMARETTO", 8, 106118},
	{"SLUNG", 5, 106119},
	{"KNOCKIN", 7, 106120},
	{"FAIRLANE", 8, 106121},
	{"ZVY", 3, 106122},
	{"ZBM", 3, 106123},
	{"YQR", 3, 106124},
	{"RQG", 3, 106125},
	{"PZR", 3, 106126},
	{"LVZ", 3, 106127},
	{"LQF", 3, 106128},
	{"KXG", 3, 106129},
	{"WATERPARK", 9, 106130},
	{"COMPAN", 6, 106131},
	{"WENZHOU", 7, 106132},
	{"CODICE", 6, 106133},
	{"STABBIN", 7, 106134},
	{"RGAO", 4, 106135},
	{"NGPM", 4, 106136},
	{"KDOU", 4, 106137},
	{"IVRE", 4, 106138},
	{"DADB", 4, 106139},
	{"AROK", 4, 106140},
	{"ROWERS", 6, 106141},
	{"SHOCKINGLY", 10, 106142},
	{"BREN", 4, 106143},
	{"HEADBANDS", 9, 106144},
	{"TOCK", 4, 106145},
	{"CHIMAIRA", 8, 106146},
	{"VIAJE", 5, 106147},
	{"SELECTA", 7, 106148},
	{"BAPT", 4, 106149},
	{"VAGRANT", 7, 106150},
	{"TELEHEALTH", 10, 106151},
	{"LCMS", 4, 106152},
	{"GGSN", 4, 106153},
	{"YPTW", 4, 106154},
	{"MNAV", 4, 106155},
	{"MNAR", 4, 106156},
	{"IFBR", 4, 106157},
	{"GESJ", 4, 106158},
	{"FLHI", 4, 106159},
	{"FFCL", 4, 106160},
	{"DYMC", 4, 106161},
	{"DOSF", 4, 106162},
	{"BBYL", 4, 106163},
	{"DATAFLOW", 8, 106164},
	{"BEEKEEPING", 10, 106165},
	{"PASCOE", 6, 106166},
	{"LONGSLEEVE", 10, 106167},
	{"MANGOSTEEN", 10, 106168},
	{"POTOSI", 6, 106169},
	{"FLUCONAZOLE", 11, 106170},
	{"HIGHLIGHTERS", 12, 106171},
	{"EMPTIES", 7, 106172},
	{"BIGHT", 5, 106173},
	{"BIAFRA", 6, 106174},
	{"PROLIFERATE", 11, 106175},
	{"ZEOU", 4, 106176},
	{"RSKO", 4, 106177},
	{"HKER", 4, 106178},
	{"FNAZ", 4, 106179},
	{"STEROIDAL", 9, 106180},
	{"ENCYCLICAL", 10, 106181},
	{"CARRERAS", 8, 106182},
	{"DOMINOS", 7, 106183},
	{"ENTRA", 5, 106184},
	{"POWERBAR", 8, 106185},
	{"SICUREZZA", 9, 106186},
	{"FELLS", 5, 106187},
	{"DECIBEL", 7, 106188},
	{"MCNAUGHTON", 10, 106189},
	{"JOSEPHS", 7, 106190},
	{"MORGEN", 6, 106191},
	{"RASIERT", 7, 106192},
	{"PENFIELD", 8, 106193},
	{"YGRU", 4, 106194},
	{"SFUM", 4, 106195},
	{"MCNU", 4, 106196},
	{"BBYG", 4, 106197},
	{"AYOG", 4, 106198},
	{"BACKHAND", 8, 106199},
	{"LORS", 4, 106200},
	{"CEPA", 4, 106201},
	{"ACTIVATORS", 10, 106202},
	{"TRANSPORTE", 10, 106203},
	{"DORMER", 6, 106204},
	{"PRYCE", 5, 106205},
	{"MARTON", 6, 106206},
	{"STASIS", 6, 106207},
	{"PYTHONS", 7, 106208},
	{"BIOSCI", 6, 106209},
	{"BARRIOS", 7, 106210},
	{"UNDERPRIVILEGED", 15, 106211},
	{"SCHRAMM", 7, 106212},
	{"WIFH", 4, 106213},
	{"VEDQ", 4, 106214},
	{"RLRO", 4, 106215},
	{"POVI", 4, 106216},
	{"OPDA", 4, 106217},
	{"NYEF", 4, 106218},
	{"NGMD", 4, 106219},
	{"KSBL", 4, 106220},
	{"IBOL", 4, 106221},
	{"OUTILS", 6, 106222},
	{"BOLZANO", 7, 106223},
	{"PANICS", 6, 106224},
	{"INDUSTRIALISTS", 14, 106225},
	{"WIKITECH", 8, 106226},
	{"PROVERA", 7, 106227},
	{"BISCHOFF", 8, 106228},
	{"CARABINER", 9, 106229},
	{"VEDRA", 5, 106230},
	{"COMPETENTLY", 11, 106231},
	{"OWWR", 4, 106232},
	{"OUBI", 4, 106233},
	{"CNOW", 4, 106234},
	{"ROSENBLUM", 9, 106235},
	{"JFC", 3, 106236},
	{"MISCELLANEA", 11, 106237},
	{"KILROY", 6, 106238},
	{"PAREJAS", 7, 106239},
	{"LEAKE", 5, 106240},
	{"KONNECTIONS", 11, 106241},
	{"ADMIXTURES", 10, 106242},
	{"ERENT", 5, 106243},
	{"PANDEY", 6, 106244},
	{"ZHONGSHAN", 9, 106245},
	{"PROLONGATION", 12, 106246},
	{"TUCKS", 5, 106247},
	{"SAFTEY", 6, 106248},
	{"ARNICA", 6, 106249},
	{"MCCOMB", 6, 106250},
	{"JACKO", 5, 106251},
	{"ELDERCARE", 9, 106252},
	{"YCEO", 4, 106253},
	{"RGYN", 4, 106254},
	{"NKPL", 4, 106255},
	{"KIMT", 4, 106256},
	{"GTWE", 4, 106257},
	{"CYSC", 4, 106258},
	{"BIAD", 4, 106259},
	{"EMBARKS", 7, 106260},
	{"UPROOTED", 8, 106261},
	{"DUSHKU", 6, 106262},
	{"SUBLINGUAL", 10, 106263},
	{"PGD", 3, 106264},
	{"TALONS", 6, 106265},
	{"XTAR", 4, 106266},
	{"LPAV", 4, 106267},
	{"IPSG", 4, 106268},
	{"AVYG", 4, 106269},
	{"DISTORTS", 8, 106270},
	{"SARANDON", 8, 106271},
	{"PRR", 3, 106272},
	{"GERMAINE", 8, 106273},
	{"DUALISM", 7, 106274},
	{"MILIAN", 6, 106275},
	{"SINFONIA", 8, 106276},
	{"GRANDMAS", 8, 106277},
	{"SAUD", 4, 106278},
	{"WLANS", 5, 106279},
	{"MERRIFIELD", 10, 106280},
	{"INTRIGUES", 9, 106281},
	{"CANNIBALS", 9, 106282},
	{"USUK", 4, 106283},
	{"TCEM", 4, 106284},
	{"PTYB", 4, 106285},
	{"MFED", 4, 106286},
	{"MAKH", 4, 106287},
	{"GSLU", 4, 106288},
	{"EFJO", 4, 106289},
	{"BONL", 4, 106290},
	{"BAWI", 4, 106291},
	{"WINFAST", 7, 106292},
	{"OXYTOCIN", 8, 106293},
	{"POUNCE", 6, 106294},
	{"GENEALOGISTS", 12, 106295},
	{"MARCHANT", 8, 106296},
	{"VEDAS", 5, 106297},
	{"MARBURY", 7, 106298},
	{"SUBSIDIZING", 11, 106299},
	{"PANIER", 6, 106300},
	{"DRP", 3, 106301},
	{"PIPA", 4, 106302},
	{"SOBEL", 5, 106303},
	{"NORSKE", 6, 106304},
	{"SECUESTRO", 9, 106305},
	{"ABLES", 5, 106306},
	{"TZAL", 4, 106307},
	{"RHUD", 4, 106308},
	{"GILV", 4, 106309},
	{"EMIW", 4, 106310},
	{"OXBOW", 5, 106311},
	{"MOUTHFULS", 9, 106312},
	{"INSTILLED", 9, 106313},
	{"STALINIST", 9, 106314},
	{"IDVD", 4, 106315},
	{"DUALLY", 6, 106316},
	{"VARELA", 6, 106317},
	{"DECIBELS", 8, 106318},
	{"CALYX", 5, 106319},
	{"PRIYA", 5, 106320},
	{"TRUETONE", 8, 106321},
	{"LOTHIANS", 8, 106322},
	{"ARGENTINO", 9, 106323},
	{"VALOUR", 6, 106324},
	{"PRAEGER", 7, 106325},
	{"UINB", 4, 106326},
	{"RVOR", 4, 106327},
	{"MOSF", 4, 106328},
	{"LITLE", 5, 106329},
	{"MIGHTILY", 8, 106330},
	{"REFURBISHING", 12, 106331},
	{"FLL", 3, 106332},
	{"SUID", 4, 106333},
	{"REKLAMA", 7, 106334},
	{"FACTOID", 7, 106335},
	{"YFOS", 4, 106336},
	{"IZUM", 4, 106337},
	{"AKYO", 4, 106338},
	{"PIAGGIO", 7, 106339},
	{"CUZCO", 5, 106340},
	{"AFRINIC", 7, 106341},
	{"PASHTO", 6, 106342},
	{"VANDROSS", 8, 106343},
	{"CVSIGNORE", 9, 106344},
	{"JUTLAND", 7, 106345},
	{"GAMERHELP", 9, 106346},
	{"RAGDOLL", 7, 106347},
	{"UNWIELDY", 8, 106348},
	{"PERPETUATED", 11, 106349},
	{"JANNE", 5, 106350},
	{"TRANSCODING", 11, 106351},
	{"RGHU", 4, 106352},
	{"OFTG", 4, 106353},
	{"FTUP", 4, 106354},
	{"PHILL", 5, 106355},
	{"CHANCELLORS", 11, 106356},
	{"WEENIE", 6, 106357},
	{"EXAGGERATING", 12, 106358},
	{"CORAM", 5, 106359},
	{"PREPAYMENTS", 11, 106360},
	{"YORV", 4, 106361},
	{"WFIG", 4, 106362},
	{"UGOV", 4, 106363},
	{"RUPR", 4, 106364},
	{"LYAQ", 4, 106365},
	{"GUYM", 4, 106366},
	{"FRIL", 4, 106367},
	{"AKOP", 4, 106368},
	{"UNMIK", 5, 106369},
	{"PENALIZE", 8, 106370},
	{"ORILLIA", 7, 106371},
	{"SMOLDERING", 10, 106372},
	{"ENGARDE", 7, 106373},
	{"REFINANCED", 10, 106374},
	{"PEUVENT", 7, 106375},
	{"INFOMERCIAL", 11, 106376},
	{"SNUB", 4, 106377},
	{"SIGNUPS", 7, 106378},
	{"WESM", 4, 106379},
	{"WANB", 4, 106380},
	{"OADY", 4, 106381},
	{"LCIO", 4, 106382},
	{"GADJ", 4, 106383},
	{"CUSL", 4, 106384},
	{"CKII", 4, 106385},
	{"CILV", 4, 106386},
	{"MANISH", 6, 106387},
	{"EMBRY", 5, 106388},
	{"IZZO", 4, 106389},
	{"TWEEDY", 6, 106390},
	{"COARSELY", 8, 106391},
	{"NICOBAR", 7, 106392},
	{"ARRAYED", 7, 106393},
	{"ESPOO", 5, 106394},
	{"EYETOY", 6, 106395},
	{"SHALLOTS", 8, 106396},
	{"ARCTICA", 7, 106397},
	{"TEXTPATTERN", 11, 106398},
	{"ODDBINS", 7, 106399},
	{"RAFF", 4, 106400},
	{"YJET", 4, 106401},
	{"TJOK", 4, 106402},
	{"OXWE", 4, 106403},
	{"NPIR", 4, 106404},
	{"DUTE", 4, 106405},
	{"CKPH", 4, 106406},
	{"BWES", 4, 106407},
	{"WITHSTANDING", 12, 106408},
	{"STAMPER", 7, 106409},
	{"PANELING", 8, 106410},
	{"ADRA", 4, 106411},
	{"DAMPENING", 9, 106412},
	{"JOCKSTRAPS", 10, 106413},
	{"WOULDN", 6, 106414},
	{"THICKENS", 8, 106415},
	{"HISSING", 7, 106416},
	{"PEDOMETERS", 10, 106417},
	{"NORTHVILLE", 10, 106418},
	{"URUA", 4, 106419},
	{"UMCR", 4, 106420},
	{"ULAK", 4, 106421},
	{"UATR", 4, 106422},
	{"OPYC", 4, 106423},
	{"EPIV", 4, 106424},
	{"AILV", 4, 106425},
	{"CRUMPLED", 8, 106426},
	{"SCHEDA", 6, 106427},
	{"LAKEHEAD", 8, 106428},
	{"TAKEUCHI", 8, 106429},
	{"JOJOBA", 6, 106430},
	{"TABULATIONS", 11, 106431},
	{"COMPRESSIBLE", 12, 106432},
	{"BHATIA", 6, 106433},
	{"MILLEDGEVILLE", 13, 106434},
	{"PRAT", 4, 106435},
	{"OUTCROP", 7, 106436},
	{"GAYA", 4, 106437},
	{"DIMS", 4, 106438},
	{"DESJARDINS", 10, 106439},
	{"TOPMOST", 7, 106440},
	{"INTRUDE", 7, 106441},
	{"BATCHING", 8, 106442},
	{"UMMU", 4, 106443},
	{"TTMC", 4, 106444},
	{"INRY", 4, 106445},
	{"DSIB", 4, 106446},
	{"BGEN", 4, 106447},
	{"LIBERTAS", 8, 106448},
	{"ESTEPONA", 8, 106449},
	{"ROSARIES", 8, 106450},
	{"OPIOIDS", 7, 106451},
	{"BAYH", 4, 106452},
	{"COLADA", 6, 106453},
	{"BEHEST", 6, 106454},
	{"HOFER", 5, 106455},
	{"YPAK", 4, 106456},
	{"YIKN", 4, 106457},
	{"JONR", 4, 106458},
	{"GGYA", 4, 106459},
	{"DUGU", 4, 106460},
	{"SEDARIS", 7, 106461},
	{"KELLS", 5, 106462},
	{"PITKIN", 6, 106463},
	{"SILKSCREEN", 10, 106464},
	{"REMARRIED", 9, 106465},
	{"VOYT", 4, 106466},
	{"LOBR", 4, 106467},
	{"LDEH", 4, 106468},
	{"AXAL", 4, 106469},
	{"APUM", 4, 106470},
	{"WACKO", 5, 106471},
	{"SILVERTHORNE", 12, 106472},
	{"NTLK", 4, 106473},
	{"SCARPA", 6, 106474},
	{"RESTO", 5, 106475},
	{"CHARMER", 7, 106476},
	{"SHUTTERSTOCK", 12, 106477},
	{"SCCO", 4, 106478},
	{"RPEP", 4, 106479},
	{"REKL", 4, 106480},
	{"NLDQ", 4, 106481},
	{"DIMU", 4, 106482},
	{"ABCDE", 5, 106483},
	{"STARKVILLE", 10, 106484},
	{"ESCAPADES", 9, 106485},
	{"LIPPED", 6, 106486},
	{"HAPHAZARD", 9, 106487},
	{"INFIRM", 6, 106488},
	{"PONTIFF", 7, 106489},
	{"DERM", 4, 106490},
	{"COPAY", 5, 106491},
	{"COVARIATES", 10, 106492},
	{"CORNERING", 9, 106493},
	{"WENDOVER", 8, 106494},
	{"MEISSNER", 8, 106495},
	{"YSJE", 4, 106496},
	{"RTYK", 4, 106497},
	{"PSMU", 4, 106498},
	{"MBAP", 4, 106499},
	{"EYUG", 4, 106500},
	{"EXFU", 4, 106501},
	{"DEMC", 4, 106502},
	{"COOGAN", 6, 106503},
	{"QUAGGA", 6, 106504},
	{"MENAGE", 6, 106505},
	{"PREACHES", 8, 106506},
	{"MOTHERLAND", 10, 106507},
	{"VARIOS", 6, 106508},
	{"FELLINI", 7, 106509},
	{"EXTENSA", 7, 106510},
	{"GROWLING", 8, 106511},
	{"BATTLETECH", 10, 106512},
	{"INDESCRIBABLE", 13, 106513},
	{"CORRENTE", 8, 106514},
	{"ARRAIGNMENT", 11, 106515},
	{"DEVX", 4, 106516},
	{"YDWA", 4, 106517},
	{"UYNE", 4, 106518},
	{"RCHK", 4, 106519},
	{"QWHE", 4, 106520},
	{"LTAY", 4, 106521},
	{"LOSF", 4, 106522},
	{"LABW", 4, 106523},
	{"IPEP", 4, 106524},
	{"GYDI", 4, 106525},
	{"EZFO", 4, 106526},
	{"EFSF", 4, 106527},
	{"CHNY", 4, 106528},
	{"STREETER", 8, 106529},
	{"BLACKHEATH", 10, 106530},
	{"TIKIWIKI", 8, 106531},
	{"CHASEY", 6, 106532},
	{"BREWERIANA", 10, 106533},
	{"HDFC", 4, 106534},
	{"RUSHTON", 7, 106535},
	{"EUGEN", 5, 106536},
	{"CARTOONING", 10, 106537},
	{"FFREESTANDING", 13, 106538},
	{"MATERIALITY", 11, 106539},
	{"UNGRADED", 8, 106540},
	{"KENTISH", 7, 106541},
	{"RACKHAM", 7, 106542},
	{"DISQUE", 6, 106543},
	{"SCABIES", 7, 106544},
	{"ROLANDO", 7, 106545},
	{"YPEG", 4, 106546},
	{"SLUI", 4, 106547},
	{"RASQ", 4, 106548},
	{"NZLE", 4, 106549},
	{"KBYM", 4, 106550},
	{"EKOB", 4, 106551},
	{"DOUC", 4, 106552},
	{"DGSO", 4, 106553},
	{"HIGHWIRE", 8, 106554},
	{"NAPPING", 7, 106555},
	{"SABATINI", 8, 106556},
	{"WEEKLIES", 8, 106557},
	{"EXTRUSIONS", 10, 106558},
	{"USOC", 4, 106559},
	{"MOMENTA", 7, 106560},
	{"TOPPLING", 8, 106561},
	{"NKGR", 4, 106562},
	{"LNWA", 4, 106563},
	{"LANV", 4, 106564},
	{"KSFL", 4, 106565},
	{"GNRA", 4, 106566},
	{"WORKWEEK", 8, 106567},
	{"OXYGENATION", 11, 106568},
	{"INBETWEEN", 9, 106569},
	{"ASTLEY", 6, 106570},
	{"ECARTIS", 7, 106571},
	{"BOUTON", 6, 106572},
	{"EXCELLENTLY", 11, 106573},
	{"ULMER", 5, 106574},
	{"GALOIS", 6, 106575},
	{"RELACIONES", 10, 106576},
	{"WINGMAN", 7, 106577},
	{"PAILS", 5, 106578},
	{"BURLY", 5, 106579},
	{"EBOOKERS", 8, 106580},
	{"DERECHO", 7, 106581},
	{"AKASA", 5, 106582},
	{"UTKO", 4, 106583},
	{"HARKINS", 7, 106584},
	{"GIANNA", 6, 106585},
	{"FORMULE", 7, 106586},
	{"HILLSIDES", 9, 106587},
	{"DENGAN", 6, 106588},
	{"SEGUNDA", 7, 106589},
	{"CHRETIEN", 8, 106590},
	{"UNDERUTILIZED", 13, 106591},
	{"XXIX", 4, 106592},
	{"CAND", 4, 106593},
	{"CISCOWORKS", 10, 106594},
	{"SYBIAN", 6, 106595},
	{"ZYTH", 4, 106596},
	{"RSEJ", 4, 106597},
	{"OBWO", 4, 106598},
	{"GASPAR", 6, 106599},
	{"CONTENU", 7, 106600},
	{"DIVEST", 6, 106601},
	{"MANGE", 5, 106602},
	{"MULTIUSER", 9, 106603},
	{"SEALIFE", 7, 106604},
	{"REINTRODUCTION", 14, 106605},
	{"CULBERTSON", 10, 106606},
	{"BUTADIENE", 9, 106607},
	{"DINGS", 5, 106608},
	{"UNFAIRNESS", 10, 106609},
	{"UNCHAINED", 9, 106610},
	{"KRUK", 4, 106611},
	{"WOONSOCKET", 10, 106612},
	{"BRINKMAN", 8, 106613},
	{"ABATED", 6, 106614},
	{"BELLET", 6, 106615},
	{"EHLERS", 6, 106616},
	{"YLEK", 4, 106617},
	{"XTOL", 4, 106618},
	{"RMDU", 4, 106619},
	{"RAPF", 4, 106620},
	{"GYCE", 4, 106621},
	{"GNCH", 4, 106622},
	{"GHEB", 4, 106623},
	{"FNEP", 4, 106624},
	{"PSYLLIUM", 8, 106625},
	{"OPTOELECTRONIC", 14, 106626},
	{"NANOSTRUCTURES", 14, 106627},
	{"POPLIN", 6, 106628},
	{"ANANDTECH", 9, 106629},
	{"LIMS", 4, 106630},
	{"JAAP", 4, 106631},
	{"SRILA", 5, 106632},
	{"NABP", 4, 106633},
	{"WEIZMANN", 8, 106634},
	{"RNGU", 4, 106635},
	{"RIFR", 4, 106636},
	{"IYYA", 4, 106637},
	{"FJEN", 4, 106638},
	{"ARNL", 4, 106639},
	{"ALDQ", 4, 106640},
	{"AIPR", 4, 106641},
	{"TINIEST", 7, 106642},
	{"NEUROSIS", 8, 106643},
	{"MOWED", 5, 106644},
	{"MORESBY", 7, 106645},
	{"AGENCIA", 7, 106646},
	{"PERMEATES", 9, 106647},
	{"OVERHAULED", 10, 106648},
	{"ANAPHYLAXIS", 11, 106649},
	{"STAMPIN", 7, 106650},
	{"CRISTIANO", 9, 106651},
	{"CASKETS", 7, 106652},
	{"LECTEUR", 7, 106653},
	{"YCOH", 4, 106654},
	{"RMCD", 4, 106655},
	{"RILJ", 4, 106656},
	{"REOK", 4, 106657},
	{"OKUG", 4, 106658},
	{"LKAM", 4, 106659},
	{"KDIA", 4, 106660},
	{"DLUT", 4, 106661},
	{"CONGENIAL", 9, 106662},
	{"SUPERNOVAE", 10, 106663},
	{"PFM", 3, 106664},
	{"MOFO", 4, 106665},
	{"BARBIERI", 8, 106666},
	{"FERVENTLY", 9, 106667},
	{"YEPP", 4, 106668},
	{"AURORAL", 7, 106669},
	{"URINATE", 7, 106670},
	{"KEYMAP", 6, 106671},
	{"UINL", 4, 106672},
	{"UFEL", 4, 106673},
	{"REKJ", 4, 106674},
	{"RDOZ", 4, 106675},
	{"PMRE", 4, 106676},
	{"OWLM", 4, 106677},
	{"HEKW", 4, 106678},
	{"GMYP", 4, 106679},
	{"DNAU", 4, 106680},
	{"DMRM", 4, 106681},
	{"AVAF", 4, 106682},
	{"KAREEM", 6, 106683},
	{"CARBOXYL", 8, 106684},
	{"CHOICEPOINT", 11, 106685},
	{"LINCS", 5, 106686},
	{"LYCEUM", 6, 106687},
	{"SPRAINED", 8, 106688},
	{"HARLOT", 6, 106689},
	{"RAVAGES", 7, 106690},
	{"MICROCREDIT", 11, 106691},
	{"WEATHERVANE", 11, 106692},
	{"MWR", 3, 106693},
	{"CHOIX", 5, 106694},
	{"LONGBOARD", 9, 106695},
	{"BEDROOMED", 9, 106696},
	{"EXTRACTIONS", 11, 106697},
	{"AUDEMARS", 8, 106698},
	{"DILUTIONS", 9, 106699},
	{"SUPERHUMAN", 10, 106700},
	{"OSRU", 4, 106701},
	{"LDEW", 4, 106702},
	{"IPBR", 4, 106703},
	{"ERUF", 4, 106704},
	{"BENU", 4, 106705},
	{"BEARDEN", 7, 106706},
	{"INVIA", 5, 106707},
	{"ENTOMOLOGICAL", 13, 106708},
	{"RUBIK", 5, 106709},
	{"SCHLEMMER", 9, 106710},
	{"FOOBAR", 6, 106711},
	{"SNOWDONIA", 9, 106712},
	{"QUANTIZED", 9, 106713},
	{"INTERNETOWE", 11, 106714},
	{"ECHECK", 6, 106715},
	{"UNLINED", 7, 106716},
	{"WIKIWORD", 8, 106717},
	{"KABIR", 5, 106718},
	{"GOUDA", 5, 106719},
	{"GETTYPE", 7, 106720},
	{"WKSB", 4, 106721},
	{"UCHK", 4, 106722},
	{"TCOB", 4, 106723},
	{"LKCA", 4, 106724},
	{"FRAJ", 4, 106725},
	{"FPOC", 4, 106726},
	{"FDIM", 4, 106727},
	{"RUDNICK", 7, 106728},
	{"MOGWAI", 6, 106729},
	{"AWARDEES", 8, 106730},
	{"INGLESIDE", 9, 106731},
	{"CONCLAVE", 8, 106732},
	{"ANTJE", 5, 106733},
	{"WAHLBERG", 8, 106734},
	{"APPLEBEE", 8, 106735},
	{"HUMANLY", 7, 106736},
	{"CARSDIRECT", 10, 106737},
	{"ABIOTIC", 7, 106738},
	{"MORRICONE", 9, 106739},
	{"YUDEN", 5, 106740},
	{"ALTURA", 6, 106741},
	{"CODEWARRIOR", 11, 106742},
	{"EALTH", 5, 106743},
	{"LIVIA", 5, 106744},
	{"WCHO", 4, 106745},
	{"VAUN", 4, 106746},
	{"THKU", 4, 106747},
	{"THDY", 4, 106748},
	{"FTDA", 4, 106749},
	{"CHYB", 4, 106750},
	{"BUKE", 4, 106751},
	{"ATYU", 4, 106752},
	{"AJIR", 4, 106753},
	{"RENTZ", 5, 106754},
	{"CAUSA", 5, 106755},
	{"XCX", 3, 106756},
	{"UQR", 3, 106757},
	{"PXU", 3, 106758},
	{"FVX", 3, 106759},
	{"DKQ", 3, 106760},
	{"DENTRO", 6, 106761},
	{"WCDMA", 5, 106762},
	{"UNIONISM", 8, 106763},
	{"MARLO", 5, 106764},
	{"AVENTAIL", 8, 106765},
	{"INITIALISATION", 14, 106766},
	{"GREENHILL", 9, 106767},
	{"SEALE", 5, 106768},
	{"JASC", 4, 106769},
	{"MAGNIFICENCE", 12, 106770},
	{"LEEQ", 4, 106771},
	{"GROY", 4, 106772},
	{"ELTV", 4, 106773},
	{"MATIAS", 6, 106774},
	{"EVERT", 5, 106775},
	{"XIAOPING", 8, 106776},
	{"SUPERGIRL", 9, 106777},
	{"DAMM", 4, 106778},
	{"SACRAMENTAL", 11, 106779},
	{"MPF", 3, 106780},
	{"PEDDLER", 7, 106781},
	{"WNSK", 4, 106782},
	{"PUSR", 4, 106783},
	{"LBIA", 4, 106784},
	{"FLRE", 4, 106785},
	{"HELIO", 5, 106786},
	{"BOYCOTTS", 8, 106787},
	{"ETERNA", 6, 106788},
	{"SUBACUTE", 8, 106789},
	{"NUTHIN", 6, 106790},
	{"GEOMATICS", 9, 106791},
	{"CROSSROAD", 9, 106792},
	{"MYSTERE", 7, 106793},
	{"NADAL", 5, 106794},
	{"FAYRE", 5, 106795},
	{"HAGGERTY", 8, 106796},
	{"BELLVILLE", 9, 106797},
	{"ELSON", 5, 106798},
	{"SOLICITS", 8, 106799},
	{"YWEG", 4, 106800},
	{"YFIC", 4, 106801},
	{"WIMI", 4, 106802},
	{"SIDR", 4, 106803},
	{"CDAY", 4, 106804},
	{"STREAMCAM", 9, 106805},
	{"GLARED", 6, 106806},
	{"LEEKS", 5, 106807},
	{"LIAONING", 8, 106808},
	{"ADVERBS", 7, 106809},
	{"DONC", 4, 106810},
	{"UGLINESS", 8, 106811},
	{"CONSTANTIA", 10, 106812},
	{"REPRESENTA", 10, 106813},
	{"SHAVINGS", 8, 106814},
	{"BLOGLET", 7, 106815},
	{"MCDOUGAL", 8, 106816},
	{"ARTHROPODA", 10, 106817},
	{"MERRILLVILLE", 12, 106818},
	{"SOKL", 4, 106819},
	{"ICSJ", 4, 106820},
	{"FBUF", 4, 106821},
	{"FONCTION", 8, 106822},
	{"HOBBITS", 7, 106823},
	{"TROON", 5, 106824},
	{"CHEONG", 6, 106825},
	{"SANCTIONING", 11, 106826},
	{"MAHARAJ", 7, 106827},
	{"TRATION", 7, 106828},
	{"HAWAIIANS", 9, 106829},
	{"MODERNISING", 11, 106830},
	{"SOLDTYPES", 9, 106831},
	{"MIKADO", 6, 106832},
	{"RIVERINA", 8, 106833},
	{"PETROLOGY", 9, 106834},
	{"DILLINGHAM", 10, 106835},
	{"FVWM", 4, 106836},
	{"YLST", 4, 106837},
	{"YDAW", 4, 106838},
	{"WWWL", 4, 106839},
	{"WVOT", 4, 106840},
	{"USYP", 4, 106841},
	{"TOPK", 4, 106842},
	{"RYUG", 4, 106843},
	{"ORGC", 4, 106844},
	{"LDCN", 4, 106845},
	{"KSIX", 4, 106846},
	{"ENGC", 4, 106847},
	{"EGGM", 4, 106848},
	{"AZZT", 4, 106849},
	{"BASEBOARD", 9, 106850},
	{"LUSTS", 5, 106851},
	{"FIANNA", 6, 106852},
	{"LIVESTRONG", 10, 106853},
	{"HIPER", 5, 106854},
	{"RELI", 4, 106855},
	{"NUNCA", 5, 106856},
	{"RDB", 3, 106857},
	{"HELPLESSLY", 10, 106858},
	{"QUINTESSENCE", 12, 106859},
	{"GUNNED", 6, 106860},
	{"LIBELLOUS", 9, 106861},
	{"XBRI", 4, 106862},
	{"WEYM", 4, 106863},
	{"OXSC", 4, 106864},
	{"DVAU", 4, 106865},
	{"GUIN", 4, 106866},
	{"THROES", 6, 106867},
	{"GASLAMP", 7, 106868},
	{"HDLC", 4, 106869},
	{"MALABAR", 7, 106870},
	{"PYROTECHNICS", 12, 106871},
	{"CROWBAR", 7, 106872},
	{"HOMEBOUND", 9, 106873},
	{"PEDDLING", 8, 106874},
	{"EQUIPE", 6, 106875},
	{"PAINTBRUSH", 10, 106876},
	{"OYWO", 4, 106877},
	{"GSWR", 4, 106878},
	{"COSR", 4, 106879},
	{"APKI", 4, 106880},
	{"BLOTS", 5, 106881},
	{"BRAZZIL", 7, 106882},
	{"THIESSEN", 8, 106883},
	{"VISUALSOFT", 10, 106884},
	{"CATEGORISATION", 14, 106885},
	{"NETTLES", 7, 106886},
	{"BIOTEST", 7, 106887},
	{"SUNRAY", 6, 106888},
	{"NAUKA", 5, 106889},
	{"SCUD", 4, 106890},
	{"OARK", 4, 106891},
	{"IMCE", 4, 106892},
	{"ERKT", 4, 106893},
	{"TROMEY", 6, 106894},
	{"FORTALEZA", 9, 106895},
	{"ROSEMARIE", 9, 106896},
	{"CREDA", 5, 106897},
	{"CULMINATE", 9, 106898},
	{"WHITELEY", 8, 106899},
	{"DECONSTRUCTING", 14, 106900},
	{"CORRELATING", 11, 106901},
	{"RAKED", 5, 106902},
	{"FUMIGATION", 10, 106903},
	{"STOLLER", 7, 106904},
	{"HAMANN", 6, 106905},
	{"PRECONCEPTION", 13, 106906},
	{"JUSTIFIABLY", 11, 106907},
	{"MEAGAN", 6, 106908},
	{"WGOL", 4, 106909},
	{"RAKN", 4, 106910},
	{"OFDN", 4, 106911},
	{"MICJ", 4, 106912},
	{"GIAD", 4, 106913},
	{"FSAG", 4, 106914},
	{"BEAJ", 4, 106915},
	{"CRUISED", 7, 106916},
	{"PROPOSERS", 9, 106917},
	{"STUPIDLY", 8, 106918},
	{"LASHING", 7, 106919},
	{"OCCIPITAL", 9, 106920},
	{"CRESTOR", 7, 106921},
	{"THEISM", 6, 106922},
	{"BIZET", 5, 106923},
	{"GAUDY", 5, 106924},
	{"JRUN", 4, 106925},
	{"ELECTROPHORETIC", 15, 106926},
	{"ALLEGAN", 7, 106927},
	{"RIVERBEND", 9, 106928},
	{"FOTOVISTA", 9, 106929},
	{"SAARC", 5, 106930},
	{"UHOL", 4, 106931},
	{"TSYD", 4, 106932},
	{"RCYA", 4, 106933},
	{"PIAZ", 4, 106934},
	{"PACL", 4, 106935},
	{"IBUI", 4, 106936},
	{"FCWE", 4, 106937},
	{"MVD", 3, 106938},
	{"EARHART", 7, 106939},
	{"PAGINE", 6, 106940},
	{"CLIPPERTON", 10, 106941},
	{"TABLING", 7, 106942},
	{"TARJETAS", 8, 106943},
	{"MERRIMAN", 8, 106944},
	{"DMF", 3, 106945},
	{"ERWEITERTE", 10, 106946},
	{"SWOON", 5, 106947},
	{"BOGNOR", 6, 106948},
	{"MCHALE", 6, 106949},
	{"HUNDREDTHS", 10, 106950},
	{"ZFRO", 4, 106951},
	{"SMWE", 4, 106952},
	{"RNJO", 4, 106953},
	{"OPAW", 4, 106954},
	{"NNPR", 4, 106955},
	{"LSUL", 4, 106956},
	{"ERFS", 4, 106957},
	{"BYAA", 4, 106958},
	{"BCWA", 4, 106959},
	{"BBYP", 4, 106960},
	{"AWBY", 4, 106961},
	{"ACDE", 4, 106962},
	{"BUCKSKIN", 8, 106963},
	{"BRICKYARD", 9, 106964},
	{"SOFTW", 5, 106965},
	{"GOLA", 4, 106966},
	{"KOMMT", 5, 106967},
	{"CAPTCHA", 7, 106968},
	{"JASJAR", 6, 106969},
	{"FLOATER", 7, 106970},
	{"SUCHMASCHINE", 12, 106971},
	{"OGILVY", 6, 106972},
	{"CRICKETERS", 10, 106973},
	{"FREEMASONS", 10, 106974},
	{"MUANG", 5, 106975},
	{"ROMER", 5, 106976},
	{"HITEC", 5, 106977},
	{"PMFE", 4, 106978},
	{"PHDA", 4, 106979},
	{"FAJU", 4, 106980},
	{"APOK", 4, 106981},
	{"DIMMU", 5, 106982},
	{"FOGO", 4, 106983},
	{"TROIKA", 6, 106984},
	{"MANPAGES", 8, 106985},
	{"AMATORKI", 8, 106986},
	{"RECLUSE", 7, 106987},
	{"YOUIE", 5, 106988},
	{"FRENAME", 7, 106989},
	{"LOFTON", 6, 106990},
	{"CHIANGMAI", 9, 106991},
	{"ALPINESTARS", 11, 106992},
	{"YDSA", 4, 106993},
	{"WVEN", 4, 106994},
	{"VEDK", 4, 106995},
	{"GLOI", 4, 106996},
	{"EGPS", 4, 106997},
	{"SELDEN", 6, 106998},
	{"OUTFITTING", 10, 106999},
	{"DISPLACING", 10, 107000},
	{"PROTOZOA", 8, 107001},
	{"STONING", 7, 107002},
	{"NEAPOLITAN", 10, 107003},
	{"MULTIDAPT", 9, 107004},
	{"BLACKER", 7, 107005},
	{"WEARABLES", 9, 107006},
	{"HAARLEM", 7, 107007},
	{"SUBSTRUCTURE", 12, 107008},
	{"RIDF", 4, 107009},
	{"KFIV", 4, 107010},
	{"QUEL", 4, 107011},
	{"ASPIRES", 7, 107012},
	{"CHOATE", 6, 107013},
	{"ISOTYPE", 7, 107014},
	{"HANDRAILS", 9, 107015},
	{"CHITTAGONG", 10, 107016},
	{"TELEGRAPHIC", 11, 107017},
	{"REVITALIZED", 11, 107018},
	{"REMAKING", 8, 107019},
	{"NETWORKER", 9, 107020},
	{"BRAINY", 6, 107021},
	{"EFAX", 4, 107022},
	{"HOMC", 4, 107023},
	{"CVEN", 4, 107024},
	{"BAID", 4, 107025},
	{"ALMH", 4, 107026},
	{"TABLOIDS", 8, 107027},
	{"BREUER", 6, 107028},
	{"CROSSCUT", 8, 107029},
	{"FDP", 3, 107030},
	{"QUALI", 5, 107031},
	{"MANDIBLE", 8, 107032},
	{"AGERE", 5, 107033},
	{"YWIC", 4, 107034},
	{"XISD", 4, 107035},
	{"XFEE", 4, 107036},
	{"WOEP", 4, 107037},
	{"PYHE", 4, 107038},
	{"GISJ", 4, 107039},
	{"FMAU", 4, 107040},
	{"GLENVILLE", 9, 107041},
	{"MOONBAT", 7, 107042},
	{"FRESCOES", 8, 107043},
	{"PATTED", 6, 107044},
	{"PURITANS", 8, 107045},
	{"MACGYVER", 8, 107046},
	{"ONIMUSHA", 8, 107047},
	{"GENTLEWOMAN", 11, 107048},
	{"SUBGRAPH", 8, 107049},
	{"BOSLEY", 6, 107050},
	{"CARTOUCHE", 9, 107051},
	{"FROSH", 5, 107052},
	{"MALNOURISHED", 12, 107053},
	{"KEBAB", 5, 107054},
	{"KNOTTING", 8, 107055},
	{"ASTROGRID", 9, 107056},
	{"AFFIRMATIVELY", 13, 107057},
	{"STATEROOMS", 10, 107058},
	{"STVU", 4, 107059},
	{"OYFU", 4, 107060},
	{"OREZ", 4, 107061},
	{"NCKE", 4, 107062},
	{"IRIP", 4, 107063},
	{"FAGL", 4, 107064},
	{"DYJA", 4, 107065},
	{"SUNDIALS", 8, 107066},
	{"VXWORKS", 7, 107067},
	{"CLOTURE", 7, 107068},
	{"PIGGYBACK", 9, 107069},
	{"VEVENT", 6, 107070},
	{"SOMME", 5, 107071},
	{"AUDRA", 5, 107072},
	{"WAPO", 4, 107073},
	{"DILLER", 6, 107074},
	{"GYMNASTS", 8, 107075},
	{"FRIEDLANDER", 11, 107076},
	{"PBUH", 4, 107077},
	{"FUENGIROLA", 10, 107078},
	{"USJE", 4, 107079},
	{"LBYF", 4, 107080},
	{"KIDR", 4, 107081},
	{"ERVL", 4, 107082},
	{"CRIMPING", 8, 107083},
	{"VARNISHES", 9, 107084},
	{"VEGETATED", 9, 107085},
	{"CALCULI", 7, 107086},
	{"MEINEN", 6, 107087},
	{"ARGUEMENT", 9, 107088},
	{"HAUCK", 5, 107089},
	{"DIJKSTRA", 8, 107090},
	{"NOUVEAUX", 8, 107091},
	{"AVRAHAM", 7, 107092},
	{"SHEBOYS", 7, 107093},
	{"UGAC", 4, 107094},
	{"OXPR", 4, 107095},
	{"MREI", 4, 107096},
	{"ISUM", 4, 107097},
	{"INYM", 4, 107098},
	{"IMFL", 4, 107099},
	{"DWYE", 4, 107100},
	{"DEXD", 4, 107101},
	{"DEEC", 4, 107102},
	{"CBIL", 4, 107103},
	{"AJEV", 4, 107104},
	{"LOEW", 4, 107105},
	{"TEMPUR", 6, 107106},
	{"VICTORS", 7, 107107},
	{"FONTAINEBLEAU", 13, 107108},
	{"CHAND", 5, 107109},
	{"JOURN", 5, 107110},
	{"RUNCORN", 7, 107111},
	{"COLLEY", 6, 107112},
	{"REVELS", 6, 107113},
	{"SUGARY", 6, 107114},
	{"CORMAN", 6, 107115},
	{"BROWNBACK", 9, 107116},
	{"CARRADINE", 9, 107117},
	{"SULA", 4, 107118},
	{"SKIL", 4, 107119},
	{"TIMM", 4, 107120},
	{"SELBSTBEFRIEDIGUNG", 18, 107121},
	{"TLAV", 4, 107122},
	{"PSTY", 4, 107123},
	{"NKCR", 4, 107124},
	{"LSYE", 4, 107125},
	{"KENK", 4, 107126},
	{"ALLSOP", 6, 107127},
	{"DROVES", 6, 107128},
	{"HYPOALLERGENIC", 14, 107129},
	{"WISEGUY", 7, 107130},
	{"SLUR", 4, 107131},
	{"BLODGETT", 8, 107132},
	{"GEENA", 5, 107133},
	{"VIKAS", 5, 107134},
	{"YOFZ", 4, 107135},
	{"UGWH", 4, 107136},
	{"TOLM", 4, 107137},
	{"TBEJ", 4, 107138},
	{"LKRI", 4, 107139},
	{"IZAM", 4, 107140},
	{"IKOW", 4, 107141},
	{"AFEV", 4, 107142},
	{"YUASA", 5, 107143},
	{"TIMMONS", 7, 107144},
	{"ORLANE", 6, 107145},
	{"BROWNWOOD", 9, 107146},
	{"FERRAND", 7, 107147},
	{"LAETITIA", 8, 107148},
	{"RLSU", 4, 107149},
	{"MSJO", 4, 107150},
	{"BOOKMAN", 7, 107151},
	{"ARVIN", 5, 107152},
	{"TROTTERS", 8, 107153},
	{"FERROMAGNETIC", 13, 107154},
	{"PHRASED", 7, 107155},
	{"ADRESSES", 8, 107156},
	{"ANOLON", 6, 107157},
	{"RUNGE", 5, 107158},
	{"AHRAM", 5, 107159},
	{"BINAURAL", 8, 107160},
	{"PUDDLES", 7, 107161},
	{"WARRENSBURG", 11, 107162},
	{"YEAHS", 5, 107163},
	{"EPHEMERIS", 9, 107164},
	{"VYSH", 4, 107165},
	{"KSTW", 4, 107166},
	{"GEDK", 4, 107167},
	{"REFURBISH", 9, 107168},
	{"ORANGEVILLE", 11, 107169},
	{"LATCHING", 8, 107170},
	{"PENNER", 6, 107171},
	{"SILVERA", 7, 107172},
	{"NOBLEMAN", 8, 107173},
	{"KORT", 4, 107174},
	{"CLAWSON", 7, 107175},
	{"PKGS", 4, 107176},
	{"ASSAILANT", 9, 107177},
	{"MACOSXHINTS", 11, 107178},
	{"TECHONLINE", 10, 107179},
	{"DYSTOPIA", 8, 107180},
	{"LTBO", 4, 107181},
	{"JANOS", 5, 107182},
	{"XCR", 3, 107183},
	{"LUXURIOUSLY", 11, 107184},
	{"TIPPS", 5, 107185},
	{"AMBIT", 5, 107186},
	{"FLATNESS", 8, 107187},
	{"TIEREN", 6, 107188},
	{"PARDONS", 7, 107189},
	{"DEBAUCHERY", 10, 107190},
	{"EXTRAVAGANCE", 12, 107191},
	{"BUTTRESS", 8, 107192},
	{"BISBEE", 6, 107193},
	{"RKKE", 4, 107194},
	{"OKVE", 4, 107195},
	{"DECP", 4, 107196},
	{"HEARNE", 6, 107197},
	{"KASINO", 6, 107198},
	{"STRUCTURAE", 10, 107199},
	{"ENTRADA", 7, 107200},
	{"EUTROPHICATION", 14, 107201},
	{"RIGG", 4, 107202},
	{"JUNGE", 5, 107203},
	{"EBATES", 6, 107204},
	{"AUTHORISING", 11, 107205},
	{"DEFUSE", 6, 107206},
	{"NEMOURS", 7, 107207},
	{"TVLA", 4, 107208},
	{"MIEC", 4, 107209},
	{"EXGO", 4, 107210},
	{"AZUZ", 4, 107211},
	{"WHISKER", 7, 107212},
	{"VESICULAR", 9, 107213},
	{"SEAVER", 6, 107214},
	{"GHOUL", 5, 107215},
	{"MICROECONOMIC", 13, 107216},
	{"RIGORS", 6, 107217},
	{"LAVASOFT", 8, 107218},
	{"SASKIA", 6, 107219},
	{"BOOBED", 6, 107220},
	{"FOREGONE", 8, 107221},
	{"STELLUNG", 8, 107222},
	{"ZYTO", 4, 107223},
	{"YGEA", 4, 107224},
	{"SCHB", 4, 107225},
	{"LAAP", 4, 107226},
	{"GNOP", 4, 107227},
	{"DEID", 4, 107228},
	{"TANDOORI", 8, 107229},
	{"LXER", 4, 107230},
	{"ALEXANDRITE", 11, 107231},
	{"GILLILAND", 9, 107232},
	{"DIRITTI", 7, 107233},
	{"SEQUINED", 8, 107234},
	{"OVERJOYED", 9, 107235},
	{"ASWAN", 5, 107236},
	{"FASTBALL", 8, 107237},
	{"JEFFORDS", 8, 107238},
	{"RECTIFIERS", 10, 107239},
	{"UBLO", 4, 107240},
	{"SZAC", 4, 107241},
	{"ONUK", 4, 107242},
	{"OLIQ", 4, 107243},
	{"FEFI", 4, 107244},
	{"COMPACTNESS", 11, 107245},
	{"OXBLOG", 6, 107246},
	{"MONOPOLISTIC", 12, 107247},
	{"BOULTON", 7, 107248},
	{"XZVFF", 5, 107249},
	{"WAIKOLOA", 8, 107250},
	{"BOURGOGNE", 9, 107251},
	{"FLYIN", 5, 107252},
	{"LUPTON", 6, 107253},
	{"AUTOLOAD", 8, 107254},
	{"XZZZF", 5, 107255},
	{"STREETMAP", 9, 107256},
	{"FASTPITCH", 9, 107257},
	{"NEWHAVEN", 8, 107258},
	{"YFEN", 4, 107259},
	{"VOGE", 4, 107260},
	{"OCKK", 4, 107261},
	{"LYMR", 4, 107262},
	{"LMOI", 4, 107263},
	{"IMHU", 4, 107264},
	{"APOLOGISTS", 10, 107265},
	{"UNBUNDLING", 10, 107266},
	{"IZATION", 7, 107267},
	{"MBBS", 4, 107268},
	{"YAMASHITA", 9, 107269},
	{"STATOIL", 7, 107270},
	{"ALLEMAGNE", 9, 107271},
	{"CLACK", 5, 107272},
	{"SEARC", 5, 107273},
	{"FCU", 3, 107274},
	{"VIND", 4, 107275},
	{"INTELL", 6, 107276},
	{"SALMO", 5, 107277},
	{"WAWI", 4, 107278},
	{"POPH", 4, 107279},
	{"OYPR", 4, 107280},
	{"IMGI", 4, 107281},
	{"IMAJ", 4, 107282},
	{"GNPL", 4, 107283},
	{"DCTO", 4, 107284},
	{"CURIAM", 6, 107285},
	{"SHOTEN", 6, 107286},
	{"INVITROGEN", 10, 107287},
	{"LOTSA", 5, 107288},
	{"WADDINGTON", 10, 107289},
	{"REFILLED", 8, 107290},
	{"ECORI", 5, 107291},
	{"DIGESTER", 8, 107292},
	{"SEACREST", 8, 107293},
	{"FRETBOARD", 9, 107294},
	{"GRETSCH", 7, 107295},
	{"UNIXWARE", 8, 107296},
	{"CYTOSKELETAL", 12, 107297},
	{"SMASHMETHOD", 11, 107298},
	{"RAWU", 4, 107299},
	{"NPOM", 4, 107300},
	{"IVEZ", 4, 107301},
	{"WHIFF", 5, 107302},
	{"KENORA", 6, 107303},
	{"SMARTOR", 7, 107304},
	{"BURROWING", 9, 107305},
	{"NYTR", 4, 107306},
	{"STROLLED", 8, 107307},
	{"UPNP", 4, 107308},
	{"SORORITIES", 10, 107309},
	{"ALOJAMIENTO", 11, 107310},
	{"PHPWIKI", 7, 107311},
	{"ANNOUCEMENTS", 12, 107312},
	{"FLUGHAFEN", 9, 107313},
	{"BGSU", 4, 107314},
	{"GROOVIN", 7, 107315},
	{"INSTYLE", 7, 107316},
	{"BLOKES", 6, 107317},
	{"RUPH", 4, 107318},
	{"FCAD", 4, 107319},
	{"MSHOWA", 6, 107320},
	{"LATCHED", 7, 107321},
	{"NORTHSHORE", 10, 107322},
	{"AQUAMAN", 7, 107323},
	{"DEMARCO", 7, 107324},
	{"SPAWNS", 6, 107325},
	{"EFFI", 4, 107326},
	{"BBK", 3, 107327},
	{"MAILE", 5, 107328},
	{"KAZUO", 5, 107329},
	{"WHITSUNDAY", 10, 107330},
	{"URIC", 4, 107331},
	{"REGEN", 5, 107332},
	{"REALMONEY", 9, 107333},
	{"GIDDINGS", 8, 107334},
	{"SPACEREF", 8, 107335},
	{"CRAVERS", 7, 107336},
	{"LETHALITY", 9, 107337},
	{"WONJ", 4, 107338},
	{"VAZQ", 4, 107339},
	{"OSYR", 4, 107340},
	{"OPYW", 4, 107341},
	{"NCZE", 4, 107342},
	{"KORR", 4, 107343},
	{"EYID", 4, 107344},
	{"DSKU", 4, 107345},
	{"CBST", 4, 107346},
	{"KINABALU", 8, 107347},
	{"HORSERACING", 11, 107348},
	{"ENCRUSTED", 9, 107349},
	{"REJECTIONS", 10, 107350},
	{"CLASHED", 7, 107351},
	{"HOLDALL", 7, 107352},
	{"XJB", 3, 107353},
	{"XGW", 3, 107354},
	{"WKZ", 3, 107355},
	{"KZP", 3, 107356},
	{"GZP", 3, 107357},
	{"GQP", 3, 107358},
	{"HAMPSON", 7, 107359},
	{"VICTORIANS", 10, 107360},
	{"UDWE", 4, 107361},
	{"RABP", 4, 107362},
	{"OZZL", 4, 107363},
	{"LIOD", 4, 107364},
	{"BOFO", 4, 107365},
	{"HARPOON", 7, 107366},
	{"REINING", 7, 107367},
	{"BARTLESVILLE", 12, 107368},
	{"REWRITES", 8, 107369},
	{"GOTOMYPC", 8, 107370},
	{"ZHAR", 4, 107371},
	{"VEYH", 4, 107372},
	{"TRYJ", 4, 107373},
	{"TMUH", 4, 107374},
	{"PHCA", 4, 107375},
	{"KPUR", 4, 107376},
	{"GKIT", 4, 107377},
	{"PUBLICISED", 10, 107378},
	{"STARTINCLUDE", 12, 107379},
	{"SOMBRE", 6, 107380},
	{"CREAR", 5, 107381},
	{"NADEAU", 6, 107382},
	{"CYBERWYRE", 9, 107383},
	{"SUCCINATE", 9, 107384},
	{"MACHINATIONS", 12, 107385},
	{"MARILLION", 9, 107386},
	{"ADMINSTRATION", 13, 107387},
	{"IMAPD", 5, 107388},
	{"LUNN", 4, 107389},
	{"HEARSE", 6, 107390},
	{"UOTC", 4, 107391},
	{"OLOL", 4, 107392},
	{"LOPN", 4, 107393},
	{"HWAB", 4, 107394},
	{"FFOX", 4, 107395},
	{"DIFR", 4, 107396},
	{"BASM", 4, 107397},
	{"PARHAM", 6, 107398},
	{"BECKENHAM", 9, 107399},
	{"BUCHHOLZ", 8, 107400},
	{"EVIAN", 5, 107401},
	{"TOMMOROW", 8, 107402},
	{"FLUORESCEIN", 11, 107403},
	{"REBROADCAST", 11, 107404},
	{"XUXA", 4, 107405},
	{"MARCELA", 7, 107406},
	{"NYKO", 4, 107407},
	{"ANALVERKEHR", 11, 107408},
	{"DENAVIR", 7, 107409},
	{"GIARDINO", 8, 107410},
	{"LIBERTAD", 8, 107411},
	{"YHYD", 4, 107412},
	{"XART", 4, 107413},
	{"PAPL", 4, 107414},
	{"NTCY", 4, 107415},
	{"NDNY", 4, 107416},
	{"LUEV", 4, 107417},
	{"KSVO", 4, 107418},
	{"IZEU", 4, 107419},
	{"SONICARE", 8, 107420},
	{"PARAPHRASING", 12, 107421},
	{"SUPERSIZE", 9, 107422},
	{"BOOTCUT", 7, 107423},
	{"ROAMED", 6, 107424},
	{"TOHMATSU", 8, 107425},
	{"CAULK", 5, 107426},
	{"PHARMACOTHERAPY", 15, 107427},
	{"APPROBATION", 11, 107428},
	{"SCRATCHY", 8, 107429},
	{"MONOLAYER", 9, 107430},
	{"PIGO", 4, 107431},
	{"OBYH", 4, 107432},
	{"MLYS", 4, 107433},
	{"LMYR", 4, 107434},
	{"GHEP", 4, 107435},
	{"GGMA", 4, 107436},
	{"COWW", 4, 107437},
	{"BOTR", 4, 107438},
	{"CALMNESS", 8, 107439},
	{"CONFOUND", 8, 107440},
	{"NICHOL", 6, 107441},
	{"BASEBAND", 8, 107442},
	{"SCHICK", 6, 107443},
	{"MULCAHY", 7, 107444},
	{"LINFIELD", 8, 107445},
	{"TILTS", 5, 107446},
	{"XMLRPC", 6, 107447},
	{"SEPARATISTS", 11, 107448},
	{"AIREDALE", 8, 107449},
	{"EXEMPTING", 9, 107450},
	{"BEENTHERE", 9, 107451},
	{"SEIYA", 5, 107452},
	{"YBAP", 4, 107453},
	{"URMP", 4, 107454},
	{"PWEN", 4, 107455},
	{"OLYD", 4, 107456},
	{"MCUL", 4, 107457},
	{"EFCH", 4, 107458},
	{"DOLC", 4, 107459},
	{"POIRIER", 7, 107460},
	{"LIGUE", 5, 107461},
	{"TREIBER", 7, 107462},
	{"KUVA", 4, 107463},
	{"FINALIZATION", 12, 107464},
	{"PLUMMETED", 9, 107465},
	{"LENGTHWISE", 10, 107466},
	{"ENTERGY", 7, 107467},
	{"FATTER", 6, 107468},
	{"CARROL", 6, 107469},
	{"MKHA", 4, 107470},
	{"HYID", 4, 107471},
	{"FEMU", 4, 107472},
	{"EILD", 4, 107473},
	{"DDIO", 4, 107474},
	{"CKYN", 4, 107475},
	{"ABSTAINED", 9, 107476},
	{"UNINHIBITED", 11, 107477},
	{"LIMBA", 5, 107478},
	{"REJUVENATING", 12, 107479},
	{"NABLUS", 6, 107480},
	{"EMULATES", 8, 107481},
	{"PFLUGERVILLE", 12, 107482},
	{"OLAY", 4, 107483},
	{"ADIPISCING", 10, 107484},
	{"DEFLATE", 7, 107485},
	{"PAREJA", 6, 107486},
	{"ERMA", 4, 107487},
	{"UZZO", 4, 107488},
	{"KKON", 4, 107489},
	{"KAWO", 4, 107490},
	{"IZMO", 4, 107491},
	{"GBAI", 4, 107492},
	{"BCUT", 4, 107493},
	{"DIGIPACK", 8, 107494},
	{"CANNERY", 7, 107495},
	{"KAPALUA", 7, 107496},
	{"HOPR", 4, 107497},
	{"MANNOSE", 7, 107498},
	{"IMAGERUNNER", 11, 107499},
	{"RESPEC", 6, 107500},
	{"GAUCHO", 6, 107501},
	{"SCHOO", 5, 107502},
	{"NEWSLINKS", 9, 107503},
	{"BOOTHBAY", 8, 107504},
	{"PULLIAM", 7, 107505},
	{"CONDS", 5, 107506},
	{"PJOB", 4, 107507},
	{"KYBO", 4, 107508},
	{"IFDI", 4, 107509},
	{"EYOG", 4, 107510},
	{"EWWF", 4, 107511},
	{"CMOM", 4, 107512},
	{"LANZA", 5, 107513},
	{"DALAM", 5, 107514},
	{"ONLINESPORTS", 12, 107515},
	{"MELITTA", 7, 107516},
	{"DECOMPRESS", 10, 107517},
	{"NELLIS", 6, 107518},
	{"CHASSE", 6, 107519},
	{"USCIS", 5, 107520},
	{"TANTRUMS", 8, 107521},
	{"GLASSMAN", 8, 107522},
	{"DUNGANNON", 9, 107523},
	{"MCARDLE", 7, 107524},
	{"ASHKENAZI", 9, 107525},
	{"UADM", 4, 107526},
	{"RFTH", 4, 107527},
	{"BSAF", 4, 107528},
	{"FOLKTALES", 9, 107529},
	{"CHRISTEN", 8, 107530},
	{"SKLAVE", 6, 107531},
	{"LOGOTYPE", 8, 107532},
	{"CREPES", 6, 107533},
	{"COMPARAISON", 11, 107534},
	{"GRISOFT", 7, 107535},
	{"TEHAMA", 6, 107536},
	{"SHEPHARD", 8, 107537},
	{"SHIMBUN", 7, 107538},
	{"TMYN", 4, 107539},
	{"SMSW", 4, 107540},
	{"RTUL", 4, 107541},
	{"RPIR", 4, 107542},
	{"RNFU", 4, 107543},
	{"MVIA", 4, 107544},
	{"HLOG", 4, 107545},
	{"DYYO", 4, 107546},
	{"VALEUR", 6, 107547},
	{"PAYSITE", 7, 107548},
	{"BOREL", 5, 107549},
	{"PCWORLD", 7, 107550},
	{"ADITYA", 6, 107551},
	{"SENILE", 6, 107552},
	{"COBWEBS", 7, 107553},
	{"ORIENTE", 7, 107554},
	{"KINGMAX", 7, 107555},
	{"AUTOCLAVE", 9, 107556},
	{"SHAMBHALA", 9, 107557},
	{"MILLISECOND", 11, 107558},
	{"EXPEDITING", 10, 107559},
	{"PUSHCHAIR", 9, 107560},
	{"KPET", 4, 107561},
	{"EDDW", 4, 107562},
	{"UNDERWRITE", 10, 107563},
	{"USEDOM", 6, 107564},
	{"CARLSSON", 8, 107565},
	{"TUSK", 4, 107566},
	{"ESCHATOLOGY", 11, 107567},
	{"PIRIE", 5, 107568},
	{"TRANSCODE", 9, 107569},
	{"ELECTROCHEMISTRY", 16, 107570},
	{"HELLISH", 7, 107571},
	{"AFFERENT", 8, 107572},
	{"CONQUERS", 8, 107573},
	{"OKAMOTO", 7, 107574},
	{"UYP", 3, 107575},
	{"IGLESIA", 7, 107576},
	{"MDOO", 4, 107577},
	{"IMFU", 4, 107578},
	{"EUSV", 4, 107579},
	{"URC", 3, 107580},
	{"DREE", 4, 107581},
	{"OBRIEN", 6, 107582},
	{"SUMMARIZATION", 13, 107583},
	{"PRECEPTOR", 9, 107584},
	{"UNDERCLASSMAN", 13, 107585},
	{"HUMONGOUS", 9, 107586},
	{"VASQUE", 6, 107587},
	{"ENGRAVABLE", 10, 107588},
	{"STEIGER", 7, 107589},
	{"HOMINID", 7, 107590},
	{"SSYW", 4, 107591},
	{"ROUA", 4, 107592},
	{"LWRA", 4, 107593},
	{"ITUM", 4, 107594},
	{"IGDR", 4, 107595},
	{"GAKU", 4, 107596},
	{"DALV", 4, 107597},
	{"BTWH", 4, 107598},
	{"AZUM", 4, 107599},
	{"PREEMPTED", 9, 107600},
	{"CLARO", 5, 107601},
	{"UGLIEST", 7, 107602},
	{"GASTROENTERITIS", 15, 107603},
	{"NCAC", 4, 107604},
	{"ORINDA", 6, 107605},
	{"RECOG", 5, 107606},
	{"TERAPIA", 7, 107607},
	{"MAJIKTHISE", 10, 107608},
	{"PROPIONATE", 10, 107609},
	{"CHARENTES", 9, 107610},
	{"YKHA", 4, 107611},
	{"UKRE", 4, 107612},
	{"KHAB", 4, 107613},
	{"GALN", 4, 107614},
	{"KESSEL", 6, 107615},
	{"BDU", 3, 107616},
	{"DEWSBURY", 8, 107617},
	{"UNGRATEFUL", 10, 107618},
	{"CNEWS", 5, 107619},
	{"HIGHLINE", 8, 107620},
	{"KINERASE", 8, 107621},
	{"WIKICITIES", 10, 107622},
	{"RENOUNCED", 9, 107623},
	{"TRUMPED", 7, 107624},
	{"CLASHING", 8, 107625},
	{"AGGLOMERATION", 13, 107626},
	{"VICKERY", 7, 107627},
	{"DECOMPOSING", 11, 107628},
	{"TRAINSPOTTING", 13, 107629},
	{"BRAITHWAITE", 11, 107630},
	{"SAUTER", 6, 107631},
	{"ZESU", 4, 107632},
	{"SPYW", 4, 107633},
	{"LVEB", 4, 107634},
	{"IRMR", 4, 107635},
	{"IKAP", 4, 107636},
	{"IDYL", 4, 107637},
	{"AHBL", 4, 107638},
	{"AGUSTIN", 7, 107639},
	{"CARNES", 6, 107640},
	{"MUENSTER", 8, 107641},
	{"NURAY", 5, 107642},
	{"LIGHTBULB", 9, 107643},
	{"NJAC", 4, 107644},
	{"FCM", 3, 107645},
	{"GARRITY", 7, 107646},
	{"KAUNAS", 6, 107647},
	{"CRAN", 4, 107648},
	{"BLAWG", 5, 107649},
	{"SIKHISM", 7, 107650},
	{"POSTPONING", 10, 107651},
	{"ADAMO", 5, 107652},
	{"ISRAELITE", 9, 107653},
	{"GRAVER", 6, 107654},
	{"ISOENZYMES", 10, 107655},
	{"HORSESHOES", 10, 107656},
	{"CNTY", 4, 107657},
	{"KERATIN", 7, 107658},
	{"FLEES", 5, 107659},
	{"AUSTRALIEN", 10, 107660},
	{"NORMALISED", 10, 107661},
	{"WSKY", 4, 107662},
	{"SEGID", 5, 107663},
	{"POLLA", 5, 107664},
	{"ATIONAL", 7, 107665},
	{"KIMMY", 5, 107666},
	{"IMMOBILISER", 11, 107667},
	{"BROPHY", 6, 107668},
	{"CATALASE", 8, 107669},
	{"FINSBURY", 8, 107670},
	{"GORDY", 5, 107671},
	{"LIBBEY", 6, 107672},
	{"DOLLZ", 5, 107673},
	{"DISASSEMBLED", 12, 107674},
	{"DISPONIBLES", 11, 107675},
	{"BLOCS", 5, 107676},
	{"FITZWILLIAM", 11, 107677},
	{"UVEP", 4, 107678},
	{"UORU", 4, 107679},
	{"UIVO", 4, 107680},
	{"RORV", 4, 107681},
	{"RMDR", 4, 107682},
	{"LTZS", 4, 107683},
	{"KYPO", 4, 107684},
	{"KAFA", 4, 107685},
	{"UNSPOILT", 8, 107686},
	{"TORRID", 6, 107687},
	{"GOLDSTONE", 9, 107688},
	{"ABSALOM", 7, 107689},
	{"NEWSAGENTS", 10, 107690},
	{"LEISHMANIA", 10, 107691},
	{"FRIENDLIER", 10, 107692},
	{"PRECONCEIVED", 12, 107693},
	{"SUPERSITE", 9, 107694},
	{"SNICKERS", 8, 107695},
	{"ALBIN", 5, 107696},
	{"YAAKOV", 6, 107697},
	{"ZUG", 3, 107698},
	{"RGSE", 4, 107699},
	{"HYGR", 4, 107700},
	{"ELLENSBURG", 10, 107701},
	{"MAPTECH", 7, 107702},
	{"CABELL", 6, 107703},
	{"AVVOCATI", 8, 107704},
	{"TILBURY", 7, 107705},
	{"SHIBA", 5, 107706},
	{"MICROGRAM", 9, 107707},
	{"FARNELL", 7, 107708},
	{"HUTCHES", 7, 107709},
	{"INFERRING", 9, 107710},
	{"ECOLOGISTS", 10, 107711},
	{"EVICTIONS", 9, 107712},
	{"SPOKESPERSONS", 13, 107713},
	{"ENGRAVE", 7, 107714},
	{"YUSC", 4, 107715},
	{"YHAZ", 4, 107716},
	{"TZIM", 4, 107717},
	{"RZEL", 4, 107718},
	{"PHSM", 4, 107719},
	{"ILID", 4, 107720},
	{"IGOP", 4, 107721},
	{"GBAY", 4, 107722},
	{"EEPV", 4, 107723},
	{"DISHONOR", 8, 107724},
	{"TEXTFILE", 8, 107725},
	{"SCHUTT", 6, 107726},
	{"HOARDING", 8, 107727},
	{"RIMM", 4, 107728},
	{"HAVEING", 7, 107729},
	{"BAUXITE", 7, 107730},
	{"ROADLESS", 8, 107731},
	{"STEREOLAB", 9, 107732},
	{"COMMERCIALIZE", 13, 107733},
	{"HOTELCLUB", 9, 107734},
	{"BARRACK", 7, 107735},
	{"BORGIR", 6, 107736},
	{"UNDERARM", 8, 107737},
	{"RECONDITIONING", 14, 107738},
	{"SCRIPTURL", 9, 107739},
	{"USKS", 4, 107740},
	{"UNSK", 4, 107741},
	{"TGUL", 4, 107742},
	{"SBEW", 4, 107743},
	{"RAEX", 4, 107744},
	{"PEXC", 4, 107745},
	{"LTUE", 4, 107746},
	{"GYAC", 4, 107747},
	{"FFEX", 4, 107748},
	{"BENK", 4, 107749},
	{"COMPATRIOTS", 11, 107750},
	{"BABYAGE", 7, 107751},
	{"DORR", 4, 107752},
	{"WALA", 4, 107753},
	{"SUBCLIPSE", 9, 107754},
	{"STEREOTYPED", 11, 107755},
	{"COQUILLE", 8, 107756},
	{"SHINJI", 6, 107757},
	{"MANUELA", 7, 107758},
	{"GLENNA", 6, 107759},
	{"GOUACHE", 7, 107760},
	{"SARTO", 5, 107761},
	{"FWHM", 4, 107762},
	{"IFME", 4, 107763},
	{"HOKK", 4, 107764},
	{"GYEL", 4, 107765},
	{"BTCR", 4, 107766},
	{"ANTACIDS", 8, 107767},
	{"CONSCRIPTION", 12, 107768},
	{"EXTREMEDAP", 10, 107769},
	{"ENLARGER", 8, 107770},
	{"FCL", 3, 107771},
	{"FAUQUIER", 8, 107772},
	{"MFIXED", 6, 107773},
	{"MAKEN", 5, 107774},
	{"PHILOSOPHIE", 11, 107775},
	{"EXCELENT", 8, 107776},
	{"VCX", 3, 107777},
	{"WNJA", 4, 107778},
	{"SREY", 4, 107779},
	{"RKMC", 4, 107780},
	{"PGAR", 4, 107781},
	{"KLAK", 4, 107782},
	{"CERK", 4, 107783},
	{"STRAINERS", 9, 107784},
	{"MINNA", 5, 107785},
	{"JOURDAN", 7, 107786},
	{"MANCHURIAN", 10, 107787},
	{"TRADESMAN", 9, 107788},
	{"LOZENGES", 8, 107789},
	{"PLUSES", 6, 107790},
	{"MYOPIC", 6, 107791},
	{"OCONTO", 6, 107792},
	{"SAYER", 5, 107793},
	{"CONTRARIAN", 10, 107794},
	{"DIZZYING", 8, 107795},
	{"WIMMER", 6, 107796},
	{"LYSATES", 7, 107797},
	{"EMBODYING", 9, 107798},
	{"UNSCATHED", 9, 107799},
	{"ULFL", 4, 107800},
	{"PYSE", 4, 107801},
	{"NZIG", 4, 107802},
	{"KTOV", 4, 107803},
	{"RETROFITTING", 12, 107804},
	{"MOSLEMS", 7, 107805},
	{"COURAGEOUSLY", 12, 107806},
	{"STARLUCK", 8, 107807},
	{"UNOPPOSED", 9, 107808},
	{"LDCONFIG", 8, 107809},
	{"MCNEAL", 6, 107810},
	{"SNUGLY", 6, 107811},
	{"MIDVALE", 7, 107812},
	{"TARRY", 5, 107813},
	{"FEVERS", 6, 107814},
	{"ANCESTRIES", 10, 107815},
	{"JOULE", 5, 107816},
	{"INTERROGATE", 11, 107817},
	{"TUBER", 5, 107818},
	{"WLAP", 4, 107819},
	{"UDFO", 4, 107820},
	{"TMRB", 4, 107821},
	{"TKRA", 4, 107822},
	{"RJUA", 4, 107823},
	{"OFDH", 4, 107824},
	{"MRAB", 4, 107825},
	{"KBAY", 4, 107826},
	{"GANV", 4, 107827},
	{"FRIP", 4, 107828},
	{"EIFM", 4, 107829},
	{"CHPM", 4, 107830},
	{"AALM", 4, 107831},
	{"EOCENE", 6, 107832},
	{"KEILLOR", 7, 107833},
	{"TAILLIGHT", 9, 107834},
	{"NUTTALL", 7, 107835},
	{"GRATUITS", 8, 107836},
	{"MUDDLED", 7, 107837},
	{"SKLAVEN", 7, 107838},
	{"PICON", 5, 107839},
	{"LEONORA", 7, 107840},
	{"FALKLANDS", 9, 107841},
	{"UZZW", 4, 107842},
	{"SKDR", 4, 107843},
	{"IIPR", 4, 107844},
	{"HBYM", 4, 107845},
	{"GRYB", 4, 107846},
	{"GHPH", 4, 107847},
	{"GEJE", 4, 107848},
	{"EXGI", 4, 107849},
	{"CODONS", 6, 107850},
	{"HOPF", 4, 107851},
	{"MILITAIRE", 9, 107852},
	{"SMEARING", 8, 107853},
	{"SUBJECTION", 10, 107854},
	{"MODULA", 6, 107855},
	{"EVOKING", 7, 107856},
	{"PUNCTUALITY", 11, 107857},
	{"REACTIVATED", 11, 107858},
	{"CVSLOG", 6, 107859},
	{"ACROBATIC", 9, 107860},
	{"WELCOMEGUEST", 12, 107861},
	{"ONBC", 4, 107862},
	{"LFSC", 4, 107863},
	{"LDKA", 4, 107864},
	{"AGRICOLA", 8, 107865},
	{"HOARSE", 6, 107866},
	{"DETECTIONS", 10, 107867},
	{"LYR", 3, 107868},
	{"DIERENT", 7, 107869},
	{"MISFORTUNES", 11, 107870},
	{"RAZORLIGHT", 10, 107871},
	{"KWELI", 5, 107872},
	{"VEXED", 5, 107873},
	{"DETENTIONS", 10, 107874},
	{"LESTAT", 6, 107875},
	{"MAPI", 4, 107876},
	{"SIRVISETTI", 10, 107877},
	{"DRIVIN", 6, 107878},
	{"ANNIVERSAIRE", 12, 107879},
	{"PHOTOVOLTAICS", 13, 107880},
	{"COMPLEXED", 9, 107881},
	{"CURRIES", 7, 107882},
	{"LECTIONARY", 10, 107883},
	{"GZZ", 3, 107884},
	{"ARAD", 4, 107885},
	{"YDEW", 4, 107886},
	{"UPEF", 4, 107887},
	{"UOTM", 4, 107888},
	{"RKJO", 4, 107889},
	{"PHFO", 4, 107890},
	{"OLEJ", 4, 107891},
	{"IPKE", 4, 107892},
	{"HOMY", 4, 107893},
	{"AMIV", 4, 107894},
	{"DELOS", 5, 107895},
	{"BUREAUCRACIES", 13, 107896},
	{"SLINGER", 7, 107897},
	{"COLUMNAR", 8, 107898},
	{"SCOBLEIZER", 10, 107899},
	{"INTEX", 5, 107900},
	{"LORETTO", 7, 107901},
	{"MILI", 4, 107902},
	{"CLIQUES", 7, 107903},
	{"HORWITZ", 7, 107904},
	{"WWP", 3, 107905},
	{"TERABYTE", 8, 107906},
	{"DELVING", 7, 107907},
	{"HALPERIN", 8, 107908},
	{"VANQUISHED", 10, 107909},
	{"MALLETS", 7, 107910},
	{"GAINWARD", 8, 107911},
	{"LIMOUSIN", 8, 107912},
	{"YPIR", 4, 107913},
	{"SEMR", 4, 107914},
	{"KYSO", 4, 107915},
	{"ICGL", 4, 107916},
	{"APIZ", 4, 107917},
	{"AJRA", 4, 107918},
	{"LAPEER", 6, 107919},
	{"HEADLINING", 10, 107920},
	{"ENSIM", 5, 107921},
	{"MELAKA", 6, 107922},
	{"FRITO", 5, 107923},
	{"BAROMETERS", 10, 107924},
	{"UTILISES", 8, 107925},
	{"SERCH", 5, 107926},
	{"INQUISITOR", 10, 107927},
	{"SHALIMAR", 8, 107928},
	{"ATACAMA", 7, 107929},
	{"FLOORED", 7, 107930},
	{"UOSU", 4, 107931},
	{"UBDE", 4, 107932},
	{"DYVO", 4, 107933},
	{"DDMA", 4, 107934},
	{"CBEI", 4, 107935},
	{"THUONG", 6, 107936},
	{"MBM", 3, 107937},
	{"MICRA", 5, 107938},
	{"LAHAYE", 6, 107939},
	{"INHERITING", 10, 107940},
	{"HAGGLE", 6, 107941},
	{"PLANKTONIC", 10, 107942},
	{"HISTORIQUE", 10, 107943},
	{"SHILO", 5, 107944},
	{"PROGRAMFILESDIR", 15, 107945},
	{"PLIED", 5, 107946},
	{"KRISTIE", 7, 107947},
	{"RAJU", 4, 107948},
	{"MIDLINE", 7, 107949},
	{"NTRODUCTION", 11, 107950},
	{"GOODFELLOW", 10, 107951},
	{"BEATERS", 7, 107952},
	{"XHOR", 4, 107953},
	{"URFS", 4, 107954},
	{"LBSA", 4, 107955},
	{"KYHO", 4, 107956},
	{"GLAV", 4, 107957},
	{"DGIG", 4, 107958},
	{"ENABLERS", 8, 107959},
	{"BEMIS", 5, 107960},
	{"CRTS", 4, 107961},
	{"SAYBROOK", 8, 107962},
	{"MAGYARUL", 8, 107963},
	{"MYFEEDSTER", 10, 107964},
	{"HORAN", 5, 107965},
	{"CELLINI", 7, 107966},
	{"BOVIS", 5, 107967},
	{"CHADRON", 7, 107968},
	{"RUSLAN", 6, 107969},
	{"TWANG", 5, 107970},
	{"TEXTFORMATTINGRULES", 19, 107971},
	{"RACCOONS", 8, 107972},
	{"UNCORRELATED", 12, 107973},
	{"WYLDE", 5, 107974},
	{"IMPLODE", 7, 107975},
	{"OMBRE", 5, 107976},
	{"SHUBERT", 7, 107977},
	{"WOVA", 4, 107978},
	{"LIXS", 4, 107979},
	{"IEWG", 4, 107980},
	{"HIBU", 4, 107981},
	{"ELJE", 4, 107982},
	{"EFYI", 4, 107983},
	{"DEKN", 4, 107984},
	{"CONCEIVING", 10, 107985},
	{"DALL", 4, 107986},
	{"EPFL", 4, 107987},
	{"WRD", 3, 107988},
	{"NYHETER", 7, 107989},
	{"SYRIANS", 7, 107990},
	{"MANAG", 5, 107991},
	{"INDIVISIBLE", 11, 107992},
	{"PHONIC", 6, 107993},
	{"POETICAL", 8, 107994},
	{"PLAYTECH", 8, 107995},
	{"UFFP", 4, 107996},
	{"TVEL", 4, 107997},
	{"OYDM", 4, 107998},
	{"LCAD", 4, 107999},
	{"HMYD", 4, 108000},
	{"FEBP", 4, 108001},
	{"ERBH", 4, 108002},
	{"EMSV", 4, 108003},
	{"ADKA", 4, 108004},
	{"CALLGIRLS", 9, 108005},
	{"STAGGER", 7, 108006},
	{"RWXRWXR", 7, 108007},
	{"CRUSTED", 7, 108008},
	{"GANTRY", 6, 108009},
	{"MODULATES", 9, 108010},
	{"FORSBERG", 8, 108011},
	{"NIKLAS", 6, 108012},
	{"HERALDIC", 8, 108013},
	{"PHARMGKB", 8, 108014},
	{"ELASTOMERIC", 11, 108015},
	{"BROOKDALE", 9, 108016},
	{"ARTICHOKES", 10, 108017},
	{"GALACTOSIDASE", 13, 108018},
	{"BELLI", 5, 108019},
	{"SEVENDUST", 9, 108020},
	{"MALADIES", 8, 108021},
	{"UPYE", 4, 108022},
	{"SYTR", 4, 108023},
	{"LLAJ", 4, 108024},
	{"LAMR", 4, 108025},
	{"DPHR", 4, 108026},
	{"DIDV", 4, 108027},
	{"DDAH", 4, 108028},
	{"COMG", 4, 108029},
	{"CLASSI", 6, 108030},
	{"ADJUDGED", 8, 108031},
	{"TORFAEN", 7, 108032},
	{"YXJ", 3, 108033},
	{"YQF", 3, 108034},
	{"WQW", 3, 108035},
	{"VKF", 3, 108036},
	{"LKX", 3, 108037},
	{"CQF", 3, 108038},
	{"SONTAG", 6, 108039},
	{"ADOLPHE", 7, 108040},
	{"CONNICK", 7, 108041},
	{"WINSTROL", 8, 108042},
	{"HORSLEY", 7, 108043},
	{"MOBILISE", 8, 108044},
	{"IDEOLOGICALLY", 13, 108045},
	{"EQUITORIAL", 10, 108046},
	{"ETECH", 5, 108047},
	{"PASD", 4, 108048},
	{"GJIM", 4, 108049},
	{"BBIA", 4, 108050},
	{"AGSB", 4, 108051},
	{"GROHE", 5, 108052},
	{"MADAN", 5, 108053},
	{"TAKEAWAYS", 9, 108054},
	{"KATHI", 5, 108055},
	{"COURTHOUSES", 11, 108056},
	{"PRINCELY", 8, 108057},
	{"KYL", 3, 108058},
	{"LINDQUIST", 9, 108059},
	{"GILLIARD", 8, 108060},
	{"KOSTENLOSER", 11, 108061},
	{"WISSEN", 6, 108062},
	{"BAUDELAIRE", 10, 108063},
	{"ZELW", 4, 108064},
	{"WOFG", 4, 108065},
	{"RWEV", 4, 108066},
	{"RTJE", 4, 108067},
	{"NICY", 4, 108068},
	{"NGRS", 4, 108069},
	{"EKAZ", 4, 108070},
	{"CWHA", 4, 108071},
	{"ALPE", 4, 108072},
	{"TURRETS", 7, 108073},
	{"CLEVEDON", 8, 108074},
	{"CALLUM", 6, 108075},
	{"GUNSAMERICA", 11, 108076},
	{"DIATRIBE", 8, 108077},
	{"CENTREX", 7, 108078},
	{"PERCENTILES", 11, 108079},
	{"BUSINESSPEOPLE", 14, 108080},
	{"HYDRODYNAMICS", 13, 108081},
	{"DIRICHLET", 9, 108082},
	{"PKK", 3, 108083},
	{"CLEP", 4, 108084},
	{"PRESSION", 8, 108085},
	{"UYHI", 4, 108086},
	{"UPJO", 4, 108087},
	{"UIFE", 4, 108088},
	{"UECI", 4, 108089},
	{"UDIR", 4, 108090},
	{"UBWE", 4, 108091},
	{"LANX", 4, 108092},
	{"GICN", 4, 108093},
	{"COWP", 4, 108094},
	{"CEEQ", 4, 108095},
	{"OSBOURNES", 9, 108096},
	{"SLEEPOVER", 9, 108097},
	{"EFTER", 5, 108098},
	{"CALMS", 5, 108099},
	{"ACHARYA", 7, 108100},
	{"NADP", 4, 108101},
	{"SAFLE", 5, 108102},
	{"MISGIVINGS", 10, 108103},
	{"BUSINESSWOMAN", 13, 108104},
	{"RADU", 4, 108105},
	{"WAYNESBURG", 10, 108106},
	{"NEYER", 5, 108107},
	{"IMMEDIATLY", 10, 108108},
	{"XVER", 4, 108109},
	{"UPVE", 4, 108110},
	{"OLPU", 4, 108111},
	{"IKUR", 4, 108112},
	{"HEUD", 4, 108113},
	{"CLAUDETTE", 9, 108114},
	{"ARNOTT", 6, 108115},
	{"HAVEL", 5, 108116},
	{"SUFISM", 6, 108117},
	{"SLITHER", 7, 108118},
	{"PRESUMES", 8, 108119},
	{"JUGGLER", 7, 108120},
	{"OBEYS", 5, 108121},
	{"FLOODPLAINS", 11, 108122},
	{"RASIERTE", 8, 108123},
	{"KEGEL", 5, 108124},
	{"CONTADOR", 8, 108125},
	{"MOCKUP", 6, 108126},
	{"WORSENS", 7, 108127},
	{"STIFLED", 7, 108128},
	{"MASTITIS", 8, 108129},
	{"YIBE", 4, 108130},
	{"SRIB", 4, 108131},
	{"SKAV", 4, 108132},
	{"JAYN", 4, 108133},
	{"IMTW", 4, 108134},
	{"FHOC", 4, 108135},
	{"ERRD", 4, 108136},
	{"EMGA", 4, 108137},
	{"EGGH", 4, 108138},
	{"FORMICA", 7, 108139},
	{"MONOAMINE", 9, 108140},
	{"WIESEL", 6, 108141},
	{"TAKITANI", 8, 108142},
	{"TRACIE", 6, 108143},
	{"REFERENDUMS", 11, 108144},
	{"PREPOSITION", 11, 108145},
	{"MAXFIELD", 8, 108146},
	{"PERRYVILLE", 10, 108147},
	{"LOCANDA", 7, 108148},
	{"URINALS", 7, 108149},
	{"SUBGENRE", 8, 108150},
	{"PUSHCHAIRS", 10, 108151},
	{"WILMSLOW", 8, 108152},
	{"TELENOR", 7, 108153},
	{"COWLITZ", 7, 108154},
	{"NRIM", 4, 108155},
	{"MMYE", 4, 108156},
	{"AWNP", 4, 108157},
	{"VESTIBULE", 9, 108158},
	{"DUNCANVILLE", 11, 108159},
	{"MOURNFUL", 8, 108160},
	{"SAMSARA", 7, 108161},
	{"AMELIORATE", 10, 108162},
	{"SCHEMING", 8, 108163},
	{"XGIR", 4, 108164},
	{"RTZI", 4, 108165},
	{"MYIT", 4, 108166},
	{"LGOF", 4, 108167},
	{"APUC", 4, 108168},
	{"TRIGEMINAL", 10, 108169},
	{"TRASHING", 8, 108170},
	{"DISARMED", 8, 108171},
	{"TRANSECTS", 9, 108172},
	{"BASELESS", 8, 108173},
	{"LOADABLE", 8, 108174},
	{"PREAMPLIFIER", 12, 108175},
	{"CEIL", 4, 108176},
	{"RADIOL", 6, 108177},
	{"PARLIAMENTARIAN", 15, 108178},
	{"VOILE", 5, 108179},
	{"UBSR", 4, 108180},
	{"HODB", 4, 108181},
	{"FPUS", 4, 108182},
	{"EULO", 4, 108183},
	{"AUGW", 4, 108184},
	{"PICTURING", 9, 108185},
	{"BLOGHER", 7, 108186},
	{"DISMEMBERMENT", 13, 108187},
	{"MITCHEL", 7, 108188},
	{"SUBREGION", 9, 108189},
	{"SPIVEY", 6, 108190},
	{"RACH", 4, 108191},
	{"SUSPENSEFUL", 11, 108192},
	{"BICESTER", 8, 108193},
	{"QUARTERED", 9, 108194},
	{"TEASES", 6, 108195},
	{"DANESNBOXERS", 12, 108196},
	{"AGRIPPA", 7, 108197},
	{"UNCH", 4, 108198},
	{"WWEV", 4, 108199},
	{"WBED", 4, 108200},
	{"UBCL", 4, 108201},
	{"RLCO", 4, 108202},
	{"HRAF", 4, 108203},
	{"EPAB", 4, 108204},
	{"MYSAP", 5, 108205},
	{"MESTRE", 6, 108206},
	{"OMNIMOUNT", 9, 108207},
	{"CBGB", 4, 108208},
	{"BRAILLENOTE", 11, 108209},
	{"LIONESS", 7, 108210},
	{"DISINGENUOUS", 12, 108211},
	{"MULLAN", 6, 108212},
	{"KELO", 4, 108213},
	{"FALCONE", 7, 108214},
	{"APPENDAGES", 10, 108215},
	{"CROMER", 6, 108216},
	{"FEVERISH", 8, 108217},
	{"RNQU", 4, 108218},
	{"RLDQ", 4, 108219},
	{"MMEH", 4, 108220},
	{"ENYU", 4, 108221},
	{"DICM", 4, 108222},
	{"UNFCCC", 6, 108223},
	{"STAIRWELL", 9, 108224},
	{"AMERKS", 6, 108225},
	{"PAVILLON", 8, 108226},
	{"LORELEI", 7, 108227},
	{"COULEURS", 8, 108228},
	{"CARICOM", 7, 108229},
	{"NEGLECTS", 8, 108230},
	{"SUCKLING", 8, 108231},
	{"ORFS", 4, 108232},
	{"SCYTHE", 6, 108233},
	{"MIZRAHI", 7, 108234},
	{"NEWMARK", 7, 108235},
	{"BANDWITH", 8, 108236},
	{"KAYLEE", 6, 108237},
	{"RAMADI", 6, 108238},
	{"YDYN", 4, 108239},
	{"TTGR", 4, 108240},
	{"PTYT", 4, 108241},
	{"KDIE", 4, 108242},
	{"GEOB", 4, 108243},
	{"GATV", 4, 108244},
	{"AUVE", 4, 108245},
	{"BULLDOZERS", 10, 108246},
	{"COLWELL", 7, 108247},
	{"KILIM", 5, 108248},
	{"MACD", 4, 108249},
	{"LAYED", 5, 108250},
	{"ICAM", 4, 108251},
	{"SAVONA", 6, 108252},
	{"SPONGIFORM", 10, 108253},
	{"HEAVING", 7, 108254},
	{"GEYER", 5, 108255},
	{"ROWENTA", 7, 108256},
	{"GHAZI", 5, 108257},
	{"HOMILY", 6, 108258},
	{"BODINE", 6, 108259},
	{"PEAY", 4, 108260},
	{"UDEX", 4, 108261},
	{"OLRU", 4, 108262},
	{"OBPR", 4, 108263},
	{"DNFL", 4, 108264},
	{"ZELLER", 6, 108265},
	{"BIOSPACE", 8, 108266},
	{"PENSIVE", 7, 108267},
	{"COMPAREZ", 8, 108268},
	{"STEREOSCOPIC", 12, 108269},
	{"TRAWLING", 8, 108270},
	{"IMMUNOSORBENT", 13, 108271},
	{"LADO", 4, 108272},
	{"TOPAMAX", 7, 108273},
	{"PASCHAL", 7, 108274},
	{"FUM", 3, 108275},
	{"UPSHOT", 6, 108276},
	{"FORCEWARE", 9, 108277},
	{"SHOWOFF", 7, 108278},
	{"DEPAKOTE", 8, 108279},
	{"FLATMATE", 8, 108280},
	{"COCKATOO", 8, 108281},
	{"RELIEFWEB", 9, 108282},
	{"RADICALISM", 10, 108283},
	{"POTRERO", 7, 108284},
	{"MJER", 4, 108285},
	{"HIZU", 4, 108286},
	{"GMYO", 4, 108287},
	{"RUHR", 4, 108288},
	{"CITGO", 5, 108289},
	{"KAMINSKI", 8, 108290},
	{"COUMADIN", 8, 108291},
	{"HAVILLAND", 9, 108292},
	{"OFFICINE", 8, 108293},
	{"HITWISE", 7, 108294},
	{"SEIKI", 5, 108295},
	{"SIFTED", 6, 108296},
	{"DELKIN", 6, 108297},
	{"BLUEZ", 5, 108298},
	{"TRIBULUS", 8, 108299},
	{"FELDER", 6, 108300},
	{"CHICKADEE", 9, 108301},
	{"RUFOUS", 6, 108302},
	{"MAXTECH", 7, 108303},
	{"YRUI", 4, 108304},
	{"UKEL", 4, 108305},
	{"RNOK", 4, 108306},
	{"RKLY", 4, 108307},
	{"PFEL", 4, 108308},
	{"PFAI", 4, 108309},
	{"LYKO", 4, 108310},
	{"HYEV", 4, 108311},
	{"FUERTE", 6, 108312},
	{"BOISTEROUS", 10, 108313},
	{"RAILROADING", 11, 108314},
	{"KYODO", 5, 108315},
	{"ALLEVIATED", 10, 108316},
	{"WINY", 4, 108317},
	{"UBFR", 4, 108318},
	{"TUPN", 4, 108319},
	{"BWEL", 4, 108320},
	{"MANICURED", 9, 108321},
	{"RAKESH", 6, 108322},
	{"OUTBUILDINGS", 12, 108323},
	{"MONDERA", 7, 108324},
	{"PACEMAKERS", 10, 108325},
	{"BIDDEFORD", 9, 108326},
	{"CORELLE", 7, 108327},
	{"ELDREDGE", 8, 108328},
	{"ATTWOOD", 7, 108329},
	{"SIGNI", 5, 108330},
	{"GUESTMAP", 8, 108331},
	{"HARDENNE", 8, 108332},
	{"UKAL", 4, 108333},
	{"NELJ", 4, 108334},
	{"JORV", 4, 108335},
	{"DMCL", 4, 108336},
	{"LOJBAN", 6, 108337},
	{"DECANTERS", 9, 108338},
	{"ELEVATES", 8, 108339},
	{"POITIERS", 8, 108340},
	{"CLEVO", 5, 108341},
	{"FFMPEG", 6, 108342},
	{"PANCHAYAT", 9, 108343},
	{"BRAVIA", 6, 108344},
	{"HOLYROOD", 8, 108345},
	{"AIRFIELDS", 9, 108346},
	{"LIVEWIRE", 8, 108347},
	{"PALIN", 5, 108348},
	{"PALMSOURCE", 10, 108349},
	{"MTWRF", 5, 108350},
	{"TOCQUEVILLE", 11, 108351},
	{"WHORL", 5, 108352},
	{"FLORISSANT", 10, 108353},
	{"UOTK", 4, 108354},
	{"UDUB", 4, 108355},
	{"OYCH", 4, 108356},
	{"IFBE", 4, 108357},
	{"HDIM", 4, 108358},
	{"EFSY", 4, 108359},
	{"CAYI", 4, 108360},
	{"NONEMPLOYER", 11, 108361},
	{"CARIB", 5, 108362},
	{"OFGEM", 5, 108363},
	{"WEGENER", 7, 108364},
	{"SWITCHBLADE", 11, 108365},
	{"EVERLY", 6, 108366},
	{"FREECELL", 8, 108367},
	{"GOED", 4, 108368},
	{"KYUNG", 5, 108369},
	{"BLOKS", 5, 108370},
	{"COWLING", 7, 108371},
	{"ZOLPIDEM", 8, 108372},
	{"FERMENT", 7, 108373},
	{"ENVISIONING", 11, 108374},
	{"PELICULAS", 9, 108375},
	{"CAPP", 4, 108376},
	{"BIVARIATE", 9, 108377},
	{"BUSIER", 6, 108378},
	{"REINVENTION", 11, 108379},
	{"MARCEAU", 7, 108380},
	{"BOUNTIES", 8, 108381},
	{"RMEV", 4, 108382},
	{"NOXY", 4, 108383},
	{"MLUC", 4, 108384},
	{"KIDH", 4, 108385},
	{"DHOB", 4, 108386},
	{"BCPR", 4, 108387},
	{"ANGV", 4, 108388},
	{"LEVESQUE", 8, 108389},
	{"DIFFIE", 6, 108390},
	{"CLEA", 4, 108391},
	{"MARPLE", 6, 108392},
	{"TRAXX", 5, 108393},
	{"INCURSION", 9, 108394},
	{"PHENOM", 6, 108395},
	{"AURELIA", 7, 108396},
	{"WARMUP", 6, 108397},
	{"PSCE", 4, 108398},
	{"OFNB", 4, 108399},
	{"MRGA", 4, 108400},
	{"KLAB", 4, 108401},
	{"JAYB", 4, 108402},
	{"HGLE", 4, 108403},
	{"FATY", 4, 108404},
	{"ELUI", 4, 108405},
	{"BOXM", 4, 108406},
	{"BETTENDORF", 10, 108407},
	{"NONFAMILY", 9, 108408},
	{"TRICYCLEN", 9, 108409},
	{"LEAPSTER", 8, 108410},
	{"BERGHAUS", 8, 108411},
	{"MORDECAI", 8, 108412},
	{"KATERINA", 8, 108413},
	{"ADMINISTRA", 10, 108414},
	{"LONGBOAT", 8, 108415},
	{"THINNED", 7, 108416},
	{"FOODIE", 6, 108417},
	{"FLAPPER", 7, 108418},
	{"JUHA", 4, 108419},
	{"VANV", 4, 108420},
	{"ULIB", 4, 108421},
	{"TMEK", 4, 108422},
	{"TBOG", 4, 108423},
	{"FPIR", 4, 108424},
	{"FFJU", 4, 108425},
	{"AJMA", 4, 108426},
	{"FABIEN", 6, 108427},
	{"SEIDIO", 6, 108428},
	{"CYNULLIAD", 9, 108429},
	{"AIRCREW", 7, 108430},
	{"YEONG", 5, 108431},
	{"FUP", 3, 108432},
	{"BEANE", 5, 108433},
	{"SEABIRD", 7, 108434},
	{"CONSTERNATION", 13, 108435},
	{"PRELUDES", 8, 108436},
	{"MAJID", 5, 108437},
	{"HOISTED", 7, 108438},
	{"ZZAT", 4, 108439},
	{"YUPI", 4, 108440},
	{"RAPC", 4, 108441},
	{"OVCH", 4, 108442},
	{"LTUO", 4, 108443},
	{"KEZO", 4, 108444},
	{"KEYK", 4, 108445},
	{"HEUW", 4, 108446},
	{"EBFO", 4, 108447},
	{"DHUT", 4, 108448},
	{"DHUB", 4, 108449},
	{"AWGR", 4, 108450},
	{"AMFU", 4, 108451},
	{"HISTOPATHOLOGY", 14, 108452},
	{"INTERNALIZED", 12, 108453},
	{"REICHERT", 8, 108454},
	{"TRIVIALLY", 9, 108455},
	{"JONESVILLE", 10, 108456},
	{"MAASAI", 6, 108457},
	{"ROTTWEILERS", 11, 108458},
	{"AEROPLANES", 10, 108459},
	{"WEIRDEST", 8, 108460},
	{"TURAL", 5, 108461},
	{"YYAH", 4, 108462},
	{"RWAD", 4, 108463},
	{"RUAL", 4, 108464},
	{"OCAV", 4, 108465},
	{"BOILERPLATE", 11, 108466},
	{"GOUGE", 5, 108467},
	{"AUTEURS", 7, 108468},
	{"ANTIGONE", 8, 108469},
	{"ALTONA", 6, 108470},
	{"CHIRP", 5, 108471},
	{"PLAST", 5, 108472},
	{"WASTAGE", 7, 108473},
	{"GALLSTONES", 10, 108474},
	{"MAGA", 4, 108475},
	{"HEADLINERS", 10, 108476},
	{"POLYPHONIQUES", 13, 108477},
	{"BUSPIRONE", 9, 108478},
	{"IVAR", 4, 108479},
	{"UTZE", 4, 108480},
	{"UMEV", 4, 108481},
	{"RHAC", 4, 108482},
	{"OJEF", 4, 108483},
	{"GTAU", 4, 108484},
	{"ETUG", 4, 108485},
	{"DDWE", 4, 108486},
	{"BOUS", 4, 108487},
	{"DEMAGNETIZATION", 15, 108488},
	{"DIMMED", 6, 108489},
	{"SIMONA", 6, 108490},
	{"INTRAVENOUSLY", 13, 108491},
	{"MOMMIES", 7, 108492},
	{"WONDERFULL", 10, 108493},
	{"TIMORESE", 8, 108494},
	{"LOREX", 5, 108495},
	{"YORE", 4, 108496},
	{"ALENDRONATE", 11, 108497},
	{"XCHAT", 5, 108498},
	{"ANBIETER", 8, 108499},
	{"POWERSUPPLY", 11, 108500},
	{"MODIFIABLE", 10, 108501},
	{"UTIP", 4, 108502},
	{"OLYH", 4, 108503},
	{"MLYB", 4, 108504},
	{"EUPY", 4, 108505},
	{"BULGES", 6, 108506},
	{"WORLDCONNECT", 12, 108507},
	{"STARGAZING", 10, 108508},
	{"ETYMOTIC", 8, 108509},
	{"IMPROVISATIONAL", 15, 108510},
	{"COFFEEGEEK", 10, 108511},
	{"PBD", 3, 108512},
	{"SCURRY", 6, 108513},
	{"EUSKAL", 6, 108514},
	{"GROWTHS", 7, 108515},
	{"GYRUS", 5, 108516},
	{"GANJA", 5, 108517},
	{"WAYZATA", 7, 108518},
	{"KATARINA", 8, 108519},
	{"HALVE", 5, 108520},
	{"MUSICSTACK", 10, 108521},
	{"FLAGG", 5, 108522},
	{"ALKA", 4, 108523},
	{"CONVERSANT", 10, 108524},
	{"AMINA", 5, 108525},
	{"STMR", 4, 108526},
	{"KYPR", 4, 108527},
	{"GEID", 4, 108528},
	{"FIZE", 4, 108529},
	{"ECKN", 4, 108530},
	{"DRCO", 4, 108531},
	{"COYA", 4, 108532},
	{"ADDONICS", 8, 108533},
	{"UMP", 3, 108534},
	{"COUSTEAU", 8, 108535},
	{"TORPEDOES", 9, 108536},
	{"VRBO", 4, 108537},
	{"BROUWER", 7, 108538},
	{"PEARLAND", 8, 108539},
	{"SOVEREIGNS", 10, 108540},
	{"COINCIDING", 10, 108541},
	{"SOLUCE", 6, 108542},
	{"XDES", 4, 108543},
	{"PETB", 4, 108544},
	{"KSEM", 4, 108545},
	{"GGAV", 4, 108546},
	{"BRECK", 5, 108547},
	{"LORCA", 5, 108548},
	{"NOFOLLOW", 8, 108549},
	{"AUSTRO", 6, 108550},
	{"CDKITCHEN", 9, 108551},
	{"LANDRANGER", 10, 108552},
	{"SCHOOLWORK", 10, 108553},
	{"OUTBOX", 6, 108554},
	{"SHOEMALL", 8, 108555},
	{"EARP", 4, 108556},
	{"ACQUIRER", 8, 108557},
	{"MALFORMATION", 12, 108558},
	{"WEBWORKS", 8, 108559},
	{"CONSIGNMENTS", 12, 108560},
	{"VARGA", 5, 108561},
	{"LIFELINES", 9, 108562},
	{"GRAFIX", 6, 108563},
	{"XSCH", 4, 108564},
	{"WJOU", 4, 108565},
	{"UGOR", 4, 108566},
	{"SUMB", 4, 108567},
	{"EMRU", 4, 108568},
	{"DPGR", 4, 108569},
	{"FUKUSHIMA", 9, 108570},
	{"POPULATING", 10, 108571},
	{"METHENY", 7, 108572},
	{"ELICITING", 9, 108573},
	{"LOCKYER", 7, 108574},
	{"TAMED", 5, 108575},
	{"SHQU", 4, 108576},
	{"MEAJ", 4, 108577},
	{"GIRR", 4, 108578},
	{"BINJ", 4, 108579},
	{"HERRINGTON", 10, 108580},
	{"PAPILLION", 9, 108581},
	{"FARMONLINE", 10, 108582},
	{"CRIST", 5, 108583},
	{"PHOTOALTO", 9, 108584},
	{"MILAM", 5, 108585},
	{"TOTING", 6, 108586},
	{"MONTAG", 6, 108587},
	{"ZETEC", 5, 108588},
	{"FIENDS", 6, 108589},
	{"CATEGORIZING", 12, 108590},
	{"FARMYARD", 8, 108591},
	{"DIRECTORATES", 12, 108592},
	{"CONDENSE", 8, 108593},
	{"IYENGAR", 7, 108594},
	{"GARBLED", 7, 108595},
	{"UPEM", 4, 108596},
	{"UDIU", 4, 108597},
	{"OBUM", 4, 108598},
	{"NPEP", 4, 108599},
	{"MKIT", 4, 108600},
	{"DPOC", 4, 108601},
	{"DMYN", 4, 108602},
	{"ECONOMETRICA", 12, 108603},
	{"VILLAWARE", 9, 108604},
	{"STROKER", 7, 108605},
	{"TALLOW", 6, 108606},
	{"BENEFITTED", 10, 108607},
	{"PMG", 3, 108608},
	{"LAMINATORS", 10, 108609},
	{"KFOR", 4, 108610},
	{"ANIONS", 6, 108611},
	{"UNFORGIVING", 11, 108612},
	{"ROWER", 5, 108613},
	{"HIXSON", 6, 108614},
	{"HYALURONIC", 10, 108615},
	{"SIFFREDI", 8, 108616},
	{"POIPU", 5, 108617},
	{"SUBREGIONAL", 11, 108618},
	{"REDGRAVE", 8, 108619},
	{"UYAP", 4, 108620},
	{"ULPU", 4, 108621},
	{"TTPL", 4, 108622},
	{"SOGU", 4, 108623},
	{"RTYJ", 4, 108624},
	{"MSIF", 4, 108625},
	{"KISK", 4, 108626},
	{"IELK", 4, 108627},
	{"HYAW", 4, 108628},
	{"ROCKETRY", 8, 108629},
	{"PRINCIPIA", 9, 108630},
	{"IMMOBILE", 8, 108631},
	{"ZAMAN", 5, 108632},
	{"INTERCHANGES", 12, 108633},
	{"INDISPUTABLE", 12, 108634},
	{"GUARDRAIL", 9, 108635},
	{"NATALEE", 7, 108636},
	{"CONSECTETUER", 12, 108637},
	{"LACHEY", 6, 108638},
	{"SANITIZED", 9, 108639},
	{"HARBOROUGH", 10, 108640},
	{"TICKERS", 7, 108641},
	{"INTRONS", 7, 108642},
	{"SALICYLATE", 10, 108643},
	{"UVIN", 4, 108644},
	{"RTEZ", 4, 108645},
	{"PMAG", 4, 108646},
	{"BHOP", 4, 108647},
	{"DIMMERS", 7, 108648},
	{"WINDVD", 6, 108649},
	{"UNKIND", 6, 108650},
	{"SPORTINGGOODS", 13, 108651},
	{"COMPRESSEDFILENAMES", 19, 108652},
	{"CARAVELLE", 9, 108653},
	{"MISREAD", 7, 108654},
	{"FULLNAME", 8, 108655},
	{"TELITAL", 7, 108656},
	{"VAKANTIES", 9, 108657},
	{"MAGNETOSPHERE", 13, 108658},
	{"GARR", 4, 108659},
	{"PRISMATIC", 9, 108660},
	{"YOURGUIDE", 9, 108661},
	{"OLMERT", 6, 108662},
	{"AFFICHE", 7, 108663},
	{"WGOT", 4, 108664},
	{"PPSI", 4, 108665},
	{"OKJU", 4, 108666},
	{"OIGU", 4, 108667},
	{"MMTH", 4, 108668},
	{"KJOB", 4, 108669},
	{"FOFG", 4, 108670},
	{"CKIC", 4, 108671},
	{"AUNTY", 5, 108672},
	{"PATIL", 5, 108673},
	{"EPITAXIAL", 9, 108674},
	{"CBOE", 4, 108675},
	{"SPOOFS", 6, 108676},
	{"PAUCITY", 7, 108677},
	{"KANATA", 6, 108678},
	{"MUSICALE", 8, 108679},
	{"ELENI", 5, 108680},
	{"ROEPER", 6, 108681},
	{"TOBACCIANA", 10, 108682},
	{"GILS", 4, 108683},
	{"FRIEDA", 6, 108684},
	{"YTAG", 4, 108685},
	{"VPRE", 4, 108686},
	{"DYWR", 4, 108687},
	{"SNAFU", 5, 108688},
	{"WELLSVILLE", 10, 108689},
	{"EXPEDIENCY", 10, 108690},
	{"FRISIAN", 7, 108691},
	{"ELIEZER", 7, 108692},
	{"GETADDRINFO", 11, 108693},
	{"HEATHCOTE", 9, 108694},
	{"ZKB", 3, 108695},
	{"ZGY", 3, 108696},
	{"YXZ", 3, 108697},
	{"YWQ", 3, 108698},
	{"YQL", 3, 108699},
	{"VYZ", 3, 108700},
	{"LZZ", 3, 108701},
	{"LIEUTENANTS", 11, 108702},
	{"LEFEVRE", 7, 108703},
	{"BGGSUPPORTER", 12, 108704},
	{"CONTACTLESS", 11, 108705},
	{"EPRINTS", 7, 108706},
	{"CECELIA", 7, 108707},
	{"BLOK", 4, 108708},
	{"WFAI", 4, 108709},
	{"RIXO", 4, 108710},
	{"NDKL", 4, 108711},
	{"EFEF", 4, 108712},
	{"AVANTGARDE", 10, 108713},
	{"INCUBATE", 8, 108714},
	{"DEVEREUX", 8, 108715},
	{"PHILOLOGY", 9, 108716},
	{"PEACHPIT", 8, 108717},
	{"PROPHESIED", 10, 108718},
	{"NBCW", 4, 108719},
	{"LGED", 4, 108720},
	{"LFCR", 4, 108721},
	{"DRYR", 4, 108722},
	{"DIDU", 4, 108723},
	{"DIAV", 4, 108724},
	{"BAGF", 4, 108725},
	{"AKCH", 4, 108726},
	{"STIEFEL", 7, 108727},
	{"DATAVISION", 10, 108728},
	{"PARM", 4, 108729},
	{"ROSSENDALE", 10, 108730},
	{"KRON", 4, 108731},
	{"ACRYLAMIDE", 10, 108732},
	{"FABS", 4, 108733},
	{"JAMIN", 5, 108734},
	{"HOLLINGS", 8, 108735},
	{"NFLD", 4, 108736},
	{"WAGGONER", 8, 108737},
	{"JAYE", 4, 108738},
	{"RYZOM", 5, 108739},
	{"TRANMS", 6, 108740},
	{"BUCCI", 5, 108741},
	{"BROCKVILLE", 10, 108742},
	{"COMPL", 5, 108743},
	{"UCEY", 4, 108744},
	{"RTKN", 4, 108745},
	{"RLPO", 4, 108746},
	{"AKGR", 4, 108747},
	{"TRIASSIC", 8, 108748},
	{"SHAUL", 5, 108749},
	{"ALBEE", 5, 108750},
	{"PAPO", 4, 108751},
	{"DEADBEAT", 8, 108752},
	{"CHATTERS", 8, 108753},
	{"ASHVILLE", 8, 108754},
	{"TRACKPOINT", 10, 108755},
	{"HORSEY", 6, 108756},
	{"AGRICOLE", 8, 108757},
	{"BHATTACHARYA", 12, 108758},
	{"BENZODIAZEPINE", 14, 108759},
	{"BACKWOODS", 9, 108760},
	{"TMEF", 4, 108761},
	{"PYBU", 4, 108762},
	{"LPBR", 4, 108763},
	{"EDUF", 4, 108764},
	{"RCR", 3, 108765},
	{"FAZIO", 5, 108766},
	{"PHEASANTS", 9, 108767},
	{"EAZY", 4, 108768},
	{"RFEE", 4, 108769},
	{"THUMPER", 7, 108770},
	{"NAUK", 4, 108771},
	{"GEARBOXES", 9, 108772},
	{"PRAMS", 5, 108773},
	{"GENEOLOGY", 9, 108774},
	{"ZZOS", 4, 108775},
	{"WETW", 4, 108776},
	{"ICOG", 4, 108777},
	{"HEGW", 4, 108778},
	{"FFYT", 4, 108779},
	{"EBEP", 4, 108780},
	{"BPLO", 4, 108781},
	{"RATIONALISATION", 15, 108782},
	{"EERILY", 6, 108783},
	{"LAPACK", 6, 108784},
	{"AMERICINN", 9, 108785},
	{"REPOSSESSION", 12, 108786},
	{"NAUGHTON", 8, 108787},
	{"UNTOUCHABLES", 12, 108788},
	{"UNICOM", 6, 108789},
	{"EMITTANCE", 9, 108790},
	{"SLOUCH", 6, 108791},
	{"FLYS", 4, 108792},
	{"AMULETS", 7, 108793},
	{"ULKY", 4, 108794},
	{"UEDG", 4, 108795},
	{"UCEU", 4, 108796},
	{"RPIG", 4, 108797},
	{"OKPE", 4, 108798},
	{"NTYK", 4, 108799},
	{"CLEARCASE", 9, 108800},
	{"MINTEK", 6, 108801},
	{"MICROMEDEX", 10, 108802},
	{"PADERBORN", 9, 108803},
	{"THERMOSTATIC", 12, 108804},
	{"AARONS", 6, 108805},
	{"LEGOS", 5, 108806},
	{"CARGOES", 7, 108807},
	{"FLAVONOIDS", 10, 108808},
	{"BIOPIC", 6, 108809},
	{"EYEBEAM", 7, 108810},
	{"PSOD", 4, 108811},
	{"ODOJ", 4, 108812},
	{"MMAF", 4, 108813},
	{"GHKE", 4, 108814},
	{"CLEK", 4, 108815},
	{"AXAC", 4, 108816},
	{"ACCENTUATED", 11, 108817},
	{"EDDIES", 6, 108818},
	{"DECAFFEINATED", 13, 108819},
	{"TYSONS", 6, 108820},
	{"ROOR", 4, 108821},
	{"PHOTOACCESS", 11, 108822},
	{"MONAD", 5, 108823},
	{"COMPUWARE", 9, 108824},
	{"ZAPATISTA", 9, 108825},
	{"ZIYI", 4, 108826},
	{"KATEGORIEN", 10, 108827},
	{"JOISTS", 6, 108828},
	{"DISOBEY", 7, 108829},
	{"STABILIZES", 10, 108830},
	{"RNRU", 4, 108831},
	{"KMAW", 4, 108832},
	{"IEWY", 4, 108833},
	{"EYSY", 4, 108834},
	{"AFAD", 4, 108835},
	{"FACULTAD", 8, 108836},
	{"CHRONOS", 7, 108837},
	{"ACCOMADATION", 12, 108838},
	{"LITERATUR", 9, 108839},
	{"LVIV", 4, 108840},
	{"ALUMNA", 6, 108841},
	{"SILOAM", 6, 108842},
	{"BANDY", 5, 108843},
	{"WATERCOURSES", 12, 108844},
	{"DEREGULATED", 11, 108845},
	{"PUBLICISE", 9, 108846},
	{"REMD", 4, 108847},
	{"PEMI", 4, 108848},
	{"NRYR", 4, 108849},
	{"NDXI", 4, 108850},
	{"MGOR", 4, 108851},
	{"IPFE", 4, 108852},
	{"GKNE", 4, 108853},
	{"AFTU", 4, 108854},
	{"CYGD", 4, 108855},
	{"DOCTORATES", 10, 108856},
	{"CHROMED", 7, 108857},
	{"CALENDRIER", 10, 108858},
	{"CONFECTIONS", 11, 108859},
	{"THACKER", 7, 108860},
	{"AMICABLE", 8, 108861},
	{"SLOP", 4, 108862},
	{"ENCLAVES", 8, 108863},
	{"PARAKEET", 8, 108864},
	{"PRESSMAN", 8, 108865},
	{"IMMUNOPRECIPITATION", 19, 108866},
	{"MINISAT", 7, 108867},
	{"MAPP", 4, 108868},
	{"XUAN", 4, 108869},
	{"RVAD", 4, 108870},
	{"MYAF", 4, 108871},
	{"IKAD", 4, 108872},
	{"IKAC", 4, 108873},
	{"HSPU", 4, 108874},
	{"AWUP", 4, 108875},
	{"PROSPERED", 9, 108876},
	{"GOLFSMITH", 9, 108877},
	{"SAVOURY", 7, 108878},
	{"CLIMACTIC", 9, 108879},
	{"MEAGHER", 7, 108880},
	{"BARBECUED", 9, 108881},
	{"ABOVEGROUND", 11, 108882},
	{"HUMVEE", 6, 108883},
	{"UOOF", 4, 108884},
	{"UNAK", 4, 108885},
	{"PCAK", 4, 108886},
	{"MGIR", 4, 108887},
	{"LEMG", 4, 108888},
	{"KMYS", 4, 108889},
	{"GTHD", 4, 108890},
	{"FEDF", 4, 108891},
	{"EPMT", 4, 108892},
	{"TATOUAGE", 8, 108893},
	{"NEDIS", 5, 108894},
	{"PANDERING", 9, 108895},
	{"PENDLE", 6, 108896},
	{"RADIOCARBON", 11, 108897},
	{"MATOS", 5, 108898},
	{"CITADINES", 9, 108899},
	{"ONEILL", 6, 108900},
	{"SERIALZ", 7, 108901},
	{"WEBELEMENTS", 11, 108902},
	{"COLLOQUY", 8, 108903},
	{"RODHAM", 6, 108904},
	{"IRISES", 6, 108905},
	{"SOUNDCLICK", 10, 108906},
	{"REFINERS", 8, 108907},
	{"PERSONALE", 9, 108908},
	{"NWSOURCE", 8, 108909},
	{"AMHARIC", 7, 108910},
	{"SCROLLED", 8, 108911},
	{"WSID", 4, 108912},
	{"ULVO", 4, 108913},
	{"SGUR", 4, 108914},
	{"SDUP", 4, 108915},
	{"FTCL", 4, 108916},
	{"EXFA", 4, 108917},
	{"RETORTED", 8, 108918},
	{"FUTABA", 6, 108919},
	{"FIFTIETH", 8, 108920},
	{"GROUPIES", 8, 108921},
	{"JOYFULLY", 8, 108922},
	{"SHEARWATER", 10, 108923},
	{"CLEAVED", 7, 108924},
	{"BOOKSDESKTOPSWIRELESS", 21, 108925},
	{"WASCO", 5, 108926},
	{"CASTROL", 7, 108927},
	{"MINOTEL", 7, 108928},
	{"THERMOELECTRIC", 14, 108929},
	{"DATBLYGU", 8, 108930},
	{"DISTCC", 6, 108931},
	{"WOLSELEY", 8, 108932},
	{"SKITTLES", 8, 108933},
	{"ESKIMOS", 7, 108934},
	{"KITBAG", 6, 108935},
	{"SOURIS", 6, 108936},
	{"CUPE", 4, 108937},
	{"UOSJ", 4, 108938},
	{"RIGR", 4, 108939},
	{"LGOW", 4, 108940},
	{"HSUD", 4, 108941},
	{"FKNI", 4, 108942},
	{"COLLEGIAL", 9, 108943},
	{"ALBUFEIRA", 9, 108944},
	{"SAITAMA", 7, 108945},
	{"AACC", 4, 108946},
	{"ONDER", 5, 108947},
	{"PAPILLARY", 9, 108948},
	{"ABNF", 4, 108949},
	{"SNIDE", 5, 108950},
	{"CONTRAINDICATED", 15, 108951},
	{"STYLESIDE", 9, 108952},
	{"OFFENSIVELY", 11, 108953},
	{"YMEI", 4, 108954},
	{"UACO", 4, 108955},
	{"NDNB", 4, 108956},
	{"EMYK", 4, 108957},
	{"EDOX", 4, 108958},
	{"DCOE", 4, 108959},
	{"ALZE", 4, 108960},
	{"XARA", 4, 108961},
	{"ROBERTCMARTIN", 13, 108962},
	{"NCATE", 5, 108963},
	{"ANDIE", 5, 108964},
	{"CHAPERONES", 10, 108965},
	{"VIALE", 5, 108966},
	{"FLIPPIN", 7, 108967},
	{"SPECIFIERS", 10, 108968},
	{"PLAUSIBILITY", 12, 108969},
	{"APOPKA", 6, 108970},
	{"COMMITTMENT", 11, 108971},
	{"SCHUMAN", 7, 108972},
	{"MULTISERVICE", 12, 108973},
	{"VIDEL", 5, 108974},
	{"BLARNEY", 7, 108975},
	{"HOLLADAY", 8, 108976},
	{"DVDORCHARD", 10, 108977},
	{"ZSCO", 4, 108978},
	{"YGHO", 4, 108979},
	{"URWR", 4, 108980},
	{"SMPH", 4, 108981},
	{"JAYW", 4, 108982},
	{"EEDK", 4, 108983},
	{"EAWF", 4, 108984},
	{"CYCR", 4, 108985},
	{"BNOX", 4, 108986},
	{"PROCUREMENTS", 12, 108987},
	{"ATTITUDINAL", 11, 108988},
	{"HATCHERIES", 10, 108989},
	{"NICKLE", 6, 108990},
	{"JILIN", 5, 108991},
	{"OGGI", 4, 108992},
	{"MAGNATE", 7, 108993},
	{"PILLAGE", 7, 108994},
	{"VENGEFUL", 8, 108995},
	{"LUNATICS", 8, 108996},
	{"COMPENSABLE", 11, 108997},
	{"MORENA", 6, 108998},
	{"TEETER", 6, 108999},
	{"MARNIE", 6, 109000},
	{"USYB", 4, 109001},
	{"OTUL", 4, 109002},
	{"MRSO", 4, 109003},
	{"ILPU", 4, 109004},
	{"FSPL", 4, 109005},
	{"EPBO", 4, 109006},
	{"CGOA", 4, 109007},
	{"AGNOSTICISM", 11, 109008},
	{"GADFLY", 6, 109009},
	{"RETALIATORY", 11, 109010},
	{"LEBOWSKI", 8, 109011},
	{"KNEEBOARDING", 12, 109012},
	{"ISHARES", 7, 109013},
	{"PAINTBALLS", 10, 109014},
	{"EDOM", 4, 109015},
	{"RLY", 3, 109016},
	{"IMPRACTICABLE", 13, 109017},
	{"SUBSUMED", 8, 109018},
	{"HOSPICES", 8, 109019},
	{"LADNER", 6, 109020},
	{"PELICANS", 8, 109021},
	{"VITACOST", 8, 109022},
	{"PROTOZOAN", 9, 109023},
	{"NCDC", 4, 109024},
	{"CODEGEN", 7, 109025},
	{"MISDIRECTED", 11, 109026},
	{"WWTP", 4, 109027},
	{"WEER", 4, 109028},
	{"SPATIO", 6, 109029},
	{"PREFLIGHT", 9, 109030},
	{"CREECH", 6, 109031},
	{"YASJ", 4, 109032},
	{"UAIL", 4, 109033},
	{"RINZ", 4, 109034},
	{"RDLU", 4, 109035},
	{"NLUK", 4, 109036},
	{"MGAV", 4, 109037},
	{"LTZA", 4, 109038},
	{"ERSZ", 4, 109039},
	{"AWYO", 4, 109040},
	{"JADAKISS", 8, 109041},
	{"SURRENDERS", 10, 109042},
	{"MANCHURIA", 9, 109043},
	{"SATISFIABILITY", 14, 109044},
	{"FOWARD", 6, 109045},
	{"SCRUFFY", 7, 109046},
	{"PLES", 4, 109047},
	{"PLAYFULLY", 9, 109048},
	{"BARONY", 6, 109049},
	{"GRUPAL", 6, 109050},
	{"ALBERNI", 7, 109051},
	{"DUSTS", 5, 109052},
	{"ECHR", 4, 109053},
	{"RIDM", 4, 109054},
	{"KIEG", 4, 109055},
	{"KDIF", 4, 109056},
	{"CMEL", 4, 109057},
	{"CKAH", 4, 109058},
	{"ATCY", 4, 109059},
	{"VIBRATO", 7, 109060},
	{"CHESHAM", 7, 109061},
	{"LEYDEN", 6, 109062},
	{"STOCKMAN", 8, 109063},
	{"BOZO", 4, 109064},
	{"CADDIE", 6, 109065},
	{"EJECTOR", 7, 109066},
	{"SDLT", 4, 109067},
	{"GRUFF", 5, 109068},
	{"MILLWALL", 8, 109069},
	{"PMWIKI", 6, 109070},
	{"PHOTOJOURNALIST", 15, 109071},
	{"GILGAMESH", 9, 109072},
	{"ZZLY", 4, 109073},
	{"YLLE", 4, 109074},
	{"MYSW", 4, 109075},
	{"KYHE", 4, 109076},
	{"GBED", 4, 109077},
	{"CLAA", 4, 109078},
	{"ABUK", 4, 109079},
	{"BUXOM", 5, 109080},
	{"DECIPHERING", 11, 109081},
	{"CARYN", 5, 109082},
	{"BANKCARD", 8, 109083},
	{"NICAM", 5, 109084},
	{"KRISTOFFERSON", 13, 109085},
	{"ISOMER", 6, 109086},
	{"BOTANIST", 8, 109087},
	{"MSVC", 4, 109088},
	{"MFM", 3, 109089},
	{"VOTIVES", 7, 109090},
	{"TAMPONS", 7, 109091},
	{"JOHNGOMES", 9, 109092},
	{"DEINE", 5, 109093},
	{"SANITIZER", 9, 109094},
	{"GLYCOLIC", 8, 109095},
	{"TIMIDITY", 8, 109096},
	{"UPET", 4, 109097},
	{"RAKR", 4, 109098},
	{"NGZI", 4, 109099},
	{"MRSE", 4, 109100},
	{"LMSR", 4, 109101},
	{"IAMY", 4, 109102},
	{"HUBF", 4, 109103},
	{"DOAM", 4, 109104},
	{"NUMBE", 5, 109105},
	{"CONSTRAINS", 10, 109106},
	{"NARCOLEPSY", 10, 109107},
	{"MUSTY", 5, 109108},
	{"SILENCES", 8, 109109},
	{"INSUR", 5, 109110},
	{"CURABLE", 7, 109111},
	{"CACO", 4, 109112},
	{"GUINEAS", 7, 109113},
	{"HABITACIONES", 12, 109114},
	{"SAMETIME", 8, 109115},
	{"AMAL", 4, 109116},
	{"LAWNMOWERS", 10, 109117},
	{"ERVICES", 7, 109118},
	{"DENNETT", 7, 109119},
	{"ALLREADY", 8, 109120},
	{"LUPO", 4, 109121},
	{"DROIDS", 6, 109122},
	{"UBUI", 4, 109123},
	{"OLTB", 4, 109124},
	{"LUZO", 4, 109125},
	{"CTAU", 4, 109126},
	{"CLUR", 4, 109127},
	{"HEBBEN", 6, 109128},
	{"MINISTERING", 11, 109129},
	{"OLEVIA", 6, 109130},
	{"HEANEY", 6, 109131},
	{"TRANSITS", 8, 109132},
	{"DEGRAW", 6, 109133},
	{"LITHOLOGY", 9, 109134},
	{"ARTICOLI", 8, 109135},
	{"GUENSTIG", 8, 109136},
	{"BAUCUS", 6, 109137},
	{"STRANGLE", 8, 109138},
	{"CCJS", 4, 109139},
	{"KIEJ", 4, 109140},
	{"GRAA", 4, 109141},
	{"SWERVE", 6, 109142},
	{"PROSCRIBED", 10, 109143},
	{"PANDIT", 6, 109144},
	{"LECTOR", 6, 109145},
	{"URLPARAM", 8, 109146},
	{"ANATOMICALLY", 12, 109147},
	{"BRISKET", 7, 109148},
	{"EILAT", 5, 109149},
	{"MOVEON", 6, 109150},
	{"VRAT", 4, 109151},
	{"RGIG", 4, 109152},
	{"PMDA", 4, 109153},
	{"LWHY", 4, 109154},
	{"KQUA", 4, 109155},
	{"DPAW", 4, 109156},
	{"ADDF", 4, 109157},
	{"SLEEPINESS", 10, 109158},
	{"KNUTSON", 7, 109159},
	{"CHATTERING", 10, 109160},
	{"PROPOLIS", 8, 109161},
	{"ZANTAC", 6, 109162},
	{"STATCOUNTER", 11, 109163},
	{"ESSER", 5, 109164},
	{"ORDINE", 6, 109165},
	{"NEVIN", 5, 109166},
	{"RESCHEDULING", 12, 109167},
	{"BELEN", 5, 109168},
	{"MRRAT", 5, 109169},
	{"SYNCHRONIZER", 12, 109170},
	{"FRANCONIA", 9, 109171},
	{"VULN", 4, 109172},
	{"DOMINIONS", 9, 109173},
	{"UDAA", 4, 109174},
	{"SDUL", 4, 109175},
	{"OTLY", 4, 109176},
	{"ICJE", 4, 109177},
	{"HNFR", 4, 109178},
	{"HEWF", 4, 109179},
	{"GEKN", 4, 109180},
	{"CTBL", 4, 109181},
	{"CGWI", 4, 109182},
	{"ROANE", 5, 109183},
	{"SIRSI", 5, 109184},
	{"CAPRIS", 6, 109185},
	{"PLATEAUS", 8, 109186},
	{"BERTHOLD", 8, 109187},
	{"SPANIARD", 8, 109188},
	{"SINTRA", 6, 109189},
	{"RAMPING", 7, 109190},
	{"VEGANS", 6, 109191},
	{"ORTHODONTIST", 12, 109192},
	{"PLUMMET", 7, 109193},
	{"HRESULT", 7, 109194},
	{"DEPLETE", 7, 109195},
	{"ENVIADO", 7, 109196},
	{"USERSPACE", 9, 109197},
	{"MACPERL", 7, 109198},
	{"LITTON", 6, 109199},
	{"HEIRLOOMS", 9, 109200},
	{"JAISALMER", 9, 109201},
	{"TYRANNOSAURUS", 13, 109202},
	{"KOSTER", 6, 109203},
	{"LOSTPROPHETS", 12, 109204},
	{"LOGWATCH", 8, 109205},
	{"NEOVO", 5, 109206},
	{"PUNKELECTRONIC", 14, 109207},
	{"NVIV", 4, 109208},
	{"MOWH", 4, 109209},
	{"KMHM", 4, 109210},
	{"IROQ", 4, 109211},
	{"DSMY", 4, 109212},
	{"AALR", 4, 109213},
	{"HONEYDEW", 8, 109214},
	{"GEORGI", 6, 109215},
	{"SYNCRO", 6, 109216},
	{"HAARETZ", 7, 109217},
	{"MAHONING", 8, 109218},
	{"CYCLOCROSS", 10, 109219},
	{"OAKENFOLD", 9, 109220},
	{"TRANSPLANTING", 13, 109221},
	{"VALUTAZIONE", 11, 109222},
	{"CASUALS", 7, 109223},
	{"SACCO", 5, 109224},
	{"UPDIKE", 6, 109225},
	{"XREG", 4, 109226},
	{"OUGS", 4, 109227},
	{"OBRY", 4, 109228},
	{"MNOL", 4, 109229},
	{"LKSU", 4, 109230},
	{"GULI", 4, 109231},
	{"FVES", 4, 109232},
	{"POSTULATES", 10, 109233},
	{"RJR", 3, 109234},
	{"MARIANI", 7, 109235},
	{"CARDOSO", 7, 109236},
	{"ONLOOKERS", 9, 109237},
	{"SOFIE", 5, 109238},
	{"TWITCHGURU", 10, 109239},
	{"ANDERSONVILLE", 13, 109240},
	{"WISSENSCHAFT", 12, 109241},
	{"MANSOUR", 7, 109242},
	{"WDOU", 4, 109243},
	{"GYGA", 4, 109244},
	{"EAPB", 4, 109245},
	{"DOCL", 4, 109246},
	{"TERRAPIN", 8, 109247},
	{"PHEBE", 5, 109248},
	{"DSCC", 4, 109249},
	{"SLATTERY", 8, 109250},
	{"EASINESS", 8, 109251},
	{"TREPIDATION", 11, 109252},
	{"RESENE", 6, 109253},
	{"SQUATTERS", 9, 109254},
	{"PARACETAMOL", 11, 109255},
	{"DOWNBEAT", 8, 109256},
	{"PLANTAIN", 8, 109257},
	{"BAMBINO", 7, 109258},
	{"SVAU", 4, 109259},
	{"IKUM", 4, 109260},
	{"IFBU", 4, 109261},
	{"AEQU", 4, 109262},
	{"ELDIS", 5, 109263},
	{"OBJECTORS", 9, 109264},
	{"FROMM", 5, 109265},
	{"COUSCOUS", 8, 109266},
	{"TUBULES", 7, 109267},
	{"PEPYS", 5, 109268},
	{"MUMIA", 5, 109269},
	{"SANSUI", 6, 109270},
	{"STABILISED", 10, 109271},
	{"FRAILTY", 7, 109272},
	{"JETSTREAM", 9, 109273},
	{"SERVIDOR", 8, 109274},
	{"NEUTRALIZED", 11, 109275},
	{"TANGIER", 7, 109276},
	{"VEZO", 4, 109277},
	{"RPME", 4, 109278},
	{"PSRO", 4, 109279},
	{"LTDT", 4, 109280},
	{"HAZL", 4, 109281},
	{"FEYO", 4, 109282},
	{"SEVERIN", 7, 109283},
	{"CROMPTON", 8, 109284},
	{"REASSIGN", 8, 109285},
	{"ANNEALED", 8, 109286},
	{"DRAGONLANCE", 11, 109287},
	{"BAKA", 4, 109288},
	{"ENGLER", 6, 109289},
	{"ISMAEL", 6, 109290},
	{"OUGUIYA", 7, 109291},
	{"PREWAR", 6, 109292},
	{"POLLAS", 6, 109293},
	{"MERINGUE", 8, 109294},
	{"GUTEN", 5, 109295},
	{"YNCA", 4, 109296},
	{"WOMU", 4, 109297},
	{"UOWN", 4, 109298},
	{"UARK", 4, 109299},
	{"TCYI", 4, 109300},
	{"RAUR", 4, 109301},
	{"NBCE", 4, 109302},
	{"DCIG", 4, 109303},
	{"BHOR", 4, 109304},
	{"MMBTU", 5, 109305},
	{"BATEAU", 6, 109306},
	{"CRUSHERS", 8, 109307},
	{"INFRASTRUCTURAL", 15, 109308},
	{"NEBULIZER", 9, 109309},
	{"OVERUSED", 8, 109310},
	{"RAGWEED", 7, 109311},
	{"LIGHTHEARTED", 12, 109312},
	{"MCKEON", 6, 109313},
	{"TWEETERS", 8, 109314},
	{"RHODESIAN", 9, 109315},
	{"YIMI", 4, 109316},
	{"VREC", 4, 109317},
	{"KBYP", 4, 109318},
	{"IRMD", 4, 109319},
	{"FBYS", 4, 109320},
	{"ARBOGAST", 8, 109321},
	{"VETIVER", 7, 109322},
	{"MOURNERS", 8, 109323},
	{"MAYVILLE", 8, 109324},
	{"FRSE", 4, 109325},
	{"BRANNON", 7, 109326},
	{"EQUIPED", 7, 109327},
	{"RHIC", 4, 109328},
	{"BOLINGBROOK", 11, 109329},
	{"REOPENS", 7, 109330},
	{"SCOTTSBLUFF", 11, 109331},
	{"HARV", 4, 109332},
	{"PRABHU", 6, 109333},
	{"WYNTON", 6, 109334},
	{"METTLER", 7, 109335},
	{"HURE", 4, 109336},
	{"UDAM", 4, 109337},
	{"FTEY", 4, 109338},
	{"EJUA", 4, 109339},
	{"MINIMALISM", 10, 109340},
	{"BOXWOOD", 7, 109341},
	{"CMPT", 4, 109342},
	{"CASSIS", 6, 109343},
	{"LITHOGRAPHIC", 12, 109344},
	{"UNSALTED", 8, 109345},
	{"ANAGEMENT", 9, 109346},
	{"FAWKES", 6, 109347},
	{"PLAGNE", 6, 109348},
	{"PATRAS", 6, 109349},
	{"STENTOR", 7, 109350},
	{"UITG", 4, 109351},
	{"RSAX", 4, 109352},
	{"OWLU", 4, 109353},
	{"LFIB", 4, 109354},
	{"KIDB", 4, 109355},
	{"CTPI", 4, 109356},
	{"PASSAGEWAY", 10, 109357},
	{"SEASHELLS", 9, 109358},
	{"JONESTOWN", 9, 109359},
	{"PROVER", 6, 109360},
	{"IRONPORT", 8, 109361},
	{"PADDLERS", 8, 109362},
	{"NARAYANAN", 9, 109363},
	{"NANDA", 5, 109364},
	{"INPUTSTREAM", 11, 109365},
	{"QUICKFLIX", 9, 109366},
	{"RECODIFIED", 10, 109367},
	{"REESTABLISH", 11, 109368},
	{"MENTED", 6, 109369},
	{"VOTZEN", 6, 109370},
	{"IRONSTONE", 9, 109371},
	{"DOCID", 5, 109372},
	{"UFIS", 4, 109373},
	{"TFAB", 4, 109374},
	{"SBOG", 4, 109375},
	{"LKSD", 4, 109376},
	{"KORH", 4, 109377},
	{"EZAP", 4, 109378},
	{"ELFK", 4, 109379},
	{"BOFI", 4, 109380},
	{"ASTAR", 5, 109381},
	{"XJP", 3, 109382},
	{"JYF", 3, 109383},
	{"KEYNESIAN", 9, 109384},
	{"SALWAR", 6, 109385},
	{"MICROSTATION", 12, 109386},
	{"LONGLINE", 8, 109387},
	{"FONDO", 5, 109388},
	{"RBIS", 4, 109389},
	{"BROKING", 7, 109390},
	{"PARSONAGE", 9, 109391},
	{"BERM", 4, 109392},
	{"SCAVENGING", 10, 109393},
	{"YERV", 4, 109394},
	{"WSMU", 4, 109395},
	{"WBOU", 4, 109396},
	{"TYUT", 4, 109397},
	{"NLOY", 4, 109398},
	{"MRUL", 4, 109399},
	{"FLAA", 4, 109400},
	{"MARGHERITA", 10, 109401},
	{"SURFIN", 6, 109402},
	{"OUTPUTTING", 10, 109403},
	{"SACRAL", 6, 109404},
	{"QUIEN", 5, 109405},
	{"SULPHIDE", 8, 109406},
	{"STONEBRIDGE", 11, 109407},
	{"OUTCASTS", 8, 109408},
	{"MORTALLY", 8, 109409},
	{"RATHBONE", 8, 109410},
	{"BIZZY", 5, 109411},
	{"OXIDANTS", 8, 109412},
	{"HOMESTYLE", 9, 109413},
	{"NEGOCIOS", 8, 109414},
	{"YRUD", 4, 109415},
	{"WROB", 4, 109416},
	{"REUG", 4, 109417},
	{"RDVD", 4, 109418},
	{"FREH", 4, 109419},
	{"DIQU", 4, 109420},
	{"AKAU", 4, 109421},
	{"MXP", 3, 109422},
	{"CARBONIC", 8, 109423},
	{"SERTRALINE", 10, 109424},
	{"LAWLOR", 6, 109425},
	{"FONDOS", 6, 109426},
	{"UNASSUMING", 10, 109427},
	{"HARBORSIDE", 10, 109428},
	{"DISILLUSIONMENT", 15, 109429},
	{"PLCS", 4, 109430},
	{"NOUVEL", 6, 109431},
	{"HUMANOS", 7, 109432},
	{"LOCATIONAL", 10, 109433},
	{"YMCD", 4, 109434},
	{"UTZA", 4, 109435},
	{"TVFO", 4, 109436},
	{"MTEB", 4, 109437},
	{"IMOB", 4, 109438},
	{"FBLE", 4, 109439},
	{"DAAM", 4, 109440},
	{"BUSHVELD", 8, 109441},
	{"KNEAD", 5, 109442},
	{"PROGRAMMI", 9, 109443},
	{"PREMARITAL", 10, 109444},
	{"LAMAS", 5, 109445},
	{"WILFUL", 6, 109446},
	{"CAERNARFON", 10, 109447},
	{"TWISTY", 6, 109448},
	{"THRUSTER", 8, 109449},
	{"GAOL", 4, 109450},
	{"PHONEMIC", 8, 109451},
	{"STUMBLEUPON", 11, 109452},
	{"NETCRAFT", 8, 109453},
	{"MISRA", 5, 109454},
	{"YUPW", 4, 109455},
	{"YIPH", 4, 109456},
	{"ORGB", 4, 109457},
	{"LKSE", 4, 109458},
	{"EUKB", 4, 109459},
	{"CHENBRO", 7, 109460},
	{"ERUDITE", 7, 109461},
	{"WESTER", 6, 109462},
	{"VIRTEX", 6, 109463},
	{"NGORONGORO", 10, 109464},
	{"APPRECIABLY", 11, 109465},
	{"SMITHTOWN", 9, 109466},
	{"PENTACLE", 8, 109467},
	{"EQUALIZE", 8, 109468},
	{"LUPD", 4, 109469},
	{"KPAY", 4, 109470},
	{"IXLI", 4, 109471},
	{"GVIN", 4, 109472},
	{"GELP", 4, 109473},
	{"DGOH", 4, 109474},
	{"AEROSOLES", 9, 109475},
	{"LPARAM", 6, 109476},
	{"CAREERONE", 9, 109477},
	{"PREPOSITIONS", 12, 109478},
	{"MORDOR", 6, 109479},
	{"AVNET", 5, 109480},
	{"PETITS", 6, 109481},
	{"AAVSO", 5, 109482},
	{"BARKSDALE", 9, 109483},
	{"ENDEAVOURED", 11, 109484},
	{"ELECTROPLATING", 14, 109485},
	{"PARAGRAPHE", 10, 109486},
	{"ZEMANOVA", 8, 109487},
	{"STARTINS", 8, 109488},
	{"MANVILLE", 8, 109489},
	{"XITF", 4, 109490},
	{"SZCZ", 4, 109491},
	{"RSMD", 4, 109492},
	{"RKFU", 4, 109493},
	{"OFBC", 4, 109494},
	{"NEYV", 4, 109495},
	{"MPSD", 4, 109496},
	{"KDEB", 4, 109497},
	{"HORK", 4, 109498},
	{"FAAR", 4, 109499},
	{"DCEI", 4, 109500},
	{"CHGL", 4, 109501},
	{"MULTIBYTE", 9, 109502},
	{"GROSSING", 8, 109503},
	{"GRANULOCYTE", 11, 109504},
	{"ATTENTIVELY", 11, 109505},
	{"SPOTSYLVANIA", 12, 109506},
	{"REBUT", 5, 109507},
	{"EMBARASSING", 11, 109508},
	{"JMB", 3, 109509},
	{"CYBERTRON", 9, 109510},
	{"ZANU", 4, 109511},
	{"HOBIE", 5, 109512},
	{"STRETTON", 8, 109513},
	{"YCAD", 4, 109514},
	{"XLIN", 4, 109515},
	{"WUPP", 4, 109516},
	{"TVIG", 4, 109517},
	{"OUBY", 4, 109518},
	{"IVOD", 4, 109519},
	{"ILKH", 4, 109520},
	{"HEXR", 4, 109521},
	{"EBTP", 4, 109522},
	{"DSYA", 4, 109523},
	{"CUPU", 4, 109524},
	{"ADRAN", 5, 109525},
	{"LSPS", 4, 109526},
	{"MISINTERPRETATION", 17, 109527},
	{"HILDEBRANDT", 11, 109528},
	{"WORDMARK", 8, 109529},
	{"INTERRED", 8, 109530},
	{"SAGAR", 5, 109531},
	{"NSYSUM", 6, 109532},
	{"IBISWORLD", 9, 109533},
	{"ICECREAM", 8, 109534},
	{"INDISCRIMINATELY", 16, 109535},
	{"PBYM", 4, 109536},
	{"MEMR", 4, 109537},
	{"LEONIDAS", 8, 109538},
	{"HAMMERFALL", 10, 109539},
	{"GRAZIE", 6, 109540},
	{"NETBLK", 6, 109541},
	{"GREENWAYS", 9, 109542},
	{"KEYBOARDIST", 11, 109543},
	{"WAHM", 4, 109544},
	{"XIRCOM", 6, 109545},
	{"FIRESTARTER", 11, 109546},
	{"ALANYA", 6, 109547},
	{"KYRIAD", 6, 109548},
	{"ARUNACHAL", 9, 109549},
	{"GERSON", 6, 109550},
	{"MAHINDRA", 8, 109551},
	{"SPRAIN", 6, 109552},
	{"DICLOFENAC", 10, 109553},
	{"OKLA", 4, 109554},
	{"HERODOTUS", 9, 109555},
	{"PAYLOADFILESHAVEPREFIX", 22, 109556},
	{"NOREEN", 6, 109557},
	{"HARSHEST", 8, 109558},
	{"WKID", 4, 109559},
	{"WHEF", 4, 109560},
	{"FTHL", 4, 109561},
	{"EILW", 4, 109562},
	{"ASYV", 4, 109563},
	{"HOMEBUILDERS", 12, 109564},
	{"QUANTIFIER", 10, 109565},
	{"MAISTO", 6, 109566},
	{"FAVOURING", 9, 109567},
	{"REDUCTIL", 8, 109568},
	{"DISHWASHING", 11, 109569},
	{"PLATEN", 6, 109570},
	{"PIGTAILS", 8, 109571},
	{"POACEAE", 7, 109572},
	{"NOSPAM", 6, 109573},
	{"NEUTRALS", 8, 109574},
	{"LAOTIAN", 7, 109575},
	{"GALLEGOS", 8, 109576},
	{"PETRONAS", 8, 109577},
	{"ROTHER", 6, 109578},
	{"GNOMEDEX", 8, 109579},
	{"WNYA", 4, 109580},
	{"PITL", 4, 109581},
	{"OGSR", 4, 109582},
	{"OCUP", 4, 109583},
	{"NWWW", 4, 109584},
	{"GOSF", 4, 109585},
	{"AVYY", 4, 109586},
	{"MAYBELLINE", 10, 109587},
	{"CONSPIRE", 8, 109588},
	{"KUIPER", 6, 109589},
	{"MICROFIBRE", 10, 109590},
	{"COMMERCIALIZED", 14, 109591},
	{"BODYGUARDS", 10, 109592},
	{"RECOMPENSE", 10, 109593},
	{"TECHNETIUM", 10, 109594},
	{"MEATBALL", 8, 109595},
	{"WORLDNETDAILY", 13, 109596},
	{"OLIPHANT", 8, 109597},
	{"VIDUAL", 6, 109598},
	{"CHISELS", 7, 109599},
	{"AQUARIAN", 8, 109600},
	{"YBID", 4, 109601},
	{"RLEH", 4, 109602},
	{"NLAL", 4, 109603},
	{"KJER", 4, 109604},
	{"JHAR", 4, 109605},
	{"IXWO", 4, 109606},
	{"FDIP", 4, 109607},
	{"CSGA", 4, 109608},
	{"AUSR", 4, 109609},
	{"BACTERIOLOGICAL", 15, 109610},
	{"ORIYA", 5, 109611},
	{"SOLBERG", 7, 109612},
	{"WOUTER", 6, 109613},
	{"MALTON", 6, 109614},
	{"PHONEME", 7, 109615},
	{"CENTRIFUGES", 11, 109616},
	{"BREATHABILITY", 13, 109617},
	{"FURBY", 5, 109618},
	{"OFFICIEL", 8, 109619},
	{"CONDIT", 6, 109620},
	{"KWAME", 5, 109621},
	{"ELLIPTICALS", 11, 109622},
	{"COLONNADE", 9, 109623},
	{"UNDE", 4, 109624},
	{"EUSTACE", 7, 109625},
	{"ZACA", 4, 109626},
	{"VDCO", 4, 109627},
	{"TFAD", 4, 109628},
	{"SMRB", 4, 109629},
	{"PONZ", 4, 109630},
	{"NYSK", 4, 109631},
	{"MIOL", 4, 109632},
	{"AIMU", 4, 109633},
	{"ANHYDRIDE", 9, 109634},
	{"SHREE", 5, 109635},
	{"OVERBURDEN", 10, 109636},
	{"INDEXATION", 10, 109637},
	{"ABIDES", 6, 109638},
	{"ARCHITECTURALLY", 15, 109639},
	{"SPILLWAY", 8, 109640},
	{"BNIP", 4, 109641},
	{"BINGAMAN", 8, 109642},
	{"WIEBE", 5, 109643},
	{"SPOOFED", 7, 109644},
	{"TRANSFERRIN", 11, 109645},
	{"EUROPC", 6, 109646},
	{"WLYL", 4, 109647},
	{"UNVA", 4, 109648},
	{"UBSD", 4, 109649},
	{"PBEN", 4, 109650},
	{"PALH", 4, 109651},
	{"LPGE", 4, 109652},
	{"HYAD", 4, 109653},
	{"GHYP", 4, 109654},
	{"EKDI", 4, 109655},
	{"DROF", 4, 109656},
	{"BEOW", 4, 109657},
	{"PRIVOXY", 7, 109658},
	{"DAMEN", 5, 109659},
	{"NEWSSTANDS", 10, 109660},
	{"STROVE", 6, 109661},
	{"TALKIES", 7, 109662},
	{"NEWSOME", 7, 109663},
	{"BACHCHAN", 8, 109664},
	{"BAVARO", 6, 109665},
	{"GML", 3, 109666},
	{"INTEROPERATE", 12, 109667},
	{"YZES", 4, 109668},
	{"WPAG", 4, 109669},
	{"LTHL", 4, 109670},
	{"EKOP", 4, 109671},
	{"ISLEY", 5, 109672},
	{"ALPEN", 5, 109673},
	{"DISSENTERS", 10, 109674},
	{"SUSTAINABLY", 11, 109675},
	{"STUTTER", 7, 109676},
	{"MCKESSON", 8, 109677},
	{"ATING", 5, 109678},
	{"VIAGGIATORE", 11, 109679},
	{"IMPARTING", 9, 109680},
	{"WELS", 4, 109681},
	{"FUNDY", 5, 109682},
	{"BOPP", 4, 109683},
	{"YLLP", 4, 109684},
	{"WGUY", 4, 109685},
	{"VDPL", 4, 109686},
	{"SBUZ", 4, 109687},
	{"HTCU", 4, 109688},
	{"EPDR", 4, 109689},
	{"BMEE", 4, 109690},
	{"AOFU", 4, 109691},
	{"SKEGNESS", 8, 109692},
	{"DANSMOVIES", 10, 109693},
	{"SUIKODEN", 8, 109694},
	{"EVERTHING", 9, 109695},
	{"RETICLE", 7, 109696},
	{"COPTER", 6, 109697},
	{"WENDI", 5, 109698},
	{"APOLOGIZING", 11, 109699},
	{"ROGRAM", 6, 109700},
	{"BONKERS", 7, 109701},
	{"NEWSCENTER", 10, 109702},
	{"GEFICKT", 7, 109703},
	{"YMAH", 4, 109704},
	{"REKW", 4, 109705},
	{"NDCF", 4, 109706},
	{"LPES", 4, 109707},
	{"LDUM", 4, 109708},
	{"DDYF", 4, 109709},
	{"COUPS", 5, 109710},
	{"NEOTROPICAL", 11, 109711},
	{"CALIGULA", 8, 109712},
	{"FUKUDA", 6, 109713},
	{"RIDGELINE", 9, 109714},
	{"VERDANT", 7, 109715},
	{"MECHATRONICS", 12, 109716},
	{"ZWER", 4, 109717},
	{"SGIB", 4, 109718},
	{"LHYD", 4, 109719},
	{"GBOB", 4, 109720},
	{"FSED", 4, 109721},
	{"EUMM", 4, 109722},
	{"CUOM", 4, 109723},
	{"COMMUTES", 8, 109724},
	{"CASALE", 6, 109725},
	{"SECRETE", 7, 109726},
	{"MINTO", 5, 109727},
	{"SEGUE", 5, 109728},
	{"LIBRIS", 6, 109729},
	{"HOTELIERS", 9, 109730},
	{"DOTTY", 5, 109731},
	{"TWIRL", 5, 109732},
	{"INGOT", 5, 109733},
	{"PEDAGOGIC", 9, 109734},
	{"TZWI", 4, 109735},
	{"RSMR", 4, 109736},
	{"RPWH", 4, 109737},
	{"PTAD", 4, 109738},
	{"OZED", 4, 109739},
	{"KNEC", 4, 109740},
	{"GILC", 4, 109741},
	{"AKSM", 4, 109742},
	{"POSSI", 5, 109743},
	{"GALLAUDET", 9, 109744},
	{"TOURISTIC", 9, 109745},
	{"BARRERA", 7, 109746},
	{"MIMEO", 5, 109747},
	{"FAGS", 4, 109748},
	{"VREE", 4, 109749},
	{"BELLEN", 6, 109750},
	{"DISNEYANA", 9, 109751},
	{"GUANGXI", 7, 109752},
	{"STRANGELOVE", 11, 109753},
	{"MATELY", 6, 109754},
	{"VEYM", 4, 109755},
	{"RAMJ", 4, 109756},
	{"NIBL", 4, 109757},
	{"LNOP", 4, 109758},
	{"IGIR", 4, 109759},
	{"FEKA", 4, 109760},
	{"COLW", 4, 109761},
	{"BCWH", 4, 109762},
	{"APMO", 4, 109763},
	{"ALIU", 4, 109764},
	{"LOUNGER", 7, 109765},
	{"BIOACTIVE", 9, 109766},
	{"KAUS", 4, 109767},
	{"BEADLE", 6, 109768},
	{"DENIZENS", 8, 109769},
	{"REVAMPING", 9, 109770},
	{"YAKOV", 5, 109771},
	{"FINNLAND", 8, 109772},
	{"REMARRIAGE", 10, 109773},
	{"TENANCIES", 9, 109774},
	{"BIRGIT", 6, 109775},
	{"MICROCODE", 9, 109776},
	{"COCKNEY", 7, 109777},
	{"VEYP", 4, 109778},
	{"RIKN", 4, 109779},
	{"PTYI", 4, 109780},
	{"IMOG", 4, 109781},
	{"GMYM", 4, 109782},
	{"KLUX", 4, 109783},
	{"BOGNER", 6, 109784},
	{"LIBOBJS", 7, 109785},
	{"GRILLZ", 6, 109786},
	{"WODONGA", 7, 109787},
	{"BILINGUALISM", 12, 109788},
	{"GUPPY", 5, 109789},
	{"PENNING", 7, 109790},
	{"GAMMONS", 7, 109791},
	{"NODULE", 6, 109792},
	{"ABETTING", 8, 109793},
	{"PHINNEY", 7, 109794},
	{"XTPA", 4, 109795},
	{"WHYL", 4, 109796},
	{"WETU", 4, 109797},
	{"VSKA", 4, 109798},
	{"SIFC", 4, 109799},
	{"PUSU", 4, 109800},
	{"PIWA", 4, 109801},
	{"NDDJ", 4, 109802},
	{"LTYG", 4, 109803},
	{"HYSP", 4, 109804},
	{"HWOL", 4, 109805},
	{"ALGH", 4, 109806},
	{"GUSTA", 5, 109807},
	{"ROSSLYN", 7, 109808},
	{"MESHUGGAH", 9, 109809},
	{"HABERMAS", 8, 109810},
	{"PARIBAS", 7, 109811},
	{"SEAGROVE", 8, 109812},
	{"PAELLA", 6, 109813},
	{"SIGNA", 5, 109814},
	{"TRAXXAS", 7, 109815},
	{"LYRIS", 5, 109816},
	{"THARP", 5, 109817},
	{"ENCICLOPEDIA", 12, 109818},
	{"RAIDEN", 6, 109819},
	{"COLEY", 5, 109820},
	{"MODELERS", 8, 109821},
	{"QUOE", 4, 109822},
	{"OVDE", 4, 109823},
	{"DTID", 4, 109824},
	{"SOUTHWORTH", 10, 109825},
	{"HANDOFF", 7, 109826},
	{"LEECHES", 7, 109827},
	{"JAROSLAV", 8, 109828},
	{"NIHONGO", 7, 109829},
	{"INFILTRATING", 12, 109830},
	{"VRIJE", 5, 109831},
	{"CONFIRMATORY", 12, 109832},
	{"SPIGA", 5, 109833},
	{"CHOCO", 5, 109834},
	{"RIVENDELL", 9, 109835},
	{"CONVOYS", 7, 109836},
	{"PPF", 3, 109837},
	{"DRAVID", 6, 109838},
	{"MANOEUVRES", 10, 109839},
	{"XLOS", 4, 109840},
	{"XHUS", 4, 109841},
	{"URUT", 4, 109842},
	{"UINP", 4, 109843},
	{"FGON", 4, 109844},
	{"EVYA", 4, 109845},
	{"OSPREYS", 7, 109846},
	{"SENDEN", 6, 109847},
	{"COOPERATES", 10, 109848},
	{"CODEBOOK", 8, 109849},
	{"AMPLIFYING", 10, 109850},
	{"RAFFAELLO", 9, 109851},
	{"MASSILLON", 9, 109852},
	{"ALIMENTATION", 12, 109853},
	{"LYRED", 5, 109854},
	{"INTERVIDEO", 10, 109855},
	{"CONJURES", 8, 109856},
	{"IGOUGO", 6, 109857},
	{"WNMY", 4, 109858},
	{"UIVE", 4, 109859},
	{"RURG", 4, 109860},
	{"RUMR", 4, 109861},
	{"RDWR", 4, 109862},
	{"PTAG", 4, 109863},
	{"HILJ", 4, 109864},
	{"WINTERTHUR", 10, 109865},
	{"SHAPELY", 7, 109866},
	{"ASPARTIC", 8, 109867},
	{"ALESSIO", 7, 109868},
	{"NECES", 5, 109869},
	{"VIMAX", 5, 109870},
	{"ROOKS", 5, 109871},
	{"TUNNELLING", 10, 109872},
	{"FIRECRACKER", 11, 109873},
	{"HILAIRE", 7, 109874},
	{"BODHISATTVA", 11, 109875},
	{"YZST", 4, 109876},
	{"WWOM", 4, 109877},
	{"WMYS", 4, 109878},
	{"KSEP", 4, 109879},
	{"ISCW", 4, 109880},
	{"CWOM", 4, 109881},
	{"FAIRGROUND", 10, 109882},
	{"CHOWAN", 6, 109883},
	{"CARREFOUR", 9, 109884},
	{"NIGERIANS", 9, 109885},
	{"IMAGEPIXEL", 10, 109886},
	{"WOODALL", 7, 109887},
	{"GPD", 3, 109888},
	{"PAPADOPOULOS", 12, 109889},
	{"SHUDDERED", 9, 109890},
	{"SKYHAWK", 7, 109891},
	{"DRAFTERS", 8, 109892},
	{"TELIA", 5, 109893},
	{"INTERNETONLINE", 14, 109894},
	{"ULSM", 4, 109895},
	{"TZLE", 4, 109896},
	{"MTIL", 4, 109897},
	{"LAAC", 4, 109898},
	{"ITZM", 4, 109899},
	{"FFEU", 4, 109900},
	{"BUYG", 4, 109901},
	{"MULLAH", 6, 109902},
	{"WHEELIE", 7, 109903},
	{"PREEMIE", 7, 109904},
	{"NASTOLATKI", 10, 109905},
	{"STELLE", 6, 109906},
	{"SPAYED", 6, 109907},
	{"TAMAN", 5, 109908},
	{"NODING", 6, 109909},
	{"OVERACTIVE", 10, 109910},
	{"MAHD", 4, 109911},
	{"KIMU", 4, 109912},
	{"BBCW", 4, 109913},
	{"ARMG", 4, 109914},
	{"HOMEY", 5, 109915},
	{"ORNAMENTATION", 13, 109916},
	{"REARRANGEMENTS", 14, 109917},
	{"LYNCHING", 8, 109918},
	{"SOMMES", 6, 109919},
	{"ACCESORIOS", 10, 109920},
	{"PERDIDO", 7, 109921},
	{"DICTATORIAL", 11, 109922},
	{"UNCOMFORTABLY", 13, 109923},
	{"RABBINIC", 8, 109924},
	{"CSTYLE", 6, 109925},
	{"COSWORTH", 8, 109926},
	{"REFINER", 7, 109927},
	{"BENJAMINS", 9, 109928},
	{"WINU", 4, 109929},
	{"TELV", 4, 109930},
	{"RAHF", 4, 109931},
	{"OYDR", 4, 109932},
	{"OVOW", 4, 109933},
	{"MCGW", 4, 109934},
	{"IAMK", 4, 109935},
	{"EWNB", 4, 109936},
	{"AMARANTH", 8, 109937},
	{"ZIDOVUDINE", 10, 109938},
	{"FHUS", 4, 109939},
	{"TOURER", 6, 109940},
	{"DEFENSELESS", 11, 109941},
	{"JOKINGLY", 8, 109942},
	{"IBOOKS", 6, 109943},
	{"GLEAN", 5, 109944},
	{"PATOU", 5, 109945},
	{"AMORY", 5, 109946},
	{"SAYED", 5, 109947},
	{"MACNEILLIE", 10, 109948},
	{"ANDER", 5, 109949},
	{"PDUE", 4, 109950},
	{"OUFF", 4, 109951},
	{"EYDL", 4, 109952},
	{"COAK", 4, 109953},
	{"AOFJ", 4, 109954},
	{"AGLU", 4, 109955},
	{"CHOREOGRAPHERS", 14, 109956},
	{"MIRAPOINT", 9, 109957},
	{"WHITECHAPEL", 11, 109958},
	{"WETHERSFIELD", 12, 109959},
	{"BURWOOD", 7, 109960},
	{"EDAD", 4, 109961},
	{"ENGELBREIT", 10, 109962},
	{"KENNARD", 7, 109963},
	{"WOODTURNING", 11, 109964},
	{"ICICLE", 6, 109965},
	{"PREGGOS", 7, 109966},
	{"HOOVES", 6, 109967},
	{"GRATIFIED", 9, 109968},
	{"PARTICIPLE", 10, 109969},
	{"UAVE", 4, 109970},
	{"ONYJ", 4, 109971},
	{"KEMB", 4, 109972},
	{"DRWI", 4, 109973},
	{"BBSI", 4, 109974},
	{"ULLA", 4, 109975},
	{"SCHLEGEL", 8, 109976},
	{"FEATHERSTONE", 12, 109977},
	{"CARTERSVILLE", 12, 109978},
	{"HOTDOG", 6, 109979},
	{"WATCHMEN", 8, 109980},
	{"GALLEON", 7, 109981},
	{"SSRIS", 5, 109982},
	{"WINEMAKERS", 10, 109983},
	{"EXITOS", 6, 109984},
	{"TRAVAUX", 7, 109985},
	{"ERATION", 7, 109986},
	{"INMOTION", 8, 109987},
	{"RBYK", 4, 109988},
	{"MCAF", 4, 109989},
	{"LTVE", 4, 109990},
	{"LIDH", 4, 109991},
	{"KVOL", 4, 109992},
	{"GYZS", 4, 109993},
	{"EMQU", 4, 109994},
	{"BBST", 4, 109995},
	{"ALDJ", 4, 109996},
	{"TIPOS", 5, 109997},
	{"SHIBATA", 7, 109998},
	{"KETONES", 7, 109999},
	{"TRALEE", 6, 110000},
	{"PRIORS", 6, 110001},
	{"FRIBOURG", 8, 110002},
	{"MAILUTILS", 9, 110003},
	{"CHAFING", 7, 110004},
	{"ALUN", 4, 110005},
	{"RAMI", 4, 110006},
	{"SAKHALIN", 8, 110007},
	{"SBUB", 4, 110008},
	{"RKAU", 4, 110009},
	{"KSUM", 4, 110010},
	{"EPGE", 4, 110011},
	{"AMBD", 4, 110012},
	{"CIHR", 4, 110013},
	{"MOLONEY", 7, 110014},
	{"VOICEXML", 8, 110015},
	{"BIPARTITE", 9, 110016},
	{"PHYTOSANITARY", 13, 110017},
	{"AIRCRAFTS", 9, 110018},
	{"CIARAN", 6, 110019},
	{"KEITEL", 6, 110020},
	{"FCR", 3, 110021},
	{"SCID", 4, 110022},
	{"LVDS", 4, 110023},
	{"BETRAYS", 7, 110024},
	{"ULYSSE", 6, 110025},
	{"SUNROOM", 7, 110026},
	{"LANGLOIS", 8, 110027},
	{"LENG", 4, 110028},
	{"WYBODAETH", 9, 110029},
	{"SLYY", 4, 110030},
	{"NMYI", 4, 110031},
	{"LMIK", 4, 110032},
	{"KSAU", 4, 110033},
	{"FKUR", 4, 110034},
	{"DLUS", 4, 110035},
	{"BATG", 4, 110036},
	{"AEDU", 4, 110037},
	{"GREYSTONE", 9, 110038},
	{"ASSYRIA", 7, 110039},
	{"MUGEN", 5, 110040},
	{"PITTSFORD", 9, 110041},
	{"JFW", 3, 110042},
	{"INWARDS", 7, 110043},
	{"IMAGEBASE", 9, 110044},
	{"REGROUP", 7, 110045},
	{"WZD", 3, 110046},
	{"WFV", 3, 110047},
	{"UXZ", 3, 110048},
	{"MZV", 3, 110049},
	{"BENGTSSON", 9, 110050},
	{"XPEO", 4, 110051},
	{"MRPE", 4, 110052},
	{"KGOE", 4, 110053},
	{"EFRY", 4, 110054},
	{"ABBC", 4, 110055},
	{"BOFH", 4, 110056},
	{"PURDIE", 6, 110057},
	{"PHILLIPE", 8, 110058},
	{"JOANIE", 6, 110059},
	{"CORSICAN", 8, 110060},
	{"LIBERTINE", 9, 110061},
	{"PRAVACHOL", 9, 110062},
	{"DBP", 3, 110063},
	{"PACIFISM", 8, 110064},
	{"PERFORMA", 8, 110065},
	{"IMMEASURABLE", 12, 110066},
	{"WANKER", 6, 110067},
	{"FLUORIDATION", 12, 110068},
	{"YSNU", 4, 110069},
	{"VFRO", 4, 110070},
	{"UTYR", 4, 110071},
	{"UDNE", 4, 110072},
	{"UCIV", 4, 110073},
	{"TZCA", 4, 110074},
	{"PFIZ", 4, 110075},
	{"ISILO", 5, 110076},
	{"YUGI", 4, 110077},
	{"CONSOLIDATORS", 13, 110078},
	{"BEVERIDGE", 9, 110079},
	{"SCAMMED", 7, 110080},
	{"THORNBURY", 9, 110081},
	{"ESTHETIC", 8, 110082},
	{"GANESHA", 7, 110083},
	{"SOILING", 7, 110084},
	{"TESTATOR", 8, 110085},
	{"ADDARIO", 7, 110086},
	{"DISTASTE", 8, 110087},
	{"SEMICON", 7, 110088},
	{"OJOK", 4, 110089},
	{"NHYB", 4, 110090},
	{"GSIF", 4, 110091},
	{"EPHU", 4, 110092},
	{"PERISCOPE", 9, 110093},
	{"WHITCOMB", 8, 110094},
	{"MURA", 4, 110095},
	{"OFFSHOOT", 8, 110096},
	{"HUELVA", 6, 110097},
	{"RIKKU", 5, 110098},
	{"SMITHSON", 8, 110099},
	{"MELINA", 6, 110100},
	{"RESOLUTELY", 10, 110101},
	{"CELESTION", 9, 110102},
	{"FRIENDLIEST", 11, 110103},
	{"UTTERING", 8, 110104},
	{"MULTILANGUAGE", 13, 110105},
	{"JACOBUS", 7, 110106},
	{"GERMANE", 7, 110107},
	{"CHIMPS", 6, 110108},
	{"TAMR", 4, 110109},
	{"OMIF", 4, 110110},
	{"LNCO", 4, 110111},
	{"GCOI", 4, 110112},
	{"PRACTICALITIES", 14, 110113},
	{"CONSTRUE", 8, 110114},
	{"HYPERTROPHIC", 12, 110115},
	{"JABBA", 5, 110116},
	{"BEITRAG", 7, 110117},
	{"VOXEL", 5, 110118},
	{"ANDREJ", 6, 110119},
	{"ALGEMEEN", 8, 110120},
	{"NUSSBAUM", 8, 110121},
	{"DIANAPOST", 9, 110122},
	{"NSERC", 5, 110123},
	{"KAIZEN", 6, 110124},
	{"MOURNED", 7, 110125},
	{"CULPABILITY", 11, 110126},
	{"SEGREGATE", 9, 110127},
	{"LPM", 3, 110128},
	{"DESPOTISM", 9, 110129},
	{"PBYH", 4, 110130},
	{"NMBA", 4, 110131},
	{"LKAD", 4, 110132},
	{"HUGU", 4, 110133},
	{"GDOR", 4, 110134},
	{"EIDB", 4, 110135},
	{"DMCN", 4, 110136},
	{"DIKA", 4, 110137},
	{"CYAF", 4, 110138},
	{"ATKM", 4, 110139},
	{"FLOTILLA", 8, 110140},
	{"FRAGMENTARY", 11, 110141},
	{"ANJOU", 5, 110142},
	{"CSRS", 4, 110143},
	{"HEIKO", 5, 110144},
	{"STARCK", 6, 110145},
	{"PUBNS", 5, 110146},
	{"CHIPPEWAS", 9, 110147},
	{"VERTICALS", 9, 110148},
	{"MERRIL", 6, 110149},
	{"LUNCHEONS", 9, 110150},
	{"OMNISCIENT", 10, 110151},
	{"PHOTODIGITAL", 12, 110152},
	{"SBBC", 4, 110153},
	{"RUEV", 4, 110154},
	{"LTUB", 4, 110155},
	{"LBYI", 4, 110156},
	{"AMATORIALE", 10, 110157},
	{"GLADNESS", 8, 110158},
	{"FLOWCHARTS", 10, 110159},
	{"FRISKY", 6, 110160},
	{"TARZANA", 7, 110161},
	{"MISSA", 5, 110162},
	{"HOMEBACK", 8, 110163},
	{"CHAVES", 6, 110164},
	{"BESWICK", 7, 110165},
	{"FOLLADA", 7, 110166},
	{"DCEMU", 5, 110167},
	{"WOODCUT", 7, 110168},
	{"CONLON", 6, 110169},
	{"GLICKMAN", 8, 110170},
	{"BAYLINER", 8, 110171},
	{"BALLISTICS", 10, 110172},
	{"BLOWIN", 6, 110173},
	{"RAIW", 4, 110174},
	{"MRRA", 4, 110175},
	{"LMYL", 4, 110176},
	{"GPSY", 4, 110177},
	{"EYUP", 4, 110178},
	{"ABEV", 4, 110179},
	{"ECTOR", 5, 110180},
	{"GENERALITIES", 12, 110181},
	{"BATTLEGROUNDS", 13, 110182},
	{"WORKDAYS", 8, 110183},
	{"CONDOLENCE", 10, 110184},
	{"BOGLE", 5, 110185},
	{"RAMBLIN", 7, 110186},
	{"STRSTR", 6, 110187},
	{"SIDDHARTHA", 10, 110188},
	{"MISTREATED", 10, 110189},
	{"OEMC", 4, 110190},
	{"LBOL", 4, 110191},
	{"WORDWEB", 7, 110192},
	{"ULTRASHARP", 10, 110193},
	{"INVERTIBLE", 10, 110194},
	{"DBXREF", 6, 110195},
	{"BRIGHTENING", 11, 110196},
	{"VITANET", 7, 110197},
	{"INIMITABLE", 10, 110198},
	{"INEFFECTUAL", 11, 110199},
	{"OFFSHOREONLY", 12, 110200},
	{"WEBW", 4, 110201},
	{"PWEA", 4, 110202},
	{"NIJU", 4, 110203},
	{"LYEP", 4, 110204},
	{"GOSM", 4, 110205},
	{"DULR", 4, 110206},
	{"DDAC", 4, 110207},
	{"RACOON", 6, 110208},
	{"IMPOUNDED", 9, 110209},
	{"ARMORIAL", 8, 110210},
	{"CAREW", 5, 110211},
	{"BREMBO", 6, 110212},
	{"BAJAJ", 5, 110213},
	{"NKJV", 4, 110214},
	{"LACOMBE", 7, 110215},
	{"POPPA", 5, 110216},
	{"ALLBUSINESS", 11, 110217},
	{"THICKLY", 7, 110218},
	{"SELFLESSNESS", 12, 110219},
	{"BLOSSOMED", 9, 110220},
	{"CISTERN", 7, 110221},
	{"NAKHON", 6, 110222},
	{"QUADRANTS", 9, 110223},
	{"DAVES", 5, 110224},
	{"CASTA", 5, 110225},
	{"PARCO", 5, 110226},
	{"EPONYMOUS", 9, 110227},
	{"WGOI", 4, 110228},
	{"UDSL", 4, 110229},
	{"RKGE", 4, 110230},
	{"EUDS", 4, 110231},
	{"DRIM", 4, 110232},
	{"AXPL", 4, 110233},
	{"AALW", 4, 110234},
	{"TABLEAUX", 8, 110235},
	{"FIBRIN", 6, 110236},
	{"GEVALIA", 7, 110237},
	{"ONLINESHOP", 10, 110238},
	{"STEADMAN", 8, 110239},
	{"CYNLLUN", 7, 110240},
	{"TECK", 4, 110241},
	{"LATINS", 6, 110242},
	{"ADELMAN", 7, 110243},
	{"PHAETON", 7, 110244},
	{"RESTAURATEURS", 13, 110245},
	{"IRFAN", 5, 110246},
	{"FECUNDITY", 9, 110247},
	{"HIJACKER", 8, 110248},
	{"DINOS", 5, 110249},
	{"BAMAKO", 6, 110250},
	{"MALLE", 5, 110251},
	{"ESSELTE", 7, 110252},
	{"TIMESHIFT", 9, 110253},
	{"RELAXANT", 8, 110254},
	{"VPP", 3, 110255},
	{"OPLEIDING", 9, 110256},
	{"KRISTOF", 7, 110257},
	{"ZIRI", 4, 110258},
	{"PSJU", 4, 110259},
	{"KELU", 4, 110260},
	{"GYFI", 4, 110261},
	{"CKWR", 4, 110262},
	{"PURISTS", 7, 110263},
	{"NEWLANDS", 8, 110264},
	{"CALIPH", 6, 110265},
	{"SURROGATES", 10, 110266},
	{"ISSAC", 5, 110267},
	{"ANALYSERS", 9, 110268},
	{"ECMA", 4, 110269},
	{"SPEEDOS", 7, 110270},
	{"DYSENTERY", 9, 110271},
	{"ARBUCKLE", 8, 110272},
	{"GRENIER", 7, 110273},
	{"ATASCADERO", 10, 110274},
	{"FUNNELS", 7, 110275},
	{"XFUN", 4, 110276},
	{"TPUP", 4, 110277},
	{"NYEU", 4, 110278},
	{"NPMT", 4, 110279},
	{"PASTY", 5, 110280},
	{"WESTIE", 6, 110281},
	{"ABBREV", 6, 110282},
	{"CUBANA", 6, 110283},
	{"HUDDLESTON", 10, 110284},
	{"DIVESTMENT", 10, 110285},
	{"GOLDWYN", 7, 110286},
	{"VELASCO", 7, 110287},
	{"INSTONE", 7, 110288},
	{"MRQ", 3, 110289},
	{"GAGA", 4, 110290},
	{"DEBENTURE", 9, 110291},
	{"CUFFED", 6, 110292},
	{"PEAU", 4, 110293},
	{"PRINE", 5, 110294},
	{"LYDY", 4, 110295},
	{"LMYC", 4, 110296},
	{"AVAB", 4, 110297},
	{"TUMULT", 6, 110298},
	{"DEFOE", 5, 110299},
	{"UROLOGICAL", 10, 110300},
	{"SQLEXCEPTION", 12, 110301},
	{"BARSTOOL", 8, 110302},
	{"LYSOZYME", 8, 110303},
	{"ALPHANUMERICAL", 14, 110304},
	{"ANTIHISTAMINE", 13, 110305},
	{"CURATE", 6, 110306},
	{"MONONOKE", 8, 110307},
	{"PRINTINGPRINT", 13, 110308},
	{"PHOSPHODIESTERASE", 17, 110309},
	{"DONNED", 6, 110310},
	{"UNEXCUSED", 9, 110311},
	{"WILKS", 5, 110312},
	{"YUPB", 4, 110313},
	{"GREH", 4, 110314},
	{"GDPG", 4, 110315},
	{"EXTJ", 4, 110316},
	{"COBJ", 4, 110317},
	{"VIXENS", 6, 110318},
	{"SUFFIELD", 8, 110319},
	{"TARSUS", 6, 110320},
	{"ALLEGORICAL", 11, 110321},
	{"SHOJI", 5, 110322},
	{"PAVER", 5, 110323},
	{"KHOMEINI", 8, 110324},
	{"ICEWM", 5, 110325},
	{"LPP", 3, 110326},
	{"MONOTONY", 8, 110327},
	{"GAIAM", 5, 110328},
	{"DEFOMA", 6, 110329},
	{"WATCHMAKER", 10, 110330},
	{"REVE", 4, 110331},
	{"PYRIDINE", 8, 110332},
	{"TAGORE", 6, 110333},
	{"ENTRAINMENT", 11, 110334},
	{"XCHE", 4, 110335},
	{"OLOK", 4, 110336},
	{"KUTO", 4, 110337},
	{"FTAW", 4, 110338},
	{"CTSK", 4, 110339},
	{"POINCARE", 8, 110340},
	{"PIEMONTE", 8, 110341},
	{"KATADYN", 7, 110342},
	{"AZRIA", 5, 110343},
	{"OFFICEPRODUCTS", 14, 110344},
	{"VALERO", 6, 110345},
	{"RTFM", 4, 110346},
	{"ALLOGENEIC", 10, 110347},
	{"DESCRAMBLER", 11, 110348},
	{"OPENSUSE", 8, 110349},
	{"VISIONING", 9, 110350},
	{"RIBAVIRIN", 9, 110351},
	{"LEGALIZING", 10, 110352},
	{"STEAMROLLER", 11, 110353},
	{"WELLHEAD", 8, 110354},
	{"EFPI", 4, 110355},
	{"LUCILE", 6, 110356},
	{"XMIN", 4, 110357},
	{"SPILLOVERS", 10, 110358},
	{"AMAZONS", 7, 110359},
	{"MANON", 5, 110360},
	{"MINISCULE", 9, 110361},
	{"UNABATED", 8, 110362},
	{"NECCESSARY", 10, 110363},
	{"GOATLIST", 8, 110364},
	{"SHOULDA", 7, 110365},
	{"MARNI", 5, 110366},
	{"PLANTE", 6, 110367},
	{"ZILT", 4, 110368},
	{"RAMK", 4, 110369},
	{"FANP", 4, 110370},
	{"CWAL", 4, 110371},
	{"PANADOC", 7, 110372},
	{"CURZON", 6, 110373},
	{"MICROBOARDS", 11, 110374},
	{"RAYONG", 6, 110375},
	{"WOHL", 4, 110376},
	{"CANINES", 7, 110377},
	{"STROBES", 7, 110378},
	{"LINDO", 5, 110379},
	{"REMINISCE", 9, 110380},
	{"RNTU", 4, 110381},
	{"NYIR", 4, 110382},
	{"FUPS", 4, 110383},
	{"MANMOHAN", 8, 110384},
	{"BACKSTORY", 9, 110385},
	{"MARKSMAN", 8, 110386},
	{"RPP", 3, 110387},
	{"REBUILDS", 8, 110388},
	{"GFERG", 5, 110389},
	{"DANCEHIP", 8, 110390},
	{"PUBLICIZING", 11, 110391},
	{"RACKSPACE", 9, 110392},
	{"PHILOSOPHIC", 11, 110393},
	{"SCUDDER", 7, 110394},
	{"LOLI", 4, 110395},
	{"ONTRACK", 7, 110396},
	{"TSPM", 4, 110397},
	{"RADN", 4, 110398},
	{"JUAR", 4, 110399},
	{"GJIA", 4, 110400},
	{"FOCE", 4, 110401},
	{"EHRU", 4, 110402},
	{"PLETE", 5, 110403},
	{"FALLOPIAN", 9, 110404},
	{"MULCHING", 8, 110405},
	{"DIGGIN", 6, 110406},
	{"DENNA", 5, 110407},
	{"BHAKTI", 6, 110408},
	{"LIVEPERSON", 10, 110409},
	{"DOWNLINE", 8, 110410},
	{"HIBBING", 7, 110411},
	{"WESTFALEN", 9, 110412},
	{"SKYROCKET", 9, 110413},
	{"TROUBADOUR", 10, 110414},
	{"LETTS", 5, 110415},
	{"ORMJ", 4, 110416},
	{"HULM", 4, 110417},
	{"APFI", 4, 110418},
	{"VOLGENDE", 8, 110419},
	{"ONMOUSEOUT", 10, 110420},
	{"BARAKA", 6, 110421},
	{"TRUEST", 6, 110422},
	{"TERREBONNE", 10, 110423},
	{"ABBR", 4, 110424},
	{"NONREFUNDABLE", 13, 110425},
	{"RDNA", 4, 110426},
	{"ALDOSTERONE", 11, 110427},
	{"HYPNOTIZED", 10, 110428},
	{"MORGENSTERN", 11, 110429},
	{"GEOFIELDNAME", 12, 110430},
	{"PNAME", 5, 110431},
	{"SUMU", 4, 110432},
	{"MRSL", 4, 110433},
	{"KYOR", 4, 110434},
	{"IDUO", 4, 110435},
	{"VOITURES", 8, 110436},
	{"INTERNATIONALES", 15, 110437},
	{"GHOULS", 6, 110438},
	{"CARDWELL", 8, 110439},
	{"RUDENESS", 8, 110440},
	{"RAKHI", 5, 110441},
	{"THERMALS", 8, 110442},
	{"SNITCH", 6, 110443},
	{"ABORTING", 8, 110444},
	{"ZEAC", 4, 110445},
	{"UKEP", 4, 110446},
	{"PVIS", 4, 110447},
	{"MEEU", 4, 110448},
	{"KBYC", 4, 110449},
	{"GOKA", 4, 110450},
	{"GBOF", 4, 110451},
	{"BIMO", 4, 110452},
	{"KANAZAWA", 8, 110453},
	{"ALLIN", 5, 110454},
	{"MARAN", 5, 110455},
	{"NOVIA", 5, 110456},
	{"MELLENCAMP", 10, 110457},
	{"CMTE", 4, 110458},
	{"FELLED", 6, 110459},
	{"ALLEEN", 6, 110460},
	{"BAREFEET", 8, 110461},
	{"TINNED", 6, 110462},
	{"CONCOCTION", 10, 110463},
	{"POLLAK", 6, 110464},
	{"FLAY", 4, 110465},
	{"OBGYN", 5, 110466},
	{"PILSEN", 6, 110467},
	{"XERA", 4, 110468},
	{"WAUG", 4, 110469},
	{"UOWH", 4, 110470},
	{"OELD", 4, 110471},
	{"KBIR", 4, 110472},
	{"FPES", 4, 110473},
	{"EKOV", 4, 110474},
	{"CSAG", 4, 110475},
	{"BLYV", 4, 110476},
	{"BORDA", 5, 110477},
	{"SWANTON", 7, 110478},
	{"PATTER", 6, 110479},
	{"AGIOS", 5, 110480},
	{"INVESTIGACIONES", 15, 110481},
	{"CAMPFIRES", 9, 110482},
	{"COMMIE", 6, 110483},
	{"BRENTON", 7, 110484},
	{"SEINEN", 6, 110485},
	{"SUPERFAST", 9, 110486},
	{"BEANBAG", 7, 110487},
	{"RIAD", 4, 110488},
	{"BRODEUR", 7, 110489},
	{"OVALS", 5, 110490},
	{"VIDAR", 5, 110491},
	{"ALLIGATORWRESTLING", 18, 110492},
	{"IFJO", 4, 110493},
	{"HEAVYWEIGHTS", 12, 110494},
	{"RIDATA", 6, 110495},
	{"INTERCELLULAR", 13, 110496},
	{"BOOTIE", 6, 110497},
	{"TRUTHOUT", 8, 110498},
	{"CHRONICLING", 11, 110499},
	{"MOTORCYCLISTS", 13, 110500},
	{"DEVCENTER", 9, 110501},
	{"SPEEDTOUCH", 10, 110502},
	{"FLASHCARD", 9, 110503},
	{"CALEDON", 7, 110504},
	{"GSAVE", 5, 110505},
	{"ARTHRITIC", 9, 110506},
	{"ARSCH", 5, 110507},
	{"YHEY", 4, 110508},
	{"UHOP", 4, 110509},
	{"UDHI", 4, 110510},
	{"NKEX", 4, 110511},
	{"LPUM", 4, 110512},
	{"LKTA", 4, 110513},
	{"KYLO", 4, 110514},
	{"STREPTOCOCCAL", 13, 110515},
	{"SNARKY", 6, 110516},
	{"TORTOISES", 9, 110517},
	{"LIBSANE", 7, 110518},
	{"SIRF", 4, 110519},
	{"ROXANA", 6, 110520},
	{"HUMBERTO", 8, 110521},
	{"BUMMED", 6, 110522},
	{"KOFFER", 6, 110523},
	{"YYIE", 4, 110524},
	{"WANP", 4, 110525},
	{"TCWH", 4, 110526},
	{"REXR", 4, 110527},
	{"NIBB", 4, 110528},
	{"MOSB", 4, 110529},
	{"UNDIAGNOSED", 11, 110530},
	{"SWAPPABLE", 9, 110531},
	{"ASHRAF", 6, 110532},
	{"POPALTERNATIVE", 14, 110533},
	{"CRONE", 5, 110534},
	{"BYARS", 5, 110535},
	{"TWENTE", 6, 110536},
	{"SIDECAR", 7, 110537},
	{"POSSESSOR", 9, 110538},
	{"CICHLIDS", 8, 110539},
	{"LIBERA", 6, 110540},
	{"WINTRY", 6, 110541},
	{"USYI", 4, 110542},
	{"ULEG", 4, 110543},
	{"GODE", 4, 110544},
	{"OUTFLIGHT", 9, 110545},
	{"MUSICROOM", 9, 110546},
	{"ISING", 5, 110547},
	{"WPARAM", 6, 110548},
	{"STROBEL", 7, 110549},
	{"DLM", 3, 110550},
	{"VIEWINGS", 8, 110551},
	{"ANGBAND", 7, 110552},
	{"PROBIOTIC", 9, 110553},
	{"SHOREWOOD", 9, 110554},
	{"BILAYER", 7, 110555},
	{"RIZAL", 5, 110556},
	{"MARCIE", 6, 110557},
	{"ADMONISHED", 10, 110558},
	{"NARW", 4, 110559},
	{"LHUG", 4, 110560},
	{"HJAY", 4, 110561},
	{"FEDP", 4, 110562},
	{"EIFR", 4, 110563},
	{"DKON", 4, 110564},
	{"INBREEDING", 10, 110565},
	{"DATENBANK", 9, 110566},
	{"CDDB", 4, 110567},
	{"WINTERTIME", 10, 110568},
	{"SHIMLA", 6, 110569},
	{"SCHENGEN", 8, 110570},
	{"WICKEDLY", 8, 110571},
	{"KATYA", 5, 110572},
	{"ERITREAN", 8, 110573},
	{"DEPDIR", 6, 110574},
	{"REVD", 4, 110575},
	{"MOINMOIN", 8, 110576},
	{"ECKHART", 7, 110577},
	{"TICAL", 5, 110578},
	{"ULTRASTRUCTURAL", 15, 110579},
	{"WSIL", 4, 110580},
	{"WSGA", 4, 110581},
	{"WIKN", 4, 110582},
	{"SOFX", 4, 110583},
	{"SMCK", 4, 110584},
	{"SKLO", 4, 110585},
	{"PYPR", 4, 110586},
	{"NYIF", 4, 110587},
	{"HLMA", 4, 110588},
	{"ANEMIC", 6, 110589},
	{"MATTS", 5, 110590},
	{"MAXILLARY", 9, 110591},
	{"THUNK", 5, 110592},
	{"DILIP", 5, 110593},
	{"CATENIN", 7, 110594},
	{"GALLIANO", 8, 110595},
	{"STOVALL", 7, 110596},
	{"SANTORO", 7, 110597},
	{"BEALS", 5, 110598},
	{"DEFINATLY", 9, 110599},
	{"BANOS", 5, 110600},
	{"TZCO", 4, 110601},
	{"SMAV", 4, 110602},
	{"RPAM", 4, 110603},
	{"RCYS", 4, 110604},
	{"PEAV", 4, 110605},
	{"JOYL", 4, 110606},
	{"HBAK", 4, 110607},
	{"FHAY", 4, 110608},
	{"YARBROUGH", 9, 110609},
	{"TEXTING", 7, 110610},
	{"THERION", 7, 110611},
	{"ALTREC", 6, 110612},
	{"GRATUITI", 8, 110613},
	{"ARACHIDONIC", 11, 110614},
	{"LAVER", 5, 110615},
	{"DUCHAMP", 7, 110616},
	{"SHAMED", 6, 110617},
	{"INFOCOMM", 8, 110618},
	{"BUTTHEAD", 8, 110619},
	{"PETOSKEY", 8, 110620},
	{"UNICORE", 7, 110621},
	{"MANNEQUINS", 10, 110622},
	{"CARTELS", 7, 110623},
	{"GCHAR", 5, 110624},
	{"ASTROCYTES", 10, 110625},
	{"KUL", 3, 110626},
	{"ELUDED", 6, 110627},
	{"MADDUX", 6, 110628},
	{"VCAN", 4, 110629},
	{"TGAB", 4, 110630},
	{"TDWE", 4, 110631},
	{"PHDF", 4, 110632},
	{"OOBR", 4, 110633},
	{"OMBD", 4, 110634},
	{"OKUT", 4, 110635},
	{"MSOB", 4, 110636},
	{"IFWI", 4, 110637},
	{"DYOV", 4, 110638},
	{"CWON", 4, 110639},
	{"AIGC", 4, 110640},
	{"BEHEADING", 9, 110641},
	{"PEEKS", 5, 110642},
	{"BIAXIN", 6, 110643},
	{"HARNETT", 7, 110644},
	{"CARBONATES", 10, 110645},
	{"MILTER", 6, 110646},
	{"SCOTTRADE", 9, 110647},
	{"DWODP", 5, 110648},
	{"INCRIMINATING", 13, 110649},
	{"EVENTOS", 7, 110650},
	{"GASB", 4, 110651},
	{"VSCA", 4, 110652},
	{"UNVI", 4, 110653},
	{"UKUS", 4, 110654},
	{"RUMD", 4, 110655},
	{"SMALLMOUTH", 10, 110656},
	{"ENTERTAINME", 11, 110657},
	{"MANZANILLO", 10, 110658},
	{"HAIGH", 5, 110659},
	{"MARYBOROUGH", 11, 110660},
	{"ESHOP", 5, 110661},
	{"TIMESHEETS", 10, 110662},
	{"ELONGATE", 8, 110663},
	{"LOGGINS", 7, 110664},
	{"YAHTZEE", 7, 110665},
	{"NETHACK", 7, 110666},
	{"STEPPIN", 7, 110667},
	{"LANDLESS", 8, 110668},
	{"CORDERO", 7, 110669},
	{"SQUELCH", 7, 110670},
	{"UNSEALED", 8, 110671},
	{"PODIATRIC", 9, 110672},
	{"VIKS", 4, 110673},
	{"UBFI", 4, 110674},
	{"TODW", 4, 110675},
	{"THKR", 4, 110676},
	{"TGRU", 4, 110677},
	{"MEJI", 4, 110678},
	{"MBFO", 4, 110679},
	{"DNBC", 4, 110680},
	{"MISINFORMED", 11, 110681},
	{"MOONRISE", 8, 110682},
	{"BANZAI", 6, 110683},
	{"MUSKINGUM", 9, 110684},
	{"VOSONIC", 7, 110685},
	{"DUODENUM", 8, 110686},
	{"TAMBIEN", 7, 110687},
	{"STARFIGHTER", 11, 110688},
	{"VARDENAFIL", 10, 110689},
	{"SAMG", 4, 110690},
	{"KKEL", 4, 110691},
	{"ERGG", 4, 110692},
	{"CREQ", 4, 110693},
	{"APTL", 4, 110694},
	{"DUTT", 4, 110695},
	{"LUBA", 4, 110696},
	{"JOURNEYED", 9, 110697},
	{"ZDG", 3, 110698},
	{"XGD", 3, 110699},
	{"VJF", 3, 110700},
	{"LJY", 3, 110701},
	{"FQL", 3, 110702},
	{"PRESENTA", 8, 110703},
	{"BIGSOCCER", 9, 110704},
	{"TARGETTED", 9, 110705},
	{"MICHIEL", 7, 110706},
	{"HANNON", 6, 110707},
	{"HEEROMA", 7, 110708},
	{"CREEL", 5, 110709},
	{"APPETIT", 7, 110710},
	{"HOWLIN", 6, 110711},
	{"PERCUSSIVE", 10, 110712},
	{"SDKS", 4, 110713},
	{"SEASCAPES", 9, 110714},
	{"TRING", 5, 110715},
	{"GEKNEBELT", 9, 110716},
	{"ZORE", 4, 110717},
	{"PBYC", 4, 110718},
	{"MAKR", 4, 110719},
	{"LRYC", 4, 110720},
	{"LCRY", 4, 110721},
	{"KUSU", 4, 110722},
	{"GYCH", 4, 110723},
	{"CHYP", 4, 110724},
	{"AJAB", 4, 110725},
	{"DELIS", 5, 110726},
	{"COMPATIBLES", 11, 110727},
	{"MAGNIFICENTLY", 13, 110728},
	{"FOSHAN", 6, 110729},
	{"UNPUNISHED", 10, 110730},
	{"VERANO", 6, 110731},
	{"ALBATROS", 8, 110732},
	{"BLOGSITE", 8, 110733},
	{"OPHTHALMOLOGIST", 15, 110734},
	{"STATIONERS", 10, 110735},
	{"MOSSEL", 6, 110736},
	{"ISOFLAVONES", 11, 110737},
	{"APOSTASY", 8, 110738},
	{"SISTEMI", 7, 110739},
	{"ZZMU", 4, 110740},
	{"OMMS", 4, 110741},
	{"NAMV", 4, 110742},
	{"FUSR", 4, 110743},
	{"FRUT", 4, 110744},
	{"ERWY", 4, 110745},
	{"BEREFT", 6, 110746},
	{"LUCRETIA", 8, 110747},
	{"NEOOFFICE", 9, 110748},
	{"HIBERNIAN", 9, 110749},
	{"SHAWANO", 7, 110750},
	{"SEAWAY", 6, 110751},
	{"CAPITALISE", 10, 110752},
	{"VITRIOL", 7, 110753},
	{"OOFF", 4, 110754},
	{"WLCO", 4, 110755},
	{"SUPN", 4, 110756},
	{"RKOM", 4, 110757},
	{"OAGL", 4, 110758},
	{"IXFR", 4, 110759},
	{"CHATJOB", 7, 110760},
	{"HANNAN", 6, 110761},
	{"GRILLO", 6, 110762},
	{"AKIM", 4, 110763},
	{"VICARAGE", 8, 110764},
	{"LUPRON", 6, 110765},
	{"VESTRY", 6, 110766},
	{"TOSLINK", 7, 110767},
	{"SENSITIZED", 10, 110768},
	{"JEPSON", 6, 110769},
	{"LPL", 3, 110770},
	{"BLOGDEX", 7, 110771},
	{"XMAC", 4, 110772},
	{"TPMP", 4, 110773},
	{"SADW", 4, 110774},
	{"MAPF", 4, 110775},
	{"LBYL", 4, 110776},
	{"POPOV", 5, 110777},
	{"UNSUBSIDIZED", 12, 110778},
	{"BASTIEN", 7, 110779},
	{"RUMBLES", 7, 110780},
	{"RHINELANDER", 11, 110781},
	{"GNANCY", 6, 110782},
	{"ROSSVILLE", 9, 110783},
	{"LAURENTIAN", 10, 110784},
	{"HORNBLOWER", 10, 110785},
	{"HECKMAN", 7, 110786},
	{"COMPACTORS", 10, 110787},
	{"YMYT", 4, 110788},
	{"URYJ", 4, 110789},
	{"UMRI", 4, 110790},
	{"LFNE", 4, 110791},
	{"LAXO", 4, 110792},
	{"GWRE", 4, 110793},
	{"GWEV", 4, 110794},
	{"FLEP", 4, 110795},
	{"BUMN", 4, 110796},
	{"SUBOPTIMAL", 10, 110797},
	{"CORNMEAL", 8, 110798},
	{"ASCITES", 7, 110799},
	{"KANTOR", 6, 110800},
	{"EXTENSIS", 8, 110801},
	{"GLEEFULLY", 9, 110802},
	{"FEBRILE", 7, 110803},
	{"HATEBREED", 9, 110804},
	{"MERCIES", 7, 110805},
	{"TOPLEVEL", 8, 110806},
	{"PARALLELED", 10, 110807},
	{"HARTKE", 6, 110808},
	{"CASUARINA", 9, 110809},
	{"ENTWINED", 8, 110810},
	{"FABOLOUS", 8, 110811},
	{"FOSSE", 5, 110812},
	{"EMPL", 4, 110813},
	{"QUIXTAR", 7, 110814},
	{"SECUREPOINT", 11, 110815},
	{"BOLSA", 5, 110816},
	{"STRIATUM", 8, 110817},
	{"MOUNTAINTOP", 11, 110818},
	{"ILEX", 4, 110819},
	{"VDSA", 4, 110820},
	{"RNPU", 4, 110821},
	{"PIFT", 4, 110822},
	{"PHSF", 4, 110823},
	{"GOIW", 4, 110824},
	{"RICS", 4, 110825},
	{"SHEPPARTON", 10, 110826},
	{"SINTERING", 9, 110827},
	{"MANILLA", 7, 110828},
	{"INKRITE", 7, 110829},
	{"GLOBIN", 6, 110830},
	{"RUBBERBALL", 10, 110831},
	{"BILINEAR", 8, 110832},
	{"FICTIONWISE", 11, 110833},
	{"BOROVETS", 8, 110834},
	{"TAGBOARD", 8, 110835},
	{"MAXXIS", 6, 110836},
	{"BERRA", 5, 110837},
	{"TAILLE", 6, 110838},
	{"SAFETRADER", 10, 110839},
	{"MPW", 3, 110840},
	{"RESPLENDENT", 11, 110841},
	{"INSECURITIES", 12, 110842},
	{"RASMOL", 6, 110843},
	{"MORAGA", 6, 110844},
	{"ROTAVIRUS", 9, 110845},
	{"RLAV", 4, 110846},
	{"MYFL", 4, 110847},
	{"ETUD", 4, 110848},
	{"CTGU", 4, 110849},
	{"CTAK", 4, 110850},
	{"ABSF", 4, 110851},
	{"THRALL", 6, 110852},
	{"KUNDEN", 6, 110853},
	{"ILEGAL", 6, 110854},
	{"BARKED", 6, 110855},
	{"AIRFOIL", 7, 110856},
	{"ISHIDA", 6, 110857},
	{"MOBILIT", 7, 110858},
	{"KATOWICE", 8, 110859},
	{"ANTENA", 6, 110860},
	{"TROMELIN", 8, 110861},
	{"CORMAC", 6, 110862},
	{"LIGNITE", 7, 110863},
	{"YFAD", 4, 110864},
	{"UGSE", 4, 110865},
	{"IRYW", 4, 110866},
	{"GOAP", 4, 110867},
	{"EYDH", 4, 110868},
	{"DRPA", 4, 110869},
	{"COFP", 4, 110870},
	{"BINV", 4, 110871},
	{"BAGGETT", 7, 110872},
	{"OSTEOPATHS", 10, 110873},
	{"CATHIE", 6, 110874},
	{"UNUM", 4, 110875},
	{"RELAXANTS", 9, 110876},
	{"SCORNED", 7, 110877},
	{"NEWSCHANNEL", 11, 110878},
	{"CYTHEREA", 8, 110879},
	{"STULL", 5, 110880},
	{"PSYCHEDELIA", 11, 110881},
	{"FERRETTI", 8, 110882},
	{"ZAGAT", 5, 110883},
	{"RELAPSED", 8, 110884},
	{"ZACO", 4, 110885},
	{"QUIB", 4, 110886},
	{"NGZA", 4, 110887},
	{"EMOZ", 4, 110888},
	{"EGNU", 4, 110889},
	{"BFOU", 4, 110890},
	{"DECONGESTANT", 12, 110891},
	{"THICKEN", 7, 110892},
	{"ACTONEL", 7, 110893},
	{"KAZA", 4, 110894},
	{"DEFINITLY", 9, 110895},
	{"CRAIGAVON", 9, 110896},
	{"UNLEASHES", 9, 110897},
	{"RINGSIDE", 8, 110898},
	{"CORELLI", 7, 110899},
	{"CECI", 4, 110900},
	{"SELENE", 6, 110901},
	{"MOSSAD", 6, 110902},
	{"EVMS", 4, 110903},
	{"CHANDOS", 7, 110904},
	{"INNOVATING", 10, 110905},
	{"SLOF", 4, 110906},
	{"NDBH", 4, 110907},
	{"GNDO", 4, 110908},
	{"EVEZ", 4, 110909},
	{"ARTFULLY", 8, 110910},
	{"RETCODE", 7, 110911},
	{"PILGRIMAGES", 11, 110912},
	{"SHANDA", 6, 110913},
	{"HIRSCHMANN", 10, 110914},
	{"HOMEMAKERS", 10, 110915},
	{"TROTT", 5, 110916},
	{"FIDES", 5, 110917},
	{"REPAYABLE", 9, 110918},
	{"PARKSVILLE", 10, 110919},
	{"CHUR", 4, 110920},
	{"INDIC", 5, 110921},
	{"ALTACE", 6, 110922},
	{"BLAZED", 6, 110923},
	{"EBIZ", 4, 110924},
	{"EDDA", 4, 110925},
	{"CUPPED", 6, 110926},
	{"NATED", 5, 110927},
	{"BARACK", 6, 110928},
	{"NIEDERSACHSEN", 13, 110929},
	{"ENCONTRAR", 9, 110930},
	{"BLOGROLLING", 11, 110931},
	{"WHEELBARROW", 11, 110932},
	{"ROSNER", 6, 110933},
	{"MAIMED", 6, 110934},
	{"WVIC", 4, 110935},
	{"WVAR", 4, 110936},
	{"SSYB", 4, 110937},
	{"JIKI", 4, 110938},
	{"HRDC", 4, 110939},
	{"MINIMIS", 7, 110940},
	{"ZENER", 5, 110941},
	{"YZF", 3, 110942},
	{"DAGGETT", 7, 110943},
	{"MORPHED", 7, 110944},
	{"LOWA", 4, 110945},
	{"FOTZEN", 6, 110946},
	{"NIKOLAY", 7, 110947},
	{"CHOR", 4, 110948},
	{"REORGANIZING", 12, 110949},
	{"SPIL", 4, 110950},
	{"TUNW", 4, 110951},
	{"LREW", 4, 110952},
	{"IXBO", 4, 110953},
	{"GTHM", 4, 110954},
	{"AYJE", 4, 110955},
	{"DERNIER", 7, 110956},
	{"NGAY", 4, 110957},
	{"DUDA", 4, 110958},
	{"SHTML", 5, 110959},
	{"ROOTKITS", 8, 110960},
	{"SILVICULTURE", 12, 110961},
	{"EMBRAER", 7, 110962},
	{"PATER", 5, 110963},
	{"INGROUND", 8, 110964},
	{"INTERGROUP", 10, 110965},
	{"ACCION", 6, 110966},
	{"MARINARA", 8, 110967},
	{"CRICSHOP", 8, 110968},
	{"SEARCHPART", 10, 110969},
	{"FURNITURES", 10, 110970},
	{"HEFFERNAN", 9, 110971},
	{"FLEISHMAN", 9, 110972},
	{"MUSED", 5, 110973},
	{"JAMAIS", 6, 110974},
	{"POLLUTERS", 9, 110975},
	{"SGAP", 4, 110976},
	{"RMEY", 4, 110977},
	{"NUSG", 4, 110978},
	{"LOTG", 4, 110979},
	{"ILHU", 4, 110980},
	{"IGSM", 4, 110981},
	{"HDFR", 4, 110982},
	{"DZOO", 4, 110983},
	{"CZYN", 4, 110984},
	{"CENTIPEDE", 9, 110985},
	{"TURBOLINUX", 10, 110986},
	{"PETREL", 6, 110987},
	{"CALLIOPE", 8, 110988},
	{"MILEPOST", 8, 110989},
	{"BOOMTOWN", 8, 110990},
	{"PUFFING", 7, 110991},
	{"SYSTEMWIDE", 10, 110992},
	{"FIREPAY", 7, 110993},
	{"STATESBORO", 10, 110994},
	{"BESTEN", 6, 110995},
	{"MUTAGENIC", 9, 110996},
	{"SHAYS", 5, 110997},
	{"WIELDED", 7, 110998},
	{"FORMALIN", 8, 110999},
	{"LONGLEY", 7, 111000},
	{"SAVANA", 6, 111001},
	{"FUTURITY", 8, 111002},
	{"KHAY", 4, 111003},
	{"HYGE", 4, 111004},
	{"DYJU", 4, 111005},
	{"DIFM", 4, 111006},
	{"ARZI", 4, 111007},
	{"TRAVELBLOG", 10, 111008},
	{"JEWERLY", 7, 111009},
	{"LBNL", 4, 111010},
	{"BUHL", 4, 111011},
	{"GENESYS", 7, 111012},
	{"MARCA", 5, 111013},
	{"LAVAGE", 6, 111014},
	{"EVERHART", 8, 111015},
	{"CASTORS", 7, 111016},
	{"LOPSIDED", 8, 111017},
	{"PNEL", 4, 111018},
	{"NUMO", 4, 111019},
	{"MPAK", 4, 111020},
	{"CHAWENG", 7, 111021},
	{"FLIPPERS", 8, 111022},
	{"JOSEP", 5, 111023},
	{"BLANCHETT", 9, 111024},
	{"NONMEMBERS", 10, 111025},
	{"ACCESSO", 7, 111026},
	{"GWASANAETH", 10, 111027},
	{"TIBOR", 5, 111028},
	{"ETOMITE", 7, 111029},
	{"QUICKSAND", 9, 111030},
	{"SHEATHING", 9, 111031},
	{"SCHENK", 6, 111032},
	{"JOBSEMPLOYMENT", 14, 111033},
	{"ENRICHES", 8, 111034},
	{"LAWRIE", 6, 111035},
	{"HYMNAL", 6, 111036},
	{"YPUM", 4, 111037},
	{"PANJ", 4, 111038},
	{"MEHM", 4, 111039},
	{"EFSB", 4, 111040},
	{"DIVU", 4, 111041},
	{"FINIALS", 7, 111042},
	{"MASTURBATORS", 12, 111043},
	{"GANDY", 5, 111044},
	{"CHLORELLA", 9, 111045},
	{"TRESTLE", 7, 111046},
	{"MIXMASTER", 9, 111047},
	{"OBAGI", 5, 111048},
	{"CORENUCLEOTIDE", 14, 111049},
	{"LYVU", 4, 111050},
	{"JOEJ", 4, 111051},
	{"INWY", 4, 111052},
	{"DHOF", 4, 111053},
	{"CCTO", 4, 111054},
	{"PROBABLES", 9, 111055},
	{"FUNAI", 5, 111056},
	{"NEOPHYTE", 8, 111057},
	{"EGMONT", 6, 111058},
	{"MILLIONTH", 9, 111059},
	{"TRANSPONDERS", 12, 111060},
	{"RAPPAHANNOCK", 12, 111061},
	{"YMIE", 4, 111062},
	{"UNTJ", 4, 111063},
	{"GOIR", 4, 111064},
	{"ETLU", 4, 111065},
	{"EMOY", 4, 111066},
	{"ANGELI", 6, 111067},
	{"HOUSEMATES", 10, 111068},
	{"SKANK", 5, 111069},
	{"SOUFFLE", 7, 111070},
	{"CAPLIO", 6, 111071},
	{"KHATAMI", 7, 111072},
	{"GREENPOINT", 10, 111073},
	{"REBUS", 5, 111074},
	{"PHILLIPSBURG", 12, 111075},
	{"MEGHALAYA", 9, 111076},
	{"PARAPROFESSIONAL", 16, 111077},
	{"HOWLETT", 7, 111078},
	{"PROCES", 6, 111079},
	{"NKCL", 4, 111080},
	{"IRKP", 4, 111081},
	{"EFWE", 4, 111082},
	{"BUYN", 4, 111083},
	{"SPIKING", 7, 111084},
	{"GOLDTONE", 8, 111085},
	{"AXONAL", 6, 111086},
	{"FIBA", 4, 111087},
	{"SENTINELS", 9, 111088},
	{"BLEPHAROPLASTY", 14, 111089},
	{"VINYLS", 6, 111090},
	{"RCPT", 4, 111091},
	{"EROTICAS", 8, 111092},
	{"TRAVERTINE", 10, 111093},
	{"MINDSAY", 7, 111094},
	{"PARDONED", 8, 111095},
	{"WORMWOOD", 8, 111096},
	{"MULLING", 7, 111097},
	{"BUSTAMANTE", 10, 111098},
	{"FORMFIELD", 9, 111099},
	{"WINDOWING", 9, 111100},
	{"IFELSE", 6, 111101},
	{"XPAC", 4, 111102},
	{"VIDV", 4, 111103},
	{"UKWH", 4, 111104},
	{"OSDR", 4, 111105},
	{"MMIR", 4, 111106},
	{"MILB", 4, 111107},
	{"IFIF", 4, 111108},
	{"FPAD", 4, 111109},
	{"FKOS", 4, 111110},
	{"EKUS", 4, 111111},
	{"DONQ", 4, 111112},
	{"SIGHING", 7, 111113},
	{"REPELLANT", 9, 111114},
	{"CAJA", 4, 111115},
	{"NCNUM", 5, 111116},
	{"HARZ", 4, 111117},
	{"AWED", 4, 111118},
	{"PERGOLA", 7, 111119},
	{"SHRANK", 6, 111120},
	{"OILSEEDS", 8, 111121},
	{"ELABORATING", 11, 111122},
	{"REDWALL", 7, 111123},
	{"CHUO", 4, 111124},
	{"WALLACH", 7, 111125},
	{"SIPP", 4, 111126},
	{"PERPIGNAN", 9, 111127},
	{"CUPPING", 7, 111128},
	{"SLIPCOVER", 9, 111129},
	{"CONCEALS", 8, 111130},
	{"YONU", 4, 111131},
	{"LAIK", 4, 111132},
	{"IMOP", 4, 111133},
	{"CGLO", 4, 111134},
	{"DYSGU", 5, 111135},
	{"BRAINSTEM", 9, 111136},
	{"OGDENSBURG", 10, 111137},
	{"WALLINGTON", 10, 111138},
	{"SATANISM", 8, 111139},
	{"XINETD", 6, 111140},
	{"PINEAL", 6, 111141},
	{"GARBO", 5, 111142},
	{"HUSB", 4, 111143},
	{"SUOMEKSI", 8, 111144},
	{"LUGER", 5, 111145},
	{"XINF", 4, 111146},
	{"OLQU", 4, 111147},
	{"NOVG", 4, 111148},
	{"GIFA", 4, 111149},
	{"ATTORNEYPAGES", 13, 111150},
	{"GLYCERINE", 9, 111151},
	{"NUNES", 5, 111152},
	{"FRANKFORD", 9, 111153},
	{"PRIETO", 6, 111154},
	{"MYRICK", 6, 111155},
	{"RECEIVERSHIP", 12, 111156},
	{"NATIONALISTIC", 13, 111157},
	{"WYCKOFF", 7, 111158},
	{"TOYLAND", 7, 111159},
	{"STEINWAY", 8, 111160},
	{"REDMUZE", 7, 111161},
	{"PERSONNAL", 9, 111162},
	{"PPEW", 4, 111163},
	{"AGMI", 4, 111164},
	{"STAUB", 5, 111165},
	{"ROHIT", 5, 111166},
	{"CARDIOVASC", 10, 111167},
	{"MILLIPORE", 9, 111168},
	{"EARACHE", 7, 111169},
	{"PADME", 5, 111170},
	{"CIMETIDINE", 10, 111171},
	{"BILLFOLD", 8, 111172},
	{"ABOLITIONIST", 12, 111173},
	{"FOAMY", 5, 111174},
	{"PILIPINAS", 9, 111175},
	{"BLACKTOWN", 9, 111176},
	{"BUDGIE", 6, 111177},
	{"AVENTURE", 8, 111178},
	{"AKTIEN", 6, 111179},
	{"SAARLAND", 8, 111180},
	{"MEUNIER", 7, 111181},
	{"SHAGGING", 8, 111182},
	{"YRHY", 4, 111183},
	{"OZZA", 4, 111184},
	{"OMYU", 4, 111185},
	{"CUEI", 4, 111186},
	{"BMOV", 4, 111187},
	{"MILLTOWN", 8, 111188},
	{"UPPING", 6, 111189},
	{"ONSTAR", 6, 111190},
	{"UNPAINTED", 9, 111191},
	{"KNOLLS", 6, 111192},
	{"GRANBURY", 8, 111193},
	{"RINGWORM", 8, 111194},
	{"IONIZER", 7, 111195},
	{"UNWELL", 6, 111196},
	{"HEALTHSOUTH", 11, 111197},
	{"POTTSTOWN", 9, 111198},
	{"LYRIK", 5, 111199},
	{"ISOTHERMAL", 10, 111200},
	{"CLBRDRL", 7, 111201},
	{"ASUKA", 5, 111202},
	{"UNCONSCIONABLE", 14, 111203},
	{"WEDGED", 6, 111204},
	{"YAMAZAKI", 8, 111205},
	{"KERMAN", 6, 111206},
	{"OUTGROWN", 8, 111207},
	{"RAFAH", 5, 111208},
	{"MARRAKESH", 9, 111209},
	{"INTERLINGUA", 11, 111210},
	{"THROWDOWN", 9, 111211},
	{"GEILES", 6, 111212},
	{"UBAW", 4, 111213},
	{"RMRI", 4, 111214},
	{"OBYR", 4, 111215},
	{"NYEW", 4, 111216},
	{"LPMO", 4, 111217},
	{"KSCI", 4, 111218},
	{"EVADING", 7, 111219},
	{"COMMEMORATED", 12, 111220},
	{"WIKITOOLNAME", 12, 111221},
	{"LURID", 5, 111222},
	{"ANNUNCIATION", 12, 111223},
	{"HONOREES", 8, 111224},
	{"DARDS", 5, 111225},
	{"FFEE", 4, 111226},
	{"HERM", 4, 111227},
	{"BEAMLINE", 8, 111228},
	{"RUMOURED", 8, 111229},
	{"SIOUXSIE", 8, 111230},
	{"URUL", 4, 111231},
	{"OVMA", 4, 111232},
	{"GTIL", 4, 111233},
	{"DDNE", 4, 111234},
	{"BEUT", 4, 111235},
	{"UNDEMOCRATIC", 12, 111236},
	{"DISPENSARY", 10, 111237},
	{"BOONDOCKS", 9, 111238},
	{"LUNT", 4, 111239},
	{"FUTURISM", 8, 111240},
	{"OMFG", 4, 111241},
	{"NEPHI", 5, 111242},
	{"ABANDONWARE", 11, 111243},
	{"CLTXLRTB", 8, 111244},
	{"MURDERDOLLS", 11, 111245},
	{"CONFUCIANISM", 12, 111246},
	{"COALESCE", 8, 111247},
	{"OLAV", 4, 111248},
	{"DELTAS", 6, 111249},
	{"GISELE", 6, 111250},
	{"CANTABRIA", 9, 111251},
	{"SKYWARN", 7, 111252},
	{"YLLT", 4, 111253},
	{"TMYI", 4, 111254},
	{"LTLO", 4, 111255},
	{"FITY", 4, 111256},
	{"EMTV", 4, 111257},
	{"BSSP", 4, 111258},
	{"PAMPA", 5, 111259},
	{"ORKUT", 5, 111260},
	{"WINGFIELD", 9, 111261},
	{"GEQUAELT", 8, 111262},
	{"FUTSAL", 6, 111263},
	{"BROUGHAM", 8, 111264},
	{"ANTAL", 5, 111265},
	{"MAUMEE", 6, 111266},
	{"SYSTE", 5, 111267},
	{"GWNEUD", 6, 111268},
	{"BENET", 5, 111269},
	{"BOHEME", 6, 111270},
	{"STRIPER", 7, 111271},
	{"CREDENTIALED", 12, 111272},
	{"FRUITING", 8, 111273},
	{"WLTO", 4, 111274},
	{"UBAH", 4, 111275},
	{"TPRU", 4, 111276},
	{"RSHF", 4, 111277},
	{"RLCA", 4, 111278},
	{"DDYM", 4, 111279},
	{"REDFISH", 7, 111280},
	{"ROSKILDE", 8, 111281},
	{"PRODOM", 6, 111282},
	{"HERCEGOVINA", 11, 111283},
	{"WINDINGS", 8, 111284},
	{"STRONGHOLDS", 11, 111285},
	{"CLUDING", 7, 111286},
	{"CUBISM", 6, 111287},
	{"HOTELE", 6, 111288},
	{"QUECHUA", 7, 111289},
	{"MADURA", 6, 111290},
	{"GAMESEEK", 8, 111291},
	{"BURGLARS", 8, 111292},
	{"MULLS", 5, 111293},
	{"MOLLUSCS", 8, 111294},
	{"NUMN", 4, 111295},
	{"IKUN", 4, 111296},
	{"GOVC", 4, 111297},
	{"EJOL", 4, 111298},
	{"CBEV", 4, 111299},
	{"INDUCTIVELY", 11, 111300},
	{"FAQTS", 5, 111301},
	{"ANATOLIAN", 9, 111302},
	{"TUKWILA", 7, 111303},
	{"MACC", 4, 111304},
	{"BIOTECHNOL", 10, 111305},
	{"ANELLI", 6, 111306},
	{"SARCOIDOSIS", 11, 111307},
	{"GRICE", 5, 111308},
	{"CASTLEBAR", 9, 111309},
	{"PECTORIS", 8, 111310},
	{"SHRIMPS", 7, 111311},
	{"VACHERON", 8, 111312},
	{"STOCKBROKER", 11, 111313},
	{"ROCHFORD", 8, 111314},
	{"CRAWFORDSVILLE", 14, 111315},
	{"DOWLAND", 7, 111316},
	{"SJSU", 4, 111317},
	{"UPPS", 4, 111318},
	{"PTPE", 4, 111319},
	{"ORXI", 4, 111320},
	{"OOPM", 4, 111321},
	{"OLJO", 4, 111322},
	{"HMOL", 4, 111323},
	{"SEATPOSTS", 9, 111324},
	{"MURDERBALL", 10, 111325},
	{"XMM", 3, 111326},
	{"CULLMANN", 8, 111327},
	{"ABACO", 5, 111328},
	{"CLBRDRB", 7, 111329},
	{"IMMUNOREACTIVITY", 16, 111330},
	{"SHAWSHANK", 9, 111331},
	{"STIRRUP", 7, 111332},
	{"HECKER", 6, 111333},
	{"VIATICAL", 8, 111334},
	{"DIMAGGIO", 8, 111335},
	{"IGBO", 4, 111336},
	{"SERIA", 5, 111337},
	{"TTYL", 4, 111338},
	{"WCAST", 5, 111339},
	{"CREO", 4, 111340},
	{"POTEN", 5, 111341},
	{"PHOTOSEARCH", 11, 111342},
	{"MISAPPROPRIATION", 16, 111343},
	{"SHIPPENSBURG", 12, 111344},
	{"ATTENDANCES", 11, 111345},
	{"PHOTOGRAMMETRY", 14, 111346},
	{"WABU", 4, 111347},
	{"PUTV", 4, 111348},
	{"LROG", 4, 111349},
	{"IYAK", 4, 111350},
	{"HABD", 4, 111351},
	{"WAVS", 4, 111352},
	{"DICTIONNAIRE", 12, 111353},
	{"SCRUBBERS", 9, 111354},
	{"FINDE", 5, 111355},
	{"ARENDT", 6, 111356},
	{"FLOPPED", 7, 111357},
	{"FOCKERS", 7, 111358},
	{"BREASTFEED", 10, 111359},
	{"SUBTEXT", 7, 111360},
	{"OURAY", 5, 111361},
	{"SAMMENLIGN", 10, 111362},
	{"GHOSTFACE", 9, 111363},
	{"SOLAS", 5, 111364},
	{"CONTAXG", 7, 111365},
	{"WOCU", 4, 111366},
	{"WEWH", 4, 111367},
	{"RPLI", 4, 111368},
	{"POUC", 4, 111369},
	{"LOOTERS", 7, 111370},
	{"ELBE", 4, 111371},
	{"SMITTY", 6, 111372},
	{"WHITEWASH", 9, 111373},
	{"STORYTALKBACK", 13, 111374},
	{"NTLM", 4, 111375},
	{"SQUEEZES", 8, 111376},
	{"SUBSERVIENT", 11, 111377},
	{"NARC", 4, 111378},
	{"AUDIOLOGISTS", 12, 111379},
	{"STUFFER", 7, 111380},
	{"SUIVANTE", 8, 111381},
	{"BRASSWIND", 9, 111382},
	{"SINGULAIR", 9, 111383},
	{"FREITAS", 7, 111384},
	{"MUSASHI", 7, 111385},
	{"LYRICALLY", 9, 111386},
	{"WNOB", 4, 111387},
	{"TMAM", 4, 111388},
	{"OWDF", 4, 111389},
	{"NKOM", 4, 111390},
	{"LYHY", 4, 111391},
	{"EBWH", 4, 111392},
	{"SKILLZ", 6, 111393},
	{"STUBBORNLY", 10, 111394},
	{"BUCKAROO", 8, 111395},
	{"AEROPORTO", 9, 111396},
	{"GLUCAN", 6, 111397},
	{"ADOPTEES", 8, 111398},
	{"NORSEMAN", 8, 111399},
	{"KOLLER", 6, 111400},
	{"HALSTED", 7, 111401},
	{"SPEARFISH", 9, 111402},
	{"HANSGROHE", 9, 111403},
	{"DOTSON", 6, 111404},
	{"TRAITEMENT", 10, 111405},
	{"ZVR", 3, 111406},
	{"ZGW", 3, 111407},
	{"RXQ", 3, 111408},
	{"MQR", 3, 111409},
	{"KZF", 3, 111410},
	{"FVK", 3, 111411},
	{"HENRIKSEN", 9, 111412},
	{"BENEDICTION", 11, 111413},
	{"FRESHLOOK", 9, 111414},
	{"CURLEW", 6, 111415},
	{"PEQUOT", 6, 111416},
	{"DISOBEDIENT", 11, 111417},
	{"RCEY", 4, 111418},
	{"PKIL", 4, 111419},
	{"MNOB", 4, 111420},
	{"LCAF", 4, 111421},
	{"IDSV", 4, 111422},
	{"HTYM", 4, 111423},
	{"GGSC", 4, 111424},
	{"AMRY", 4, 111425},
	{"MINNOWS", 7, 111426},
	{"SEAMSTRESS", 10, 111427},
	{"GIARDIA", 7, 111428},
	{"CARDENAS", 8, 111429},
	{"LILLIPUT", 8, 111430},
	{"ABCE", 4, 111431},
	{"SALSAS", 6, 111432},
	{"COFFRET", 7, 111433},
	{"RELATEDNESS", 11, 111434},
	{"LEGIONELLA", 10, 111435},
	{"IMMORTALS", 9, 111436},
	{"TRANSFERABILITY", 15, 111437},
	{"PINWHEEL", 8, 111438},
	{"CLBRDRT", 7, 111439},
	{"ISAPI", 5, 111440},
	{"WEDV", 4, 111441},
	{"VULS", 4, 111442},
	{"UEQU", 4, 111443},
	{"RPSM", 4, 111444},
	{"RJOK", 4, 111445},
	{"RBEV", 4, 111446},
	{"ORUK", 4, 111447},
	{"WHINY", 5, 111448},
	{"SPDIF", 5, 111449},
	{"THALER", 6, 111450},
	{"EURIPIDES", 9, 111451},
	{"NISSEN", 6, 111452},
	{"LITHGOW", 7, 111453},
	{"UNINITIATED", 11, 111454},
	{"GRESTORE", 8, 111455},
	{"BROADWATER", 10, 111456},
	{"DONRUSS", 7, 111457},
	{"LALO", 4, 111458},
	{"ELLIPSES", 8, 111459},
	{"BLUFFING", 8, 111460},
	{"MIKKO", 5, 111461},
	{"EVENTING", 8, 111462},
	{"WOOLDRIDGE", 10, 111463},
	{"SPECO", 5, 111464},
	{"MOND", 4, 111465},
	{"INSTRU", 6, 111466},
	{"RUCK", 4, 111467},
	{"SCHOTTKY", 8, 111468},
	{"ULAV", 4, 111469},
	{"PIFI", 4, 111470},
	{"PASQ", 4, 111471},
	{"OLKH", 4, 111472},
	{"MLAD", 4, 111473},
	{"FDUS", 4, 111474},
	{"ZWART", 5, 111475},
	{"GAMETRACKER", 11, 111476},
	{"BRISKLY", 7, 111477},
	{"BRUNI", 5, 111478},
	{"AFFLICTIONS", 11, 111479},
	{"GMM", 3, 111480},
	{"TECHNOWORLD", 11, 111481},
	{"BUON", 4, 111482},
	{"HUMORAL", 7, 111483},
	{"FARWELL", 7, 111484},
	{"PROSTAR", 7, 111485},
	{"MAFF", 4, 111486},
	{"RESUMEN", 7, 111487},
	{"YELD", 4, 111488},
	{"VSPE", 4, 111489},
	{"UKCO", 4, 111490},
	{"MADG", 4, 111491},
	{"LIUB", 4, 111492},
	{"LAFU", 4, 111493},
	{"GUAS", 4, 111494},
	{"EPRC", 4, 111495},
	{"DMPH", 4, 111496},
	{"KHARKOV", 7, 111497},
	{"WIZKIDS", 7, 111498},
	{"HUFFY", 5, 111499},
	{"DRAGO", 5, 111500},
	{"WOODWORKER", 10, 111501},
	{"TWIKIADMINGROUP", 15, 111502},
	{"SNAZZY", 6, 111503},
	{"PMACHINE", 8, 111504},
	{"PACQUIAO", 8, 111505},
	{"WEARINESS", 9, 111506},
	{"COVARIANT", 9, 111507},
	{"VARNEY", 6, 111508},
	{"MURROW", 6, 111509},
	{"JAHSHAKA", 8, 111510},
	{"PUBLICAT", 8, 111511},
	{"MSQL", 4, 111512},
	{"CLBRDRR", 7, 111513},
	{"XLER", 4, 111514},
	{"OHUD", 4, 111515},
	{"NDZH", 4, 111516},
	{"MYAM", 4, 111517},
	{"IKOF", 4, 111518},
	{"BMAS", 4, 111519},
	{"QUBIT", 5, 111520},
	{"LAEVIS", 6, 111521},
	{"CORTONA", 7, 111522},
	{"SUBPLOT", 7, 111523},
	{"ASCENDANCY", 10, 111524},
	{"SEPHIROTH", 9, 111525},
	{"STFU", 4, 111526},
	{"REALE", 5, 111527},
	{"DENGURU", 7, 111528},
	{"PREKINDERGARTEN", 15, 111529},
	{"INGROWN", 7, 111530},
	{"UINM", 4, 111531},
	{"QARE", 4, 111532},
	{"MYSK", 4, 111533},
	{"HEWG", 4, 111534},
	{"GOVP", 4, 111535},
	{"EUBA", 4, 111536},
	{"SCRIVI", 6, 111537},
	{"SANUR", 5, 111538},
	{"BOWKER", 6, 111539},
	{"CURTAILMENT", 11, 111540},
	{"BLIGH", 5, 111541},
	{"HUSKER", 6, 111542},
	{"LAMIVUDINE", 10, 111543},
	{"ARTHROPLASTY", 12, 111544},
	{"KUCHING", 7, 111545},
	{"SWITCHOVER", 10, 111546},
	{"BESTS", 5, 111547},
	{"ACRO", 4, 111548},
	{"DOBB", 4, 111549},
	{"NANTWICH", 8, 111550},
	{"AFFRONT", 7, 111551},
	{"CUOMO", 5, 111552},
	{"WKSS", 4, 111553},
	{"RRAZ", 4, 111554},
	{"IMKN", 4, 111555},
	{"COWD", 4, 111556},
	{"MEMORIZATION", 12, 111557},
	{"SPECTROPHOTOMETRY", 17, 111558},
	{"BAILEYS", 7, 111559},
	{"BLINDSIDE", 9, 111560},
	{"OUTTURN", 7, 111561},
	{"MATRA", 5, 111562},
	{"BUILDROOT", 9, 111563},
	{"SPEARMINT", 9, 111564},
	{"INARI", 5, 111565},
	{"FERPA", 5, 111566},
	{"TATOOS", 6, 111567},
	{"TELEPHONED", 10, 111568},
	{"KISHORE", 7, 111569},
	{"MBB", 3, 111570},
	{"NABIL", 5, 111571},
	{"TREASURIES", 10, 111572},
	{"ULKS", 4, 111573},
	{"NPLY", 4, 111574},
	{"LEZI", 4, 111575},
	{"FEBL", 4, 111576},
	{"DDSH", 4, 111577},
	{"BCSB", 4, 111578},
	{"BAGP", 4, 111579},
	{"AYOW", 4, 111580},
	{"AUDW", 4, 111581},
	{"ENERGETICALLY", 13, 111582},
	{"CHATBOX", 7, 111583},
	{"DJEMBE", 6, 111584},
	{"TINGE", 5, 111585},
	{"KIRILL", 6, 111586},
	{"RIDGELAND", 9, 111587},
	{"VINING", 6, 111588},
	{"FINGAL", 6, 111589},
	{"RIPSTOP", 7, 111590},
	{"SCUFF", 5, 111591},
	{"AIRSPEED", 8, 111592},
	{"MOGULS", 6, 111593},
	{"DEFECTION", 9, 111594},
	{"PDIF", 4, 111595},
	{"LONGABERGER", 11, 111596},
	{"DOGGETT", 7, 111597},
	{"MURMURS", 7, 111598},
	{"SLOG", 4, 111599},
	{"OAKRIDGE", 8, 111600},
	{"MOVL", 4, 111601},
	{"DISPERSING", 10, 111602},
	{"QUIPS", 5, 111603},
	{"VODE", 4, 111604},
	{"TDOV", 4, 111605},
	{"KKID", 4, 111606},
	{"ACWO", 4, 111607},
	{"GRIMSHAW", 8, 111608},
	{"PARTUM", 6, 111609},
	{"TRACTABLE", 9, 111610},
	{"COOLANGATTA", 11, 111611},
	{"RANDOMIZER", 10, 111612},
	{"CRESPO", 6, 111613},
	{"GLEANER", 7, 111614},
	{"ELECTROPHYSIOLOGICAL", 20, 111615},
	{"FRICKIN", 7, 111616},
	{"ARACHNE", 7, 111617},
	{"HELPFULL", 8, 111618},
	{"BURI", 4, 111619},
	{"ZINK", 4, 111620},
	{"LAPPED", 6, 111621},
	{"CORLEY", 6, 111622},
	{"LECOULTRE", 9, 111623},
	{"AZITHROMYCIN", 12, 111624},
	{"XTRU", 4, 111625},
	{"XLAN", 4, 111626},
	{"WAFR", 4, 111627},
	{"VIKR", 4, 111628},
	{"MRKA", 4, 111629},
	{"KYPA", 4, 111630},
	{"ENLC", 4, 111631},
	{"CPOT", 4, 111632},
	{"BACKMED", 7, 111633},
	{"RHEL", 4, 111634},
	{"ERYTHROPOIETIN", 14, 111635},
	{"NECESSITATING", 13, 111636},
	{"NORMALCY", 8, 111637},
	{"RONSON", 6, 111638},
	{"INFOTAINMENT", 12, 111639},
	{"PECS", 4, 111640},
	{"GOODSON", 7, 111641},
	{"COHASSET", 8, 111642},
	{"BANDANAS", 8, 111643},
	{"SITION", 6, 111644},
	{"FLORIS", 6, 111645},
	{"ZORS", 4, 111646},
	{"OVAM", 4, 111647},
	{"JOAC", 4, 111648},
	{"BAIW", 4, 111649},
	{"OSAMU", 5, 111650},
	{"BACKWASH", 8, 111651},
	{"SOUTHINGTON", 11, 111652},
	{"FERNANDINA", 10, 111653},
	{"MUZIEK", 6, 111654},
	{"GUNNA", 5, 111655},
	{"RIDINGS", 7, 111656},
	{"PETITIONING", 11, 111657},
	{"ENABLEMENT", 10, 111658},
	{"CLAWED", 6, 111659},
	{"ANOUK", 5, 111660},
	{"NMSU", 4, 111661},
	{"CONTACTOR", 9, 111662},
	{"WECL", 4, 111663},
	{"HIPJ", 4, 111664},
	{"DGHO", 4, 111665},
	{"DAQC", 4, 111666},
	{"AYMR", 4, 111667},
	{"GYROSCOPE", 9, 111668},
	{"PAWLEYS", 7, 111669},
	{"HAPTER", 6, 111670},
	{"COOSA", 5, 111671},
	{"CHOKERS", 7, 111672},
	{"RUNTERLADEN", 11, 111673},
	{"MANAUS", 6, 111674},
	{"DEMEANING", 9, 111675},
	{"NIFEDIPINE", 10, 111676},
	{"BEREICH", 7, 111677},
	{"RREE", 4, 111678},
	{"PORTRAYALS", 10, 111679},
	{"FOLLADAS", 8, 111680},
	{"WARZONE", 7, 111681},
	{"SHARMAN", 7, 111682},
	{"DISORIENTATION", 14, 111683},
	{"SKMS", 4, 111684},
	{"SDOZ", 4, 111685},
	{"OGUT", 4, 111686},
	{"LOSK", 4, 111687},
	{"LIMH", 4, 111688},
	{"KHAK", 4, 111689},
	{"GITG", 4, 111690},
	{"NORMALE", 7, 111691},
	{"CASTLEGAR", 9, 111692},
	{"KAROLINSKA", 10, 111693},
	{"MURKOWSKI", 9, 111694},
	{"NABBED", 6, 111695},
	{"WELTON", 6, 111696},
	{"SHOPFOR", 7, 111697},
	{"MESSAGGIO", 9, 111698},
	{"EINMAL", 6, 111699},
	{"BERCHTESGADEN", 13, 111700},
	{"SMARTE", 6, 111701},
	{"TANAGER", 7, 111702},
	{"UNIONDALE", 9, 111703},
	{"AVIRA", 5, 111704},
	{"ROTHKO", 6, 111705},
	{"WINSOME", 7, 111706},
	{"TELECOMM", 8, 111707},
	{"CAPSID", 6, 111708},
	{"MORTGAGOR", 9, 111709},
	{"PRESUMING", 9, 111710},
	{"PULMONOLOGY", 11, 111711},
	{"BORGER", 6, 111712},
	{"YKRI", 4, 111713},
	{"YBIB", 4, 111714},
	{"SRAJ", 4, 111715},
	{"PIDB", 4, 111716},
	{"NDMT", 4, 111717},
	{"MAJG", 4, 111718},
	{"LDD", 3, 111719},
	{"ENGLISHMEN", 10, 111720},
	{"BANSHEES", 8, 111721},
	{"NHLBI", 5, 111722},
	{"MULDOON", 7, 111723},
	{"STOOPID", 7, 111724},
	{"DVDRECORDER", 11, 111725},
	{"EQUALED", 7, 111726},
	{"AIRSTRIKE", 9, 111727},
	{"WAVEGUIDES", 10, 111728},
	{"GASSES", 6, 111729},
	{"CASTELLI", 8, 111730},
	{"UBEO", 4, 111731},
	{"RILG", 4, 111732},
	{"OIJU", 4, 111733},
	{"IMPH", 4, 111734},
	{"GOVB", 4, 111735},
	{"GAYT", 4, 111736},
	{"FFKE", 4, 111737},
	{"WORMHOLE", 8, 111738},
	{"POWE", 4, 111739},
	{"FLOG", 4, 111740},
	{"PEACEMAKERS", 11, 111741},
	{"EFFECTUATE", 10, 111742},
	{"ZATION", 6, 111743},
	{"MARKY", 5, 111744},
	{"EMERITA", 7, 111745},
	{"ACTIVI", 6, 111746},
	{"LONGBOW", 7, 111747},
	{"LORAN", 5, 111748},
	{"YHIP", 4, 111749},
	{"UMTU", 4, 111750},
	{"TVWA", 4, 111751},
	{"RHIK", 4, 111752},
	{"POPW", 4, 111753},
	{"MBAM", 4, 111754},
	{"LTVI", 4, 111755},
	{"LTIY", 4, 111756},
	{"KDER", 4, 111757},
	{"JGEN", 4, 111758},
	{"IGCR", 4, 111759},
	{"EBOP", 4, 111760},
	{"DDUL", 4, 111761},
	{"MEATPACKING", 11, 111762},
	{"OCCIDENTALIS", 12, 111763},
	{"DEFERRING", 9, 111764},
	{"BAIKAL", 6, 111765},
	{"SURBITON", 8, 111766},
	{"QUILLS", 6, 111767},
	{"STREETBALL", 10, 111768},
	{"BIGLIETTI", 9, 111769},
	{"NOIZE", 5, 111770},
	{"SINTERED", 8, 111771},
	{"MERV", 4, 111772},
	{"ERASES", 6, 111773},
	{"SCHREINER", 9, 111774},
	{"CRUSE", 5, 111775},
	{"SCALPER", 7, 111776},
	{"NANOSCIENCE", 11, 111777},
	{"KRIZIA", 6, 111778},
	{"STENBERG", 8, 111779},
	{"SUBDUCTION", 10, 111780},
	{"HAIRLINE", 8, 111781},
	{"GATEHOUSE", 9, 111782},
	{"TAXCUT", 6, 111783},
	{"PRACTISES", 9, 111784},
	{"SKOB", 4, 111785},
	{"RTEP", 4, 111786},
	{"MULR", 4, 111787},
	{"LUMF", 4, 111788},
	{"LOPF", 4, 111789},
	{"LFAU", 4, 111790},
	{"VERUCA", 6, 111791},
	{"HEWETT", 6, 111792},
	{"LUXENBERG", 9, 111793},
	{"PRADEEP", 7, 111794},
	{"VISTEON", 7, 111795},
	{"EVENS", 5, 111796},
	{"TARTANS", 7, 111797},
	{"YALTA", 5, 111798},
	{"UNATTAINABLE", 12, 111799},
	{"UNREMARKABLE", 12, 111800},
	{"COMPLETA", 8, 111801},
	{"LENGTHENED", 10, 111802},
	{"RAJEEV", 6, 111803},
	{"OFWY", 4, 111804},
	{"BAFA", 4, 111805},
	{"ACPL", 4, 111806},
	{"MUTHA", 5, 111807},
	{"PROLETARIAN", 11, 111808},
	{"AKOYA", 5, 111809},
	{"BODMIN", 6, 111810},
	{"SITTINGBOURNE", 13, 111811},
	{"DRAMATIST", 9, 111812},
	{"GRAYISH", 7, 111813},
	{"MICROSTAR", 9, 111814},
	{"MINERALOGICAL", 13, 111815},
	{"ENNISKILLEN", 11, 111816},
	{"HARING", 6, 111817},
	{"POPWIN", 6, 111818},
	{"DEUT", 4, 111819},
	{"UNCHARACTERIZED", 15, 111820},
	{"HALLUCINATION", 13, 111821},
	{"LOGARITHMS", 10, 111822},
	{"WERENT", 6, 111823},
	{"YCED", 4, 111824},
	{"WLAK", 4, 111825},
	{"VYWI", 4, 111826},
	{"QIGO", 4, 111827},
	{"KRZY", 4, 111828},
	{"WILDMAN", 7, 111829},
	{"LISTON", 6, 111830},
	{"WORKPIECE", 9, 111831},
	{"MIRKO", 5, 111832},
	{"EXHORTATION", 11, 111833},
	{"AROUSING", 8, 111834},
	{"DRAGAN", 6, 111835},
	{"SYNTHETICS", 10, 111836},
	{"KAKADU", 6, 111837},
	{"HSDPA", 5, 111838},
	{"SHORELINESHANTYHOTEL", 20, 111839},
	{"RUFFIN", 6, 111840},
	{"JOUBERT", 7, 111841},
	{"BEEING", 6, 111842},
	{"AVOCADOS", 8, 111843},
	{"HYPOTHESIZE", 11, 111844},
	{"TAXICABS", 8, 111845},
	{"BRUKER", 6, 111846},
	{"VEYD", 4, 111847},
	{"UGAV", 4, 111848},
	{"OFNY", 4, 111849},
	{"MRBL", 4, 111850},
	{"GJIN", 4, 111851},
	{"ERWW", 4, 111852},
	{"EILB", 4, 111853},
	{"DYVI", 4, 111854},
	{"DYOW", 4, 111855},
	{"CXXFLAGS", 8, 111856},
	{"RNIB", 4, 111857},
	{"HIPPOPOTAMUS", 12, 111858},
	{"SMPTE", 5, 111859},
	{"MONGERING", 9, 111860},
	{"ETHANE", 6, 111861},
	{"PUFFER", 6, 111862},
	{"CROBAR", 6, 111863},
	{"CODIGO", 6, 111864},
	{"RFLP", 4, 111865},
	{"WILE", 4, 111866},
	{"UVALDE", 6, 111867},
	{"SNAPSTREAM", 10, 111868},
	{"XHAM", 4, 111869},
	{"OPAQ", 4, 111870},
	{"KDEE", 4, 111871},
	{"HDOR", 4, 111872},
	{"BEZZ", 4, 111873},
	{"AGADIR", 6, 111874},
	{"DIDCOT", 6, 111875},
	{"CLAYPOOL", 8, 111876},
	{"HOMERED", 7, 111877},
	{"POSTREL", 7, 111878},
	{"SMIRNOFF", 8, 111879},
	{"FORGERIES", 9, 111880},
	{"MEDIOS", 6, 111881},
	{"IOLITE", 6, 111882},
	{"TATYANA", 7, 111883},
	{"RUMSEY", 6, 111884},
	{"MONTAIGNE", 9, 111885},
	{"HAEMORRHAGE", 11, 111886},
	{"WKIL", 4, 111887},
	{"LETK", 4, 111888},
	{"KILB", 4, 111889},
	{"GSFL", 4, 111890},
	{"FKIT", 4, 111891},
	{"EEUG", 4, 111892},
	{"BOFD", 4, 111893},
	{"PROPAGATOR", 10, 111894},
	{"PUNCHLINE", 9, 111895},
	{"MALLETT", 7, 111896},
	{"CHARTRES", 8, 111897},
	{"MSGR", 4, 111898},
	{"RECLINE", 7, 111899},
	{"MAITRE", 6, 111900},
	{"SYSCALL", 7, 111901},
	{"TYPEFACES", 9, 111902},
	{"THERMISTOR", 10, 111903},
	{"HOURSSHOW", 9, 111904},
	{"UREZ", 4, 111905},
	{"PECR", 4, 111906},
	{"GHSF", 4, 111907},
	{"EBAF", 4, 111908},
	{"AKSL", 4, 111909},
	{"HONEYBEE", 8, 111910},
	{"FLUVIAL", 7, 111911},
	{"REMEMBRANCES", 12, 111912},
	{"BERRYMAN", 8, 111913},
	{"ACTISYS", 7, 111914},
	{"UPMARKET", 8, 111915},
	{"SADDLEBACK", 10, 111916},
	{"MUFFS", 5, 111917},
	{"TELOS", 5, 111918},
	{"SLYTHERIN", 9, 111919},
	{"OAKHAM", 6, 111920},
	{"DISTURBS", 8, 111921},
	{"SHAUGHNESSY", 11, 111922},
	{"IREWARDS", 8, 111923},
	{"DJVU", 4, 111924},
	{"CHUMS", 5, 111925},
	{"ADRES", 5, 111926},
	{"CANDELA", 7, 111927},
	{"RIKKI", 5, 111928},
	{"UIDP", 4, 111929},
	{"ROWV", 4, 111930},
	{"RGOY", 4, 111931},
	{"ILEQ", 4, 111932},
	{"IFDO", 4, 111933},
	{"GNAU", 4, 111934},
	{"EZUN", 4, 111935},
	{"DVIV", 4, 111936},
	{"DFAD", 4, 111937},
	{"BYBY", 4, 111938},
	{"PEDICURES", 9, 111939},
	{"HANSSON", 7, 111940},
	{"PHONECARDS", 10, 111941},
	{"DETERMINATE", 11, 111942},
	{"WATERLINE", 9, 111943},
	{"HEEDED", 6, 111944},
	{"LIQUIDATIONS", 12, 111945},
	{"HAUGEN", 6, 111946},
	{"BETHPAGE", 8, 111947},
	{"POLSON", 6, 111948},
	{"TELEPHONING", 11, 111949},
	{"SOPHOCLES", 9, 111950},
	{"SHABBOS", 7, 111951},
	{"JELL", 4, 111952},
	{"ROCAWEAR", 8, 111953},
	{"WHAMMY", 6, 111954},
	{"POPDEX", 6, 111955},
	{"CENTIVES", 8, 111956},
	{"COLLARD", 7, 111957},
	{"JELENA", 6, 111958},
	{"ASOLO", 5, 111959},
	{"YVEP", 4, 111960},
	{"WSDU", 4, 111961},
	{"OJAV", 4, 111962},
	{"ASCY", 4, 111963},
	{"LISTSERVER", 10, 111964},
	{"WEMAN", 5, 111965},
	{"SACHET", 6, 111966},
	{"LUPE", 4, 111967},
	{"MARQUARDT", 9, 111968},
	{"INSTRUC", 7, 111969},
	{"HUMILIATE", 9, 111970},
	{"SCHOOLYARD", 10, 111971},
	{"HOMEFRONT", 9, 111972},
	{"WOODWORTH", 9, 111973},
	{"DRAKES", 6, 111974},
	{"WHATCHA", 7, 111975},
	{"KINKO", 5, 111976},
	{"SKOM", 4, 111977},
	{"PEZS", 4, 111978},
	{"NDVU", 4, 111979},
	{"LFEW", 4, 111980},
	{"FTYC", 4, 111981},
	{"EURF", 4, 111982},
	{"EGSC", 4, 111983},
	{"STRIVECTIN", 10, 111984},
	{"WEILAND", 7, 111985},
	{"SONAL", 5, 111986},
	{"ROUSER", 6, 111987},
	{"VETTED", 6, 111988},
	{"ERFURT", 6, 111989},
	{"ADIGE", 5, 111990},
	{"TITERS", 6, 111991},
	{"TYPISTS", 7, 111992},
	{"GROUPSEKS", 9, 111993},
	{"WASSER", 6, 111994},
	{"TOMES", 5, 111995},
	{"SVOBODA", 7, 111996},
	{"LUMINAIRE", 9, 111997},
	{"LEDGERS", 7, 111998},
	{"PDV", 3, 111999},
	{"POLANSKI", 8, 112000},
	{"INGEN", 5, 112001},
	{"XESD", 4, 112002},
	{"OPFU", 4, 112003},
	{"EXSP", 4, 112004},
	{"ELMT", 4, 112005},
	{"CYBR", 4, 112006},
	{"JAPENESE", 8, 112007},
	{"CHORIONIC", 9, 112008},
	{"ACCOMPANIMENTS", 14, 112009},
	{"BUCKMAN", 7, 112010},
	{"OFFENBACH", 9, 112011},
	{"CLAIRVOYANT", 11, 112012},
	{"CALCITONIN", 10, 112013},
	{"FOOTLOOSE", 9, 112014},
	{"DURY", 4, 112015},
	{"SHRIEK", 6, 112016},
	{"INCLUDINGWEB", 12, 112017},
	{"POSITS", 6, 112018},
	{"DEAVER", 6, 112019},
	{"BGM", 3, 112020},
	{"FAECAL", 6, 112021},
	{"YAKUZA", 6, 112022},
	{"BARRETTE", 8, 112023},
	{"REHABS", 6, 112024},
	{"CARPINTERIA", 11, 112025},
	{"NYMPHETS", 8, 112026},
	{"PEACEBUILDING", 13, 112027},
	{"OLEANDER", 8, 112028},
	{"BYKR", 4, 112029},
	{"DEICIDE", 7, 112030},
	{"YOUS", 4, 112031},
	{"BUNGLE", 6, 112032},
	{"MESMERIZED", 10, 112033},
	{"NSSTRING", 8, 112034},
	{"GLOSSOP", 7, 112035},
	{"FFP", 3, 112036},
	{"PROBIT", 6, 112037},
	{"KINDERGARTENS", 13, 112038},
	{"GREENDAY", 8, 112039},
	{"BENTONITE", 9, 112040},
	{"CROZIER", 7, 112041},
	{"FEROCITY", 8, 112042},
	{"RERL", 4, 112043},
	{"LRYD", 4, 112044},
	{"LREY", 4, 112045},
	{"FKAM", 4, 112046},
	{"DHIC", 4, 112047},
	{"QUOI", 4, 112048},
	{"FREESTRIP", 9, 112049},
	{"SOLITON", 7, 112050},
	{"GEIR", 4, 112051},
	{"WITHERING", 9, 112052},
	{"ANNOUNCERS", 10, 112053},
	{"COCHE", 5, 112054},
	{"BABB", 4, 112055},
	{"UNDERPINS", 9, 112056},
	{"EVEREX", 6, 112057},
	{"PROCREATION", 11, 112058},
	{"GLENGARRY", 9, 112059},
	{"CORDILLERA", 10, 112060},
	{"ALBERTSONS", 10, 112061},
	{"WRUS", 4, 112062},
	{"ROGB", 4, 112063},
	{"PCUS", 4, 112064},
	{"NUMW", 4, 112065},
	{"LLOK", 4, 112066},
	{"KADM", 4, 112067},
	{"VIDEORECORDER", 13, 112068},
	{"REELECTED", 9, 112069},
	{"SUGOI", 5, 112070},
	{"POKERS", 6, 112071},
	{"GLOBALIZED", 10, 112072},
	{"ISHOP", 5, 112073},
	{"SCHIRMER", 8, 112074},
	{"CRAIGHEAD", 9, 112075},
	{"EXASPERATED", 11, 112076},
	{"CROPPER", 7, 112077},
	{"HEMMINGS", 8, 112078},
	{"EERSTE", 6, 112079},
	{"PISOS", 5, 112080},
	{"GROPING", 7, 112081},
	{"PATTERICO", 9, 112082},
	{"BRUCELLOSIS", 11, 112083},
	{"PATRICIO", 8, 112084},
	{"YPIO", 4, 112085},
	{"VWOR", 4, 112086},
	{"USGL", 4, 112087},
	{"THRB", 4, 112088},
	{"SKLA", 4, 112089},
	{"PEUS", 4, 112090},
	{"ORPB", 4, 112091},
	{"FSAX", 4, 112092},
	{"FLCA", 4, 112093},
	{"APYS", 4, 112094},
	{"AKUB", 4, 112095},
	{"AJGE", 4, 112096},
	{"SPEEDSKATING", 12, 112097},
	{"COMMENTI", 8, 112098},
	{"EXONERATED", 10, 112099},
	{"FRWE", 4, 112100},
	{"SOULE", 5, 112101},
	{"SHUSTER", 7, 112102},
	{"MULTILINE", 9, 112103},
	{"ORANGEMEN", 9, 112104},
	{"PINNACLES", 9, 112105},
	{"HYPERGLYCEMIA", 13, 112106},
	{"SHERRIE", 7, 112107},
	{"LENNIE", 6, 112108},
	{"APEL", 4, 112109},
	{"YHOC", 4, 112110},
	{"WNGU", 4, 112111},
	{"RNLY", 4, 112112},
	{"IRLD", 4, 112113},
	{"HEZW", 4, 112114},
	{"FOFD", 4, 112115},
	{"EGEU", 4, 112116},
	{"AAPL", 4, 112117},
	{"CABANAS", 7, 112118},
	{"MISER", 5, 112119},
	{"RTEMS", 5, 112120},
	{"RATIONALES", 10, 112121},
	{"CODEGURU", 8, 112122},
	{"SCAFFOLDS", 9, 112123},
	{"CLIMA", 5, 112124},
	{"TAGGER", 6, 112125},
	{"RHOADES", 7, 112126},
	{"KAHLO", 5, 112127},
	{"NIFER", 5, 112128},
	{"YCOB", 4, 112129},
	{"YCEC", 4, 112130},
	{"XHER", 4, 112131},
	{"SLEU", 4, 112132},
	{"RAOP", 4, 112133},
	{"OPMW", 4, 112134},
	{"LPSB", 4, 112135},
	{"LOPD", 4, 112136},
	{"FASTLANE", 8, 112137},
	{"CSIR", 4, 112138},
	{"SUISUN", 6, 112139},
	{"SHORING", 7, 112140},
	{"REPRISALS", 9, 112141},
	{"MRCP", 4, 112142},
	{"CULPABLE", 8, 112143},
	{"SVCDOC", 6, 112144},
	{"ENTRYWAY", 8, 112145},
	{"UNSERER", 7, 112146},
	{"SIDEBARS", 8, 112147},
	{"WORDPLAY", 8, 112148},
	{"FUJIWARA", 8, 112149},
	{"RELP", 4, 112150},
	{"QUOG", 4, 112151},
	{"MRKE", 4, 112152},
	{"MKEL", 4, 112153},
	{"GUSD", 4, 112154},
	{"GURB", 4, 112155},
	{"DUEB", 4, 112156},
	{"PAGOSA", 6, 112157},
	{"XZU", 3, 112158},
	{"KWX", 3, 112159},
	{"JGD", 3, 112160},
	{"GQR", 3, 112161},
	{"FGZ", 3, 112162},
	{"WHYALLA", 7, 112163},
	{"POTTSVILLE", 10, 112164},
	{"CONTACTER", 9, 112165},
	{"WOOGIE", 6, 112166},
	{"CJR", 3, 112167},
	{"MEDIANS", 7, 112168},
	{"ONEFILE", 7, 112169},
	{"TARR", 4, 112170},
	{"FLG", 3, 112171},
	{"ENSLAVEMENT", 11, 112172},
	{"MUTATE", 6, 112173},
	{"COMPARISION", 11, 112174},
	{"OPENSWAN", 8, 112175},
	{"WAWE", 4, 112176},
	{"TMCA", 4, 112177},
	{"RYEY", 4, 112178},
	{"KADR", 4, 112179},
	{"HOGW", 4, 112180},
	{"EXGA", 4, 112181},
	{"DLEX", 4, 112182},
	{"AXLA", 4, 112183},
	{"ALUD", 4, 112184},
	{"ABSOLUTES", 9, 112185},
	{"ASUNDER", 7, 112186},
	{"DESTABILIZING", 13, 112187},
	{"STATIST", 7, 112188},
	{"BRUNS", 5, 112189},
	{"ENCYLOPEDIA", 11, 112190},
	{"QUALMS", 6, 112191},
	{"TREAS", 5, 112192},
	{"LESABRE", 7, 112193},
	{"KALIMANTAN", 10, 112194},
	{"CIPA", 4, 112195},
	{"UNIVERSALISM", 12, 112196},
	{"CREMATED", 8, 112197},
	{"TUXE", 4, 112198},
	{"TDOB", 4, 112199},
	{"SNUF", 4, 112200},
	{"RAJS", 4, 112201},
	{"KYCH", 4, 112202},
	{"KDET", 4, 112203},
	{"FZER", 4, 112204},
	{"ELTZ", 4, 112205},
	{"COGA", 4, 112206},
	{"BBYD", 4, 112207},
	{"FULLBACK", 8, 112208},
	{"PALEY", 5, 112209},
	{"FILEHANDLE", 10, 112210},
	{"SIMVASTATIN", 11, 112211},
	{"SPOKESMEN", 9, 112212},
	{"COUNTERINTELLIGENCE", 19, 112213},
	{"SLIPCASE", 8, 112214},
	{"NONSMOKING", 10, 112215},
	{"PROFLOWERS", 10, 112216},
	{"COLLECTIVES", 11, 112217},
	{"RAMACHANDRAN", 12, 112218},
	{"UNHARMED", 8, 112219},
	{"LATIONS", 7, 112220},
	{"SHEAVES", 7, 112221},
	{"TRITT", 5, 112222},
	{"OGWO", 4, 112223},
	{"MMEG", 4, 112224},
	{"LBYJ", 4, 112225},
	{"IMUT", 4, 112226},
	{"EPEV", 4, 112227},
	{"PAYOT", 5, 112228},
	{"KITEBOARDING", 12, 112229},
	{"GODMOTHER", 9, 112230},
	{"MCGINLEY", 8, 112231},
	{"BROAN", 5, 112232},
	{"IMPRESSES", 9, 112233},
	{"FRDE", 4, 112234},
	{"LISTGROUP", 9, 112235},
	{"DKU", 3, 112236},
	{"ANATOLY", 7, 112237},
	{"NADLER", 6, 112238},
	{"POLEMIC", 7, 112239},
	{"WALLABIES", 9, 112240},
	{"NEWKIRK", 7, 112241},
	{"LIDIA", 5, 112242},
	{"AXAPTA", 6, 112243},
	{"LOGUE", 5, 112244},
	{"BEESON", 6, 112245},
	{"COUNCILMEMBERS", 14, 112246},
	{"SMBA", 4, 112247},
	{"RIIM", 4, 112248},
	{"REJI", 4, 112249},
	{"LTDR", 4, 112250},
	{"IBAK", 4, 112251},
	{"HYRA", 4, 112252},
	{"DSSM", 4, 112253},
	{"DRBE", 4, 112254},
	{"AUSL", 4, 112255},
	{"CELEBRANT", 9, 112256},
	{"PLUSIEURS", 9, 112257},
	{"BUTTONED", 8, 112258},
	{"SPROUTED", 8, 112259},
	{"NUXEO", 5, 112260},
	{"WAITANGI", 8, 112261},
	{"MAILSERVER", 10, 112262},
	{"PERFECTIONIST", 13, 112263},
	{"PERCUSSIONIST", 13, 112264},
	{"SWIDTH", 6, 112265},
	{"ORCINUS", 7, 112266},
	{"BAFFIN", 6, 112267},
	{"WLOV", 4, 112268},
	{"UISU", 4, 112269},
	{"NPIG", 4, 112270},
	{"LIXA", 4, 112271},
	{"KARW", 4, 112272},
	{"GELR", 4, 112273},
	{"EGYR", 4, 112274},
	{"AVAU", 4, 112275},
	{"APEXI", 5, 112276},
	{"SHMERA", 6, 112277},
	{"SOCIOCULTURAL", 13, 112278},
	{"HOMEBASED", 9, 112279},
	{"DWIDTH", 6, 112280},
	{"ARMOURY", 7, 112281},
	{"LAMBSKIN", 8, 112282},
	{"MARSHALLING", 11, 112283},
	{"BACKTRACK", 9, 112284},
	{"MYMSN", 5, 112285},
	{"DUDS", 4, 112286},
	{"DISTINCTIVENESS", 15, 112287},
	{"BURWELL", 7, 112288},
	{"IKNOW", 5, 112289},
	{"KONFABULATOR", 12, 112290},
	{"COLCHICINE", 10, 112291},
	{"NOXC", 4, 112292},
	{"ICAJ", 4, 112293},
	{"GFLY", 4, 112294},
	{"REALONE", 7, 112295},
	{"LONGUE", 6, 112296},
	{"OMELETTE", 8, 112297},
	{"DISINTEGRATED", 13, 112298},
	{"FORGETFULNESS", 13, 112299},
	{"MARTE", 5, 112300},
	{"TREVINO", 7, 112301},
	{"PNPHPBB", 7, 112302},
	{"GLOS", 4, 112303},
	{"XIONG", 5, 112304},
	{"MUERTE", 6, 112305},
	{"YBIA", 4, 112306},
	{"RCYH", 4, 112307},
	{"MIGN", 4, 112308},
	{"LSUT", 4, 112309},
	{"GUYG", 4, 112310},
	{"NICOLLET", 8, 112311},
	{"CAPITALISED", 11, 112312},
	{"PHLOX", 5, 112313},
	{"MESOPOTAMIAN", 12, 112314},
	{"HUBCAPS", 7, 112315},
	{"COVERART", 8, 112316},
	{"FARKAS", 6, 112317},
	{"CFDJ", 4, 112318},
	{"XISB", 4, 112319},
	{"TPOV", 4, 112320},
	{"LPUP", 4, 112321},
	{"KEMR", 4, 112322},
	{"FEOU", 4, 112323},
	{"DBAP", 4, 112324},
	{"BOFB", 4, 112325},
	{"STILTS", 6, 112326},
	{"NETATALK", 8, 112327},
	{"SOUTHPARK", 9, 112328},
	{"HAPTIC", 6, 112329},
	{"THRESOMES", 9, 112330},
	{"RIPKEN", 6, 112331},
	{"SAMARITANS", 10, 112332},
	{"PIKEVILLE", 9, 112333},
	{"ELAYNE", 6, 112334},
	{"NAAQS", 5, 112335},
	{"BARABOO", 7, 112336},
	{"STARKS", 6, 112337},
	{"KNOCKER", 7, 112338},
	{"SEQUENCERS", 10, 112339},
	{"STRADDLING", 10, 112340},
	{"UNDERFOOT", 9, 112341},
	{"ROOFED", 6, 112342},
	{"ZESB", 4, 112343},
	{"YSMR", 4, 112344},
	{"WWEI", 4, 112345},
	{"EKBR", 4, 112346},
	{"UNHINGED", 8, 112347},
	{"HERRAMIENTAS", 12, 112348},
	{"NUNC", 4, 112349},
	{"PRIMEVAL", 8, 112350},
	{"AUTOMATOR", 9, 112351},
	{"FUQUA", 5, 112352},
	{"SINGITA", 7, 112353},
	{"PORTFILE", 8, 112354},
	{"DEVITO", 6, 112355},
	{"INTERNED", 8, 112356},
	{"OPERETTA", 8, 112357},
	{"STARSAILOR", 10, 112358},
	{"SCREAMIN", 8, 112359},
	{"SAKES", 5, 112360},
	{"HORSEMANSHIP", 12, 112361},
	{"NACKTE", 6, 112362},
	{"SHREVE", 6, 112363},
	{"STOREYS", 7, 112364},
	{"PENSIONABLE", 11, 112365},
	{"GUR", 3, 112366},
	{"AVIATORS", 8, 112367},
	{"TRANSCRIBERS", 12, 112368},
	{"MCMURDO", 7, 112369},
	{"DESTINIES", 9, 112370},
	{"ZELO", 4, 112371},
	{"MSKA", 4, 112372},
	{"MCIR", 4, 112373},
	{"LDTY", 4, 112374},
	{"LALG", 4, 112375},
	{"DOUI", 4, 112376},
	{"CBUR", 4, 112377},
	{"KEIBLER", 7, 112378},
	{"JURE", 4, 112379},
	{"HARDLINE", 8, 112380},
	{"SUSP", 4, 112381},
	{"SHERBET", 7, 112382},
	{"NORMALISATION", 13, 112383},
	{"SAFEKEEPING", 11, 112384},
	{"CFDA", 4, 112385},
	{"DEPARTEMENT", 11, 112386},
	{"THYROXINE", 9, 112387},
	{"INSTAL", 6, 112388},
	{"PROGRAMCHECKER", 14, 112389},
	{"VERNIER", 7, 112390},
	{"LANNING", 7, 112391},
	{"VYST", 4, 112392},
	{"SPUZ", 4, 112393},
	{"DCOG", 4, 112394},
	{"JOLLEY", 6, 112395},
	{"TADJIKISTAN", 11, 112396},
	{"NUTRITIVE", 9, 112397},
	{"SUWANEE", 7, 112398},
	{"UNCONSOLIDATED", 14, 112399},
	{"PLAB", 4, 112400},
	{"TALIA", 5, 112401},
	{"BERSERKER", 9, 112402},
	{"BOYLOVER", 8, 112403},
	{"CAHIERS", 7, 112404},
	{"MCLAIN", 6, 112405},
	{"POLYPHONY", 9, 112406},
	{"LAKOFF", 6, 112407},
	{"UEDN", 4, 112408},
	{"DMOC", 4, 112409},
	{"NISHIMURA", 9, 112410},
	{"DOUGAL", 6, 112411},
	{"IMEDIA", 6, 112412},
	{"RISPERDAL", 9, 112413},
	{"OAKTON", 6, 112414},
	{"EXEFIND", 7, 112415},
	{"HURRYING", 8, 112416},
	{"HELDEN", 6, 112417},
	{"MORGANTON", 9, 112418},
	{"CDOT", 4, 112419},
	{"CHEHALIS", 8, 112420},
	{"PREVIA", 6, 112421},
	{"DISSOCIATIVE", 12, 112422},
	{"HOTBED", 6, 112423},
	{"TEPID", 5, 112424},
	{"INESSENTIAL", 11, 112425},
	{"DONOGHUE", 8, 112426},
	{"BREADED", 7, 112427},
	{"OFPM", 4, 112428},
	{"LNEY", 4, 112429},
	{"LJEA", 4, 112430},
	{"KANP", 4, 112431},
	{"ILSK", 4, 112432},
	{"GSGI", 4, 112433},
	{"DLUI", 4, 112434},
	{"DATAMAX", 7, 112435},
	{"LIJST", 5, 112436},
	{"OVERESTIMATED", 13, 112437},
	{"GUSHER", 6, 112438},
	{"DUMFRIESSHIRE", 13, 112439},
	{"MUSCARINIC", 10, 112440},
	{"TWIKIREGISTRATION", 17, 112441},
	{"BALLINGER", 9, 112442},
	{"HAIDER", 6, 112443},
	{"SLEDGEHAMMER", 12, 112444},
	{"OPPORTUNE", 9, 112445},
	{"HYPERTHERMIA", 12, 112446},
	{"INTUITIONS", 10, 112447},
	{"SINHALESE", 9, 112448},
	{"BLOWOUTS", 8, 112449},
	{"DISSUADE", 8, 112450},
	{"YUST", 4, 112451},
	{"YJAR", 4, 112452},
	{"WENJ", 4, 112453},
	{"SHMC", 4, 112454},
	{"PHOC", 4, 112455},
	{"OXTR", 4, 112456},
	{"MSUL", 4, 112457},
	{"IDKN", 4, 112458},
	{"GHIC", 4, 112459},
	{"FTAD", 4, 112460},
	{"EOFX", 4, 112461},
	{"DYSR", 4, 112462},
	{"COFL", 4, 112463},
	{"ARBROATH", 8, 112464},
	{"RRD", 3, 112465},
	{"VISCONTI", 8, 112466},
	{"GATHERERS", 9, 112467},
	{"EUROCOM", 7, 112468},
	{"SLURS", 5, 112469},
	{"KEFALONIA", 9, 112470},
	{"UNCOMMENT", 9, 112471},
	{"DJING", 5, 112472},
	{"CONFORMATIONS", 13, 112473},
	{"AZAR", 4, 112474},
	{"DRINKIN", 7, 112475},
	{"DOULA", 5, 112476},
	{"HEMMED", 6, 112477},
	{"DEUTER", 6, 112478},
	{"ASSTRAFFIC", 10, 112479},
	{"REVEGETATION", 12, 112480},
	{"MALATE", 6, 112481},
	{"GYMRAEG", 7, 112482},
	{"WPEN", 4, 112483},
	{"WEEM", 4, 112484},
	{"UVAC", 4, 112485},
	{"TCCO", 4, 112486},
	{"RGHF", 4, 112487},
	{"PUTG", 4, 112488},
	{"PDEB", 4, 112489},
	{"JORJ", 4, 112490},
	{"IEWJ", 4, 112491},
	{"DZEP", 4, 112492},
	{"BCAF", 4, 112493},
	{"DISKLESS", 8, 112494},
	{"POMFRET", 7, 112495},
	{"EPHRATA", 7, 112496},
	{"BEGA", 4, 112497},
	{"COMPUVEST", 9, 112498},
	{"DAFOE", 5, 112499},
	{"MICROELECTRONIC", 15, 112500},
	{"SOUNDSCAPES", 11, 112501},
	{"BTWN", 4, 112502},
	{"PERSONIFIED", 11, 112503},
	{"BLAENAU", 7, 112504},
	{"NIBBLES", 7, 112505},
	{"HODSON", 6, 112506},
	{"INKSCAPE", 8, 112507},
	{"CORNICE", 7, 112508},
	{"YSSW", 4, 112509},
	{"XFOO", 4, 112510},
	{"WBOD", 4, 112511},
	{"SMMI", 4, 112512},
	{"LTVS", 4, 112513},
	{"HUBI", 4, 112514},
	{"FECR", 4, 112515},
	{"ERPG", 4, 112516},
	{"CSAD", 4, 112517},
	{"BEJE", 4, 112518},
	{"MCBEAL", 6, 112519},
	{"SMOCK", 5, 112520},
	{"OVERPOPULATION", 14, 112521},
	{"MASSIE", 6, 112522},
	{"PLIOCENE", 8, 112523},
	{"COEFF", 5, 112524},
	{"OVERCLOCKERS", 12, 112525},
	{"CARDO", 5, 112526},
	{"LIGHTTPD", 8, 112527},
	{"TYNER", 5, 112528},
	{"WRANGELL", 8, 112529},
	{"MUSKET", 6, 112530},
	{"CARHIRE", 7, 112531},
	{"BIBLIOWORKS", 11, 112532},
	{"BUNTON", 6, 112533},
	{"SIRED", 5, 112534},
	{"XHOSA", 5, 112535},
	{"BALLSTON", 8, 112536},
	{"NOVATION", 8, 112537},
	{"VONR", 4, 112538},
	{"SMWO", 4, 112539},
	{"RMUM", 4, 112540},
	{"ONVU", 4, 112541},
	{"ODDF", 4, 112542},
	{"MSTW", 4, 112543},
	{"KSUI", 4, 112544},
	{"EEMD", 4, 112545},
	{"DYBI", 4, 112546},
	{"MCMURTRY", 8, 112547},
	{"WHISPERER", 9, 112548},
	{"SECTEUR", 7, 112549},
	{"RHAID", 5, 112550},
	{"GELB", 4, 112551},
	{"BEAUTIFY", 8, 112552},
	{"TANNERY", 7, 112553},
	{"SOOTY", 5, 112554},
	{"AUTORES", 7, 112555},
	{"BUCKLED", 7, 112556},
	{"PURVEYOR", 8, 112557},
	{"TELOMERE", 8, 112558},
	{"MIGLIA", 6, 112559},
	{"KERBSIDE", 8, 112560},
	{"PAUSCHAL", 8, 112561},
	{"OBFUSCATION", 11, 112562},
	{"MANGEMENT", 9, 112563},
	{"XLES", 4, 112564},
	{"UCHQ", 4, 112565},
	{"LNOB", 4, 112566},
	{"DNAC", 4, 112567},
	{"CIPHERTEXT", 10, 112568},
	{"BOKER", 5, 112569},
	{"KINDLED", 7, 112570},
	{"NEEDLECRAFT", 11, 112571},
	{"RAZORGATOR", 10, 112572},
	{"ABBYY", 5, 112573},
	{"SOUTHBRIDGE", 11, 112574},
	{"DEMYSTIFYING", 12, 112575},
	{"CUBBY", 5, 112576},
	{"PROVENCAL", 9, 112577},
	{"DAEDALUS", 8, 112578},
	{"OTHEROTHER", 10, 112579},
	{"PROTECH", 7, 112580},
	{"CHEMOTAXIS", 10, 112581},
	{"SCHEIN", 6, 112582},
	{"PREMISED", 8, 112583},
	{"BRACHYTHERAPY", 13, 112584},
	{"PENTATHLON", 10, 112585},
	{"FFPU", 4, 112586},
	{"THALLIUM", 8, 112587},
	{"FAILSAFE", 8, 112588},
	{"STAIRWAYS", 9, 112589},
	{"PORKY", 5, 112590},
	{"MAULDIN", 7, 112591},
	{"BARBITURATES", 12, 112592},
	{"METHODISTS", 10, 112593},
	{"CKING", 5, 112594},
	{"ELOY", 4, 112595},
	{"HENCHMEN", 8, 112596},
	{"WCG", 3, 112597},
	{"CUDDLING", 8, 112598},
	{"WORKSOP", 7, 112599},
	{"ATTENUATORS", 11, 112600},
	{"LAPP", 4, 112601},
	{"NSAID", 5, 112602},
	{"YMAM", 4, 112603},
	{"TDAD", 4, 112604},
	{"SMRM", 4, 112605},
	{"RENDEZ", 6, 112606},
	{"SEABISCUIT", 10, 112607},
	{"BOURG", 5, 112608},
	{"SPINOFF", 7, 112609},
	{"JACQUELYN", 9, 112610},
	{"NALOXONE", 8, 112611},
	{"PRETENCE", 8, 112612},
	{"QUESTIONER", 10, 112613},
	{"BIOFILM", 7, 112614},
	{"FUELLING", 8, 112615},
	{"HELLSING", 8, 112616},
	{"WEYL", 4, 112617},
	{"EREGI", 5, 112618},
	{"ZMAR", 4, 112619},
	{"TOBC", 4, 112620},
	{"OFMB", 4, 112621},
	{"NUMT", 4, 112622},
	{"LUSN", 4, 112623},
	{"DIBU", 4, 112624},
	{"AZZP", 4, 112625},
	{"AIGM", 4, 112626},
	{"REPUTE", 6, 112627},
	{"SAMMAMISH", 9, 112628},
	{"NAKEDNESS", 9, 112629},
	{"SCABBARD", 8, 112630},
	{"DUCHESNE", 8, 112631},
	{"FAECES", 6, 112632},
	{"BLAC", 4, 112633},
	{"COVET", 5, 112634},
	{"PROSPERO", 8, 112635},
	{"SILVESTRE", 9, 112636},
	{"SOMATOSTATIN", 12, 112637},
	{"DEBE", 4, 112638},
	{"GENERALISATION", 14, 112639},
	{"RIPPLING", 8, 112640},
	{"YODD", 4, 112641},
	{"YAJO", 4, 112642},
	{"UIFY", 4, 112643},
	{"OUOP", 4, 112644},
	{"OPCI", 4, 112645},
	{"OKYE", 4, 112646},
	{"IGMU", 4, 112647},
	{"HFAV", 4, 112648},
	{"GUPY", 4, 112649},
	{"EFDO", 4, 112650},
	{"AKLO", 4, 112651},
	{"MONY", 4, 112652},
	{"UPR", 3, 112653},
	{"NELLE", 5, 112654},
	{"PUDONG", 6, 112655},
	{"GABI", 4, 112656},
	{"ASPECTJ", 7, 112657},
	{"DIETICIAN", 9, 112658},
	{"LYAPUNOV", 8, 112659},
	{"HANDRAIL", 8, 112660},
	{"SIGNPOSTS", 9, 112661},
	{"RATIONALISM", 11, 112662},
	{"RIMLESS", 7, 112663},
	{"WISTFUL", 7, 112664},
	{"VACLAV", 6, 112665},
	{"KNICKERBOCKER", 13, 112666},
	{"TWINKIE", 7, 112667},
	{"RESTOCKIT", 9, 112668},
	{"LIFEBLOOD", 9, 112669},
	{"RMAV", 4, 112670},
	{"NYED", 4, 112671},
	{"DRYM", 4, 112672},
	{"SCHOOLNET", 9, 112673},
	{"BOMBA", 5, 112674},
	{"AUTONOMOUSLY", 12, 112675},
	{"ADMIRES", 7, 112676},
	{"MORONIC", 7, 112677},
	{"LATIENNE", 8, 112678},
	{"HISSED", 6, 112679},
	{"MAHATHIR", 8, 112680},
	{"MICHELSON", 9, 112681},
	{"MACROVISION", 11, 112682},
	{"REIZEN", 6, 112683},
	{"OVERPOWERED", 11, 112684},
	{"ACIDIFICATION", 13, 112685},
	{"FOGEL", 5, 112686},
	{"PERVADES", 8, 112687},
	{"MELE", 4, 112688},
	{"MULTICASTING", 12, 112689},
	{"KIPP", 4, 112690},
	{"UKAA", 4, 112691},
	{"TLUT", 4, 112692},
	{"RHEJ", 4, 112693},
	{"KOSK", 4, 112694},
	{"ILMY", 4, 112695},
	{"IBAU", 4, 112696},
	{"GOJI", 4, 112697},
	{"TIRADE", 6, 112698},
	{"CYBERPOWER", 10, 112699},
	{"REGURGITATION", 13, 112700},
	{"ALFRESCO", 8, 112701},
	{"REIV", 4, 112702},
	{"LAUREATES", 9, 112703},
	{"SELLOUT", 7, 112704},
	{"PSYCHOACTIVE", 12, 112705},
	{"FBC", 3, 112706},
	{"SOMOA", 5, 112707},
	{"ELUCIDATION", 11, 112708},
	{"ELOHIM", 6, 112709},
	{"RELEVENT", 8, 112710},
	{"UVET", 4, 112711},
	{"LMAW", 4, 112712},
	{"DRTH", 4, 112713},
	{"PGADMIN", 7, 112714},
	{"INPATIENTS", 10, 112715},
	{"CHARLIES", 8, 112716},
	{"KEMAL", 5, 112717},
	{"PRONGS", 6, 112718},
	{"FUMBLED", 7, 112719},
	{"BLASTP", 6, 112720},
	{"TARAN", 5, 112721},
	{"HASHANAH", 8, 112722},
	{"FOCK", 4, 112723},
	{"CATHERINES", 10, 112724},
	{"JOOLS", 5, 112725},
	{"LOUNGEWEAR", 10, 112726},
	{"CONFIDED", 8, 112727},
	{"DEPCOMP", 7, 112728},
	{"HUMEDAD", 7, 112729},
	{"UMIST", 5, 112730},
	{"RATERS", 6, 112731},
	{"ESCALATORS", 10, 112732},
	{"SNPRINTF", 8, 112733},
	{"ALMADEN", 7, 112734},
	{"YSTM", 4, 112735},
	{"OGHU", 4, 112736},
	{"AUPO", 4, 112737},
	{"SEARCHENGINE", 12, 112738},
	{"MUMBLING", 8, 112739},
	{"SWEATPANTS", 10, 112740},
	{"REDBIRDS", 8, 112741},
	{"DANY", 4, 112742},
	{"ABSTAINING", 10, 112743},
	{"GIOTTO", 6, 112744},
	{"ACCADEMIA", 9, 112745},
	{"PUNKTE", 6, 112746},
	{"LANCERS", 7, 112747},
	{"HEIMLICH", 8, 112748},
	{"GCP", 3, 112749},
	{"INFECTIVITY", 11, 112750},
	{"GYROS", 5, 112751},
	{"UPWELLING", 9, 112752},
	{"WAREN", 5, 112753},
	{"CONFEDERATES", 12, 112754},
	{"YAMY", 4, 112755},
	{"NAMF", 4, 112756},
	{"MGAT", 4, 112757},
	{"JRWH", 4, 112758},
	{"ILKF", 4, 112759},
	{"HLAV", 4, 112760},
	{"HHYP", 4, 112761},
	{"GJOS", 4, 112762},
	{"EEFC", 4, 112763},
	{"DPMT", 4, 112764},
	{"DEMW", 4, 112765},
	{"CSVI", 4, 112766},
	{"CAUN", 4, 112767},
	{"PALADINS", 8, 112768},
	{"MEDELLIN", 8, 112769},
	{"CELLULARACCESSORY", 17, 112770},
	{"BRUBAKER", 8, 112771},
	{"MARSALA", 7, 112772},
	{"PITURES", 7, 112773},
	{"DXG", 3, 112774},
	{"SPILLOVER", 9, 112775},
	{"CONTINUATIONS", 13, 112776},
	{"LGW", 3, 112777},
	{"GRIMALDI", 8, 112778},
	{"BORREGO", 7, 112779},
	{"RGDI", 4, 112780},
	{"FSCU", 4, 112781},
	{"STRETCHERS", 10, 112782},
	{"THREESAMES", 10, 112783},
	{"DUFFERIN", 8, 112784},
	{"DEMOSTHENES", 11, 112785},
	{"CONTRACTILE", 11, 112786},
	{"TOENAILS", 8, 112787},
	{"ELASTICATED", 11, 112788},
	{"BUTION", 6, 112789},
	{"WANNABES", 8, 112790},
	{"IBARRA", 6, 112791},
	{"TERMINATORS", 11, 112792},
	{"RGPR", 4, 112793},
	{"PSUI", 4, 112794},
	{"LIDU", 4, 112795},
	{"LELW", 4, 112796},
	{"FOBE", 4, 112797},
	{"EMYU", 4, 112798},
	{"DAIC", 4, 112799},
	{"WARUM", 5, 112800},
	{"XMETAL", 6, 112801},
	{"UPSURGE", 7, 112802},
	{"PEEWEE", 6, 112803},
	{"FORSALE", 7, 112804},
	{"CONTACTUS", 9, 112805},
	{"INEQUITABLE", 11, 112806},
	{"AVAIT", 5, 112807},
	{"MULTITHREADING", 14, 112808},
	{"MINTY", 5, 112809},
	{"LUDINGTON", 9, 112810},
	{"EARLHAM", 7, 112811},
	{"DREIER", 6, 112812},
	{"REPTILIAN", 9, 112813},
	{"CENTRONICS", 10, 112814},
	{"POSTOB", 6, 112815},
	{"DEVONIAN", 8, 112816},
	{"UMOT", 4, 112817},
	{"TMRM", 4, 112818},
	{"JARG", 4, 112819},
	{"FSME", 4, 112820},
	{"ERLL", 4, 112821},
	{"EFPA", 4, 112822},
	{"STARRETT", 8, 112823},
	{"INFINITUM", 9, 112824},
	{"PROBLEMAS", 9, 112825},
	{"MISNOMER", 8, 112826},
	{"OSADA", 5, 112827},
	{"HARPENDEN", 9, 112828},
	{"FITZSIMMONS", 11, 112829},
	{"BRAIDING", 8, 112830},
	{"WAITAKERE", 9, 112831},
	{"CONOCOPHILLIPS", 14, 112832},
	{"JUSTO", 5, 112833},
	{"MAGGI", 5, 112834},
	{"WORKCOVER", 9, 112835},
	{"FAROESE", 7, 112836},
	{"TREFF", 5, 112837},
	{"BEIJA", 5, 112838},
	{"WEOU", 4, 112839},
	{"UTEJ", 4, 112840},
	{"UERC", 4, 112841},
	{"RIMD", 4, 112842},
	{"REGW", 4, 112843},
	{"OMSG", 4, 112844},
	{"LGEI", 4, 112845},
	{"KBAD", 4, 112846},
	{"HRAX", 4, 112847},
	{"EGSU", 4, 112848},
	{"CTKI", 4, 112849},
	{"AZUK", 4, 112850},
	{"TOOLTIPS", 8, 112851},
	{"OINTMENTS", 9, 112852},
	{"SPEEK", 5, 112853},
	{"KNORR", 5, 112854},
	{"ENDOTHELIN", 10, 112855},
	{"DIFFRENT", 8, 112856},
	{"LIMERICKS", 9, 112857},
	{"ORGANOMETALLIC", 14, 112858},
	{"CONGER", 6, 112859},
	{"TUGGING", 7, 112860},
	{"ODORLESS", 8, 112861},
	{"MYTRAVELGUIDE", 13, 112862},
	{"BORLA", 5, 112863},
	{"XPERT", 5, 112864},
	{"AMITABH", 7, 112865},
	{"HECKLER", 7, 112866},
	{"FISSILE", 7, 112867},
	{"GIAMBI", 6, 112868},
	{"EDELBROCK", 9, 112869},
	{"JESSI", 5, 112870},
	{"OPULENCE", 8, 112871},
	{"VPOF", 4, 112872},
	{"RRAU", 4, 112873},
	{"RASJ", 4, 112874},
	{"BGRA", 4, 112875},
	{"GARUDA", 6, 112876},
	{"XENIUM", 6, 112877},
	{"APPOMATTOX", 10, 112878},
	{"FUJII", 5, 112879},
	{"RAIKKONEN", 9, 112880},
	{"AMAVISD", 7, 112881},
	{"BENTHAM", 7, 112882},
	{"GUARDSMEN", 9, 112883},
	{"ORGANELLES", 10, 112884},
	{"RITONAVIR", 9, 112885},
	{"ALAMANCE", 8, 112886},
	{"GASTRONOMIC", 11, 112887},
	{"UNEASE", 6, 112888},
	{"DICTATORSHIPS", 13, 112889},
	{"CENTIGRADE", 10, 112890},
	{"NGHYMRU", 7, 112891},
	{"BARRET", 6, 112892},
	{"DISMISSALS", 10, 112893},
	{"YSWR", 4, 112894},
	{"UDOV", 4, 112895},
	{"SGEM", 4, 112896},
	{"ROFZ", 4, 112897},
	{"FPOK", 4, 112898},
	{"CKEW", 4, 112899},
	{"AIGL", 4, 112900},
	{"WOODPECKERS", 11, 112901},
	{"ACHIM", 5, 112902},
	{"PARKERS", 7, 112903},
	{"ACCPAC", 6, 112904},
	{"CARPHONE", 8, 112905},
	{"COURSING", 8, 112906},
	{"JUKKA", 5, 112907},
	{"VIEWMASTER", 10, 112908},
	{"ZWP", 3, 112909},
	{"ZRL", 3, 112910},
	{"XDJ", 3, 112911},
	{"WZY", 3, 112912},
	{"WKX", 3, 112913},
	{"WFJ", 3, 112914},
	{"KQC", 3, 112915},
	{"KKZ", 3, 112916},
	{"CFZ", 3, 112917},
	{"FACEBOOK", 8, 112918},
	{"TRUONG", 6, 112919},
	{"BLOGRINGS", 9, 112920},
	{"BESCHREIBUNG", 12, 112921},
	{"ZAWI", 4, 112922},
	{"PASL", 4, 112923},
	{"LECY", 4, 112924},
	{"IDUC", 4, 112925},
	{"VAUX", 4, 112926},
	{"HOPKINSVILLE", 12, 112927},
	{"BONTRAGER", 9, 112928},
	{"ORNITHOLOGICAL", 14, 112929},
	{"VIDALIA", 7, 112930},
	{"ROEMER", 6, 112931},
	{"EZSUPPORTER", 11, 112932},
	{"PATRICIAN", 9, 112933},
	{"TOURNIQUET", 10, 112934},
	{"ASSISTANTSHIP", 13, 112935},
	{"LOONS", 5, 112936},
	{"WINDSHIELDS", 11, 112937},
	{"OPERANDI", 8, 112938},
	{"ZACHARIAS", 9, 112939},
	{"TOLUCA", 6, 112940},
	{"AVANDIA", 7, 112941},
	{"DONGGUAN", 8, 112942},
	{"YETY", 4, 112943},
	{"WBON", 4, 112944},
	{"UEZT", 4, 112945},
	{"TVWH", 4, 112946},
	{"ONWY", 4, 112947},
	{"LRUB", 4, 112948},
	{"HMYL", 4, 112949},
	{"GBUN", 4, 112950},
	{"FALP", 4, 112951},
	{"EMYV", 4, 112952},
	{"ELDK", 4, 112953},
	{"DTIB", 4, 112954},
	{"CSGR", 4, 112955},
	{"BUDW", 4, 112956},
	{"AMUK", 4, 112957},
	{"MOLYNEUX", 8, 112958},
	{"WHIPPET", 7, 112959},
	{"MELODRAMATIC", 12, 112960},
	{"ROUSSE", 6, 112961},
	{"MICROSOMES", 10, 112962},
	{"MOONLIGHTING", 12, 112963},
	{"EFFET", 5, 112964},
	{"FELIS", 5, 112965},
	{"SPORTAGE", 8, 112966},
	{"PERAK", 5, 112967},
	{"INEXPERIENCE", 12, 112968},
	{"CHICANE", 7, 112969},
	{"PALABRAS", 8, 112970},
	{"TZRE", 4, 112971},
	{"REOM", 4, 112972},
	{"NDNC", 4, 112973},
	{"LMYT", 4, 112974},
	{"HEVP", 4, 112975},
	{"HAKK", 4, 112976},
	{"FUDG", 4, 112977},
	{"MARDIGRAS", 9, 112978},
	{"AANTAL", 6, 112979},
	{"RIME", 4, 112980},
	{"FEEDLOT", 7, 112981},
	{"GAMELAN", 7, 112982},
	{"AQUAPAC", 7, 112983},
	{"CUDDY", 5, 112984},
	{"COUTTS", 6, 112985},
	{"TICQ", 4, 112986},
	{"NPRU", 4, 112987},
	{"FGIA", 4, 112988},
	{"CYAP", 4, 112989},
	{"NONSTEROIDAL", 12, 112990},
	{"KALLE", 5, 112991},
	{"FOURSOMES", 9, 112992},
	{"PLB", 3, 112993},
	{"FLOMAX", 6, 112994},
	{"TRUSTIX", 7, 112995},
	{"VUELOS", 6, 112996},
	{"MAKKAH", 6, 112997},
	{"JCL", 3, 112998},
	{"PEPSICO", 7, 112999},
	{"TRIGG", 5, 113000},
	{"CCITT", 5, 113001},
	{"SERIALLY", 8, 113002},
	{"URFT", 4, 113003},
	{"PITM", 4, 113004},
	{"MHMP", 4, 113005},
	{"COMPACTPCI", 10, 113006},
	{"EXTRAPREDS", 10, 113007},
	{"PUBLICIDAD", 10, 113008},
	{"ETONIC", 6, 113009},
	{"GEDIT", 5, 113010},
	{"FOTOGRAFIA", 10, 113011},
	{"DAYPOP", 6, 113012},
	{"DISPERSIVE", 10, 113013},
	{"GEFUNDEN", 8, 113014},
	{"EARPLUGS", 8, 113015},
	{"APPRISED", 8, 113016},
	{"YOUQ", 4, 113017},
	{"YDOF", 4, 113018},
	{"PSKE", 4, 113019},
	{"MSFL", 4, 113020},
	{"KAYB", 4, 113021},
	{"IUMU", 4, 113022},
	{"HCYC", 4, 113023},
	{"DSSW", 4, 113024},
	{"DIMW", 4, 113025},
	{"NIVERSITY", 9, 113026},
	{"BEENIE", 6, 113027},
	{"BAHAMANIAN", 10, 113028},
	{"UNITECH", 7, 113029},
	{"IMAGEM", 6, 113030},
	{"PROSECUTORIAL", 13, 113031},
	{"LANDO", 5, 113032},
	{"CORED", 5, 113033},
	{"THOUGHTLESS", 11, 113034},
	{"COMPARER", 8, 113035},
	{"CALDECOTT", 9, 113036},
	{"INDUSTRI", 8, 113037},
	{"VEZS", 4, 113038},
	{"UOTL", 4, 113039},
	{"ROLN", 4, 113040},
	{"KCOS", 4, 113041},
	{"HLEM", 4, 113042},
	{"GUYR", 4, 113043},
	{"GNUR", 4, 113044},
	{"GBUB", 4, 113045},
	{"GOAD", 4, 113046},
	{"JAPANIMATION", 12, 113047},
	{"UNICO", 5, 113048},
	{"MCCRAY", 6, 113049},
	{"REHABILITATING", 14, 113050},
	{"TABELLE", 7, 113051},
	{"MUNCHIES", 8, 113052},
	{"LAVERY", 6, 113053},
	{"CYRANO", 6, 113054},
	{"PARLE", 5, 113055},
	{"SATORI", 6, 113056},
	{"UPTURN", 6, 113057},
	{"MISALIGNMENT", 12, 113058},
	{"MUDDLE", 6, 113059},
	{"UGSP", 4, 113060},
	{"PTTR", 4, 113061},
	{"PFAS", 4, 113062},
	{"OPYL", 4, 113063},
	{"MBIQ", 4, 113064},
	{"GYBY", 4, 113065},
	{"FDUK", 4, 113066},
	{"BJOR", 4, 113067},
	{"FYODOR", 6, 113068},
	{"GEER", 4, 113069},
	{"LEVITES", 7, 113070},
	{"MAUSER", 6, 113071},
	{"KIDSLINE", 8, 113072},
	{"PERSONALISATION", 15, 113073},
	{"MCGARRY", 7, 113074},
	{"RACKETEERING", 12, 113075},
	{"CHRISTUS", 8, 113076},
	{"UDAY", 4, 113077},
	{"BILLERICAY", 10, 113078},
	{"CLUJ", 4, 113079},
	{"QUANTICO", 8, 113080},
	{"YSEW", 4, 113081},
	{"XREP", 4, 113082},
	{"SKLI", 4, 113083},
	{"RBBC", 4, 113084},
	{"KGAN", 4, 113085},
	{"HDIP", 4, 113086},
	{"TECHNOMARINE", 12, 113087},
	{"GENERALIZING", 12, 113088},
	{"SHEARED", 7, 113089},
	{"CUDNA", 5, 113090},
	{"BLASPHEMOUS", 11, 113091},
	{"STATUTORILY", 11, 113092},
	{"UNAIDED", 7, 113093},
	{"GABBERY", 7, 113094},
	{"STRINGBUFFER", 12, 113095},
	{"PARTICU", 7, 113096},
	{"CANDIDATURE", 11, 113097},
	{"MITEL", 5, 113098},
	{"UBBFRIEND", 9, 113099},
	{"JARI", 4, 113100},
	{"BLADED", 6, 113101},
	{"BAILED", 6, 113102},
	{"ARKANOID", 8, 113103},
	{"OUZA", 4, 113104},
	{"OFCB", 4, 113105},
	{"NDIZ", 4, 113106},
	{"LFDU", 4, 113107},
	{"KTYP", 4, 113108},
	{"IXTR", 4, 113109},
	{"IGSF", 4, 113110},
	{"CURRIED", 7, 113111},
	{"GAMEPADS", 8, 113112},
	{"CLAPPED", 7, 113113},
	{"PROGESTIN", 9, 113114},
	{"EVOLUTIONISTS", 13, 113115},
	{"VIRUSWALL", 9, 113116},
	{"WENDEL", 6, 113117},
	{"VERIO", 5, 113118},
	{"FTIR", 4, 113119},
	{"HOTKEYS", 7, 113120},
	{"SQUISHY", 7, 113121},
	{"GOODREM", 7, 113122},
	{"UNFORTUNATLY", 12, 113123},
	{"RVIK", 4, 113124},
	{"OBYM", 4, 113125},
	{"KARB", 4, 113126},
	{"IOFC", 4, 113127},
	{"IIBU", 4, 113128},
	{"HORV", 4, 113129},
	{"GYGR", 4, 113130},
	{"DGEK", 4, 113131},
	{"CSPH", 4, 113132},
	{"APGR", 4, 113133},
	{"KRAEMER", 7, 113134},
	{"HIGASHI", 7, 113135},
	{"BEAVERCREEK", 11, 113136},
	{"JETRO", 5, 113137},
	{"COOKSON", 7, 113138},
	{"GREENIES", 8, 113139},
	{"MAXIMIZER", 9, 113140},
	{"SMOKEFREE", 9, 113141},
	{"BLOCKAGES", 9, 113142},
	{"GOGLE", 5, 113143},
	{"BOGGLE", 6, 113144},
	{"FATHERLAND", 10, 113145},
	{"GUTSHOT", 7, 113146},
	{"WNSQ", 4, 113147},
	{"LSWR", 4, 113148},
	{"KYTR", 4, 113149},
	{"FACQ", 4, 113150},
	{"PARASAILING", 11, 113151},
	{"ADVANTECH", 9, 113152},
	{"FFY", 3, 113153},
	{"EVERGREENS", 10, 113154},
	{"MYASTHENIA", 10, 113155},
	{"EXUDES", 6, 113156},
	{"MINOAN", 6, 113157},
	{"FLAVIO", 6, 113158},
	{"RECEDE", 6, 113159},
	{"TEXTPROC", 8, 113160},
	{"BUZZARDS", 8, 113161},
	{"BREMNER", 7, 113162},
	{"SONESTA", 7, 113163},
	{"TORSIONAL", 9, 113164},
	{"PAKS", 4, 113165},
	{"ORPINGTON", 9, 113166},
	{"DEARS", 5, 113167},
	{"FINGERHUT", 9, 113168},
	{"SHAMANS", 7, 113169},
	{"INTREST", 7, 113170},
	{"VALENZUELA", 10, 113171},
	{"XDED", 4, 113172},
	{"PYBE", 4, 113173},
	{"OGPA", 4, 113174},
	{"MIAW", 4, 113175},
	{"IMSK", 4, 113176},
	{"GYLI", 4, 113177},
	{"FBIB", 4, 113178},
	{"ENYP", 4, 113179},
	{"EDSV", 4, 113180},
	{"SWANKY", 6, 113181},
	{"FINNAIR", 7, 113182},
	{"PANTOTHENIC", 11, 113183},
	{"LEGGI", 5, 113184},
	{"XSCREENSAVER", 12, 113185},
	{"ANSARI", 6, 113186},
	{"WILLKOMMEN", 10, 113187},
	{"MARXISTS", 8, 113188},
	{"STEROL", 6, 113189},
	{"SMOCKED", 7, 113190},
	{"DEGENERES", 9, 113191},
	{"LAVACA", 6, 113192},
	{"RUL", 3, 113193},
	{"TAFOYA", 6, 113194},
	{"CPX", 3, 113195},
	{"MASTERFULLY", 11, 113196},
	{"LAIDLAW", 7, 113197},
	{"XTFA", 4, 113198},
	{"RSEK", 4, 113199},
	{"OFZH", 4, 113200},
	{"IKIM", 4, 113201},
	{"PENUMBRA", 8, 113202},
	{"BACKYARDS", 9, 113203},
	{"SPRY", 4, 113204},
	{"OBJETS", 6, 113205},
	{"FAULTED", 7, 113206},
	{"MASTIC", 6, 113207},
	{"SPERMATOZOA", 11, 113208},
	{"MIEMBROS", 8, 113209},
	{"MAGGOTS", 7, 113210},
	{"IMLIB", 5, 113211},
	{"BONGOS", 6, 113212},
	{"BATHORY", 7, 113213},
	{"TOKINA", 6, 113214},
	{"JSPS", 4, 113215},
	{"ANTITUMOR", 9, 113216},
	{"CALOR", 5, 113217},
	{"MECHANICSVILLE", 14, 113218},
	{"LINDAS", 6, 113219},
	{"HOMINEM", 7, 113220},
	{"GENITOURINARY", 13, 113221},
	{"WAVER", 5, 113222},
	{"UDEY", 4, 113223},
	{"OOPY", 4, 113224},
	{"MKAT", 4, 113225},
	{"MAAB", 4, 113226},
	{"EMPF", 4, 113227},
	{"CDCO", 4, 113228},
	{"HANDKERCHIEFS", 13, 113229},
	{"TRACHTENBERG", 12, 113230},
	{"CANING", 6, 113231},
	{"PATHNAMES", 9, 113232},
	{"SNAGGED", 7, 113233},
	{"PUNISHES", 8, 113234},
	{"TRIFECTA", 8, 113235},
	{"INCISIONS", 9, 113236},
	{"BARBOSA", 7, 113237},
	{"CONNEMARA", 9, 113238},
	{"SALUT", 5, 113239},
	{"PROACH", 6, 113240},
	{"CARBOXYLASE", 11, 113241},
	{"ASHAMPOO", 8, 113242},
	{"XENOS", 5, 113243},
	{"DECENNIAL", 9, 113244},
	{"LORCET", 6, 113245},
	{"DOCENT", 6, 113246},
	{"UYSR", 4, 113247},
	{"REVW", 4, 113248},
	{"LEEJ", 4, 113249},
	{"EPEM", 4, 113250},
	{"ENUB", 4, 113251},
	{"DTOX", 4, 113252},
	{"AUTOLOGIN", 9, 113253},
	{"DISCIPLINING", 12, 113254},
	{"HERBALIST", 9, 113255},
	{"SHARKY", 6, 113256},
	{"WRITTING", 8, 113257},
	{"GRASSO", 6, 113258},
	{"SUBROGATION", 11, 113259},
	{"EARLEY", 6, 113260},
	{"ACQUIESCENCE", 12, 113261},
	{"MICRONET", 8, 113262},
	{"DISAFFECTED", 11, 113263},
	{"TOTAAL", 6, 113264},
	{"ANTICOAGULANTS", 14, 113265},
	{"PEROXIDATION", 12, 113266},
	{"YTHW", 4, 113267},
	{"OFXI", 4, 113268},
	{"JOYR", 4, 113269},
	{"HPAK", 4, 113270},
	{"GKEP", 4, 113271},
	{"FSKE", 4, 113272},
	{"EBJP", 4, 113273},
	{"BISL", 4, 113274},
	{"BIOR", 4, 113275},
	{"LAROUCHE", 8, 113276},
	{"MITOCHONDRION", 13, 113277},
	{"FORENAME", 8, 113278},
	{"CONIC", 5, 113279},
	{"CHARLATANS", 10, 113280},
	{"CUSTOMISABLE", 12, 113281},
	{"THIBAULT", 8, 113282},
	{"BEXHILL", 7, 113283},
	{"NEOLIBERAL", 10, 113284},
	{"HOCKLEY", 7, 113285},
	{"BARES", 5, 113286},
	{"MANORS", 6, 113287},
	{"CHRONICLED", 10, 113288},
	{"PHILVERNEY", 10, 113289},
	{"RAAB", 4, 113290},
	{"LAPIDARY", 8, 113291},
	{"STRUM", 5, 113292},
	{"LAURE", 5, 113293},
	{"VAGR", 4, 113294},
	{"PGAS", 4, 113295},
	{"COEU", 4, 113296},
	{"COEM", 4, 113297},
	{"HENRIQUE", 8, 113298},
	{"INUNDATION", 10, 113299},
	{"RESISTANCES", 11, 113300},
	{"RAPPAPORT", 9, 113301},
	{"MUFFDIVED", 9, 113302},
	{"EHEALTH", 7, 113303},
	{"SIGEL", 5, 113304},
	{"EAMONN", 6, 113305},
	{"TERED", 5, 113306},
	{"CARAWAY", 7, 113307},
	{"WEIDNER", 7, 113308},
	{"BRB", 3, 113309},
	{"CURATORIAL", 10, 113310},
	{"EARSHOT", 7, 113311},
	{"VYYA", 4, 113312},
	{"USBP", 4, 113313},
	{"SCHF", 4, 113314},
	{"RKEH", 4, 113315},
	{"IRUM", 4, 113316},
	{"GUSP", 4, 113317},
	{"DSYD", 4, 113318},
	{"CDPT", 4, 113319},
	{"OMENS", 5, 113320},
	{"PHYSIOLOGICALLY", 15, 113321},
	{"EICON", 5, 113322},
	{"SUBLICENSE", 10, 113323},
	{"RCF", 3, 113324},
	{"CHANGI", 6, 113325},
	{"PAGESPLUS", 9, 113326},
	{"SAILER", 6, 113327},
	{"RHEUM", 5, 113328},
	{"RELIENT", 7, 113329},
	{"VANES", 5, 113330},
	{"ALADIN", 6, 113331},
	{"ALLERTON", 8, 113332},
	{"PURINA", 6, 113333},
	{"YARIS", 5, 113334},
	{"HATTORI", 7, 113335},
	{"JINTAO", 6, 113336},
	{"OZAWA", 5, 113337},
	{"TYTY", 4, 113338},
	{"OKVI", 4, 113339},
	{"IRWR", 4, 113340},
	{"HYBY", 4, 113341},
	{"EBUE", 4, 113342},
	{"DJUT", 4, 113343},
	{"BATSMEN", 7, 113344},
	{"TRYED", 5, 113345},
	{"APPALOOSA", 9, 113346},
	{"TRACKBALLS", 10, 113347},
	{"REGEDIT", 7, 113348},
	{"MULTIVERSE", 10, 113349},
	{"FROU", 4, 113350},
	{"SIMSBURY", 8, 113351},
	{"LOMBARDIA", 9, 113352},
	{"TURBOS", 6, 113353},
	{"UCHIDA", 6, 113354},
	{"SMOOT", 5, 113355},
	{"RECIEVERS", 9, 113356},
	{"BRULE", 5, 113357},
	{"ZPLA", 4, 113358},
	{"NUGE", 4, 113359},
	{"MRYA", 4, 113360},
	{"LELD", 4, 113361},
	{"DMOI", 4, 113362},
	{"ACAK", 4, 113363},
	{"EIGHTS", 6, 113364},
	{"EFFERVESCENT", 12, 113365},
	{"TELECONFERENCES", 15, 113366},
	{"SAPPY", 5, 113367},
	{"EWALD", 5, 113368},
	{"HOLYHEAD", 8, 113369},
	{"WIDNES", 6, 113370},
	{"TRANSFIGURATION", 15, 113371},
	{"GIVIN", 5, 113372},
	{"SKIMMERS", 8, 113373},
	{"YSSL", 4, 113374},
	{"UPIM", 4, 113375},
	{"RDUL", 4, 113376},
	{"KHOP", 4, 113377},
	{"HOUC", 4, 113378},
	{"GSRU", 4, 113379},
	{"DAGN", 4, 113380},
	{"FERRITIN", 8, 113381},
	{"CITYPOST", 8, 113382},
	{"BLUESTONE", 9, 113383},
	{"SANDOR", 6, 113384},
	{"GEOGRAPH", 8, 113385},
	{"ALJAZEERA", 9, 113386},
	{"MEDIASPAN", 9, 113387},
	{"PUNCTURED", 9, 113388},
	{"COUGHED", 7, 113389},
	{"INVESTIGATORY", 13, 113390},
	{"REDUCTIVE", 9, 113391},
	{"RAYNOR", 6, 113392},
	{"REASSEMBLY", 10, 113393},
	{"LEFTMOST", 8, 113394},
	{"REPAYING", 8, 113395},
	{"REFORMA", 7, 113396},
	{"FILIAL", 6, 113397},
	{"XINJ", 4, 113398},
	{"SILB", 4, 113399},
	{"NPAB", 4, 113400},
	{"GARK", 4, 113401},
	{"EGEK", 4, 113402},
	{"CKOS", 4, 113403},
	{"AKIB", 4, 113404},
	{"PAVLOV", 6, 113405},
	{"WILFORD", 7, 113406},
	{"UEDA", 4, 113407},
	{"HELIPORT", 8, 113408},
	{"DAIL", 4, 113409},
	{"PROGSOC", 7, 113410},
	{"CARILLON", 8, 113411},
	{"HYDRANTS", 8, 113412},
	{"EQUA", 4, 113413},
	{"BERGMAIER", 9, 113414},
	{"STREAKING", 9, 113415},
	{"CENEDLAETHOL", 12, 113416},
	{"MOCKS", 5, 113417},
	{"FASTCGI", 7, 113418},
	{"ELDAR", 5, 113419},
	{"FREEDONIA", 9, 113420},
	{"TSUY", 4, 113421},
	{"TPMJ", 4, 113422},
	{"TMCN", 4, 113423},
	{"GGAP", 4, 113424},
	{"CEOD", 4, 113425},
	{"PALLADIO", 8, 113426},
	{"MAPPE", 5, 113427},
	{"JREF", 4, 113428},
	{"THIAMIN", 7, 113429},
	{"PRONOUNCEMENT", 13, 113430},
	{"REFRAINED", 9, 113431},
	{"TUGBOAT", 7, 113432},
	{"MINATO", 6, 113433},
	{"FARMSTAY", 8, 113434},
	{"MULRONEY", 8, 113435},
	{"WALLCOVERINGS", 13, 113436},
	{"UNIVISION", 9, 113437},
	{"CLONEDVD", 8, 113438},
	{"FATMAN", 6, 113439},
	{"HYTHE", 5, 113440},
	{"JOZEF", 5, 113441},
	{"VRC", 3, 113442},
	{"VALMONT", 7, 113443},
	{"PROCS", 5, 113444},
	{"BORAGE", 6, 113445},
	{"SLEWING", 7, 113446},
	{"PHENTERMINEFAST", 15, 113447},
	{"UARO", 4, 113448},
	{"RDAA", 4, 113449},
	{"OLCU", 4, 113450},
	{"MBYW", 4, 113451},
	{"KSKE", 4, 113452},
	{"IEGF", 4, 113453},
	{"GYPL", 4, 113454},
	{"DPOD", 4, 113455},
	{"DOMG", 4, 113456},
	{"AXLI", 4, 113457},
	{"DEANERY", 7, 113458},
	{"SETZER", 6, 113459},
	{"COLUMBIANA", 10, 113460},
	{"KIBBUTZ", 7, 113461},
	{"EQUALIZED", 9, 113462},
	{"SHALLOWER", 9, 113463},
	{"CORTISONE", 9, 113464},
	{"DURER", 5, 113465},
	{"PATRIARCHS", 10, 113466},
	{"MEGADRIVE", 9, 113467},
	{"POLYCYCLIC", 10, 113468},
	{"SUBSPACES", 9, 113469},
	{"GILFORD", 7, 113470},
	{"DORON", 5, 113471},
	{"GRANDKIDS", 9, 113472},
	{"UYLE", 4, 113473},
	{"UVEM", 4, 113474},
	{"UOLO", 4, 113475},
	{"NUPM", 4, 113476},
	{"NDCP", 4, 113477},
	{"MRBI", 4, 113478},
	{"IRKU", 4, 113479},
	{"GAKN", 4, 113480},
	{"REGNUM", 6, 113481},
	{"STUYVESANT", 10, 113482},
	{"BEDWETTING", 10, 113483},
	{"MATTOON", 7, 113484},
	{"VERTPOS", 7, 113485},
	{"REGISTERSIGN", 12, 113486},
	{"MIDRASH", 7, 113487},
	{"HUSAIN", 6, 113488},
	{"DROITWICH", 9, 113489},
	{"NATTY", 5, 113490},
	{"CONTEMP", 7, 113491},
	{"HISTORIAS", 9, 113492},
	{"KARLOVY", 7, 113493},
	{"LITTMANN", 8, 113494},
	{"CONTRALATERAL", 13, 113495},
	{"OBYC", 4, 113496},
	{"JONC", 4, 113497},
	{"EBTL", 4, 113498},
	{"AKAZ", 4, 113499},
	{"RESPECTABILITY", 14, 113500},
	{"ATARIS", 6, 113501},
	{"TOPP", 4, 113502},
	{"KOLN", 4, 113503},
	{"NEWB", 4, 113504},
	{"FARS", 4, 113505},
	{"COMMODE", 7, 113506},
	{"PADA", 4, 113507},
	{"KILLAH", 6, 113508},
	{"MASTA", 5, 113509},
	{"POSERS", 6, 113510},
	{"HEDLAND", 7, 113511},
	{"RADIOMETRIC", 11, 113512},
	{"SNEAKS", 6, 113513},
	{"WNSG", 4, 113514},
	{"SJAV", 4, 113515},
	{"OPVI", 4, 113516},
	{"OVEREATING", 10, 113517},
	{"OVERBEARING", 11, 113518},
	{"ASPIDISTRA", 10, 113519},
	{"FOTOTHING", 9, 113520},
	{"INCLUDINGTOPIC", 14, 113521},
	{"TOWNSPEOPLE", 11, 113522},
	{"CUBANO", 6, 113523},
	{"ADORING", 7, 113524},
	{"TRODDEN", 7, 113525},
	{"ATHEROSCLEROTIC", 15, 113526},
	{"COWGIRLS", 8, 113527},
	{"ADMINISTRATED", 13, 113528},
	{"YWIP", 4, 113529},
	{"XUNI", 4, 113530},
	{"XEDH", 4, 113531},
	{"TECC", 4, 113532},
	{"SUPU", 4, 113533},
	{"RSYD", 4, 113534},
	{"PPFO", 4, 113535},
	{"NOBB", 4, 113536},
	{"MCIV", 4, 113537},
	{"IIMP", 4, 113538},
	{"GADH", 4, 113539},
	{"AVLO", 4, 113540},
	{"HIDEO", 5, 113541},
	{"HUSKERS", 7, 113542},
	{"DECOUPLED", 9, 113543},
	{"SITEBUILDER", 11, 113544},
	{"REFERENDA", 9, 113545},
	{"DUNAWAY", 7, 113546},
	{"VENTILATORS", 11, 113547},
	{"ICONE", 5, 113548},
	{"STOCKPILING", 11, 113549},
	{"ZOOMIN", 6, 113550},
	{"SOUNDSTAGE", 10, 113551},
	{"TEALIGHT", 8, 113552},
	{"ESOURCES", 8, 113553},
	{"DEBITED", 7, 113554},
	{"DIKTAT", 6, 113555},
	{"REAPED", 6, 113556},
	{"AHAVA", 5, 113557},
	{"DESKPRO", 7, 113558},
	{"BEQUEATHED", 10, 113559},
	{"EXPL", 4, 113560},
	{"COLORMAP", 8, 113561},
	{"HIGHFIELD", 9, 113562},
	{"PINKO", 5, 113563},
	{"GRUMBLING", 9, 113564},
	{"STRATHCONA", 10, 113565},
	{"VABE", 4, 113566},
	{"UPUR", 4, 113567},
	{"UNSY", 4, 113568},
	{"SLAZ", 4, 113569},
	{"SDOP", 4, 113570},
	{"RMPH", 4, 113571},
	{"PEZW", 4, 113572},
	{"OGBE", 4, 113573},
	{"LFBL", 4, 113574},
	{"BMIN", 4, 113575},
	{"ADYQ", 4, 113576},
	{"FLATULENCE", 10, 113577},
	{"ELUDE", 5, 113578},
	{"GROK", 4, 113579},
	{"POPSICLE", 8, 113580},
	{"ONLINEWHERE", 11, 113581},
	{"FYDD", 4, 113582},
	{"DECENTLY", 8, 113583},
	{"AIRSTREAM", 9, 113584},
	{"CHAINSAWS", 9, 113585},
	{"METAPHORICALLY", 14, 113586},
	{"TRIPE", 5, 113587},
	{"CICADA", 6, 113588},
	{"SAGUARO", 7, 113589},
	{"CHLORIDES", 9, 113590},
	{"INDUSTRYBUSINESS", 16, 113591},
	{"KWANG", 5, 113592},
	{"RNTW", 4, 113593},
	{"PKEN", 4, 113594},
	{"NDLB", 4, 113595},
	{"INKK", 4, 113596},
	{"FINQ", 4, 113597},
	{"DAXI", 4, 113598},
	{"KDESDK", 6, 113599},
	{"GLITTERS", 8, 113600},
	{"HEADCOVER", 9, 113601},
	{"AHMET", 5, 113602},
	{"FARC", 4, 113603},
	{"AUSTERITY", 9, 113604},
	{"SHORTHAIR", 9, 113605},
	{"FALE", 4, 113606},
	{"AIDPAGE", 7, 113607},
	{"SPONDYLITIS", 11, 113608},
	{"SERVICESCHEMICAL", 16, 113609},
	{"KIKO", 4, 113610},
	{"CAPUTO", 6, 113611},
	{"MITTE", 5, 113612},
	{"GAULT", 5, 113613},
	{"DIDGERIDOO", 10, 113614},
	{"USIK", 4, 113615},
	{"UMIC", 4, 113616},
	{"UDMO", 4, 113617},
	{"LREU", 4, 113618},
	{"IKEQ", 4, 113619},
	{"HIPK", 4, 113620},
	{"GACQ", 4, 113621},
	{"BCOL", 4, 113622},
	{"WRIGHTSVILLE", 12, 113623},
	{"GAMESTAR", 8, 113624},
	{"AGRIBUSINESSIT", 14, 113625},
	{"CODETOP", 7, 113626},
	{"HICKSON", 7, 113627},
	{"WORKINGTON", 10, 113628},
	{"INFORME", 7, 113629},
	{"WEBMETHODS", 10, 113630},
	{"GARWOOD", 7, 113631},
	{"PEOPLETOP", 9, 113632},
	{"BONILLA", 7, 113633},
	{"ENJOIN", 6, 113634},
	{"DAZU", 4, 113635},
	{"COMPANIESTOP", 12, 113636},
	{"TRACBROWSER", 11, 113637},
	{"MONACOR", 7, 113638},
	{"GMF", 3, 113639},
	{"SELPHY", 6, 113640},
	{"BOYISH", 6, 113641},
	{"WHOTOWN", 7, 113642},
	{"CODECOUNTYTELEPHONE", 19, 113643},
	{"TAUF", 4, 113644},
	{"LPEZ", 4, 113645},
	{"KATG", 4, 113646},
	{"AQIF", 4, 113647},
	{"LANDCRUISER", 11, 113648},
	{"HALOPERIDOL", 11, 113649},
	{"COMPANYPRODUCTSWHO", 18, 113650},
	{"BECKS", 5, 113651},
	{"EGOTISTICAL", 11, 113652},
	{"NEARED", 6, 113653},
	{"DFP", 3, 113654},
	{"WIELAND", 7, 113655},
	{"COBRAS", 6, 113656},
	{"CLAES", 5, 113657},
	{"REAMING", 7, 113658},
	{"EUPHEMISM", 9, 113659},
	{"YMUM", 4, 113660},
	{"SJAW", 4, 113661},
	{"POPB", 4, 113662},
	{"OUVR", 4, 113663},
	{"ORUC", 4, 113664},
	{"OKMU", 4, 113665},
	{"NBAM", 4, 113666},
	{"IGHK", 4, 113667},
	{"GTHP", 4, 113668},
	{"BYRY", 4, 113669},
	{"DESHPANDE", 9, 113670},
	{"FOODSAVER", 9, 113671},
	{"ZGP", 3, 113672},
	{"VWJ", 3, 113673},
	{"KYX", 3, 113674},
	{"JZU", 3, 113675},
	{"GVX", 3, 113676},
	{"CVK", 3, 113677},
	{"RUSHDEN", 7, 113678},
	{"LEGALCONNECTION", 15, 113679},
	{"RECETTES", 8, 113680},
	{"ROSTOV", 6, 113681},
	{"LINDON", 6, 113682},
	{"NEUFELD", 7, 113683},
	{"SARAN", 5, 113684},
	{"SYNCHRONIZES", 12, 113685},
	{"NORTHCOTE", 9, 113686},
	{"DIVERGING", 9, 113687},
	{"PANKAJ", 6, 113688},
	{"BENTO", 5, 113689},
	{"BANTU", 5, 113690},
	{"BARRONS", 7, 113691},
	{"ESTOY", 5, 113692},
	{"BROMO", 5, 113693},
	{"BIPHENYLS", 9, 113694},
	{"TARDIS", 6, 113695},
	{"TEANECK", 7, 113696},
	{"DENCH", 5, 113697},
	{"MEGAPHONE", 9, 113698},
	{"FREEHELP", 8, 113699},
	{"UNINVITED", 9, 113700},
	{"MILFSEEKERS", 11, 113701},
	{"DASHA", 5, 113702},
	{"REPD", 4, 113703},
	{"OLRI", 4, 113704},
	{"GODK", 4, 113705},
	{"GMOL", 4, 113706},
	{"FTUE", 4, 113707},
	{"FEJU", 4, 113708},
	{"FAXA", 4, 113709},
	{"EWSV", 4, 113710},
	{"CYOP", 4, 113711},
	{"CTPH", 4, 113712},
	{"BUMG", 4, 113713},
	{"ACLY", 4, 113714},
	{"CANTALOUPE", 10, 113715},
	{"HALLANDALE", 10, 113716},
	{"POPU", 4, 113717},
	{"MICHELL", 7, 113718},
	{"AKONO", 5, 113719},
	{"NEUROENDOCRINE", 14, 113720},
	{"MCCOLL", 6, 113721},
	{"IRKUTSK", 7, 113722},
	{"GRANHOLM", 8, 113723},
	{"CARBURETORS", 11, 113724},
	{"SUMERIAN", 8, 113725},
	{"CARVERS", 7, 113726},
	{"UTSTARCOM", 9, 113727},
	{"ARCELOR", 7, 113728},
	{"COMATOSE", 8, 113729},
	{"LIVEN", 5, 113730},
	{"TRAPPERS", 8, 113731},
	{"HUYNH", 5, 113732},
	{"ANILINE", 7, 113733},
	{"PREDNISOLONE", 12, 113734},
	{"KLIPFOLIO", 9, 113735},
	{"LROV", 4, 113736},
	{"EFFP", 4, 113737},
	{"DFIC", 4, 113738},
	{"DAKS", 4, 113739},
	{"LATTA", 5, 113740},
	{"HYDROGRAPH", 10, 113741},
	{"ANDROGENS", 9, 113742},
	{"EXELON", 6, 113743},
	{"STEPAN", 6, 113744},
	{"GOHAN", 5, 113745},
	{"INCLUSIVENESS", 13, 113746},
	{"YEARWOOD", 8, 113747},
	{"WSWS", 4, 113748},
	{"NOTICABLE", 9, 113749},
	{"STABILISE", 9, 113750},
	{"DECODES", 7, 113751},
	{"MISPRINTS", 9, 113752},
	{"SPILT", 5, 113753},
	{"FORGETFUL", 9, 113754},
	{"CONCEDING", 9, 113755},
	{"XSCA", 4, 113756},
	{"XCHR", 4, 113757},
	{"SKAU", 4, 113758},
	{"RUMN", 4, 113759},
	{"OLTC", 4, 113760},
	{"DLID", 4, 113761},
	{"DDOF", 4, 113762},
	{"DDNA", 4, 113763},
	{"WAUPACA", 7, 113764},
	{"BRIGHTENED", 10, 113765},
	{"DOMO", 4, 113766},
	{"PRINCESA", 8, 113767},
	{"DUNKS", 5, 113768},
	{"INCONVENIENCES", 14, 113769},
	{"TRICYCLIC", 9, 113770},
	{"GRATER", 6, 113771},
	{"MAUN", 4, 113772},
	{"RTCW", 4, 113773},
	{"HYDROGEOLOGY", 12, 113774},
	{"PEYOTE", 6, 113775},
	{"SHADOWRUN", 9, 113776},
	{"OESTROGEN", 9, 113777},
	{"GYRATION", 8, 113778},
	{"KIPLINGER", 9, 113779},
	{"CAESAREAN", 9, 113780},
	{"ALDERNEY", 8, 113781},
	{"FINDLEY", 7, 113782},
	{"SUNPENTOWN", 10, 113783},
	{"SIGOURNEY", 9, 113784},
	{"SEIDMAN", 7, 113785},
	{"FUROSEMIDE", 10, 113786},
	{"SDLC", 4, 113787},
	{"WALW", 4, 113788},
	{"VAAR", 4, 113789},
	{"PABE", 4, 113790},
	{"NTMP", 4, 113791},
	{"HBYD", 4, 113792},
	{"FTVA", 4, 113793},
	{"CIWA", 4, 113794},
	{"BYEB", 4, 113795},
	{"AVUL", 4, 113796},
	{"ASYU", 4, 113797},
	{"SINDHI", 6, 113798},
	{"ANOREXIC", 8, 113799},
	{"HAYWORTH", 8, 113800},
	{"PROEDROS", 8, 113801},
	{"BUSHFIRE", 8, 113802},
	{"ACCOMM", 6, 113803},
	{"KRUTCH", 6, 113804},
	{"WELLA", 5, 113805},
	{"PATHFINDERS", 11, 113806},
	{"MORETTI", 7, 113807},
	{"LOQUAX", 6, 113808},
	{"RUGOVA", 6, 113809},
	{"DILTIAZEM", 9, 113810},
	{"REDLAND", 7, 113811},
	{"PHPWEBSITE", 10, 113812},
	{"RIGOUR", 6, 113813},
	{"TERJE", 5, 113814},
	{"YIMN", 4, 113815},
	{"OWEY", 4, 113816},
	{"MBAW", 4, 113817},
	{"LASQ", 4, 113818},
	{"DSTD", 4, 113819},
	{"RESHUFFLE", 9, 113820},
	{"POWERSEARCH", 11, 113821},
	{"DORFMAN", 7, 113822},
	{"TROMBONES", 9, 113823},
	{"INCONTRI", 8, 113824},
	{"DEWINE", 6, 113825},
	{"OXALATE", 7, 113826},
	{"POLONIA", 7, 113827},
	{"EVINCED", 7, 113828},
	{"JABS", 4, 113829},
	{"ARISTO", 6, 113830},
	{"ALITTLE", 7, 113831},
	{"IFEX", 4, 113832},
	{"VOSTOK", 6, 113833},
	{"OUJO", 4, 113834},
	{"LGIL", 4, 113835},
	{"ARPB", 4, 113836},
	{"AEKW", 4, 113837},
	{"SHAPEWEAR", 9, 113838},
	{"PHOTOGENIC", 10, 113839},
	{"NONFERROUS", 10, 113840},
	{"MIRAMICHI", 9, 113841},
	{"EGHAM", 5, 113842},
	{"RIEMANNIAN", 10, 113843},
	{"UNEASINESS", 10, 113844},
	{"VOEGELN", 7, 113845},
	{"CONFUSINGLY", 11, 113846},
	{"AFRESH", 6, 113847},
	{"GONDOR", 6, 113848},
	{"WSED", 4, 113849},
	{"WEPO", 4, 113850},
	{"TIMK", 4, 113851},
	{"NCFO", 4, 113852},
	{"MRTH", 4, 113853},
	{"LHAY", 4, 113854},
	{"IUDA", 4, 113855},
	{"HVEG", 4, 113856},
	{"HLEW", 4, 113857},
	{"BSCB", 4, 113858},
	{"AKAJ", 4, 113859},
	{"AIMC", 4, 113860},
	{"COLINAS", 7, 113861},
	{"CLIA", 4, 113862},
	{"HUBEI", 5, 113863},
	{"VISUM", 5, 113864},
	{"MEXICANO", 8, 113865},
	{"MAWSON", 6, 113866},
	{"FREESIA", 7, 113867},
	{"LIMEGREEN", 9, 113868},
	{"DOCKSIDE", 8, 113869},
	{"BGG", 3, 113870},
	{"BOURGET", 7, 113871},
	{"INNFEED", 7, 113872},
	{"MCCURDY", 7, 113873},
	{"CONDENSERS", 10, 113874},
	{"MUSKIE", 6, 113875},
	{"ROSSER", 6, 113876},
	{"XITW", 4, 113877},
	{"TFIC", 4, 113878},
	{"SRIM", 4, 113879},
	{"ROPM", 4, 113880},
	{"IMAU", 4, 113881},
	{"CIBE", 4, 113882},
	{"BOBF", 4, 113883},
	{"MANZANITA", 9, 113884},
	{"BUNKS", 5, 113885},
	{"ROYALL", 6, 113886},
	{"KLASSEN", 7, 113887},
	{"MAISEL", 6, 113888},
	{"SABC", 4, 113889},
	{"DUCKED", 6, 113890},
	{"THALAMUS", 8, 113891},
	{"JACOBOWITZ", 10, 113892},
	{"BILAL", 5, 113893},
	{"SITUATE", 7, 113894},
	{"HOMERUN", 7, 113895},
	{"DMEM", 4, 113896},
	{"BOOZ", 4, 113897},
	{"TOPICMOVED", 10, 113898},
	{"STEPPERS", 8, 113899},
	{"VACCINIA", 8, 113900},
	{"MASTERTON", 9, 113901},
	{"SOWIE", 5, 113902},
	{"FERIA", 5, 113903},
	{"OVOR", 4, 113904},
	{"MWEW", 4, 113905},
	{"HPAW", 4, 113906},
	{"HAMK", 4, 113907},
	{"GAKA", 4, 113908},
	{"ESCAPADE", 8, 113909},
	{"SCHWEDEN", 8, 113910},
	{"THIEME", 6, 113911},
	{"LOOMED", 6, 113912},
	{"XTRAS", 5, 113913},
	{"EGBERT", 6, 113914},
	{"SPACESHIPS", 10, 113915},
	{"THROTTLING", 10, 113916},
	{"HUNGARIANS", 10, 113917},
	{"MADRIGAL", 8, 113918},
	{"GIMIGNANO", 9, 113919},
	{"WITR", 4, 113920},
	{"SYVI", 4, 113921},
	{"RVLA", 4, 113922},
	{"PTSM", 4, 113923},
	{"PGOO", 4, 113924},
	{"MURC", 4, 113925},
	{"KNUM", 4, 113926},
	{"DYUP", 4, 113927},
	{"CLOI", 4, 113928},
	{"CLAMOR", 6, 113929},
	{"DEVISES", 7, 113930},
	{"MAILDIR", 7, 113931},
	{"BIOMEDICINE", 11, 113932},
	{"MFD", 3, 113933},
	{"ABDALLAH", 8, 113934},
	{"YOAKAM", 6, 113935},
	{"OPENFORUM", 9, 113936},
	{"SPEEDSTER", 9, 113937},
	{"PEAKE", 5, 113938},
	{"KULEUVEN", 8, 113939},
	{"PROBOARDS", 9, 113940},
	{"DITCHED", 7, 113941},
	{"HOMICIDAL", 9, 113942},
	{"COLOMA", 6, 113943},
	{"ROLO", 4, 113944},
	{"YIMS", 4, 113945},
	{"WDST", 4, 113946},
	{"RUGF", 4, 113947},
	{"LJET", 4, 113948},
	{"EVYS", 4, 113949},
	{"DRYU", 4, 113950},
	{"MESENTERIC", 10, 113951},
	{"EVAPOTRANSPIRATION", 18, 113952},
	{"SIGNPOST", 8, 113953},
	{"ROMANTIKDICKE", 13, 113954},
	{"SATURATE", 8, 113955},
	{"DYNE", 4, 113956},
	{"FERIENWOHNUNG", 13, 113957},
	{"AKZO", 4, 113958},
	{"TRENCHING", 9, 113959},
	{"UNSECURE", 8, 113960},
	{"BETREFF", 7, 113961},
	{"MCINTIRE", 8, 113962},
	{"BATTAGLIA", 9, 113963},
	{"FEDRA", 5, 113964},
	{"PEWS", 4, 113965},
	{"REDUCERS", 8, 113966},
	{"EASTPORT", 8, 113967},
	{"WORKHOUSE", 9, 113968},
	{"OVERSTREET", 10, 113969},
	{"JACUZZIS", 8, 113970},
	{"YTED", 4, 113971},
	{"VENQ", 4, 113972},
	{"TOMJ", 4, 113973},
	{"PGOL", 4, 113974},
	{"OLKR", 4, 113975},
	{"BSTU", 4, 113976},
	{"SENSITIVELY", 11, 113977},
	{"EUSKARA", 7, 113978},
	{"RESEDA", 6, 113979},
	{"STARTAC", 7, 113980},
	{"ORCHESTRE", 9, 113981},
	{"PEEVE", 5, 113982},
	{"PHDS", 4, 113983},
	{"STRATOVARIUS", 12, 113984},
	{"ADDERLEY", 8, 113985},
	{"KEITAI", 6, 113986},
	{"DETERRING", 9, 113987},
	{"XMEM", 4, 113988},
	{"NKYS", 4, 113989},
	{"MIRW", 4, 113990},
	{"METJ", 4, 113991},
	{"LDOH", 4, 113992},
	{"KDIV", 4, 113993},
	{"FTIL", 4, 113994},
	{"POLYHEDRON", 10, 113995},
	{"LNSL", 4, 113996},
	{"AFICIO", 6, 113997},
	{"MERRIMAC", 8, 113998},
	{"CONESTOGA", 9, 113999},
	{"BILLMON", 7, 114000},
	{"DISCHARGER", 10, 114001},
	{"POLIPUNDIT", 10, 114002},
	{"MYUNG", 5, 114003},
	{"HIDEKI", 6, 114004},
	{"GUTSY", 5, 114005},
	{"COMPE", 5, 114006},
	{"VIPPS", 5, 114007},
	{"BEEFHEART", 9, 114008},
	{"HANDBUCH", 8, 114009},
	{"GLUCOCORTICOIDS", 15, 114010},
	{"TRILLIONS", 9, 114011},
	{"GNUTLS", 6, 114012},
	{"WOJCIECHOWSKI", 13, 114013},
	{"WDTO", 4, 114014},
	{"RKOT", 4, 114015},
	{"LTDW", 4, 114016},
	{"DYSD", 4, 114017},
	{"BIGV", 4, 114018},
	{"NORTHAM", 7, 114019},
	{"MCCURRY", 7, 114020},
	{"ENERAL", 6, 114021},
	{"UNORGANIZED", 11, 114022},
	{"DISCRIMINATES", 13, 114023},
	{"CAMROSE", 7, 114024},
	{"MASTERFILE", 10, 114025},
	{"DIGABLE", 7, 114026},
	{"UKLUG", 5, 114027},
	{"WEILER", 6, 114028},
	{"PREINSTALLED", 12, 114029},
	{"IPOOL", 5, 114030},
	{"CAPEZIO", 7, 114031},
	{"ULU", 3, 114032},
	{"YEDY", 4, 114033},
	{"SCYB", 4, 114034},
	{"PURW", 4, 114035},
	{"OSYD", 4, 114036},
	{"LPLI", 4, 114037},
	{"GHUA", 4, 114038},
	{"FOGA", 4, 114039},
	{"EAPM", 4, 114040},
	{"WHALERS", 7, 114041},
	{"BPX", 3, 114042},
	{"PREDECEASED", 11, 114043},
	{"EDIRC", 5, 114044},
	{"WRESTER", 7, 114045},
	{"SMUGGLE", 7, 114046},
	{"CLUDE", 5, 114047},
	{"CABRAL", 6, 114048},
	{"GRIGIO", 6, 114049},
	{"CHATFIELD", 9, 114050},
	{"MUNN", 4, 114051},
	{"LABORING", 8, 114052},
	{"ANADROMOUS", 10, 114053},
	{"CONNEC", 6, 114054},
	{"NOOKS", 5, 114055},
	{"LRYM", 4, 114056},
	{"GDIP", 4, 114057},
	{"AYLU", 4, 114058},
	{"OSWESTRY", 8, 114059},
	{"CENTRALIZE", 10, 114060},
	{"ACCRUES", 7, 114061},
	{"ROADMAPS", 8, 114062},
	{"PROFIBUS", 8, 114063},
	{"AUTOCRATIC", 10, 114064},
	{"CFOS", 4, 114065},
	{"LKML", 4, 114066},
	{"SODEXHO", 7, 114067},
	{"GALLET", 6, 114068},
	{"TEENAGED", 8, 114069},
	{"RUTHIE", 6, 114070},
	{"HICCUP", 6, 114071},
	{"SELAH", 5, 114072},
	{"WEGNER", 6, 114073},
	{"RLLO", 4, 114074},
	{"NUXI", 4, 114075},
	{"GHAY", 4, 114076},
	{"BUYU", 4, 114077},
	{"BTOM", 4, 114078},
	{"TITANIA", 7, 114079},
	{"TABRIZ", 6, 114080},
	{"BRASOV", 6, 114081},
	{"PULSATILE", 9, 114082},
	{"SHANXI", 6, 114083},
	{"FLAVIN", 6, 114084},
	{"LEADVILLE", 9, 114085},
	{"INTERFACED", 10, 114086},
	{"AYNSLEY", 7, 114087},
	{"CONCEPCION", 10, 114088},
	{"OVERHEAT", 8, 114089},
	{"PLASMON", 7, 114090},
	{"PASCUAL", 7, 114091},
	{"ELLWOOD", 7, 114092},
	{"ALTERSKONTROLLE", 15, 114093},
	{"XOFM", 4, 114094},
	{"PYOR", 4, 114095},
	{"MLIE", 4, 114096},
	{"KMOO", 4, 114097},
	{"HSBY", 4, 114098},
	{"GAPW", 4, 114099},
	{"FLAF", 4, 114100},
	{"ENYM", 4, 114101},
	{"EBEB", 4, 114102},
	{"BRODER", 6, 114103},
	{"DOTMP", 5, 114104},
	{"MARCHI", 6, 114105},
	{"SPEAKUP", 7, 114106},
	{"OPTOMETRIC", 10, 114107},
	{"BLAQ", 4, 114108},
	{"NICKLES", 7, 114109},
	{"SHYLY", 5, 114110},
	{"SIMULCAST", 9, 114111},
	{"COUNTERCLAIM", 12, 114112},
	{"PARDO", 5, 114113},
	{"STEWED", 6, 114114},
	{"HYDRATES", 8, 114115},
	{"HASSELBECK", 10, 114116},
	{"WFEL", 4, 114117},
	{"USYM", 4, 114118},
	{"RIMN", 4, 114119},
	{"RDYW", 4, 114120},
	{"ORUA", 4, 114121},
	{"ILYY", 4, 114122},
	{"GATK", 4, 114123},
	{"EVRI", 4, 114124},
	{"CSGO", 4, 114125},
	{"WURLITZER", 9, 114126},
	{"TOPOISOMERASE", 13, 114127},
	{"FINGERNAIL", 10, 114128},
	{"SOFWARE", 7, 114129},
	{"MUSTO", 5, 114130},
	{"BARC", 4, 114131},
	{"AMERICANO", 9, 114132},
	{"IOANNIS", 7, 114133},
	{"RESTAURANTE", 11, 114134},
	{"ULTRAFAST", 9, 114135},
	{"SCONE", 5, 114136},
	{"PPAD", 4, 114137},
	{"NCTW", 4, 114138},
	{"LMHI", 4, 114139},
	{"KCUL", 4, 114140},
	{"GHIK", 4, 114141},
	{"EMLS", 4, 114142},
	{"AXEV", 4, 114143},
	{"AUDLEY", 6, 114144},
	{"JESSY", 5, 114145},
	{"BEGGS", 5, 114146},
	{"DISGUISES", 9, 114147},
	{"ANGSTROMS", 9, 114148},
	{"STOWED", 6, 114149},
	{"UNMANAGEABLE", 12, 114150},
	{"HORIZPOS", 8, 114151},
	{"BUSCADORES", 10, 114152},
	{"PIDGIN", 6, 114153},
	{"DENUNCIATION", 12, 114154},
	{"RACHMANINOV", 11, 114155},
	{"SQUEAL", 6, 114156},
	{"IREDELL", 7, 114157},
	{"MILENA", 6, 114158},
	{"TRIPLETT", 8, 114159},
	{"BRAE", 4, 114160},
	{"RDOH", 4, 114161},
	{"MPAW", 4, 114162},
	{"IFAV", 4, 114163},
	{"GHGI", 4, 114164},
	{"EWMY", 4, 114165},
	{"DNOK", 4, 114166},
	{"DUCKING", 7, 114167},
	{"FREIRE", 6, 114168},
	{"THROB", 5, 114169},
	{"DATEL", 5, 114170},
	{"FOLKSONOMY", 10, 114171},
	{"SCORCH", 6, 114172},
	{"SALAIRE", 7, 114173},
	{"CHAVS", 5, 114174},
	{"ROADKILL", 8, 114175},
	{"COMPRE", 6, 114176},
	{"MBD", 3, 114177},
	{"GOODBYES", 8, 114178},
	{"PERUSING", 8, 114179},
	{"GCSES", 5, 114180},
	{"ULL", 3, 114181},
	{"JARMAN", 6, 114182},
	{"FARID", 5, 114183},
	{"CLVERTALT", 9, 114184},
	{"ARION", 5, 114185},
	{"ARIBA", 5, 114186},
	{"DUELS", 5, 114187},
	{"RORK", 4, 114188},
	{"NXBO", 4, 114189},
	{"LZAG", 4, 114190},
	{"KPAL", 4, 114191},
	{"FMEI", 4, 114192},
	{"VILLAINOUS", 10, 114193},
	{"LIBXSLT", 7, 114194},
	{"REEXAMINATION", 13, 114195},
	{"MESOZOIC", 8, 114196},
	{"SANITIZING", 10, 114197},
	{"MASC", 4, 114198},
	{"CAIUS", 5, 114199},
	{"CELLIST", 7, 114200},
	{"LUKES", 5, 114201},
	{"PYTHAGOREAN", 11, 114202},
	{"GASPARI", 7, 114203},
	{"ANARCHO", 7, 114204},
	{"ELDERBERRY", 10, 114205},
	{"PARAMILITARIES", 14, 114206},
	{"MONTEIRO", 8, 114207},
	{"ZCOU", 4, 114208},
	{"WEYE", 4, 114209},
	{"UMBN", 4, 114210},
	{"SVAG", 4, 114211},
	{"SKCA", 4, 114212},
	{"SBPO", 4, 114213},
	{"PMAU", 4, 114214},
	{"LGIE", 4, 114215},
	{"IFTD", 4, 114216},
	{"HILP", 4, 114217},
	{"HFEM", 4, 114218},
	{"EKAV", 4, 114219},
	{"CITF", 4, 114220},
	{"AACL", 4, 114221},
	{"VEREIN", 6, 114222},
	{"ANGLICANS", 9, 114223},
	{"TUPPER", 6, 114224},
	{"TERRAZZO", 8, 114225},
	{"TRAINEESHIP", 11, 114226},
	{"STEADFASTLY", 11, 114227},
	{"SOUNDCRAFT", 10, 114228},
	{"HESHES", 6, 114229},
	{"INTERFERENCES", 13, 114230},
	{"BOOKBINDING", 11, 114231},
	{"VASHON", 6, 114232},
	{"IWATA", 5, 114233},
	{"ARCHE", 5, 114234},
	{"RUSTING", 7, 114235},
	{"SLICKER", 7, 114236},
	{"BRAZILLIAN", 10, 114237},
	{"ABSTENTION", 10, 114238},
	{"CABARRUS", 8, 114239},
	{"FOREN", 5, 114240},
	{"CONSERVATIONIST", 15, 114241},
	{"BANDWIDTHS", 10, 114242},
	{"UYAB", 4, 114243},
	{"ROYR", 4, 114244},
	{"RJAV", 4, 114245},
	{"OPIR", 4, 114246},
	{"NJUI", 4, 114247},
	{"GESQ", 4, 114248},
	{"BOLLING", 7, 114249},
	{"DININGGUIDE", 11, 114250},
	{"RECONVENED", 10, 114251},
	{"RADIATES", 8, 114252},
	{"DISJUNCTION", 11, 114253},
	{"SUBFOLDERS", 10, 114254},
	{"BANCSHARES", 10, 114255},
	{"LIFESAVER", 9, 114256},
	{"KENAN", 5, 114257},
	{"GENEALOGIES", 11, 114258},
	{"HEMMER", 6, 114259},
	{"RUTHLESSLY", 10, 114260},
	{"INTERNALIZATION", 15, 114261},
	{"CYD", 3, 114262},
	{"WHITFORD", 8, 114263},
	{"YKAL", 4, 114264},
	{"UOKA", 4, 114265},
	{"SKIJ", 4, 114266},
	{"LMYE", 4, 114267},
	{"HWBU", 4, 114268},
	{"WESTONS", 7, 114269},
	{"TORNA", 5, 114270},
	{"CHAMBLEE", 8, 114271},
	{"LOVELOCK", 8, 114272},
	{"FALSIFY", 7, 114273},
	{"RATIFYING", 9, 114274},
	{"HOMESTAR", 8, 114275},
	{"PETMEDS", 7, 114276},
	{"KALAM", 5, 114277},
	{"SWAGGER", 7, 114278},
	{"PRESERVICE", 10, 114279},
	{"RCB", 3, 114280},
	{"FLICKED", 7, 114281},
	{"MMG", 3, 114282},
	{"WINDJAMMER", 10, 114283},
	{"VOLTMETER", 9, 114284},
	{"ANDRUS", 6, 114285},
	{"EMIGRATE", 8, 114286},
	{"WGER", 4, 114287},
	{"UFTS", 4, 114288},
	{"SMCN", 4, 114289},
	{"RDEU", 4, 114290},
	{"OPBI", 4, 114291},
	{"MUBA", 4, 114292},
	{"HUYL", 4, 114293},
	{"HOBJ", 4, 114294},
	{"HOUSEPLANTS", 11, 114295},
	{"ALLELUIA", 8, 114296},
	{"HOMEOBOX", 8, 114297},
	{"FARMWORKERS", 11, 114298},
	{"WFMU", 4, 114299},
	{"ARBOUR", 6, 114300},
	{"MEETIC", 6, 114301},
	{"QPR", 3, 114302},
	{"TECHNOLOG", 9, 114303},
	{"BLYTON", 6, 114304},
	{"SYNTACTICALLY", 13, 114305},
	{"ACCOMPLICES", 11, 114306},
	{"MARIHUANA", 9, 114307},
	{"SIMONSON", 8, 114308},
	{"HADRONS", 7, 114309},
	{"BACKTRACE", 9, 114310},
	{"HELLCAT", 7, 114311},
	{"HARRIETT", 8, 114312},
	{"SHIMS", 5, 114313},
	{"YKAY", 4, 114314},
	{"SPEG", 4, 114315},
	{"RWEM", 4, 114316},
	{"NUXD", 4, 114317},
	{"EYDS", 4, 114318},
	{"EXSY", 4, 114319},
	{"ERVICE", 6, 114320},
	{"GLASSER", 7, 114321},
	{"LEISUREWEAR", 11, 114322},
	{"FECT", 4, 114323},
	{"JUMEIRAH", 8, 114324},
	{"CHEETAHS", 8, 114325},
	{"YITZHAK", 7, 114326},
	{"COALPORT", 8, 114327},
	{"STRUCTS", 7, 114328},
	{"TIALLY", 6, 114329},
	{"ESRD", 4, 114330},
	{"GOLDIN", 6, 114331},
	{"DOAJ", 4, 114332},
	{"AROOSTOOK", 9, 114333},
	{"ZZFE", 4, 114334},
	{"YVIT", 4, 114335},
	{"ORWU", 4, 114336},
	{"NKJO", 4, 114337},
	{"IPCR", 4, 114338},
	{"GDUN", 4, 114339},
	{"FFDR", 4, 114340},
	{"EAPW", 4, 114341},
	{"MARKETABILITY", 13, 114342},
	{"DEADLOCKED", 10, 114343},
	{"MAMI", 4, 114344},
	{"TAKAMINE", 8, 114345},
	{"NONPROPRIETARY", 14, 114346},
	{"SUBTOPICS", 9, 114347},
	{"MEACHAM", 7, 114348},
	{"EMBA", 4, 114349},
	{"PEARSE", 6, 114350},
	{"WESTFALL", 8, 114351},
	{"MONOCYTE", 8, 114352},
	{"MANDREL", 7, 114353},
	{"MOVIEWEB", 8, 114354},
	{"ESTEVAN", 7, 114355},
	{"ADEMA", 5, 114356},
	{"COLWYN", 6, 114357},
	{"ROARK", 5, 114358},
	{"SOLIDIFICATION", 14, 114359},
	{"ESPNEWS", 7, 114360},
	{"VALINE", 6, 114361},
	{"REDNECKS", 8, 114362},
	{"APPLECARE", 9, 114363},
	{"ZWOU", 4, 114364},
	{"WWET", 4, 114365},
	{"WOAM", 4, 114366},
	{"SVIB", 4, 114367},
	{"SIFM", 4, 114368},
	{"FRHO", 4, 114369},
	{"ERRM", 4, 114370},
	{"KWBC", 4, 114371},
	{"BIOGEOCHEMICAL", 14, 114372},
	{"SCOPATA", 7, 114373},
	{"CLOUTIER", 8, 114374},
	{"OURMEDIA", 8, 114375},
	{"BRENHAM", 7, 114376},
	{"BOOKWORMINUSALL", 15, 114377},
	{"ACTINIC", 7, 114378},
	{"ORFF", 4, 114379},
	{"RECOMPILED", 10, 114380},
	{"PROMETHAZINE", 12, 114381},
	{"BECASUE", 7, 114382},
	{"BAMFORD", 7, 114383},
	{"CONSHOHOCKEN", 12, 114384},
	{"GEBRAUCHT", 9, 114385},
	{"YADS", 4, 114386},
	{"RGGE", 4, 114387},
	{"OMUM", 4, 114388},
	{"KEOL", 4, 114389},
	{"HMRS", 4, 114390},
	{"GRUF", 4, 114391},
	{"FEWQ", 4, 114392},
	{"FEJO", 4, 114393},
	{"FDNA", 4, 114394},
	{"EZDI", 4, 114395},
	{"DOBI", 4, 114396},
	{"MANIPULATORS", 12, 114397},
	{"EROTISMO", 8, 114398},
	{"VOLLMER", 7, 114399},
	{"TELLIN", 6, 114400},
	{"TOOTHLESS", 9, 114401},
	{"BUCURESTI", 9, 114402},
	{"RABBINICAL", 10, 114403},
	{"SPELLCHECK", 10, 114404},
	{"PRENTISS", 8, 114405},
	{"KENTWOOD", 8, 114406},
	{"OFFLOAD", 7, 114407},
	{"FRANKINCENSE", 12, 114408},
	{"VAPR", 4, 114409},
	{"RPAV", 4, 114410},
	{"RARB", 4, 114411},
	{"PMDE", 4, 114412},
	{"GOEV", 4, 114413},
	{"BUGL", 4, 114414},
	{"CREOSOTE", 8, 114415},
	{"CLOAKROOM", 9, 114416},
	{"COMMENDATIONS", 13, 114417},
	{"COMPREHENDED", 12, 114418},
	{"TEXTURAL", 8, 114419},
	{"PONCHOS", 7, 114420},
	{"TAGUNGSDICKE", 12, 114421},
	{"DETOURS", 7, 114422},
	{"NANYANG", 7, 114423},
	{"PINGBACK", 8, 114424},
	{"ABOUTUS", 7, 114425},
	{"NANNOFOSSILS", 12, 114426},
	{"DARKHAIRED", 10, 114427},
	{"PEPS", 4, 114428},
	{"BRIGHTSIDE", 10, 114429},
	{"BRAVEST", 7, 114430},
	{"WHEM", 4, 114431},
	{"MIDH", 4, 114432},
	{"PAIGOW", 6, 114433},
	{"MAINWEB", 7, 114434},
	{"BLAKES", 6, 114435},
	{"MUMBO", 5, 114436},
	{"CREVICE", 7, 114437},
	{"PAGEPRINT", 9, 114438},
	{"FIRSTSEARCH", 11, 114439},
	{"AVAILIBILITY", 12, 114440},
	{"POINDEXTER", 10, 114441},
	{"WAITLIST", 8, 114442},
	{"RUNDGREN", 8, 114443},
	{"MILER", 5, 114444},
	{"STAPP", 5, 114445},
	{"RLG", 3, 114446},
	{"GUNPOINT", 8, 114447},
	{"BOUDREAU", 8, 114448},
	{"PAPEL", 5, 114449},
	{"DIMERS", 6, 114450},
	{"AIRNAV", 6, 114451},
	{"PCAU", 4, 114452},
	{"OIRC", 4, 114453},
	{"NYIL", 4, 114454},
	{"NDBB", 4, 114455},
	{"KIJU", 4, 114456},
	{"EGPL", 4, 114457},
	{"ARCW", 4, 114458},
	{"ANKK", 4, 114459},
	{"ADDP", 4, 114460},
	{"FACOG", 5, 114461},
	{"BIOGENIC", 8, 114462},
	{"SKEINS", 6, 114463},
	{"HAUER", 5, 114464},
	{"ZKF", 3, 114465},
	{"YFV", 3, 114466},
	{"XWY", 3, 114467},
	{"XRG", 3, 114468},
	{"WFK", 3, 114469},
	{"QUX", 3, 114470},
	{"DQQ", 3, 114471},
	{"GROWNUPS", 8, 114472},
	{"TELLTALE", 8, 114473},
	{"MOSKVA", 6, 114474},
	{"EVICT", 5, 114475},
	{"NORIEGA", 7, 114476},
	{"SEMPLE", 6, 114477},
	{"FPUTS", 5, 114478},
	{"TYPEWRITTEN", 11, 114479},
	{"FDNY", 4, 114480},
	{"NEGEV", 5, 114481},
	{"ZEMI", 4, 114482},
	{"RAHD", 4, 114483},
	{"MJAI", 4, 114484},
	{"MIDB", 4, 114485},
	{"LGIB", 4, 114486},
	{"HEKG", 4, 114487},
	{"GHEG", 4, 114488},
	{"DIMH", 4, 114489},
	{"DARV", 4, 114490},
	{"ARDZ", 4, 114491},
	{"INCREDIMAIL", 11, 114492},
	{"PROGENITORS", 11, 114493},
	{"VITTADINI", 9, 114494},
	{"MCONSTANT", 9, 114495},
	{"VITORIA", 7, 114496},
	{"CRUISESHIPCENTERS", 17, 114497},
	{"WOLFMAN", 7, 114498},
	{"CRIPS", 5, 114499},
	{"NAPROSYN", 8, 114500},
	{"GEHRY", 5, 114501},
	{"HUMMUS", 6, 114502},
	{"FOXTAIL", 7, 114503},
	{"FIREDOGLAKE", 11, 114504},
	{"HAYABUSA", 8, 114505},
	{"AZTECA", 6, 114506},
	{"PALCO", 5, 114507},
	{"FORGES", 6, 114508},
	{"WHALLEY", 7, 114509},
	{"PARKDALE", 8, 114510},
	{"AIRTEL", 6, 114511},
	{"PROPET", 6, 114512},
	{"CAZZO", 5, 114513},
	{"WPAL", 4, 114514},
	{"WMAG", 4, 114515},
	{"OMIW", 4, 114516},
	{"OILU", 4, 114517},
	{"LAUM", 4, 114518},
	{"KGOI", 4, 114519},
	{"FEWU", 4, 114520},
	{"DOTW", 4, 114521},
	{"DLLO", 4, 114522},
	{"DDSP", 4, 114523},
	{"CISU", 4, 114524},
	{"ALJI", 4, 114525},
	{"ABONNEMENT", 10, 114526},
	{"BEACHWEAR", 9, 114527},
	{"FREDRIC", 7, 114528},
	{"LOOSED", 6, 114529},
	{"STEPPENWOLF", 11, 114530},
	{"MADCAP", 6, 114531},
	{"COLONISATION", 12, 114532},
	{"NEIGH", 5, 114533},
	{"ERSTELLEN", 9, 114534},
	{"THEOLOGYWEB", 11, 114535},
	{"NIGAM", 5, 114536},
	{"CASIMIR", 7, 114537},
	{"HYPOXIC", 7, 114538},
	{"PERSECUTE", 9, 114539},
	{"ROXIE", 5, 114540},
	{"LUNI", 4, 114541},
	{"YPUP", 4, 114542},
	{"VAWI", 4, 114543},
	{"PKIC", 4, 114544},
	{"OROZ", 4, 114545},
	{"LUML", 4, 114546},
	{"LGHA", 4, 114547},
	{"EZWO", 4, 114548},
	{"AORU", 4, 114549},
	{"JAFFNA", 6, 114550},
	{"PIRES", 5, 114551},
	{"COUTURIER", 9, 114552},
	{"TAUX", 4, 114553},
	{"USVI", 4, 114554},
	{"CITTA", 5, 114555},
	{"VISHAL", 6, 114556},
	{"EDGUY", 5, 114557},
	{"REDINGTON", 9, 114558},
	{"UNSUB", 5, 114559},
	{"IMPERSONATOR", 12, 114560},
	{"NEGARA", 6, 114561},
	{"UMB", 3, 114562},
	{"DEDICATES", 9, 114563},
	{"UNWORKABLE", 10, 114564},
	{"INNERDETECTOR", 13, 114565},
	{"MOVIL", 5, 114566},
	{"CRABBY", 6, 114567},
	{"POTU", 4, 114568},
	{"OWLL", 4, 114569},
	{"LREJ", 4, 114570},
	{"HOLP", 4, 114571},
	{"FYUG", 4, 114572},
	{"VORACIOUS", 9, 114573},
	{"MAZOWIECKIE", 11, 114574},
	{"CARNAHAN", 8, 114575},
	{"KENWORTH", 8, 114576},
	{"EKKLESIA", 8, 114577},
	{"SHOREDITCH", 10, 114578},
	{"FORET", 5, 114579},
	{"BECTON", 6, 114580},
	{"BYD", 3, 114581},
	{"CLIFFHANGER", 11, 114582},
	{"ELICA", 5, 114583},
	{"BURLAP", 6, 114584},
	{"PHAGOCYTOSIS", 12, 114585},
	{"RESCUER", 7, 114586},
	{"MISCARRIAGES", 12, 114587},
	{"YEOP", 4, 114588},
	{"UPOI", 4, 114589},
	{"ULOT", 4, 114590},
	{"TZOF", 4, 114591},
	{"SUNJ", 4, 114592},
	{"LMEH", 4, 114593},
	{"KGLA", 4, 114594},
	{"HUNF", 4, 114595},
	{"FPIS", 4, 114596},
	{"EMKE", 4, 114597},
	{"COWC", 4, 114598},
	{"KRK", 3, 114599},
	{"MASSACRED", 9, 114600},
	{"BROOKWOOD", 9, 114601},
	{"KIDZONE", 7, 114602},
	{"FCB", 3, 114603},
	{"BOOKPLATE", 9, 114604},
	{"MONTVILLE", 9, 114605},
	{"ASYNCHRONOUSLY", 14, 114606},
	{"CCTLD", 5, 114607},
	{"PROPYL", 6, 114608},
	{"SEQUELAE", 8, 114609},
	{"AQUALUNG", 8, 114610},
	{"SKINHEAD", 8, 114611},
	{"EXCREMENT", 9, 114612},
	{"AMYOTROPHIC", 11, 114613},
	{"SIGNIFICATION", 13, 114614},
	{"XTHM", 4, 114615},
	{"SAFG", 4, 114616},
	{"NYLU", 4, 114617},
	{"HTYR", 4, 114618},
	{"BOBK", 4, 114619},
	{"QUARRELS", 8, 114620},
	{"BUCKETHEAD", 10, 114621},
	{"NLINE", 5, 114622},
	{"REMOTENESS", 10, 114623},
	{"TOGETHERNESS", 12, 114624},
	{"COSHOCTON", 9, 114625},
	{"LML", 3, 114626},
	{"SPINELLI", 8, 114627},
	{"LIBTIFF", 7, 114628},
	{"SANCTUS", 7, 114629},
	{"DOLLHOUSES", 10, 114630},
	{"BRIS", 4, 114631},
	{"ADVANI", 6, 114632},
	{"PRIVACIDAD", 10, 114633},
	{"HEMATOMA", 8, 114634},
	{"SELIG", 5, 114635},
	{"DITION", 6, 114636},
	{"WILLCOX", 7, 114637},
	{"YAMAGATA", 8, 114638},
	{"NETRATINGS", 10, 114639},
	{"SEARO", 5, 114640},
	{"DOMINUS", 7, 114641},
	{"BOTTICELLI", 10, 114642},
	{"PROVI", 5, 114643},
	{"BARCODING", 9, 114644},
	{"VLIK", 4, 114645},
	{"SOXC", 4, 114646},
	{"RPHS", 4, 114647},
	{"LIPD", 4, 114648},
	{"JONL", 4, 114649},
	{"GYDR", 4, 114650},
	{"GCRY", 4, 114651},
	{"ERCC", 4, 114652},
	{"CKGL", 4, 114653},
	{"BYIL", 4, 114654},
	{"LUTEINIZING", 11, 114655},
	{"BERWICKSHIRE", 12, 114656},
	{"RODEN", 5, 114657},
	{"DIHEDRAL", 8, 114658},
	{"EVIDENCING", 10, 114659},
	{"EQUIPS", 6, 114660},
	{"BALMY", 5, 114661},
	{"SPLINTERS", 9, 114662},
	{"KLEINER", 7, 114663},
	{"MATSUDA", 7, 114664},
	{"PODIATRIST", 10, 114665},
	{"GYMNASIUMS", 10, 114666},
	{"INTERNATIONALIZED", 17, 114667},
	{"RESONATORS", 10, 114668},
	{"YANNI", 5, 114669},
	{"TZAC", 4, 114670},
	{"BEEW", 4, 114671},
	{"EPITHET", 7, 114672},
	{"SENESCENCE", 10, 114673},
	{"BUILTINS", 8, 114674},
	{"MULTIFORMAT", 11, 114675},
	{"BLONDS", 6, 114676},
	{"PDGA", 4, 114677},
	{"PARAPROFESSIONALS", 17, 114678},
	{"UNIMPRESSED", 11, 114679},
	{"RAVENOUS", 8, 114680},
	{"NAVASSA", 7, 114681},
	{"CONTRAVENE", 10, 114682},
	{"XSARA", 5, 114683},
	{"MANDOLINS", 9, 114684},
	{"WEVE", 4, 114685},
	{"NIZORAL", 7, 114686},
	{"SUBPOPULATIONS", 14, 114687},
	{"OVERPLAY", 8, 114688},
	{"ELUTION", 7, 114689},
	{"WRECKERS", 8, 114690},
	{"XREA", 4, 114691},
	{"WSAU", 4, 114692},
	{"VAFO", 4, 114693},
	{"PCRO", 4, 114694},
	{"MBIV", 4, 114695},
	{"IRZA", 4, 114696},
	{"IELJ", 4, 114697},
	{"GRYO", 4, 114698},
	{"EGMO", 4, 114699},
	{"MONGOLS", 7, 114700},
	{"CAMPHOR", 7, 114701},
	{"SAVAGERY", 8, 114702},
	{"OBER", 4, 114703},
	{"NAVIGATED", 9, 114704},
	{"DIEPPE", 6, 114705},
	{"PROTECTIONIST", 13, 114706},
	{"SEANCODY", 8, 114707},
	{"DEAUVILLE", 9, 114708},
	{"PRETENSIONS", 11, 114709},
	{"THUNDERS", 8, 114710},
	{"MUNGER", 6, 114711},
	{"IZOD", 4, 114712},
	{"NETNEWSWIRE", 11, 114713},
	{"CLINDAMYCIN", 11, 114714},
	{"BEECHAM", 7, 114715},
	{"OKAYAMA", 7, 114716},
	{"YKUR", 4, 114717},
	{"WOPT", 4, 114718},
	{"UVIE", 4, 114719},
	{"UAFT", 4, 114720},
	{"PENJ", 4, 114721},
	{"NDAX", 4, 114722},
	{"LBYN", 4, 114723},
	{"KHUS", 4, 114724},
	{"GYCR", 4, 114725},
	{"FISB", 4, 114726},
	{"FFPI", 4, 114727},
	{"CHYC", 4, 114728},
	{"ABWI", 4, 114729},
	{"NIKHIL", 6, 114730},
	{"PATHAN", 6, 114731},
	{"TYRELL", 6, 114732},
	{"MYOECD", 6, 114733},
	{"COUNCILORS", 10, 114734},
	{"RUDDOCK", 7, 114735},
	{"PRINS", 5, 114736},
	{"MESSSAGE", 8, 114737},
	{"DIOGENES", 8, 114738},
	{"REMODELLING", 11, 114739},
	{"WORCS", 5, 114740},
	{"HARR", 4, 114741},
	{"BIBBY", 5, 114742},
	{"KIRI", 4, 114743},
	{"URSA", 4, 114744},
	{"PERN", 4, 114745},
	{"STOPINCLUDE", 11, 114746},
	{"DOZIER", 6, 114747},
	{"COMINGS", 7, 114748},
	{"WMID", 4, 114749},
	{"RGOU", 4, 114750},
	{"PSDR", 4, 114751},
	{"MPEI", 4, 114752},
	{"MHEF", 4, 114753},
	{"GYDO", 4, 114754},
	{"ACHQ", 4, 114755},
	{"PROKARYOTIC", 11, 114756},
	{"BRIX", 4, 114757},
	{"BADU", 4, 114758},
	{"SEPULVEDA", 9, 114759},
	{"POMBO", 5, 114760},
	{"DANKE", 5, 114761},
	{"WINDPROOF", 9, 114762},
	{"TIMEKEEPER", 10, 114763},
	{"KILLIN", 6, 114764},
	{"GODSPEED", 8, 114765},
	{"RESTURANT", 9, 114766},
	{"MULTIPROTOCOL", 13, 114767},
	{"WHITSUNDAYS", 11, 114768},
	{"XESM", 4, 114769},
	{"RYSQ", 4, 114770},
	{"LITG", 4, 114771},
	{"LEAY", 4, 114772},
	{"KOSM", 4, 114773},
	{"KIFA", 4, 114774},
	{"BSPL", 4, 114775},
	{"HEIDE", 5, 114776},
	{"ENFORCERS", 9, 114777},
	{"FREEZEOUT", 9, 114778},
	{"CONGLETON", 9, 114779},
	{"CRINKLE", 7, 114780},
	{"INVERSIONS", 10, 114781},
	{"CAUSEY", 6, 114782},
	{"FARTHING", 8, 114783},
	{"ELTAX", 5, 114784},
	{"EDIBLES", 7, 114785},
	{"CREVICES", 8, 114786},
	{"WRINGING", 8, 114787},
	{"SUPERPOWERS", 11, 114788},
	{"CAMBS", 5, 114789},
	{"KAMALA", 6, 114790},
	{"BROCKWAY", 8, 114791},
	{"ARDENNES", 8, 114792},
	{"NATURISM", 8, 114793},
	{"OMNIORB", 7, 114794},
	{"UNDERSTORY", 10, 114795},
	{"COLLEGIAN", 9, 114796},
	{"YREY", 4, 114797},
	{"YMCK", 4, 114798},
	{"VISG", 4, 114799},
	{"GRYS", 4, 114800},
	{"EGSF", 4, 114801},
	{"PESTPATROL", 10, 114802},
	{"ALBERTVILLE", 11, 114803},
	{"TEARFUL", 7, 114804},
	{"EVANGELIZATION", 14, 114805},
	{"BETWIXT", 7, 114806},
	{"MOLESTING", 9, 114807},
	{"FLORENT", 7, 114808},
	{"UNMISTAKABLY", 12, 114809},
	{"POSTSYNAPTIC", 12, 114810},
	{"BENGT", 5, 114811},
	{"PURPURA", 7, 114812},
	{"HOLLABACK", 9, 114813},
	{"SUBPOENAED", 10, 114814},
	{"PHAROAH", 7, 114815},
	{"INTERLEAVING", 12, 114816},
	{"ACTUALS", 7, 114817},
	{"RUMINANT", 8, 114818},
	{"INGENTA", 7, 114819},
	{"VYPR", 4, 114820},
	{"GYLL", 4, 114821},
	{"HETEROLOGOUS", 12, 114822},
	{"MASSED", 6, 114823},
	{"SIMPY", 5, 114824},
	{"CHISINAU", 8, 114825},
	{"DYSPNEA", 7, 114826},
	{"BESTBBS", 7, 114827},
	{"SALICYLIC", 9, 114828},
	{"PLUCKING", 8, 114829},
	{"ROMMEL", 6, 114830},
	{"GLENEAGLES", 10, 114831},
	{"CLEARTEXT", 9, 114832},
	{"ZESTY", 5, 114833},
	{"RAMAPO", 6, 114834},
	{"UKWA", 4, 114835},
	{"RADZ", 4, 114836},
	{"IKIC", 4, 114837},
	{"DUMT", 4, 114838},
	{"SULTS", 5, 114839},
	{"RICKSHAW", 8, 114840},
	{"LAMBRETTA", 9, 114841},
	{"FORMALIZATION", 13, 114842},
	{"INTERPOLATE", 11, 114843},
	{"SHIRES", 6, 114844},
	{"MANTELS", 7, 114845},
	{"CREATEBEFORE", 12, 114846},
	{"BESSON", 6, 114847},
	{"SUBDIRS", 7, 114848},
	{"SLAVONIC", 8, 114849},
	{"RAGIN", 5, 114850},
	{"STOMPER", 7, 114851},
	{"NAPHTHALENE", 11, 114852},
	{"NOTEPADS", 8, 114853},
	{"SILENCERS", 9, 114854},
	{"REPRIMANDED", 11, 114855},
	{"REBELLED", 8, 114856},
	{"OPWS", 4, 114857},
	{"THUNDEROUS", 10, 114858},
	{"FFC", 3, 114859},
	{"YDAS", 4, 114860},
	{"UPHU", 4, 114861},
	{"PEFE", 4, 114862},
	{"OVAD", 4, 114863},
	{"IMIW", 4, 114864},
	{"GSBI", 4, 114865},
	{"ECYA", 4, 114866},
	{"LAUTENBERG", 10, 114867},
	{"FABULOUSLY", 10, 114868},
	{"PORCHE", 6, 114869},
	{"ROLLE", 5, 114870},
	{"MINIEMPIRE", 10, 114871},
	{"OVERBLOWN", 9, 114872},
	{"VASOPRESSIN", 11, 114873},
	{"HAGERTY", 7, 114874},
	{"ENCLOSES", 8, 114875},
	{"SORTIES", 7, 114876},
	{"BRIDGEMAN", 9, 114877},
	{"BYNES", 5, 114878},
	{"CLAYMORE", 8, 114879},
	{"CANTATAS", 8, 114880},
	{"PRIORITISED", 11, 114881},
	{"CARVILLE", 8, 114882},
	{"LAFARGE", 7, 114883},
	{"HYPHENATION", 11, 114884},
	{"REVIVES", 7, 114885},
	{"ALEXISONFIRE", 12, 114886},
	{"TOLERATION", 10, 114887},
	{"SUITORS", 7, 114888},
	{"BLACKSMITHING", 13, 114889},
	{"AMADORAS", 8, 114890},
	{"UEJE", 4, 114891},
	{"RLYQ", 4, 114892},
	{"MRRE", 4, 114893},
	{"GIOG", 4, 114894},
	{"FESW", 4, 114895},
	{"EWAX", 4, 114896},
	{"AWVI", 4, 114897},
	{"ARLG", 4, 114898},
	{"FORKING", 7, 114899},
	{"WIGGLY", 6, 114900},
	{"PLOP", 4, 114901},
	{"GENOCIDAL", 9, 114902},
	{"MINUTIAE", 8, 114903},
	{"DISSIPATIVE", 11, 114904},
	{"CALCIFICATION", 13, 114905},
	{"CASEWORKER", 10, 114906},
	{"TITTEL", 6, 114907},
	{"DEVIATED", 8, 114908},
	{"INTRAVASCULAR", 13, 114909},
	{"CYBERNETIC", 10, 114910},
	{"KULT", 4, 114911},
	{"EXERCISER", 9, 114912},
	{"PRESCRIPTIONNEED", 16, 114913},
	{"SLEIGHT", 7, 114914},
	{"BURMAN", 6, 114915},
	{"BENING", 6, 114916},
	{"PARATRANSIT", 11, 114917},
	{"SPECTROGRAPH", 12, 114918},
	{"GOOGEL", 6, 114919},
	{"LICKIN", 6, 114920},
	{"YSEF", 4, 114921},
	{"UVEC", 4, 114922},
	{"RUTU", 4, 114923},
	{"RAQO", 4, 114924},
	{"LVAI", 4, 114925},
	{"ILFL", 4, 114926},
	{"EXFR", 4, 114927},
	{"DSWR", 4, 114928},
	{"BJOH", 4, 114929},
	{"AQIC", 4, 114930},
	{"RYDGES", 6, 114931},
	{"VELVETEEN", 9, 114932},
	{"GANSU", 5, 114933},
	{"BENNER", 6, 114934},
	{"WONDERBRA", 9, 114935},
	{"DAGMAR", 6, 114936},
	{"AUTOLOADS", 9, 114937},
	{"SOLITONS", 8, 114938},
	{"MURRY", 5, 114939},
	{"FORTIN", 6, 114940},
	{"DROGHEDA", 8, 114941},
	{"CREDITO", 7, 114942},
	{"NONPAYMENT", 10, 114943},
	{"WLXL", 4, 114944},
	{"MURM", 4, 114945},
	{"TRICOT", 6, 114946},
	{"SHUTOFF", 7, 114947},
	{"GLW", 3, 114948},
	{"ORTHOP", 6, 114949},
	{"HEADLINED", 9, 114950},
	{"BALT", 4, 114951},
	{"ELECTR", 6, 114952},
	{"SOURCESAFE", 10, 114953},
	{"PITTSBORO", 9, 114954},
	{"THRUSTMASTER", 12, 114955},
	{"PHENTERMINECAN", 14, 114956},
	{"SKIRTED", 7, 114957},
	{"FITZSIMONS", 10, 114958},
	{"WISU", 4, 114959},
	{"UIDD", 4, 114960},
	{"TSMR", 4, 114961},
	{"OPDU", 4, 114962},
	{"NUTM", 4, 114963},
	{"NHLP", 4, 114964},
	{"KLIB", 4, 114965},
	{"HKIR", 4, 114966},
	{"EWMC", 4, 114967},
	{"DDYP", 4, 114968},
	{"KIRKMAN", 7, 114969},
	{"COACHMAN", 8, 114970},
	{"BIGOTS", 6, 114971},
	{"MECCANO", 7, 114972},
	{"DAYBOOK", 7, 114973},
	{"SNOWBALLS", 9, 114974},
	{"ELUCIDATED", 10, 114975},
	{"BHATT", 5, 114976},
	{"REAPPEARED", 10, 114977},
	{"COMPREHENDING", 13, 114978},
	{"RECKONS", 7, 114979},
	{"HORNCHURCH", 10, 114980},
	{"PILLWANT", 8, 114981},
	{"MODCHIP", 7, 114982},
	{"INEXHAUSTIBLE", 13, 114983},
	{"ESCANABA", 8, 114984},
	{"MANIPULATES", 11, 114985},
	{"KEGAN", 5, 114986},
	{"VERMEULEN", 9, 114987},
	{"HOOTIE", 6, 114988},
	{"LUCERO", 6, 114989},
	{"PUZZLER", 7, 114990},
	{"UCAR", 4, 114991},
	{"SUPERSEARCH", 11, 114992},
	{"CARAVAGGIO", 10, 114993},
	{"UMAU", 4, 114994},
	{"OVPA", 4, 114995},
	{"NGGY", 4, 114996},
	{"KOCO", 4, 114997},
	{"ERNQ", 4, 114998},
	{"COBL", 4, 114999},
	{"AILK", 4, 115000},
	{"POLSKIE", 7, 115001},
	{"CANNY", 5, 115002},
	{"FAINTED", 7, 115003},
	{"FRON", 4, 115004},
	{"LUCHA", 5, 115005},
	{"MWST", 4, 115006},
	{"ONLINEENTER", 11, 115007},
	{"SIMRAD", 6, 115008},
	{"SEGURA", 6, 115009},
	{"WESTHAMPTON", 11, 115010},
	{"ROATAN", 6, 115011},
	{"PIANOFORTE", 10, 115012},
	{"REUPTAKE", 8, 115013},
	{"STADLER", 7, 115014},
	{"FAVERSHAM", 9, 115015},
	{"YEGG", 4, 115016},
	{"WMER", 4, 115017},
	{"ODYJ", 4, 115018},
	{"EZZL", 4, 115019},
	{"EYEG", 4, 115020},
	{"ECBO", 4, 115021},
	{"CARLSBERG", 9, 115022},
	{"EUFAULA", 7, 115023},
	{"CONCHO", 6, 115024},
	{"RIFTS", 5, 115025},
	{"ROSALYN", 7, 115026},
	{"JARRELL", 7, 115027},
	{"CGIAR", 5, 115028},
	{"ASHEBORO", 8, 115029},
	{"BEATY", 5, 115030},
	{"FLESHED", 7, 115031},
	{"TRACKSUITS", 10, 115032},
	{"DPORTS", 6, 115033},
	{"URBANISATION", 12, 115034},
	{"HAYWARDS", 8, 115035},
	{"WINKING", 7, 115036},
	{"MASTODON", 8, 115037},
	{"CLARINETS", 9, 115038},
	{"TELEPHONIC", 10, 115039},
	{"ISIGHT", 6, 115040},
	{"WALLABY", 7, 115041},
	{"WRAD", 4, 115042},
	{"NUCO", 4, 115043},
	{"MYAU", 4, 115044},
	{"KREQ", 4, 115045},
	{"INKV", 4, 115046},
	{"IKLA", 4, 115047},
	{"IBLO", 4, 115048},
	{"EZBE", 4, 115049},
	{"RACECOURSES", 11, 115050},
	{"EXEMPLARS", 9, 115051},
	{"STRAIGHTS", 9, 115052},
	{"EIGER", 5, 115053},
	{"PHENTERMINEFIND", 15, 115054},
	{"BASSAS", 6, 115055},
	{"THIMEROSAL", 10, 115056},
	{"FIRMAMENT", 9, 115057},
	{"MATAGORDA", 9, 115058},
	{"FERRARO", 7, 115059},
	{"DGPS", 4, 115060},
	{"VROOM", 5, 115061},
	{"MELLY", 5, 115062},
	{"SAKAR", 5, 115063},
	{"ZAWODNY", 7, 115064},
	{"RIBONUCLEASE", 12, 115065},
	{"ZIGG", 4, 115066},
	{"WKSC", 4, 115067},
	{"UBYA", 4, 115068},
	{"TJAK", 4, 115069},
	{"ROLV", 4, 115070},
	{"RLRE", 4, 115071},
	{"LUPH", 4, 115072},
	{"LPSR", 4, 115073},
	{"KTHU", 4, 115074},
	{"KELW", 4, 115075},
	{"JIMJ", 4, 115076},
	{"FJAS", 4, 115077},
	{"EGYS", 4, 115078},
	{"DTUL", 4, 115079},
	{"TAIGA", 5, 115080},
	{"CERULEAN", 8, 115081},
	{"INSTAOFFICE", 11, 115082},
	{"MYLO", 4, 115083},
	{"HOVERS", 6, 115084},
	{"BRASILEIRAS", 11, 115085},
	{"RIEGER", 6, 115086},
	{"BILBERRY", 8, 115087},
	{"PHOTOESS", 8, 115088},
	{"OURINFO", 7, 115089},
	{"BYELORUSSIAN", 12, 115090},
	{"PHENTERMINEREAL", 15, 115091},
	{"VPTS", 4, 115092},
	{"QINGHAI", 7, 115093},
	{"GROSSED", 7, 115094},
	{"INTERRELATIONSHIP", 17, 115095},
	{"YSIU", 4, 115096},
	{"WSAV", 4, 115097},
	{"SPIV", 4, 115098},
	{"OOPB", 4, 115099},
	{"MIEW", 4, 115100},
	{"KYWE", 4, 115101},
	{"EPTY", 4, 115102},
	{"COFB", 4, 115103},
	{"CHIY", 4, 115104},
	{"PDFTEX", 6, 115105},
	{"SINENSIS", 8, 115106},
	{"COTTONS", 7, 115107},
	{"THOROUGHNESS", 12, 115108},
	{"DUESSELDORF", 11, 115109},
	{"PAGEE", 5, 115110},
	{"ARTICULATES", 11, 115111},
	{"CONFESSOR", 9, 115112},
	{"MERION", 6, 115113},
	{"WELLNESSDICKE", 13, 115114},
	{"GOOSEBERRY", 10, 115115},
	{"BAGUIO", 6, 115116},
	{"PHENTERMINETHIS", 15, 115117},
	{"AIMLESSLY", 9, 115118},
	{"OPPOR", 5, 115119},
	{"CODLOCATION", 11, 115120},
	{"LIGATURE", 8, 115121},
	{"ENDOMETRIUM", 11, 115122},
	{"SAGITTAL", 8, 115123},
	{"ANGELOS", 7, 115124},
	{"TOUCHPOINT", 10, 115125},
	{"WMOU", 4, 115126},
	{"WFED", 4, 115127},
	{"TEMV", 4, 115128},
	{"RIKH", 4, 115129},
	{"LBAU", 4, 115130},
	{"KJUN", 4, 115131},
	{"ISCD", 4, 115132},
	{"HBUN", 4, 115133},
	{"EPSR", 4, 115134},
	{"MLD", 3, 115135},
	{"PRONOUNCING", 11, 115136},
	{"CARDOZO", 7, 115137},
	{"RAMDISK", 7, 115138},
	{"MULLED", 6, 115139},
	{"BPC", 3, 115140},
	{"AGASSIZ", 7, 115141},
	{"DAZZLED", 7, 115142},
	{"INBORN", 6, 115143},
	{"MANERA", 6, 115144},
	{"SPELLMAN", 8, 115145},
	{"MERCANTILA", 10, 115146},
	{"RIPA", 4, 115147},
	{"EFFECTSREAL", 11, 115148},
	{"ROHR", 4, 115149},
	{"OULD", 4, 115150},
	{"CONSULS", 7, 115151},
	{"ACTIVIDADES", 11, 115152},
	{"WATW", 4, 115153},
	{"SPYO", 4, 115154},
	{"GSIR", 4, 115155},
	{"EWGL", 4, 115156},
	{"DYLL", 4, 115157},
	{"WEEKLONG", 8, 115158},
	{"ABLETON", 7, 115159},
	{"ZHUANG", 6, 115160},
	{"FAULTING", 8, 115161},
	{"REBLOG", 6, 115162},
	{"EURE", 4, 115163},
	{"RELAT", 5, 115164},
	{"DORIA", 5, 115165},
	{"THRUSTERS", 9, 115166},
	{"MCBAIN", 6, 115167},
	{"ROSENHEIM", 9, 115168},
	{"BELLWOOD", 8, 115169},
	{"NEWNESS", 7, 115170},
	{"ASCETIC", 7, 115171},
	{"SPORTDICKE", 10, 115172},
	{"CARLITO", 7, 115173},
	{"BEARABLE", 8, 115174},
	{"ATTESTING", 9, 115175},
	{"UNINSPIRED", 10, 115176},
	{"BLACKFRIARS", 11, 115177},
	{"KHALIFA", 7, 115178},
	{"REXNL", 5, 115179},
	{"POLARISED", 9, 115180},
	{"PILLSCATALOG", 12, 115181},
	{"RUSSET", 6, 115182},
	{"ZIED", 4, 115183},
	{"SXIV", 4, 115184},
	{"KYFI", 4, 115185},
	{"IFAU", 4, 115186},
	{"DICF", 4, 115187},
	{"SHIZUOKA", 8, 115188},
	{"RUMEN", 5, 115189},
	{"PESACH", 6, 115190},
	{"SPECIE", 6, 115191},
	{"BIBSOURCE", 9, 115192},
	{"MAXDATA", 7, 115193},
	{"DEFI", 4, 115194},
	{"DEOXY", 5, 115195},
	{"MECHS", 5, 115196},
	{"FROSTBURG", 9, 115197},
	{"REMINISCING", 11, 115198},
	{"FLINN", 5, 115199},
	{"SIPC", 4, 115200},
	{"CIFIC", 5, 115201},
	{"ELIGIBLES", 9, 115202},
	{"MERTENS", 7, 115203},
	{"SHMUEL", 6, 115204},
	{"AUTOFS", 6, 115205},
	{"TAYR", 4, 115206},
	{"RCOE", 4, 115207},
	{"OVAG", 4, 115208},
	{"MFLI", 4, 115209},
	{"EFMO", 4, 115210},
	{"DRYP", 4, 115211},
	{"GILDER", 6, 115212},
	{"FINANZA", 7, 115213},
	{"HILTONS", 7, 115214},
	{"LAVIN", 5, 115215},
	{"KRILL", 5, 115216},
	{"HOTHOUSE", 8, 115217},
	{"HIFIBITZ", 8, 115218},
	{"SENSENBRENNER", 13, 115219},
	{"MILKWEED", 8, 115220},
	{"INCAS", 5, 115221},
	{"PATELLA", 7, 115222},
	{"TERPS", 5, 115223},
	{"CHINGY", 6, 115224},
	{"SKEIN", 5, 115225},
	{"BIZAR", 5, 115226},
	{"REFLOW", 6, 115227},
	{"PURPUREA", 8, 115228},
	{"VMAS", 4, 115229},
	{"MORPHS", 6, 115230},
	{"SLICERS", 7, 115231},
	{"WKSI", 4, 115232},
	{"UPNI", 4, 115233},
	{"RMCE", 4, 115234},
	{"MRGO", 4, 115235},
	{"KYES", 4, 115236},
	{"GAZP", 4, 115237},
	{"FBUN", 4, 115238},
	{"DTOZ", 4, 115239},
	{"DOWY", 4, 115240},
	{"BIBE", 4, 115241},
	{"BAGB", 4, 115242},
	{"VIRGINIE", 8, 115243},
	{"NONHUMAN", 8, 115244},
	{"CRONKITE", 8, 115245},
	{"EYEWITNESSES", 12, 115246},
	{"BARDEN", 6, 115247},
	{"PLEDGEBANK", 10, 115248},
	{"SPANKY", 6, 115249},
	{"METTLE", 6, 115250},
	{"MOLDY", 5, 115251},
	{"BODYSUIT", 8, 115252},
	{"QUANTIFIERS", 11, 115253},
	{"RELEGATION", 10, 115254},
	{"ENDEAVORED", 10, 115255},
	{"BULGER", 6, 115256},
	{"RONALDINHO", 10, 115257},
	{"ENALAPRIL", 9, 115258},
	{"PLACKET", 7, 115259},
	{"INFLORESCENCE", 13, 115260},
	{"MAYALL", 6, 115261},
	{"MATIN", 5, 115262},
	{"CHIPMUNKS", 9, 115263},
	{"UPIA", 4, 115264},
	{"NOGL", 4, 115265},
	{"FYON", 4, 115266},
	{"COMY", 4, 115267},
	{"AIDZ", 4, 115268},
	{"HALOGENATED", 11, 115269},
	{"FILMCO", 6, 115270},
	{"HGNC", 4, 115271},
	{"DEMONSTRATIVE", 13, 115272},
	{"DURAMAX", 7, 115273},
	{"DIONE", 5, 115274},
	{"FBR", 3, 115275},
	{"ARTHROPOD", 9, 115276},
	{"LEVODOPA", 8, 115277},
	{"FORMATE", 7, 115278},
	{"INSETS", 6, 115279},
	{"TENDULKAR", 9, 115280},
	{"TVAU", 4, 115281},
	{"GUANG", 5, 115282},
	{"FORMATTEDSEARCH", 15, 115283},
	{"DEVENDRA", 8, 115284},
	{"LACZ", 4, 115285},
	{"FMCG", 4, 115286},
	{"SOUNDKASE", 9, 115287},
	{"SAMEER", 6, 115288},
	{"JOVOVICH", 8, 115289},
	{"LYSATE", 6, 115290},
	{"DETTA", 5, 115291},
	{"BOBBLEHEAD", 10, 115292},
	{"BIGOTED", 7, 115293},
	{"FORMERS", 7, 115294},
	{"DISCORDANT", 10, 115295},
	{"PDG", 3, 115296},
	{"LILACS", 6, 115297},
	{"MAGNUSSON", 9, 115298},
	{"ORME", 4, 115299},
	{"UPRIGHTS", 8, 115300},
	{"UANZ", 4, 115301},
	{"KLIE", 4, 115302},
	{"HIVP", 4, 115303},
	{"EBBU", 4, 115304},
	{"LEVYING", 7, 115305},
	{"FOREARMS", 8, 115306},
	{"MCCONAUGHEY", 11, 115307},
	{"KIERNAN", 7, 115308},
	{"ELLES", 5, 115309},
	{"BRIERLEY", 8, 115310},
	{"KREUK", 5, 115311},
	{"MISDIAGNOSIS", 12, 115312},
	{"WXPORT", 6, 115313},
	{"TAKAGI", 6, 115314},
	{"PAXSON", 6, 115315},
	{"CYNON", 5, 115316},
	{"REPLAYTV", 8, 115317},
	{"PROTEOLYSIS", 11, 115318},
	{"UBGE", 4, 115319},
	{"HUAL", 4, 115320},
	{"HMYW", 4, 115321},
	{"ECIC", 4, 115322},
	{"CCCO", 4, 115323},
	{"ARNR", 4, 115324},
	{"COPYWRITERS", 11, 115325},
	{"XBK", 3, 115326},
	{"WVY", 3, 115327},
	{"WLZ", 3, 115328},
	{"RWQ", 3, 115329},
	{"PFZ", 3, 115330},
	{"MORTICIAN", 9, 115331},
	{"QUICKIES", 8, 115332},
	{"BETHNAL", 7, 115333},
	{"MINUTO", 6, 115334},
	{"ORIEL", 5, 115335},
	{"REDORBIT", 8, 115336},
	{"COLUMBO", 7, 115337},
	{"BALLPARKS", 9, 115338},
	{"FISCH", 5, 115339},
	{"NONEMPTY", 8, 115340},
	{"BUOYED", 6, 115341},
	{"WLSO", 4, 115342},
	{"UANR", 4, 115343},
	{"TURS", 4, 115344},
	{"SMIM", 4, 115345},
	{"MADL", 4, 115346},
	{"AXPO", 4, 115347},
	{"SLURPING", 8, 115348},
	{"HAIDA", 5, 115349},
	{"RESORPTION", 10, 115350},
	{"MALADY", 6, 115351},
	{"VANIER", 6, 115352},
	{"ANGELIKA", 8, 115353},
	{"YNEZ", 4, 115354},
	{"INHIBITIONS", 11, 115355},
	{"ORPHEUM", 7, 115356},
	{"ANTIMATTER", 10, 115357},
	{"XONP", 4, 115358},
	{"UEIR", 4, 115359},
	{"RMMU", 4, 115360},
	{"KYAL", 4, 115361},
	{"DINZ", 4, 115362},
	{"SILLA", 5, 115363},
	{"CENTERSTAGE", 11, 115364},
	{"DOUGLASVILLE", 12, 115365},
	{"ELISSA", 6, 115366},
	{"SANRIO", 6, 115367},
	{"AUTOSTART", 9, 115368},
	{"ELECTROMAGNETISM", 16, 115369},
	{"BRAHMIN", 7, 115370},
	{"GRANDSONS", 9, 115371},
	{"TAVERNA", 7, 115372},
	{"QIAGEN", 6, 115373},
	{"MASHUP", 6, 115374},
	{"TEMPERS", 7, 115375},
	{"STANDARDOUT", 11, 115376},
	{"PREVOST", 7, 115377},
	{"XTHB", 4, 115378},
	{"USUM", 4, 115379},
	{"TVWI", 4, 115380},
	{"SKGR", 4, 115381},
	{"PANL", 4, 115382},
	{"OFPC", 4, 115383},
	{"OBIK", 4, 115384},
	{"GGYM", 4, 115385},
	{"DNCA", 4, 115386},
	{"DMUM", 4, 115387},
	{"QUININE", 7, 115388},
	{"ROSENBLATT", 10, 115389},
	{"WIKIPROJECT", 11, 115390},
	{"PEDOPHILIA", 10, 115391},
	{"NOTRIX", 6, 115392},
	{"THIRTIETH", 9, 115393},
	{"MONEDA", 6, 115394},
	{"ILLEGALITY", 10, 115395},
	{"PARAPHRASED", 11, 115396},
	{"OLEFIN", 6, 115397},
	{"BABYUNIVERSE", 12, 115398},
	{"ASCORBATE", 9, 115399},
	{"ELYSE", 5, 115400},
	{"SAMY", 4, 115401},
	{"MERCRUISER", 10, 115402},
	{"YJAZ", 4, 115403},
	{"UDOK", 4, 115404},
	{"TERX", 4, 115405},
	{"SULS", 4, 115406},
	{"SIMG", 4, 115407},
	{"ORMK", 4, 115408},
	{"MLYO", 4, 115409},
	{"AZIC", 4, 115410},
	{"PARKAS", 6, 115411},
	{"CALISTA", 7, 115412},
	{"GOTOMEETING", 11, 115413},
	{"BEANSTALK", 9, 115414},
	{"RETROVIRUSES", 12, 115415},
	{"WILBERT", 7, 115416},
	{"PORTADA", 7, 115417},
	{"WAILUKU", 7, 115418},
	{"GROG", 4, 115419},
	{"ZAKK", 4, 115420},
	{"RADIALLY", 8, 115421},
	{"SIGNPOSTED", 10, 115422},
	{"RADIOIMMUNOASSAY", 16, 115423},
	{"UIRT", 4, 115424},
	{"SARV", 4, 115425},
	{"PJAC", 4, 115426},
	{"MAXC", 4, 115427},
	{"KORL", 4, 115428},
	{"EXMI", 4, 115429},
	{"BHUM", 4, 115430},
	{"AVAW", 4, 115431},
	{"MARCIANO", 8, 115432},
	{"STIGMATA", 8, 115433},
	{"FESTER", 6, 115434},
	{"SUFIACORP", 9, 115435},
	{"SPEY", 4, 115436},
	{"BUSHLAND", 8, 115437},
	{"PATHOLOGIES", 11, 115438},
	{"NEXTGEN", 7, 115439},
	{"FREECYCLE", 9, 115440},
	{"PERMEATED", 9, 115441},
	{"CADASTRAL", 9, 115442},
	{"XISF", 4, 115443},
	{"UDSI", 4, 115444},
	{"RBSC", 4, 115445},
	{"PRAL", 4, 115446},
	{"KHAP", 4, 115447},
	{"JUXT", 4, 115448},
	{"GHIP", 4, 115449},
	{"AGYA", 4, 115450},
	{"IMMUNOSUPPRESSION", 17, 115451},
	{"RETARDS", 7, 115452},
	{"MANDAN", 6, 115453},
	{"MCK", 3, 115454},
	{"CONVEXITY", 9, 115455},
	{"RESENTFUL", 9, 115456},
	{"ARITY", 5, 115457},
	{"HEGRE", 5, 115458},
	{"HEADLANDS", 9, 115459},
	{"GERAIS", 6, 115460},
	{"MELL", 4, 115461},
	{"COMPLEMENTATION", 15, 115462},
	{"SAINTLY", 7, 115463},
	{"ENVISAGES", 9, 115464},
	{"TARANTO", 7, 115465},
	{"MICHELS", 7, 115466},
	{"OUDE", 4, 115467},
	{"FELTHAM", 7, 115468},
	{"AUDITIONING", 11, 115469},
	{"ZAIR", 4, 115470},
	{"UMKI", 4, 115471},
	{"UKHE", 4, 115472},
	{"UBTB", 4, 115473},
	{"SUNQ", 4, 115474},
	{"RLUT", 4, 115475},
	{"OBOG", 4, 115476},
	{"KYNO", 4, 115477},
	{"IXUP", 4, 115478},
	{"CKTY", 4, 115479},
	{"PICNICKING", 10, 115480},
	{"SOLVANG", 7, 115481},
	{"GORMLEY", 7, 115482},
	{"TARNOVO", 7, 115483},
	{"DCMS", 4, 115484},
	{"PUSHKIN", 7, 115485},
	{"ATTICUS", 7, 115486},
	{"LYMINGTON", 9, 115487},
	{"ARTFORUM", 8, 115488},
	{"AUGHT", 5, 115489},
	{"NOSEARCH", 8, 115490},
	{"CORNELIS", 8, 115491},
	{"ADJUNCTS", 8, 115492},
	{"CORONAVIRUS", 11, 115493},
	{"ENTOMOL", 7, 115494},
	{"SHOREBIRDS", 10, 115495},
	{"JEWELLER", 8, 115496},
	{"CRYPTOLOGY", 10, 115497},
	{"SCRIBBLES", 9, 115498},
	{"BRIMFIELD", 9, 115499},
	{"INDIVID", 7, 115500},
	{"ZFES", 4, 115501},
	{"YLIQ", 4, 115502},
	{"XAMA", 4, 115503},
	{"WSPH", 4, 115504},
	{"WOAG", 4, 115505},
	{"METV", 4, 115506},
	{"IFLU", 4, 115507},
	{"GTUB", 4, 115508},
	{"HARRASSING", 10, 115509},
	{"GANGLAND", 8, 115510},
	{"PHORUM", 6, 115511},
	{"FERENC", 6, 115512},
	{"BOURQUE", 7, 115513},
	{"ROSEAU", 6, 115514},
	{"FIORENTINO", 10, 115515},
	{"UNBAN", 5, 115516},
	{"NONFAT", 6, 115517},
	{"HELMER", 6, 115518},
	{"STDEV", 5, 115519},
	{"DBIX", 4, 115520},
	{"NARCO", 5, 115521},
	{"XAFT", 4, 115522},
	{"UTSG", 4, 115523},
	{"UKWI", 4, 115524},
	{"LLCY", 4, 115525},
	{"ENGY", 4, 115526},
	{"AKIK", 4, 115527},
	{"EPDM", 4, 115528},
	{"DIRECTSHOW", 10, 115529},
	{"ALEJANDRA", 9, 115530},
	{"GRUBBY", 6, 115531},
	{"DANZIGER", 8, 115532},
	{"CIFRA", 5, 115533},
	{"WOOING", 6, 115534},
	{"BLANEY", 6, 115535},
	{"FLYNT", 5, 115536},
	{"BACKROADS", 9, 115537},
	{"CONJUNCTIONS", 12, 115538},
	{"BLUEBELL", 8, 115539},
	{"PGR", 3, 115540},
	{"LASSETER", 8, 115541},
	{"DIETHYL", 7, 115542},
	{"WEBF", 4, 115543},
	{"PMOC", 4, 115544},
	{"KAGU", 4, 115545},
	{"FEBW", 4, 115546},
	{"EMBELLISH", 9, 115547},
	{"NICOLETTE", 9, 115548},
	{"LELONG", 6, 115549},
	{"HIPPOS", 6, 115550},
	{"LALIT", 5, 115551},
	{"CORDES", 6, 115552},
	{"TINYOS", 6, 115553},
	{"TELEPATHIC", 10, 115554},
	{"PREG", 4, 115555},
	{"DISINFECT", 9, 115556},
	{"XHIK", 4, 115557},
	{"COYL", 4, 115558},
	{"BMAY", 4, 115559},
	{"ADDW", 4, 115560},
	{"MOONLIT", 7, 115561},
	{"DICKEN", 6, 115562},
	{"INTERCEPTING", 12, 115563},
	{"NECRO", 5, 115564},
	{"ASPYR", 5, 115565},
	{"PRIVATISED", 10, 115566},
	{"MELANGE", 7, 115567},
	{"PARACEL", 7, 115568},
	{"BCEAO", 5, 115569},
	{"KEPPEL", 6, 115570},
	{"PALPATINE", 9, 115571},
	{"DENOUNCES", 9, 115572},
	{"CROISSANT", 9, 115573},
	{"HOOPLA", 6, 115574},
	{"BUZZMACHINE", 11, 115575},
	{"CENTERPOINT", 11, 115576},
	{"GULES", 5, 115577},
	{"COSTUMED", 8, 115578},
	{"ANALIZE", 7, 115579},
	{"TRILATERAL", 10, 115580},
	{"WATERMARKED", 11, 115581},
	{"INTERSIL", 8, 115582},
	{"BESSER", 6, 115583},
	{"PENNYSAVER", 10, 115584},
	{"YGOF", 4, 115585},
	{"TYEF", 4, 115586},
	{"SSPY", 4, 115587},
	{"SCUA", 4, 115588},
	{"PPSW", 4, 115589},
	{"JAYM", 4, 115590},
	{"DDSM", 4, 115591},
	{"CYMB", 4, 115592},
	{"VACUOLAR", 8, 115593},
	{"QUARTERFINAL", 12, 115594},
	{"NIKOLAOS", 8, 115595},
	{"CENAS", 5, 115596},
	{"OBSTETRICAL", 11, 115597},
	{"PERFECTO", 8, 115598},
	{"OPERABILITY", 11, 115599},
	{"CRK", 3, 115600},
	{"PREQUALIFY", 10, 115601},
	{"STANSFIELD", 10, 115602},
	{"WEGEN", 5, 115603},
	{"WALZ", 4, 115604},
	{"DEDICATIONS", 11, 115605},
	{"METOPROLOL", 10, 115606},
	{"LEBARON", 7, 115607},
	{"MCAULEY", 7, 115608},
	{"DIENST", 6, 115609},
	{"RESIDENZA", 9, 115610},
	{"WPET", 4, 115611},
	{"SMEB", 4, 115612},
	{"RYEI", 4, 115613},
	{"RNKI", 4, 115614},
	{"NHLC", 4, 115615},
	{"MGIL", 4, 115616},
	{"JOYP", 4, 115617},
	{"IRYS", 4, 115618},
	{"EBWA", 4, 115619},
	{"DSUZ", 4, 115620},
	{"CKIR", 4, 115621},
	{"RECURRENCES", 11, 115622},
	{"ULCERATION", 10, 115623},
	{"GOBLE", 5, 115624},
	{"PHILIPSBURG", 11, 115625},
	{"AFTERTASTE", 10, 115626},
	{"DLESE", 5, 115627},
	{"DAMPENED", 8, 115628},
	{"STALKERS", 8, 115629},
	{"POCONOS", 7, 115630},
	{"POPULUS", 7, 115631},
	{"CNNMONEY", 8, 115632},
	{"CANTLY", 6, 115633},
	{"PAYETTE", 7, 115634},
	{"QUIZES", 6, 115635},
	{"CORKS", 5, 115636},
	{"BENHAM", 6, 115637},
	{"LITHIA", 6, 115638},
	{"OBSCURING", 9, 115639},
	{"TOPBAND", 7, 115640},
	{"YSHY", 4, 115641},
	{"YBYV", 4, 115642},
	{"WMEL", 4, 115643},
	{"UBTY", 4, 115644},
	{"RJAW", 4, 115645},
	{"MOBL", 4, 115646},
	{"LMCL", 4, 115647},
	{"KMUR", 4, 115648},
	{"AYAY", 4, 115649},
	{"AUFI", 4, 115650},
	{"AFTY", 4, 115651},
	{"METHACRYLATE", 12, 115652},
	{"DEMOTED", 7, 115653},
	{"TAGES", 5, 115654},
	{"NULLIFY", 7, 115655},
	{"CAMBORNE", 8, 115656},
	{"PLOWS", 5, 115657},
	{"DELTONA", 7, 115658},
	{"WROS", 4, 115659},
	{"PATG", 4, 115660},
	{"ITZL", 4, 115661},
	{"HLBE", 4, 115662},
	{"AZMA", 4, 115663},
	{"JALAL", 5, 115664},
	{"MOVIEZ", 6, 115665},
	{"REFINES", 7, 115666},
	{"INFARCT", 7, 115667},
	{"HTLV", 4, 115668},
	{"SIMPLEBOARD", 11, 115669},
	{"TRICKING", 8, 115670},
	{"TARIFA", 6, 115671},
	{"LIQUIDATING", 11, 115672},
	{"BASINGER", 8, 115673},
	{"COMPACTING", 10, 115674},
	{"MERCYHURST", 10, 115675},
	{"CORROBORATE", 11, 115676},
	{"UODE", 4, 115677},
	{"PLIV", 4, 115678},
	{"NJAW", 4, 115679},
	{"LBYE", 4, 115680},
	{"HEFP", 4, 115681},
	{"EJAB", 4, 115682},
	{"DAKH", 4, 115683},
	{"MALHOTRA", 8, 115684},
	{"HORRY", 5, 115685},
	{"FIORDLAND", 9, 115686},
	{"LRB", 3, 115687},
	{"BICKNELL", 8, 115688},
	{"ACCE", 4, 115689},
	{"STRONA", 6, 115690},
	{"SHUFFLES", 8, 115691},
	{"ABORTS", 6, 115692},
	{"WAKER", 5, 115693},
	{"ERGOTRON", 8, 115694},
	{"FOLKLIFE", 8, 115695},
	{"ENVIED", 6, 115696},
	{"HANKINS", 7, 115697},
	{"ICAP", 4, 115698},
	{"DIRTIEST", 8, 115699},
	{"DENNEY", 6, 115700},
	{"FREECALL", 8, 115701},
	{"CHINS", 5, 115702},
	{"PSYCHOSOMATIC", 13, 115703},
	{"KIDNAPPINGS", 11, 115704},
	{"WPIC", 4, 115705},
	{"TFUS", 4, 115706},
	{"RDYL", 4, 115707},
	{"RAIB", 4, 115708},
	{"LPBE", 4, 115709},
	{"GIDL", 4, 115710},
	{"EMRB", 4, 115711},
	{"ELSJ", 4, 115712},
	{"EDCD", 4, 115713},
	{"CORING", 6, 115714},
	{"USERAGENT", 9, 115715},
	{"FRICTIONAL", 10, 115716},
	{"AVENA", 5, 115717},
	{"RUNT", 4, 115718},
	{"BENADRYL", 8, 115719},
	{"REZONE", 6, 115720},
	{"CONNEX", 6, 115721},
	{"SDTV", 4, 115722},
	{"NURSED", 6, 115723},
	{"MONOLAYERS", 10, 115724},
	{"TUTC", 4, 115725},
	{"TTYQ", 4, 115726},
	{"SLIZ", 4, 115727},
	{"LABD", 4, 115728},
	{"ICZO", 4, 115729},
	{"FSFR", 4, 115730},
	{"DNAZ", 4, 115731},
	{"BBOC", 4, 115732},
	{"FREEWNN", 7, 115733},
	{"CERI", 4, 115734},
	{"PLACEHOLDERS", 12, 115735},
	{"SQUIRM", 6, 115736},
	{"SHIPTON", 7, 115737},
	{"BILLINGSLEY", 11, 115738},
	{"PHILATELY", 9, 115739},
	{"REPAIRABLE", 10, 115740},
	{"PREFECTURAL", 11, 115741},
	{"SIEBERT", 7, 115742},
	{"LOATHSOME", 9, 115743},
	{"CHINCOTEAGUE", 12, 115744},
	{"ARKIN", 5, 115745},
	{"RENARD", 6, 115746},
	{"VACANZA", 7, 115747},
	{"YPOK", 4, 115748},
	{"WANL", 4, 115749},
	{"WALG", 4, 115750},
	{"UKBA", 4, 115751},
	{"PTLO", 4, 115752},
	{"PSHU", 4, 115753},
	{"OUEL", 4, 115754},
	{"LADF", 4, 115755},
	{"HTWR", 4, 115756},
	{"GLEJ", 4, 115757},
	{"GEEW", 4, 115758},
	{"FFJA", 4, 115759},
	{"DISEQUILIBRIUM", 14, 115760},
	{"OPENSP", 6, 115761},
	{"WICKES", 6, 115762},
	{"PAISTE", 6, 115763},
	{"COSAS", 5, 115764},
	{"DEPORTIVO", 9, 115765},
	{"ROCKBOX", 7, 115766},
	{"FESTIVA", 7, 115767},
	{"ORMAN", 5, 115768},
	{"SPRINGBOK", 9, 115769},
	{"TIBERIAN", 8, 115770},
	{"CHITA", 5, 115771},
	{"ALTHEA", 6, 115772},
	{"KJOS", 4, 115773},
	{"UKID", 4, 115774},
	{"RNBI", 4, 115775},
	{"PABR", 4, 115776},
	{"FUNM", 4, 115777},
	{"FTTU", 4, 115778},
	{"AJAG", 4, 115779},
	{"REVOLUTIONIZING", 15, 115780},
	{"HAMMACHER", 9, 115781},
	{"DANDO", 5, 115782},
	{"TRIPPY", 6, 115783},
	{"DIENSTAG", 8, 115784},
	{"TWISTERS", 8, 115785},
	{"HARMONIZING", 11, 115786},
	{"RANCE", 5, 115787},
	{"TULA", 4, 115788},
	{"MANDERLAY", 9, 115789},
	{"ICEBERGS", 8, 115790},
	{"VODKAPUNDIT", 11, 115791},
	{"SACKING", 7, 115792},
	{"SKINLESS", 8, 115793},
	{"SAUERKRAUT", 10, 115794},
	{"COSTUMING", 9, 115795},
	{"UDOC", 4, 115796},
	{"GDAD", 4, 115797},
	{"ESUZ", 4, 115798},
	{"CINR", 4, 115799},
	{"CLAPPER", 7, 115800},
	{"OPRYLAND", 8, 115801},
	{"SETTEE", 6, 115802},
	{"DRIEST", 6, 115803},
	{"BAUGH", 5, 115804},
	{"CALVO", 5, 115805},
	{"HARGRAVE", 8, 115806},
	{"INVER", 5, 115807},
	{"FPR", 3, 115808},
	{"COWETA", 6, 115809},
	{"KINOWY", 6, 115810},
	{"ONCORHYNCHUS", 12, 115811},
	{"JUV", 3, 115812},
	{"SCIPIO", 6, 115813},
	{"SUBSTATIONS", 11, 115814},
	{"BEAUTICIAN", 10, 115815},
	{"BASELIB", 7, 115816},
	{"CONCEN", 6, 115817},
	{"HENKE", 5, 115818},
	{"SYNTHESES", 9, 115819},
	{"UNDERPAID", 9, 115820},
	{"VACA", 4, 115821},
	{"STEALTHY", 8, 115822},
	{"GENTAMICIN", 10, 115823},
	{"UPSWING", 7, 115824},
	{"RYIC", 4, 115825},
	{"LTSY", 4, 115826},
	{"IUSG", 4, 115827},
	{"FLAUNT", 6, 115828},
	{"INTERROGATORS", 13, 115829},
	{"GRATIOT", 7, 115830},
	{"DIDI", 4, 115831},
	{"DOUBLEHEADER", 12, 115832},
	{"MISTAKING", 9, 115833},
	{"BASHAR", 6, 115834},
	{"HOOLIGAN", 8, 115835},
	{"GTKMM", 5, 115836},
	{"PACKAGERS", 9, 115837},
	{"TELEDYNE", 8, 115838},
	{"MDD", 3, 115839},
	{"ESCALANTE", 9, 115840},
	{"SITGES", 6, 115841},
	{"VCP", 3, 115842},
	{"DASHER", 6, 115843},
	{"GUNNERY", 7, 115844},
	{"DYSPEPSIA", 9, 115845},
	{"PERMS", 5, 115846},
	{"YSIW", 4, 115847},
	{"TVWO", 4, 115848},
	{"RLLA", 4, 115849},
	{"RIAJ", 4, 115850},
	{"KEKO", 4, 115851},
	{"IUSV", 4, 115852},
	{"GERQ", 4, 115853},
	{"CGOW", 4, 115854},
	{"OLINE", 5, 115855},
	{"DIGESTIBLE", 10, 115856},
	{"REAVER", 6, 115857},
	{"PAGENAME", 8, 115858},
	{"WLDJ", 4, 115859},
	{"AUGMENTS", 8, 115860},
	{"TRYST", 5, 115861},
	{"TAXID", 5, 115862},
	{"UNSWEETENED", 11, 115863},
	{"SETNAME", 7, 115864},
	{"DAYDREAMS", 9, 115865},
	{"CEDE", 4, 115866},
	{"VALUENGINE", 10, 115867},
	{"FICKKONTAKTE", 12, 115868},
	{"FLUORITE", 8, 115869},
	{"PLUGINVERSION", 13, 115870},
	{"BENCHMADE", 9, 115871},
	{"PYROLYSIS", 9, 115872},
	{"CONVENES", 8, 115873},
	{"SONOGRAPHY", 10, 115874},
	{"ANNIHILATE", 10, 115875},
	{"SAYLES", 6, 115876},
	{"WKAN", 4, 115877},
	{"WIKT", 4, 115878},
	{"ODDJ", 4, 115879},
	{"CALLUS", 6, 115880},
	{"MOESEN", 6, 115881},
	{"EQPT", 4, 115882},
	{"APOLOGIST", 9, 115883},
	{"NERUDA", 6, 115884},
	{"GYNECOLOGIST", 12, 115885},
	{"MCALISTER", 9, 115886},
	{"EUARCHONTOGLIRES", 16, 115887},
	{"TARTRATE", 8, 115888},
	{"RIDIN", 5, 115889},
	{"VATION", 6, 115890},
	{"CANDIDLY", 8, 115891},
	{"HONORABLY", 9, 115892},
	{"SHIFTY", 6, 115893},
	{"CALIBAN", 7, 115894},
	{"SNOWE", 5, 115895},
	{"RAFI", 4, 115896},
	{"COMDEX", 6, 115897},
	{"ANANOVA", 7, 115898},
	{"SOULSEEK", 8, 115899},
	{"ATTENTIONAL", 11, 115900},
	{"ZISM", 4, 115901},
	{"UNHU", 4, 115902},
	{"RETG", 4, 115903},
	{"LAYK", 4, 115904},
	{"BOWB", 4, 115905},
	{"BCSH", 4, 115906},
	{"ERTY", 4, 115907},
	{"ELLO", 4, 115908},
	{"EGLINTON", 8, 115909},
	{"ORPHANAGES", 10, 115910},
	{"RDL", 3, 115911},
	{"FOSSA", 5, 115912},
	{"BIOC", 4, 115913},
	{"NORWELL", 7, 115914},
	{"OLLI", 4, 115915},
	{"DECEPTIONS", 10, 115916},
	{"BOTANARY", 8, 115917},
	{"TAMURA", 6, 115918},
	{"SNORTED", 7, 115919},
	{"SYAB", 4, 115920},
	{"NARV", 4, 115921},
	{"GCIN", 4, 115922},
	{"FYYO", 4, 115923},
	{"EGPA", 4, 115924},
	{"DISY", 4, 115925},
	{"ABHU", 4, 115926},
	{"UPWIND", 6, 115927},
	{"FINLAYSON", 9, 115928},
	{"SIGNE", 5, 115929},
	{"KBR", 3, 115930},
	{"SHIVERED", 8, 115931},
	{"REPLENISHED", 11, 115932},
	{"OVEREXPOSURE", 12, 115933},
	{"HELMSLEY", 8, 115934},
	{"NEUTROPENIA", 11, 115935},
	{"MASSLESS", 8, 115936},
	{"ASSAILANTS", 10, 115937},
	{"FITMENT", 7, 115938},
	{"DEGENERACY", 10, 115939},
	{"HOSTELLING", 10, 115940},
	{"NEANDERTHAL", 11, 115941},
	{"UFAI", 4, 115942},
	{"OLFD", 4, 115943},
	{"HOLU", 4, 115944},
	{"GMYL", 4, 115945},
	{"FDAS", 4, 115946},
	{"MATZ", 4, 115947},
	{"LEMMING", 7, 115948},
	{"LAMININ", 7, 115949},
	{"APPENDS", 7, 115950},
	{"PERKINELMER", 11, 115951},
	{"MERIWETHER", 10, 115952},
	{"NEUROTOXICITY", 13, 115953},
	{"ETHERCHANNEL", 12, 115954},
	{"ROBT", 4, 115955},
	{"HUNTINGDONSHIRE", 15, 115956},
	{"ZOHAR", 5, 115957},
	{"VRAM", 4, 115958},
	{"KCRW", 4, 115959},
	{"GIOVANNA", 8, 115960},
	{"FLUORO", 6, 115961},
	{"CONSUMMATED", 11, 115962},
	{"MORAES", 6, 115963},
	{"LIPOPOLYSACCHARIDE", 18, 115964},
	{"COSIMO", 6, 115965},
	{"ADVERTISMENTS", 13, 115966},
	{"KINGTON", 7, 115967},
	{"INFOSET", 7, 115968},
	{"SETLOCALE", 9, 115969},
	{"URRB", 4, 115970},
	{"GGSF", 4, 115971},
	{"EGSP", 4, 115972},
	{"ECYP", 4, 115973},
	{"DUCL", 4, 115974},
	{"CELR", 4, 115975},
	{"ABAW", 4, 115976},
	{"CYANOBACTERIA", 13, 115977},
	{"EXTRANETS", 9, 115978},
	{"MORPHISMS", 9, 115979},
	{"THORA", 5, 115980},
	{"CSSKIM", 6, 115981},
	{"COTES", 5, 115982},
	{"GEOSTATIONARY", 13, 115983},
	{"ALANNA", 6, 115984},
	{"FERTILISATION", 13, 115985},
	{"POKERSTARS", 10, 115986},
	{"INSURABLE", 9, 115987},
	{"CLASSLOADER", 11, 115988},
	{"YPIS", 4, 115989},
	{"YNUT", 4, 115990},
	{"YDST", 4, 115991},
	{"WTHD", 4, 115992},
	{"VANQ", 4, 115993},
	{"PSRI", 4, 115994},
	{"PERQ", 4, 115995},
	{"NGND", 4, 115996},
	{"LOPB", 4, 115997},
	{"KGUN", 4, 115998},
	{"IKIB", 4, 115999},
	{"EMRM", 4, 116000},
	{"COLF", 4, 116001},
	{"OBSTINATE", 9, 116002},
	{"MULTIPARTY", 10, 116003},
	{"RUDMAN", 6, 116004},
	{"EARTHWORK", 9, 116005},
	{"LEESON", 6, 116006},
	{"CARDEN", 6, 116007},
	{"ARTESIAN", 8, 116008},
	{"JEOPARDIZED", 11, 116009},
	{"HENSHAW", 7, 116010},
	{"FRIO", 4, 116011},
	{"CASSEGRAIN", 10, 116012},
	{"RETINOBLASTOMA", 14, 116013},
	{"PIPELINED", 9, 116014},
	{"BACKDOORS", 9, 116015},
	{"DRIV", 4, 116016},
	{"BITKEEPER", 9, 116017},
	{"SEROLOGY", 8, 116018},
	{"DISORIENTED", 11, 116019},
	{"ALPHABETIZED", 12, 116020},
	{"BUTTOCK", 7, 116021},
	{"FARQUHAR", 8, 116022},
	{"CONSE", 5, 116023},
	{"ERGODIC", 7, 116024},
	{"YOLY", 4, 116025},
	{"YAMM", 4, 116026},
	{"WPHI", 4, 116027},
	{"WCEL", 4, 116028},
	{"UAHU", 4, 116029},
	{"RCYB", 4, 116030},
	{"HRAJ", 4, 116031},
	{"FFSR", 4, 116032},
	{"FBID", 4, 116033},
	{"EMFU", 4, 116034},
	{"CLYR", 4, 116035},
	{"AWHY", 4, 116036},
	{"SUPERSEDING", 11, 116037},
	{"RETRACE", 7, 116038},
	{"LINEWIDTH", 9, 116039},
	{"VERONIQUE", 9, 116040},
	{"GLASSHOUSE", 10, 116041},
	{"GRABER", 6, 116042},
	{"REVOLVERS", 9, 116043},
	{"BROADCASTED", 11, 116044},
	{"LURCH", 5, 116045},
	{"SEVASTOPOL", 10, 116046},
	{"BRAINDUMPS", 10, 116047},
	{"MEDALLIST", 9, 116048},
	{"GREGARIOUS", 10, 116049},
	{"INDUCTEES", 9, 116050},
	{"TORRENTIAL", 10, 116051},
	{"JETWAY", 6, 116052},
	{"ALLEE", 5, 116053},
	{"SUPERSET", 8, 116054},
	{"BROCKMAN", 8, 116055},
	{"UGBE", 4, 116056},
	{"HWAD", 4, 116057},
	{"GNUN", 4, 116058},
	{"BOWR", 4, 116059},
	{"CAMILO", 6, 116060},
	{"BONK", 4, 116061},
	{"ELECTROWEAK", 11, 116062},
	{"ZEVON", 5, 116063},
	{"LUBLIN", 6, 116064},
	{"NIGHTGOWN", 9, 116065},
	{"APARTAMENTY", 11, 116066},
	{"SYSTRAN", 7, 116067},
	{"SPLURGE", 7, 116068},
	{"BOMBARD", 7, 116069},
	{"MAGPIES", 7, 116070},
	{"STALINGRAD", 10, 116071},
	{"MISSUS", 6, 116072},
	{"MYSTIFIED", 9, 116073},
	{"SANDIEGO", 8, 116074},
	{"MATTA", 5, 116075},
	{"HASHED", 6, 116076},
	{"DROOPING", 8, 116077},
	{"TDOZ", 4, 116078},
	{"RVAB", 4, 116079},
	{"MNIB", 4, 116080},
	{"IMPY", 4, 116081},
	{"IDNU", 4, 116082},
	{"IDKO", 4, 116083},
	{"DEEU", 4, 116084},
	{"BSOM", 4, 116085},
	{"AMLU", 4, 116086},
	{"QUASH", 5, 116087},
	{"AEROPUERTO", 10, 116088},
	{"ADJUDICATE", 10, 116089},
	{"DIABLE", 6, 116090},
	{"INCONSIDERATE", 13, 116091},
	{"TICTAP", 6, 116092},
	{"HEFLIN", 6, 116093},
	{"BCOM", 4, 116094},
	{"HIGHCHAIRS", 10, 116095},
	{"MYTRAVEL", 8, 116096},
	{"MOUSETRAP", 9, 116097},
	{"DEFPOINTS", 9, 116098},
	{"NAMESERVERS", 11, 116099},
	{"RASUR", 5, 116100},
	{"SCHWARZKOPF", 11, 116101},
	{"CIALLY", 6, 116102},
	{"ROSEMEAD", 8, 116103},
	{"HOKEY", 5, 116104},
	{"ENDOCYTOSIS", 11, 116105},
	{"SREF", 4, 116106},
	{"SWIRLED", 7, 116107},
	{"RAMSES", 6, 116108},
	{"DLOPEN", 6, 116109},
	{"FARIBAULT", 9, 116110},
	{"DARTED", 6, 116111},
	{"SYGATE", 6, 116112},
	{"WARLIKE", 7, 116113},
	{"USTR", 4, 116114},
	{"PARTICIPATIVE", 13, 116115},
	{"BERNER", 6, 116116},
	{"PREPRINTED", 10, 116117},
	{"SOUTHBANK", 9, 116118},
	{"RUMU", 4, 116119},
	{"RMAO", 4, 116120},
	{"OUDU", 4, 116121},
	{"LABH", 4, 116122},
	{"CSOP", 4, 116123},
	{"BIDP", 4, 116124},
	{"COLONS", 6, 116125},
	{"DUOS", 4, 116126},
	{"BINDIR", 6, 116127},
	{"WHEATGRASS", 10, 116128},
	{"SUPPLICATION", 12, 116129},
	{"FRETTED", 7, 116130},
	{"BEGONIA", 7, 116131},
	{"TUGJOB", 6, 116132},
	{"COURTENEY", 9, 116133},
	{"RABINOWITZ", 10, 116134},
	{"SCREAMER", 8, 116135},
	{"BOYLAN", 6, 116136},
	{"JANEANE", 7, 116137},
	{"ZCB", 3, 116138},
	{"XVV", 3, 116139},
	{"WZL", 3, 116140},
	{"WJK", 3, 116141},
	{"WBQ", 3, 116142},
	{"VZC", 3, 116143},
	{"VQD", 3, 116144},
	{"QMG", 3, 116145},
	{"GWX", 3, 116146},
	{"MEDA", 4, 116147},
	{"DECLARANT", 9, 116148},
	{"BUSSELTON", 9, 116149},
	{"SALTO", 5, 116150},
	{"RUTA", 4, 116151},
	{"PRACTICALS", 10, 116152},
	{"YEPA", 4, 116153},
	{"UJAN", 4, 116154},
	{"THKL", 4, 116155},
	{"OPTU", 4, 116156},
	{"LEHY", 4, 116157},
	{"IFFM", 4, 116158},
	{"HSCL", 4, 116159},
	{"GASV", 4, 116160},
	{"BAKEWELL", 8, 116161},
	{"RIFAMPIN", 8, 116162},
	{"SMITS", 5, 116163},
	{"GAUGED", 6, 116164},
	{"POSTHUMOUSLY", 12, 116165},
	{"DIETERS", 7, 116166},
	{"UKGML", 5, 116167},
	{"OVERHANGING", 11, 116168},
	{"PUSAN", 5, 116169},
	{"POPP", 4, 116170},
	{"UKC", 3, 116171},
	{"SEONG", 5, 116172},
	{"GIGMASTERS", 10, 116173},
	{"MARKE", 5, 116174},
	{"SILVERLINE", 10, 116175},
	{"IMPROPRIETY", 11, 116176},
	{"RLIZ", 4, 116177},
	{"ERBM", 4, 116178},
	{"ADJUSTRIGHT", 11, 116179},
	{"BLC", 3, 116180},
	{"SONUS", 5, 116181},
	{"MALIGNED", 8, 116182},
	{"REPACKAGED", 10, 116183},
	{"THACKERAY", 9, 116184},
	{"INFOPRINT", 9, 116185},
	{"OFERTA", 6, 116186},
	{"PULVER", 6, 116187},
	{"ALCUDIA", 7, 116188},
	{"SORENSTAM", 9, 116189},
	{"SCHOHARIE", 9, 116190},
	{"CASTRIES", 8, 116191},
	{"CONCERNANT", 10, 116192},
	{"EISENSTEIN", 10, 116193},
	{"YRNA", 4, 116194},
	{"YAZA", 4, 116195},
	{"ULSS", 4, 116196},
	{"UERH", 4, 116197},
	{"NZOR", 4, 116198},
	{"MIFA", 4, 116199},
	{"IECK", 4, 116200},
	{"ROACHES", 7, 116201},
	{"NOUGHT", 6, 116202},
	{"PKTS", 4, 116203},
	{"ACOG", 4, 116204},
	{"BARDOT", 6, 116205},
	{"BARBAROUS", 9, 116206},
	{"HUTSON", 6, 116207},
	{"EXPRESSIVENESS", 14, 116208},
	{"BOERNE", 6, 116209},
	{"WSSD", 4, 116210},
	{"DESCRIZIONE", 11, 116211},
	{"CLES", 4, 116212},
	{"ASHBROOK", 8, 116213},
	{"MOMJIAN", 7, 116214},
	{"GRANDI", 6, 116215},
	{"LANDRIEU", 8, 116216},
	{"YVAS", 4, 116217},
	{"YSMY", 4, 116218},
	{"VYAR", 4, 116219},
	{"RCIF", 4, 116220},
	{"POWI", 4, 116221},
	{"MYJU", 4, 116222},
	{"MTAM", 4, 116223},
	{"LFPL", 4, 116224},
	{"GTID", 4, 116225},
	{"EUSJ", 4, 116226},
	{"EPHF", 4, 116227},
	{"AZYW", 4, 116228},
	{"AGAK", 4, 116229},
	{"SINKER", 6, 116230},
	{"PRACTICEMASTER", 14, 116231},
	{"NYQUIST", 7, 116232},
	{"ISERE", 5, 116233},
	{"UNPREDICTABILITY", 16, 116234},
	{"OLLY", 4, 116235},
	{"HAHNEMANN", 9, 116236},
	{"INSPEC", 6, 116237},
	{"LARP", 4, 116238},
	{"SOUTHAFRICA", 11, 116239},
	{"ESPNU", 5, 116240},
	{"UBAB", 4, 116241},
	{"SUBH", 4, 116242},
	{"PSVE", 4, 116243},
	{"NCHJ", 4, 116244},
	{"IARG", 4, 116245},
	{"FFOV", 4, 116246},
	{"DAED", 4, 116247},
	{"BYKU", 4, 116248},
	{"BMOR", 4, 116249},
	{"LICH", 4, 116250},
	{"DUX", 3, 116251},
	{"EGGNOG", 6, 116252},
	{"MACDOUGALL", 10, 116253},
	{"ORIENTALE", 9, 116254},
	{"SFSU", 4, 116255},
	{"ENDDO", 5, 116256},
	{"PULSARS", 7, 116257},
	{"WIKIBOOKS", 9, 116258},
	{"CORDING", 7, 116259},
	{"PRESCRIPTIVES", 13, 116260},
	{"SCEPTER", 7, 116261},
	{"EVISTA", 6, 116262},
	{"APHRODISIACS", 12, 116263},
	{"SICJ", 4, 116264},
	{"RCTH", 4, 116265},
	{"MYNI", 4, 116266},
	{"LIFL", 4, 116267},
	{"IXRO", 4, 116268},
	{"ISVU", 4, 116269},
	{"CNNC", 4, 116270},
	{"AUGP", 4, 116271},
	{"DOCUPRINT", 9, 116272},
	{"WRITHING", 8, 116273},
	{"SCRAPIE", 7, 116274},
	{"MALAMUTE", 8, 116275},
	{"RENATE", 6, 116276},
	{"ENTICED", 7, 116277},
	{"LUCIANA", 7, 116278},
	{"LURIE", 5, 116279},
	{"GLUCONATE", 9, 116280},
	{"BACKHAUL", 8, 116281},
	{"KENNEBUNKPORT", 13, 116282},
	{"WIRTZ", 5, 116283},
	{"SCHMUCK", 7, 116284},
	{"SERVEWARE", 9, 116285},
	{"MUFTI", 5, 116286},
	{"WEOW", 4, 116287},
	{"OGAY", 4, 116288},
	{"MBYF", 4, 116289},
	{"ILKB", 4, 116290},
	{"IJEW", 4, 116291},
	{"HURH", 4, 116292},
	{"GNFL", 4, 116293},
	{"EIBR", 4, 116294},
	{"IRONCLAD", 8, 116295},
	{"UPMC", 4, 116296},
	{"CASTLEFORD", 10, 116297},
	{"IMAGENS", 7, 116298},
	{"GASPS", 5, 116299},
	{"POLIOVIRUS", 10, 116300},
	{"EXCLAIM", 7, 116301},
	{"REHASH", 6, 116302},
	{"LITTERING", 9, 116303},
	{"ABKHAZIA", 8, 116304},
	{"PETALING", 8, 116305},
	{"GNRH", 4, 116306},
	{"DCCC", 4, 116307},
	{"GALLI", 5, 116308},
	{"PLASMATELEVISION", 16, 116309},
	{"SHEVCHENKO", 10, 116310},
	{"GREVE", 5, 116311},
	{"CUC", 3, 116312},
	{"WTWI", 4, 116313},
	{"VSPO", 4, 116314},
	{"PTYN", 4, 116315},
	{"ERLT", 4, 116316},
	{"EMVI", 4, 116317},
	{"DUMS", 4, 116318},
	{"DJIL", 4, 116319},
	{"NITION", 6, 116320},
	{"MAEVE", 5, 116321},
	{"BRAINARD", 8, 116322},
	{"ENLACE", 6, 116323},
	{"CONFUCIAN", 9, 116324},
	{"VESTIGES", 8, 116325},
	{"YOGYAKARTA", 10, 116326},
	{"BANANARAMA", 10, 116327},
	{"HARRASSMENT", 11, 116328},
	{"OPINIONJOURNAL", 14, 116329},
	{"RUSTLING", 8, 116330},
	{"GOEL", 4, 116331},
	{"SEPTA", 5, 116332},
	{"SODOMIE", 7, 116333},
	{"BRAINWAVE", 9, 116334},
	{"CLAVIER", 7, 116335},
	{"KIELY", 5, 116336},
	{"SARDEGNA", 8, 116337},
	{"URBANWORKS", 10, 116338},
	{"YBRY", 4, 116339},
	{"URFB", 4, 116340},
	{"UESQ", 4, 116341},
	{"UDSH", 4, 116342},
	{"TLYQ", 4, 116343},
	{"OKIF", 4, 116344},
	{"OBPE", 4, 116345},
	{"MMOF", 4, 116346},
	{"LPWA", 4, 116347},
	{"LIMG", 4, 116348},
	{"KLEJ", 4, 116349},
	{"ICAK", 4, 116350},
	{"HWHY", 4, 116351},
	{"HBLE", 4, 116352},
	{"ETCY", 4, 116353},
	{"PURIST", 6, 116354},
	{"RECAPTURED", 10, 116355},
	{"FREESTONE", 9, 116356},
	{"FORMULAIC", 9, 116357},
	{"SMIRNOV", 7, 116358},
	{"HITECH", 6, 116359},
	{"AWWA", 4, 116360},
	{"EARTHWORM", 9, 116361},
	{"PHONEMES", 8, 116362},
	{"MARAUDERS", 9, 116363},
	{"SPARS", 5, 116364},
	{"DELISTING", 9, 116365},
	{"DISHED", 6, 116366},
	{"KBES", 4, 116367},
	{"IRMG", 4, 116368},
	{"INYR", 4, 116369},
	{"HYIW", 4, 116370},
	{"GHYI", 4, 116371},
	{"GEHW", 4, 116372},
	{"BSKI", 4, 116373},
	{"AORL", 4, 116374},
	{"FRISE", 5, 116375},
	{"PUK", 3, 116376},
	{"CORNED", 6, 116377},
	{"SHOCKLEY", 8, 116378},
	{"LEFTON", 6, 116379},
	{"KEISHA", 6, 116380},
	{"LIFEGUARDS", 10, 116381},
	{"BRIDPORT", 8, 116382},
	{"ANTISERUM", 9, 116383},
	{"BIRTHWEIGHT", 11, 116384},
	{"RVR", 3, 116385},
	{"HOWLS", 5, 116386},
	{"SEISMICITY", 10, 116387},
	{"ANSWERABLE", 10, 116388},
	{"SPINK", 5, 116389},
	{"INKY", 4, 116390},
	{"YASSIN", 6, 116391},
	{"TRIPLICATE", 10, 116392},
	{"CMAP", 4, 116393},
	{"STICKNEY", 8, 116394},
	{"VIWA", 4, 116395},
	{"ULOC", 4, 116396},
	{"MPSR", 4, 116397},
	{"MPHF", 4, 116398},
	{"FDRY", 4, 116399},
	{"EARZ", 4, 116400},
	{"BUYCENTRAL", 10, 116401},
	{"PECTORAL", 8, 116402},
	{"SNEER", 5, 116403},
	{"STICKINESS", 10, 116404},
	{"SAATCHI", 7, 116405},
	{"KUNKEL", 6, 116406},
	{"CATACLYSMIC", 11, 116407},
	{"CURIA", 5, 116408},
	{"SOEKRIS", 7, 116409},
	{"CONOCO", 6, 116410},
	{"HUSTLERS", 8, 116411},
	{"BRIDLINGTON", 11, 116412},
	{"XPAS", 4, 116413},
	{"WITL", 4, 116414},
	{"OZEL", 4, 116415},
	{"NBCH", 4, 116416},
	{"LOWQ", 4, 116417},
	{"IDLU", 4, 116418},
	{"GBOK", 4, 116419},
	{"DYSK", 4, 116420},
	{"DUGI", 4, 116421},
	{"ALLAY", 5, 116422},
	{"BRATT", 5, 116423},
	{"DERISION", 8, 116424},
	{"ESHER", 5, 116425},
	{"UNLOGGED", 8, 116426},
	{"IDIOTARIAN", 10, 116427},
	{"PARACHUTING", 11, 116428},
	{"DUTIFULLY", 9, 116429},
	{"INSTALLABLE", 11, 116430},
	{"RESAMPLING", 10, 116431},
	{"VITAMINE", 8, 116432},
	{"FREDERICKS", 10, 116433},
	{"TAMILS", 6, 116434},
	{"HONOREE", 7, 116435},
	{"PLYMPTON", 8, 116436},
	{"WWTH", 4, 116437},
	{"RUJI", 4, 116438},
	{"ROHU", 4, 116439},
	{"RLDK", 4, 116440},
	{"OVEQ", 4, 116441},
	{"IGFR", 4, 116442},
	{"EKDO", 4, 116443},
	{"CROD", 4, 116444},
	{"OCTAVO", 6, 116445},
	{"POSTA", 5, 116446},
	{"ORANGUTAN", 9, 116447},
	{"JERROLD", 7, 116448},
	{"PISGAH", 6, 116449},
	{"ZONDER", 6, 116450},
	{"MADDENING", 9, 116451},
	{"NONTOXIC", 8, 116452},
	{"DURGA", 5, 116453},
	{"FALCONRY", 8, 116454},
	{"SPRATLY", 7, 116455},
	{"LEXICONS", 8, 116456},
	{"LANTZ", 5, 116457},
	{"IDEALISTA", 9, 116458},
	{"BACKBOARD", 9, 116459},
	{"ISCHAEMIC", 9, 116460},
	{"BAILOUT", 7, 116461},
	{"PRECONCEPTIONS", 14, 116462},
	{"NIQUES", 6, 116463},
	{"MIDDLEMEN", 9, 116464},
	{"AERONET", 7, 116465},
	{"PLUNDERED", 9, 116466},
	{"MARCHERS", 8, 116467},
	{"OBPA", 4, 116468},
	{"GJES", 4, 116469},
	{"DDRM", 4, 116470},
	{"REFORMATTING", 12, 116471},
	{"SLAMBALL", 8, 116472},
	{"CORIAN", 6, 116473},
	{"DAMIT", 5, 116474},
	{"BICOLOR", 7, 116475},
	{"HENRIETTE", 9, 116476},
	{"CREDENZA", 8, 116477},
	{"BUELLER", 7, 116478},
	{"IMPEX", 5, 116479},
	{"DECRY", 5, 116480},
	{"FELIXSTOWE", 10, 116481},
	{"BUEN", 4, 116482},
	{"EVINRUDE", 8, 116483},
	{"ANNULUS", 7, 116484},
	{"PCLAW", 5, 116485},
	{"GUINESS", 7, 116486},
	{"NEWTONS", 7, 116487},
	{"NEWFIELD", 8, 116488},
	{"TSSOP", 5, 116489},
	{"DEVANT", 6, 116490},
	{"FENNELL", 7, 116491},
	{"CONSPIRATOR", 11, 116492},
	{"SUDHIR", 6, 116493},
	{"YIGO", 4, 116494},
	{"UMIM", 4, 116495},
	{"TDWA", 4, 116496},
	{"QDOY", 4, 116497},
	{"KGAV", 4, 116498},
	{"EZAK", 4, 116499},
	{"DRBR", 4, 116500},
	{"CJOB", 4, 116501},
	{"AGAF", 4, 116502},
	{"HXWXD", 5, 116503},
	{"LURING", 6, 116504},
	{"JABEZ", 5, 116505},
	{"PROMISCUITY", 11, 116506},
	{"TRANSITIONED", 12, 116507},
	{"GALLANTRY", 9, 116508},
	{"ZYX", 3, 116509},
	{"MITTEE", 6, 116510},
	{"WHISKED", 7, 116511},
	{"TROCADERO", 9, 116512},
	{"MEJIA", 5, 116513},
	{"YEEC", 4, 116514},
	{"WETC", 4, 116515},
	{"RNSK", 4, 116516},
	{"RLUM", 4, 116517},
	{"PIGR", 4, 116518},
	{"LGLI", 4, 116519},
	{"EMYJ", 4, 116520},
	{"DYEM", 4, 116521},
	{"MORDECHAI", 9, 116522},
	{"OUTCROPS", 8, 116523},
	{"TIMUR", 5, 116524},
	{"INTERLOCUTORY", 13, 116525},
	{"PERICLES", 8, 116526},
	{"DESERTION", 9, 116527},
	{"PSPP", 4, 116528},
	{"FLP", 3, 116529},
	{"MINOW", 5, 116530},
	{"REEMPLOYMENT", 12, 116531},
	{"CRESWELL", 8, 116532},
	{"CREWMEMBERS", 11, 116533},
	{"KIROV", 5, 116534},
	{"FLIRTS", 6, 116535},
	{"ALGA", 4, 116536},
	{"DRYSDALE", 8, 116537},
	{"ACROBATICS", 10, 116538},
	{"YGIB", 4, 116539},
	{"VORR", 4, 116540},
	{"UDPR", 4, 116541},
	{"OJOR", 4, 116542},
	{"NKGA", 4, 116543},
	{"JOEK", 4, 116544},
	{"DAAF", 4, 116545},
	{"AEDG", 4, 116546},
	{"WITTED", 6, 116547},
	{"KATAKANA", 8, 116548},
	{"SRPSKA", 6, 116549},
	{"NOVELLO", 7, 116550},
	{"DANC", 4, 116551},
	{"ARGUABLE", 8, 116552},
	{"ECLAMPSIA", 9, 116553},
	{"RUMANIA", 7, 116554},
	{"LEEUWEN", 7, 116555},
	{"DEMOTION", 8, 116556},
	{"SINFULL", 7, 116557},
	{"BONZAI", 6, 116558},
	{"WHEREWITH", 9, 116559},
	{"SILICEOUS", 9, 116560},
	{"SAILFISH", 8, 116561},
	{"RFU", 3, 116562},
	{"MILONIC", 7, 116563},
	{"PADH", 4, 116564},
	{"LDUC", 4, 116565},
	{"FTUL", 4, 116566},
	{"FFAH", 4, 116567},
	{"EZSC", 4, 116568},
	{"BTLY", 4, 116569},
	{"SMURFS", 6, 116570},
	{"BLADEN", 6, 116571},
	{"TELEFONIA", 9, 116572},
	{"MUND", 4, 116573},
	{"SUTER", 5, 116574},
	{"GREASEMONKEY", 12, 116575},
	{"CIRCULATES", 10, 116576},
	{"MANATEES", 8, 116577},
	{"FARIA", 5, 116578},
	{"SIGNORE", 7, 116579},
	{"COLDLY", 6, 116580},
	{"MCLUHAN", 7, 116581},
	{"TRADENAME", 9, 116582},
	{"UNENCRYPTED", 11, 116583},
	{"PROVID", 6, 116584},
	{"FENUGREEK", 9, 116585},
	{"ENVOYS", 6, 116586},
	{"IMGT", 4, 116587},
	{"POLYPHONE", 9, 116588},
	{"METEOROLOGISTS", 14, 116589},
	{"RESTORER", 8, 116590},
	{"EQUIPO", 6, 116591},
	{"RMAE", 4, 116592},
	{"RKEG", 4, 116593},
	{"QWER", 4, 116594},
	{"MRSD", 4, 116595},
	{"IKIR", 4, 116596},
	{"GIZM", 4, 116597},
	{"FEXH", 4, 116598},
	{"BOTULISM", 8, 116599},
	{"PYRIDOXINE", 10, 116600},
	{"STAVES", 6, 116601},
	{"VEDANTA", 7, 116602},
	{"COLDNESS", 8, 116603},
	{"OUSLY", 5, 116604},
	{"DEPOLARIZATION", 14, 116605},
	{"LISTNAME", 8, 116606},
	{"CHAUVET", 7, 116607},
	{"NOGUCHI", 7, 116608},
	{"SPELLBINDING", 12, 116609},
	{"ISIDRO", 6, 116610},
	{"PASCALE", 7, 116611},
	{"GROUCHY", 7, 116612},
	{"RASPUTIN", 8, 116613},
	{"VALANCES", 8, 116614},
	{"ASUNCION", 8, 116615},
	{"SGLU", 4, 116616},
	{"HSCU", 4, 116617},
	{"EVYC", 4, 116618},
	{"EBEK", 4, 116619},
	{"BULW", 4, 116620},
	{"AMCD", 4, 116621},
	{"EXISTE", 6, 116622},
	{"GUMMI", 5, 116623},
	{"FRIESLAND", 9, 116624},
	{"SIZER", 5, 116625},
	{"MOCA", 4, 116626},
	{"MOBSTER", 7, 116627},
	{"ORDEN", 5, 116628},
	{"HITOMI", 6, 116629},
	{"RIVIERE", 7, 116630},
	{"DEVIZES", 7, 116631},
	{"YMYC", 4, 116632},
	{"XFLA", 4, 116633},
	{"OGDO", 4, 116634},
	{"MYCI", 4, 116635},
	{"EXDR", 4, 116636},
	{"CYFU", 4, 116637},
	{"CTKN", 4, 116638},
	{"ADUK", 4, 116639},
	{"NCSOFT", 6, 116640},
	{"SIBLU", 5, 116641},
	{"JPM", 3, 116642},
	{"ROGERSON", 8, 116643},
	{"THROWABLE", 9, 116644},
	{"CROATS", 6, 116645},
	{"AVOWED", 6, 116646},
	{"LUMINAIRES", 10, 116647},
	{"CARDSCAN", 8, 116648},
	{"HALESOWEN", 9, 116649},
	{"GUSTY", 5, 116650},
	{"SENSEO", 6, 116651},
	{"ESHOWCASE", 9, 116652},
	{"OODLES", 6, 116653},
	{"BAFTA", 5, 116654},
	{"DICOTA", 6, 116655},
	{"CANALES", 7, 116656},
	{"BRAZIER", 7, 116657},
	{"BAYREUTH", 8, 116658},
	{"TUDO", 4, 116659},
	{"OLDSCHOOL", 9, 116660},
	{"CASTAWAYS", 9, 116661},
	{"ASSAMESE", 8, 116662},
	{"WGLO", 4, 116663},
	{"TSMD", 4, 116664},
	{"NDCN", 4, 116665},
	{"MRSR", 4, 116666},
	{"IFFP", 4, 116667},
	{"EUCE", 4, 116668},
	{"EAWK", 4, 116669},
	{"SONNTAG", 7, 116670},
	{"LIBG", 4, 116671},
	{"GRENFELL", 8, 116672},
	{"CSUS", 4, 116673},
	{"APRESS", 6, 116674},
	{"ABHISHEK", 8, 116675},
	{"ARCHON", 6, 116676},
	{"PIGSTYLE", 8, 116677},
	{"FILOFAX", 7, 116678},
	{"INTERNATIONALIST", 16, 116679},
	{"SEMAINE", 7, 116680},
	{"GODLINESS", 9, 116681},
	{"POWERBOATING", 12, 116682},
	{"OCOEE", 5, 116683},
	{"NORTHRUP", 8, 116684},
	{"GOTFRAG", 7, 116685},
	{"DOCILE", 6, 116686},
	{"SPYCAMS", 7, 116687},
	{"DWM", 3, 116688},
	{"TEJAS", 5, 116689},
	{"SATYRICON", 9, 116690},
	{"PROSTATECTOMY", 13, 116691},
	{"BUTTLE", 6, 116692},
	{"MALICIOUSLY", 11, 116693},
	{"ZBEC", 4, 116694},
	{"YARK", 4, 116695},
	{"WOJO", 4, 116696},
	{"VYBO", 4, 116697},
	{"VEZE", 4, 116698},
	{"TCBU", 4, 116699},
	{"ONFM", 4, 116700},
	{"IMJA", 4, 116701},
	{"CTGI", 4, 116702},
	{"ARUH", 4, 116703},
	{"ANDR", 4, 116704},
	{"SHOWMANSHIP", 11, 116705},
	{"KLINIK", 6, 116706},
	{"MATHUR", 6, 116707},
	{"VOLE", 4, 116708},
	{"CLUTCHED", 8, 116709},
	{"CANTONS", 7, 116710},
	{"SIGLO", 5, 116711},
	{"ENVELOPING", 10, 116712},
	{"WRIGHTS", 7, 116713},
	{"HIGHTECH", 8, 116714},
	{"KEOKUK", 6, 116715},
	{"PIEDRA", 6, 116716},
	{"SUBITO", 6, 116717},
	{"NOMAR", 5, 116718},
	{"JSUT", 4, 116719},
	{"UCERTIFY", 8, 116720},
	{"SUNSCREENS", 10, 116721},
	{"BELMAR", 6, 116722},
	{"REFI", 4, 116723},
	{"WEIMER", 6, 116724},
	{"WSKA", 4, 116725},
	{"TNBC", 4, 116726},
	{"SKRO", 4, 116727},
	{"PYDI", 4, 116728},
	{"FONM", 4, 116729},
	{"ENUK", 4, 116730},
	{"EFOW", 4, 116731},
	{"TANGLES", 7, 116732},
	{"SUCKY", 5, 116733},
	{"SCRIVENER", 9, 116734},
	{"PARADOR", 7, 116735},
	{"WELLFLEET", 9, 116736},
	{"MEANEST", 7, 116737},
	{"BASCOM", 6, 116738},
	{"MAERSK", 6, 116739},
	{"AEROBATIC", 9, 116740},
	{"CARABINERS", 10, 116741},
	{"REFUTES", 7, 116742},
	{"SUBSEQUENCE", 11, 116743},
	{"BLOODBORNE", 10, 116744},
	{"MUDGE", 5, 116745},
	{"CARDIOID", 8, 116746},
	{"LOVETOKNOW", 10, 116747},
	{"MPB", 3, 116748},
	{"HOLLOWS", 7, 116749},
	{"YRAW", 4, 116750},
	{"PICL", 4, 116751},
	{"NDMD", 4, 116752},
	{"IWAK", 4, 116753},
	{"EVYO", 4, 116754},
	{"DECILE", 6, 116755},
	{"LUCKIEST", 8, 116756},
	{"DOMINICANA", 10, 116757},
	{"REPROGRAMMING", 13, 116758},
	{"SQUYRES", 7, 116759},
	{"RESERVAS", 8, 116760},
	{"DUK", 3, 116761},
	{"SLIPSTREAM", 10, 116762},
	{"OFFICIATE", 9, 116763},
	{"GARG", 4, 116764},
	{"MUMBLE", 6, 116765},
	{"DECEMBERISTS", 12, 116766},
	{"TIGNES", 6, 116767},
	{"MARIES", 6, 116768},
	{"ARAL", 4, 116769},
	{"YRIO", 4, 116770},
	{"XBOY", 4, 116771},
	{"PDRE", 4, 116772},
	{"MCAI", 4, 116773},
	{"FVAS", 4, 116774},
	{"DAXE", 4, 116775},
	{"AZYI", 4, 116776},
	{"MINIMAX", 7, 116777},
	{"SUBSPECIALTY", 12, 116778},
	{"WEICHERT", 8, 116779},
	{"GOOSEBUMPS", 10, 116780},
	{"BIANNUAL", 8, 116781},
	{"CONGENIALITY", 12, 116782},
	{"VASCULITIS", 10, 116783},
	{"COMPLICIT", 9, 116784},
	{"SUBSTANTIATION", 14, 116785},
	{"KUTZTOWN", 8, 116786},
	{"DEPLIBS", 7, 116787},
	{"GUSTER", 6, 116788},
	{"SAFFORD", 7, 116789},
	{"SALAUN", 6, 116790},
	{"HUNTERSVILLE", 12, 116791},
	{"MONTECITO", 9, 116792},
	{"CAPITATION", 10, 116793},
	{"SONGBIRDS", 9, 116794},
	{"ESPACIO", 7, 116795},
	{"DEVRIES", 7, 116796},
	{"OPPRESS", 7, 116797},
	{"EXCERTO", 7, 116798},
	{"CITEBASE", 8, 116799},
	{"VBADVANCED", 10, 116800},
	{"ECCE", 4, 116801},
	{"YALV", 4, 116802},
	{"XTOB", 4, 116803},
	{"XTBU", 4, 116804},
	{"OFCD", 4, 116805},
	{"NKUA", 4, 116806},
	{"LOYW", 4, 116807},
	{"KIGA", 4, 116808},
	{"GIGN", 4, 116809},
	{"FANR", 4, 116810},
	{"ABRY", 4, 116811},
	{"GRANDFATHERS", 12, 116812},
	{"GETRIGHT", 8, 116813},
	{"MRK", 3, 116814},
	{"WEATHERMAN", 10, 116815},
	{"SPILSBURY", 9, 116816},
	{"SEGV", 4, 116817},
	{"USURY", 5, 116818},
	{"TORRENS", 7, 116819},
	{"APOLOGISES", 10, 116820},
	{"YESDIRECT", 9, 116821},
	{"PPPS", 4, 116822},
	{"ISADORA", 7, 116823},
	{"SENCO", 5, 116824},
	{"YOSSI", 5, 116825},
	{"LYNCHET", 7, 116826},
	{"NEUROSURG", 9, 116827},
	{"FREINDS", 7, 116828},
	{"REDES", 5, 116829},
	{"RUSSES", 6, 116830},
	{"MEMRI", 5, 116831},
	{"ENDURA", 6, 116832},
	{"COVERUP", 7, 116833},
	{"ALDEHYDES", 9, 116834},
	{"GREEDILY", 8, 116835},
	{"FUSCHIA", 7, 116836},
	{"STREPTOMYCIN", 12, 116837},
	{"VSWI", 4, 116838},
	{"SKDO", 4, 116839},
	{"RTSQ", 4, 116840},
	{"DZIM", 4, 116841},
	{"ACGR", 4, 116842},
	{"WNEUD", 5, 116843},
	{"EKATERINBURG", 12, 116844},
	{"BRANCO", 6, 116845},
	{"REEVALUATE", 10, 116846},
	{"PADLOCKS", 8, 116847},
	{"VIZIER", 6, 116848},
	{"OVERBERG", 8, 116849},
	{"ANTEBELLUM", 10, 116850},
	{"LCOS", 4, 116851},
	{"ARGONAUT", 8, 116852},
	{"PUJOLS", 6, 116853},
	{"NAVSTUDIO", 9, 116854},
	{"NOSTRIL", 7, 116855},
	{"IMPEDES", 7, 116856},
	{"TOMBSTONES", 10, 116857},
	{"ROADIE", 6, 116858},
	{"NINDS", 5, 116859},
	{"WAVERING", 8, 116860},
	{"DOPAMINERGIC", 12, 116861},
	{"WEOP", 4, 116862},
	{"SFIB", 4, 116863},
	{"RGHB", 4, 116864},
	{"OYEV", 4, 116865},
	{"OFCM", 4, 116866},
	{"ODDN", 4, 116867},
	{"JOBN", 4, 116868},
	{"BBLA", 4, 116869},
	{"CARNATIC", 8, 116870},
	{"BARBARISM", 9, 116871},
	{"STAPHYLOCOCCAL", 14, 116872},
	{"AUTOBIOGRAPHIES", 15, 116873},
	{"CONSEJO", 7, 116874},
	{"SMALLS", 6, 116875},
	{"HAIRSTYLISTS", 12, 116876},
	{"HCPCS", 5, 116877},
	{"VIENNE", 6, 116878},
	{"HOOCH", 5, 116879},
	{"RAZORBACK", 9, 116880},
	{"DREYFUSS", 8, 116881},
	{"ESCRIBIR", 8, 116882},
	{"CONSTRUC", 8, 116883},
	{"USLU", 4, 116884},
	{"PMIG", 4, 116885},
	{"PGUI", 4, 116886},
	{"LCEA", 4, 116887},
	{"IXFL", 4, 116888},
	{"HWRE", 4, 116889},
	{"FFGE", 4, 116890},
	{"BJUG", 4, 116891},
	{"OFFICIALCITYSITES", 17, 116892},
	{"SHRM", 4, 116893},
	{"ALWAY", 5, 116894},
	{"SURMISE", 7, 116895},
	{"REDCLIFFE", 9, 116896},
	{"DRUMHELLER", 10, 116897},
	{"COLLEGEVILLE", 12, 116898},
	{"CELLULARI", 9, 116899},
	{"BRITANY", 7, 116900},
	{"CLAWFOOT", 8, 116901},
	{"BLANCH", 6, 116902},
	{"GREENAWAY", 9, 116903},
	{"CORSTEN", 7, 116904},
	{"MBAR", 4, 116905},
	{"RABI", 4, 116906},
	{"MORELOS", 7, 116907},
	{"POULTON", 7, 116908},
	{"INSCRUTABLE", 11, 116909},
	{"DUCHOVNY", 8, 116910},
	{"TRAMMELL", 8, 116911},
	{"WKSF", 4, 116912},
	{"WHIF", 4, 116913},
	{"UEJO", 4, 116914},
	{"MBAF", 4, 116915},
	{"LUPR", 4, 116916},
	{"KGUI", 4, 116917},
	{"DYOS", 4, 116918},
	{"AYOK", 4, 116919},
	{"EPRI", 4, 116920},
	{"REYNA", 5, 116921},
	{"QUEENSWAY", 9, 116922},
	{"ANTIALIASING", 12, 116923},
	{"ISAACSON", 8, 116924},
	{"CAMPAGNE", 8, 116925},
	{"MUGGER", 6, 116926},
	{"ERLANGER", 8, 116927},
	{"MCNAB", 5, 116928},
	{"JULBO", 5, 116929},
	{"TIPPECANOE", 10, 116930},
	{"UNDERBELLY", 10, 116931},
	{"BRONWYN", 7, 116932},
	{"CREWED", 6, 116933},
	{"GROOMER", 7, 116934},
	{"TEPPER", 6, 116935},
	{"SALUTED", 7, 116936},
	{"BRESLIN", 7, 116937},
	{"ZREC", 4, 116938},
	{"OSFU", 4, 116939},
	{"LREH", 4, 116940},
	{"BETFAIR", 7, 116941},
	{"REDUCIBLE", 9, 116942},
	{"PROTECTORATE", 12, 116943},
	{"LBF", 3, 116944},
	{"CASLON", 6, 116945},
	{"SILER", 5, 116946},
	{"HIEROGLYPHICS", 13, 116947},
	{"EVACUATIONS", 11, 116948},
	{"DRESDNER", 8, 116949},
	{"MATERIALIST", 11, 116950},
	{"CIENCY", 6, 116951},
	{"HARADA", 6, 116952},
	{"SADOMASO", 8, 116953},
	{"LANDLADY", 8, 116954},
	{"POTENTIATION", 12, 116955},
	{"VERTEBRA", 8, 116956},
	{"DARTBOARD", 9, 116957},
	{"OVUL", 4, 116958},
	{"KBYB", 4, 116959},
	{"IGUP", 4, 116960},
	{"IGNJ", 4, 116961},
	{"HNCL", 4, 116962},
	{"FAMP", 4, 116963},
	{"EYOL", 4, 116964},
	{"EODY", 4, 116965},
	{"BSQU", 4, 116966},
	{"RADI", 4, 116967},
	{"HOSTESSEN", 9, 116968},
	{"OZAUKEE", 7, 116969},
	{"BLAMELESS", 9, 116970},
	{"AMALIA", 6, 116971},
	{"DEMOCRATISATION", 15, 116972},
	{"YTMND", 5, 116973},
	{"NEWSAGENT", 9, 116974},
	{"POLENTA", 7, 116975},
	{"ABSURDLY", 8, 116976},
	{"BIDWELL", 7, 116977},
	{"ARCOLA", 6, 116978},
	{"MCNEALY", 7, 116979},
	{"ZRG", 3, 116980},
	{"WZV", 3, 116981},
	{"UJV", 3, 116982},
	{"RWZ", 3, 116983},
	{"QXR", 3, 116984},
	{"KKX", 3, 116985},
	{"JWK", 3, 116986},
	{"FXJ", 3, 116987},
	{"MSOG", 4, 116988},
	{"KPAD", 4, 116989},
	{"DNEB", 4, 116990},
	{"GARNISHED", 9, 116991},
	{"FERNAND", 7, 116992},
	{"PROBATIVE", 9, 116993},
	{"SCALLIONS", 9, 116994},
	{"SOSSUSVLEI", 10, 116995},
	{"VELAZQUEZ", 9, 116996},
	{"WHITELIST", 9, 116997},
	{"LEOLA", 5, 116998},
	{"CORPOREAL", 9, 116999},
	{"PASSIVITY", 9, 117000},
	{"PARTIALITY", 10, 117001},
	{"ANONYM", 6, 117002},
	{"SABERS", 6, 117003},
	{"GIRLES", 6, 117004},
	{"GOODWINS", 8, 117005},
	{"DWORKIN", 7, 117006},
	{"ROUNDABOUTS", 11, 117007},
	{"YBOG", 4, 117008},
	{"XISW", 4, 117009},
	{"WVEH", 4, 117010},
	{"UTAJ", 4, 117011},
	{"UDSW", 4, 117012},
	{"TCYB", 4, 117013},
	{"RNBC", 4, 117014},
	{"ONPC", 4, 117015},
	{"IBBU", 4, 117016},
	{"EPYT", 4, 117017},
	{"DBUB", 4, 117018},
	{"BNAL", 4, 117019},
	{"ABYN", 4, 117020},
	{"PKD", 3, 117021},
	{"CVG", 3, 117022},
	{"VOOM", 4, 117023},
	{"EMARKETING", 10, 117024},
	{"OCTAVES", 7, 117025},
	{"DISPOSES", 8, 117026},
	{"BOYES", 5, 117027},
	{"AMPEG", 5, 117028},
	{"BERTA", 5, 117029},
	{"EMANATE", 7, 117030},
	{"STAFFROOM", 9, 117031},
	{"CATARINA", 8, 117032},
	{"QUINCEANERA", 11, 117033},
	{"GUSTAFSSON", 10, 117034},
	{"VOLGOGRAD", 9, 117035},
	{"PREFETCHING", 11, 117036},
	{"MENZEL", 6, 117037},
	{"YATJ", 4, 117038},
	{"UWEA", 4, 117039},
	{"UDOB", 4, 117040},
	{"TOPQ", 4, 117041},
	{"TLSU", 4, 117042},
	{"SBIZ", 4, 117043},
	{"RTUC", 4, 117044},
	{"RAHJ", 4, 117045},
	{"NRYK", 4, 117046},
	{"FOXR", 4, 117047},
	{"DWIV", 4, 117048},
	{"DGOP", 4, 117049},
	{"WEBBGCOLOR", 10, 117050},
	{"TOMMIE", 6, 117051},
	{"CAPEX", 5, 117052},
	{"RUMMAGE", 7, 117053},
	{"OBJECTIVISM", 11, 117054},
	{"LEGALITIES", 10, 117055},
	{"LMR", 3, 117056},
	{"ABACUSLAW", 9, 117057},
	{"WHATIS", 6, 117058},
	{"GREGSON", 7, 117059},
	{"RIGEL", 5, 117060},
	{"HEADSTRONG", 10, 117061},
	{"AVRO", 4, 117062},
	{"PALUMBO", 7, 117063},
	{"YOSHIMURA", 9, 117064},
	{"TITTENFICK", 10, 117065},
	{"JCK", 3, 117066},
	{"WTRADITIONAL", 12, 117067},
	{"PLIES", 5, 117068},
	{"CHAMPIONING", 11, 117069},
	{"LOSARTAN", 8, 117070},
	{"SYNCHRONISED", 12, 117071},
	{"POLITICOS", 9, 117072},
	{"BUMBLING", 8, 117073},
	{"IURG", 4, 117074},
	{"GGHA", 4, 117075},
	{"FPUP", 4, 117076},
	{"PICKLING", 8, 117077},
	{"REFUTING", 8, 117078},
	{"PRIVATIZING", 11, 117079},
	{"CHRISSIE", 8, 117080},
	{"KOSTAS", 6, 117081},
	{"IRSSI", 5, 117082},
	{"SCANTILY", 8, 117083},
	{"WAAR", 4, 117084},
	{"MULTIPORT", 9, 117085},
	{"DUONG", 5, 117086},
	{"MAKINGS", 7, 117087},
	{"BLUMBERG", 8, 117088},
	{"SHOPSSHOP", 9, 117089},
	{"SLOVAKIAN", 9, 117090},
	{"MITTWOCH", 8, 117091},
	{"UADH", 4, 117092},
	{"UACK", 4, 117093},
	{"SAYJ", 4, 117094},
	{"RTZE", 4, 117095},
	{"LFPI", 4, 117096},
	{"IOFP", 4, 117097},
	{"INUG", 4, 117098},
	{"GOTK", 4, 117099},
	{"DYCU", 4, 117100},
	{"COXI", 4, 117101},
	{"ANJR", 4, 117102},
	{"BUU", 3, 117103},
	{"BEFRIENDED", 10, 117104},
	{"SCHENCK", 7, 117105},
	{"DUCTAL", 6, 117106},
	{"KOSCIUSKO", 9, 117107},
	{"ARMI", 4, 117108},
	{"STEVENSVILLE", 12, 117109},
	{"INDC", 4, 117110},
	{"BIRKBECK", 8, 117111},
	{"TENDONITIS", 10, 117112},
	{"PROFESSING", 10, 117113},
	{"MWYN", 4, 117114},
	{"FIERO", 5, 117115},
	{"UBAF", 4, 117116},
	{"TRHY", 4, 117117},
	{"MJUD", 4, 117118},
	{"HDYN", 4, 117119},
	{"EFBE", 4, 117120},
	{"RINGE", 5, 117121},
	{"NESTLING", 8, 117122},
	{"YESHUA", 6, 117123},
	{"PIEDRAS", 7, 117124},
	{"WAXAHACHIE", 10, 117125},
	{"NEUROPHYSIOL", 12, 117126},
	{"COOR", 4, 117127},
	{"WEEMS", 5, 117128},
	{"IMMORTALIZED", 12, 117129},
	{"LEPER", 5, 117130},
	{"YETK", 4, 117131},
	{"TWEU", 4, 117132},
	{"OPSK", 4, 117133},
	{"OFWW", 4, 117134},
	{"NGPP", 4, 117135},
	{"LECC", 4, 117136},
	{"KEAQ", 4, 117137},
	{"EGYB", 4, 117138},
	{"EBPR", 4, 117139},
	{"DDSC", 4, 117140},
	{"BYID", 4, 117141},
	{"VIERA", 5, 117142},
	{"LALONDE", 7, 117143},
	{"GREENCASTLE", 11, 117144},
	{"GENEANET", 8, 117145},
	{"ANIMUS", 6, 117146},
	{"DIMPLE", 6, 117147},
	{"CPUC", 4, 117148},
	{"DBU", 3, 117149},
	{"PGL", 3, 117150},
	{"ANNALEE", 7, 117151},
	{"STARCHES", 8, 117152},
	{"WTOP", 4, 117153},
	{"HANDBRAKE", 9, 117154},
	{"NOBLEST", 7, 117155},
	{"UROLOGISTS", 10, 117156},
	{"LEVITATION", 10, 117157},
	{"MONTELUKAST", 11, 117158},
	{"SUPINE", 6, 117159},
	{"SUBMITED", 8, 117160},
	{"CHARNWOOD", 9, 117161},
	{"SCHAUM", 6, 117162},
	{"UIDM", 4, 117163},
	{"UBEH", 4, 117164},
	{"GHSK", 4, 117165},
	{"EGBA", 4, 117166},
	{"BSAY", 4, 117167},
	{"AYUT", 4, 117168},
	{"MARRERO", 7, 117169},
	{"POWERTOOLS", 10, 117170},
	{"CHINN", 5, 117171},
	{"BAHCO", 5, 117172},
	{"BLOODTHIRSTY", 12, 117173},
	{"DERAILLEURS", 11, 117174},
	{"HAEMOGLOBIN", 11, 117175},
	{"CHAMPLIN", 8, 117176},
	{"FORAM", 5, 117177},
	{"WEIGHTINGS", 10, 117178},
	{"PBGC", 4, 117179},
	{"SUEY", 4, 117180},
	{"SQUINT", 6, 117181},
	{"JACKRABBIT", 10, 117182},
	{"LINVILLE", 8, 117183},
	{"AMAVIS", 6, 117184},
	{"UDHE", 4, 117185},
	{"NIFM", 4, 117186},
	{"MRLI", 4, 117187},
	{"LRYR", 4, 117188},
	{"LIKU", 4, 117189},
	{"GRSQ", 4, 117190},
	{"FDED", 4, 117191},
	{"BONJ", 4, 117192},
	{"GENZYME", 7, 117193},
	{"LINUXINSIDER", 12, 117194},
	{"MISTYPED", 8, 117195},
	{"DENIA", 5, 117196},
	{"VITALS", 6, 117197},
	{"CINDI", 5, 117198},
	{"HOPWOOD", 7, 117199},
	{"MONONA", 6, 117200},
	{"FRUITLAND", 9, 117201},
	{"GLASNOST", 8, 117202},
	{"LYSOSOMAL", 9, 117203},
	{"BUKHARI", 7, 117204},
	{"MURRELL", 7, 117205},
	{"UFAL", 4, 117206},
	{"TRIY", 4, 117207},
	{"ODUK", 4, 117208},
	{"DMAA", 4, 117209},
	{"AMZA", 4, 117210},
	{"ARABI", 5, 117211},
	{"ROSSITER", 8, 117212},
	{"OLDIE", 5, 117213},
	{"CULOS", 5, 117214},
	{"LIBBONOBO", 9, 117215},
	{"UMPQUA", 6, 117216},
	{"PARTIC", 6, 117217},
	{"LAMENTING", 9, 117218},
	{"WENHAM", 6, 117219},
	{"BENEDETTO", 9, 117220},
	{"TATER", 5, 117221},
	{"TOYAMA", 6, 117222},
	{"REAFFIRMING", 11, 117223},
	{"HOSSEIN", 7, 117224},
	{"KHAKIS", 6, 117225},
	{"METHYLPHENIDATE", 15, 117226},
	{"VINDICTIVE", 10, 117227},
	{"BOBBINS", 7, 117228},
	{"UOSV", 4, 117229},
	{"PBUY", 4, 117230},
	{"OKAV", 4, 117231},
	{"EZWE", 4, 117232},
	{"EDOJ", 4, 117233},
	{"DEVR", 4, 117234},
	{"BOOTUP", 6, 117235},
	{"HAIRSTON", 8, 117236},
	{"ECMWF", 5, 117237},
	{"ANNIV", 5, 117238},
	{"PREBLE", 6, 117239},
	{"MEGABITS", 8, 117240},
	{"TELIT", 5, 117241},
	{"SIRACUSA", 8, 117242},
	{"HADDONFIELD", 11, 117243},
	{"SPLENIC", 7, 117244},
	{"CARMINA", 7, 117245},
	{"OVERTOOK", 8, 117246},
	{"YAKN", 4, 117247},
	{"SSGL", 4, 117248},
	{"EPCU", 4, 117249},
	{"DYSN", 4, 117250},
	{"POLYPHONIQUE", 12, 117251},
	{"INTERNETWORKERS", 15, 117252},
	{"FUSCO", 5, 117253},
	{"ELWAY", 5, 117254},
	{"ELECTROCARDIOGRAPHY", 19, 117255},
	{"PYRIMIDINE", 10, 117256},
	{"PALAST", 6, 117257},
	{"DEIDRE", 6, 117258},
	{"SYBEX", 5, 117259},
	{"VINAY", 5, 117260},
	{"TRIPTYCH", 8, 117261},
	{"RIFLEMAN", 8, 117262},
	{"ANSONIA", 7, 117263},
	{"MTBF", 4, 117264},
	{"KENNINGTON", 10, 117265},
	{"TRIUMPHED", 9, 117266},
	{"HERRIA", 6, 117267},
	{"IPSWITCH", 8, 117268},
	{"SCANTY", 6, 117269},
	{"XELR", 4, 117270},
	{"ROCY", 4, 117271},
	{"PPAA", 4, 117272},
	{"PMNE", 4, 117273},
	{"MBWH", 4, 117274},
	{"LORK", 4, 117275},
	{"EEKK", 4, 117276},
	{"DIFFICILE", 9, 117277},
	{"TANKINI", 7, 117278},
	{"PHARR", 5, 117279},
	{"CIRA", 4, 117280},
	{"MAXED", 5, 117281},
	{"MOHAMAD", 7, 117282},
	{"OVERLOADS", 9, 117283},
	{"BRAWLEY", 7, 117284},
	{"MARMITE", 7, 117285},
	{"BARTOK", 6, 117286},
	{"SORENTO", 7, 117287},
	{"VAGARIES", 8, 117288},
	{"LANDRUM", 7, 117289},
	{"WINDOZE", 7, 117290},
	{"UNDAUNTED", 9, 117291},
	{"LUCAN", 5, 117292},
	{"BETZ", 4, 117293},
	{"HEMMING", 7, 117294},
	{"IZUK", 4, 117295},
	{"ELFY", 4, 117296},
	{"PRAKTICA", 8, 117297},
	{"NUEVAS", 6, 117298},
	{"DEFILED", 7, 117299},
	{"STILLBORN", 9, 117300},
	{"FALTERING", 9, 117301},
	{"JULIANNA", 8, 117302},
	{"SARACENS", 8, 117303},
	{"FEHR", 4, 117304},
	{"DEDE", 4, 117305},
	{"OVERRULE", 8, 117306},
	{"OLDAILY", 7, 117307},
	{"TISCH", 5, 117308},
	{"BENSER", 6, 117309},
	{"INTERNIC", 8, 117310},
	{"HUMANISTS", 9, 117311},
	{"BETULA", 6, 117312},
	{"PIPPA", 5, 117313},
	{"BENSALEM", 8, 117314},
	{"EYECARE", 7, 117315},
	{"SUNSOFT", 7, 117316},
	{"DISCOUNTERS", 11, 117317},
	{"DESNUDO", 7, 117318},
	{"CONSTRUCTIVISM", 14, 117319},
	{"VANNET", 6, 117320},
	{"TRICEPS", 7, 117321},
	{"PTYL", 4, 117322},
	{"PTBO", 4, 117323},
	{"INCZ", 4, 117324},
	{"GUZZ", 4, 117325},
	{"GMAO", 4, 117326},
	{"CNUL", 4, 117327},
	{"CHYD", 4, 117328},
	{"CDEN", 4, 117329},
	{"BOLF", 4, 117330},
	{"AKEQ", 4, 117331},
	{"AGUC", 4, 117332},
	{"OBSTETRICIAN", 12, 117333},
	{"CONCEITED", 9, 117334},
	{"DENYS", 5, 117335},
	{"TARLETON", 8, 117336},
	{"TIVITY", 6, 117337},
	{"RULL", 4, 117338},
	{"GABAPENTIN", 10, 117339},
	{"NAISSANCE", 9, 117340},
	{"NEONATE", 7, 117341},
	{"MICHENER", 8, 117342},
	{"ROEDD", 5, 117343},
	{"GWP", 3, 117344},
	{"RAINMAKER", 9, 117345},
	{"LAYMEN", 6, 117346},
	{"ARYA", 4, 117347},
	{"SHOPKEEPERS", 11, 117348},
	{"YPIP", 4, 117349},
	{"WEUR", 4, 117350},
	{"PAUT", 4, 117351},
	{"OCHD", 4, 117352},
	{"MIRZ", 4, 117353},
	{"JRTH", 4, 117354},
	{"CZYK", 4, 117355},
	{"BCWO", 4, 117356},
	{"BFP", 3, 117357},
	{"MORTIFICATION", 13, 117358},
	{"GEMEINSCHAFT", 12, 117359},
	{"COMMITEE", 8, 117360},
	{"TELSTAR", 7, 117361},
	{"MONOGAMY", 8, 117362},
	{"NAIDU", 5, 117363},
	{"ROOFERS", 7, 117364},
	{"TREEHUGGER", 10, 117365},
	{"DEADMAN", 7, 117366},
	{"APPLEONE", 8, 117367},
	{"COMBATS", 7, 117368},
	{"TIFB", 4, 117369},
	{"SGOP", 4, 117370},
	{"RELV", 4, 117371},
	{"KYOF", 4, 117372},
	{"ICTX", 4, 117373},
	{"SHEMAL", 6, 117374},
	{"SALK", 4, 117375},
	{"INDULGENCES", 11, 117376},
	{"CFTC", 4, 117377},
	{"AQUARIA", 7, 117378},
	{"POLYTONES", 9, 117379},
	{"KANGOL", 6, 117380},
	{"TARD", 4, 117381},
	{"PRIMEZONE", 9, 117382},
	{"MITCHUM", 7, 117383},
	{"FATTENING", 9, 117384},
	{"DRENCH", 6, 117385},
	{"CHRISTIANSBURG", 14, 117386},
	{"LIBR", 4, 117387},
	{"STUPIDEST", 9, 117388},
	{"METAFILE", 8, 117389},
	{"DIERKS", 6, 117390},
	{"XORB", 4, 117391},
	{"LFYO", 4, 117392},
	{"GHSB", 4, 117393},
	{"FUPA", 4, 117394},
	{"CUCUSOFT", 8, 117395},
	{"CANDIA", 6, 117396},
	{"REVISITS", 8, 117397},
	{"PRENDERGAST", 11, 117398},
	{"EVERITT", 7, 117399},
	{"ADVTS", 5, 117400},
	{"PYTHONMAC", 9, 117401},
	{"LIBXEXT", 7, 117402},
	{"LEGIBLY", 7, 117403},
	{"DIGESTING", 9, 117404},
	{"WMUL", 4, 117405},
	{"UELU", 4, 117406},
	{"LKHI", 4, 117407},
	{"LIOB", 4, 117408},
	{"FJAR", 4, 117409},
	{"EPIU", 4, 117410},
	{"COFG", 4, 117411},
	{"BOXD", 4, 117412},
	{"AUTOUPDATE", 10, 117413},
	{"CHENOWETH", 9, 117414},
	{"UNDELIVERED", 11, 117415},
	{"AUTOTHEME", 9, 117416},
	{"IFLA", 4, 117417},
	{"BENJ", 4, 117418},
	{"HEYMAN", 6, 117419},
	{"BOREN", 5, 117420},
	{"GUINN", 5, 117421},
	{"CUPOLA", 6, 117422},
	{"MQSERIES", 8, 117423},
	{"POLYTHENE", 9, 117424},
	{"UNCONTROLLABLY", 14, 117425},
	{"PUNA", 4, 117426},
	{"PROWSE", 6, 117427},
	{"UMAO", 4, 117428},
	{"OLTU", 4, 117429},
	{"LOLE", 4, 117430},
	{"HNMU", 4, 117431},
	{"FMAM", 4, 117432},
	{"EIMR", 4, 117433},
	{"DDSE", 4, 117434},
	{"BCEN", 4, 117435},
	{"AZZW", 4, 117436},
	{"IMPERMISSIBLE", 13, 117437},
	{"HUND", 4, 117438},
	{"KOMMER", 6, 117439},
	{"KERRIGAN", 8, 117440},
	{"CROCHETING", 10, 117441},
	{"CANST", 5, 117442},
	{"FLAN", 4, 117443},
	{"BEATIFUL", 8, 117444},
	{"NORRATH", 7, 117445},
	{"IDLENESS", 8, 117446},
	{"ARBITRATE", 9, 117447},
	{"MUONS", 5, 117448},
	{"CLINTONS", 8, 117449},
	{"SECURITISATION", 14, 117450},
	{"REDHEADED", 9, 117451},
	{"SETVALUE", 8, 117452},
	{"TVOW", 4, 117453},
	{"RGIM", 4, 117454},
	{"PULC", 4, 117455},
	{"ODWR", 4, 117456},
	{"LAWU", 4, 117457},
	{"GBIK", 4, 117458},
	{"CEUR", 4, 117459},
	{"PERITONITIS", 11, 117460},
	{"LUNGE", 5, 117461},
	{"CLOSERS", 7, 117462},
	{"MAHMUD", 6, 117463},
	{"MINUET", 6, 117464},
	{"ENTOMBED", 8, 117465},
	{"SUBSCRIPTOR", 11, 117466},
	{"FERS", 4, 117467},
	{"MAUNG", 5, 117468},
	{"LENTZ", 5, 117469},
	{"UNDERGRADS", 10, 117470},
	{"DIVERGED", 8, 117471},
	{"GOSSETT", 7, 117472},
	{"DUCATION", 8, 117473},
	{"OKUMA", 5, 117474},
	{"SPOUTS", 6, 117475},
	{"FILELIST", 8, 117476},
	{"PONTIFICAL", 10, 117477},
	{"YRAV", 4, 117478},
	{"VYBL", 4, 117479},
	{"UVAR", 4, 117480},
	{"TOUK", 4, 117481},
	{"OLNP", 4, 117482},
	{"IRIK", 4, 117483},
	{"FERJ", 4, 117484},
	{"EPBL", 4, 117485},
	{"ALRH", 4, 117486},
	{"NICENE", 6, 117487},
	{"GLIDED", 6, 117488},
	{"TETRACHLORIDE", 13, 117489},
	{"SHUFFLEBOARD", 12, 117490},
	{"CRAZIEST", 8, 117491},
	{"SLEEPLESSNESS", 13, 117492},
	{"CAREN", 5, 117493},
	{"SWALE", 5, 117494},
	{"RIMAGE", 6, 117495},
	{"AXED", 4, 117496},
	{"WEBMISTRESS", 11, 117497},
	{"MICROPLATE", 10, 117498},
	{"OVERDONE", 8, 117499},
	{"SOCRATIC", 8, 117500},
	{"RIPOFF", 6, 117501},
	{"FSFE", 4, 117502},
	{"REEVALUATION", 12, 117503},
	{"JERNIGAN", 8, 117504},
	{"YULIA", 5, 117505},
	{"REVULSION", 9, 117506},
	{"RHYTHMBOX", 9, 117507},
	{"DESTINATOR", 10, 117508},
	{"YRDO", 4, 117509},
	{"WMIG", 4, 117510},
	{"WEDY", 4, 117511},
	{"THMM", 4, 117512},
	{"SKSL", 4, 117513},
	{"RJAH", 4, 117514},
	{"NIFP", 4, 117515},
	{"HMYO", 4, 117516},
	{"CNNW", 4, 117517},
	{"CBLU", 4, 117518},
	{"ROSAMOND", 8, 117519},
	{"ASSLICKING", 10, 117520},
	{"SCHWARZE", 8, 117521},
	{"FERRIER", 7, 117522},
	{"JAGS", 4, 117523},
	{"LARGOS", 6, 117524},
	{"OVERHEATED", 10, 117525},
	{"MAYR", 4, 117526},
	{"CGW", 3, 117527},
	{"ULEU", 4, 117528},
	{"TLUX", 4, 117529},
	{"RPDE", 4, 117530},
	{"PDAY", 4, 117531},
	{"MRON", 4, 117532},
	{"LKAC", 4, 117533},
	{"HTYF", 4, 117534},
	{"FNAG", 4, 117535},
	{"DGHA", 4, 117536},
	{"DEMOBILIZATION", 14, 117537},
	{"GOLDENSEAL", 10, 117538},
	{"DEFLECTORS", 10, 117539},
	{"SERVICEMEMBERS", 14, 117540},
	{"SOILWORK", 8, 117541},
	{"FISHHOOKS", 9, 117542},
	{"SREBRENICA", 10, 117543},
	{"CLEANSES", 8, 117544},
	{"SECONDMENT", 10, 117545},
	{"RAGAN", 5, 117546},
	{"SUNBRELLA", 9, 117547},
	{"CRITICISING", 11, 117548},
	{"PORPOISE", 8, 117549},
	{"BACKLESS", 8, 117550},
	{"XOFI", 4, 117551},
	{"WVIL", 4, 117552},
	{"UCEV", 4, 117553},
	{"RPSF", 4, 117554},
	{"RCYR", 4, 117555},
	{"PELP", 4, 117556},
	{"OOFV", 4, 117557},
	{"HAUM", 4, 117558},
	{"GELG", 4, 117559},
	{"CSIL", 4, 117560},
	{"BOXR", 4, 117561},
	{"ABCI", 4, 117562},
	{"OLIGARCHY", 9, 117563},
	{"ROUPA", 5, 117564},
	{"LEVAQUIN", 8, 117565},
	{"INGUINAL", 8, 117566},
	{"BASSLINE", 8, 117567},
	{"HERBIVORES", 10, 117568},
	{"ELTRON", 6, 117569},
	{"TOPEX", 5, 117570},
	{"UNREGISTER", 10, 117571},
	{"CLOTHINGS", 9, 117572},
	{"ROLLUP", 6, 117573},
	{"SPAMMED", 7, 117574},
	{"TARJETA", 7, 117575},
	{"STENNIS", 7, 117576},
	{"HOSED", 5, 117577},
	{"MONTCALM", 8, 117578},
	{"FONDATION", 9, 117579},
	{"PELZER", 6, 117580},
	{"ELITISTS", 8, 117581},
	{"SOLEUS", 6, 117582},
	{"MSSM", 4, 117583},
	{"KIMPTON", 7, 117584},
	{"XCLO", 4, 117585},
	{"WLIM", 4, 117586},
	{"VITU", 4, 117587},
	{"LGEM", 4, 117588},
	{"LEEY", 4, 117589},
	{"FTYM", 4, 117590},
	{"FBIC", 4, 117591},
	{"CMLO", 4, 117592},
	{"CBAY", 4, 117593},
	{"BIGK", 4, 117594},
	{"AGWE", 4, 117595},
	{"SAHEL", 5, 117596},
	{"PSYCHICAL", 9, 117597},
	{"KEYGENS", 7, 117598},
	{"ARRSE", 5, 117599},
	{"DOORMAT", 7, 117600},
	{"PRESONUS", 8, 117601},
	{"RIVES", 5, 117602},
	{"MYCOLOGY", 8, 117603},
	{"ZBIGNIEW", 8, 117604},
	{"RYEGRASS", 8, 117605},
	{"AREAGUIDE", 9, 117606},
	{"WASILLA", 7, 117607},
	{"STORAGETEK", 10, 117608},
	{"HEARTEDLY", 9, 117609},
	{"CANCERCHROMOSOMES", 17, 117610},
	{"AREOLAS", 7, 117611},
	{"UQUI", 4, 117612},
	{"UGPO", 4, 117613},
	{"RADK", 4, 117614},
	{"MOMB", 4, 117615},
	{"MMGU", 4, 117616},
	{"HLAL", 4, 117617},
	{"CPIN", 4, 117618},
	{"ROWMAN", 6, 117619},
	{"LEXIE", 5, 117620},
	{"MICROSOFTMSN", 12, 117621},
	{"DRIBBLING", 9, 117622},
	{"EXMH", 4, 117623},
	{"CELADON", 7, 117624},
	{"BLEH", 4, 117625},
	{"FAFBLOG", 7, 117626},
	{"OCCITAN", 7, 117627},
	{"MOUTHWASH", 9, 117628},
	{"MIZE", 4, 117629},
	{"LIQUEFACTION", 12, 117630},
	{"LARCHMONT", 9, 117631},
	{"TROGLODYTES", 11, 117632},
	{"HOUTEN", 6, 117633},
	{"GASKELL", 7, 117634},
	{"TIMPANI", 7, 117635},
	{"FICHIERS", 8, 117636},
	{"FANNED", 6, 117637},
	{"MACT", 4, 117638},
	{"BERGE", 5, 117639},
	{"RBAP", 4, 117640},
	{"OFCC", 4, 117641},
	{"KSWR", 4, 117642},
	{"GICG", 4, 117643},
	{"EKDU", 4, 117644},
	{"AYDN", 4, 117645},
	{"TCDD", 4, 117646},
	{"WAGGING", 7, 117647},
	{"SCOR", 4, 117648},
	{"JAYHAWK", 7, 117649},
	{"BOOKMARKLETS", 12, 117650},
	{"GERMINATE", 9, 117651},
	{"NIXDORF", 7, 117652},
	{"FASTBACK", 8, 117653},
	{"CHRYSANTHEMUMS", 14, 117654},
	{"RUBIAS", 6, 117655},
	{"WRENS", 5, 117656},
	{"KJELL", 5, 117657},
	{"VOLCANISM", 9, 117658},
	{"RUMINANTS", 9, 117659},
	{"MISDEEDS", 8, 117660},
	{"FUZHOU", 6, 117661},
	{"BULLBOARDS", 10, 117662},
	{"PRIORITISATION", 14, 117663},
	{"FARRIER", 7, 117664},
	{"WVIE", 4, 117665},
	{"VPAR", 4, 117666},
	{"TUSV", 4, 117667},
	{"RAYU", 4, 117668},
	{"MLOG", 4, 117669},
	{"LTBL", 4, 117670},
	{"INZU", 4, 117671},
	{"ERDL", 4, 117672},
	{"AUGF", 4, 117673},
	{"AKOM", 4, 117674},
	{"POWERQUEST", 10, 117675},
	{"VALERIO", 7, 117676},
	{"EARNESTNESS", 11, 117677},
	{"AUTOZONE", 8, 117678},
	{"WETTED", 6, 117679},
	{"LIPPERT", 7, 117680},
	{"SHOCKERS", 8, 117681},
	{"NOLAND", 6, 117682},
	{"TEHERAN", 7, 117683},
	{"DOMNODE", 7, 117684},
	{"MEDEIROS", 8, 117685},
	{"UIGHUR", 6, 117686},
	{"MONOLINGUAL", 11, 117687},
	{"HARRELSON", 9, 117688},
	{"UNDERCURRENT", 12, 117689},
	{"ESPINOZA", 8, 117690},
	{"RAED", 4, 117691},
	{"ALLOCABLE", 9, 117692},
	{"LUNF", 4, 117693},
	{"KYBR", 4, 117694},
	{"GFEN", 4, 117695},
	{"FLIA", 4, 117696},
	{"DKAZ", 4, 117697},
	{"CBOU", 4, 117698},
	{"AWCL", 4, 117699},
	{"AMSQ", 4, 117700},
	{"DATASTREAM", 10, 117701},
	{"MUMM", 4, 117702},
	{"WUXI", 4, 117703},
	{"FLIN", 4, 117704},
	{"WORLDNET", 8, 117705},
	{"STEERAGE", 8, 117706},
	{"QUIP", 4, 117707},
	{"PACESETTER", 10, 117708},
	{"TAXONOMIES", 10, 117709},
	{"FEEDBACKHELP", 12, 117710},
	{"NOVAE", 5, 117711},
	{"CALENDERS", 9, 117712},
	{"BALLERS", 7, 117713},
	{"DENATURED", 9, 117714},
	{"TEDESCO", 7, 117715},
	{"POSTFACH", 8, 117716},
	{"VTRA", 4, 117717},
	{"UADB", 4, 117718},
	{"TGUT", 4, 117719},
	{"NYAV", 4, 117720},
	{"ERBF", 4, 117721},
	{"CFRI", 4, 117722},
	{"LADERA", 6, 117723},
	{"KWIKI", 5, 117724},
	{"DUY", 3, 117725},
	{"ZHUHAI", 6, 117726},
	{"KOMPAKT", 7, 117727},
	{"KARLOFF", 7, 117728},
	{"YAGER", 5, 117729},
	{"SUBJECTIVELY", 12, 117730},
	{"ARTARAMA", 8, 117731},
	{"SLOX", 4, 117732},
	{"STARA", 5, 117733},
	{"PRIVACYLEGALADVERTISE", 21, 117734},
	{"DISREPAIR", 9, 117735},
	{"GRU", 3, 117736},
	{"CODEV", 5, 117737},
	{"PHYSI", 5, 117738},
	{"BLACKADDER", 10, 117739},
	{"SCHLOSSER", 9, 117740},
	{"NESBIT", 6, 117741},
	{"LUSTHAUS", 8, 117742},
	{"UPAK", 4, 117743},
	{"SELG", 4, 117744},
	{"MWAV", 4, 117745},
	{"LARQ", 4, 117746},
	{"HJOY", 4, 117747},
	{"GOMU", 4, 117748},
	{"EFFU", 4, 117749},
	{"EBWI", 4, 117750},
	{"DDFO", 4, 117751},
	{"AZEP", 4, 117752},
	{"FILAMENTOUS", 11, 117753},
	{"TIMECODE", 8, 117754},
	{"POLYP", 5, 117755},
	{"BOOKMARZ", 8, 117756},
	{"INCOMPRESSIBLE", 14, 117757},
	{"SMEDLEY", 7, 117758},
	{"GRANARY", 7, 117759},
	{"GENUKI", 6, 117760},
	{"FELICITARI", 10, 117761},
	{"MANHASSET", 9, 117762},
	{"LIVEUPDATE", 10, 117763},
	{"NILSEN", 6, 117764},
	{"ECLIPTIC", 8, 117765},
	{"BEFITTING", 9, 117766},
	{"CENTE", 5, 117767},
	{"BOLSHEVIKS", 10, 117768},
	{"XESR", 4, 117769},
	{"WNJE", 4, 117770},
	{"SIXV", 4, 117771},
	{"RYLY", 4, 117772},
	{"RLUI", 4, 117773},
	{"MRME", 4, 117774},
	{"LELP", 4, 117775},
	{"KYOK", 4, 117776},
	{"IARL", 4, 117777},
	{"HEKC", 4, 117778},
	{"GUSR", 4, 117779},
	{"ECIB", 4, 117780},
	{"BCHI", 4, 117781},
	{"BCFO", 4, 117782},
	{"PODCASTERS", 10, 117783},
	{"NETLIBRARY", 10, 117784},
	{"MICROSOMAL", 10, 117785},
	{"ANTHRACIS", 9, 117786},
	{"STATUSES", 8, 117787},
	{"EXPANDABILITY", 13, 117788},
	{"WHITISH", 7, 117789},
	{"MELANIN", 7, 117790},
	{"IRRECONCILABLE", 14, 117791},
	{"AUTHENTICALLY", 13, 117792},
	{"GPOINTER", 8, 117793},
	{"UDINE", 5, 117794},
	{"BARFIELD", 8, 117795},
	{"TUSCARAWAS", 10, 117796},
	{"TRIBUTION", 9, 117797},
	{"ENTRYDATE", 9, 117798},
	{"WIFW", 4, 117799},
	{"TBIB", 4, 117800},
	{"RRHI", 4, 117801},
	{"RDAK", 4, 117802},
	{"MRAP", 4, 117803},
	{"GWIF", 4, 117804},
	{"GIVETH", 6, 117805},
	{"BRY", 3, 117806},
	{"DIVORCING", 9, 117807},
	{"CONCOCTED", 9, 117808},
	{"SCHNAPPS", 8, 117809},
	{"GARGANTUAN", 10, 117810},
	{"BHARTI", 6, 117811},
	{"RIDESHARE", 9, 117812},
	{"KARENINA", 8, 117813},
	{"ZXM", 3, 117814},
	{"ZPY", 3, 117815},
	{"ZLG", 3, 117816},
	{"XKD", 3, 117817},
	{"XJW", 3, 117818},
	{"XBV", 3, 117819},
	{"WQR", 3, 117820},
	{"QQW", 3, 117821},
	{"KJY", 3, 117822},
	{"ESSAYIST", 8, 117823},
	{"CHDIR", 5, 117824},
	{"WALLOP", 6, 117825},
	{"CARPORTS", 8, 117826},
	{"BOURGAS", 7, 117827},
	{"SANSONE", 7, 117828},
	{"LTSP", 4, 117829},
	{"SUPRANATIONAL", 13, 117830},
	{"EPICUREAN", 9, 117831},
	{"LEAVER", 6, 117832},
	{"HAUGHTON", 8, 117833},
	{"UNITHOLDERS", 11, 117834},
	{"MARGINALIZATION", 15, 117835},
	{"MISREPRESENTING", 15, 117836},
	{"CALUM", 5, 117837},
	{"VEIC", 4, 117838},
	{"ILCU", 4, 117839},
	{"DVDT", 4, 117840},
	{"DLIU", 4, 117841},
	{"CHOG", 4, 117842},
	{"STRERROR", 8, 117843},
	{"MUJAHIDEEN", 10, 117844},
	{"BLACKED", 7, 117845},
	{"POLLSTER", 8, 117846},
	{"AZERBAIDJAN", 11, 117847},
	{"ARPELS", 6, 117848},
	{"COLLOIDS", 8, 117849},
	{"DAML", 4, 117850},
	{"POULSEN", 7, 117851},
	{"MINESWEEPER", 11, 117852},
	{"SUBPROGRAM", 10, 117853},
	{"OPPORTUNITIESDIRECT", 19, 117854},
	{"SILVERBERG", 10, 117855},
	{"CUSTO", 5, 117856},
	{"CLOROX", 6, 117857},
	{"YLIL", 4, 117858},
	{"YCOX", 4, 117859},
	{"WSVE", 4, 117860},
	{"UAYS", 4, 117861},
	{"TYWR", 4, 117862},
	{"OYDT", 4, 117863},
	{"MBWI", 4, 117864},
	{"LKLE", 4, 117865},
	{"GKAI", 4, 117866},
	{"FDYN", 4, 117867},
	{"BEYW", 4, 117868},
	{"AWNL", 4, 117869},
	{"BATTLEFORD", 10, 117870},
	{"IRIAN", 5, 117871},
	{"DOWSING", 7, 117872},
	{"ETEAMZ", 6, 117873},
	{"REFIT", 5, 117874},
	{"MORRIE", 6, 117875},
	{"DOSED", 5, 117876},
	{"DALBY", 5, 117877},
	{"BOITE", 5, 117878},
	{"MUSHKIN", 7, 117879},
	{"AHRENS", 6, 117880},
	{"KASUMI", 6, 117881},
	{"HEADPIECE", 9, 117882},
	{"MODBASE", 7, 117883},
	{"BOOKIES", 7, 117884},
	{"TERRAINS", 8, 117885},
	{"SAFRAN", 6, 117886},
	{"VITERBO", 7, 117887},
	{"UNWASHED", 8, 117888},
	{"STRNCMP", 7, 117889},
	{"DETAINING", 9, 117890},
	{"CARRELLO", 8, 117891},
	{"ABCAZ", 5, 117892},
	{"VIRTUOSITY", 10, 117893},
	{"SHAANXI", 7, 117894},
	{"INTERSCHOLASTIC", 15, 117895},
	{"FPP", 3, 117896},
	{"TROUTDALE", 9, 117897},
	{"HPSY", 4, 117898},
	{"EFFD", 4, 117899},
	{"BOGI", 4, 117900},
	{"EXMOOR", 6, 117901},
	{"ECOM", 4, 117902},
	{"RFF", 3, 117903},
	{"ZAMBONI", 7, 117904},
	{"FRAMERATE", 9, 117905},
	{"MABLE", 5, 117906},
	{"TOPEAK", 6, 117907},
	{"ROXEN", 5, 117908},
	{"RADIOFREQUENCY", 14, 117909},
	{"MAGNOLIAS", 9, 117910},
	{"PRECOMPILED", 11, 117911},
	{"ORATORIO", 8, 117912},
	{"BEFALL", 6, 117913},
	{"CAMILLUS", 8, 117914},
	{"ESCAFLOWNE", 10, 117915},
	{"APPURTENANCES", 13, 117916},
	{"ACCESSABLE", 10, 117917},
	{"FIGMENT", 7, 117918},
	{"HARB", 4, 117919},
	{"RLBU", 4, 117920},
	{"PPYG", 4, 117921},
	{"NHLG", 4, 117922},
	{"MSVA", 4, 117923},
	{"LEXK", 4, 117924},
	{"CTJA", 4, 117925},
	{"BPAN", 4, 117926},
	{"ANODES", 6, 117927},
	{"WEARILY", 7, 117928},
	{"LEESVILLE", 9, 117929},
	{"NORTHERNMOST", 12, 117930},
	{"TROLLOPE", 8, 117931},
	{"HOMEHOTMAILMY", 13, 117932},
	{"TAPU", 4, 117933},
	{"RAIDMAX", 7, 117934},
	{"MSNSIGN", 7, 117935},
	{"ENCHANTER", 9, 117936},
	{"FOYLE", 5, 117937},
	{"PCLAWPRO", 8, 117938},
	{"GLAZIER", 7, 117939},
	{"THEISTIC", 8, 117940},
	{"UNSCIENTIFIC", 12, 117941},
	{"WITHSTOOD", 9, 117942},
	{"SANDHILLS", 9, 117943},
	{"OPENIB", 6, 117944},
	{"FOERSTER", 8, 117945},
	{"WECU", 4, 117946},
	{"UFIL", 4, 117947},
	{"SCBN", 4, 117948},
	{"RTZW", 4, 117949},
	{"RDEO", 4, 117950},
	{"KMCG", 4, 117951},
	{"GGSB", 4, 117952},
	{"EGCA", 4, 117953},
	{"DYVE", 4, 117954},
	{"DICB", 4, 117955},
	{"PERMEATION", 10, 117956},
	{"PLAYPEN", 7, 117957},
	{"ANCHOVY", 7, 117958},
	{"HEAVINESS", 9, 117959},
	{"PUCKS", 5, 117960},
	{"STATEHOUSE", 10, 117961},
	{"KNAPSACK", 8, 117962},
	{"MALLEE", 6, 117963},
	{"SBCL", 4, 117964},
	{"BRIDGEDALE", 10, 117965},
	{"ANIMAUX", 7, 117966},
	{"CALCUL", 6, 117967},
	{"EARINGS", 7, 117968},
	{"RYYA", 4, 117969},
	{"RKOB", 4, 117970},
	{"NKYT", 4, 117971},
	{"ADJI", 4, 117972},
	{"BRACHIAL", 8, 117973},
	{"SEROQUEL", 8, 117974},
	{"EROTICISM", 9, 117975},
	{"SAMMIE", 6, 117976},
	{"CONSCIENCES", 11, 117977},
	{"TOURNEYS", 8, 117978},
	{"HOTSHOT", 7, 117979},
	{"DOMI", 4, 117980},
	{"FUMO", 4, 117981},
	{"ADDL", 4, 117982},
	{"EXTINCTIONS", 11, 117983},
	{"ROLLAND", 7, 117984},
	{"PADMA", 5, 117985},
	{"VERGARA", 7, 117986},
	{"TENDERERS", 9, 117987},
	{"REMODELS", 8, 117988},
	{"SUNLAND", 7, 117989},
	{"PROTOTYPICAL", 12, 117990},
	{"INFLECTED", 9, 117991},
	{"CORREIA", 7, 117992},
	{"KERNS", 5, 117993},
	{"VECC", 4, 117994},
	{"UKEG", 4, 117995},
	{"RGSU", 4, 117996},
	{"NDMB", 4, 117997},
	{"LGAB", 4, 117998},
	{"KKAL", 4, 117999},
	{"HYEX", 4, 118000},
	{"CIDU", 4, 118001},
	{"AZOL", 4, 118002},
	{"LINSEED", 7, 118003},
	{"INLINING", 8, 118004},
	{"JEOPARDIZING", 12, 118005},
	{"HARTER", 6, 118006},
	{"CAISSE", 6, 118007},
	{"STACCATO", 8, 118008},
	{"AMSAT", 5, 118009},
	{"ISONIAZID", 9, 118010},
	{"RMVB", 4, 118011},
	{"POLYHEDRAL", 10, 118012},
	{"MASAKI", 6, 118013},
	{"LANGEVIN", 8, 118014},
	{"CORRELATOR", 10, 118015},
	{"HOSTNAMES", 9, 118016},
	{"DOWNSIDES", 9, 118017},
	{"DELS", 4, 118018},
	{"WAISTLINE", 9, 118019},
	{"FRD", 3, 118020},
	{"RUPB", 4, 118021},
	{"KHWA", 4, 118022},
	{"AGAMEMNON", 9, 118023},
	{"TROGON", 6, 118024},
	{"DODGED", 6, 118025},
	{"DEMERS", 6, 118026},
	{"NONIMMIGRANT", 12, 118027},
	{"GREENBLATT", 10, 118028},
	{"BOTTI", 5, 118029},
	{"LAVELLE", 7, 118030},
	{"CLAREMORE", 9, 118031},
	{"CLASSRM", 7, 118032},
	{"REFUSALS", 8, 118033},
	{"GOLDFARB", 8, 118034},
	{"ASHINGTON", 9, 118035},
	{"SUPERCARS", 9, 118036},
	{"POLITICIZED", 11, 118037},
	{"WAYANS", 6, 118038},
	{"KINGSFORD", 9, 118039},
	{"TAMRAC", 6, 118040},
	{"LMU", 3, 118041},
	{"ZAYED", 5, 118042},
	{"GLB", 3, 118043},
	{"GILLEN", 6, 118044},
	{"WWWO", 4, 118045},
	{"WSPU", 4, 118046},
	{"REWK", 4, 118047},
	{"OLBI", 4, 118048},
	{"KWRO", 4, 118049},
	{"EYJE", 4, 118050},
	{"EPHG", 4, 118051},
	{"DUOO", 4, 118052},
	{"REFUELLING", 10, 118053},
	{"MONOTHERAPY", 11, 118054},
	{"MUTATIONAL", 10, 118055},
	{"STANWOOD", 8, 118056},
	{"IMPERMEABLE", 11, 118057},
	{"JULIETA", 7, 118058},
	{"CACOPHONY", 9, 118059},
	{"OUTRAGES", 8, 118060},
	{"CUNEIFORM", 9, 118061},
	{"FOOTSTOOL", 9, 118062},
	{"MITZVAHS", 8, 118063},
	{"LECTERN", 7, 118064},
	{"TRAPT", 5, 118065},
	{"DOPO", 4, 118066},
	{"QUEENSBURY", 10, 118067},
	{"METZLER", 7, 118068},
	{"FUTHER", 6, 118069},
	{"EBOOKMAN", 8, 118070},
	{"BEOGRAD", 7, 118071},
	{"ROMANCING", 9, 118072},
	{"BACKSCATTER", 11, 118073},
	{"SKPE", 4, 118074},
	{"SHUC", 4, 118075},
	{"RRTO", 4, 118076},
	{"PEAG", 4, 118077},
	{"MBYD", 4, 118078},
	{"KIMH", 4, 118079},
	{"ANTICOAGULATION", 15, 118080},
	{"HALLIE", 6, 118081},
	{"EMBLAZONED", 10, 118082},
	{"WALFORD", 7, 118083},
	{"SAPIENZA", 8, 118084},
	{"METTRE", 6, 118085},
	{"DUPLICATIVE", 11, 118086},
	{"GRAVITATE", 9, 118087},
	{"WRANGLING", 9, 118088},
	{"BENNETTS", 8, 118089},
	{"BRST", 4, 118090},
	{"FINNED", 6, 118091},
	{"THEMIS", 6, 118092},
	{"TYEC", 4, 118093},
	{"KJOI", 4, 118094},
	{"HEPF", 4, 118095},
	{"EXWE", 4, 118096},
	{"EHWB", 4, 118097},
	{"CMOU", 4, 118098},
	{"BAMI", 4, 118099},
	{"ABUA", 4, 118100},
	{"GIGASET", 7, 118101},
	{"BITTNER", 7, 118102},
	{"SAVANE", 6, 118103},
	{"TRANSCO", 7, 118104},
	{"DORCAS", 6, 118105},
	{"LOOSES", 6, 118106},
	{"CONFISCATE", 10, 118107},
	{"CATFIGHT", 8, 118108},
	{"TABLELANDS", 10, 118109},
	{"HORCHOW", 7, 118110},
	{"BLOODS", 6, 118111},
	{"ODOURS", 6, 118112},
	{"KOZLOWSKI", 9, 118113},
	{"CYBERSTORE", 10, 118114},
	{"HADASSAH", 8, 118115},
	{"WFLI", 4, 118116},
	{"MMOC", 4, 118117},
	{"LKEA", 4, 118118},
	{"KSOB", 4, 118119},
	{"BIWH", 4, 118120},
	{"AGBA", 4, 118121},
	{"RESTORERS", 9, 118122},
	{"FEELGOOD", 8, 118123},
	{"STORYBOARDS", 11, 118124},
	{"MONGREL", 7, 118125},
	{"RIFKIN", 6, 118126},
	{"NUTRISYSTEM", 11, 118127},
	{"QTVR", 4, 118128},
	{"VACCINATE", 9, 118129},
	{"SHOUJO", 6, 118130},
	{"FOREWARNED", 10, 118131},
	{"AFTERHOURS", 10, 118132},
	{"FERNANDA", 8, 118133},
	{"LETTERA", 7, 118134},
	{"DRK", 3, 118135},
	{"UGGS", 4, 118136},
	{"DEGENERATED", 11, 118137},
	{"TGIRLS", 6, 118138},
	{"EVENTIDE", 8, 118139},
	{"HASHISH", 7, 118140},
	{"DEBBI", 5, 118141},
	{"POLYTECHNIQUE", 13, 118142},
	{"DELANY", 6, 118143},
	{"ANALYTES", 8, 118144},
	{"VENTNOR", 7, 118145},
	{"ZAFO", 4, 118146},
	{"TZLA", 4, 118147},
	{"OXYL", 4, 118148},
	{"OGAF", 4, 118149},
	{"MELG", 4, 118150},
	{"IRLM", 4, 118151},
	{"EZEP", 4, 118152},
	{"APPF", 4, 118153},
	{"GOSSELIN", 8, 118154},
	{"CATHCART", 8, 118155},
	{"DISODIUM", 8, 118156},
	{"GMTUNKNOWN", 10, 118157},
	{"LYMPHOBLASTIC", 13, 118158},
	{"GLOMERULONEPHRITIS", 18, 118159},
	{"ARTIN", 5, 118160},
	{"IFFY", 4, 118161},
	{"WELTY", 5, 118162},
	{"AMMA", 4, 118163},
	{"INHALERS", 8, 118164},
	{"IMPAIRING", 9, 118165},
	{"KHOURY", 6, 118166},
	{"HODGKINS", 8, 118167},
	{"DISPOSSESSED", 12, 118168},
	{"BROCKEN", 7, 118169},
	{"UNCOMMITTED", 11, 118170},
	{"MEAGRE", 6, 118171},
	{"AVERILL", 7, 118172},
	{"TRIMARK", 7, 118173},
	{"YBIC", 4, 118174},
	{"XBRA", 4, 118175},
	{"UGEV", 4, 118176},
	{"LPSD", 4, 118177},
	{"CIDT", 4, 118178},
	{"SERC", 4, 118179},
	{"BRAMLEY", 7, 118180},
	{"ENVIROMENTAL", 12, 118181},
	{"LOCOMOTOR", 9, 118182},
	{"ALMANACK", 8, 118183},
	{"MOPPING", 7, 118184},
	{"IVER", 4, 118185},
	{"JKL", 3, 118186},
	{"THURBER", 7, 118187},
	{"LYDON", 5, 118188},
	{"FANTASTICAL", 11, 118189},
	{"JECTS", 5, 118190},
	{"IMMOBILIEN", 10, 118191},
	{"GIFTWRAP", 8, 118192},
	{"ADRS", 4, 118193},
	{"RECONNECTING", 12, 118194},
	{"DORF", 4, 118195},
	{"YAMA", 4, 118196},
	{"PESCI", 5, 118197},
	{"HAILE", 5, 118198},
	{"INTERVARSITY", 12, 118199},
	{"ZWHE", 4, 118200},
	{"YNEF", 4, 118201},
	{"UBNE", 4, 118202},
	{"SMYN", 4, 118203},
	{"NFAD", 4, 118204},
	{"MLYE", 4, 118205},
	{"FHAZ", 4, 118206},
	{"EFFK", 4, 118207},
	{"AMYI", 4, 118208},
	{"LAATSTE", 7, 118209},
	{"PAWLENTY", 8, 118210},
	{"MBTA", 4, 118211},
	{"CHINTZ", 6, 118212},
	{"NEBULOUS", 8, 118213},
	{"OUIJA", 5, 118214},
	{"SLINK", 5, 118215},
	{"MORIAH", 6, 118216},
	{"THOME", 5, 118217},
	{"DISTCLEAN", 9, 118218},
	{"MULTIPLATFORM", 13, 118219},
	{"LITTLEJOHN", 10, 118220},
	{"CMPS", 4, 118221},
	{"REDI", 4, 118222},
	{"ARKHAM", 6, 118223},
	{"KIVA", 4, 118224},
	{"LINEAL", 6, 118225},
	{"USYC", 4, 118226},
	{"MDOG", 4, 118227},
	{"LVON", 4, 118228},
	{"LTEV", 4, 118229},
	{"LEZW", 4, 118230},
	{"IBOW", 4, 118231},
	{"CHEPSTOW", 8, 118232},
	{"MISSPELLING", 11, 118233},
	{"GAINFUL", 7, 118234},
	{"DOGZ", 4, 118235},
	{"MILBANK", 7, 118236},
	{"WEBCORE", 7, 118237},
	{"ALDRIN", 6, 118238},
	{"ORTHODONTISTS", 13, 118239},
	{"DROLL", 5, 118240},
	{"NONDISCRIMINATORY", 17, 118241},
	{"VALU", 4, 118242},
	{"BRETFORD", 8, 118243},
	{"COPIA", 5, 118244},
	{"PROXILAW", 8, 118245},
	{"LESSEES", 7, 118246},
	{"BENZOATE", 8, 118247},
	{"LAMBSWOOL", 9, 118248},
	{"ROCKLEDGE", 9, 118249},
	{"WEXE", 4, 118250},
	{"WCUT", 4, 118251},
	{"PPYR", 4, 118252},
	{"OBMC", 4, 118253},
	{"LURS", 4, 118254},
	{"KGER", 4, 118255},
	{"HUPB", 4, 118256},
	{"HMCD", 4, 118257},
	{"EXBA", 4, 118258},
	{"DRBA", 4, 118259},
	{"AQWH", 4, 118260},
	{"EDGARTOWN", 9, 118261},
	{"CITALOPRAM", 10, 118262},
	{"HONOURING", 9, 118263},
	{"KCBS", 4, 118264},
	{"GRENADIER", 9, 118265},
	{"TURCO", 5, 118266},
	{"ANACHRONISM", 11, 118267},
	{"METHODICALLY", 12, 118268},
	{"FLUCTUATES", 10, 118269},
	{"STIFFENED", 9, 118270},
	{"ATHENIANS", 9, 118271},
	{"GOFAL", 5, 118272},
	{"DUPLICATIONS", 12, 118273},
	{"HAUTES", 6, 118274},
	{"SHYAM", 5, 118275},
	{"EVERIO", 6, 118276},
	{"SYNTRAX", 7, 118277},
	{"SUSTAINMENT", 11, 118278},
	{"PROTOOLS", 8, 118279},
	{"LADYTRON", 8, 118280},
	{"BILLIGE", 7, 118281},
	{"ROBOSAPIEN", 10, 118282},
	{"ALEPPO", 6, 118283},
	{"TEMPOROMANDIBULAR", 17, 118284},
	{"NKDA", 4, 118285},
	{"MVID", 4, 118286},
	{"HOUP", 4, 118287},
	{"GNSM", 4, 118288},
	{"FWIG", 4, 118289},
	{"EECB", 4, 118290},
	{"CTYE", 4, 118291},
	{"AQIG", 4, 118292},
	{"ADAZ", 4, 118293},
	{"WININFO", 7, 118294},
	{"WHIMPER", 7, 118295},
	{"RODA", 4, 118296},
	{"WHOMSOEVER", 10, 118297},
	{"VICIOUSLY", 9, 118298},
	{"SPINEL", 6, 118299},
	{"SNOWBOARDER", 11, 118300},
	{"FIDDLERS", 8, 118301},
	{"SLINGO", 6, 118302},
	{"CALLOUT", 7, 118303},
	{"PAUA", 4, 118304},
	{"ENDOW", 5, 118305},
	{"MONOGAMOUS", 10, 118306},
	{"NCTB", 4, 118307},
	{"LJUB", 4, 118308},
	{"ICCY", 4, 118309},
	{"GJEN", 4, 118310},
	{"EUBANKS", 7, 118311},
	{"KYB", 3, 118312},
	{"GMU", 3, 118313},
	{"RAUM", 4, 118314},
	{"PATENTABLE", 10, 118315},
	{"INCISED", 7, 118316},
	{"MOHICANS", 8, 118317},
	{"KAPOSI", 6, 118318},
	{"HYPERSONIC", 10, 118319},
	{"INDISTINCT", 10, 118320},
	{"COUNTERBALANCE", 14, 118321},
	{"RAZED", 5, 118322},
	{"ELICITS", 7, 118323},
	{"RAYNAUD", 7, 118324},
	{"FLESCH", 6, 118325},
	{"XYCO", 4, 118326},
	{"XTED", 4, 118327},
	{"UMFL", 4, 118328},
	{"UDNO", 4, 118329},
	{"SSYP", 4, 118330},
	{"ROTW", 4, 118331},
	{"REGC", 4, 118332},
	{"QUOY", 4, 118333},
	{"NOVP", 4, 118334},
	{"MYEV", 4, 118335},
	{"LYIV", 4, 118336},
	{"LTDS", 4, 118337},
	{"FGAU", 4, 118338},
	{"ESUK", 4, 118339},
	{"EEZY", 4, 118340},
	{"APSG", 4, 118341},
	{"BOLGER", 6, 118342},
	{"CINEMAX", 7, 118343},
	{"LYNDEN", 6, 118344},
	{"ANZAHL", 6, 118345},
	{"ECONWPA", 7, 118346},
	{"ZOPYRUS", 7, 118347},
	{"REDEMPTIONS", 11, 118348},
	{"NEVIRAPINE", 10, 118349},
	{"CHLORINATION", 12, 118350},
	{"AVHRR", 5, 118351},
	{"INVENTS", 7, 118352},
	{"UNITRUST", 8, 118353},
	{"LOUNGERS", 8, 118354},
	{"INITIALISE", 10, 118355},
	{"WILBERFORCE", 11, 118356},
	{"XTWO", 4, 118357},
	{"XPOU", 4, 118358},
	{"XCRU", 4, 118359},
	{"RYOD", 4, 118360},
	{"MUSB", 4, 118361},
	{"IGOB", 4, 118362},
	{"FJUR", 4, 118363},
	{"FHEK", 4, 118364},
	{"DAMJ", 4, 118365},
	{"BADJ", 4, 118366},
	{"FLICKING", 8, 118367},
	{"PRESYNAPTIC", 11, 118368},
	{"SEAMASTER", 9, 118369},
	{"SPECTROPHOTOMETER", 17, 118370},
	{"DEDUCTIBILITY", 13, 118371},
	{"SPANIELS", 8, 118372},
	{"SQUEEGEE", 8, 118373},
	{"SHATTERS", 8, 118374},
	{"FOTKI", 5, 118375},
	{"WANTAGE", 7, 118376},
	{"PANJABI", 7, 118377},
	{"TRACHOMATIS", 11, 118378},
	{"MANUS", 5, 118379},
	{"TASKER", 6, 118380},
	{"TENFOLD", 7, 118381},
	{"XTMI", 4, 118382},
	{"VYIS", 4, 118383},
	{"SSCY", 4, 118384},
	{"MLAY", 4, 118385},
	{"KEWR", 4, 118386},
	{"FCAI", 4, 118387},
	{"DWYN", 4, 118388},
	{"SOKOL", 5, 118389},
	{"BLUEFIN", 7, 118390},
	{"NEUROSURGICAL", 13, 118391},
	{"JAMMERS", 7, 118392},
	{"ARCTURUS", 8, 118393},
	{"CONCERTINA", 10, 118394},
	{"NANCI", 5, 118395},
	{"SCOURED", 7, 118396},
	{"PRETAX", 6, 118397},
	{"RONCO", 5, 118398},
	{"DESICCANT", 9, 118399},
	{"SCHULE", 6, 118400},
	{"BUSHIDO", 7, 118401},
	{"LAYAWAY", 7, 118402},
	{"STATMENT", 8, 118403},
	{"TELEFUNKEN", 10, 118404},
	{"CARLEY", 6, 118405},
	{"GELDER", 6, 118406},
	{"PILSNER", 7, 118407},
	{"KNOTTY", 6, 118408},
	{"SALMONIDS", 9, 118409},
	{"SCARLATTI", 9, 118410},
	{"ATKIN", 5, 118411},
	{"RBSS", 4, 118412},
	{"NPAM", 4, 118413},
	{"KMES", 4, 118414},
	{"HMEX", 4, 118415},
	{"HILU", 4, 118416},
	{"HFIX", 4, 118417},
	{"GYSP", 4, 118418},
	{"EBAV", 4, 118419},
	{"DMCM", 4, 118420},
	{"AVAILABILTY", 11, 118421},
	{"DSSSL", 5, 118422},
	{"STEWARDESS", 10, 118423},
	{"CATALA", 6, 118424},
	{"SUBIACO", 7, 118425},
	{"DAYDREAMING", 11, 118426},
	{"PHYTOPHTHORA", 12, 118427},
	{"CAJUNS", 6, 118428},
	{"KNOPFLER", 8, 118429},
	{"FURTHERED", 9, 118430},
	{"PABST", 5, 118431},
	{"RMAIL", 5, 118432},
	{"MATSCAN", 7, 118433},
	{"ENDBLK", 6, 118434},
	{"TREADWELL", 9, 118435},
	{"SHETTY", 6, 118436},
	{"LIMNOLOGY", 9, 118437},
	{"HOBAN", 5, 118438},
	{"YGIN", 4, 118439},
	{"WEWR", 4, 118440},
	{"WBYA", 4, 118441},
	{"PPYN", 4, 118442},
	{"NKGU", 4, 118443},
	{"NAUX", 4, 118444},
	{"IMKA", 4, 118445},
	{"FAXI", 4, 118446},
	{"EUMR", 4, 118447},
	{"PRIATE", 6, 118448},
	{"SEVYLOR", 7, 118449},
	{"BACKOFFICE", 10, 118450},
	{"INTERCOMS", 9, 118451},
	{"INVENSYS", 8, 118452},
	{"WORDSEARCH", 10, 118453},
	{"CHANCEL", 7, 118454},
	{"ADVANTAGED", 10, 118455},
	{"RUMFORD", 7, 118456},
	{"PONTEFRACT", 10, 118457},
	{"DUPRE", 5, 118458},
	{"KLUTZ", 5, 118459},
	{"FINKEL", 6, 118460},
	{"SPOV", 4, 118461},
	{"LAVR", 4, 118462},
	{"KUPQ", 4, 118463},
	{"CEOJ", 4, 118464},
	{"ARMADALE", 8, 118465},
	{"OSTRAVA", 7, 118466},
	{"BLOODBATH", 9, 118467},
	{"LAMPREY", 7, 118468},
	{"ELIMINATIONS", 12, 118469},
	{"MAGIK", 5, 118470},
	{"INEXORABLY", 10, 118471},
	{"MILLIS", 6, 118472},
	{"PIMCO", 5, 118473},
	{"GRIDLEY", 7, 118474},
	{"ZZOUNDS", 7, 118475},
	{"MITGLIEDER", 10, 118476},
	{"DIVERTER", 8, 118477},
	{"WAKA", 4, 118478},
	{"MERCHANDISERS", 13, 118479},
	{"PANCRAS", 7, 118480},
	{"FARRELLY", 8, 118481},
	{"CRG", 3, 118482},
	{"ULID", 4, 118483},
	{"SCFO", 4, 118484},
	{"ROSG", 4, 118485},
	{"LUWA", 4, 118486},
	{"LEGY", 4, 118487},
	{"KEXE", 4, 118488},
	{"GBYN", 4, 118489},
	{"DPHD", 4, 118490},
	{"BUYR", 4, 118491},
	{"WORSHIPS", 8, 118492},
	{"WASHOUT", 7, 118493},
	{"SHIRO", 5, 118494},
	{"IRONED", 6, 118495},
	{"BLUESY", 6, 118496},
	{"CONSISTANT", 10, 118497},
	{"BIOSENSORS", 10, 118498},
	{"ONALASKA", 8, 118499},
	{"SHEETFED", 8, 118500},
	{"INHABITS", 8, 118501},
	{"DARSHAN", 7, 118502},
	{"PIGSKIN", 7, 118503},
	{"YAUC", 4, 118504},
	{"UYLO", 4, 118505},
	{"SSYF", 4, 118506},
	{"RTKA", 4, 118507},
	{"ONKW", 4, 118508},
	{"NBUM", 4, 118509},
	{"GRYC", 4, 118510},
	{"GOVO", 4, 118511},
	{"GILG", 4, 118512},
	{"FSAW", 4, 118513},
	{"DDOV", 4, 118514},
	{"BANKRATE", 8, 118515},
	{"SHAKOPEE", 8, 118516},
	{"DOMESTICATION", 13, 118517},
	{"CLUDED", 6, 118518},
	{"AMAZONIAN", 9, 118519},
	{"TEXTFIELD", 9, 118520},
	{"INTERGRATED", 11, 118521},
	{"COUNTERCULTURE", 14, 118522},
	{"GAMEROOM", 8, 118523},
	{"RETOLD", 6, 118524},
	{"OLOF", 4, 118525},
	{"PHOTOG", 6, 118526},
	{"EPOINTZ", 7, 118527},
	{"MEDIRESOURCE", 12, 118528},
	{"COLUM", 5, 118529},
	{"REDRUTH", 7, 118530},
	{"EMBEDS", 6, 118531},
	{"YLOP", 4, 118532},
	{"VDIS", 4, 118533},
	{"UGNE", 4, 118534},
	{"RZOG", 4, 118535},
	{"OXYC", 4, 118536},
	{"ORBB", 4, 118537},
	{"OFKL", 4, 118538},
	{"OFCZ", 4, 118539},
	{"GLYV", 4, 118540},
	{"FENL", 4, 118541},
	{"ECYT", 4, 118542},
	{"OPPOSITIONAL", 12, 118543},
	{"JAPON", 5, 118544},
	{"CONTACTSMANAGER", 15, 118545},
	{"APPENDAGE", 9, 118546},
	{"KARELIA", 7, 118547},
	{"TOKYOPOP", 8, 118548},
	{"LEWMAR", 6, 118549},
	{"CRUSTACEAN", 10, 118550},
	{"MONOTONICITY", 12, 118551},
	{"GEOGRAPHER", 10, 118552},
	{"VOLANT", 6, 118553},
	{"DIVESTITURES", 12, 118554},
	{"WRITELN", 7, 118555},
	{"MINDSCAPE", 9, 118556},
	{"DENDROBIUM", 10, 118557},
	{"AIRWAVE", 7, 118558},
	{"CKD", 3, 118559},
	{"MOREE", 5, 118560},
	{"YMYB", 4, 118561},
	{"YBEK", 4, 118562},
	{"RDYT", 4, 118563},
	{"PUMM", 4, 118564},
	{"MSOD", 4, 118565},
	{"ELFJ", 4, 118566},
	{"EEMF", 4, 118567},
	{"DRUC", 4, 118568},
	{"LEENA", 5, 118569},
	{"ELWA", 4, 118570},
	{"RECYCLES", 8, 118571},
	{"FUSIONS", 7, 118572},
	{"AUER", 4, 118573},
	{"JOIST", 5, 118574},
	{"TAPPER", 6, 118575},
	{"CORNETT", 7, 118576},
	{"TUSCOLA", 7, 118577},
	{"UPCARD", 6, 118578},
	{"OMNIS", 5, 118579},
	{"NAPHTHA", 7, 118580},
	{"CLAIRVOYANCE", 12, 118581},
	{"ARIF", 4, 118582},
	{"AXCIS", 5, 118583},
	{"TREETOPS", 8, 118584},
	{"DEBUNKED", 8, 118585},
	{"YMCL", 4, 118586},
	{"YDUS", 4, 118587},
	{"UMDR", 4, 118588},
	{"UESV", 4, 118589},
	{"RJAZ", 4, 118590},
	{"PMOU", 4, 118591},
	{"OLIR", 4, 118592},
	{"LWYN", 4, 118593},
	{"FFIA", 4, 118594},
	{"EDRB", 4, 118595},
	{"DJUV", 4, 118596},
	{"DUCTWORK", 8, 118597},
	{"ORTHOGRAPHIC", 12, 118598},
	{"ACTIVATIONS", 11, 118599},
	{"OVERSEA", 7, 118600},
	{"MOSQUITOS", 9, 118601},
	{"JEANNINE", 8, 118602},
	{"KLOSE", 5, 118603},
	{"CENTCOM", 7, 118604},
	{"JANSSON", 7, 118605},
	{"BURGANDY", 8, 118606},
	{"SHERBURNE", 9, 118607},
	{"FRENTE", 6, 118608},
	{"KROEGER", 7, 118609},
	{"PORTILLO", 8, 118610},
	{"AENEAS", 6, 118611},
	{"NUKEAMAZON", 10, 118612},
	{"NARAL", 5, 118613},
	{"KNICK", 5, 118614},
	{"BAATH", 5, 118615},
	{"RICKIE", 6, 118616},
	{"XDIF", 4, 118617},
	{"RYNG", 4, 118618},
	{"RTEW", 4, 118619},
	{"RJIN", 4, 118620},
	{"FISF", 4, 118621},
	{"DMYI", 4, 118622},
	{"VIDYA", 5, 118623},
	{"RANJIT", 6, 118624},
	{"NARRATES", 8, 118625},
	{"GIRDLES", 7, 118626},
	{"LEFFLER", 7, 118627},
	{"BARNESVILLE", 11, 118628},
	{"MCGEHEE", 7, 118629},
	{"DREA", 4, 118630},
	{"NRDC", 4, 118631},
	{"FIZZY", 5, 118632},
	{"GYMPIE", 6, 118633},
	{"USATF", 5, 118634},
	{"HEARTBROKEN", 11, 118635},
	{"TRIMETHOPRIM", 12, 118636},
	{"COULTHARD", 9, 118637},
	{"PIDM", 4, 118638},
	{"DIMR", 4, 118639},
	{"BHOL", 4, 118640},
	{"SUPERCAB", 8, 118641},
	{"ALEKSANDER", 10, 118642},
	{"HOMEVISIONS", 11, 118643},
	{"DASGUPTA", 8, 118644},
	{"MONGO", 5, 118645},
	{"FEDOR", 5, 118646},
	{"PAROLA", 6, 118647},
	{"LAMENESS", 8, 118648},
	{"DIGITIZERS", 10, 118649},
	{"OFFAL", 5, 118650},
	{"SMITHY", 6, 118651},
	{"STOCKIST", 8, 118652},
	{"WETMORE", 7, 118653},
	{"NASTIEST", 8, 118654},
	{"CEMENTITIOUS", 12, 118655},
	{"PRIVACIDADE", 11, 118656},
	{"DAWNS", 5, 118657},
	{"ULTJ", 4, 118658},
	{"PEAD", 4, 118659},
	{"OSDU", 4, 118660},
	{"EWEQ", 4, 118661},
	{"TENBY", 5, 118662},
	{"MUNGO", 5, 118663},
	{"BANNOCK", 7, 118664},
	{"FRAIS", 5, 118665},
	{"COUVERTURE", 10, 118666},
	{"STAID", 5, 118667},
	{"CRYST", 5, 118668},
	{"ENCIRCLING", 10, 118669},
	{"PUSSEY", 6, 118670},
	{"CRATING", 7, 118671},
	{"FERRULE", 7, 118672},
	{"TIGHTROPE", 9, 118673},
	{"VERTE", 5, 118674},
	{"IGNITES", 7, 118675},
	{"WOVE", 4, 118676},
	{"BENFICA", 7, 118677},
	{"REPAINTED", 9, 118678},
	{"CCDS", 4, 118679},
	{"PITHY", 5, 118680},
	{"ZXL", 3, 118681},
	{"ZWB", 3, 118682},
	{"WDX", 3, 118683},
	{"VUQ", 3, 118684},
	{"QQC", 3, 118685},
	{"QCY", 3, 118686},
	{"QCQ", 3, 118687},
	{"PUQ", 3, 118688},
	{"DQX", 3, 118689},
	{"CVY", 3, 118690},
	{"LOPW", 4, 118691},
	{"GHTZ", 4, 118692},
	{"FTSL", 4, 118693},
	{"DDWH", 4, 118694},
	{"BHAK", 4, 118695},
	{"CARESSED", 8, 118696},
	{"SRPMS", 5, 118697},
	{"INFINITIVE", 10, 118698},
	{"NATRIURETIC", 11, 118699},
	{"MIHAI", 5, 118700},
	{"REDOUTE", 7, 118701},
	{"HYSTERICALLY", 12, 118702},
	{"KATHREIN", 8, 118703},
	{"SATTELITE", 9, 118704},
	{"BELLEFONTAINE", 13, 118705},
	{"CRUZI", 5, 118706},
	{"SHAYLA", 6, 118707},
	{"WINDSURF", 8, 118708},
	{"ENROLLS", 7, 118709},
	{"CHAUDHURI", 9, 118710},
	{"SHORTBREAD", 10, 118711},
	{"INCANTATION", 11, 118712},
	{"WHISTLEBLOWERS", 14, 118713},
	{"BLISSFULLY", 10, 118714},
	{"SHIRK", 5, 118715},
	{"TAHLEQUAH", 9, 118716},
	{"GRATIN", 6, 118717},
	{"GALLERI", 7, 118718},
	{"ZADI", 4, 118719},
	{"YISY", 4, 118720},
	{"XFAM", 4, 118721},
	{"UPAU", 4, 118722},
	{"OECK", 4, 118723},
	{"NMUH", 4, 118724},
	{"INWW", 4, 118725},
	{"FYCO", 4, 118726},
	{"EURH", 4, 118727},
	{"EGGT", 4, 118728},
	{"DOFZ", 4, 118729},
	{"DHOV", 4, 118730},
	{"DCYB", 4, 118731},
	{"OPCODES", 7, 118732},
	{"AMAZONIA", 8, 118733},
	{"KAIROS", 6, 118734},
	{"PANGS", 5, 118735},
	{"SPECIALE", 8, 118736},
	{"MONSIGNOR", 9, 118737},
	{"KAORU", 5, 118738},
	{"CAFFEINATED", 11, 118739},
	{"FULNESS", 7, 118740},
	{"NCBA", 4, 118741},
	{"WAPP", 4, 118742},
	{"CROUTONS", 8, 118743},
	{"UNKLE", 5, 118744},
	{"BUTTMAN", 7, 118745},
	{"SAVILE", 6, 118746},
	{"HASLAM", 6, 118747},
	{"SUBPROJECT", 10, 118748},
	{"BWC", 3, 118749},
	{"KANON", 5, 118750},
	{"TOLBERT", 7, 118751},
	{"DUNGENESS", 9, 118752},
	{"COMMANDE", 8, 118753},
	{"DOMESTICS", 9, 118754},
	{"UNPRETENTIOUS", 13, 118755},
	{"KHALEEJ", 7, 118756},
	{"BODO", 4, 118757},
	{"POACHERS", 8, 118758},
	{"LEGM", 4, 118759},
	{"HILW", 4, 118760},
	{"BKIN", 4, 118761},
	{"LYTT", 4, 118762},
	{"DIGITA", 6, 118763},
	{"SOUNDERS", 8, 118764},
	{"JOURNALER", 9, 118765},
	{"INVERCLYDE", 10, 118766},
	{"GALVANIC", 8, 118767},
	{"ENTERTAINM", 10, 118768},
	{"DATASOURCES", 11, 118769},
	{"WENG", 4, 118770},
	{"BALOCHISTAN", 11, 118771},
	{"MALAYSIANS", 10, 118772},
	{"SIPIX", 5, 118773},
	{"YDCO", 4, 118774},
	{"VBRO", 4, 118775},
	{"TDUP", 4, 118776},
	{"RILK", 4, 118777},
	{"PEXT", 4, 118778},
	{"OBCU", 4, 118779},
	{"LAAB", 4, 118780},
	{"EUPU", 4, 118781},
	{"DRDI", 4, 118782},
	{"COFD", 4, 118783},
	{"BENL", 4, 118784},
	{"ALDV", 4, 118785},
	{"NARR", 4, 118786},
	{"WORLDRES", 8, 118787},
	{"KNUTSFORD", 9, 118788},
	{"CORNFLOWER", 10, 118789},
	{"SPANGLISH", 9, 118790},
	{"KOREN", 5, 118791},
	{"UKBETTING", 9, 118792},
	{"JOVEN", 5, 118793},
	{"MOGADISHU", 9, 118794},
	{"WIKINEWS", 8, 118795},
	{"PARLANCE", 8, 118796},
	{"GCR", 3, 118797},
	{"LETHARGIC", 9, 118798},
	{"DRUNKARD", 8, 118799},
	{"LANGPACK", 8, 118800},
	{"ZCHA", 4, 118801},
	{"YLIP", 4, 118802},
	{"TYND", 4, 118803},
	{"RSKU", 4, 118804},
	{"NDLL", 4, 118805},
	{"EVMA", 4, 118806},
	{"EMLB", 4, 118807},
	{"AABR", 4, 118808},
	{"SHIGA", 5, 118809},
	{"ADCOCK", 6, 118810},
	{"SYSDEPS", 7, 118811},
	{"PROBST", 6, 118812},
	{"MONOPOLE", 8, 118813},
	{"RIBOSOMES", 9, 118814},
	{"MASADA", 6, 118815},
	{"FIELDNAME", 9, 118816},
	{"CONVEYANCES", 11, 118817},
	{"STEINMETZ", 9, 118818},
	{"ANTICOMPETITIVE", 15, 118819},
	{"MAJORED", 7, 118820},
	{"COWPER", 6, 118821},
	{"CATALYZE", 8, 118822},
	{"NORTHALLERTON", 13, 118823},
	{"YRHO", 4, 118824},
	{"LTFE", 4, 118825},
	{"LMWE", 4, 118826},
	{"LIPK", 4, 118827},
	{"HKIM", 4, 118828},
	{"GDUM", 4, 118829},
	{"FEAM", 4, 118830},
	{"EUKG", 4, 118831},
	{"CHOME", 5, 118832},
	{"NOSOCOMIAL", 10, 118833},
	{"CALKINS", 7, 118834},
	{"BRONZES", 7, 118835},
	{"KNELL", 5, 118836},
	{"EMAGIC", 6, 118837},
	{"PROFITED", 8, 118838},
	{"KDEMULTIMEDIA", 13, 118839},
	{"FLAVIA", 6, 118840},
	{"ENCHILADAS", 10, 118841},
	{"YMPU", 4, 118842},
	{"VAOF", 4, 118843},
	{"UXLE", 4, 118844},
	{"RKOL", 4, 118845},
	{"NLIP", 4, 118846},
	{"MPSL", 4, 118847},
	{"ELLQ", 4, 118848},
	{"DOLW", 4, 118849},
	{"AIBU", 4, 118850},
	{"AMPLIFIES", 9, 118851},
	{"BAYWOOD", 7, 118852},
	{"STARTLE", 7, 118853},
	{"KIGALI", 6, 118854},
	{"HEARTBREAKERS", 13, 118855},
	{"SNOWBIRDS", 9, 118856},
	{"ZIDANE", 6, 118857},
	{"ALGERNON", 8, 118858},
	{"LINDELL", 7, 118859},
	{"MICROMETERS", 11, 118860},
	{"MULTISTATE", 10, 118861},
	{"SMASHES", 7, 118862},
	{"EXTERMINATE", 11, 118863},
	{"PEIC", 4, 118864},
	{"OMBM", 4, 118865},
	{"OCTW", 4, 118866},
	{"MYUS", 4, 118867},
	{"MBCO", 4, 118868},
	{"CCOB", 4, 118869},
	{"HEIKKI", 6, 118870},
	{"ERECTOR", 7, 118871},
	{"BUCKSHOT", 8, 118872},
	{"ELECTRODYNAMICS", 15, 118873},
	{"DRUMSTICKS", 10, 118874},
	{"EXALT", 5, 118875},
	{"MACCENTRAL", 10, 118876},
	{"COMPLEANNO", 10, 118877},
	{"FARRAGUT", 8, 118878},
	{"GOBI", 4, 118879},
	{"INFONET", 7, 118880},
	{"TESTKING", 8, 118881},
	{"DIMPLEX", 7, 118882},
	{"CEDAW", 5, 118883},
	{"GLASSJAW", 8, 118884},
	{"LOVERBOY", 8, 118885},
	{"YITG", 4, 118886},
	{"UFFU", 4, 118887},
	{"SDAG", 4, 118888},
	{"LAAD", 4, 118889},
	{"GIVA", 4, 118890},
	{"FRAF", 4, 118891},
	{"DOSL", 4, 118892},
	{"DBAH", 4, 118893},
	{"AWSL", 4, 118894},
	{"INTERLUDES", 10, 118895},
	{"LORTON", 6, 118896},
	{"PARATROOPER", 11, 118897},
	{"JAHREN", 6, 118898},
	{"CHALCEDONY", 10, 118899},
	{"PARISI", 6, 118900},
	{"CAUCASIANS", 10, 118901},
	{"ALACANT", 7, 118902},
	{"IGNACE", 6, 118903},
	{"MORTGAGEMAVERICKSONLINE", 23, 118904},
	{"ERASABLE", 8, 118905},
	{"CINERGY", 7, 118906},
	{"PROPELLERHEAD", 13, 118907},
	{"CUEVAS", 6, 118908},
	{"BIDE", 4, 118909},
	{"SUITOR", 6, 118910},
	{"TRADITIONALIST", 14, 118911},
	{"PHRA", 4, 118912},
	{"INTERMISSIONS", 13, 118913},
	{"PARKHURST", 9, 118914},
	{"SCAY", 4, 118915},
	{"OUDG", 4, 118916},
	{"MEEG", 4, 118917},
	{"IPIR", 4, 118918},
	{"FANL", 4, 118919},
	{"EZFA", 4, 118920},
	{"DFAK", 4, 118921},
	{"CUSN", 4, 118922},
	{"CICHLID", 7, 118923},
	{"TYNAN", 5, 118924},
	{"SHUTTLEWORTH", 12, 118925},
	{"JUXTAPOSED", 10, 118926},
	{"AWARDEE", 7, 118927},
	{"CRUCIATE", 8, 118928},
	{"TRASPORTO", 9, 118929},
	{"CMMI", 4, 118930},
	{"WWWOFFLE", 8, 118931},
	{"NORTHWAVE", 9, 118932},
	{"BAYAN", 5, 118933},
	{"ABAD", 4, 118934},
	{"REHM", 4, 118935},
	{"BUCKHORN", 8, 118936},
	{"EXTREMEPIXELS", 13, 118937},
	{"CAMPTON", 7, 118938},
	{"MANDELBROT", 10, 118939},
	{"LIMPIEZA", 8, 118940},
	{"ROOMING", 7, 118941},
	{"KATELYN", 7, 118942},
	{"SMALLHOLDER", 11, 118943},
	{"RUSSE", 5, 118944},
	{"SPILLER", 7, 118945},
	{"BEVY", 4, 118946},
	{"WBIZ", 4, 118947},
	{"UPPH", 4, 118948},
	{"UPAV", 4, 118949},
	{"RGSH", 4, 118950},
	{"RAQF", 4, 118951},
	{"MRAR", 4, 118952},
	{"LHIP", 4, 118953},
	{"KEYV", 4, 118954},
	{"HYAF", 4, 118955},
	{"LITHOSPHERE", 11, 118956},
	{"CHOOSEN", 7, 118957},
	{"GRAVELLY", 8, 118958},
	{"WELSHPOOL", 9, 118959},
	{"FORGINGS", 8, 118960},
	{"FLOWMETER", 9, 118961},
	{"BEARCAT", 7, 118962},
	{"INCONSPICUOUS", 13, 118963},
	{"CRECHE", 6, 118964},
	{"ELRIC", 5, 118965},
	{"ILFRACOMBE", 10, 118966},
	{"ITRC", 4, 118967},
	{"ILUGC", 5, 118968},
	{"KUM", 3, 118969},
	{"EXCIMER", 7, 118970},
	{"YPIA", 4, 118971},
	{"KBOY", 4, 118972},
	{"CUEL", 4, 118973},
	{"RECONVENE", 9, 118974},
	{"BUEHLER", 7, 118975},
	{"DISMISSIVE", 10, 118976},
	{"JUSTE", 5, 118977},
	{"CASHEWS", 7, 118978},
	{"BRESSON", 7, 118979},
	{"WINDIR", 6, 118980},
	{"TOXOPLASMOSIS", 13, 118981},
	{"ALESSE", 6, 118982},
	{"SOAPSTONE", 9, 118983},
	{"WOLVERTON", 9, 118984},
	{"CRONENBERG", 10, 118985},
	{"PSYCHOPATH", 10, 118986},
	{"LIANA", 5, 118987},
	{"WISPS", 5, 118988},
	{"SUHARTO", 7, 118989},
	{"SANDBLASTING", 12, 118990},
	{"COMPRAS", 7, 118991},
	{"CHILDMINDERS", 12, 118992},
	{"BANKA", 5, 118993},
	{"OPOSSUM", 7, 118994},
	{"XCOD", 4, 118995},
	{"URRS", 4, 118996},
	{"PYLI", 4, 118997},
	{"MEGY", 4, 118998},
	{"MBYB", 4, 118999},
	{"KYFR", 4, 119000},
	{"CGRI", 4, 119001},
	{"GREENSTONE", 10, 119002},
	{"STOCKBROKERS", 12, 119003},
	{"GHIBLI", 6, 119004},
	{"GBOOLEAN", 8, 119005},
	{"AUTOROUTE", 9, 119006},
	{"SEGFAULTS", 9, 119007},
	{"TICKLES", 7, 119008},
	{"SUNCOM", 6, 119009},
	{"THROCKMORTON", 12, 119010},
	{"MOSHI", 5, 119011},
	{"LAHTI", 5, 119012},
	{"OUTDRAW", 7, 119013},
	{"INTERREGIONAL", 13, 119014},
	{"NAUGHTYOFFICE", 13, 119015},
	{"VAKS", 4, 119016},
	{"UMNB", 4, 119017},
	{"RFWA", 4, 119018},
	{"OKBR", 4, 119019},
	{"KYSI", 4, 119020},
	{"HUNP", 4, 119021},
	{"HFOX", 4, 119022},
	{"URBANE", 6, 119023},
	{"BILSON", 6, 119024},
	{"CHENANGO", 8, 119025},
	{"POWERBOATS", 10, 119026},
	{"KICKBACKS", 9, 119027},
	{"LURKERS", 7, 119028},
	{"MATRESS", 7, 119029},
	{"HOSTBABY", 8, 119030},
	{"ZRIC", 4, 119031},
	{"TTYU", 4, 119032},
	{"NMAF", 4, 119033},
	{"KILP", 4, 119034},
	{"IADV", 4, 119035},
	{"DUEN", 4, 119036},
	{"DRAE", 4, 119037},
	{"AUNL", 4, 119038},
	{"PIPELINING", 10, 119039},
	{"CRAMPONS", 8, 119040},
	{"CABG", 4, 119041},
	{"SARDINE", 7, 119042},
	{"NEBUCHADNEZZAR", 14, 119043},
	{"CKC", 3, 119044},
	{"VGP", 3, 119045},
	{"FOREXBOOKS", 10, 119046},
	{"NUECES", 6, 119047},
	{"HULBERT", 7, 119048},
	{"CRABB", 5, 119049},
	{"CIVILISATIONS", 13, 119050},
	{"NIEMANN", 7, 119051},
	{"MESHING", 7, 119052},
	{"MENISCUS", 8, 119053},
	{"DIFFUSING", 9, 119054},
	{"RESUBMITTED", 11, 119055},
	{"INTERSTATES", 11, 119056},
	{"STUPOR", 6, 119057},
	{"MENOMONEE", 9, 119058},
	{"ZOFT", 4, 119059},
	{"ZBER", 4, 119060},
	{"YNUC", 4, 119061},
	{"WUPH", 4, 119062},
	{"ODDD", 4, 119063},
	{"NNGR", 4, 119064},
	{"IARB", 4, 119065},
	{"GINQ", 4, 119066},
	{"AOLC", 4, 119067},
	{"GLM", 3, 119068},
	{"GRATUITOUSLY", 12, 119069},
	{"COLMAR", 6, 119070},
	{"SAGAMORE", 8, 119071},
	{"NAKAYAMA", 8, 119072},
	{"VIDEOJUEGOS", 11, 119073},
	{"UNFILED", 7, 119074},
	{"AIMLESS", 7, 119075},
	{"LIVELINK", 8, 119076},
	{"RENEGOTIATION", 13, 119077},
	{"PARFAIT", 7, 119078},
	{"THEORIZING", 10, 119079},
	{"SCAVENGERS", 10, 119080},
	{"MKINSTALLDIRS", 13, 119081},
	{"WBAI", 4, 119082},
	{"DFAS", 4, 119083},
	{"YLAG", 4, 119084},
	{"WFOC", 4, 119085},
	{"URGV", 4, 119086},
	{"LUPF", 4, 119087},
	{"GMEO", 4, 119088},
	{"DEAY", 4, 119089},
	{"CMAL", 4, 119090},
	{"BSEV", 4, 119091},
	{"AZYH", 4, 119092},
	{"COMEAU", 6, 119093},
	{"FLIT", 4, 119094},
	{"ADINA", 5, 119095},
	{"PRESI", 5, 119096},
	{"QUIETNESS", 9, 119097},
	{"PANOLA", 6, 119098},
	{"KENNA", 5, 119099},
	{"PLEATS", 6, 119100},
	{"ACCEDE", 6, 119101},
	{"COSPONSOR", 9, 119102},
	{"BERNINA", 7, 119103},
	{"PRESSIT", 7, 119104},
	{"BOOTHE", 6, 119105},
	{"SICHER", 6, 119106},
	{"SORK", 4, 119107},
	{"CELECOXIB", 9, 119108},
	{"MASSAGED", 8, 119109},
	{"MISSONI", 7, 119110},
	{"MEASLY", 6, 119111},
	{"FOLKWAYS", 8, 119112},
	{"SUBDIVIDE", 9, 119113},
	{"YAMHILL", 7, 119114},
	{"QUOTABLES", 9, 119115},
	{"YVEM", 4, 119116},
	{"WOJU", 4, 119117},
	{"OKVA", 4, 119118},
	{"NKGE", 4, 119119},
	{"DOPU", 4, 119120},
	{"COOB", 4, 119121},
	{"CATHARSIS", 9, 119122},
	{"LRU", 3, 119123},
	{"OVERSHADOW", 10, 119124},
	{"SYSCTL", 6, 119125},
	{"PRINCIPALE", 10, 119126},
	{"OUTPLACEMENT", 12, 119127},
	{"ASSIGNOR", 8, 119128},
	{"MALIA", 5, 119129},
	{"JOHNSEN", 7, 119130},
	{"CUDDLES", 7, 119131},
	{"MACYS", 5, 119132},
	{"DILI", 4, 119133},
	{"SORTERS", 7, 119134},
	{"LOTUSPHERE", 10, 119135},
	{"AMORTIZING", 10, 119136},
	{"WELEDA", 6, 119137},
	{"BUIL", 4, 119138},
	{"VIMA", 4, 119139},
	{"SIXK", 4, 119140},
	{"OLAZ", 4, 119141},
	{"OCOB", 4, 119142},
	{"NIXP", 4, 119143},
	{"NDEJ", 4, 119144},
	{"KPRA", 4, 119145},
	{"KIAC", 4, 119146},
	{"KHAU", 4, 119147},
	{"FKRA", 4, 119148},
	{"BURNETTE", 8, 119149},
	{"SANGRIA", 7, 119150},
	{"ANTIVIR", 7, 119151},
	{"ANTILOCK", 8, 119152},
	{"TURNIPS", 7, 119153},
	{"VELOPMENT", 9, 119154},
	{"RACEWAYS", 8, 119155},
	{"BACKSERV", 8, 119156},
	{"STATUETTE", 9, 119157},
	{"BURBS", 5, 119158},
	{"ALLRIGHT", 8, 119159},
	{"WATERBED", 8, 119160},
	{"THEOBALD", 8, 119161},
	{"COVA", 4, 119162},
	{"DIBUJO", 6, 119163},
	{"ZINGY", 5, 119164},
	{"DISBURSE", 8, 119165},
	{"ZALL", 4, 119166},
	{"WAFI", 4, 119167},
	{"PORW", 4, 119168},
	{"PMST", 4, 119169},
	{"LUDL", 4, 119170},
	{"IMIK", 4, 119171},
	{"SCALEABLE", 9, 119172},
	{"KHUSHWANT", 9, 119173},
	{"LAKER", 5, 119174},
	{"BARNA", 5, 119175},
	{"JUNIE", 5, 119176},
	{"JARRE", 5, 119177},
	{"DWINDLED", 8, 119178},
	{"ELABORATES", 10, 119179},
	{"DISPENSES", 9, 119180},
	{"BAHADUR", 7, 119181},
	{"FRANSISCO", 9, 119182},
	{"FERTILIZING", 11, 119183},
	{"OWER", 4, 119184},
	{"ALPHASERVER", 11, 119185},
	{"YTUC", 4, 119186},
	{"WDIE", 4, 119187},
	{"CODR", 4, 119188},
	{"UNIONE", 6, 119189},
	{"NARCISSIST", 10, 119190},
	{"BLACKBODY", 9, 119191},
	{"ESOUND", 6, 119192},
	{"DFB", 3, 119193},
	{"STOMPED", 7, 119194},
	{"PONTYPRIDD", 10, 119195},
	{"FALSEHOODS", 10, 119196},
	{"PINAL", 5, 119197},
	{"SWAMPY", 6, 119198},
	{"EUCH", 4, 119199},
	{"ORIENTING", 9, 119200},
	{"OBTENIR", 7, 119201},
	{"HEADSTONES", 10, 119202},
	{"AVENSIS", 7, 119203},
	{"YOUSSEF", 7, 119204},
	{"BUZ", 3, 119205},
	{"UYBE", 4, 119206},
	{"LTPL", 4, 119207},
	{"LDIB", 4, 119208},
	{"PREBUFFER", 9, 119209},
	{"DONNING", 7, 119210},
	{"DOUGIE", 6, 119211},
	{"HYBL", 4, 119212},
	{"CATECHOLAMINES", 14, 119213},
	{"CECILY", 6, 119214},
	{"DURUM", 5, 119215},
	{"SAPPHO", 6, 119216},
	{"ASTANA", 6, 119217},
	{"PLANERS", 7, 119218},
	{"PUREAV", 6, 119219},
	{"ESTANCIA", 8, 119220},
	{"ARELLANO", 8, 119221},
	{"WURDEN", 6, 119222},
	{"PUBLIKATIONEN", 13, 119223},
	{"URGN", 4, 119224},
	{"UIEM", 4, 119225},
	{"OPYE", 4, 119226},
	{"NBCN", 4, 119227},
	{"MLEH", 4, 119228},
	{"JAYD", 4, 119229},
	{"GDUC", 4, 119230},
	{"DGUR", 4, 119231},
	{"LONGWORTH", 9, 119232},
	{"VIBURNUM", 8, 119233},
	{"MIQUEL", 6, 119234},
	{"MEALTIME", 8, 119235},
	{"VALENTE", 7, 119236},
	{"PBDJ", 4, 119237},
	{"OXIDOREDUCTASES", 15, 119238},
	{"FAMA", 4, 119239},
	{"LIEK", 4, 119240},
	{"EDGECOMBE", 9, 119241},
	{"MARIELLA", 8, 119242},
	{"BIBLICALLY", 10, 119243},
	{"LUSTFUL", 7, 119244},
	{"RFG", 3, 119245},
	{"ESMAY", 5, 119246},
	{"TEHACHAPI", 9, 119247},
	{"IRRELEVANCE", 11, 119248},
	{"GUANO", 5, 119249},
	{"ERDOGAN", 7, 119250},
	{"PRESBYTERIANS", 13, 119251},
	{"PHILHARMONIA", 12, 119252},
	{"FRAGGLE", 7, 119253},
	{"DOMS", 4, 119254},
	{"BRINT", 5, 119255},
	{"MOLLUSKS", 8, 119256},
	{"COMPAR", 6, 119257},
	{"ZDID", 4, 119258},
	{"RPOF", 4, 119259},
	{"PTFI", 4, 119260},
	{"PASF", 4, 119261},
	{"OIMB", 4, 119262},
	{"HSDU", 4, 119263},
	{"DZIE", 4, 119264},
	{"WORSHIPED", 9, 119265},
	{"DUQUE", 5, 119266},
	{"NCTM", 4, 119267},
	{"FERL", 4, 119268},
	{"GRANDAD", 7, 119269},
	{"AUTEM", 5, 119270},
	{"REBUKED", 7, 119271},
	{"LINDAHL", 7, 119272},
	{"ELANCE", 6, 119273},
	{"ROCKBRIDGE", 10, 119274},
	{"DELAUNAY", 8, 119275},
	{"NONMEMBER", 9, 119276},
	{"BPR", 3, 119277},
	{"NECROTIC", 8, 119278},
	{"OPTRONICS", 9, 119279},
	{"BUYOUTS", 7, 119280},
	{"CLOISTERS", 9, 119281},
	{"EVERYPLACE", 10, 119282},
	{"FRIENDSWOOD", 11, 119283},
	{"LUELLA", 6, 119284},
	{"WICOMICO", 8, 119285},
	{"SMEY", 4, 119286},
	{"SCIG", 4, 119287},
	{"PSRU", 4, 119288},
	{"NIDL", 4, 119289},
	{"MBSD", 4, 119290},
	{"KMEL", 4, 119291},
	{"FTYI", 4, 119292},
	{"EUKF", 4, 119293},
	{"ETYV", 4, 119294},
	{"DZAN", 4, 119295},
	{"BWIN", 4, 119296},
	{"PRESUMPTUOUS", 12, 119297},
	{"CPJ", 3, 119298},
	{"TOOTHACHE", 9, 119299},
	{"RASHAD", 6, 119300},
	{"MISSTATEMENT", 12, 119301},
	{"CADALYST", 8, 119302},
	{"PAPILLOMA", 9, 119303},
	{"INTERWEB", 8, 119304},
	{"REDRUM", 6, 119305},
	{"PHENOLS", 7, 119306},
	{"PRESAGE", 7, 119307},
	{"ANASAZI", 7, 119308},
	{"SOFTWORKS", 9, 119309},
	{"BOARS", 5, 119310},
	{"TEDDINGTON", 10, 119311},
	{"AFORE", 5, 119312},
	{"FANSEDGE", 8, 119313},
	{"MARDEN", 6, 119314},
	{"QUATRO", 6, 119315},
	{"JAPANES", 7, 119316},
	{"YMOF", 4, 119317},
	{"WIWI", 4, 119318},
	{"UYRE", 4, 119319},
	{"RZHA", 4, 119320},
	{"RYPM", 4, 119321},
	{"OUDD", 4, 119322},
	{"LLUV", 4, 119323},
	{"GMYD", 4, 119324},
	{"GIFO", 4, 119325},
	{"AKVI", 4, 119326},
	{"DOUR", 4, 119327},
	{"SEQUIM", 6, 119328},
	{"MOISTENED", 9, 119329},
	{"KEGS", 4, 119330},
	{"NCSL", 4, 119331},
	{"UNADULTERATED", 13, 119332},
	{"FAIRYTALES", 10, 119333},
	{"SPARKNOTES", 10, 119334},
	{"RECIPROCATE", 11, 119335},
	{"HEGEMONIC", 9, 119336},
	{"EXPLOITATIVE", 12, 119337},
	{"RUISLIP", 7, 119338},
	{"SKANDIA", 7, 119339},
	{"DREAMBOOK", 9, 119340},
	{"URTICARIA", 9, 119341},
	{"NEONATOLOGY", 11, 119342},
	{"NANOPARTICLE", 12, 119343},
	{"VERDUN", 6, 119344},
	{"MUEBLES", 7, 119345},
	{"UNACCEPTABLY", 12, 119346},
	{"UBFA", 4, 119347},
	{"RUNV", 4, 119348},
	{"RMPI", 4, 119349},
	{"REXO", 4, 119350},
	{"PWOO", 4, 119351},
	{"OPJU", 4, 119352},
	{"ERLS", 4, 119353},
	{"DMU", 3, 119354},
	{"HOLOGRAPHY", 10, 119355},
	{"INURL", 5, 119356},
	{"RADE", 4, 119357},
	{"POSTRE", 6, 119358},
	{"QUIA", 4, 119359},
	{"ROSALES", 7, 119360},
	{"CAMISA", 6, 119361},
	{"KONIG", 5, 119362},
	{"SPINESHANK", 10, 119363},
	{"REINVEST", 8, 119364},
	{"ROSSELLINI", 10, 119365},
	{"UOBA", 4, 119366},
	{"UNPH", 4, 119367},
	{"OKUM", 4, 119368},
	{"OBJO", 4, 119369},
	{"HSBR", 4, 119370},
	{"FEGG", 4, 119371},
	{"EHYM", 4, 119372},
	{"ECAW", 4, 119373},
	{"CEOM", 4, 119374},
	{"HYPNO", 5, 119375},
	{"GOODALE", 7, 119376},
	{"SCHWAN", 6, 119377},
	{"AMADORES", 8, 119378},
	{"SALMONID", 8, 119379},
	{"YOJIMBO", 7, 119380},
	{"BLV", 3, 119381},
	{"BOBL", 4, 119382},
	{"AFFORESTATION", 13, 119383},
	{"DISINCENTIVE", 12, 119384},
	{"HARROLD", 7, 119385},
	{"SERENATA", 8, 119386},
	{"ROJA", 4, 119387},
	{"FAIRHOPE", 8, 119388},
	{"TURBOCHARGER", 12, 119389},
	{"TIDYING", 7, 119390},
	{"SMOKIES", 7, 119391},
	{"ZLEM", 4, 119392},
	{"RMCK", 4, 119393},
	{"OBMO", 4, 119394},
	{"OBHU", 4, 119395},
	{"IJUN", 4, 119396},
	{"CHYF", 4, 119397},
	{"QUOIZEL", 7, 119398},
	{"GAYBOYS", 7, 119399},
	{"HALDANE", 7, 119400},
	{"MAYPOLE", 7, 119401},
	{"BIRDSEYE", 8, 119402},
	{"KASABIAN", 8, 119403},
	{"BEGAT", 5, 119404},
	{"LIFTOFF", 7, 119405},
	{"KEIR", 4, 119406},
	{"ROADWORKS", 9, 119407},
	{"ZEIGLER", 7, 119408},
	{"URLID", 5, 119409},
	{"TEAMBUILDING", 12, 119410},
	{"XUSO", 4, 119411},
	{"VSMA", 4, 119412},
	{"NFOG", 4, 119413},
	{"DTHP", 4, 119414},
	{"DODR", 4, 119415},
	{"AJAD", 4, 119416},
	{"UCHAR", 5, 119417},
	{"STUDENTEN", 9, 119418},
	{"ASIATIQUE", 9, 119419},
	{"SUBSERIES", 9, 119420},
	{"SORBITOL", 8, 119421},
	{"DATURA", 6, 119422},
	{"CAMM", 4, 119423},
	{"JANNA", 5, 119424},
	{"SALAMANDERS", 11, 119425},
	{"MINIPORTAL", 10, 119426},
	{"MANEUVERABILITY", 15, 119427},
	{"STABLY", 6, 119428},
	{"PROPELLING", 10, 119429},
	{"VOCOPRO", 7, 119430},
	{"RIPEN", 5, 119431},
	{"BERNIER", 7, 119432},
	{"LENSING", 7, 119433},
	{"REKINDLE", 8, 119434},
	{"YMOC", 4, 119435},
	{"UEUR", 4, 119436},
	{"TLOD", 4, 119437},
	{"PPSO", 4, 119438},
	{"NYKA", 4, 119439},
	{"MBID", 4, 119440},
	{"LTJO", 4, 119441},
	{"DVIK", 4, 119442},
	{"DTHB", 4, 119443},
	{"CYMI", 4, 119444},
	{"RACHMANINOFF", 12, 119445},
	{"PIGLETS", 7, 119446},
	{"SUFFOCATING", 11, 119447},
	{"DIMEN", 5, 119448},
	{"LITIGATED", 9, 119449},
	{"NEWPATH", 7, 119450},
	{"GRASSE", 6, 119451},
	{"CINQ", 4, 119452},
	{"MORELLI", 7, 119453},
	{"NORDETTE", 8, 119454},
	{"SWEATSHOPS", 10, 119455},
	{"LIFERS", 6, 119456},
	{"MONGERS", 7, 119457},
	{"GIBSONS", 7, 119458},
	{"WANM", 4, 119459},
	{"VPLA", 4, 119460},
	{"OWPH", 4, 119461},
	{"MAEV", 4, 119462},
	{"KIAW", 4, 119463},
	{"KEOK", 4, 119464},
	{"KEGL", 4, 119465},
	{"IXGR", 4, 119466},
	{"GSKA", 4, 119467},
	{"GNEM", 4, 119468},
	{"GMAM", 4, 119469},
	{"ERUE", 4, 119470},
	{"IGNITING", 8, 119471},
	{"LAFLEUR", 7, 119472},
	{"WEARE", 5, 119473},
	{"APPN", 4, 119474},
	{"ANTONELLA", 9, 119475},
	{"ADPCM", 5, 119476},
	{"BRAWN", 5, 119477},
	{"ARBENNIG", 8, 119478},
	{"FROWNING", 8, 119479},
	{"GAIUS", 5, 119480},
	{"TRAKTOR", 7, 119481},
	{"SNACKING", 8, 119482},
	{"CAFETERIAS", 10, 119483},
	{"PECHALA", 7, 119484},
	{"WHISKIES", 8, 119485},
	{"PRAETORIAN", 10, 119486},
	{"ANNUITANT", 9, 119487},
	{"PERIODONTICS", 12, 119488},
	{"BREASTFED", 9, 119489},
	{"OUSTER", 6, 119490},
	{"MSGBOX", 6, 119491},
	{"GREASES", 7, 119492},
	{"AKUMAL", 6, 119493},
	{"LEDOUX", 6, 119494},
	{"WHEG", 4, 119495},
	{"TCYO", 4, 119496},
	{"RDSQ", 4, 119497},
	{"NKJE", 4, 119498},
	{"LDOY", 4, 119499},
	{"IGPU", 4, 119500},
	{"AYOD", 4, 119501},
	{"MATCHLESS", 9, 119502},
	{"REFINISH", 8, 119503},
	{"AETHER", 6, 119504},
	{"PROHIBITIVELY", 13, 119505},
	{"CASTANEDA", 9, 119506},
	{"LAIKA", 5, 119507},
	{"BROILERS", 8, 119508},
	{"LEGENDRE", 8, 119509},
	{"WOLTERS", 7, 119510},
	{"PACTS", 5, 119511},
	{"CHOLINESTERASE", 14, 119512},
	{"DEFORMABLE", 10, 119513},
	{"AUSCERT", 7, 119514},
	{"NETRA", 5, 119515},
	{"MORGANS", 7, 119516},
	{"TAMIA", 5, 119517},
	{"TICKETWEB", 9, 119518},
	{"FORTHE", 6, 119519},
	{"WOLS", 4, 119520},
	{"WNAV", 4, 119521},
	{"RNKA", 4, 119522},
	{"REGIO", 5, 119523},
	{"SAYLOR", 6, 119524},
	{"FLUG", 4, 119525},
	{"PORR", 4, 119526},
	{"YQV", 3, 119527},
	{"VWU", 3, 119528},
	{"MZJ", 3, 119529},
	{"GCQ", 3, 119530},
	{"CXY", 3, 119531},
	{"FORTIER", 7, 119532},
	{"BLACKSTAR", 9, 119533},
	{"KLINGELTON", 10, 119534},
	{"CAPTOPRIL", 9, 119535},
	{"JMF", 3, 119536},
	{"WYDEN", 5, 119537},
	{"DAWGS", 5, 119538},
	{"JIANGXI", 7, 119539},
	{"BOATMAN", 7, 119540},
	{"WOWW", 4, 119541},
	{"WMIR", 4, 119542},
	{"UMFU", 4, 119543},
	{"UILF", 4, 119544},
	{"UEIM", 4, 119545},
	{"RPSR", 4, 119546},
	{"QUAW", 4, 119547},
	{"OMOZ", 4, 119548},
	{"MBUE", 4, 119549},
	{"LURT", 4, 119550},
	{"LMAU", 4, 119551},
	{"KLOT", 4, 119552},
	{"FFNA", 4, 119553},
	{"BYUT", 4, 119554},
	{"AUBO", 4, 119555},
	{"AMSTEL", 6, 119556},
	{"LAPOINTE", 8, 119557},
	{"EIGENVECTOR", 11, 119558},
	{"SARDAR", 6, 119559},
	{"MARKLEY", 7, 119560},
	{"UNCONCERNED", 11, 119561},
	{"REFUGIO", 7, 119562},
	{"VERSIONPRINTER", 14, 119563},
	{"FIETSEN", 7, 119564},
	{"UNITA", 5, 119565},
	{"NEWLYWED", 8, 119566},
	{"OFFTEK", 6, 119567},
	{"MILWAUKIE", 9, 119568},
	{"EXISTANT", 8, 119569},
	{"MCINNIS", 7, 119570},
	{"BRINDISI", 8, 119571},
	{"WFAT", 4, 119572},
	{"UKUR", 4, 119573},
	{"NCEZ", 4, 119574},
	{"LMBY", 4, 119575},
	{"LFOV", 4, 119576},
	{"HODC", 4, 119577},
	{"FUKUI", 5, 119578},
	{"ZIPLY", 5, 119579},
	{"HERITABILITY", 12, 119580},
	{"BELLAONLINE", 11, 119581},
	{"WOULDA", 6, 119582},
	{"OVERCLOCKED", 11, 119583},
	{"MYADSL", 6, 119584},
	{"DOOD", 4, 119585},
	{"NEGATES", 7, 119586},
	{"HALVERSON", 9, 119587},
	{"VTABLE", 6, 119588},
	{"AUSTER", 6, 119589},
	{"RADKO", 5, 119590},
	{"SALUDOS", 7, 119591},
	{"DOLITTLE", 8, 119592},
	{"YUV", 3, 119593},
	{"METASTABLE", 10, 119594},
	{"PGCE", 4, 119595},
	{"VSCH", 4, 119596},
	{"RSFC", 4, 119597},
	{"REKB", 4, 119598},
	{"RBIF", 4, 119599},
	{"PGIR", 4, 119600},
	{"DDBA", 4, 119601},
	{"CSPU", 4, 119602},
	{"ABYJ", 4, 119603},
	{"ORTHOGRAPHY", 11, 119604},
	{"BRICKMAN", 8, 119605},
	{"PUTTS", 5, 119606},
	{"MARTINEAU", 9, 119607},
	{"BLOGSTREET", 10, 119608},
	{"BORSE", 5, 119609},
	{"KLINGER", 7, 119610},
	{"FESTUS", 6, 119611},
	{"MANOIR", 6, 119612},
	{"SEMIOTIC", 8, 119613},
	{"MANTON", 6, 119614},
	{"SHRINERS", 8, 119615},
	{"MFL", 3, 119616},
	{"WAUWATOSA", 9, 119617},
	{"INSTANTSERVERS", 14, 119618},
	{"EXTERMINATOR", 12, 119619},
	{"BACKBONES", 9, 119620},
	{"JUILLIARD", 9, 119621},
	{"CONTIENE", 8, 119622},
	{"WISBECH", 7, 119623},
	{"ARBONNE", 7, 119624},
	{"SBEV", 4, 119625},
	{"OYTR", 4, 119626},
	{"IOFB", 4, 119627},
	{"IGSK", 4, 119628},
	{"ICIV", 4, 119629},
	{"HNUR", 4, 119630},
	{"EGYG", 4, 119631},
	{"ECDE", 4, 119632},
	{"MISBEHAVIOR", 11, 119633},
	{"CONJURED", 8, 119634},
	{"ASSYRIANS", 9, 119635},
	{"ACRYLATE", 8, 119636},
	{"ALLS", 4, 119637},
	{"SELV", 4, 119638},
	{"SINGAPOREANS", 12, 119639},
	{"SCIENZA", 7, 119640},
	{"HOLOTYPE", 8, 119641},
	{"IVTV", 4, 119642},
	{"WECHSLER", 8, 119643},
	{"VAULTING", 8, 119644},
	{"MARYAM", 6, 119645},
	{"PECO", 4, 119646},
	{"SPAGNA", 6, 119647},
	{"TELK", 4, 119648},
	{"REMT", 4, 119649},
	{"REFT", 4, 119650},
	{"RBEM", 4, 119651},
	{"OUOB", 4, 119652},
	{"NKEW", 4, 119653},
	{"IDIK", 4, 119654},
	{"EGIU", 4, 119655},
	{"GARNERING", 9, 119656},
	{"MARLTON", 7, 119657},
	{"FAUSTO", 6, 119658},
	{"BOWTIE", 6, 119659},
	{"FONTE", 5, 119660},
	{"SYNCOPE", 7, 119661},
	{"NUISANCES", 9, 119662},
	{"NDVI", 4, 119663},
	{"FINLANDIA", 9, 119664},
	{"GOSSIPING", 9, 119665},
	{"MELDEN", 6, 119666},
	{"FRESHEN", 7, 119667},
	{"NASIR", 5, 119668},
	{"BOSTITCH", 8, 119669},
	{"TUGGED", 6, 119670},
	{"RETRIEVALS", 10, 119671},
	{"LICENCING", 9, 119672},
	{"YOSC", 4, 119673},
	{"YKEA", 4, 119674},
	{"YETG", 4, 119675},
	{"WHID", 4, 119676},
	{"UGOC", 4, 119677},
	{"UAFR", 4, 119678},
	{"TTCL", 4, 119679},
	{"TJUI", 4, 119680},
	{"TCED", 4, 119681},
	{"SOXP", 4, 119682},
	{"SKSD", 4, 119683},
	{"PHBE", 4, 119684},
	{"PFLE", 4, 119685},
	{"FKRI", 4, 119686},
	{"ECKG", 4, 119687},
	{"DVDW", 4, 119688},
	{"BIEC", 4, 119689},
	{"CHEERIOS", 8, 119690},
	{"PINCUS", 6, 119691},
	{"OUTDONE", 7, 119692},
	{"ANTONOV", 7, 119693},
	{"INSTRUMENTALIST", 15, 119694},
	{"STERNUM", 7, 119695},
	{"PIJPEN", 6, 119696},
	{"EVELOPMENT", 10, 119697},
	{"PHOSPHORYLASE", 13, 119698},
	{"VALERI", 6, 119699},
	{"TREACY", 6, 119700},
	{"EVARISTE", 8, 119701},
	{"VIBRAPHONE", 10, 119702},
	{"IBLOG", 5, 119703},
	{"SHWRS", 5, 119704},
	{"JETSPEED", 8, 119705},
	{"IGUANAS", 7, 119706},
	{"DETEST", 6, 119707},
	{"XLEV", 4, 119708},
	{"VPAN", 4, 119709},
	{"OWKA", 4, 119710},
	{"MPPO", 4, 119711},
	{"JROF", 4, 119712},
	{"HBUY", 4, 119713},
	{"GFEB", 4, 119714},
	{"FLWI", 4, 119715},
	{"DKRE", 4, 119716},
	{"HAMMING", 7, 119717},
	{"CHAINRINGS", 10, 119718},
	{"NECRONOMICON", 12, 119719},
	{"PHOBOS", 6, 119720},
	{"TELARC", 6, 119721},
	{"STRASSENSTRICH", 14, 119722},
	{"OVERWRITES", 10, 119723},
	{"VERSIONPRINT", 12, 119724},
	{"NYPHP", 5, 119725},
	{"VISCOELASTIC", 12, 119726},
	{"DPSYCO", 6, 119727},
	{"RECIRCULATING", 13, 119728},
	{"JORDANA", 7, 119729},
	{"MLF", 3, 119730},
	{"SOUTHBOROUGH", 12, 119731},
	{"PARADED", 7, 119732},
	{"DESENSITIZATION", 15, 119733},
	{"TRIFLING", 8, 119734},
	{"UNDERGROWTH", 11, 119735},
	{"ENAMORED", 8, 119736},
	{"XISR", 4, 119737},
	{"XECS", 4, 119738},
	{"VOYO", 4, 119739},
	{"UIWA", 4, 119740},
	{"PQUE", 4, 119741},
	{"PPOO", 4, 119742},
	{"PKID", 4, 119743},
	{"LWOL", 4, 119744},
	{"GMYW", 4, 119745},
	{"DROH", 4, 119746},
	{"DCYN", 4, 119747},
	{"CIBI", 4, 119748},
	{"AJUV", 4, 119749},
	{"GOODEN", 6, 119750},
	{"BODAS", 5, 119751},
	{"COEDGE", 6, 119752},
	{"CARLOTTA", 8, 119753},
	{"MEGO", 4, 119754},
	{"MTVN", 4, 119755},
	{"UNIVERSI", 8, 119756},
	{"CEUX", 4, 119757},
	{"ITERATIVELY", 11, 119758},
	{"INTRESTED", 9, 119759},
	{"CUATRO", 6, 119760},
	{"HARDCOVERS", 10, 119761},
	{"PINFO", 5, 119762},
	{"PHAIDON", 7, 119763},
	{"METHODE", 7, 119764},
	{"STIPE", 5, 119765},
	{"INTOUCH", 7, 119766},
	{"SUPERCENTER", 11, 119767},
	{"VIGILANTES", 10, 119768},
	{"TOOTHPICKS", 10, 119769},
	{"ULTERIOR", 8, 119770},
	{"IRAF", 4, 119771},
	{"IRKB", 4, 119772},
	{"FURM", 4, 119773},
	{"FIXO", 4, 119774},
	{"DPOM", 4, 119775},
	{"AWDU", 4, 119776},
	{"HARDTAIL", 8, 119777},
	{"MULTIMETERS", 11, 119778},
	{"AHRC", 4, 119779},
	{"CRYPTOLOGIC", 11, 119780},
	{"MOKA", 4, 119781},
	{"DOWNPLAY", 8, 119782},
	{"COCONINO", 8, 119783},
	{"PURO", 4, 119784},
	{"SCAPES", 6, 119785},
	{"ASBESTOSIS", 10, 119786},
	{"INBUILT", 7, 119787},
	{"RECHARGER", 9, 119788},
	{"LEGLER", 6, 119789},
	{"PROTOSS", 7, 119790},
	{"MXDJ", 4, 119791},
	{"AUSAID", 6, 119792},
	{"ECHOLS", 6, 119793},
	{"EUROCARD", 8, 119794},
	{"HOMETOPIC", 9, 119795},
	{"UMII", 4, 119796},
	{"OYAW", 4, 119797},
	{"NIXF", 4, 119798},
	{"KYDO", 4, 119799},
	{"KLAD", 4, 119800},
	{"KALP", 4, 119801},
	{"IRLL", 4, 119802},
	{"FKEV", 4, 119803},
	{"DPIZ", 4, 119804},
	{"DICD", 4, 119805},
	{"CAMRON", 6, 119806},
	{"BURZUM", 6, 119807},
	{"NIPPER", 6, 119808},
	{"SKINCEUTICALS", 13, 119809},
	{"ATTENBOROUGH", 12, 119810},
	{"HERACLES", 8, 119811},
	{"WARFIGHTING", 11, 119812},
	{"WHIRLED", 7, 119813},
	{"INVENTORIED", 11, 119814},
	{"PADSTOW", 7, 119815},
	{"ENTHUSED", 8, 119816},
	{"RECLAME", 7, 119817},
	{"DABS", 4, 119818},
	{"MINHA", 5, 119819},
	{"LENTICULAR", 10, 119820},
	{"PASSIM", 6, 119821},
	{"SYMBOLOGY", 9, 119822},
	{"MARINUS", 7, 119823},
	{"CHEX", 4, 119824},
	{"TAKR", 4, 119825},
	{"RETV", 4, 119826},
	{"NMUD", 4, 119827},
	{"LIFN", 4, 119828},
	{"HBEY", 4, 119829},
	{"EBTM", 4, 119830},
	{"SHEETMETAL", 10, 119831},
	{"ENLISTS", 7, 119832},
	{"GEBRUIK", 7, 119833},
	{"CYBERCULTURE", 12, 119834},
	{"CAVITATION", 10, 119835},
	{"DIHYDRO", 7, 119836},
	{"LANSKY", 6, 119837},
	{"POSY", 4, 119838},
	{"ARTISANAL", 9, 119839},
	{"MCGWIRE", 7, 119840},
	{"SCINTILLA", 9, 119841},
	{"LAKEPORT", 8, 119842},
	{"TEARDOWN", 8, 119843},
	{"EJAC", 4, 119844},
	{"NOWRA", 5, 119845},
	{"ZAKOPANE", 8, 119846},
	{"VICKS", 5, 119847},
	{"LLD", 3, 119848},
	{"MALLON", 6, 119849},
	{"VRAAG", 5, 119850},
	{"JOVIAL", 6, 119851},
	{"SCOUNDREL", 9, 119852},
	{"YSOY", 4, 119853},
	{"PMYS", 4, 119854},
	{"MVIN", 4, 119855},
	{"IZEV", 4, 119856},
	{"ILCI", 4, 119857},
	{"GYBI", 4, 119858},
	{"GPUM", 4, 119859},
	{"ENUW", 4, 119860},
	{"CTSJ", 4, 119861},
	{"MENDELSON", 9, 119862},
	{"CORUNA", 6, 119863},
	{"PLEURISY", 8, 119864},
	{"FUGAZI", 6, 119865},
	{"FACONNABLE", 10, 119866},
	{"UUP", 3, 119867},
	{"KUBA", 4, 119868},
	{"EDIFACT", 7, 119869},
	{"ROMANY", 6, 119870},
	{"MEMEORANDUM", 11, 119871},
	{"CYBERCODERS", 11, 119872},
	{"TOTORO", 6, 119873},
	{"KRISTENSEN", 10, 119874},
	{"GRAEMLINS", 9, 119875},
	{"BAGGER", 6, 119876},
	{"INTELLI", 7, 119877},
	{"MOTOS", 5, 119878},
	{"ENSCHEDE", 8, 119879},
	{"NAILERS", 7, 119880},
	{"TRANVESTITES", 12, 119881},
	{"WATM", 4, 119882},
	{"VONC", 4, 119883},
	{"KTEC", 4, 119884},
	{"GJET", 4, 119885},
	{"ASKART", 6, 119886},
	{"ITECH", 5, 119887},
	{"EARNSHAW", 8, 119888},
	{"HADSY", 5, 119889},
	{"DFARS", 5, 119890},
	{"GRAVESIDE", 9, 119891},
	{"DOODY", 5, 119892},
	{"TASCHEN", 7, 119893},
	{"MAJOLICA", 8, 119894},
	{"PORTMEIRION", 11, 119895},
	{"MARIKA", 6, 119896},
	{"KIRKWALL", 8, 119897},
	{"ACCURSED", 8, 119898},
	{"DETRITAL", 8, 119899},
	{"BLARING", 7, 119900},
	{"BRITTAIN", 8, 119901},
	{"ZABU", 4, 119902},
	{"VEUR", 4, 119903},
	{"UPFU", 4, 119904},
	{"NFBI", 4, 119905},
	{"LRYO", 4, 119906},
	{"KICE", 4, 119907},
	{"KBEY", 4, 119908},
	{"GULT", 4, 119909},
	{"DEZH", 4, 119910},
	{"FELISA", 6, 119911},
	{"ENGINED", 7, 119912},
	{"DUPLICITY", 9, 119913},
	{"REJUVENATED", 11, 119914},
	{"MEDDLE", 6, 119915},
	{"IRREFUTABLE", 11, 119916},
	{"PARIGI", 6, 119917},
	{"TOMBOY", 6, 119918},
	{"CHEWBACCA", 9, 119919},
	{"AIKMAN", 6, 119920},
	{"EXALTATION", 10, 119921},
	{"RETARDANTS", 10, 119922},
	{"SEIBERT", 7, 119923},
	{"HANDIWORK", 9, 119924},
	{"COLDCUT", 7, 119925},
	{"CAYE", 4, 119926},
	{"TORU", 4, 119927},
	{"ANDRAS", 6, 119928},
	{"METABOLIZED", 11, 119929},
	{"ALIYAH", 6, 119930},
	{"REAPPOINTED", 11, 119931},
	{"JOYOUSLY", 8, 119932},
	{"RPMO", 4, 119933},
	{"KBIG", 4, 119934},
	{"FMUD", 4, 119935},
	{"DGEY", 4, 119936},
	{"SPOOLER", 7, 119937},
	{"REPSOL", 6, 119938},
	{"UCTS", 4, 119939},
	{"TANCREDO", 8, 119940},
	{"CANCION", 7, 119941},
	{"MTRS", 4, 119942},
	{"HEAPING", 7, 119943},
	{"DENDRITES", 9, 119944},
	{"CHAINMAIL", 9, 119945},
	{"STRIDENT", 8, 119946},
	{"BERNDT", 6, 119947},
	{"BEAUNE", 6, 119948},
	{"DKIM", 4, 119949},
	{"GOOGLES", 7, 119950},
	{"ORATION", 7, 119951},
	{"GRUNTED", 7, 119952},
	{"RICHE", 5, 119953},
	{"PILOTE", 6, 119954},
	{"RHEK", 4, 119955},
	{"LJEN", 4, 119956},
	{"KELC", 4, 119957},
	{"KALY", 4, 119958},
	{"ILOD", 4, 119959},
	{"IKRI", 4, 119960},
	{"IFGI", 4, 119961},
	{"EKOD", 4, 119962},
	{"EEMW", 4, 119963},
	{"DESTABILIZE", 11, 119964},
	{"PINSKIA", 7, 119965},
	{"INTERNATIONALISM", 16, 119966},
	{"FTPADM", 6, 119967},
	{"SMOKEHOUSE", 10, 119968},
	{"SUMMARISING", 11, 119969},
	{"NORDRHEIN", 9, 119970},
	{"EMERICA", 7, 119971},
	{"AREAMAP", 7, 119972},
	{"GOODRIDGE", 9, 119973},
	{"BARBIER", 7, 119974},
	{"ISEMPTY", 7, 119975},
	{"BRITPOP", 7, 119976},
	{"TACCHINI", 8, 119977},
	{"SIMULA", 6, 119978},
	{"BENZOYL", 7, 119979},
	{"ZONR", 4, 119980},
	{"VOYE", 4, 119981},
	{"RNND", 4, 119982},
	{"PORF", 4, 119983},
	{"OTUM", 4, 119984},
	{"OMAZ", 4, 119985},
	{"NRWA", 4, 119986},
	{"NLTD", 4, 119987},
	{"LPHC", 4, 119988},
	{"FWIC", 4, 119989},
	{"KURD", 4, 119990},
	{"BATTS", 5, 119991},
	{"WESCO", 5, 119992},
	{"WAMPUM", 6, 119993},
	{"HAIRPIECES", 10, 119994},
	{"DREADING", 8, 119995},
	{"SUTRAS", 6, 119996},
	{"REDEMPTIVE", 10, 119997},
	{"BELTLINE", 8, 119998},
	{"LONGITUDINALLY", 14, 119999},
	{"SOFTNEWS", 8, 120000},
	{"ELGATO", 6, 120001},
	{"ENDANGERS", 9, 120002},
	{"HUMORIST", 8, 120003},
	{"QUINE", 5, 120004},
	{"GRANDFATHERED", 13, 120005},
	{"YZEW", 4, 120006},
	{"YJOY", 4, 120007},
	{"PTFA", 4, 120008},
	{"OARB", 4, 120009},
	{"LPBO", 4, 120010},
	{"KIWE", 4, 120011},
	{"KHRU", 4, 120012},
	{"IMOC", 4, 120013},
	{"FJUM", 4, 120014},
	{"EMGI", 4, 120015},
	{"DUEW", 4, 120016},
	{"DDOP", 4, 120017},
	{"SEPERATION", 10, 120018},
	{"CANARD", 6, 120019},
	{"NYSED", 5, 120020},
	{"NOURISHES", 9, 120021},
	{"TALLULAH", 8, 120022},
	{"SPRATT", 6, 120023},
	{"KANCHANABURI", 12, 120024},
	{"BATCHED", 7, 120025},
	{"LIBCLANLIB", 10, 120026},
	{"STYLISHLY", 9, 120027},
	{"PARALLELIZATION", 15, 120028},
	{"INTELLIGENTSIA", 14, 120029},
	{"COMBATIVE", 9, 120030},
	{"BIERCE", 6, 120031},
	{"BAKR", 4, 120032},
	{"MENOMONIE", 9, 120033},
	{"EDGBASTON", 9, 120034},
	{"VIEJ", 4, 120035},
	{"KMHA", 4, 120036},
	{"IFPL", 4, 120037},
	{"EUFO", 4, 120038},
	{"EBEU", 4, 120039},
	{"DOGN", 4, 120040},
	{"SUNNA", 5, 120041},
	{"CLECS", 5, 120042},
	{"PREVI", 5, 120043},
	{"AUTOCOMPLETE", 12, 120044},
	{"BRUCELLA", 8, 120045},
	{"WOODFIELD", 9, 120046},
	{"SILOM", 5, 120047},
	{"MATURA", 6, 120048},
	{"KIRSTIE", 7, 120049},
	{"POSITED", 7, 120050},
	{"MICHIKO", 7, 120051},
	{"MANDAMUS", 8, 120052},
	{"TARG", 4, 120053},
	{"MUITO", 5, 120054},
	{"MABSWID", 7, 120055},
	{"DEVGURU", 7, 120056},
	{"FLINTOFF", 8, 120057},
	{"WINKED", 6, 120058},
	{"DITCHING", 8, 120059},
	{"BRIARWOOD", 9, 120060},
	{"HALFORD", 7, 120061},
	{"YNOF", 4, 120062},
	{"VETC", 4, 120063},
	{"SECW", 4, 120064},
	{"RAXA", 4, 120065},
	{"OBYW", 4, 120066},
	{"LFIC", 4, 120067},
	{"DPEG", 4, 120068},
	{"NORTHLAKE", 9, 120069},
	{"BBM", 3, 120070},
	{"NICOLAUS", 8, 120071},
	{"PEDIR", 5, 120072},
	{"AFSC", 4, 120073},
	{"STURGES", 7, 120074},
	{"KUDLOW", 6, 120075},
	{"OTHERWORLD", 10, 120076},
	{"UNHAPPILY", 9, 120077},
	{"RUBE", 4, 120078},
	{"CHRONOMETER", 11, 120079},
	{"BATHGATE", 8, 120080},
	{"SECC", 4, 120081},
	{"ULTRALITE", 9, 120082},
	{"THIMM", 5, 120083},
	{"PKIX", 4, 120084},
	{"SIMILARES", 9, 120085},
	{"FLYBY", 5, 120086},
	{"CARN", 4, 120087},
	{"PINECREST", 9, 120088},
	{"RLUX", 4, 120089},
	{"IGMS", 4, 120090},
	{"EIVY", 4, 120091},
	{"BROL", 4, 120092},
	{"AMYC", 4, 120093},
	{"DETONATE", 8, 120094},
	{"THUNDERSTONE", 12, 120095},
	{"SANDHURST", 9, 120096},
	{"SQUARING", 8, 120097},
	{"BRISAS", 6, 120098},
	{"GUBA", 4, 120099},
	{"THAME", 5, 120100},
	{"PENNINE", 7, 120101},
	{"BLOX", 4, 120102},
	{"REGEBRO", 7, 120103},
	{"PHPLDAPADMIN", 12, 120104},
	{"LEISHMANIASIS", 13, 120105},
	{"CYSYLLTWCH", 10, 120106},
	{"WRING", 5, 120107},
	{"APPARITIONS", 11, 120108},
	{"FIESTAS", 7, 120109},
	{"OGRU", 4, 120110},
	{"LPIM", 4, 120111},
	{"IPVI", 4, 120112},
	{"AZPR", 4, 120113},
	{"SHRIEKING", 9, 120114},
	{"UAVS", 4, 120115},
	{"DITIONS", 7, 120116},
	{"CATON", 5, 120117},
	{"GOOGL", 5, 120118},
	{"BOGUE", 5, 120119},
	{"GRAAF", 5, 120120},
	{"UNWINDING", 9, 120121},
	{"ANDREE", 6, 120122},
	{"DIMA", 4, 120123},
	{"SCURVY", 6, 120124},
	{"GUTMAN", 6, 120125},
	{"PULIZIA", 7, 120126},
	{"COMODO", 6, 120127},
	{"CHALFONT", 8, 120128},
	{"URBANDALE", 9, 120129},
	{"AMANO", 5, 120130},
	{"WARGAME", 7, 120131},
	{"MCCREARY", 8, 120132},
	{"LUMSDEN", 7, 120133},
	{"PLUMERIA", 8, 120134},
	{"OPOK", 4, 120135},
	{"MEXH", 4, 120136},
	{"LPOX", 4, 120137},
	{"KMUL", 4, 120138},
	{"KEIK", 4, 120139},
	{"FTVI", 4, 120140},
	{"EFAW", 4, 120141},
	{"EDMD", 4, 120142},
	{"AORW", 4, 120143},
	{"LEHR", 4, 120144},
	{"ANTISEMITISM", 12, 120145},
	{"KWAL", 4, 120146},
	{"OPHIR", 5, 120147},
	{"WOULDST", 7, 120148},
	{"ELROND", 6, 120149},
	{"STILT", 5, 120150},
	{"LENTEN", 6, 120151},
	{"SNOWBOARDERS", 12, 120152},
	{"POCKETED", 8, 120153},
	{"LIVESHOW", 8, 120154},
	{"WOTU", 4, 120155},
	{"SVIK", 4, 120156},
	{"OELC", 4, 120157},
	{"HKEP", 4, 120158},
	{"DNTV", 4, 120159},
	{"APYW", 4, 120160},
	{"SUSEWWW", 7, 120161},
	{"FILEATTACHMENTS", 15, 120162},
	{"ENORMITY", 8, 120163},
	{"DONINGTON", 9, 120164},
	{"CUNA", 4, 120165},
	{"STRCHR", 6, 120166},
	{"POTENTIOMETERS", 14, 120167},
	{"SALUDA", 6, 120168},
	{"COARSER", 7, 120169},
	{"SYNCHRONY", 9, 120170},
	{"JOHNSBURY", 9, 120171},
	{"MOLESTER", 8, 120172},
	{"PAVAN", 5, 120173},
	{"OVERFISHING", 11, 120174},
	{"MARKUPS", 7, 120175},
	{"PINGBACKS", 9, 120176},
	{"LOADMODULE", 10, 120177},
	{"FUTUREHEADS", 11, 120178},
	{"HYPNOTISM", 9, 120179},
	{"WTRY", 4, 120180},
	{"LAXT", 4, 120181},
	{"IKIW", 4, 120182},
	{"HULZ", 4, 120183},
	{"GDIC", 4, 120184},
	{"EVEV", 4, 120185},
	{"DCAK", 4, 120186},
	{"CYFA", 4, 120187},
	{"INDUSTRIALISATION", 17, 120188},
	{"BRYON", 5, 120189},
	{"APPX", 4, 120190},
	{"SERENO", 6, 120191},
	{"SCHNITZER", 9, 120192},
	{"CYTOSINE", 8, 120193},
	{"DISSOCIATED", 11, 120194},
	{"JANEY", 5, 120195},
	{"WATCHIN", 7, 120196},
	{"EXCLAIMS", 8, 120197},
	{"ARGENTINAS", 10, 120198},
	{"PATTIE", 6, 120199},
	{"STORIE", 6, 120200},
	{"MAPES", 5, 120201},
	{"GRAMPS", 6, 120202},
	{"SHIMMY", 6, 120203},
	{"CEASELESS", 9, 120204},
	{"SUBRAMANIAN", 11, 120205},
	{"RECONNECTED", 11, 120206},
	{"EMBLEMATIC", 10, 120207},
	{"MICROSPHERES", 12, 120208},
	{"YSTP", 4, 120209},
	{"XASG", 4, 120210},
	{"WMAJ", 4, 120211},
	{"OUGM", 4, 120212},
	{"OPYP", 4, 120213},
	{"NGWU", 4, 120214},
	{"NCOX", 4, 120215},
	{"IZWA", 4, 120216},
	{"ALYD", 4, 120217},
	{"LERWICK", 7, 120218},
	{"IDRIS", 5, 120219},
	{"RADIUSD", 7, 120220},
	{"MOSEL", 5, 120221},
	{"USDOT", 5, 120222},
	{"CARBOXY", 7, 120223},
	{"STECK", 5, 120224},
	{"THURINGIENSIS", 13, 120225},
	{"FERTILIZE", 9, 120226},
	{"CHALLIS", 7, 120227},
	{"SOOKE", 5, 120228},
	{"RAWS", 4, 120229},
	{"COUGHLAN", 8, 120230},
	{"BESLAN", 6, 120231},
	{"DISENGAGE", 9, 120232},
	{"CLIENTES", 8, 120233},
	{"LDF", 3, 120234},
	{"PASSCODE", 8, 120235},
	{"TRANSPOSON", 10, 120236},
	{"SEEPS", 5, 120237},
	{"ALIQUOT", 7, 120238},
	{"LIBUNGIF", 8, 120239},
	{"WEATHERIZATION", 14, 120240},
	{"SCHILDER", 8, 120241},
	{"RGLU", 4, 120242},
	{"RGDA", 4, 120243},
	{"KUIS", 4, 120244},
	{"CBUL", 4, 120245},
	{"BONR", 4, 120246},
	{"AKGO", 4, 120247},
	{"GUZZLERS", 8, 120248},
	{"MARDUK", 6, 120249},
	{"DIGITALIS", 9, 120250},
	{"COMMONEST", 9, 120251},
	{"BISSON", 6, 120252},
	{"RUEDA", 5, 120253},
	{"FESTINA", 7, 120254},
	{"OUTSELL", 7, 120255},
	{"ADORA", 5, 120256},
	{"NETSUITE", 8, 120257},
	{"REGAINS", 7, 120258},
	{"MABSADD", 7, 120259},
	{"BARRICK", 7, 120260},
	{"UNRESERVED", 10, 120261},
	{"MONOTONICALLY", 13, 120262},
	{"COUNTERATTACK", 13, 120263},
	{"CONOSCO", 7, 120264},
	{"PROCESO", 7, 120265},
	{"UDMA", 4, 120266},
	{"XLIK", 4, 120267},
	{"TWIP", 4, 120268},
	{"SPMT", 4, 120269},
	{"SMDO", 4, 120270},
	{"JERA", 4, 120271},
	{"HUPF", 4, 120272},
	{"BTBU", 4, 120273},
	{"BMR", 3, 120274},
	{"BALDILOCKS", 10, 120275},
	{"ELECTROCARDIOGRAM", 17, 120276},
	{"AZIMUTHAL", 9, 120277},
	{"SLIMS", 5, 120278},
	{"LESSENS", 7, 120279},
	{"PEARSALL", 8, 120280},
	{"BELLAS", 6, 120281},
	{"MOVIEGOODS", 10, 120282},
	{"JUDICIALLY", 10, 120283},
	{"CHULALONGKORN", 13, 120284},
	{"MCCOMBS", 7, 120285},
	{"VEND", 4, 120286},
	{"COBBLERS", 8, 120287},
	{"GUINOT", 6, 120288},
	{"SRWA", 4, 120289},
	{"RSPM", 4, 120290},
	{"RPOV", 4, 120291},
	{"OFPY", 4, 120292},
	{"OADK", 4, 120293},
	{"HREK", 4, 120294},
	{"DDOH", 4, 120295},
	{"WARNERS", 7, 120296},
	{"SMATTERING", 10, 120297},
	{"CLOUDINESS", 10, 120298},
	{"TAUNTS", 6, 120299},
	{"TMPDIR", 6, 120300},
	{"CHEVRONTEXACO", 13, 120301},
	{"BACKACHE", 8, 120302},
	{"THIELE", 6, 120303},
	{"GUMBY", 5, 120304},
	{"STEALTHILY", 10, 120305},
	{"LUNCHROOM", 9, 120306},
	{"DUMPTY", 6, 120307},
	{"DETALJER", 8, 120308},
	{"TOTALE", 6, 120309},
	{"MAUPIN", 6, 120310},
	{"NIEMEYER", 8, 120311},
	{"PICCARD", 7, 120312},
	{"RANEY", 5, 120313},
	{"MBOC", 4, 120314},
	{"MBHI", 4, 120315},
	{"IDOD", 4, 120316},
	{"EKAK", 4, 120317},
	{"BTOW", 4, 120318},
	{"BMOD", 4, 120319},
	{"ARCD", 4, 120320},
	{"RIPENED", 7, 120321},
	{"MOSMAN", 6, 120322},
	{"MADRONA", 7, 120323},
	{"CLEVERNESS", 10, 120324},
	{"AUTHENTICS", 10, 120325},
	{"PIPPI", 5, 120326},
	{"DBJ", 3, 120327},
	{"GEMSTAR", 7, 120328},
	{"VENTES", 6, 120329},
	{"ROPED", 5, 120330},
	{"WORF", 4, 120331},
	{"ECRI", 4, 120332},
	{"SORCERERS", 9, 120333},
	{"CLANG", 5, 120334},
	{"LELA", 4, 120335},
	{"ADAPTION", 8, 120336},
	{"GDAL", 4, 120337},
	{"ECKSTEIN", 8, 120338},
	{"PALATKA", 7, 120339},
	{"YNBA", 4, 120340},
	{"YANJ", 4, 120341},
	{"KTAX", 4, 120342},
	{"ERDN", 4, 120343},
	{"ENGK", 4, 120344},
	{"CLINICA", 7, 120345},
	{"NEPHRITIS", 9, 120346},
	{"PIVOTS", 6, 120347},
	{"POKERROOM", 9, 120348},
	{"WHATTHEFONT", 11, 120349},
	{"UNIVERSITAET", 12, 120350},
	{"SHELIA", 6, 120351},
	{"KITTERY", 7, 120352},
	{"BANDSAW", 7, 120353},
	{"MELENDEZ", 8, 120354},
	{"TOENAIL", 7, 120355},
	{"MEENA", 5, 120356},
	{"ANJALI", 6, 120357},
	{"POULSBO", 7, 120358},
	{"SUBTOPIC", 8, 120359},
	{"AUBIN", 5, 120360},
	{"DOMICILIARY", 11, 120361},
	{"TRANSFERING", 11, 120362},
	{"IMMUNOGEN", 9, 120363},
	{"SARDINIAN", 9, 120364},
	{"SELECTMAN", 9, 120365},
	{"AUTOMOBILI", 10, 120366},
	{"GLOWED", 6, 120367},
	{"COMPRO", 6, 120368},
	{"OYAP", 4, 120369},
	{"OUNB", 4, 120370},
	{"NCYJ", 4, 120371},
	{"LEKH", 4, 120372},
	{"HDUT", 4, 120373},
	{"VENABLES", 8, 120374},
	{"KERSTIN", 7, 120375},
	{"FIESTAWARE", 10, 120376},
	{"FOOTSMART", 9, 120377},
	{"WALTZES", 7, 120378},
	{"UNDIRECTED", 10, 120379},
	{"CISC", 4, 120380},
	{"STATON", 6, 120381},
	{"SUNLIT", 6, 120382},
	{"KABC", 4, 120383},
	{"REDISCOVERY", 11, 120384},
	{"GOLDA", 5, 120385},
	{"ATTESTS", 7, 120386},
	{"PARCHED", 7, 120387},
	{"PEACEABLE", 9, 120388},
	{"REFACING", 8, 120389},
	{"SPORTAL", 7, 120390},
	{"UDYN", 4, 120391},
	{"REUX", 4, 120392},
	{"OUCU", 4, 120393},
	{"KREB", 4, 120394},
	{"GDPI", 4, 120395},
	{"ELFV", 4, 120396},
	{"BAMO", 4, 120397},
	{"AMMS", 4, 120398},
	{"ACHTUNG", 7, 120399},
	{"OVERDRAFTS", 10, 120400},
	{"SHAREAZA", 8, 120401},
	{"MONODEVELOP", 11, 120402},
	{"HIGHAM", 6, 120403},
	{"HEDGEHOGS", 9, 120404},
	{"STANZAS", 7, 120405},
	{"RIGGER", 6, 120406},
	{"POSTTRAUMATIC", 13, 120407},
	{"BROADBANDREPORTS", 16, 120408},
	{"RESNET", 6, 120409},
	{"OLANZAPINE", 10, 120410},
	{"BAGGINS", 7, 120411},
	{"DOWNLOD", 7, 120412},
	{"WORRALL", 7, 120413},
	{"QUEBECOIS", 9, 120414},
	{"HENMAN", 6, 120415},
	{"PHYSICO", 7, 120416},
	{"ANOPHELES", 9, 120417},
	{"ZXP", 3, 120418},
	{"ZUQ", 3, 120419},
	{"YWZ", 3, 120420},
	{"VZR", 3, 120421},
	{"UQQ", 3, 120422},
	{"PZY", 3, 120423},
	{"MZK", 3, 120424},
	{"JWU", 3, 120425},
	{"FBQ", 3, 120426},
	{"YWEF", 4, 120427},
	{"WATU", 4, 120428},
	{"RARK", 4, 120429},
	{"OUAW", 4, 120430},
	{"OSGU", 4, 120431},
	{"JORK", 4, 120432},
	{"EJIG", 4, 120433},
	{"DIGT", 4, 120434},
	{"DCBC", 4, 120435},
	{"TONSILS", 7, 120436},
	{"INFURIATED", 10, 120437},
	{"DJINN", 5, 120438},
	{"HERSEY", 6, 120439},
	{"TOTNES", 6, 120440},
	{"SYLMAR", 6, 120441},
	{"KURSY", 5, 120442},
	{"MSFC", 4, 120443},
	{"LINKEXCHANGE", 12, 120444},
	{"XCOPY", 5, 120445},
	{"BASETOPIC", 9, 120446},
	{"TUBMAN", 6, 120447},
	{"FUK", 3, 120448},
	{"GAGGLE", 6, 120449},
	{"COBLE", 5, 120450},
	{"DISMOUNTED", 10, 120451},
	{"ORGIA", 5, 120452},
	{"JEANNA", 6, 120453},
	{"YSPM", 4, 120454},
	{"UOYE", 4, 120455},
	{"RGIB", 4, 120456},
	{"PPSF", 4, 120457},
	{"OUTZ", 4, 120458},
	{"OOPF", 4, 120459},
	{"IFWO", 4, 120460},
	{"DDEX", 4, 120461},
	{"BIEM", 4, 120462},
	{"ACKQ", 4, 120463},
	{"CRESTLINE", 9, 120464},
	{"BREESE", 6, 120465},
	{"ANESTHESIOLOGIST", 16, 120466},
	{"TOUNGE", 6, 120467},
	{"IDIOMAS", 7, 120468},
	{"SARIS", 5, 120469},
	{"FLUCTUATED", 10, 120470},
	{"DORMANCY", 8, 120471},
	{"EXACERBATION", 12, 120472},
	{"CLANNAD", 7, 120473},
	{"HEREDIA", 7, 120474},
	{"FOOTYMAD", 8, 120475},
	{"GRIFFINS", 8, 120476},
	{"INCONGRUOUS", 11, 120477},
	{"QUIJOTE", 7, 120478},
	{"CASELOADS", 9, 120479},
	{"CHICONY", 7, 120480},
	{"KINDEST", 7, 120481},
	{"VETV", 4, 120482},
	{"TYEQ", 4, 120483},
	{"TUKA", 4, 120484},
	{"ROPG", 4, 120485},
	{"ROEB", 4, 120486},
	{"NRUP", 4, 120487},
	{"MYRN", 4, 120488},
	{"MTUB", 4, 120489},
	{"LKSM", 4, 120490},
	{"ILKM", 4, 120491},
	{"HJOR", 4, 120492},
	{"EZAG", 4, 120493},
	{"EWWR", 4, 120494},
	{"DUHA", 4, 120495},
	{"PRECONSTRUCTION", 15, 120496},
	{"RHEINGOLD", 9, 120497},
	{"COSPONSORED", 11, 120498},
	{"HVAL", 4, 120499},
	{"COUPLAND", 8, 120500},
	{"INTERVENES", 10, 120501},
	{"HANGINGCOM", 10, 120502},
	{"YULETIDE", 8, 120503},
	{"GOUTAL", 6, 120504},
	{"PIPEWORK", 8, 120505},
	{"RDU", 3, 120506},
	{"CORINA", 6, 120507},
	{"ENTWISTLE", 9, 120508},
	{"MALINDA", 7, 120509},
	{"CYBERSKIN", 9, 120510},
	{"LAKIN", 5, 120511},
	{"TERRORIZED", 10, 120512},
	{"THERMOCOUPLES", 13, 120513},
	{"DAIGLE", 6, 120514},
	{"TERMCAP", 7, 120515},
	{"REVA", 4, 120516},
	{"URAJ", 4, 120517},
	{"UCYS", 4, 120518},
	{"OXDE", 4, 120519},
	{"MELN", 4, 120520},
	{"HOLF", 4, 120521},
	{"EIDM", 4, 120522},
	{"OREILLY", 7, 120523},
	{"TABACO", 6, 120524},
	{"REPHRASE", 8, 120525},
	{"MONOCULARS", 10, 120526},
	{"MICROVISION", 11, 120527},
	{"SISTAS", 6, 120528},
	{"VIELES", 6, 120529},
	{"STRAHAN", 7, 120530},
	{"BONNETS", 7, 120531},
	{"PANELED", 7, 120532},
	{"JUNGIAN", 7, 120533},
	{"LUKOIL", 6, 120534},
	{"SOUNDSCAPE", 10, 120535},
	{"BARED", 5, 120536},
	{"RABE", 4, 120537},
	{"SCIATIC", 7, 120538},
	{"BAPE", 4, 120539},
	{"FRENCHMEN", 9, 120540},
	{"MULTIPHASE", 10, 120541},
	{"RUSCH", 5, 120542},
	{"SILKWORM", 8, 120543},
	{"PANAMAX", 7, 120544},
	{"YCEE", 4, 120545},
	{"TBUG", 4, 120546},
	{"MPWE", 4, 120547},
	{"MFIX", 4, 120548},
	{"KOPA", 4, 120549},
	{"JEEV", 4, 120550},
	{"APUZ", 4, 120551},
	{"FLAVORINGS", 10, 120552},
	{"JAWAHARLAL", 10, 120553},
	{"KENMARE", 7, 120554},
	{"OSDL", 4, 120555},
	{"MILITANCY", 9, 120556},
	{"SUBANG", 6, 120557},
	{"SURI", 4, 120558},
	{"KISWAHILI", 9, 120559},
	{"CATHODIC", 8, 120560},
	{"COMORBIDITY", 11, 120561},
	{"SHEATHS", 7, 120562},
	{"FIETS", 5, 120563},
	{"KORUNI", 6, 120564},
	{"IBMS", 4, 120565},
	{"PALMISTRY", 9, 120566},
	{"ADDITONAL", 9, 120567},
	{"CALLOW", 6, 120568},
	{"SMEAD", 5, 120569},
	{"CONTD", 5, 120570},
	{"CHLOROQUINE", 11, 120571},
	{"MERIBEL", 7, 120572},
	{"USCY", 4, 120573},
	{"SEYJ", 4, 120574},
	{"OXPL", 4, 120575},
	{"OMIU", 4, 120576},
	{"GSVE", 4, 120577},
	{"GIED", 4, 120578},
	{"EUML", 4, 120579},
	{"ERIJ", 4, 120580},
	{"ENGB", 4, 120581},
	{"DUTH", 4, 120582},
	{"BBEF", 4, 120583},
	{"UNDERFLOOR", 10, 120584},
	{"MUTH", 4, 120585},
	{"EDICTS", 6, 120586},
	{"LEMUEL", 6, 120587},
	{"CHARLEVILLE", 11, 120588},
	{"DEMOLITIONS", 11, 120589},
	{"ROBINSONS", 9, 120590},
	{"DARLEY", 6, 120591},
	{"JUGULAR", 7, 120592},
	{"LCDPROJECTOR", 12, 120593},
	{"PIMPLE", 6, 120594},
	{"XRF", 3, 120595},
	{"DISTDIR", 7, 120596},
	{"PICKETING", 9, 120597},
	{"AEGEE", 5, 120598},
	{"TRAYNOR", 7, 120599},
	{"HUMUS", 5, 120600},
	{"INATTENTIVE", 11, 120601},
	{"PKM", 3, 120602},
	{"PRECESSION", 10, 120603},
	{"GOTEBORG", 8, 120604},
	{"TRANSMUTATION", 13, 120605},
	{"PLASTIMO", 8, 120606},
	{"PROSCIUTTO", 10, 120607},
	{"SCRA", 4, 120608},
	{"AKINS", 5, 120609},
	{"YPMT", 4, 120610},
	{"RYAK", 4, 120611},
	{"PNOM", 4, 120612},
	{"OWYA", 4, 120613},
	{"KSUG", 4, 120614},
	{"EUKH", 4, 120615},
	{"DTVA", 4, 120616},
	{"BISU", 4, 120617},
	{"EVAPORATES", 10, 120618},
	{"SECTIONING", 10, 120619},
	{"CRESSIDA", 8, 120620},
	{"BEMUSED", 7, 120621},
	{"UNINFECTED", 10, 120622},
	{"ALLOGRAFT", 9, 120623},
	{"OFFEREDTYPES", 12, 120624},
	{"HACKSAW", 7, 120625},
	{"INTEREXCHANGE", 13, 120626},
	{"COONHOUND", 9, 120627},
	{"VARLEY", 6, 120628},
	{"UNEXPENDED", 10, 120629},
	{"BASHED", 6, 120630},
	{"RSPCA", 5, 120631},
	{"SWEETEN", 7, 120632},
	{"CONFIDE", 7, 120633},
	{"VOICELESS", 9, 120634},
	{"UNCLUTTERED", 11, 120635},
	{"HARUM", 5, 120636},
	{"SOMBRERO", 8, 120637},
	{"INTERROGATOR", 12, 120638},
	{"HAJIME", 6, 120639},
	{"ROADSHOWS", 9, 120640},
	{"MACAQUE", 7, 120641},
	{"ZEVE", 4, 120642},
	{"VELJ", 4, 120643},
	{"UMPD", 4, 120644},
	{"SMSM", 4, 120645},
	{"RYUA", 4, 120646},
	{"EXSL", 4, 120647},
	{"CIAG", 4, 120648},
	{"ISIDORE", 7, 120649},
	{"HEADDRESS", 9, 120650},
	{"WEFAN", 5, 120651},
	{"ABUT", 4, 120652},
	{"NUESTROS", 8, 120653},
	{"TANNIN", 6, 120654},
	{"BATSON", 6, 120655},
	{"NALLY", 5, 120656},
	{"PALATINO", 8, 120657},
	{"MOTORCYCLIST", 12, 120658},
	{"LAUDS", 5, 120659},
	{"TORNADOS", 8, 120660},
	{"PALMERS", 7, 120661},
	{"OPTIK", 5, 120662},
	{"TAHIR", 5, 120663},
	{"YLUT", 4, 120664},
	{"WNHU", 4, 120665},
	{"RPWA", 4, 120666},
	{"OORQ", 4, 120667},
	{"LPIA", 4, 120668},
	{"HYCL", 4, 120669},
	{"HIRP", 4, 120670},
	{"GOVD", 4, 120671},
	{"EVEU", 4, 120672},
	{"DYVA", 4, 120673},
	{"DNUN", 4, 120674},
	{"LIMITE", 6, 120675},
	{"OUTCALL", 7, 120676},
	{"VIEWGREATER", 11, 120677},
	{"FOOTBOARD", 9, 120678},
	{"ASSCHER", 7, 120679},
	{"BIDEFORD", 8, 120680},
	{"CHILIES", 7, 120681},
	{"BOUGHS", 6, 120682},
	{"SPENDER", 7, 120683},
	{"FAMILIARISE", 11, 120684},
	{"GREATSCHOOLS", 12, 120685},
	{"KAGE", 4, 120686},
	{"EDUCATIONS", 10, 120687},
	{"YREK", 4, 120688},
	{"USUG", 4, 120689},
	{"UGBU", 4, 120690},
	{"RKPH", 4, 120691},
	{"OKCR", 4, 120692},
	{"OFCP", 4, 120693},
	{"HFUT", 4, 120694},
	{"ESLL", 4, 120695},
	{"DIDK", 4, 120696},
	{"MADCATZ", 7, 120697},
	{"KENALOG", 7, 120698},
	{"KLIN", 4, 120699},
	{"FREEROLLS", 9, 120700},
	{"WORL", 4, 120701},
	{"ANASTOMOSIS", 11, 120702},
	{"NATUREL", 7, 120703},
	{"WEINGARTEN", 10, 120704},
	{"LAOGHAIRE", 9, 120705},
	{"GINNIE", 6, 120706},
	{"TYRD", 4, 120707},
	{"OKUA", 4, 120708},
	{"OKPI", 4, 120709},
	{"MPCH", 4, 120710},
	{"LRUM", 4, 120711},
	{"LPCL", 4, 120712},
	{"KYBL", 4, 120713},
	{"FKMA", 4, 120714},
	{"AKOL", 4, 120715},
	{"DERMIS", 6, 120716},
	{"WEBADMIN", 8, 120717},
	{"OVERSEERS", 9, 120718},
	{"HUNTLY", 6, 120719},
	{"COWIE", 5, 120720},
	{"INSUREDS", 8, 120721},
	{"PRESENTMENT", 11, 120722},
	{"HIERARCHICALLY", 14, 120723},
	{"SPRIGS", 6, 120724},
	{"MARIOTT", 7, 120725},
	{"AMIENS", 6, 120726},
	{"ANIMES", 6, 120727},
	{"SUZETTE", 7, 120728},
	{"BUC", 3, 120729},
	{"IMPOSTER", 8, 120730},
	{"DROPSHIPPING", 12, 120731},
	{"CINCOM", 6, 120732},
	{"AUTHORITARIANISM", 16, 120733},
	{"DEGUSSA", 7, 120734},
	{"MATHWORLD", 9, 120735},
	{"SUMMONER", 8, 120736},
	{"DBNAME", 6, 120737},
	{"DIEZ", 4, 120738},
	{"TPMB", 4, 120739},
	{"RBCO", 4, 120740},
	{"OLJA", 4, 120741},
	{"KAOF", 4, 120742},
	{"IYAL", 4, 120743},
	{"IRGL", 4, 120744},
	{"IPFA", 4, 120745},
	{"FSFI", 4, 120746},
	{"ELUB", 4, 120747},
	{"ABDR", 4, 120748},
	{"COVERALL", 8, 120749},
	{"JAFFREY", 7, 120750},
	{"EDUCATIONCOLLEGE", 16, 120751},
	{"CONTRAVENES", 11, 120752},
	{"SHOWALTER", 9, 120753},
	{"PRINTRONIX", 10, 120754},
	{"NOOKIE", 6, 120755},
	{"BARROSO", 7, 120756},
	{"ACAPELLA", 8, 120757},
	{"DVLA", 4, 120758},
	{"RESULTADO", 9, 120759},
	{"DIMENSIONING", 12, 120760},
	{"PETERSFIELD", 11, 120761},
	{"WEYBURN", 7, 120762},
	{"PERFUMERY", 9, 120763},
	{"FARMLANDS", 9, 120764},
	{"WINFX", 5, 120765},
	{"WODEN", 5, 120766},
	{"CTION", 5, 120767},
	{"SNOWSPORTS", 10, 120768},
	{"KIPER", 5, 120769},
	{"WINDCHIMES", 10, 120770},
	{"NEUKEN", 6, 120771},
	{"DELEUZE", 7, 120772},
	{"YRUT", 4, 120773},
	{"UXBU", 4, 120774},
	{"RPHR", 4, 120775},
	{"PASB", 4, 120776},
	{"LRIF", 4, 120777},
	{"IELU", 4, 120778},
	{"HIRK", 4, 120779},
	{"GSBL", 4, 120780},
	{"FPIG", 4, 120781},
	{"EGDP", 4, 120782},
	{"AUXS", 4, 120783},
	{"EGIFTS", 6, 120784},
	{"NOSTRAND", 8, 120785},
	{"TOLLFREE", 8, 120786},
	{"HABANERO", 8, 120787},
	{"PRUDENTLY", 9, 120788},
	{"BENETEAU", 8, 120789},
	{"HYPERDATA", 9, 120790},
	{"ECOSOC", 6, 120791},
	{"FORESEES", 8, 120792},
	{"DICCIONARIO", 11, 120793},
	{"PHED", 4, 120794},
	{"PARATROOPERS", 12, 120795},
	{"LUFF", 4, 120796},
	{"STYMIE", 6, 120797},
	{"REFWORKS", 8, 120798},
	{"HILARIOUSLY", 11, 120799},
	{"VIRAGO", 6, 120800},
	{"CATTARAUGUS", 11, 120801},
	{"CHICORY", 7, 120802},
	{"ANTIETAM", 8, 120803},
	{"UMOUNT", 6, 120804},
	{"VARNAME", 7, 120805},
	{"SUBSOIL", 7, 120806},
	{"SEYBOLD", 7, 120807},
	{"PRIVE", 5, 120808},
	{"DENEN", 5, 120809},
	{"AUTOMORPHISM", 12, 120810},
	{"ZDUR", 4, 120811},
	{"WMCC", 4, 120812},
	{"UFFD", 4, 120813},
	{"NLUM", 4, 120814},
	{"MRSG", 4, 120815},
	{"LYSG", 4, 120816},
	{"IFJA", 4, 120817},
	{"HCEM", 4, 120818},
	{"GOSB", 4, 120819},
	{"GBLE", 4, 120820},
	{"DECRYPTER", 9, 120821},
	{"PESCARA", 7, 120822},
	{"THRESH", 6, 120823},
	{"PATRONIZING", 11, 120824},
	{"STARDOCK", 8, 120825},
	{"FEBRUARI", 8, 120826},
	{"TORTURA", 7, 120827},
	{"EDELSTEIN", 9, 120828},
	{"PRESENTABLE", 11, 120829},
	{"MONNIER", 7, 120830},
	{"NCUA", 4, 120831},
	{"DARPHIN", 7, 120832},
	{"XMLJ", 4, 120833},
	{"LADIN", 5, 120834},
	{"ABERDARE", 8, 120835},
	{"CHABLIS", 7, 120836},
	{"POPMATTERS", 10, 120837},
	{"PAJERO", 6, 120838},
	{"UNIFIES", 7, 120839},
	{"PALES", 5, 120840},
	{"SHORTENS", 8, 120841},
	{"FRUITCAKE", 9, 120842},
	{"RPEG", 4, 120843},
	{"MOYN", 4, 120844},
	{"KGOR", 4, 120845},
	{"IOLU", 4, 120846},
	{"IFMC", 4, 120847},
	{"HILK", 4, 120848},
	{"GGWH", 4, 120849},
	{"SNOOTY", 6, 120850},
	{"MALASPINA", 9, 120851},
	{"ELITISM", 7, 120852},
	{"MCGUINTY", 8, 120853},
	{"SULTANATE", 9, 120854},
	{"FOETAL", 6, 120855},
	{"FAIRLEIGH", 9, 120856},
	{"HELICON", 7, 120857},
	{"METACITY", 8, 120858},
	{"ADORNMENT", 9, 120859},
	{"BEGG", 4, 120860},
	{"SALESLOGIX", 10, 120861},
	{"PREMATURITY", 11, 120862},
	{"HORIE", 5, 120863},
	{"PRECIPITATING", 13, 120864},
	{"HEPATOCYTE", 10, 120865},
	{"SERTA", 5, 120866},
	{"ENTOMOLOGIST", 12, 120867},
	{"CARWASH", 7, 120868},
	{"HEARKEN", 7, 120869},
	{"CARPATHIAN", 10, 120870},
	{"BLAIN", 5, 120871},
	{"COLLEGIUM", 9, 120872},
	{"TACHYON", 7, 120873},
	{"XFIR", 4, 120874},
	{"WDAV", 4, 120875},
	{"UPSG", 4, 120876},
	{"TYSQ", 4, 120877},
	{"SGDP", 4, 120878},
	{"OXYA", 4, 120879},
	{"MDIC", 4, 120880},
	{"ITZV", 4, 120881},
	{"GVEG", 4, 120882},
	{"CYTA", 4, 120883},
	{"AJIV", 4, 120884},
	{"LEVANTE", 7, 120885},
	{"SUNOCO", 6, 120886},
	{"CMHC", 4, 120887},
	{"COOKSTOWN", 9, 120888},
	{"JESSOPS", 7, 120889},
	{"PINOLE", 6, 120890},
	{"INSOLENCE", 9, 120891},
	{"WESSEL", 6, 120892},
	{"FELTS", 5, 120893},
	{"BLOCKHEAD", 9, 120894},
	{"BRALESS", 7, 120895},
	{"INOCULUM", 8, 120896},
	{"DISNEYS", 7, 120897},
	{"JPOP", 4, 120898},
	{"KISTLER", 7, 120899},
	{"HYPERWAVE", 9, 120900},
	{"AMBAZONIA", 9, 120901},
	{"EINIGE", 6, 120902},
	{"XGOA", 4, 120903},
	{"UKMA", 4, 120904},
	{"TAMD", 4, 120905},
	{"OYPO", 4, 120906},
	{"LAGD", 4, 120907},
	{"JOYD", 4, 120908},
	{"JONK", 4, 120909},
	{"ENGM", 4, 120910},
	{"BOBP", 4, 120911},
	{"BERQ", 4, 120912},
	{"PATTING", 7, 120913},
	{"GEISLER", 7, 120914},
	{"MOCS", 4, 120915},
	{"TIMMS", 5, 120916},
	{"IRRITANTS", 9, 120917},
	{"DATEI", 5, 120918},
	{"GANTZ", 5, 120919},
	{"SHEETMUSIC", 10, 120920},
	{"TYKES", 5, 120921},
	{"HIPPOCRATES", 11, 120922},
	{"DAYNA", 5, 120923},
	{"ANEMOMETER", 10, 120924},
	{"CONGAS", 6, 120925},
	{"BARHAM", 6, 120926},
	{"THEOSOPHICAL", 12, 120927},
	{"TRANSVERSAL", 11, 120928},
	{"ELABORATELY", 11, 120929},
	{"IFACE", 5, 120930},
	{"TRACKSIDE", 9, 120931},
	{"LUNDI", 5, 120932},
	{"CARLSEN", 7, 120933},
	{"GASLIGHT", 8, 120934},
	{"NIOBIUM", 7, 120935},
	{"UBD", 3, 120936},
	{"PRESIDES", 8, 120937},
	{"DDU", 3, 120938},
	{"XTTR", 4, 120939},
	{"XSTU", 4, 120940},
	{"WBYP", 4, 120941},
	{"UNSG", 4, 120942},
	{"SPYA", 4, 120943},
	{"RMNA", 4, 120944},
	{"NPHR", 4, 120945},
	{"HOML", 4, 120946},
	{"GIWI", 4, 120947},
	{"DVII", 4, 120948},
	{"HOEKSTRA", 8, 120949},
	{"CIRCLEVILLE", 11, 120950},
	{"DIVESTED", 8, 120951},
	{"PTHREADS", 8, 120952},
	{"NETDJ", 5, 120953},
	{"HANDICAPPERS", 12, 120954},
	{"TSUBASA", 7, 120955},
	{"LIGGETT", 7, 120956},
	{"OBERMEYER", 9, 120957},
	{"EAUX", 4, 120958},
	{"TRANSVAAL", 9, 120959},
	{"SOLUS", 5, 120960},
	{"STORMPAY", 8, 120961},
	{"ALPHAVILLE", 10, 120962},
	{"GAFF", 4, 120963},
	{"NPTL", 4, 120964},
	{"CSOUND", 6, 120965},
	{"BASEWEB", 7, 120966},
	{"YSTJ", 4, 120967},
	{"VYWH", 4, 120968},
	{"RBSH", 4, 120969},
	{"MPSY", 4, 120970},
	{"LPOV", 4, 120971},
	{"LAAF", 4, 120972},
	{"KISV", 4, 120973},
	{"FWAV", 4, 120974},
	{"AKFI", 4, 120975},
	{"GEARHEAD", 8, 120976},
	{"EINTRAG", 7, 120977},
	{"XACTI", 5, 120978},
	{"DISINTEGRATING", 14, 120979},
	{"FOLIE", 5, 120980},
	{"MOMENTUS", 8, 120981},
	{"TRAUMAS", 7, 120982},
	{"THEISMANN", 9, 120983},
	{"FERMAT", 6, 120984},
	{"HARDEMAN", 8, 120985},
	{"METABO", 6, 120986},
	{"GREENUP", 7, 120987},
	{"FROCK", 5, 120988},
	{"RETROVIRUS", 10, 120989},
	{"VICTORIAS", 9, 120990},
	{"BLEUE", 5, 120991},
	{"ABERGAVENNY", 11, 120992},
	{"UOTP", 4, 120993},
	{"UCTG", 4, 120994},
	{"RLFO", 4, 120995},
	{"RGFR", 4, 120996},
	{"ORGP", 4, 120997},
	{"FTVE", 4, 120998},
	{"EDGH", 4, 120999},
	{"AMKO", 4, 121000},
	{"RAGSDALE", 8, 121001},
	{"KABOOM", 6, 121002},
	{"DISSEMINATES", 12, 121003},
	{"CADILAC", 7, 121004},
	{"KUFF", 4, 121005},
	{"WATERMELONS", 11, 121006},
	{"LEMONT", 6, 121007},
	{"FLAMBEAU", 8, 121008},
	{"BRYLANE", 7, 121009},
	{"BIRO", 4, 121010},
	{"CONTROLE", 8, 121011},
	{"ADVAN", 5, 121012},
	{"DOILIES", 7, 121013},
	{"ROBBIN", 6, 121014},
	{"GODALMING", 9, 121015},
	{"DUSTERS", 7, 121016},
	{"RAILBIRDS", 9, 121017},
	{"SILICONES", 9, 121018},
	{"PSYCHED", 7, 121019},
	{"FLATMATES", 9, 121020},
	{"BLANCPAIN", 9, 121021},
	{"STARSTRUCK", 10, 121022},
	{"FUMING", 6, 121023},
	{"EXCELLANT", 9, 121024},
	{"FISHKILL", 8, 121025},
	{"TANGENTS", 8, 121026},
	{"VEEL", 4, 121027},
	{"COPPIN", 6, 121028},
	{"NAKAGAWA", 8, 121029},
	{"LAWLEY", 6, 121030},
	{"CHATTEL", 7, 121031},
	{"CHANNELLED", 10, 121032},
	{"WREST", 5, 121033},
	{"WISHART", 7, 121034},
	{"SCHECTER", 8, 121035},
	{"FORGIVES", 8, 121036},
	{"YHIK", 4, 121037},
	{"XTWH", 4, 121038},
	{"SKIY", 4, 121039},
	{"GYAG", 4, 121040},
	{"GODY", 4, 121041},
	{"DIEK", 4, 121042},
	{"CYEN", 4, 121043},
	{"AWNG", 4, 121044},
	{"WATERLESS", 9, 121045},
	{"MAINSTEM", 8, 121046},
	{"GNOSIS", 6, 121047},
	{"POWWOW", 6, 121048},
	{"KILAUEA", 7, 121049},
	{"RUNIC", 5, 121050},
	{"SKEWNESS", 8, 121051},
	{"ROZEN", 5, 121052},
	{"FUNCTIONALS", 11, 121053},
	{"TRIBUNUS", 8, 121054},
	{"AUTHENTICATES", 13, 121055},
	{"BUTLERS", 7, 121056},
	{"LIBNET", 6, 121057},
	{"TRANSMISSIBLE", 13, 121058},
	{"SCHOOLTEACHER", 13, 121059},
	{"WAALS", 5, 121060},
	{"WRITELOG", 8, 121061},
	{"PERFORATIONS", 12, 121062},
	{"CSMECHER", 8, 121063},
	{"NORDICA", 7, 121064},
	{"PDFWRITE", 8, 121065},
	{"YNAL", 4, 121066},
	{"RYIV", 4, 121067},
	{"MRFO", 4, 121068},
	{"MEAY", 4, 121069},
	{"LFFE", 4, 121070},
	{"KBEE", 4, 121071},
	{"IFOF", 4, 121072},
	{"GPHE", 4, 121073},
	{"EEGL", 4, 121074},
	{"APWE", 4, 121075},
	{"CONJ", 4, 121076},
	{"BOMIS", 5, 121077},
	{"LUNSFORD", 8, 121078},
	{"KEELY", 5, 121079},
	{"FRAMER", 6, 121080},
	{"EFFECTUAL", 9, 121081},
	{"UNSTYLED", 8, 121082},
	{"POLISHERS", 9, 121083},
	{"DILUTING", 8, 121084},
	{"UNIMPROVED", 10, 121085},
	{"WOODHAVEN", 9, 121086},
	{"KATSUMI", 7, 121087},
	{"ARTERIOVENOUS", 13, 121088},
	{"AFTERBURNER", 11, 121089},
	{"LEEUW", 5, 121090},
	{"COMUNE", 6, 121091},
	{"DEAMINASE", 9, 121092},
	{"EUROVAN", 7, 121093},
	{"TEESIDE", 7, 121094},
	{"PADDLED", 7, 121095},
	{"BDF", 3, 121096},
	{"TRISOMY", 7, 121097},
	{"INKLING", 7, 121098},
	{"FLOATERS", 8, 121099},
	{"YDLI", 4, 121100},
	{"USYF", 4, 121101},
	{"UKUD", 4, 121102},
	{"TUNM", 4, 121103},
	{"PRAP", 4, 121104},
	{"OEFL", 4, 121105},
	{"OCTP", 4, 121106},
	{"NDLS", 4, 121107},
	{"MUDG", 4, 121108},
	{"KOCC", 4, 121109},
	{"HAMJ", 4, 121110},
	{"GOVR", 4, 121111},
	{"FYAH", 4, 121112},
	{"EGSB", 4, 121113},
	{"CFIS", 4, 121114},
	{"AORF", 4, 121115},
	{"TENNEY", 6, 121116},
	{"EIVIND", 6, 121117},
	{"SADAT", 5, 121118},
	{"VIGILS", 6, 121119},
	{"SCHOENEN", 8, 121120},
	{"DENTED", 6, 121121},
	{"FOOTBRIDGE", 10, 121122},
	{"CHRX", 4, 121123},
	{"GARCONS", 7, 121124},
	{"ABIES", 5, 121125},
	{"AMACOM", 6, 121126},
	{"GAUNTLETS", 9, 121127},
	{"PATRIA", 6, 121128},
	{"BLACKSMITHS", 11, 121129},
	{"VENLAFAXINE", 11, 121130},
	{"HOLLANDSE", 9, 121131},
	{"OREGONIANS", 10, 121132},
	{"LEROUX", 6, 121133},
	{"FEDBIZOPPS", 10, 121134},
	{"PEARLMAN", 8, 121135},
	{"HARDCODED", 9, 121136},
	{"GREENSLEEVES", 12, 121137},
	{"SUGG", 4, 121138},
	{"GRANDADDY", 9, 121139},
	{"THMG", 4, 121140},
	{"LYCY", 4, 121141},
	{"IGCL", 4, 121142},
	{"MENOR", 5, 121143},
	{"BIRLA", 5, 121144},
	{"REVINFO", 7, 121145},
	{"KUSH", 4, 121146},
	{"ORWELLIAN", 9, 121147},
	{"MENDELSOHN", 10, 121148},
	{"SYSCONFIG", 9, 121149},
	{"PLOUGHING", 9, 121150},
	{"NICOLET", 7, 121151},
	{"STRUMMER", 8, 121152},
	{"MICHAELIS", 9, 121153},
	{"SHUTE", 5, 121154},
	{"CEEDY", 5, 121155},
	{"TIMON", 5, 121156},
	{"REVASCULARIZATION", 17, 121157},
	{"MOLA", 4, 121158},
	{"PARSIMONY", 9, 121159},
	{"DIDSBURY", 8, 121160},
	{"RAMBLAS", 7, 121161},
	{"TYPIFIED", 8, 121162},
	{"CLOTHESLINE", 11, 121163},
	{"ARBUTUS", 7, 121164},
	{"HELTER", 6, 121165},
	{"POBL", 4, 121166},
	{"RNAY", 4, 121167},
	{"KIMG", 4, 121168},
	{"KGRI", 4, 121169},
	{"IELY", 4, 121170},
	{"CIED", 4, 121171},
	{"ANMM", 4, 121172},
	{"ADDH", 4, 121173},
	{"MINISYNC", 8, 121174},
	{"PARDEE", 6, 121175},
	{"POLYHEDRA", 9, 121176},
	{"CONGRESO", 8, 121177},
	{"SIMBAD", 6, 121178},
	{"HOCHSCHULE", 10, 121179},
	{"DARTING", 7, 121180},
	{"RAUNCH", 6, 121181},
	{"RXVT", 4, 121182},
	{"COPES", 5, 121183},
	{"TRIPPER", 7, 121184},
	{"BANUS", 5, 121185},
	{"CMDR", 4, 121186},
	{"RECTO", 5, 121187},
	{"MAXSPEAK", 8, 121188},
	{"HINDUNET", 8, 121189},
	{"PSEUDONYMS", 10, 121190},
	{"KIKUCHI", 7, 121191},
	{"TZBE", 4, 121192},
	{"RNUG", 4, 121193},
	{"KNEV", 4, 121194},
	{"IZMA", 4, 121195},
	{"LAVOIE", 6, 121196},
	{"HARWELL", 7, 121197},
	{"FABRY", 5, 121198},
	{"BALAJI", 6, 121199},
	{"MPU", 3, 121200},
	{"CHUG", 4, 121201},
	{"ANTISPY", 7, 121202},
	{"PETERHEAD", 9, 121203},
	{"OVERSHOOT", 9, 121204},
	{"SINGTEL", 7, 121205},
	{"ANKYLOSING", 10, 121206},
	{"BLUNTED", 7, 121207},
	{"POEPLE", 6, 121208},
	{"RBK", 3, 121209},
	{"ALLAIRE", 7, 121210},
	{"PUSHERS", 7, 121211},
	{"MURPH", 5, 121212},
	{"MADDOCK", 7, 121213},
	{"THIOL", 5, 121214},
	{"SNARL", 5, 121215},
	{"UROG", 4, 121216},
	{"TILK", 4, 121217},
	{"NFOW", 4, 121218},
	{"LPMI", 4, 121219},
	{"ESKW", 4, 121220},
	{"CEYB", 4, 121221},
	{"BUMU", 4, 121222},
	{"BOWF", 4, 121223},
	{"UNLINKED", 8, 121224},
	{"ECONOMIE", 8, 121225},
	{"COMPTOIR", 8, 121226},
	{"BURKHART", 8, 121227},
	{"CONJOINT", 8, 121228},
	{"ESTHETICS", 9, 121229},
	{"CARTOLINE", 9, 121230},
	{"SEILER", 6, 121231},
	{"SILVESTER", 9, 121232},
	{"SKEWER", 6, 121233},
	{"PAINED", 6, 121234},
	{"LIAISING", 8, 121235},
	{"RAMJET", 6, 121236},
	{"LOOKER", 6, 121237},
	{"INEXCUSABLE", 11, 121238},
	{"DENBIGH", 7, 121239},
	{"LARISA", 6, 121240},
	{"CHEYNE", 6, 121241},
	{"AXTELL", 6, 121242},
	{"LAUD", 4, 121243},
	{"LIPSCHITZ", 9, 121244},
	{"BUTS", 4, 121245},
	{"AMAZONAS", 8, 121246},
	{"MUTTERINGS", 10, 121247},
	{"ZANC", 4, 121248},
	{"OZAC", 4, 121249},
	{"MIEF", 4, 121250},
	{"LSHC", 4, 121251},
	{"IXSC", 4, 121252},
	{"IBEY", 4, 121253},
	{"GBYG", 4, 121254},
	{"DVAI", 4, 121255},
	{"CICH", 4, 121256},
	{"BHAL", 4, 121257},
	{"AYUM", 4, 121258},
	{"PROVABLE", 8, 121259},
	{"KURS", 4, 121260},
	{"DEERNS", 6, 121261},
	{"SAANICH", 7, 121262},
	{"PUBLIX", 6, 121263},
	{"TARIF", 5, 121264},
	{"CHEBI", 5, 121265},
	{"LISTVIEW", 8, 121266},
	{"JERE", 4, 121267},
	{"DOMSTRING", 9, 121268},
	{"HETEROCYCLIC", 12, 121269},
	{"GRASMERE", 8, 121270},
	{"MEZZ", 4, 121271},
	{"GENOVESE", 8, 121272},
	{"KONTO", 5, 121273},
	{"BENATAR", 7, 121274},
	{"PRECIPICE", 9, 121275},
	{"CARYL", 5, 121276},
	{"ZEWO", 4, 121277},
	{"ZEDJ", 4, 121278},
	{"TYSV", 4, 121279},
	{"OROX", 4, 121280},
	{"IPTB", 4, 121281},
	{"ILKR", 4, 121282},
	{"IKRE", 4, 121283},
	{"HEBF", 4, 121284},
	{"DHIV", 4, 121285},
	{"GESCHRIEBEN", 11, 121286},
	{"SCHULLER", 8, 121287},
	{"ROLLERBLADE", 11, 121288},
	{"PARLOPHONE", 10, 121289},
	{"RECALCITRANT", 12, 121290},
	{"THOUGHTFULNESS", 14, 121291},
	{"OUTMODED", 8, 121292},
	{"DOWNGRADING", 11, 121293},
	{"HARSHNESS", 9, 121294},
	{"HAWKEN", 6, 121295},
	{"PEDDLE", 6, 121296},
	{"YELLOWFIN", 9, 121297},
	{"GOER", 4, 121298},
	{"AILES", 5, 121299},
	{"PHANG", 5, 121300},
	{"TORRI", 5, 121301},
	{"NEUVE", 5, 121302},
	{"COHIBA", 6, 121303},
	{"ORLISTAT", 8, 121304},
	{"DISPONIBILE", 11, 121305},
	{"STOCKDISC", 9, 121306},
	{"YSIQ", 4, 121307},
	{"XPLE", 4, 121308},
	{"WENR", 4, 121309},
	{"RGDE", 4, 121310},
	{"POWH", 4, 121311},
	{"NWYO", 4, 121312},
	{"FTFE", 4, 121313},
	{"EXLA", 4, 121314},
	{"AYYI", 4, 121315},
	{"MARKDOWN", 8, 121316},
	{"FIXUP", 5, 121317},
	{"WARIO", 5, 121318},
	{"MANDELSON", 9, 121319},
	{"EVERWOOD", 8, 121320},
	{"ENTHRALLING", 11, 121321},
	{"RLOGIN", 6, 121322},
	{"LIMPING", 7, 121323},
	{"ROJECT", 6, 121324},
	{"SOUNDCARDS", 10, 121325},
	{"REFEREEING", 10, 121326},
	{"BARBEQUES", 9, 121327},
	{"NSDL", 4, 121328},
	{"DARUM", 5, 121329},
	{"RINGETONE", 9, 121330},
	{"SPYGLASS", 8, 121331},
	{"VISV", 4, 121332},
	{"UYSU", 4, 121333},
	{"KOVW", 4, 121334},
	{"GMEW", 4, 121335},
	{"FMUH", 4, 121336},
	{"BESD", 4, 121337},
	{"AZYP", 4, 121338},
	{"AWEV", 4, 121339},
	{"EMPATHIZE", 9, 121340},
	{"ACTUALY", 7, 121341},
	{"URU", 3, 121342},
	{"CONTRAT", 7, 121343},
	{"UTTERS", 6, 121344},
	{"PANNED", 6, 121345},
	{"STERILISATION", 13, 121346},
	{"PROCESSIONS", 11, 121347},
	{"METROGUIDE", 10, 121348},
	{"ROXBURGH", 8, 121349},
	{"AUTOMOTIVES", 11, 121350},
	{"FOODSTUFF", 9, 121351},
	{"STOWELL", 7, 121352},
	{"TELEPHARMACIES", 14, 121353},
	{"GLUTTONY", 8, 121354},
	{"AGRITURISMO", 11, 121355},
	{"EUROZONE", 8, 121356},
	{"KNEADING", 8, 121357},
	{"ANGIELSKIEGO", 12, 121358},
	{"XMAT", 4, 121359},
	{"UKAW", 4, 121360},
	{"RBEW", 4, 121361},
	{"MIDK", 4, 121362},
	{"HILG", 4, 121363},
	{"EKUL", 4, 121364},
	{"EBPO", 4, 121365},
	{"CUTG", 4, 121366},
	{"AIMY", 4, 121367},
	{"LUSKIN", 6, 121368},
	{"ETWAS", 5, 121369},
	{"TIRAMISU", 8, 121370},
	{"PANNA", 5, 121371},
	{"UTILISER", 8, 121372},
	{"MARKOFF", 7, 121373},
	{"OHARE", 5, 121374},
	{"CHROM", 5, 121375},
	{"PROSTATITIS", 11, 121376},
	{"GOGOL", 5, 121377},
	{"HAHAHAHAHA", 10, 121378},
	{"WPL", 3, 121379},
	{"WINDOWED", 8, 121380},
	{"KAITLIN", 7, 121381},
	{"CALABRESE", 9, 121382},
	{"COMMERCIALISM", 13, 121383},
	{"STEGER", 6, 121384},
	{"WOMENSWEAR", 10, 121385},
	{"CRUMBLES", 8, 121386},
	{"CLUBLEXUS", 9, 121387},
	{"KFORCE", 6, 121388},
	{"UNPATRIOTIC", 11, 121389},
	{"TEMPLARS", 8, 121390},
	{"MKTIME", 6, 121391},
	{"YKOS", 4, 121392},
	{"UCOR", 4, 121393},
	{"NDLT", 4, 121394},
	{"MMYK", 4, 121395},
	{"GKHA", 4, 121396},
	{"FHIV", 4, 121397},
	{"AUBI", 4, 121398},
	{"ABCH", 4, 121399},
	{"NINEVEH", 7, 121400},
	{"LEXER", 5, 121401},
	{"SCROUNGR", 8, 121402},
	{"STICKWITU", 9, 121403},
	{"CHEMUNG", 7, 121404},
	{"ABBOUD", 6, 121405},
	{"WRANGLERS", 9, 121406},
	{"PEED", 4, 121407},
	{"BANDSTAND", 9, 121408},
	{"FRAMELESS", 9, 121409},
	{"MESURES", 7, 121410},
	{"ANIONIC", 7, 121411},
	{"DEANA", 5, 121412},
	{"ASSESMENT", 9, 121413},
	{"ANHALT", 6, 121414},
	{"CPK", 3, 121415},
	{"SISSON", 6, 121416},
	{"FADERS", 6, 121417},
	{"TIMBAVATI", 9, 121418},
	{"BLACKFORD", 9, 121419},
	{"PATCHOGUE", 9, 121420},
	{"UXTH", 4, 121421},
	{"RKEF", 4, 121422},
	{"IZAW", 4, 121423},
	{"EUPJ", 4, 121424},
	{"EJEL", 4, 121425},
	{"DRPE", 4, 121426},
	{"BSAM", 4, 121427},
	{"DIGESTIBILITY", 13, 121428},
	{"ARCHAEA", 7, 121429},
	{"ENQUIRED", 8, 121430},
	{"CASCADED", 8, 121431},
	{"APHORISMS", 9, 121432},
	{"SHARKOON", 8, 121433},
	{"CMJ", 3, 121434},
	{"SPYDERCO", 8, 121435},
	{"COMPLEAT", 8, 121436},
	{"REITZ", 5, 121437},
	{"ZRK", 3, 121438},
	{"ZBP", 3, 121439},
	{"ZBF", 3, 121440},
	{"YQD", 3, 121441},
	{"YMQ", 3, 121442},
	{"XWF", 3, 121443},
	{"XPJ", 3, 121444},
	{"WXU", 3, 121445},
	{"UQC", 3, 121446},
	{"RQX", 3, 121447},
	{"RQQ", 3, 121448},
	{"GFV", 3, 121449},
	{"BQL", 3, 121450},
	{"FORAGES", 7, 121451},
	{"RIFFLE", 6, 121452},
	{"SYLLABICS", 9, 121453},
	{"ARRIVENET", 9, 121454},
	{"CHAMBERED", 9, 121455},
	{"VOLANTE", 7, 121456},
	{"CONSUMPTIVE", 11, 121457},
	{"COGAN", 5, 121458},
	{"XEVA", 4, 121459},
	{"WSIX", 4, 121460},
	{"UPGI", 4, 121461},
	{"TGUR", 4, 121462},
	{"SVAM", 4, 121463},
	{"SKSR", 4, 121464},
	{"RGHH", 4, 121465},
	{"OYWE", 4, 121466},
	{"MBSC", 4, 121467},
	{"HMOF", 4, 121468},
	{"FTUB", 4, 121469},
	{"EXVI", 4, 121470},
	{"DDIX", 4, 121471},
	{"CILN", 4, 121472},
	{"BYOS", 4, 121473},
	{"AARU", 4, 121474},
	{"MELANCHOLIC", 11, 121475},
	{"PROYECTOS", 9, 121476},
	{"MUNDELEIN", 9, 121477},
	{"DALMATIA", 8, 121478},
	{"CATHARTIC", 9, 121479},
	{"NOISILY", 7, 121480},
	{"CORTICOTROPIN", 13, 121481},
	{"HABILITATION", 12, 121482},
	{"FLUENCE", 7, 121483},
	{"SPELMAN", 7, 121484},
	{"POPJ", 4, 121485},
	{"SOQUEL", 6, 121486},
	{"READJUSTMENT", 12, 121487},
	{"DENATURATION", 12, 121488},
	{"UNACCOUNTABLE", 13, 121489},
	{"WEISE", 5, 121490},
	{"LIFEWISE", 8, 121491},
	{"UAMO", 4, 121492},
	{"TULO", 4, 121493},
	{"TAGW", 4, 121494},
	{"PUSN", 4, 121495},
	{"PMTI", 4, 121496},
	{"LJIM", 4, 121497},
	{"ISXV", 4, 121498},
	{"IKOM", 4, 121499},
	{"GNFU", 4, 121500},
	{"BTOC", 4, 121501},
	{"BOWC", 4, 121502},
	{"PUSHKA", 6, 121503},
	{"TOURISMUS", 9, 121504},
	{"TRICKLING", 9, 121505},
	{"REGISTRATI", 10, 121506},
	{"WILLIAMSTON", 11, 121507},
	{"KERATINOCYTES", 13, 121508},
	{"NOLIN", 5, 121509},
	{"AUTOANYTHING", 12, 121510},
	{"SPURLOCK", 8, 121511},
	{"COMMONER", 8, 121512},
	{"AIUTO", 5, 121513},
	{"RDD", 3, 121514},
	{"XGRO", 4, 121515},
	{"ORIY", 4, 121516},
	{"ORCB", 4, 121517},
	{"MTVA", 4, 121518},
	{"LBOB", 4, 121519},
	{"KYWO", 4, 121520},
	{"GAYN", 4, 121521},
	{"FREDRICKSON", 11, 121522},
	{"REMINISCENCE", 12, 121523},
	{"MOHANDAS", 8, 121524},
	{"MEGASITE", 8, 121525},
	{"GROTH", 5, 121526},
	{"BRACKETT", 8, 121527},
	{"OWATONNA", 8, 121528},
	{"NOTOTAL", 7, 121529},
	{"GMG", 3, 121530},
	{"BRAMA", 5, 121531},
	{"MOREIRA", 7, 121532},
	{"NUCLEASE", 8, 121533},
	{"WOODBLOCK", 9, 121534},
	{"PHOTODIODE", 10, 121535},
	{"AFLATOXIN", 9, 121536},
	{"POUVOIR", 7, 121537},
	{"YEUX", 4, 121538},
	{"DESCENDENT", 10, 121539},
	{"INVALIDATION", 12, 121540},
	{"ALTEA", 5, 121541},
	{"XLAW", 4, 121542},
	{"RRUI", 4, 121543},
	{"RBTO", 4, 121544},
	{"OLMT", 4, 121545},
	{"IALZ", 4, 121546},
	{"HYDA", 4, 121547},
	{"DMIE", 4, 121548},
	{"DKNA", 4, 121549},
	{"DBBC", 4, 121550},
	{"BILS", 4, 121551},
	{"ABAZ", 4, 121552},
	{"RECREATES", 9, 121553},
	{"BARILOCHE", 9, 121554},
	{"EJEMPLO", 7, 121555},
	{"FETISHISM", 9, 121556},
	{"MARITIMA", 8, 121557},
	{"BERGIN", 6, 121558},
	{"MERU", 4, 121559},
	{"WANED", 5, 121560},
	{"ASSENTED", 8, 121561},
	{"MOTORE", 6, 121562},
	{"PUNKY", 5, 121563},
	{"STACKHOUSE", 10, 121564},
	{"BILLINGHAM", 10, 121565},
	{"HYBRIDIZED", 10, 121566},
	{"OVERCHARGED", 11, 121567},
	{"LANDSHUT", 8, 121568},
	{"FLAGSTONE", 9, 121569},
	{"SULU", 4, 121570},
	{"GENEALOGIST", 11, 121571},
	{"READDIR", 7, 121572},
	{"MAKN", 4, 121573},
	{"IMOW", 4, 121574},
	{"FZIM", 4, 121575},
	{"CUPL", 4, 121576},
	{"AUMB", 4, 121577},
	{"PUCKER", 6, 121578},
	{"INFERENTIAL", 11, 121579},
	{"SANCTIFY", 8, 121580},
	{"METALLOPROTEINASE", 17, 121581},
	{"PRERECORDED", 11, 121582},
	{"IPADDRESS", 9, 121583},
	{"FRANSCHHOEK", 11, 121584},
	{"ESTUDIANTES", 11, 121585},
	{"PORTREF", 7, 121586},
	{"UTLEY", 5, 121587},
	{"RAZZLE", 6, 121588},
	{"MAISONETTE", 10, 121589},
	{"STUSSY", 6, 121590},
	{"MISBEHAVING", 11, 121591},
	{"WEARERS", 7, 121592},
	{"IBEW", 4, 121593},
	{"IMAGECLASS", 10, 121594},
	{"SKSU", 4, 121595},
	{"LRAH", 4, 121596},
	{"LKYW", 4, 121597},
	{"KLEL", 4, 121598},
	{"HEWD", 4, 121599},
	{"GWOL", 4, 121600},
	{"ERZY", 4, 121601},
	{"AWTR", 4, 121602},
	{"CATHARINA", 9, 121603},
	{"KEMPS", 5, 121604},
	{"MESSRS", 6, 121605},
	{"INSOLENT", 8, 121606},
	{"SOLEY", 5, 121607},
	{"AUGIE", 5, 121608},
	{"SUPREMACIST", 11, 121609},
	{"PLEXIGLASS", 10, 121610},
	{"OCTAVIO", 7, 121611},
	{"DYSTONIA", 8, 121612},
	{"MARGOLIN", 8, 121613},
	{"DISPOSITIVE", 11, 121614},
	{"MARYANNE", 8, 121615},
	{"DATALINK", 8, 121616},
	{"ORTHONORMAL", 11, 121617},
	{"CINELERRA", 9, 121618},
	{"NEUROPATHIC", 11, 121619},
	{"HOMEMAKING", 10, 121620},
	{"ETOWAH", 6, 121621},
	{"KOLMOGOROV", 10, 121622},
	{"CORRALES", 8, 121623},
	{"DBAS", 4, 121624},
	{"MARWAN", 6, 121625},
	{"SIKORSKY", 8, 121626},
	{"SCRIPTSUFFIX", 12, 121627},
	{"USDM", 4, 121628},
	{"TAGF", 4, 121629},
	{"RERG", 4, 121630},
	{"PGOT", 4, 121631},
	{"KIGO", 4, 121632},
	{"JRIS", 4, 121633},
	{"PORTES", 6, 121634},
	{"FINIS", 5, 121635},
	{"BREWPUBS", 8, 121636},
	{"GLOBETROTTER", 12, 121637},
	{"COMPREHENSIVENESS", 17, 121638},
	{"CHERTSEY", 8, 121639},
	{"RECLUSIVE", 9, 121640},
	{"ZELDMAN", 7, 121641},
	{"FBBT", 4, 121642},
	{"DPV", 3, 121643},
	{"SOZOPOL", 7, 121644},
	{"RISHI", 5, 121645},
	{"NEWCOMMAND", 10, 121646},
	{"FORTRESSES", 10, 121647},
	{"SISTANI", 7, 121648},
	{"SUBSTANTIVELY", 13, 121649},
	{"JAMO", 4, 121650},
	{"SATYAM", 6, 121651},
	{"PELIKAN", 7, 121652},
	{"BLOGPULSE", 9, 121653},
	{"ALOIS", 5, 121654},
	{"ZONB", 4, 121655},
	{"XMAY", 4, 121656},
	{"UTZI", 4, 121657},
	{"UALQ", 4, 121658},
	{"ORPP", 4, 121659},
	{"LBYO", 4, 121660},
	{"GSHR", 4, 121661},
	{"FIGE", 4, 121662},
	{"EGGC", 4, 121663},
	{"DDEI", 4, 121664},
	{"LETDOWN", 7, 121665},
	{"MATRONS", 7, 121666},
	{"SYMBOLIZING", 11, 121667},
	{"MSAC", 4, 121668},
	{"NONESUCH", 8, 121669},
	{"GOLUB", 5, 121670},
	{"LORAINE", 7, 121671},
	{"FRIEL", 5, 121672},
	{"BOYCOTTING", 10, 121673},
	{"BROTHA", 6, 121674},
	{"PENSIONE", 8, 121675},
	{"GHAZAL", 6, 121676},
	{"CORRIDAS", 8, 121677},
	{"GOODLAND", 8, 121678},
	{"TARVER", 6, 121679},
	{"WEBTOURIST", 10, 121680},
	{"INTELLISTATION", 14, 121681},
	{"DRED", 4, 121682},
	{"SOLENOIDS", 9, 121683},
	{"KIRWAN", 6, 121684},
	{"GAWAIN", 6, 121685},
	{"YTUB", 4, 121686},
	{"YTHB", 4, 121687},
	{"YELT", 4, 121688},
	{"WLWH", 4, 121689},
	{"UBEB", 4, 121690},
	{"TPOK", 4, 121691},
	{"NUMF", 4, 121692},
	{"GAWR", 4, 121693},
	{"EBYY", 4, 121694},
	{"CMIG", 4, 121695},
	{"LAPIERRE", 8, 121696},
	{"ZENCUDO", 7, 121697},
	{"LEGIBILITY", 10, 121698},
	{"LUTHOR", 6, 121699},
	{"CONTACTORS", 10, 121700},
	{"GUINEVERE", 9, 121701},
	{"CYCLOPEDIA", 10, 121702},
	{"ENVIR", 5, 121703},
	{"HERESIES", 8, 121704},
	{"MAXFLI", 6, 121705},
	{"MGL", 3, 121706},
	{"ARCANUM", 7, 121707},
	{"TLAF", 4, 121708},
	{"PIEW", 4, 121709},
	{"KACE", 4, 121710},
	{"ISUF", 4, 121711},
	{"GSFU", 4, 121712},
	{"EGGR", 4, 121713},
	{"BOTM", 4, 121714},
	{"BOFG", 4, 121715},
	{"ASSICURAZIONI", 13, 121716},
	{"CHIODOS", 7, 121717},
	{"ANNIHILATED", 11, 121718},
	{"SCHOOLER", 8, 121719},
	{"BALMER", 6, 121720},
	{"SBUS", 4, 121721},
	{"BODS", 4, 121722},
	{"PALAWAN", 7, 121723},
	{"CRACKMONKEY", 11, 121724},
	{"THORLO", 6, 121725},
	{"SECURITEAM", 10, 121726},
	{"FEMINISTE", 9, 121727},
	{"AZHAR", 5, 121728},
	{"HANDI", 5, 121729},
	{"SILVESTRI", 9, 121730},
	{"BRAYTON", 7, 121731},
	{"KELLNER", 7, 121732},
	{"CORIOLIS", 8, 121733},
	{"TARDINESS", 9, 121734},
	{"AGCENTER", 8, 121735},
	{"BENCHMARKED", 11, 121736},
	{"UKIM", 4, 121737},
	{"PUGN", 4, 121738},
	{"PORL", 4, 121739},
	{"MKNE", 4, 121740},
	{"IKAK", 4, 121741},
	{"HLPL", 4, 121742},
	{"DRRA", 4, 121743},
	{"BEAUVAIS", 8, 121744},
	{"BABELFISH", 9, 121745},
	{"ZAGORA", 6, 121746},
	{"BIRDSONG", 8, 121747},
	{"RAYNHAM", 7, 121748},
	{"JOSEFSSON", 9, 121749},
	{"DIMARCO", 7, 121750},
	{"COMPATIBILITIES", 15, 121751},
	{"FACILI", 6, 121752},
	{"MANGAN", 6, 121753},
	{"ORAC", 4, 121754},
	{"IROBOT", 6, 121755},
	{"RATCLIFF", 8, 121756},
	{"BENUTZER", 8, 121757},
	{"SPECKS", 6, 121758},
	{"LEGGY", 5, 121759},
	{"GINZA", 5, 121760},
	{"YARDBIRDS", 9, 121761},
	{"VYAT", 4, 121762},
	{"UWRO", 4, 121763},
	{"UBAY", 4, 121764},
	{"RPEC", 4, 121765},
	{"OSBL", 4, 121766},
	{"NICJ", 4, 121767},
	{"MRCL", 4, 121768},
	{"KIPO", 4, 121769},
	{"KEYU", 4, 121770},
	{"JANJ", 4, 121771},
	{"JALL", 4, 121772},
	{"DETR", 4, 121773},
	{"LINEARIZATION", 13, 121774},
	{"VFX", 3, 121775},
	{"SOLANUM", 7, 121776},
	{"DENIRO", 6, 121777},
	{"KAHLUA", 6, 121778},
	{"ADVENTISTS", 10, 121779},
	{"BUSINESSPERSON", 14, 121780},
	{"FUTUR", 5, 121781},
	{"INCREDULOUS", 11, 121782},
	{"DERE", 4, 121783},
	{"SUNTAN", 6, 121784},
	{"NASCIMENTO", 10, 121785},
	{"ABUS", 4, 121786},
	{"CYRIX", 5, 121787},
	{"SHAHEEN", 7, 121788},
	{"VENEDIG", 7, 121789},
	{"CALVINIST", 9, 121790},
	{"IMAIL", 5, 121791},
	{"MORGANA", 7, 121792},
	{"TGOP", 4, 121793},
	{"SHYM", 4, 121794},
	{"OYDH", 4, 121795},
	{"NDZU", 4, 121796},
	{"MMTO", 4, 121797},
	{"FTDU", 4, 121798},
	{"EKUM", 4, 121799},
	{"EGWE", 4, 121800},
	{"COBW", 4, 121801},
	{"CITM", 4, 121802},
	{"KAOLIN", 6, 121803},
	{"SYSFS", 5, 121804},
	{"HALON", 5, 121805},
	{"CERA", 4, 121806},
	{"BUCKLER", 7, 121807},
	{"GWR", 3, 121808},
	{"VISUALISE", 9, 121809},
	{"FLOPPING", 8, 121810},
	{"LARUS", 5, 121811},
	{"NATHANAEL", 9, 121812},
	{"VIDEOPOKER", 10, 121813},
	{"PEAL", 4, 121814},
	{"SHAZAM", 6, 121815},
	{"MINATURE", 8, 121816},
	{"ABOGADOS", 8, 121817},
	{"MINKOWSKI", 9, 121818},
	{"TRAWLERS", 8, 121819},
	{"IIDB", 4, 121820},
	{"FINCAS", 6, 121821},
	{"AVAILABILITIES", 14, 121822},
	{"NEWSMAKER", 9, 121823},
	{"CHAMPA", 6, 121824},
	{"DEMILLE", 7, 121825},
	{"UNCOOPERATIVE", 13, 121826},
	{"XAGO", 4, 121827},
	{"OMTY", 4, 121828},
	{"GHIV", 4, 121829},
	{"CFLU", 4, 121830},
	{"FISHNETS", 8, 121831},
	{"DALIT", 5, 121832},
	{"PROGR", 5, 121833},
	{"AGGARWAL", 8, 121834},
	{"KORMAN", 6, 121835},
	{"MOOREA", 6, 121836},
	{"ASUNTO", 6, 121837},
	{"INFANTIL", 8, 121838},
	{"ADROIT", 6, 121839},
	{"DEREFERENCING", 13, 121840},
	{"DILETTANTE", 10, 121841},
	{"VANAGON", 7, 121842},
	{"LOGFILES", 8, 121843},
	{"GEORGIANA", 9, 121844},
	{"PERFUSED", 8, 121845},
	{"NYNORSK", 7, 121846},
	{"MYSITES", 7, 121847},
	{"ATIVE", 5, 121848},
	{"STICKMAN", 8, 121849},
	{"BELIES", 6, 121850},
	{"XESL", 4, 121851},
	{"SPOM", 4, 121852},
	{"RDMY", 4, 121853},
	{"PIFY", 4, 121854},
	{"IRIR", 4, 121855},
	{"FPEE", 4, 121856},
	{"CRYT", 4, 121857},
	{"ABPR", 4, 121858},
	{"PUBURLPATH", 10, 121859},
	{"ZIRH", 4, 121860},
	{"VMAX", 4, 121861},
	{"PURNELL", 7, 121862},
	{"FLYOVER", 7, 121863},
	{"QUAKERTOWN", 10, 121864},
	{"SHERBORNE", 9, 121865},
	{"ECSTACY", 7, 121866},
	{"REDUC", 5, 121867},
	{"ASTRODOME", 9, 121868},
	{"UNDERFUNDED", 11, 121869},
	{"HIGHCHAIR", 9, 121870},
	{"GRABOWSKI", 9, 121871},
	{"BENCHTOP", 8, 121872},
	{"CRUSTACEA", 9, 121873},
	{"PEASANTRY", 9, 121874},
	{"REACTANT", 8, 121875},
	{"MARUYAMA", 8, 121876},
	{"WIMBERLEY", 9, 121877},
	{"COETZEE", 7, 121878},
	{"LAGI", 4, 121879},
	{"LETTERPRESS", 11, 121880},
	{"DUCKIE", 6, 121881},
	{"NEONODE", 7, 121882},
	{"TMLO", 4, 121883},
	{"RMYV", 4, 121884},
	{"RLSN", 4, 121885},
	{"DRGU", 4, 121886},
	{"CHUE", 4, 121887},
	{"NULLS", 5, 121888},
	{"OPPRESSORS", 10, 121889},
	{"BOEKEN", 6, 121890},
	{"NYMAN", 5, 121891},
	{"WEBTEAM", 7, 121892},
	{"LORIMER", 7, 121893},
	{"GIDDENS", 7, 121894},
	{"WASHCLOTH", 9, 121895},
	{"MANDELL", 7, 121896},
	{"CAVED", 5, 121897},
	{"KUCHMA", 6, 121898},
	{"AEROSTAR", 8, 121899},
	{"CORNS", 5, 121900},
	{"FARING", 6, 121901},
	{"DAMA", 4, 121902},
	{"PROTEOMIC", 9, 121903},
	{"ASTUCES", 7, 121904},
	{"RACEHORSE", 9, 121905},
	{"MELDING", 7, 121906},
	{"LUBRICATE", 9, 121907},
	{"TRUSHKIN", 8, 121908},
	{"KATRIN", 6, 121909},
	{"BTVS", 4, 121910},
	{"ILANA", 5, 121911},
	{"POOPY", 5, 121912},
	{"HAMLYN", 6, 121913},
	{"PINKISH", 7, 121914},
	{"SDEU", 4, 121915},
	{"RIDU", 4, 121916},
	{"LSUD", 4, 121917},
	{"GYSI", 4, 121918},
	{"DESCRIP", 7, 121919},
	{"BLURTED", 7, 121920},
	{"STRAYHORN", 9, 121921},
	{"BDP", 3, 121922},
	{"WARRENVILLE", 11, 121923},
	{"ELECTROMAGNETICS", 16, 121924},
	{"NEWMAR", 6, 121925},
	{"LLU", 3, 121926},
	{"TUTELAGE", 8, 121927},
	{"AMSER", 5, 121928},
	{"BALACLAVA", 9, 121929},
	{"MERITED", 7, 121930},
	{"TIPPETT", 7, 121931},
	{"POTW", 4, 121932},
	{"STITCHER", 8, 121933},
	{"SPIRITUALS", 10, 121934},
	{"OOLONG", 6, 121935},
	{"BEATNIK", 7, 121936},
	{"HACIA", 5, 121937},
	{"MODERNISED", 10, 121938},
	{"REPACK", 6, 121939},
	{"UDON", 4, 121940},
	{"CONCRETELY", 10, 121941},
	{"YCEW", 4, 121942},
	{"WLEO", 4, 121943},
	{"SIRP", 4, 121944},
	{"RWIG", 4, 121945},
	{"PSOW", 4, 121946},
	{"MIVE", 4, 121947},
	{"CYDR", 4, 121948},
	{"AIKK", 4, 121949},
	{"ADDB", 4, 121950},
	{"PLAYHOUSES", 10, 121951},
	{"CASSON", 6, 121952},
	{"NCLEX", 5, 121953},
	{"ALLOPURINOL", 11, 121954},
	{"AFTERSTEP", 9, 121955},
	{"DUIS", 4, 121956},
	{"LAMM", 4, 121957},
	{"BURSITIS", 8, 121958},
	{"SCIOTO", 6, 121959},
	{"OPERATIVELY", 11, 121960},
	{"BLOM", 4, 121961},
	{"PREFECTURES", 11, 121962},
	{"ZOOPHILIE", 9, 121963},
	{"PLANTSCOUT", 10, 121964},
	{"STOCKHOUSE", 10, 121965},
	{"SHELLAC", 7, 121966},
	{"HALONEN", 7, 121967},
	{"FURTHERS", 8, 121968},
	{"WUSHU", 5, 121969},
	{"CHEBOYGAN", 9, 121970},
	{"SUPERFINE", 9, 121971},
	{"DATUMS", 6, 121972},
	{"BERRI", 5, 121973},
	{"JAMBALAYA", 9, 121974},
	{"YORY", 4, 121975},
	{"PGAP", 4, 121976},
	{"PASY", 4, 121977},
	{"KUNL", 4, 121978},
	{"FRHE", 4, 121979},
	{"DSJE", 4, 121980},
	{"AUGR", 4, 121981},
	{"APYE", 4, 121982},
	{"AFOF", 4, 121983},
	{"AALP", 4, 121984},
	{"SDSC", 4, 121985},
	{"HELLUVA", 7, 121986},
	{"EPIDEMIOLOGIST", 14, 121987},
	{"DETECTORDESCRIPTION", 19, 121988},
	{"PSQL", 4, 121989},
	{"CBOS", 4, 121990},
	{"PECULIARITY", 11, 121991},
	{"KRAUTHAMMER", 11, 121992},
	{"DADOS", 5, 121993},
	{"WEBFINDER", 9, 121994},
	{"DECREPIT", 8, 121995},
	{"MICROVASCULAR", 13, 121996},
	{"MEGATONES", 9, 121997},
	{"WRITEABLE", 9, 121998},
	{"CMSA", 4, 121999},
	{"VPDN", 4, 122000},
	{"ENCROACHING", 11, 122001},
	{"CATHEPSIN", 9, 122002},
	{"FUJIMORI", 8, 122003},
	{"FLINTSTONE", 10, 122004},
	{"JCM", 3, 122005},
	{"SOLEMNITY", 9, 122006},
	{"YLLN", 4, 122007},
	{"WOYA", 4, 122008},
	{"RUNJ", 4, 122009},
	{"RIXD", 4, 122010},
	{"PTIG", 4, 122011},
	{"LMEG", 4, 122012},
	{"LKAG", 4, 122013},
	{"KBYL", 4, 122014},
	{"FOXP", 4, 122015},
	{"DSAX", 4, 122016},
	{"CZON", 4, 122017},
	{"APYF", 4, 122018},
	{"ANUD", 4, 122019},
	{"CHATSWOOD", 9, 122020},
	{"EQUIVOCAL", 9, 122021},
	{"GRAFIK", 6, 122022},
	{"BOCCE", 5, 122023},
	{"LIEB", 4, 122024},
	{"GMAX", 4, 122025},
	{"GREENEVILLE", 11, 122026},
	{"EDDINGTON", 9, 122027},
	{"STUMBLER", 8, 122028},
	{"CONTA", 5, 122029},
	{"STANMORE", 8, 122030},
	{"RONMENT", 7, 122031},
	{"IPCS", 4, 122032},
	{"STOPLIGHT", 9, 122033},
	{"AMASS", 5, 122034},
	{"PERFOMANCE", 10, 122035},
	{"MIZER", 5, 122036},
	{"CARRASCO", 8, 122037},
	{"SHOWA", 5, 122038},
	{"DRIVELINE", 9, 122039},
	{"SCHAFFNER", 9, 122040},
	{"SHQIP", 5, 122041},
	{"LZAN", 4, 122042},
	{"LKIM", 4, 122043},
	{"KEKN", 4, 122044},
	{"DYOG", 4, 122045},
	{"CFAT", 4, 122046},
	{"BETF", 4, 122047},
	{"ATUF", 4, 122048},
	{"AIDQ", 4, 122049},
	{"RHINEBECK", 9, 122050},
	{"RECONCILIATIONS", 15, 122051},
	{"TAMMI", 5, 122052},
	{"MAKETH", 6, 122053},
	{"CPCI", 4, 122054},
	{"IHREM", 5, 122055},
	{"STORNOWAY", 9, 122056},
	{"CRUCIFIXES", 10, 122057},
	{"SOWERBY", 7, 122058},
	{"SARG", 4, 122059},
	{"PRECONFIGURED", 13, 122060},
	{"PSUS", 4, 122061},
	{"KAMM", 4, 122062},
	{"DISENGAGED", 10, 122063},
	{"UALY", 4, 122064},
	{"SUKO", 4, 122065},
	{"RBUB", 4, 122066},
	{"MIDY", 4, 122067},
	{"LQUO", 4, 122068},
	{"LLOE", 4, 122069},
	{"HYMU", 4, 122070},
	{"FKIM", 4, 122071},
	{"EPFE", 4, 122072},
	{"DRFR", 4, 122073},
	{"DAIK", 4, 122074},
	{"FROMTHE", 7, 122075},
	{"DISTILLING", 10, 122076},
	{"TAINING", 7, 122077},
	{"DDG", 3, 122078},
	{"BOTTLENOSE", 10, 122079},
	{"EFFIGY", 6, 122080},
	{"SHEVA", 5, 122081},
	{"PARSEINT", 8, 122082},
	{"LEPORE", 6, 122083},
	{"MIRI", 4, 122084},
	{"HOPITAL", 7, 122085},
	{"LISKEARD", 8, 122086},
	{"GIANLUCA", 8, 122087},
	{"BESTEST", 7, 122088},
	{"BIOMARKER", 9, 122089},
	{"KPFK", 4, 122090},
	{"SHOWERHEAD", 10, 122091},
	{"DESTRA", 6, 122092},
	{"UNOFFICIALLY", 12, 122093},
	{"MONTEVERDE", 10, 122094},
	{"NOCOM", 5, 122095},
	{"FURNITUREFIND", 13, 122096},
	{"CYCLOOXYGENASE", 14, 122097},
	{"FANLISTINGS", 11, 122098},
	{"UOTF", 4, 122099},
	{"SIFB", 4, 122100},
	{"OMMT", 4, 122101},
	{"MRFR", 4, 122102},
	{"MREE", 4, 122103},
	{"KGAT", 4, 122104},
	{"AVSW", 4, 122105},
	{"SALOONS", 7, 122106},
	{"ASSAILED", 8, 122107},
	{"ASSOCATION", 10, 122108},
	{"PEEKSKILL", 9, 122109},
	{"MEIOTIC", 7, 122110},
	{"DITHERING", 9, 122111},
	{"INCENSED", 8, 122112},
	{"RAPPA", 5, 122113},
	{"SHAVES", 6, 122114},
	{"ZACHARIAH", 9, 122115},
	{"VENERATION", 10, 122116},
	{"ARISTOTELIAN", 12, 122117},
	{"BROACH", 6, 122118},
	{"MISERIES", 8, 122119},
	{"FELICIANO", 9, 122120},
	{"ALCOCK", 6, 122121},
	{"BASSEY", 6, 122122},
	{"VOIV", 4, 122123},
	{"VEMP", 4, 122124},
	{"SFSY", 4, 122125},
	{"RANX", 4, 122126},
	{"PAWO", 4, 122127},
	{"NDFT", 4, 122128},
	{"LDIH", 4, 122129},
	{"FTAY", 4, 122130},
	{"BUHA", 4, 122131},
	{"PWIND", 5, 122132},
	{"HYPOCHLORITE", 12, 122133},
	{"SWAYZE", 6, 122134},
	{"PERSONIFICATION", 15, 122135},
	{"CHRI", 4, 122136},
	{"PARTES", 6, 122137},
	{"NANOMETERS", 10, 122138},
	{"BALDOCK", 7, 122139},
	{"MFIS", 4, 122140},
	{"SCUTTLE", 7, 122141},
	{"INTBL", 5, 122142},
	{"NBOC", 4, 122143},
	{"IPLU", 4, 122144},
	{"GASQ", 4, 122145},
	{"XFIG", 4, 122146},
	{"DAMIER", 6, 122147},
	{"WALID", 5, 122148},
	{"ILIAC", 5, 122149},
	{"PAGAMENTO", 9, 122150},
	{"ANSAR", 5, 122151},
	{"BIHARI", 6, 122152},
	{"TECHPROGUILD", 12, 122153},
	{"PONTIFICATIONS", 14, 122154},
	{"SCINTILLATING", 13, 122155},
	{"CROSSLAND", 9, 122156},
	{"MAGGIEMUFFET", 12, 122157},
	{"MAGNETITE", 9, 122158},
	{"ARETE", 5, 122159},
	{"ROUGHER", 7, 122160},
	{"FIZOGEN", 7, 122161},
	{"CAERDYDD", 8, 122162},
	{"UNKU", 4, 122163},
	{"SOXL", 4, 122164},
	{"OYAF", 4, 122165},
	{"IGEV", 4, 122166},
	{"EZLE", 4, 122167},
	{"ADIY", 4, 122168},
	{"ARDAL", 5, 122169},
	{"ALIASED", 7, 122170},
	{"CORKSCREWS", 10, 122171},
	{"SHAMIR", 6, 122172},
	{"QUENCY", 6, 122173},
	{"SUPPLANTED", 10, 122174},
	{"TECHY", 5, 122175},
	{"MADELON", 7, 122176},
	{"LANZAR", 6, 122177},
	{"MINEHEAD", 8, 122178},
	{"ROLODEX", 7, 122179},
	{"KREW", 4, 122180},
	{"NEVINS", 6, 122181},
	{"SARDONIC", 8, 122182},
	{"DATINGCENTER", 12, 122183},
	{"WARSCHAU", 8, 122184},
	{"CONFECTIONARY", 13, 122185},
	{"LECOMPTE", 8, 122186},
	{"LUTION", 6, 122187},
	{"AGHAST", 6, 122188},
	{"DEJAGNU", 7, 122189},
	{"GUESTROOM", 9, 122190},
	{"STOCKMARKET", 11, 122191},
	{"EVENTUALITY", 11, 122192},
	{"MIAC", 4, 122193},
	{"ATTRTYPE", 8, 122194},
	{"RAIMENT", 7, 122195},
	{"WWEG", 4, 122196},
	{"OMIY", 4, 122197},
	{"OLNU", 4, 122198},
	{"OLKD", 4, 122199},
	{"OABD", 4, 122200},
	{"KCIR", 4, 122201},
	{"FUSG", 4, 122202},
	{"DYHU", 4, 122203},
	{"AUAL", 4, 122204},
	{"ASTEC", 5, 122205},
	{"GRAMMOPHON", 10, 122206},
	{"SPIKY", 5, 122207},
	{"ISOLATORS", 9, 122208},
	{"INTELLIFAX", 10, 122209},
	{"DISUSED", 7, 122210},
	{"AVEBURY", 7, 122211},
	{"DETOXIFY", 8, 122212},
	{"VETTER", 6, 122213},
	{"STRIDERS", 8, 122214},
	{"STOOPED", 7, 122215},
	{"SICRHAU", 7, 122216},
	{"CARBONS", 7, 122217},
	{"BOGAN", 5, 122218},
	{"SUMAC", 5, 122219},
	{"TIGRA", 5, 122220},
	{"BAYLISS", 7, 122221},
	{"HADDAM", 6, 122222},
	{"BEGLEY", 6, 122223},
	{"FARENHEIT", 9, 122224},
	{"CHOL", 4, 122225},
	{"ENCUENTRO", 9, 122226},
	{"DOWER", 5, 122227},
	{"RICIN", 5, 122228},
	{"NICVA", 5, 122229},
	{"TSINGHUA", 8, 122230},
	{"DAVIN", 5, 122231},
	{"HOTHAM", 6, 122232},
	{"UWAR", 4, 122233},
	{"TAYM", 4, 122234},
	{"PMEV", 4, 122235},
	{"OVAP", 4, 122236},
	{"NLLO", 4, 122237},
	{"GOLU", 4, 122238},
	{"AJAW", 4, 122239},
	{"AMIODARONE", 10, 122240},
	{"DYSFUNCTIONS", 12, 122241},
	{"ANDALUSIAN", 10, 122242},
	{"GITZO", 5, 122243},
	{"ARCHICAD", 8, 122244},
	{"WORDY", 5, 122245},
	{"SEIXAS", 6, 122246},
	{"SCHEDULERS", 10, 122247},
	{"SCCS", 4, 122248},
	{"JPC", 3, 122249},
	{"REHEAT", 6, 122250},
	{"EMMERICH", 8, 122251},
	{"FEUDALISM", 9, 122252},
	{"UNZENSIERT", 10, 122253},
	{"STARLITE", 8, 122254},
	{"CRADDOCK", 8, 122255},
	{"WABC", 4, 122256},
	{"TELEWORKING", 11, 122257},
	{"MICHI", 5, 122258},
	{"ACHILLE", 7, 122259},
	{"WIMBORNE", 8, 122260},
	{"WOEM", 4, 122261},
	{"RKSJ", 4, 122262},
	{"OJUR", 4, 122263},
	{"OBGO", 4, 122264},
	{"IEWV", 4, 122265},
	{"FISW", 4, 122266},
	{"FHRE", 4, 122267},
	{"DDOX", 4, 122268},
	{"CATHER", 6, 122269},
	{"MOLT", 4, 122270},
	{"ELROY", 5, 122271},
	{"RMF", 3, 122272},
	{"COIR", 4, 122273},
	{"PEALE", 5, 122274},
	{"MINUSCULE", 9, 122275},
	{"EXIRA", 5, 122276},
	{"MULTIFOCAL", 10, 122277},
	{"LANDSCAPER", 10, 122278},
	{"INVERMERE", 9, 122279},
	{"WATCHDOGS", 9, 122280},
	{"CNBCHELP", 8, 122281},
	{"MAGISTER", 8, 122282},
	{"UNLOCKER", 8, 122283},
	{"MICROORGANISM", 13, 122284},
	{"CROTCHET", 8, 122285},
	{"BOLTING", 7, 122286},
	{"LUMBERING", 9, 122287},
	{"KAHLER", 6, 122288},
	{"FIXATED", 7, 122289},
	{"DEADB", 5, 122290},
	{"WDOM", 4, 122291},
	{"UUMT", 4, 122292},
	{"UDUR", 4, 122293},
	{"PFEI", 4, 122294},
	{"OFGW", 4, 122295},
	{"NRYG", 4, 122296},
	{"MSKN", 4, 122297},
	{"LDCB", 4, 122298},
	{"HBYB", 4, 122299},
	{"GYMT", 4, 122300},
	{"FTYE", 4, 122301},
	{"EWRY", 4, 122302},
	{"DSEB", 4, 122303},
	{"BUYD", 4, 122304},
	{"BSKYB", 5, 122305},
	{"SKELTER", 7, 122306},
	{"COUNTERWEIGHT", 13, 122307},
	{"FOURFOLD", 8, 122308},
	{"REGIA", 5, 122309},
	{"BRACKETING", 10, 122310},
	{"REEKS", 5, 122311},
	{"JOVIAN", 6, 122312},
	{"FORGAVE", 7, 122313},
	{"DISINTEGRATE", 12, 122314},
	{"ZAFIRA", 6, 122315},
	{"CROSSLINKING", 12, 122316},
	{"UNCONJUGATED", 12, 122317},
	{"AROMATASE", 9, 122318},
	{"STIMSON", 7, 122319},
	{"BIOSYNTHETIC", 12, 122320},
	{"LAUTREC", 7, 122321},
	{"EUPHORBIA", 9, 122322},
	{"FICATION", 8, 122323},
	{"WWRO", 4, 122324},
	{"UMGE", 4, 122325},
	{"PYST", 4, 122326},
	{"EPTV", 4, 122327},
	{"ECDI", 4, 122328},
	{"DPUE", 4, 122329},
	{"BCHO", 4, 122330},
	{"POPULISM", 8, 122331},
	{"SPOILAGE", 8, 122332},
	{"SOFTSWITCH", 10, 122333},
	{"ANTONIUS", 8, 122334},
	{"SHGC", 4, 122335},
	{"ADORNO", 6, 122336},
	{"AADVANTAGE", 10, 122337},
	{"EDINBORO", 8, 122338},
	{"INDIEN", 6, 122339},
	{"ADHOC", 5, 122340},
	{"AQABA", 5, 122341},
	{"REFRIGERATING", 13, 122342},
	{"RECESSIONS", 10, 122343},
	{"RFB", 3, 122344},
	{"WNNU", 4, 122345},
	{"UAID", 4, 122346},
	{"RVAP", 4, 122347},
	{"PATK", 4, 122348},
	{"OELB", 4, 122349},
	{"KDAI", 4, 122350},
	{"INML", 4, 122351},
	{"FUSL", 4, 122352},
	{"FGRU", 4, 122353},
	{"DOLG", 4, 122354},
	{"DIEX", 4, 122355},
	{"CDAM", 4, 122356},
	{"BTYP", 4, 122357},
	{"BTWA", 4, 122358},
	{"AJAV", 4, 122359},
	{"SEAFOODS", 8, 122360},
	{"ZIHUATANEJO", 11, 122361},
	{"COLLEYVILLE", 11, 122362},
	{"DIRECWAY", 8, 122363},
	{"MAUVIEL", 7, 122364},
	{"MATX", 4, 122365},
	{"BIOLOGICALS", 11, 122366},
	{"CLV", 3, 122367},
	{"BOCHS", 5, 122368},
	{"REPLENISHING", 12, 122369},
	{"MINIBUSES", 9, 122370},
	{"ABUTMENT", 8, 122371},
	{"GRAZIA", 6, 122372},
	{"MURALI", 6, 122373},
	{"IMMEMORIAL", 10, 122374},
	{"BRADNER", 7, 122375},
	{"ARTHROSCOPIC", 12, 122376},
	{"CORS", 4, 122377},
	{"SNELLVILLE", 10, 122378},
	{"PRESCIENT", 9, 122379},
	{"LESSARD", 7, 122380},
	{"INSTILLING", 10, 122381},
	{"BOGIE", 5, 122382},
	{"YWAD", 4, 122383},
	{"YUTT", 4, 122384},
	{"UPKN", 4, 122385},
	{"UNKP", 4, 122386},
	{"ROTG", 4, 122387},
	{"RIBN", 4, 122388},
	{"MRJA", 4, 122389},
	{"LFDR", 4, 122390},
	{"LAGC", 4, 122391},
	{"IACK", 4, 122392},
	{"CHSQ", 4, 122393},
	{"CFAL", 4, 122394},
	{"BOFL", 4, 122395},
	{"ROADING", 7, 122396},
	{"INDWELLING", 10, 122397},
	{"PARLOURS", 8, 122398},
	{"DEFOREST", 8, 122399},
	{"BIOMES", 6, 122400},
	{"EVANOVICH", 9, 122401},
	{"TIFFANI", 7, 122402},
	{"ERRR", 4, 122403},
	{"JAUNT", 5, 122404},
	{"PILOTAGE", 8, 122405},
	{"CGD", 3, 122406},
	{"INJECTIVE", 9, 122407},
	{"GENERE", 6, 122408},
	{"NETOBJECTS", 10, 122409},
	{"ZWM", 3, 122410},
	{"ZGF", 3, 122411},
	{"WVJ", 3, 122412},
	{"VJW", 3, 122413},
	{"VCZ", 3, 122414},
	{"QRR", 3, 122415},
	{"PXJ", 3, 122416},
	{"KQD", 3, 122417},
	{"BXV", 3, 122418},
	{"BDZ", 3, 122419},
	{"KANGURU", 7, 122420},
	{"NETSERVER", 9, 122421},
	{"BULLWINKLE", 10, 122422},
	{"YASV", 4, 122423},
	{"UZIN", 4, 122424},
	{"RKOG", 4, 122425},
	{"PPOT", 4, 122426},
	{"LTVA", 4, 122427},
	{"LDOD", 4, 122428},
	{"ICIU", 4, 122429},
	{"HWAV", 4, 122430},
	{"FALQ", 4, 122431},
	{"EKFA", 4, 122432},
	{"DULC", 4, 122433},
	{"BTMA", 4, 122434},
	{"QUARTIER", 8, 122435},
	{"WALLOW", 6, 122436},
	{"TURBOCHARGED", 12, 122437},
	{"HOLZER", 6, 122438},
	{"ANALLY", 6, 122439},
	{"AUTOWEEK", 8, 122440},
	{"UNABASHED", 9, 122441},
	{"PORTIS", 6, 122442},
	{"CUAL", 4, 122443},
	{"BRASILIAN", 9, 122444},
	{"AGERS", 5, 122445},
	{"MOISTURISING", 12, 122446},
	{"DEMA", 4, 122447},
	{"ELECTRICSHOP", 12, 122448},
	{"PUSHTU", 6, 122449},
	{"CIRCUSES", 8, 122450},
	{"STUDIOPLUS", 10, 122451},
	{"GUANOSINE", 9, 122452},
	{"XISL", 4, 122453},
	{"UCAU", 4, 122454},
	{"UANF", 4, 122455},
	{"TMOF", 4, 122456},
	{"RGAA", 4, 122457},
	{"REYJ", 4, 122458},
	{"MMMA", 4, 122459},
	{"MITG", 4, 122460},
	{"KYET", 4, 122461},
	{"CLYC", 4, 122462},
	{"SCROLLKEEPER", 12, 122463},
	{"BUCKTOWN", 8, 122464},
	{"INTERANNUAL", 11, 122465},
	{"FIDONET", 7, 122466},
	{"PATENTABILITY", 13, 122467},
	{"ESTORIL", 7, 122468},
	{"MARLENA", 7, 122469},
	{"ZAWAHRI", 7, 122470},
	{"DIAGONALS", 9, 122471},
	{"DOKUMENT", 8, 122472},
	{"LOCTITE", 7, 122473},
	{"NIEMAN", 6, 122474},
	{"GRAMMATICALLY", 13, 122475},
	{"FORMALISED", 10, 122476},
	{"CEREUS", 6, 122477},
	{"SIDENOTE", 8, 122478},
	{"PFALZ", 5, 122479},
	{"HOMERIC", 7, 122480},
	{"BALZERS", 7, 122481},
	{"SPANNERS", 8, 122482},
	{"SUBCONSCIOUSLY", 14, 122483},
	{"YESV", 4, 122484},
	{"XYAR", 4, 122485},
	{"TPIG", 4, 122486},
	{"TPHR", 4, 122487},
	{"SOXB", 4, 122488},
	{"ICYL", 4, 122489},
	{"HOPJ", 4, 122490},
	{"DMUH", 4, 122491},
	{"CSFE", 4, 122492},
	{"AWNR", 4, 122493},
	{"TEGUCIGALPA", 11, 122494},
	{"NORMAND", 7, 122495},
	{"PHOTOCHEMISTRY", 14, 122496},
	{"LWR", 3, 122497},
	{"HAITIANS", 8, 122498},
	{"SARAI", 5, 122499},
	{"BIPLANE", 7, 122500},
	{"SPECIFICITIES", 13, 122501},
	{"FREEBORN", 8, 122502},
	{"VYBU", 4, 122503},
	{"UMNC", 4, 122504},
	{"RVIG", 4, 122505},
	{"LVAA", 4, 122506},
	{"KCOC", 4, 122507},
	{"ERUH", 4, 122508},
	{"HASSELL", 7, 122509},
	{"POSTSECRET", 10, 122510},
	{"BRUNET", 6, 122511},
	{"SPIER", 5, 122512},
	{"LINKEDIN", 8, 122513},
	{"OVERPOWER", 9, 122514},
	{"SELKIRKSHIRE", 12, 122515},
	{"BARRENS", 7, 122516},
	{"JITTERBUG", 9, 122517},
	{"CWR", 3, 122518},
	{"DIPHENHYDRAMINE", 15, 122519},
	{"MOLINARI", 8, 122520},
	{"SOCIEDADE", 9, 122521},
	{"RECEPTIONISTS", 13, 122522},
	{"LIFEWAY", 7, 122523},
	{"PRICESPY", 8, 122524},
	{"PLOS", 4, 122525},
	{"EXPOUNDED", 9, 122526},
	{"WIFEY", 5, 122527},
	{"MPAS", 4, 122528},
	{"DOWNPOUR", 8, 122529},
	{"DOMESTICATIONS", 14, 122530},
	{"NUNIT", 5, 122531},
	{"WOBY", 4, 122532},
	{"UYSN", 4, 122533},
	{"UORT", 4, 122534},
	{"PIGN", 4, 122535},
	{"OYMI", 4, 122536},
	{"NVEX", 4, 122537},
	{"IXVI", 4, 122538},
	{"IKAG", 4, 122539},
	{"GIKN", 4, 122540},
	{"FDAW", 4, 122541},
	{"FUNCTORS", 8, 122542},
	{"ESTILL", 6, 122543},
	{"SUPERSTACK", 10, 122544},
	{"MCKELLEN", 8, 122545},
	{"SUBCONTRACTED", 13, 122546},
	{"KISSOGRAMS", 10, 122547},
	{"SCHWAIGER", 9, 122548},
	{"FAIRBORN", 8, 122549},
	{"DUMBFOUNDED", 11, 122550},
	{"YARON", 5, 122551},
	{"CUBITS", 6, 122552},
	{"REMOVEABLE", 10, 122553},
	{"JAKKS", 5, 122554},
	{"INTERGENIC", 10, 122555},
	{"TORTIOUS", 8, 122556},
	{"OUTLAST", 7, 122557},
	{"WERTH", 5, 122558},
	{"VIKA", 4, 122559},
	{"NETLIST", 7, 122560},
	{"FROTHY", 6, 122561},
	{"AMICA", 5, 122562},
	{"OMNIDIRECTIONAL", 15, 122563},
	{"ROYF", 4, 122564},
	{"RMFE", 4, 122565},
	{"OXYS", 4, 122566},
	{"MJIM", 4, 122567},
	{"LPAM", 4, 122568},
	{"HSUL", 4, 122569},
	{"GUYP", 4, 122570},
	{"AXSY", 4, 122571},
	{"UMMAH", 5, 122572},
	{"HALFORDS", 8, 122573},
	{"WEBCAT", 6, 122574},
	{"KOOK", 4, 122575},
	{"MARIEL", 6, 122576},
	{"CLYDEBANK", 9, 122577},
	{"ASHGATE", 7, 122578},
	{"HEDBERG", 7, 122579},
	{"THALASSEMIA", 11, 122580},
	{"SPEARHEADING", 12, 122581},
	{"MCCLANAHAN", 10, 122582},
	{"CLIENTE", 7, 122583},
	{"NEWSREADERS", 11, 122584},
	{"UBR", 3, 122585},
	{"BRINKER", 7, 122586},
	{"CMDLINE", 7, 122587},
	{"HOUSEMATE", 9, 122588},
	{"SCANLAN", 7, 122589},
	{"MACEDONIANS", 11, 122590},
	{"STREETWEAR", 10, 122591},
	{"PERROR", 6, 122592},
	{"EMANUELE", 8, 122593},
	{"EASYGOING", 9, 122594},
	{"OKALOOSA", 8, 122595},
	{"YSIDRO", 6, 122596},
	{"SOUNDPROOF", 10, 122597},
	{"RVOW", 4, 122598},
	{"NGGH", 4, 122599},
	{"DDUD", 4, 122600},
	{"VANILLE", 7, 122601},
	{"LABOURING", 9, 122602},
	{"SCHAUB", 6, 122603},
	{"BIGG", 4, 122604},
	{"PLINE", 5, 122605},
	{"GECKOS", 6, 122606},
	{"SILV", 4, 122607},
	{"OSLER", 5, 122608},
	{"AMPHOTERICIN", 12, 122609},
	{"TRUVATIV", 8, 122610},
	{"EUROP", 5, 122611},
	{"POUVEZ", 6, 122612},
	{"APOLYTON", 8, 122613},
	{"DEPMODE", 7, 122614},
	{"BOTHWELL", 8, 122615},
	{"QUENTLY", 7, 122616},
	{"SCIENTOLOGISTS", 14, 122617},
	{"TESTRESULTS", 11, 122618},
	{"WPUR", 4, 122619},
	{"RNYE", 4, 122620},
	{"PYSH", 4, 122621},
	{"PNIC", 4, 122622},
	{"NDRP", 4, 122623},
	{"IPDA", 4, 122624},
	{"EKHM", 4, 122625},
	{"EDPC", 4, 122626},
	{"BSUN", 4, 122627},
	{"BSOV", 4, 122628},
	{"ALZB", 4, 122629},
	{"ALIQUOTS", 8, 122630},
	{"ANADARKO", 8, 122631},
	{"EJOURNALS", 9, 122632},
	{"VENDREDI", 8, 122633},
	{"MAMARONECK", 10, 122634},
	{"BROADHURST", 10, 122635},
	{"TWITTY", 6, 122636},
	{"MCCUNE", 6, 122637},
	{"UNBLEACHED", 10, 122638},
	{"SPLATTERED", 10, 122639},
	{"FATHERING", 9, 122640},
	{"ZOLLER", 6, 122641},
	{"NOTHINGS", 8, 122642},
	{"SPIP", 4, 122643},
	{"RENTACAR", 8, 122644},
	{"LIBPCAP", 7, 122645},
	{"UNEVENLY", 8, 122646},
	{"DANGLES", 7, 122647},
	{"ESPARES", 7, 122648},
	{"KOMMEN", 6, 122649},
	{"BILLER", 6, 122650},
	{"BAKKE", 5, 122651},
	{"RPFO", 4, 122652},
	{"LEJI", 4, 122653},
	{"KBYR", 4, 122654},
	{"IXBY", 4, 122655},
	{"IBEB", 4, 122656},
	{"GNSL", 4, 122657},
	{"FTOX", 4, 122658},
	{"EHUF", 4, 122659},
	{"IRENA", 5, 122660},
	{"CHEMOKINES", 10, 122661},
	{"HANDMARK", 8, 122662},
	{"HELICITY", 8, 122663},
	{"LOLZ", 4, 122664},
	{"LATOYA", 6, 122665},
	{"DVL", 3, 122666},
	{"ALLGEMEIN", 9, 122667},
	{"SOFLENS", 7, 122668},
	{"COLLISON", 8, 122669},
	{"COLONIST", 8, 122670},
	{"SORBONNE", 8, 122671},
	{"DBW", 3, 122672},
	{"PHILS", 5, 122673},
	{"SCHOOLWIDE", 10, 122674},
	{"MTEKK", 5, 122675},
	{"AKTUELL", 7, 122676},
	{"RARES", 5, 122677},
	{"ABDOMINOPLASTY", 14, 122678},
	{"PHILOS", 6, 122679},
	{"HAFNER", 6, 122680},
	{"FUNDA", 5, 122681},
	{"MENDELIAN", 9, 122682},
	{"HABLAMOS", 8, 122683},
	{"COLLA", 5, 122684},
	{"VLDB", 4, 122685},
	{"CEISTEANNA", 10, 122686},
	{"VOWA", 4, 122687},
	{"RDMC", 4, 122688},
	{"DLAZ", 4, 122689},
	{"DDRS", 4, 122690},
	{"BOSP", 4, 122691},
	{"PHILIPPI", 8, 122692},
	{"BAGH", 4, 122693},
	{"CARRIERE", 8, 122694},
	{"NOVOTNY", 7, 122695},
	{"ADDUCED", 7, 122696},
	{"GUZZLING", 8, 122697},
	{"OLEIC", 5, 122698},
	{"AGLI", 4, 122699},
	{"CHOOL", 5, 122700},
	{"ELEARNERS", 9, 122701},
	{"FLAGPOLES", 9, 122702},
	{"OSTRANDER", 9, 122703},
	{"FLATT", 5, 122704},
	{"ESCAPEMENT", 10, 122705},
	{"YSTL", 4, 122706},
	{"YLTD", 4, 122707},
	{"YLEU", 4, 122708},
	{"RBOP", 4, 122709},
	{"NKUM", 4, 122710},
	{"NFOM", 4, 122711},
	{"MROT", 4, 122712},
	{"KMWI", 4, 122713},
	{"FPEL", 4, 122714},
	{"EGYH", 4, 122715},
	{"ECDA", 4, 122716},
	{"DFET", 4, 122717},
	{"ARUW", 4, 122718},
	{"EARTHBOUND", 10, 122719},
	{"LADYBUGS", 8, 122720},
	{"UNREQUITED", 10, 122721},
	{"UTILITARIANISM", 14, 122722},
	{"EVGENY", 6, 122723},
	{"PIETERMARITZBURG", 16, 122724},
	{"SUNSPOTS", 8, 122725},
	{"THUNE", 5, 122726},
	{"MANGLE", 6, 122727},
	{"COVERCRAFT", 10, 122728},
	{"ALLUDES", 7, 122729},
	{"IPODDER", 7, 122730},
	{"DEMINING", 8, 122731},
	{"THESEUS", 7, 122732},
	{"FURN", 4, 122733},
	{"HANALEI", 7, 122734},
	{"MANHATTEN", 9, 122735},
	{"ENERJY", 6, 122736},
	{"AUTHORISATIONS", 14, 122737},
	{"YOUD", 4, 122738},
	{"REDNEX", 6, 122739},
	{"COMMUTED", 8, 122740},
	{"AZTEK", 5, 122741},
	{"ONESIE", 6, 122742},
	{"HARROD", 6, 122743},
	{"YGLI", 4, 122744},
	{"USHV", 4, 122745},
	{"UNEK", 4, 122746},
	{"TVVI", 4, 122747},
	{"RBEU", 4, 122748},
	{"PPWA", 4, 122749},
	{"NDXA", 4, 122750},
	{"GGIL", 4, 122751},
	{"FWEP", 4, 122752},
	{"SIDEN", 5, 122753},
	{"HOLLIE", 6, 122754},
	{"SEQUITUR", 8, 122755},
	{"DENOMINATORS", 12, 122756},
	{"FDM", 3, 122757},
	{"LEGIS", 5, 122758},
	{"KYOTEE", 6, 122759},
	{"FOOTIE", 6, 122760},
	{"CENTR", 5, 122761},
	{"SILVERSMITHS", 12, 122762},
	{"BORDELL", 7, 122763},
	{"DVDRECORDERHARDDISK", 19, 122764},
	{"GAYBOY", 6, 122765},
	{"BOREHAMWOOD", 11, 122766},
	{"KRASNOYARSK", 11, 122767},
	{"IMMUNOREACTIVE", 14, 122768},
	{"GINGIVITIS", 10, 122769},
	{"UKAM", 4, 122770},
	{"SFID", 4, 122771},
	{"OUAM", 4, 122772},
	{"MFLY", 4, 122773},
	{"LOTY", 4, 122774},
	{"LNOU", 4, 122775},
	{"LEEZ", 4, 122776},
	{"HDOY", 4, 122777},
	{"FLAL", 4, 122778},
	{"FKAB", 4, 122779},
	{"DBAM", 4, 122780},
	{"AMYB", 4, 122781},
	{"AZDEN", 5, 122782},
	{"STEPFORD", 8, 122783},
	{"KARAJAN", 7, 122784},
	{"QUINTERO", 8, 122785},
	{"VERIFONE", 8, 122786},
	{"SHINED", 6, 122787},
	{"MEDAN", 5, 122788},
	{"LECTINS", 7, 122789},
	{"PRECIS", 6, 122790},
	{"NANAK", 5, 122791},
	{"HEROLD", 6, 122792},
	{"CACIA", 5, 122793},
	{"LEDBURY", 7, 122794},
	{"ETOPOSIDE", 9, 122795},
	{"DLCI", 4, 122796},
	{"CHARMAP", 7, 122797},
	{"INGESTING", 9, 122798},
	{"BLUEMOON", 8, 122799},
	{"WEIGHTLESS", 10, 122800},
	{"PEETERS", 7, 122801},
	{"GUIZHOU", 7, 122802},
	{"ANGLIN", 6, 122803},
	{"PLEXIGLAS", 9, 122804},
	{"HAVELI", 6, 122805},
	{"REALIGN", 7, 122806},
	{"VIBRANCY", 8, 122807},
	{"SHEEHY", 6, 122808},
	{"BEEK", 4, 122809},
	{"ZEEL", 4, 122810},
	{"VUEL", 4, 122811},
	{"VSMI", 4, 122812},
	{"UNZI", 4, 122813},
	{"TOWL", 4, 122814},
	{"NWYN", 4, 122815},
	{"KJOE", 4, 122816},
	{"FOXO", 4, 122817},
	{"ELKR", 4, 122818},
	{"SARACEN", 7, 122819},
	{"ANNULLED", 8, 122820},
	{"BARANGAY", 8, 122821},
	{"COVERTLY", 8, 122822},
	{"VARNER", 6, 122823},
	{"NUCLEOPLASM", 11, 122824},
	{"POULENC", 7, 122825},
	{"DOKU", 4, 122826},
	{"BEARINGPOINT", 12, 122827},
	{"ARJONA", 6, 122828},
	{"FREEPAGES", 9, 122829},
	{"GAZETA", 6, 122830},
	{"PRETO", 5, 122831},
	{"HOMEFINDER", 10, 122832},
	{"DALLE", 5, 122833},
	{"WIREFRAME", 9, 122834},
	{"IFAC", 4, 122835},
	{"MEDULLARY", 9, 122836},
	{"RAPPED", 6, 122837},
	{"NIGELLA", 7, 122838},
	{"BOEHNER", 7, 122839},
	{"FOREBODING", 10, 122840},
	{"HIKARI", 6, 122841},
	{"OCTYL", 5, 122842},
	{"MACACA", 6, 122843},
	{"LOGIX", 5, 122844},
	{"LOHR", 4, 122845},
	{"VPOS", 4, 122846},
	{"UGNA", 4, 122847},
	{"SUYA", 4, 122848},
	{"QVIS", 4, 122849},
	{"PSKA", 4, 122850},
	{"ONYV", 4, 122851},
	{"HDED", 4, 122852},
	{"EIMU", 4, 122853},
	{"DDEW", 4, 122854},
	{"ENGELBERT", 9, 122855},
	{"FAVORITISM", 10, 122856},
	{"THIMBLES", 8, 122857},
	{"LOHMAN", 6, 122858},
	{"DEARING", 7, 122859},
	{"TAILING", 7, 122860},
	{"OSVDB", 5, 122861},
	{"STOICHIOMETRY", 13, 122862},
	{"OMBUDSMEN", 9, 122863},
	{"FEEDINGS", 8, 122864},
	{"CHARENTE", 8, 122865},
	{"IMIPRAMINE", 10, 122866},
	{"FORTUITOUS", 10, 122867},
	{"RABOBANK", 8, 122868},
	{"PROTONET", 8, 122869},
	{"JAINISM", 7, 122870},
	{"IMAMS", 5, 122871},
	{"AUTUMNAL", 8, 122872},
	{"WALKOUT", 7, 122873},
	{"POWERLIFTING", 12, 122874},
	{"PLAYGROUPS", 10, 122875},
	{"HURRAY", 6, 122876},
	{"PEDDLERS", 8, 122877},
	{"GAYTEEN", 7, 122878},
	{"CALIPHATE", 9, 122879},
	{"LXLI", 4, 122880},
	{"SEPULCHRE", 9, 122881},
	{"GFORTRAN", 8, 122882},
	{"CDPLAYERPORTABLE", 16, 122883},
	{"TENSORS", 7, 122884},
	{"THURGOOD", 8, 122885},
	{"SEAMONKEY", 9, 122886},
	{"FREON", 5, 122887},
	{"VIIV", 4, 122888},
	{"GESTETNER", 9, 122889},
	{"KUNT", 4, 122890},
	{"VISUALIZER", 10, 122891},
	{"DESPOTIC", 8, 122892},
	{"KESTER", 6, 122893},
	{"ADOPTABLE", 9, 122894},
	{"INTERMOLECULAR", 14, 122895},
	{"PALMOLIVE", 9, 122896},
	{"SCIEN", 5, 122897},
	{"PARKINSONS", 10, 122898},
	{"GRIECHENLAND", 12, 122899},
	{"AUBERGINE", 9, 122900},
	{"LANTRONIX", 9, 122901},
	{"DICKY", 5, 122902},
	{"SKBA", 4, 122903},
	{"PPWH", 4, 122904},
	{"OUGW", 4, 122905},
	{"OELM", 4, 122906},
	{"AORR", 4, 122907},
	{"AHUD", 4, 122908},
	{"ADUO", 4, 122909},
	{"MILITARISTIC", 12, 122910},
	{"UDRP", 4, 122911},
	{"BEHOLDEN", 8, 122912},
	{"GISELA", 6, 122913},
	{"WILLMAR", 7, 122914},
	{"AMINOPEPTIDASE", 14, 122915},
	{"BLETCHLEY", 9, 122916},
	{"NIMITZ", 6, 122917},
	{"ROLLBACKS", 9, 122918},
	{"PASQUARELLI", 11, 122919},
	{"AMORAL", 6, 122920},
	{"CELUI", 5, 122921},
	{"BRANKO", 6, 122922},
	{"LUANDA", 6, 122923},
	{"BKR", 3, 122924},
	{"APOSTATE", 8, 122925},
	{"HOPPY", 5, 122926},
	{"GURLEY", 6, 122927},
	{"EXPERIANCE", 10, 122928},
	{"TEMPTRESS", 9, 122929},
	{"BLACKTOP", 8, 122930},
	{"FALTERED", 8, 122931},
	{"VOLTERRA", 8, 122932},
	{"PHARYNX", 7, 122933},
	{"ZIGLAR", 6, 122934},
	{"QUEDA", 5, 122935},
	{"ENCYCLOPEDIE", 12, 122936},
	{"PLF", 3, 122937},
	{"TOPSHOP", 7, 122938},
	{"SMALLISH", 8, 122939},
	{"MIGRATES", 8, 122940},
	{"ALERA", 5, 122941},
	{"YUNO", 4, 122942},
	{"PEEX", 4, 122943},
	{"HNUC", 4, 122944},
	{"HLAG", 4, 122945},
	{"EXSU", 4, 122946},
	{"XYTHOS", 6, 122947},
	{"GFC", 3, 122948},
	{"ATTRACTORS", 10, 122949},
	{"SLEATER", 7, 122950},
	{"DIFFUSIVE", 9, 122951},
	{"OSTEOSARCOMA", 12, 122952},
	{"ENTRAR", 6, 122953},
	{"ASCIZ", 5, 122954},
	{"DISABLEMENT", 11, 122955},
	{"LIMBIC", 6, 122956},
	{"OEDEMA", 6, 122957},
	{"SICHERHEIT", 10, 122958},
	{"DISHING", 7, 122959},
	{"MUSAB", 5, 122960},
	{"AAFP", 4, 122961},
	{"ARMONK", 6, 122962},
	{"GORSE", 5, 122963},
	{"KAPAA", 5, 122964},
	{"LOUSE", 5, 122965},
	{"DOWNIE", 6, 122966},
	{"WILFULLY", 8, 122967},
	{"BURKHARDT", 9, 122968},
	{"BURRO", 5, 122969},
	{"STYG", 4, 122970},
	{"HMEG", 4, 122971},
	{"FMYN", 4, 122972},
	{"DOXJ", 4, 122973},
	{"TRICYCLES", 9, 122974},
	{"CATONSVILLE", 11, 122975},
	{"GLOBALSTAR", 10, 122976},
	{"PARALYSED", 9, 122977},
	{"WINCRAFT", 8, 122978},
	{"TILLIE", 6, 122979},
	{"ROMIJN", 6, 122980},
	{"ORGANELLE", 9, 122981},
	{"LURAY", 5, 122982},
	{"RAMAKRISHNA", 11, 122983},
	{"MAJLIS", 6, 122984},
	{"DIETLIBC", 8, 122985},
	{"DISTANCED", 9, 122986},
	{"VESPERS", 7, 122987},
	{"SCYLLA", 6, 122988},
	{"USINESS", 7, 122989},
	{"TSEAVER", 7, 122990},
	{"LOBELIA", 7, 122991},
	{"ALTIVEC", 7, 122992},
	{"BELLEEK", 7, 122993},
	{"RIGHTNOW", 8, 122994},
	{"EUROGAMER", 9, 122995},
	{"EXPLORIST", 9, 122996},
	{"URCHINS", 7, 122997},
	{"OUTSCORED", 9, 122998},
	{"ULOI", 4, 122999},
	{"RYUR", 4, 123000},
	{"DRDE", 4, 123001},
	{"BAYV", 4, 123002},
	{"SUCESS", 6, 123003},
	{"WESSELS", 7, 123004},
	{"KINESIS", 7, 123005},
	{"SAILINGS", 8, 123006},
	{"BATU", 4, 123007},
	{"TUCCI", 5, 123008},
	{"CNTRL", 5, 123009},
	{"PHARYNGEAL", 10, 123010},
	{"REACTANTS", 9, 123011},
	{"KPIS", 4, 123012},
	{"FLEXED", 6, 123013},
	{"CAMELEON", 8, 123014},
	{"EXTRASOLAR", 10, 123015},
	{"GALINA", 6, 123016},
	{"ARGONAUTS", 9, 123017},
	{"ILEUM", 5, 123018},
	{"FLUGELHORN", 10, 123019},
	{"QPSK", 4, 123020},
	{"JACOMO", 6, 123021},
	{"CTOR", 4, 123022},
	{"SAFFLOWER", 9, 123023},
	{"STUDENTSHIPS", 12, 123024},
	{"BAGC", 4, 123025},
	{"ALYU", 4, 123026},
	{"BASSI", 5, 123027},
	{"WRIGLEYVILLE", 12, 123028},
	{"HYPERCHOLESTEROLEMIA", 20, 123029},
	{"RESURFACE", 9, 123030},
	{"IMPLORE", 7, 123031},
	{"DYNASTAR", 8, 123032},
	{"HINARI", 6, 123033},
	{"VEGGIETALES", 11, 123034},
	{"DAKE", 4, 123035},
	{"HORLEY", 6, 123036},
	{"FRACTURING", 10, 123037},
	{"FARMERSVILLE", 12, 123038},
	{"ARCHIEF", 7, 123039},
	{"NOSEBLEED", 9, 123040},
	{"CHRISTIANSON", 12, 123041},
	{"VLBI", 4, 123042},
	{"KINDLE", 6, 123043},
	{"ZARETSKII", 9, 123044},
	{"PRICKS", 6, 123045},
	{"ROKER", 5, 123046},
	{"DEVIOUSNESS", 11, 123047},
	{"WLOU", 4, 123048},
	{"TEMK", 4, 123049},
	{"NZAW", 4, 123050},
	{"NBYY", 4, 123051},
	{"FAXE", 4, 123052},
	{"SADDLEBAGS", 10, 123053},
	{"KATU", 4, 123054},
	{"TENEMENTS", 9, 123055},
	{"PLACEMAT", 8, 123056},
	{"EMPTION", 7, 123057},
	{"VIATOR", 6, 123058},
	{"TITHES", 6, 123059},
	{"SPIDERBAIT", 10, 123060},
	{"DRAGNET", 7, 123061},
	{"THINNEST", 8, 123062},
	{"SIPPED", 6, 123063},
	{"EDUTAINMENT", 11, 123064},
	{"REGUS", 5, 123065},
	{"PESSOA", 6, 123066},
	{"INELIGIBILITY", 13, 123067},
	{"HEDONIC", 7, 123068},
	{"ANTHROPOMORPHIC", 15, 123069},
	{"RUBO", 4, 123070},
	{"OLKN", 4, 123071},
	{"MAFG", 4, 123072},
	{"FEKE", 4, 123073},
	{"FCYB", 4, 123074},
	{"EUTM", 4, 123075},
	{"URSINUS", 7, 123076},
	{"XCEN", 4, 123077},
	{"METOLIUS", 8, 123078},
	{"CHEESEMAN", 9, 123079},
	{"MINIMIZER", 9, 123080},
	{"LOWCOUNTRY", 10, 123081},
	{"STRIPCAM", 8, 123082},
	{"DELINEATING", 11, 123083},
	{"SIGG", 4, 123084},
	{"MANDO", 5, 123085},
	{"MYOCYTES", 8, 123086},
	{"THOMA", 5, 123087},
	{"MNEMONICS", 9, 123088},
	{"PROGETTO", 8, 123089},
	{"LENKA", 5, 123090},
	{"DPG", 3, 123091},
	{"TROD", 4, 123092},
	{"STENDHAL", 8, 123093},
	{"TRANMERE", 8, 123094},
	{"COFF", 4, 123095},
	{"PULSATION", 9, 123096},
	{"HITCHING", 8, 123097},
	{"CRANKCASE", 9, 123098},
	{"BETCHA", 6, 123099},
	{"ZZAH", 4, 123100},
	{"PTCI", 4, 123101},
	{"MSYE", 4, 123102},
	{"IGJO", 4, 123103},
	{"FPLO", 4, 123104},
	{"CAPB", 4, 123105},
	{"AZID", 4, 123106},
	{"RODEOS", 6, 123107},
	{"CORGAN", 6, 123108},
	{"UBLIC", 5, 123109},
	{"EXTREMAL", 8, 123110},
	{"KQED", 4, 123111},
	{"PREDATES", 8, 123112},
	{"PILLAI", 6, 123113},
	{"FFAST", 5, 123114},
	{"QIANG", 5, 123115},
	{"AGROBACTERIUM", 13, 123116},
	{"MACKLIN", 7, 123117},
	{"HERNIATED", 9, 123118},
	{"SIRTIS", 6, 123119},
	{"OBEDIENTLY", 10, 123120},
	{"CALVINISM", 9, 123121},
	{"ORDO", 4, 123122},
	{"HTPASSWD", 8, 123123},
	{"CORRIGIR", 8, 123124},
	{"UGSU", 4, 123125},
	{"CXC", 3, 123126},
	{"UROH", 4, 123127},
	{"REKU", 4, 123128},
	{"PFER", 4, 123129},
	{"NPUP", 4, 123130},
	{"METG", 4, 123131},
	{"LKBY", 4, 123132},
	{"KELH", 4, 123133},
	{"EBIU", 4, 123134},
	{"DUPK", 4, 123135},
	{"CHYM", 4, 123136},
	{"AAUG", 4, 123137},
	{"RIMA", 4, 123138},
	{"BICKFORD", 8, 123139},
	{"MARINATE", 8, 123140},
	{"VIVACE", 6, 123141},
	{"PUSHKAR", 7, 123142},
	{"STROMBERG", 9, 123143},
	{"RUTHENIUM", 9, 123144},
	{"MALS", 4, 123145},
	{"SORRELL", 7, 123146},
	{"MILKED", 6, 123147},
	{"HERNAN", 6, 123148},
	{"SKYROCKETED", 11, 123149},
	{"HELIER", 6, 123150},
	{"VESUVIUS", 8, 123151},
	{"EARTHWORMS", 10, 123152},
	{"DOUCET", 6, 123153},
	{"KAMEEZ", 6, 123154},
	{"YAOR", 4, 123155},
	{"WVID", 4, 123156},
	{"WBOS", 4, 123157},
	{"MNEG", 4, 123158},
	{"LUMH", 4, 123159},
	{"ALMM", 4, 123160},
	{"FERROELECTRIC", 13, 123161},
	{"YCEN", 4, 123162},
	{"DISEMBODIED", 11, 123163},
	{"GRATTAN", 7, 123164},
	{"AYLMER", 6, 123165},
	{"PLAYWRITING", 11, 123166},
	{"SOPER", 5, 123167},
	{"PAREDES", 7, 123168},
	{"HIPPODROME", 10, 123169},
	{"GRAPHER", 7, 123170},
	{"MCCOOL", 6, 123171},
	{"SCOFF", 5, 123172},
	{"KOZAK", 5, 123173},
	{"PALEOLITHIC", 11, 123174},
	{"PRENOTAZIONE", 12, 123175},
	{"CONFIDANT", 9, 123176},
	{"DISPARAGING", 11, 123177},
	{"LLANGOLLEN", 10, 123178},
	{"OODLE", 5, 123179},
	{"MILILANI", 8, 123180},
	{"NIMOY", 5, 123181},
	{"IMPOLITE", 8, 123182},
	{"ARTHURS", 7, 123183},
	{"STOVETOP", 8, 123184},
	{"VSWE", 4, 123185},
	{"UKHI", 4, 123186},
	{"OJAK", 4, 123187},
	{"AUCL", 4, 123188},
	{"NARCISO", 7, 123189},
	{"STATER", 6, 123190},
	{"HORMEL", 6, 123191},
	{"DISCOGRAPHIES", 13, 123192},
	{"ERGOPHARM", 9, 123193},
	{"BATAILLE", 8, 123194},
	{"CHARAT", 6, 123195},
	{"HASLETT", 7, 123196},
	{"JXTA", 4, 123197},
	{"FISHPOND", 8, 123198},
	{"SKYNET", 6, 123199},
	{"NOVIDADES", 9, 123200},
	{"DOMINE", 6, 123201},
	{"HITCHHIKING", 11, 123202},
	{"HARDROCK", 8, 123203},
	{"ENCHILADA", 9, 123204},
	{"MICHIE", 6, 123205},
	{"WCHAR", 5, 123206},
	{"TERRIE", 6, 123207},
	{"WGOD", 4, 123208},
	{"KOGL", 4, 123209},
	{"EROJ", 4, 123210},
	{"DOAV", 4, 123211},
	{"REVIVALS", 8, 123212},
	{"SLUICE", 6, 123213},
	{"KRISS", 5, 123214},
	{"RUNDLE", 6, 123215},
	{"FORFAR", 6, 123216},
	{"EADES", 5, 123217},
	{"MASER", 5, 123218},
	{"COMPLETERS", 10, 123219},
	{"DARKE", 5, 123220},
	{"MOTORES", 7, 123221},
	{"IRRIGATE", 8, 123222},
	{"MUSKY", 5, 123223},
	{"LUGOSI", 6, 123224},
	{"MANGOES", 7, 123225},
	{"ACEVEDO", 7, 123226},
	{"RUNNABLE", 8, 123227},
	{"WHISTLED", 8, 123228},
	{"PINSON", 6, 123229},
	{"MCCARRAN", 8, 123230},
	{"WEXI", 4, 123231},
	{"VAPP", 4, 123232},
	{"UEEL", 4, 123233},
	{"TBIC", 4, 123234},
	{"OLNM", 4, 123235},
	{"LJEF", 4, 123236},
	{"LFKI", 4, 123237},
	{"JIGG", 4, 123238},
	{"ICONOS", 6, 123239},
	{"WORKOPOLIS", 10, 123240},
	{"WAKEBOARDS", 10, 123241},
	{"RIVERLAND", 9, 123242},
	{"IMMUNOBLOTTING", 14, 123243},
	{"FUROR", 5, 123244},
	{"AGGREGATIONS", 12, 123245},
	{"TOMER", 5, 123246},
	{"LANCING", 7, 123247},
	{"FRANZEN", 7, 123248},
	{"EUISMOD", 7, 123249},
	{"ULP", 3, 123250},
	{"GIOIA", 5, 123251},
	{"WACOAL", 6, 123252},
	{"MATTHIEU", 8, 123253},
	{"GRUBBS", 6, 123254},
	{"METALIC", 7, 123255},
	{"SHAADI", 6, 123256},
	{"LOVEHONEY", 9, 123257},
	{"AUSTRIANS", 9, 123258},
	{"YLDQ", 4, 123259},
	{"OBFR", 4, 123260},
	{"KBOW", 4, 123261},
	{"JETL", 4, 123262},
	{"IFCL", 4, 123263},
	{"ETZL", 4, 123264},
	{"EGMC", 4, 123265},
	{"DNAF", 4, 123266},
	{"CIEV", 4, 123267},
	{"BMAK", 4, 123268},
	{"ANNEMARIE", 9, 123269},
	{"FML", 3, 123270},
	{"CRAVES", 6, 123271},
	{"TELEPORTATION", 13, 123272},
	{"GLADWIN", 7, 123273},
	{"ARBITRATIONS", 12, 123274},
	{"DAINTREE", 8, 123275},
	{"SOIREE", 6, 123276},
	{"SMARTHOME", 9, 123277},
	{"BHAVAN", 6, 123278},
	{"MULTITECH", 9, 123279},
	{"TROUVER", 7, 123280},
	{"DELSEY", 6, 123281},
	{"GRIGSBY", 7, 123282},
	{"MANNITOL", 8, 123283},
	{"ENSLAVE", 7, 123284},
	{"DIMANCHE", 8, 123285},
	{"CREDITWORTHINESS", 16, 123286},
	{"IBRD", 4, 123287},
	{"SUMMERSIDE", 10, 123288},
	{"XONF", 4, 123289},
	{"PCCO", 4, 123290},
	{"NKHU", 4, 123291},
	{"MMAU", 4, 123292},
	{"KVEN", 4, 123293},
	{"KULE", 4, 123294},
	{"KSJA", 4, 123295},
	{"IRAZ", 4, 123296},
	{"HLYG", 4, 123297},
	{"GPED", 4, 123298},
	{"GBAK", 4, 123299},
	{"PEKINGESE", 9, 123300},
	{"UNNERVING", 9, 123301},
	{"JOSEY", 5, 123302},
	{"HYPERLITE", 9, 123303},
	{"FAROUK", 6, 123304},
	{"PATMOS", 6, 123305},
	{"GRIMLY", 6, 123306},
	{"PYROPHOSPHATE", 13, 123307},
	{"HERMISTON", 9, 123308},
	{"ESPOUSE", 7, 123309},
	{"HOUCK", 5, 123310},
	{"MARANA", 6, 123311},
	{"OOMPH", 5, 123312},
	{"MDW", 3, 123313},
	{"MOBILITYGURU", 12, 123314},
	{"PACIFICARE", 10, 123315},
	{"WATCHABLE", 9, 123316},
	{"DETERIORATES", 12, 123317},
	{"LLOYDMINSTER", 12, 123318},
	{"TORTELLINI", 10, 123319},
	{"MAIMONIDES", 10, 123320},
	{"SUBHEADINGS", 11, 123321},
	{"YGAP", 4, 123322},
	{"YCET", 4, 123323},
	{"WAMB", 4, 123324},
	{"URUR", 4, 123325},
	{"UPAA", 4, 123326},
	{"RGUR", 4, 123327},
	{"MRRU", 4, 123328},
	{"MNOC", 4, 123329},
	{"KGLB", 4, 123330},
	{"GYBO", 4, 123331},
	{"EEPK", 4, 123332},
	{"CASKS", 5, 123333},
	{"FOLGER", 6, 123334},
	{"TROPONIN", 8, 123335},
	{"COGITO", 6, 123336},
	{"CONJOINED", 9, 123337},
	{"CABLED", 6, 123338},
	{"MUCHOS", 6, 123339},
	{"VDOT", 4, 123340},
	{"INCALL", 6, 123341},
	{"TICKETED", 8, 123342},
	{"LIGHTENED", 9, 123343},
	{"SPONGY", 6, 123344},
	{"COMMACK", 7, 123345},
	{"ALBUS", 5, 123346},
	{"BOBBLEHEADS", 11, 123347},
	{"VERNER", 6, 123348},
	{"BUSCEMI", 7, 123349},
	{"RAROTONGA", 9, 123350},
	{"GALVANIZING", 11, 123351},
	{"MACLACHLAN", 10, 123352},
	{"ABRACADABRA", 11, 123353},
	{"MONGER", 6, 123354},
	{"STORER", 6, 123355},
	{"SPECIOUS", 8, 123356},
	{"FRISGO", 6, 123357},
	{"LUNARPAGES", 10, 123358},
	{"LOCKERBIE", 9, 123359},
	{"TALEBAN", 7, 123360},
	{"THRESHING", 9, 123361},
	{"RATCHETING", 10, 123362},
	{"KODANSHA", 8, 123363},
	{"RVUL", 4, 123364},
	{"NURU", 4, 123365},
	{"MIRN", 4, 123366},
	{"CAAW", 4, 123367},
	{"BICT", 4, 123368},
	{"BJOERN", 6, 123369},
	{"LASCO", 5, 123370},
	{"ZOLL", 4, 123371},
	{"BLUEARROW", 9, 123372},
	{"PRUDHOE", 7, 123373},
	{"INFLICTION", 10, 123374},
	{"CONAGRA", 7, 123375},
	{"HETHERINGTON", 12, 123376},
	{"RICKER", 6, 123377},
	{"MATISYAHU", 9, 123378},
	{"DISENCHANTED", 12, 123379},
	{"WCHA", 4, 123380},
	{"SCREWBALL", 9, 123381},
	{"LANGA", 5, 123382},
	{"FREDERICA", 9, 123383},
	{"CRAK", 4, 123384},
	{"NREL", 4, 123385},
	{"NAMEPLATES", 10, 123386},
	{"BELK", 4, 123387},
	{"BAMBA", 5, 123388},
	{"PLACECARD", 9, 123389},
	{"ZOEY", 4, 123390},
	{"INTERVENOR", 10, 123391},
	{"STRANGLEHOLD", 12, 123392},
	{"PFEFFER", 7, 123393},
	{"CENTERFIELD", 11, 123394},
	{"WPLE", 4, 123395},
	{"VARU", 4, 123396},
	{"SYSP", 4, 123397},
	{"PSCU", 4, 123398},
	{"LMEY", 4, 123399},
	{"IOMU", 4, 123400},
	{"HUIZ", 4, 123401},
	{"FCIG", 4, 123402},
	{"EFPO", 4, 123403},
	{"AWIM", 4, 123404},
	{"NEWLETTER", 9, 123405},
	{"CCSP", 4, 123406},
	{"ENTRANCED", 9, 123407},
	{"RHEINLAND", 9, 123408},
	{"DIPLOMATE", 9, 123409},
	{"SAMAR", 5, 123410},
	{"LIBRAIRIE", 9, 123411},
	{"ZVM", 3, 123412},
	{"YZJ", 3, 123413},
	{"XWX", 3, 123414},
	{"XGX", 3, 123415},
	{"XGF", 3, 123416},
	{"RXZ", 3, 123417},
	{"QPW", 3, 123418},
	{"PZZ", 3, 123419},
	{"KPZ", 3, 123420},
	{"FVZ", 3, 123421},
	{"ALSTOM", 6, 123422},
	{"MULTISCALE", 10, 123423},
	{"ENDANGERMENT", 12, 123424},
	{"GROSE", 5, 123425},
	{"EMBOLIZATION", 12, 123426},
	{"BICI", 4, 123427},
	{"WALLOWA", 7, 123428},
	{"MEDICAGO", 8, 123429},
	{"IQALUIT", 7, 123430},
	{"ADENOMAS", 8, 123431},
	{"BUSHFIRES", 9, 123432},
	{"SUMPTER", 7, 123433},
	{"CAMPMOR", 7, 123434},
	{"BEFOR", 5, 123435},
	{"DYNAMIQUE", 9, 123436},
	{"NOMINATES", 9, 123437},
	{"AIELLO", 6, 123438},
	{"PINDER", 6, 123439},
	{"DEPRIVES", 8, 123440},
	{"YOKA", 4, 123441},
	{"YNFL", 4, 123442},
	{"REXS", 4, 123443},
	{"OYDG", 4, 123444},
	{"NVOG", 4, 123445},
	{"NKOC", 4, 123446},
	{"LAMN", 4, 123447},
	{"KOSW", 4, 123448},
	{"FLTH", 4, 123449},
	{"BUEH", 4, 123450},
	{"VIVICAM", 7, 123451},
	{"WADER", 5, 123452},
	{"RENAMER", 7, 123453},
	{"KASIA", 5, 123454},
	{"SCIMITAR", 8, 123455},
	{"LITIGANT", 8, 123456},
	{"BEAUJOLAIS", 10, 123457},
	{"BEEKMAN", 7, 123458},
	{"MLR", 3, 123459},
	{"MILLERSBURG", 11, 123460},
	{"HOLZ", 4, 123461},
	{"CHEMNITZ", 8, 123462},
	{"THIOREDOXIN", 11, 123463},
	{"UNINTERESTED", 12, 123464},
	{"SIXES", 5, 123465},
	{"LETTERHEADS", 11, 123466},
	{"CONNECTIONIST", 13, 123467},
	{"XEDG", 4, 123468},
	{"VORL", 4, 123469},
	{"UIZA", 4, 123470},
	{"UBIE", 4, 123471},
	{"PTDO", 4, 123472},
	{"PDIA", 4, 123473},
	{"MORV", 4, 123474},
	{"LHOF", 4, 123475},
	{"EDYG", 4, 123476},
	{"CONCEPTUALIZE", 13, 123477},
	{"CAVALCADE", 9, 123478},
	{"ACCESSORIE", 10, 123479},
	{"IMPROVISATIONS", 14, 123480},
	{"HEMATOCRIT", 10, 123481},
	{"MARCHBEIN", 9, 123482},
	{"EQUALISER", 9, 123483},
	{"ARTHROSCOPY", 11, 123484},
	{"ADULATION", 9, 123485},
	{"VIGNAUD", 7, 123486},
	{"CHAMORRO", 8, 123487},
	{"LOITERING", 9, 123488},
	{"CONTINU", 7, 123489},
	{"SUBAREA", 7, 123490},
	{"DASTARDLY", 9, 123491},
	{"PONTOTOC", 8, 123492},
	{"FISHBONE", 8, 123493},
	{"CELEBRITYS", 10, 123494},
	{"DIRHAMS", 7, 123495},
	{"BITTERS", 7, 123496},
	{"POWERMATE", 9, 123497},
	{"RAINTREE", 8, 123498},
	{"WYSOKIE", 7, 123499},
	{"DELMARVA", 8, 123500},
	{"UBEM", 4, 123501},
	{"RGSP", 4, 123502},
	{"RABF", 4, 123503},
	{"NCIG", 4, 123504},
	{"LUOU", 4, 123505},
	{"LPHH", 4, 123506},
	{"HKAL", 4, 123507},
	{"FGIF", 4, 123508},
	{"BTFO", 4, 123509},
	{"AKSR", 4, 123510},
	{"UNWITTING", 9, 123511},
	{"VALASCO", 7, 123512},
	{"FAWLTY", 6, 123513},
	{"EXPIRATORY", 10, 123514},
	{"CROMARTY", 8, 123515},
	{"LUDOVIC", 7, 123516},
	{"MCCLOGHRIE", 10, 123517},
	{"ACKERMANN", 9, 123518},
	{"TALBERT", 7, 123519},
	{"THIBODAUX", 9, 123520},
	{"CORPORATIO", 10, 123521},
	{"CONCERTI", 8, 123522},
	{"TREM", 4, 123523},
	{"AVARICE", 7, 123524},
	{"DECOMPRESSOR", 12, 123525},
	{"AJACCIO", 7, 123526},
	{"SANDRINGHAM", 11, 123527},
	{"CUDAHY", 6, 123528},
	{"TOWNER", 6, 123529},
	{"SANGEN", 6, 123530},
	{"BUTCHERED", 9, 123531},
	{"POINTEDLY", 9, 123532},
	{"APOCRYPHA", 9, 123533},
	{"MOYNE", 5, 123534},
	{"YUKO", 4, 123535},
	{"TAMIAMI", 7, 123536},
	{"OUVERTURE", 9, 123537},
	{"YEEB", 4, 123538},
	{"OMKU", 4, 123539},
	{"EWEJ", 4, 123540},
	{"BIVO", 4, 123541},
	{"HANUMAN", 7, 123542},
	{"TIMONIUM", 8, 123543},
	{"MACHTS", 6, 123544},
	{"MIMETYPE", 8, 123545},
	{"RUSTLE", 6, 123546},
	{"EXCITABLE", 9, 123547},
	{"AVENTURAS", 9, 123548},
	{"JETPRINTER", 10, 123549},
	{"INTERCEPTORS", 12, 123550},
	{"WORRELL", 7, 123551},
	{"KUNNEN", 6, 123552},
	{"SIMTEL", 6, 123553},
	{"HERMANOS", 8, 123554},
	{"CERTTUTOR", 9, 123555},
	{"BTVINFO", 7, 123556},
	{"EXCITER", 7, 123557},
	{"YMYP", 4, 123558},
	{"YDUK", 4, 123559},
	{"VACE", 4, 123560},
	{"UKFO", 4, 123561},
	{"PRUI", 4, 123562},
	{"LSSW", 4, 123563},
	{"IGRU", 4, 123564},
	{"HABC", 4, 123565},
	{"FBII", 4, 123566},
	{"ERNZ", 4, 123567},
	{"DLUG", 4, 123568},
	{"COXW", 4, 123569},
	{"BARRHEAD", 8, 123570},
	{"LIBGLADE", 8, 123571},
	{"BOIRON", 6, 123572},
	{"AUDIOLOGIST", 11, 123573},
	{"YOUNTVILLE", 10, 123574},
	{"VARINA", 6, 123575},
	{"MALTBY", 6, 123576},
	{"FLEXO", 5, 123577},
	{"AIRGUN", 6, 123578},
	{"WOZNIAK", 7, 123579},
	{"TEVATRON", 8, 123580},
	{"FORUMUL", 7, 123581},
	{"CAILLOU", 7, 123582},
	{"KBP", 3, 123583},
	{"FAHD", 4, 123584},
	{"FLEISCHMANN", 11, 123585},
	{"LEKI", 4, 123586},
	{"SCOTTSVILLE", 11, 123587},
	{"WWOO", 4, 123588},
	{"WLSI", 4, 123589},
	{"PWES", 4, 123590},
	{"OYUA", 4, 123591},
	{"OPUE", 4, 123592},
	{"NULI", 4, 123593},
	{"KMIK", 4, 123594},
	{"JOYN", 4, 123595},
	{"GMTO", 4, 123596},
	{"DYOP", 4, 123597},
	{"DBAU", 4, 123598},
	{"AUKA", 4, 123599},
	{"AKIY", 4, 123600},
	{"THRIPS", 6, 123601},
	{"PERRYSBURG", 10, 123602},
	{"PAWP", 4, 123603},
	{"PERSONHOOD", 10, 123604},
	{"ALLUDING", 8, 123605},
	{"EGIFT", 5, 123606},
	{"AUTOIMMUNITY", 12, 123607},
	{"SLUGGING", 8, 123608},
	{"SRIXON", 6, 123609},
	{"TICULAR", 7, 123610},
	{"SEMAPHORES", 10, 123611},
	{"SUNRISES", 8, 123612},
	{"CARNET", 6, 123613},
	{"FRERE", 5, 123614},
	{"FUGIT", 5, 123615},
	{"KERASTASE", 9, 123616},
	{"BOREHOLES", 9, 123617},
	{"FDG", 3, 123618},
	{"RANCHERO", 8, 123619},
	{"VELDE", 5, 123620},
	{"SUBFIELDS", 9, 123621},
	{"MYB", 3, 123622},
	{"STILA", 5, 123623},
	{"CHAUFFEURED", 11, 123624},
	{"PILCHER", 7, 123625},
	{"PLANETLAB", 9, 123626},
	{"WFIV", 4, 123627},
	{"UNMU", 4, 123628},
	{"UKGO", 4, 123629},
	{"SUEG", 4, 123630},
	{"RKOC", 4, 123631},
	{"REZC", 4, 123632},
	{"MODR", 4, 123633},
	{"MNOP", 4, 123634},
	{"KOGE", 4, 123635},
	{"IRIW", 4, 123636},
	{"IBBA", 4, 123637},
	{"GYEO", 4, 123638},
	{"FLFO", 4, 123639},
	{"DBUZ", 4, 123640},
	{"VCF", 3, 123641},
	{"BEZELS", 6, 123642},
	{"ELORA", 5, 123643},
	{"DIRTBIKE", 8, 123644},
	{"INSIPID", 7, 123645},
	{"BIASING", 7, 123646},
	{"SORTABLE", 8, 123647},
	{"GAURAV", 6, 123648},
	{"ILINK", 5, 123649},
	{"SARGEANT", 8, 123650},
	{"RESERVIST", 9, 123651},
	{"DISTRITO", 8, 123652},
	{"DEWBERRY", 8, 123653},
	{"UNFATHOMABLE", 12, 123654},
	{"INGMAR", 6, 123655},
	{"MANNERISMS", 10, 123656},
	{"PARCS", 5, 123657},
	{"STATHAM", 7, 123658},
	{"COMMONALITIES", 13, 123659},
	{"HOLIEST", 7, 123660},
	{"THINKEXIST", 10, 123661},
	{"ARBRE", 5, 123662},
	{"ZHAV", 4, 123663},
	{"XOFR", 4, 123664},
	{"UHLE", 4, 123665},
	{"KITL", 4, 123666},
	{"KGAL", 4, 123667},
	{"HEVL", 4, 123668},
	{"EIDP", 4, 123669},
	{"AZYC", 4, 123670},
	{"AKUI", 4, 123671},
	{"EMPIRICISM", 10, 123672},
	{"SEKUNDE", 7, 123673},
	{"MCINERNEY", 9, 123674},
	{"DSLAM", 5, 123675},
	{"RTECS", 5, 123676},
	{"SEAGAL", 6, 123677},
	{"EFFEMINATE", 10, 123678},
	{"CLAUSTROPHOBIC", 14, 123679},
	{"VAINLY", 6, 123680},
	{"NEMECHEK", 8, 123681},
	{"COMPOTE", 7, 123682},
	{"RICKENBACKER", 12, 123683},
	{"BEARSHARE", 9, 123684},
	{"VISTAPRINT", 10, 123685},
	{"SECTIONALS", 10, 123686},
	{"MITSUBA", 7, 123687},
	{"RCTS", 4, 123688},
	{"RILO", 4, 123689},
	{"NUMOCY", 6, 123690},
	{"TRAKL", 5, 123691},
	{"UNGAR", 5, 123692},
	{"STRAYING", 8, 123693},
	{"LODGEPOLE", 9, 123694},
	{"VENEREAL", 8, 123695},
	{"OCCULTATION", 11, 123696},
	{"TIKKA", 5, 123697},
	{"MERCIFULLY", 10, 123698},
	{"STODDART", 8, 123699},
	{"NONSMOKERS", 10, 123700},
	{"MATRICULATED", 12, 123701},
	{"MUSICALI", 8, 123702},
	{"PDOU", 4, 123703},
	{"OCHB", 4, 123704},
	{"LKYR", 4, 123705},
	{"LFBO", 4, 123706},
	{"KNAV", 4, 123707},
	{"MELALEUCA", 9, 123708},
	{"BLATT", 5, 123709},
	{"CARDMAKING", 10, 123710},
	{"PANSIES", 7, 123711},
	{"GREENACRES", 10, 123712},
	{"TROLLTECH", 9, 123713},
	{"ACCEDED", 7, 123714},
	{"SALADO", 6, 123715},
	{"DREGS", 5, 123716},
	{"TRUETIP", 7, 123717},
	{"TRAINEESHIPS", 12, 123718},
	{"BALDACCI", 8, 123719},
	{"OBSCURES", 8, 123720},
	{"STONEHILL", 9, 123721},
	{"SCHOOLCRAFT", 11, 123722},
	{"MILLAGE", 7, 123723},
	{"GACKT", 5, 123724},
	{"MAGNIFICAT", 10, 123725},
	{"ANNAPURNA", 9, 123726},
	{"KOOKABURRA", 10, 123727},
	{"FRANCOPHONES", 12, 123728},
	{"NEKR", 4, 123729},
	{"NDPP", 4, 123730},
	{"NDBS", 4, 123731},
	{"FEGR", 4, 123732},
	{"EZEW", 4, 123733},
	{"EXAP", 4, 123734},
	{"DIMB", 4, 123735},
	{"APDI", 4, 123736},
	{"ALFN", 4, 123737},
	{"PLUMBWORLD", 10, 123738},
	{"WINNSBORO", 9, 123739},
	{"BOGOFILTER", 10, 123740},
	{"DELTON", 6, 123741},
	{"FREIND", 6, 123742},
	{"BUPRENORPHINE", 13, 123743},
	{"MILLICENT", 9, 123744},
	{"KRISHNAMURTI", 12, 123745},
	{"SALEEM", 6, 123746},
	{"MONOFILAMENT", 12, 123747},
	{"PROCESSUS", 9, 123748},
	{"FORESAW", 7, 123749},
	{"DOUCETTE", 8, 123750},
	{"BEEKEEPERS", 10, 123751},
	{"FLUIDIZED", 9, 123752},
	{"TELECOMMS", 9, 123753},
	{"HYPOTHEEK", 9, 123754},
	{"MALICK", 6, 123755},
	{"DELERIUM", 8, 123756},
	{"BEFRIEND", 8, 123757},
	{"ANKER", 5, 123758},
	{"ROMANTICALLY", 12, 123759},
	{"MALIGN", 6, 123760},
	{"UBNO", 4, 123761},
	{"TYOK", 4, 123762},
	{"RSZA", 4, 123763},
	{"RROP", 4, 123764},
	{"RHUT", 4, 123765},
	{"PTWR", 4, 123766},
	{"OKKI", 4, 123767},
	{"NOLP", 4, 123768},
	{"LJOE", 4, 123769},
	{"KTWA", 4, 123770},
	{"JEUN", 4, 123771},
	{"IWOM", 4, 123772},
	{"GUGG", 4, 123773},
	{"EWKN", 4, 123774},
	{"GROSSETO", 8, 123775},
	{"CALCU", 5, 123776},
	{"TURNDOWN", 8, 123777},
	{"NEWSCASTS", 9, 123778},
	{"COHERENTLY", 10, 123779},
	{"ABORTIVE", 8, 123780},
	{"PORTAIL", 7, 123781},
	{"EMBARKATION", 11, 123782},
	{"VARNISHED", 9, 123783},
	{"CRONYISM", 8, 123784},
	{"ZARATHUSTRA", 11, 123785},
	{"UDDER", 5, 123786},
	{"VALENT", 6, 123787},
	{"INITIATORS", 10, 123788},
	{"HAYFEVER", 8, 123789},
	{"SALTILLO", 8, 123790},
	{"LICIOUS", 7, 123791},
	{"MOEBIUS", 7, 123792},
	{"IMAGESTATE", 10, 123793},
	{"KNOWETH", 7, 123794},
	{"ANEMONES", 8, 123795},
	{"SACRE", 5, 123796},
	{"VING", 4, 123797},
	{"UFFICIO", 7, 123798},
	{"ROSENZWEIG", 10, 123799},
	{"CANVEY", 6, 123800},
	{"TROUTMAN", 8, 123801},
	{"CHANGIN", 7, 123802},
	{"ZZES", 4, 123803},
	{"SWEU", 4, 123804},
	{"IRYB", 4, 123805},
	{"GOIF", 4, 123806},
	{"FNEL", 4, 123807},
	{"FEYS", 4, 123808},
	{"BHAJ", 4, 123809},
	{"MUGGLE", 6, 123810},
	{"USGPO", 5, 123811},
	{"NWFP", 4, 123812},
	{"ESCALATES", 9, 123813},
	{"TRUCKIN", 7, 123814},
	{"INDIEWIRE", 9, 123815},
	{"LIBERTADORES", 12, 123816},
	{"INLINED", 7, 123817},
	{"MINNELLI", 8, 123818},
	{"PILS", 4, 123819},
	{"HUNCHED", 7, 123820},
	{"BUZZED", 6, 123821},
	{"TELECON", 7, 123822},
	{"KRB", 3, 123823},
	{"ULAR", 4, 123824},
	{"UMMMM", 5, 123825},
	{"PICKETS", 7, 123826},
	{"THORNYBUSH", 10, 123827},
	{"ASTRINGENT", 10, 123828},
	{"TILMAN", 6, 123829},
	{"DOLDRUMS", 8, 123830},
	{"YNIK", 4, 123831},
	{"RLAF", 4, 123832},
	{"NUXO", 4, 123833},
	{"LOGM", 4, 123834},
	{"LOGL", 4, 123835},
	{"ESRY", 4, 123836},
	{"ESJR", 4, 123837},
	{"CLYF", 4, 123838},
	{"BDEN", 4, 123839},
	{"RECTIFYING", 10, 123840},
	{"SOOTHED", 7, 123841},
	{"FINFISH", 7, 123842},
	{"TOLERATES", 9, 123843},
	{"ANGSTROM", 8, 123844},
	{"PREMEDITATED", 12, 123845},
	{"NOMATICA", 8, 123846},
	{"DECOMPOSITIONS", 14, 123847},
	{"TOPICALLY", 9, 123848},
	{"DAVI", 4, 123849},
	{"STATUSCODE", 10, 123850},
	{"FUSHIGI", 7, 123851},
	{"RADIAT", 6, 123852},
	{"CANDIDE", 7, 123853},
	{"KILIAN", 6, 123854},
	{"KILLEN", 6, 123855},
	{"TMAB", 4, 123856},
	{"RICJ", 4, 123857},
	{"OLKF", 4, 123858},
	{"OBIW", 4, 123859},
	{"GNSD", 4, 123860},
	{"BCSO", 4, 123861},
	{"NEOMYCIN", 8, 123862},
	{"REGIONE", 7, 123863},
	{"FLOURED", 7, 123864},
	{"CHERCHE", 7, 123865},
	{"UPWARDLY", 8, 123866},
	{"WALTONS", 7, 123867},
	{"TSONGA", 6, 123868},
	{"POLIOMYELITIS", 13, 123869},
	{"HILLVIEW", 8, 123870},
	{"QOLLASUYU", 9, 123871},
	{"LIVIDICT", 8, 123872},
	{"HOMELIFE", 8, 123873},
	{"AUCUNE", 6, 123874},
	{"CAMPINAS", 8, 123875},
	{"TENNISON", 8, 123876},
	{"YKAS", 4, 123877},
	{"WWAG", 4, 123878},
	{"TMWI", 4, 123879},
	{"OPYS", 4, 123880},
	{"IGAU", 4, 123881},
	{"EGGL", 4, 123882},
	{"CABD", 4, 123883},
	{"AUSG", 4, 123884},
	{"AABU", 4, 123885},
	{"ORXONOX", 7, 123886},
	{"RITMO", 5, 123887},
	{"PLOTKIN", 7, 123888},
	{"CETACEAN", 8, 123889},
	{"COLLEGEBOUND", 12, 123890},
	{"YORKTON", 7, 123891},
	{"LILBURN", 7, 123892},
	{"HERDERS", 7, 123893},
	{"WORLDVIEWS", 10, 123894},
	{"PINNER", 6, 123895},
	{"PUEBLOS", 7, 123896},
	{"BARNACLE", 8, 123897},
	{"SNEAD", 5, 123898},
	{"SWIK", 4, 123899},
	{"STORCASE", 8, 123900},
	{"EASTHAMPTON", 11, 123901},
	{"STUCKEY", 7, 123902},
	{"BROWNSTOWN", 10, 123903},
	{"YTOX", 4, 123904},
	{"WKEN", 4, 123905},
	{"UYAR", 4, 123906},
	{"ULFT", 4, 123907},
	{"TMYV", 4, 123908},
	{"TEBB", 4, 123909},
	{"MOGL", 4, 123910},
	{"FEJE", 4, 123911},
	{"FEGE", 4, 123912},
	{"FALW", 4, 123913},
	{"EBUO", 4, 123914},
	{"DUTO", 4, 123915},
	{"AOUR", 4, 123916},
	{"ABOK", 4, 123917},
	{"DISCOTHEQUE", 11, 123918},
	{"EXTREMADURA", 11, 123919},
	{"PROTEINURIA", 11, 123920},
	{"DIANETICS", 9, 123921},
	{"WESLACO", 7, 123922},
	{"VILLARD", 7, 123923},
	{"GROZNY", 6, 123924},
	{"TAMAKI", 6, 123925},
	{"SENTIMENTALITY", 14, 123926},
	{"LOCALTIME", 9, 123927},
	{"KEWAUNEE", 8, 123928},
	{"TENABLE", 7, 123929},
	{"CAPELLI", 7, 123930},
	{"FANEUIL", 7, 123931},
	{"JUMBLED", 7, 123932},
	{"GARSON", 6, 123933},
	{"SPEX", 4, 123934},
	{"DINGBATS", 8, 123935},
	{"STEFFI", 6, 123936},
	{"TRIUMPHANTLY", 12, 123937},
	{"PEMBINA", 7, 123938},
	{"DEVILDRIVER", 11, 123939},
	{"DEWAYNE", 7, 123940},
	{"XRD", 3, 123941},
	{"YIDA", 4, 123942},
	{"SVOY", 4, 123943},
	{"RSYB", 4, 123944},
	{"NSLY", 4, 123945},
	{"NFAY", 4, 123946},
	{"IXRA", 4, 123947},
	{"EMOJ", 4, 123948},
	{"DOXS", 4, 123949},
	{"LEVA", 4, 123950},
	{"APCO", 4, 123951},
	{"EXTREMLY", 8, 123952},
	{"DEIONIZED", 9, 123953},
	{"STONEHOUSE", 10, 123954},
	{"VERGESSEN", 9, 123955},
	{"TRADI", 5, 123956},
	{"SCOLDED", 7, 123957},
	{"OUGHTA", 6, 123958},
	{"QQQ", 3, 123959},
	{"FETTERS", 7, 123960},
	{"TEXTAMERICA", 11, 123961},
	{"LEVERKUSEN", 10, 123962},
	{"KFFL", 4, 123963},
	{"VULGARITY", 9, 123964},
	{"TOKAMAK", 7, 123965},
	{"TRENDSETTER", 11, 123966},
	{"EPOQUE", 6, 123967},
	{"BOONEVILLE", 10, 123968},
	{"UXCO", 4, 123969},
	{"SIGR", 4, 123970},
	{"LRAS", 4, 123971},
	{"CSCU", 4, 123972},
	{"BALV", 4, 123973},
	{"AKUZ", 4, 123974},
	{"MAGASIN", 7, 123975},
	{"PERPETUATION", 12, 123976},
	{"TAFEL", 5, 123977},
	{"INDOLE", 6, 123978},
	{"EXPLAINATION", 12, 123979},
	{"OBSERVATOIRE", 12, 123980},
	{"WEBLEFTBAR", 10, 123981},
	{"MADACY", 6, 123982},
	{"PLINY", 5, 123983},
	{"HUENEME", 7, 123984},
	{"DOLPH", 5, 123985},
	{"ROMPE", 5, 123986},
	{"CARISSA", 7, 123987},
	{"SHIITAKE", 8, 123988},
	{"EGERTON", 7, 123989},
	{"SEWED", 5, 123990},
	{"SUCCULENTS", 10, 123991},
	{"JUBILANT", 8, 123992},
	{"YISQ", 4, 123993},
	{"UDSC", 4, 123994},
	{"RDUI", 4, 123995},
	{"PEZI", 4, 123996},
	{"FLHA", 4, 123997},
	{"EZSP", 4, 123998},
	{"ENGELHARDT", 10, 123999},
	{"GENCY", 5, 124000},
	{"SANGAMON", 8, 124001},
	{"WHEATUS", 7, 124002},
	{"OHARA", 5, 124003},
	{"CONTINUO", 8, 124004},
	{"ELUTED", 6, 124005},
	{"COSTANZA", 8, 124006},
	{"TUSHY", 5, 124007},
	{"WIESE", 5, 124008},
	{"CALORIMETRY", 11, 124009},
	{"IMPOUNDMENTS", 12, 124010},
	{"HIBBERT", 7, 124011},
	{"CASHEL", 6, 124012},
	{"ULTRAMAN", 8, 124013},
	{"SAMADHI", 7, 124014},
	{"CGP", 3, 124015},
	{"CROFTS", 6, 124016},
	{"BUMSKONTAKTE", 12, 124017},
	{"WELCHE", 6, 124018},
	{"READYMADE", 9, 124019},
	{"MUTAGENICITY", 12, 124020},
	{"PENALISED", 9, 124021},
	{"SILESIA", 7, 124022},
	{"UNCORKED", 8, 124023},
	{"GAMERTAG", 8, 124024},
	{"WITU", 4, 124025},
	{"RLAA", 4, 124026},
	{"RDTJ", 4, 124027},
	{"IAFU", 4, 124028},
	{"GERZ", 4, 124029},
	{"EKCL", 4, 124030},
	{"AXFI", 4, 124031},
	{"MYISAM", 6, 124032},
	{"AUDITORIUMS", 11, 124033},
	{"KIMBROUGH", 9, 124034},
	{"TIPSTER", 7, 124035},
	{"MONOPOD", 7, 124036},
	{"DISCERNABLE", 11, 124037},
	{"SEEKONK", 7, 124038},
	{"AMPUTATED", 9, 124039},
	{"MENTONE", 7, 124040},
	{"PCTV", 4, 124041},
	{"ALOYSIUS", 8, 124042},
	{"REAPPEARS", 9, 124043},
	{"XXLARGE", 7, 124044},
	{"BACKGROUNDERS", 13, 124045},
	{"SPONDING", 8, 124046},
	{"JIVAGO", 6, 124047},
	{"HERBALISM", 9, 124048},
	{"BERTELSMANN", 11, 124049},
	{"RUBEL", 5, 124050},
	{"TIKRIT", 6, 124051},
	{"ISREAL", 6, 124052},
	{"WHITMIRE", 8, 124053},
	{"TERCEL", 6, 124054},
	{"PRESCIPTION", 11, 124055},
	{"HYDROGENATION", 13, 124056},
	{"FLOETRY", 7, 124057},
	{"WAXM", 4, 124058},
	{"PGAI", 4, 124059},
	{"OKAU", 4, 124060},
	{"KUHA", 4, 124061},
	{"IDIP", 4, 124062},
	{"HBYN", 4, 124063},
	{"ABCR", 4, 124064},
	{"MACTECH", 7, 124065},
	{"ANIMALI", 7, 124066},
	{"LAPLINK", 7, 124067},
	{"INTELISTAF", 10, 124068},
	{"RAVNICA", 7, 124069},
	{"AVAILIBLE", 9, 124070},
	{"IRONTON", 7, 124071},
	{"ENQUIRING", 9, 124072},
	{"CURIOUSITY", 10, 124073},
	{"SECTIONED", 9, 124074},
	{"MASHA", 5, 124075},
	{"DILUENT", 7, 124076},
	{"GNUGO", 5, 124077},
	{"REDDEN", 6, 124078},
	{"PINATAS", 7, 124079},
	{"FIZZLE", 6, 124080},
	{"MEDITERRANEO", 12, 124081},
	{"MINOXIDIL", 9, 124082},
	{"INCONTRO", 8, 124083},
	{"UPM", 3, 124084},
	{"KREIS", 5, 124085},
	{"FACCIA", 6, 124086},
	{"JAYCO", 5, 124087},
	{"SIMPLIFICATIONS", 15, 124088},
	{"BRIDGNORTH", 10, 124089},
	{"SOBBED", 6, 124090},
	{"MILLAN", 6, 124091},
	{"SBEB", 4, 124092},
	{"OGIB", 4, 124093},
	{"NBEJ", 4, 124094},
	{"NAYL", 4, 124095},
	{"GPIA", 4, 124096},
	{"DAAG", 4, 124097},
	{"AWSK", 4, 124098},
	{"NEUROPEPTIDE", 12, 124099},
	{"LLORET", 6, 124100},
	{"OMNIUM", 6, 124101},
	{"SYPHON", 6, 124102},
	{"FUNKTION", 8, 124103},
	{"MCGINTY", 7, 124104},
	{"VIZITATI", 8, 124105},
	{"SUCCESSFULL", 11, 124106},
	{"MOHLER", 6, 124107},
	{"GRIMOIRE", 8, 124108},
	{"COPIE", 5, 124109},
	{"FORFEITURES", 11, 124110},
	{"SNUGGLED", 8, 124111},
	{"SUREST", 6, 124112},
	{"SAGRADA", 7, 124113},
	{"MONTOUR", 7, 124114},
	{"ADVAIR", 6, 124115},
	{"GREENDALE", 9, 124116},
	{"BRIBED", 6, 124117},
	{"BOPPER", 6, 124118},
	{"HALTOM", 6, 124119},
	{"SUPPRESSANTS", 12, 124120},
	{"WSEM", 4, 124121},
	{"OKFU", 4, 124122},
	{"MRDI", 4, 124123},
	{"LTZW", 4, 124124},
	{"IBEP", 4, 124125},
	{"GMSA", 4, 124126},
	{"FAUB", 4, 124127},
	{"EILY", 4, 124128},
	{"EBPM", 4, 124129},
	{"CYDU", 4, 124130},
	{"UNAM", 4, 124131},
	{"ABSTR", 5, 124132},
	{"PAMALA", 6, 124133},
	{"PELTON", 6, 124134},
	{"SOFTENERS", 9, 124135},
	{"HEADSTART", 9, 124136},
	{"DIDDLE", 6, 124137},
	{"SALOPE", 6, 124138},
	{"IBERVILLE", 9, 124139},
	{"BREGUET", 7, 124140},
	{"KIANA", 5, 124141},
	{"MATCHSTICK", 10, 124142},
	{"ALARMINGLY", 10, 124143},
	{"CATHLEEN", 8, 124144},
	{"SHOSHANA", 8, 124145},
	{"MRPROGRESSIVE", 13, 124146},
	{"HOAGLAND", 8, 124147},
	{"MALTS", 5, 124148},
	{"BRIGHTS", 7, 124149},
	{"ADRODDIAD", 9, 124150},
	{"TRANSPERSONAL", 13, 124151},
	{"KOSTEN", 6, 124152},
	{"BLOODLESS", 9, 124153},
	{"LEAWOOD", 7, 124154},
	{"BASLE", 5, 124155},
	{"YOKL", 4, 124156},
	{"WITG", 4, 124157},
	{"TMCL", 4, 124158},
	{"RYEU", 4, 124159},
	{"OUOV", 4, 124160},
	{"NLUD", 4, 124161},
	{"MIEU", 4, 124162},
	{"IKOD", 4, 124163},
	{"DULM", 4, 124164},
	{"SIGURD", 6, 124165},
	{"WEFT", 4, 124166},
	{"SUNSUN", 6, 124167},
	{"SCHWIMMER", 9, 124168},
	{"SCAMMER", 7, 124169},
	{"QOBJECT", 7, 124170},
	{"DAMIANO", 7, 124171},
	{"OBLITERATE", 10, 124172},
	{"DEFINITIONAL", 12, 124173},
	{"SABRA", 5, 124174},
	{"ELIDEL", 6, 124175},
	{"PORTALE", 7, 124176},
	{"AMBA", 4, 124177},
	{"STAVROS", 7, 124178},
	{"KHRUSHCHEV", 10, 124179},
	{"ROYKSOPP", 8, 124180},
	{"ELROD", 5, 124181},
	{"ITRADER", 7, 124182},
	{"AYESHA", 6, 124183},
	{"CELTA", 5, 124184},
	{"DORT", 4, 124185},
	{"CUENTOS", 7, 124186},
	{"FLUXBOX", 7, 124187},
	{"ZZON", 4, 124188},
	{"TUDS", 4, 124189},
	{"TPOD", 4, 124190},
	{"MDIG", 4, 124191},
	{"LYAJ", 4, 124192},
	{"LKPA", 4, 124193},
	{"ISUZ", 4, 124194},
	{"ECME", 4, 124195},
	{"DYCI", 4, 124196},
	{"AUNW", 4, 124197},
	{"DERN", 4, 124198},
	{"PERRON", 6, 124199},
	{"PESTLE", 6, 124200},
	{"LANGERHANS", 10, 124201},
	{"FAIRBAIRN", 9, 124202},
	{"FALSITY", 7, 124203},
	{"TIMESPLITTERS", 13, 124204},
	{"HALLOWELL", 9, 124205},
	{"SAPLING", 7, 124206},
	{"RUMBLINGS", 9, 124207},
	{"BCCI", 4, 124208},
	{"HEIDELBERGER", 12, 124209},
	{"ELANA", 5, 124210},
	{"ELAPSE", 6, 124211},
	{"MACDOWELL", 9, 124212},
	{"DVHS", 4, 124213},
	{"FAUNAL", 6, 124214},
	{"SCILAB", 6, 124215},
	{"CONDITIONALITY", 14, 124216},
	{"SOLARIUMCAM", 11, 124217},
	{"EISENTHAL", 9, 124218},
	{"BIOME", 5, 124219},
	{"UANL", 4, 124220},
	{"NNFR", 4, 124221},
	{"NKSK", 4, 124222},
	{"NAPK", 4, 124223},
	{"MULS", 4, 124224},
	{"DRBL", 4, 124225},
	{"CPIE", 4, 124226},
	{"BASL", 4, 124227},
	{"HIRAGANA", 8, 124228},
	{"NIGHTMARISH", 11, 124229},
	{"GORING", 6, 124230},
	{"UNBEKNOWNST", 11, 124231},
	{"KAMELOT", 7, 124232},
	{"AMERIE", 6, 124233},
	{"SUBFORUMS", 9, 124234},
	{"KIRKUS", 6, 124235},
	{"PLINTH", 6, 124236},
	{"LISTMASTER", 10, 124237},
	{"ALLOPASS", 8, 124238},
	{"ECHOS", 5, 124239},
	{"NEGRI", 5, 124240},
	{"CAWLEY", 6, 124241},
	{"PEPPERCORN", 10, 124242},
	{"WARGAMING", 9, 124243},
	{"SUPPRESSIVE", 11, 124244},
	{"KAMPUCHEA", 9, 124245},
	{"TADPOLES", 8, 124246},
	{"BABOONS", 7, 124247},
	{"URNJ", 4, 124248},
	{"TKOV", 4, 124249},
	{"SGOM", 4, 124250},
	{"RIOV", 4, 124251},
	{"RGAF", 4, 124252},
	{"REWY", 4, 124253},
	{"OGFR", 4, 124254},
	{"LGAZ", 4, 124255},
	{"GYCL", 4, 124256},
	{"FKIC", 4, 124257},
	{"CZAK", 4, 124258},
	{"AUKR", 4, 124259},
	{"APWO", 4, 124260},
	{"AGPO", 4, 124261},
	{"MYNE", 4, 124262},
	{"STAMPINGS", 9, 124263},
	{"ENAMELLED", 9, 124264},
	{"YANNICK", 7, 124265},
	{"MCLANE", 6, 124266},
	{"DYKSTRA", 7, 124267},
	{"OPENCOURSEWARE", 14, 124268},
	{"XPHONE", 6, 124269},
	{"MATTERHORN", 10, 124270},
	{"TRANSMITTANCE", 13, 124271},
	{"SCULL", 5, 124272},
	{"HASHANA", 7, 124273},
	{"ALBE", 4, 124274},
	{"INDX", 4, 124275},
	{"ZOOKEEPER", 9, 124276},
	{"DONETSK", 7, 124277},
	{"NEPOTISM", 8, 124278},
	{"AVANTE", 6, 124279},
	{"SIGRID", 6, 124280},
	{"INTERNACIONALES", 15, 124281},
	{"ICBM", 4, 124282},
	{"CHUCH", 5, 124283},
	{"GCU", 3, 124284},
	{"ZYMA", 4, 124285},
	{"WDIG", 4, 124286},
	{"THMP", 4, 124287},
	{"RYIW", 4, 124288},
	{"RSYL", 4, 124289},
	{"PFLA", 4, 124290},
	{"LURC", 4, 124291},
	{"IROG", 4, 124292},
	{"FDAA", 4, 124293},
	{"DKEA", 4, 124294},
	{"AGDO", 4, 124295},
	{"TYRESE", 6, 124296},
	{"URBZ", 4, 124297},
	{"INDUSTRIALIST", 13, 124298},
	{"BABOLAT", 7, 124299},
	{"TORMENTS", 8, 124300},
	{"MORZINE", 7, 124301},
	{"SEPHAROSE", 9, 124302},
	{"REREADING", 9, 124303},
	{"PROPELS", 7, 124304},
	{"DAOU", 4, 124305},
	{"TORTUOUS", 8, 124306},
	{"BUCCAL", 6, 124307},
	{"ALENA", 5, 124308},
	{"AUTOMAGICALLY", 13, 124309},
	{"OISEAUX", 7, 124310},
	{"INDONESIANS", 11, 124311},
	{"FLUME", 5, 124312},
	{"HALDEMAN", 8, 124313},
	{"RTTTL", 5, 124314},
	{"NUTLEY", 6, 124315},
	{"POLYCRYSTALLINE", 15, 124316},
	{"KENICHI", 7, 124317},
	{"XDOE", 4, 124318},
	{"VELK", 4, 124319},
	{"RCCO", 4, 124320},
	{"NOUC", 4, 124321},
	{"LYNP", 4, 124322},
	{"FRAV", 4, 124323},
	{"FLOB", 4, 124324},
	{"FFYE", 4, 124325},
	{"LIQUIDLIBRARY", 13, 124326},
	{"DATAFIELD", 9, 124327},
	{"LEARNINGS", 9, 124328},
	{"GALAHAD", 7, 124329},
	{"DISINFECTING", 12, 124330},
	{"KAPP", 4, 124331},
	{"SEAFARING", 9, 124332},
	{"TRIBAND", 7, 124333},
	{"TRADITIONALFORM", 15, 124334},
	{"MARRA", 5, 124335},
	{"MOOTED", 6, 124336},
	{"SYDNEE", 6, 124337},
	{"MANAS", 5, 124338},
	{"CSTRING", 7, 124339},
	{"TWEENS", 6, 124340},
	{"ZEPE", 4, 124341},
	{"YUPH", 4, 124342},
	{"PHYG", 4, 124343},
	{"PHOV", 4, 124344},
	{"OMYK", 4, 124345},
	{"OFBB", 4, 124346},
	{"EGEY", 4, 124347},
	{"AYIG", 4, 124348},
	{"ECCLESIA", 8, 124349},
	{"KARBALA", 7, 124350},
	{"PINEDA", 6, 124351},
	{"MADER", 5, 124352},
	{"JITTERY", 7, 124353},
	{"CONCHA", 6, 124354},
	{"BOXOFFICE", 9, 124355},
	{"HORWICH", 7, 124356},
	{"KRESGE", 6, 124357},
	{"ENEMAS", 6, 124358},
	{"BAKES", 5, 124359},
	{"REPENTED", 8, 124360},
	{"PRENOTAZIONI", 12, 124361},
	{"WKDW", 4, 124362},
	{"AMARANTINE", 10, 124363},
	{"INFIRMITY", 9, 124364},
	{"CORYDON", 7, 124365},
	{"BOWE", 4, 124366},
	{"SELFISHLY", 9, 124367},
	{"PHONECARD", 9, 124368},
	{"WINDOWMAKER", 11, 124369},
	{"GHIRARDELLI", 11, 124370},
	{"WINWOOD", 7, 124371},
	{"BIGCOCK", 7, 124372},
	{"SPACEMAN", 8, 124373},
	{"COULDA", 6, 124374},
	{"RTCP", 4, 124375},
	{"FLERE", 5, 124376},
	{"DRUDGERY", 8, 124377},
	{"LAUREA", 6, 124378},
	{"PACHA", 5, 124379},
	{"VSRE", 4, 124380},
	{"UEKN", 4, 124381},
	{"LSTP", 4, 124382},
	{"HBUF", 4, 124383},
	{"BIDB", 4, 124384},
	{"SMARTIES", 8, 124385},
	{"ANDROIDS", 8, 124386},
	{"DSTATIC", 7, 124387},
	{"TREV", 4, 124388},
	{"RENUMBERING", 11, 124389},
	{"IAMIGOS", 7, 124390},
	{"PARABOLA", 8, 124391},
	{"FORS", 4, 124392},
	{"BADA", 4, 124393},
	{"AEDES", 5, 124394},
	{"SHRUBBERY", 9, 124395},
	{"FLIM", 4, 124396},
	{"NAVIES", 6, 124397},
	{"PAARL", 5, 124398},
	{"MAMBOFORGE", 10, 124399},
	{"IMPARTIALLY", 11, 124400},
	{"ALEKSEY", 7, 124401},
	{"COCKE", 5, 124402},
	{"STEVAN", 6, 124403},
	{"ACLOCAL", 7, 124404},
	{"KRISTANNA", 9, 124405},
	{"SEPANG", 6, 124406},
	{"PERATURE", 8, 124407},
	{"LEILANI", 7, 124408},
	{"DOIG", 4, 124409},
	{"FFX", 3, 124410},
	{"REPRESEN", 8, 124411},
	{"EVEL", 4, 124412},
	{"PASOK", 5, 124413},
	{"IMPERFECTLY", 11, 124414},
	{"YERY", 4, 124415},
	{"UINR", 4, 124416},
	{"UGRI", 4, 124417},
	{"RGNA", 4, 124418},
	{"IEUW", 4, 124419},
	{"BDOW", 4, 124420},
	{"YSTEM", 5, 124421},
	{"COINTEGRATION", 13, 124422},
	{"AALL", 4, 124423},
	{"WFD", 3, 124424},
	{"ULTRAMARINE", 11, 124425},
	{"HAFIZ", 5, 124426},
	{"OROZCO", 6, 124427},
	{"CKEY", 4, 124428},
	{"ATMAN", 5, 124429},
	{"SLANDEROUS", 10, 124430},
	{"ADIL", 4, 124431},
	{"TUBO", 4, 124432},
	{"INTERMINABLE", 12, 124433},
	{"OUDTSHOORN", 10, 124434},
	{"SRIDHAR", 7, 124435},
	{"SOCIALISING", 11, 124436},
	{"ANCIEN", 6, 124437},
	{"WESTHEIMER", 10, 124438},
	{"CHERN", 5, 124439},
	{"ANESTHETIZED", 12, 124440},
	{"LINDH", 5, 124441},
	{"PBMC", 4, 124442},
	{"IZZARD", 6, 124443},
	{"BRITO", 5, 124444},
	{"OOMPA", 5, 124445},
	{"EMPLEO", 6, 124446},
	{"PINKER", 6, 124447},
	{"INTROVERTED", 11, 124448},
	{"INDOMITABLE", 11, 124449},
	{"CENTRIFUGED", 11, 124450},
	{"VALIDATIONS", 11, 124451},
	{"ROADMASTER", 10, 124452},
	{"BUGTRACKER", 10, 124453},
	{"CLANTON", 7, 124454},
	{"ANCHOVIES", 9, 124455},
	{"NMAZ", 4, 124456},
	{"LZBU", 4, 124457},
	{"LGAP", 4, 124458},
	{"IYEV", 4, 124459},
	{"HURU", 4, 124460},
	{"HOLR", 4, 124461},
	{"FRUGALWARE", 10, 124462},
	{"FIKEN", 5, 124463},
	{"STATESWORLDWIDE", 15, 124464},
	{"KUPU", 4, 124465},
	{"UNSEEMLY", 8, 124466},
	{"LINKBLOG", 8, 124467},
	{"PICKFORD", 8, 124468},
	{"RUNGS", 5, 124469},
	{"LYTIC", 5, 124470},
	{"MERTZ", 5, 124471},
	{"OAMARU", 6, 124472},
	{"CARITA", 6, 124473},
	{"ZBD", 3, 124474},
	{"YCX", 3, 124475},
	{"MGQ", 3, 124476},
	{"LXJ", 3, 124477},
	{"KZZ", 3, 124478},
	{"GMZ", 3, 124479},
	{"RAEL", 4, 124480},
	{"LEMOYNE", 7, 124481},
	{"GODLIKE", 7, 124482},
	{"SINGLETARY", 10, 124483},
	{"TOBJECT", 7, 124484},
	{"YDEI", 4, 124485},
	{"WORW", 4, 124486},
	{"TVMA", 4, 124487},
	{"SOBB", 4, 124488},
	{"SICY", 4, 124489},
	{"RNIP", 4, 124490},
	{"OPBL", 4, 124491},
	{"OCHC", 4, 124492},
	{"KOSP", 4, 124493},
	{"KKIM", 4, 124494},
	{"IGZA", 4, 124495},
	{"HERX", 4, 124496},
	{"FIEV", 4, 124497},
	{"BUGH", 4, 124498},
	{"REACTIES", 8, 124499},
	{"ADCENTER", 8, 124500},
	{"PROSODIC", 8, 124501},
	{"DOUALA", 6, 124502},
	{"COALVILLE", 9, 124503},
	{"PMOL", 4, 124504},
	{"DUBOSE", 6, 124505},
	{"SYTEM", 5, 124506},
	{"ENGENIUS", 8, 124507},
	{"JAVASOLARIS", 11, 124508},
	{"COMMUNITIESPARTNERSMY", 21, 124509},
	{"KHALSA", 6, 124510},
	{"GRINDCORE", 9, 124511},
	{"VEUILLEZ", 8, 124512},
	{"PERSCRIPTIONS", 13, 124513},
	{"SEELY", 5, 124514},
	{"CLF", 3, 124515},
	{"SCREENSIZE", 10, 124516},
	{"GERS", 4, 124517},
	{"BFF", 3, 124518},
	{"RESURFACED", 10, 124519},
	{"HOWDEN", 6, 124520},
	{"THERMOGRAPHY", 12, 124521},
	{"FREQUENTATION", 13, 124522},
	{"SEWICKLEY", 9, 124523},
	{"APCUPSD", 7, 124524},
	{"WEBCHAT", 7, 124525},
	{"UBIQUINONE", 10, 124526},
	{"MEADOWLARK", 10, 124527},
	{"MADHU", 5, 124528},
	{"EDGER", 5, 124529},
	{"WEXF", 4, 124530},
	{"SYUK", 4, 124531},
	{"RYOK", 4, 124532},
	{"PYDE", 4, 124533},
	{"OMCD", 4, 124534},
	{"NWEK", 4, 124535},
	{"LOXI", 4, 124536},
	{"LCED", 4, 124537},
	{"IFYY", 4, 124538},
	{"DKOL", 4, 124539},
	{"BFLA", 4, 124540},
	{"BEDG", 4, 124541},
	{"LEMOORE", 7, 124542},
	{"RADEK", 5, 124543},
	{"EVACUATING", 10, 124544},
	{"GHANDI", 6, 124545},
	{"PANERA", 6, 124546},
	{"SCRAMBLES", 9, 124547},
	{"CHAWLA", 6, 124548},
	{"TECHBUY", 7, 124549},
	{"RASKIN", 6, 124550},
	{"ARBEITEN", 8, 124551},
	{"RFQS", 4, 124552},
	{"MERRIMENT", 9, 124553},
	{"RANDELL", 7, 124554},
	{"RETINITIS", 9, 124555},
	{"THANET", 6, 124556},
	{"NONVOLATILE", 11, 124557},
	{"DISAPPOINTS", 11, 124558},
	{"ROTTED", 6, 124559},
	{"KATOOMBA", 8, 124560},
	{"THETIS", 6, 124561},
	{"UDPA", 4, 124562},
	{"RFOE", 4, 124563},
	{"PPTO", 4, 124564},
	{"NOVF", 4, 124565},
	{"MADJ", 4, 124566},
	{"UTTOXETER", 9, 124567},
	{"PREGNAT", 7, 124568},
	{"TIGHTEST", 8, 124569},
	{"CHHATTISGARH", 12, 124570},
	{"FONTCOLOR", 9, 124571},
	{"RINGMASTER", 10, 124572},
	{"GRIB", 4, 124573},
	{"SUBSIDIARITY", 12, 124574},
	{"PAULEY", 6, 124575},
	{"HASBROUCK", 9, 124576},
	{"PMEL", 4, 124577},
	{"HALLUCINOGENS", 13, 124578},
	{"ECLIPSING", 9, 124579},
	{"LOIC", 4, 124580},
	{"JANUSZ", 6, 124581},
	{"BOOGEYMAN", 9, 124582},
	{"UYMA", 4, 124583},
	{"SBNX", 4, 124584},
	{"MOBR", 4, 124585},
	{"KYOI", 4, 124586},
	{"JIBW", 4, 124587},
	{"EWSQ", 4, 124588},
	{"EKIB", 4, 124589},
	{"EECK", 4, 124590},
	{"AKBR", 4, 124591},
	{"CLID", 4, 124592},
	{"REPULSED", 8, 124593},
	{"PONYTAILED", 10, 124594},
	{"UNBLOCK", 7, 124595},
	{"TICONDEROGA", 11, 124596},
	{"ANALOGOUSLY", 11, 124597},
	{"ELVISH", 6, 124598},
	{"GARNI", 5, 124599},
	{"BOOKKOOB", 8, 124600},
	{"TTLB", 4, 124601},
	{"AUTHORWARE", 10, 124602},
	{"REPLAYED", 8, 124603},
	{"BRICKWORK", 9, 124604},
	{"BOUGHTON", 8, 124605},
	{"LITTLES", 7, 124606},
	{"BERICHTEN", 9, 124607},
	{"CORALVILLE", 10, 124608},
	{"XBASE", 5, 124609},
	{"HUNTRESS", 8, 124610},
	{"CALIBRATORS", 11, 124611},
	{"SOULLESS", 8, 124612},
	{"TEXTBOOKX", 9, 124613},
	{"DUMPLING", 8, 124614},
	{"PRESUMPTIONS", 12, 124615},
	{"PARTMENT", 8, 124616},
	{"DESKSTAR", 8, 124617},
	{"ABBOTS", 6, 124618},
	{"REDEYE", 6, 124619},
	{"MAMBA", 5, 124620},
	{"JHELP", 5, 124621},
	{"YEDK", 4, 124622},
	{"XOFB", 4, 124623},
	{"ULOA", 4, 124624},
	{"ULGU", 4, 124625},
	{"PESY", 4, 124626},
	{"ODYV", 4, 124627},
	{"LPPU", 4, 124628},
	{"KKNE", 4, 124629},
	{"IEMM", 4, 124630},
	{"EUGA", 4, 124631},
	{"FRONTISPIECE", 12, 124632},
	{"SPEEX", 5, 124633},
	{"BARAN", 5, 124634},
	{"BRATTON", 7, 124635},
	{"VIVACIOUS", 9, 124636},
	{"STORMTROOPER", 12, 124637},
	{"BLOODSHOT", 9, 124638},
	{"ABRASIONS", 9, 124639},
	{"SALUTATIONS", 11, 124640},
	{"CONTATTI", 8, 124641},
	{"PELA", 4, 124642},
	{"REMAINDERS", 10, 124643},
	{"SIGNUM", 6, 124644},
	{"STRASSER", 8, 124645},
	{"PAULIE", 6, 124646},
	{"MOIR", 4, 124647},
	{"AUTONOMA", 8, 124648},
	{"PIAF", 4, 124649},
	{"NESSIE", 6, 124650},
	{"AUDEN", 5, 124651},
	{"GNOSTICISM", 10, 124652},
	{"DOGMAS", 6, 124653},
	{"FORSOOTH", 8, 124654},
	{"UXAR", 4, 124655},
	{"UOTD", 4, 124656},
	{"RMEO", 4, 124657},
	{"RBEB", 4, 124658},
	{"OUNU", 4, 124659},
	{"MJEN", 4, 124660},
	{"LADC", 4, 124661},
	{"GTAM", 4, 124662},
	{"EKOC", 4, 124663},
	{"BYYU", 4, 124664},
	{"BTBE", 4, 124665},
	{"AWJO", 4, 124666},
	{"OLUFSEN", 7, 124667},
	{"GEORDIE", 7, 124668},
	{"KEREN", 5, 124669},
	{"ORESTES", 7, 124670},
	{"AUTONET", 7, 124671},
	{"ANDRESR", 7, 124672},
	{"BARDSTOWN", 9, 124673},
	{"AMERY", 5, 124674},
	{"PERMETHRIN", 10, 124675},
	{"PREHEATED", 9, 124676},
	{"BAILING", 7, 124677},
	{"PARASITOL", 9, 124678},
	{"BABBAGE", 7, 124679},
	{"FURST", 5, 124680},
	{"GILLAN", 6, 124681},
	{"BILT", 4, 124682},
	{"RMOW", 4, 124683},
	{"NYUR", 4, 124684},
	{"NBUG", 4, 124685},
	{"IPCE", 4, 124686},
	{"GOLDFINCH", 9, 124687},
	{"ACCESSORIZE", 11, 124688},
	{"EVIEW", 5, 124689},
	{"RENAMES", 7, 124690},
	{"DEATHBED", 8, 124691},
	{"TRICOLOR", 8, 124692},
	{"MEDIZINISCHE", 12, 124693},
	{"AUTORISATION", 12, 124694},
	{"MODERNISE", 9, 124695},
	{"BOOGALOO", 8, 124696},
	{"INDEFENSIBLE", 12, 124697},
	{"MAGNE", 5, 124698},
	{"LEMKE", 5, 124699},
	{"JINAN", 5, 124700},
	{"QUANTILE", 8, 124701},
	{"BRUTISH", 7, 124702},
	{"ASTARO", 6, 124703},
	{"DIVERGENCES", 11, 124704},
	{"APALACHICOLA", 12, 124705},
	{"PALMEIRO", 8, 124706},
	{"TRILL", 5, 124707},
	{"TRENDWARE", 9, 124708},
	{"TOMMORROW", 9, 124709},
	{"UIGH", 4, 124710},
	{"UFTH", 4, 124711},
	{"SRIK", 4, 124712},
	{"PESG", 4, 124713},
	{"PAMB", 4, 124714},
	{"NDDH", 4, 124715},
	{"MWIC", 4, 124716},
	{"GULS", 4, 124717},
	{"GMEX", 4, 124718},
	{"FOLY", 4, 124719},
	{"ELEZ", 4, 124720},
	{"DVDB", 4, 124721},
	{"TRAVELSTAR", 10, 124722},
	{"FRB", 3, 124723},
	{"NANOTECHNOLOGIES", 16, 124724},
	{"VENETIA", 7, 124725},
	{"MELCHIOR", 8, 124726},
	{"CELE", 4, 124727},
	{"REBALANCING", 11, 124728},
	{"EXTREMA", 7, 124729},
	{"MACOLA", 6, 124730},
	{"MASTERMINDS", 11, 124731},
	{"XERXES", 6, 124732},
	{"DEIR", 4, 124733},
	{"DALIA", 5, 124734},
	{"MUONSPECTROMETER", 16, 124735},
	{"FLAILING", 8, 124736},
	{"FLORHAM", 7, 124737},
	{"REALLOCATED", 11, 124738},
	{"SQLSERVER", 9, 124739},
	{"PARMS", 5, 124740},
	{"CANEY", 5, 124741},
	{"TEGAN", 5, 124742},
	{"BRONNER", 7, 124743},
	{"COMPUTERIZATION", 15, 124744},
	{"PHOTORECEPTOR", 13, 124745},
	{"MONOUNSATURATED", 15, 124746},
	{"QUICKFACTS", 10, 124747},
	{"AMPUTEES", 8, 124748},
	{"EROTICCAM", 9, 124749},
	{"RAMAKRISHNAN", 12, 124750},
	{"WADDLE", 6, 124751},
	{"BUNNING", 7, 124752},
	{"WTHU", 4, 124753},
	{"WANF", 4, 124754},
	{"UBAM", 4, 124755},
	{"ROBM", 4, 124756},
	{"PHSB", 4, 124757},
	{"OPOC", 4, 124758},
	{"MNAB", 4, 124759},
	{"MIXU", 4, 124760},
	{"KTEX", 4, 124761},
	{"IXOU", 4, 124762},
	{"DJEL", 4, 124763},
	{"AGSP", 4, 124764},
	{"FEISS", 5, 124765},
	{"GRIDDED", 7, 124766},
	{"SULFATES", 8, 124767},
	{"JUZ", 3, 124768},
	{"ANDTHE", 6, 124769},
	{"GRATOS", 6, 124770},
	{"AKIKO", 5, 124771},
	{"DONELSON", 8, 124772},
	{"STAMPERS", 8, 124773},
	{"RODENTIA", 8, 124774},
	{"LXX", 3, 124775},
	{"POUDRE", 6, 124776},
	{"RAMPARTS", 8, 124777},
	{"GOLITE", 6, 124778},
	{"KOREPETYCJE", 11, 124779},
	{"AUBURNDALE", 10, 124780},
	{"PAQUIN", 6, 124781},
	{"DISBAND", 7, 124782},
	{"GPIO", 4, 124783},
	{"WIGNER", 6, 124784},
	{"INDIAMART", 9, 124785},
	{"LEDFORD", 7, 124786},
	{"BITTERROOT", 10, 124787},
	{"SYLO", 4, 124788},
	{"NIBM", 4, 124789},
	{"MNAL", 4, 124790},
	{"KPAP", 4, 124791},
	{"EOBU", 4, 124792},
	{"EEUL", 4, 124793},
	{"DYAV", 4, 124794},
	{"BORAX", 5, 124795},
	{"SYMMETRICALLY", 13, 124796},
	{"LOFGREN", 7, 124797},
	{"CHARDON", 7, 124798},
	{"LILLEHAMMER", 11, 124799},
	{"DEBUNK", 6, 124800},
	{"REEK", 4, 124801},
	{"WOJCIECH", 8, 124802},
	{"AMYLOIDOSIS", 11, 124803},
	{"SOELDEN", 7, 124804},
	{"MANHOLES", 8, 124805},
	{"JOYRIDE", 7, 124806},
	{"KIER", 4, 124807},
	{"MEGABIT", 7, 124808},
	{"HEARERS", 7, 124809},
	{"YEARLONG", 8, 124810},
	{"JAVITS", 6, 124811},
	{"MYACCOUNT", 9, 124812},
	{"FRIGATES", 8, 124813},
	{"PETROS", 6, 124814},
	{"AVAILED", 7, 124815},
	{"VUNI", 4, 124816},
	{"UGLO", 4, 124817},
	{"SYWE", 4, 124818},
	{"KKIR", 4, 124819},
	{"IWOK", 4, 124820},
	{"IKOK", 4, 124821},
	{"GMEG", 4, 124822},
	{"DRLE", 4, 124823},
	{"AYIV", 4, 124824},
	{"AWEX", 4, 124825},
	{"ABSP", 4, 124826},
	{"CEMENTING", 9, 124827},
	{"TECHNOTES", 9, 124828},
	{"ADRIANNE", 8, 124829},
	{"REPATRIATED", 11, 124830},
	{"GIGER", 5, 124831},
	{"KAME", 4, 124832},
	{"EXTERNALS", 9, 124833},
	{"EVERHARD", 8, 124834},
	{"PRINCIPALES", 11, 124835},
	{"ANNABELL", 8, 124836},
	{"MCLE", 4, 124837},
	{"RECONSIDERING", 13, 124838},
	{"TRAZODONE", 9, 124839},
	{"PNNL", 4, 124840},
	{"NIMMO", 5, 124841},
	{"TABL", 4, 124842},
	{"PROACTIV", 8, 124843},
	{"DIRED", 5, 124844},
	{"HYNNY", 5, 124845},
	{"PENDENCY", 8, 124846},
	{"BLAIS", 5, 124847},
	{"DAMSELS", 7, 124848},
	{"ZZCO", 4, 124849},
	{"YNGA", 4, 124850},
	{"WNGI", 4, 124851},
	{"PYSA", 4, 124852},
	{"KEXA", 4, 124853},
	{"KASY", 4, 124854},
	{"FFCR", 4, 124855},
	{"SPIELEN", 7, 124856},
	{"SASHIMI", 7, 124857},
	{"VERSIE", 6, 124858},
	{"MONOTHEISM", 10, 124859},
	{"SYOSSET", 7, 124860},
	{"DRWY", 4, 124861},
	{"BASKETRY", 8, 124862},
	{"PSYCHOPATHIC", 12, 124863},
	{"MENELAUS", 8, 124864},
	{"FLEXURAL", 8, 124865},
	{"MOSFETS", 7, 124866},
	{"CRUMMY", 6, 124867},
	{"PHANTASM", 8, 124868},
	{"MORSELS", 7, 124869},
	{"LAMSON", 6, 124870},
	{"SMORGASBORD", 11, 124871},
	{"LOCALEDATA", 10, 124872},
	{"SKIRMISHES", 10, 124873},
	{"CONGRATULATORY", 14, 124874},
	{"SNICKER", 7, 124875},
	{"FEATURETTES", 11, 124876},
	{"SCHWANGER", 9, 124877},
	{"FREW", 4, 124878},
	{"TRANSMETA", 9, 124879},
	{"TOERISME", 8, 124880},
	{"SAKURAI", 7, 124881},
	{"OVERSTATE", 9, 124882},
	{"ZAADZ", 5, 124883},
	{"EVANGELISTA", 11, 124884},
	{"GHETTOS", 7, 124885},
	{"REPUBBLICA", 10, 124886},
	{"YLAL", 4, 124887},
	{"RPOK", 4, 124888},
	{"PHAZ", 4, 124889},
	{"NKUW", 4, 124890},
	{"LMCG", 4, 124891},
	{"GWWI", 4, 124892},
	{"LIDDLE", 6, 124893},
	{"GEILEN", 6, 124894},
	{"HAMAP", 5, 124895},
	{"ZULETZT", 7, 124896},
	{"PPK", 3, 124897},
	{"EWORLD", 6, 124898},
	{"OLIGOSACCHARIDES", 16, 124899},
	{"DARKTHRONE", 10, 124900},
	{"BARRAS", 6, 124901},
	{"ECCLESTON", 9, 124902},
	{"VMU", 3, 124903},
	{"OPTIMISTS", 9, 124904},
	{"LEGA", 4, 124905},
	{"RAMAYANA", 8, 124906},
	{"PREPARERS", 9, 124907},
	{"HONITON", 7, 124908},
	{"INFOMERCIALS", 12, 124909},
	{"RANGELANDS", 10, 124910},
	{"WASSON", 6, 124911},
	{"BUGTRACK", 8, 124912},
	{"ACDBPOINT", 9, 124913},
	{"PERREGAUX", 9, 124914},
	{"XXASDF", 6, 124915},
	{"WIMPS", 5, 124916},
	{"INTERTEMPORAL", 13, 124917},
	{"PIPESTONE", 9, 124918},
	{"GOATEE", 6, 124919},
	{"EXTRAJUDICIAL", 13, 124920},
	{"CONASON", 7, 124921},
	{"CMKX", 4, 124922},
	{"VOYOUR", 6, 124923},
	{"BELTRONICS", 10, 124924},
	{"SOXM", 4, 124925},
	{"OFLD", 4, 124926},
	{"GYMW", 4, 124927},
	{"DADL", 4, 124928},
	{"CYAM", 4, 124929},
	{"SHORTING", 8, 124930},
	{"RELIGOUS", 8, 124931},
	{"HOPEDALE", 8, 124932},
	{"MOTTA", 5, 124933},
	{"WEASELFISH", 10, 124934},
	{"MELODIOUS", 9, 124935},
	{"NIKOLAUS", 8, 124936},
	{"BAITED", 6, 124937},
	{"CAPSAICIN", 9, 124938},
	{"CHANA", 5, 124939},
	{"YAML", 4, 124940},
	{"MULTIYEAR", 9, 124941},
	{"BIOREACTOR", 10, 124942},
	{"UPJOHN", 6, 124943},
	{"RHODOPSIN", 9, 124944},
	{"IDITAROD", 8, 124945},
	{"DOLOMITES", 9, 124946},
	{"FILHO", 5, 124947},
	{"STERILIZER", 10, 124948},
	{"LIVRAISON", 9, 124949},
	{"ENLARGERS", 9, 124950},
	{"EDIFICIO", 8, 124951},
	{"SUNW", 4, 124952},
	{"WLXX", 4, 124953},
	{"PIEF", 4, 124954},
	{"OOFJ", 4, 124955},
	{"KEOW", 4, 124956},
	{"HAYR", 4, 124957},
	{"AUXH", 4, 124958},
	{"AUDD", 4, 124959},
	{"AGUP", 4, 124960},
	{"VEINED", 6, 124961},
	{"COPED", 5, 124962},
	{"SISQO", 5, 124963},
	{"PATRIC", 6, 124964},
	{"SANDIE", 6, 124965},
	{"REFERENC", 8, 124966},
	{"MONTEVERDI", 10, 124967},
	{"COLLETT", 7, 124968},
	{"AMINOBUTYRIC", 12, 124969},
	{"THIRSK", 6, 124970},
	{"ASPIRATED", 9, 124971},
	{"PACIFIERS", 9, 124972},
	{"ORGANISMAL", 10, 124973},
	{"SPGS", 4, 124974},
	{"RAPUNZEL", 8, 124975},
	{"EDGEFIELD", 9, 124976},
	{"SHACKELFORD", 11, 124977},
	{"HOLMBERG", 8, 124978},
	{"KAZZA", 5, 124979},
	{"HSPACE", 6, 124980},
	{"BELFORD", 7, 124981},
	{"FUBAR", 5, 124982},
	{"REPLICATIONS", 12, 124983},
	{"BELLARMINE", 10, 124984},
	{"UESJ", 4, 124985},
	{"TUEW", 4, 124986},
	{"RPOD", 4, 124987},
	{"PUPF", 4, 124988},
	{"ORUG", 4, 124989},
	{"OKWR", 4, 124990},
	{"NOVB", 4, 124991},
	{"KWID", 4, 124992},
	{"EULS", 4, 124993},
	{"CIRR", 4, 124994},
	{"EXPENSED", 8, 124995},
	{"TWENTYNINE", 10, 124996},
	{"INDIV", 5, 124997},
	{"KOKOPELLI", 9, 124998},
	{"MOTIVATORS", 10, 124999},
	{"RELIGIOSITY", 11, 125000},
	{"MICRONUTRIENTS", 14, 125001},
	{"INCIDENTALS", 11, 125002},
	{"PICALIB", 7, 125003},
	{"HYDROLYZED", 10, 125004},
	{"LINGLE", 6, 125005},
	{"MAXIMUMS", 8, 125006},
	{"SUGDEN", 6, 125007},
	{"GALIZA", 6, 125008},
	{"PLATFORMER", 10, 125009},
	{"LUCADO", 6, 125010},
	{"BARTEL", 6, 125011},
	{"THORNBURG", 9, 125012},
	{"NORWEGIANS", 10, 125013},
	{"BALTICS", 7, 125014},
	{"ACESS", 5, 125015},
	{"UMEY", 4, 125016},
	{"SMRC", 4, 125017},
	{"OYDB", 4, 125018},
	{"OKOW", 4, 125019},
	{"OFNF", 4, 125020},
	{"LLRS", 4, 125021},
	{"KIFH", 4, 125022},
	{"KFIX", 4, 125023},
	{"GPAK", 4, 125024},
	{"AVYV", 4, 125025},
	{"AERATED", 7, 125026},
	{"SWITCHBOXES", 11, 125027},
	{"IMITATES", 8, 125028},
	{"CONJUGAL", 8, 125029},
	{"BOLDEST", 7, 125030},
	{"PRCS", 4, 125031},
	{"ALIKES", 6, 125032},
	{"RRDTOOL", 7, 125033},
	{"MONOGRAMS", 9, 125034},
	{"COMENTARIO", 10, 125035},
	{"BILATERALLY", 11, 125036},
	{"UNDERCLASS", 10, 125037},
	{"HAFEN", 5, 125038},
	{"FLAUBERT", 8, 125039},
	{"ENUNCIATED", 10, 125040},
	{"STRICTURES", 10, 125041},
	{"IMPOUND", 7, 125042},
	{"KONTAKTANZEIGEN", 15, 125043},
	{"FLINGING", 8, 125044},
	{"FERME", 5, 125045},
	{"MEMBROS", 7, 125046},
	{"INDOPEDIA", 9, 125047},
	{"DISCOURAGEMENT", 14, 125048},
	{"WERKE", 5, 125049},
	{"SPERMASCHLUCKEN", 15, 125050},
	{"VOTOS", 5, 125051},
	{"REPAIRLOCAL", 11, 125052},
	{"BILSTEIN", 8, 125053},
	{"GWEITHIO", 8, 125054},
	{"WSGE", 4, 125055},
	{"UIER", 4, 125056},
	{"SAWU", 4, 125057},
	{"RMCI", 4, 125058},
	{"HVEL", 4, 125059},
	{"FOUC", 4, 125060},
	{"FEAB", 4, 125061},
	{"ECPM", 4, 125062},
	{"EAUV", 4, 125063},
	{"DOSD", 4, 125064},
	{"NIGHTLIGHT", 10, 125065},
	{"OPENDX", 6, 125066},
	{"VESPER", 6, 125067},
	{"JJB", 3, 125068},
	{"LUZERN", 6, 125069},
	{"UNSAVED", 7, 125070},
	{"ETHNOMUSICOLOGY", 15, 125071},
	{"BANTA", 5, 125072},
	{"CHIAO", 5, 125073},
	{"BIOGRAFIA", 9, 125074},
	{"HEALTHLINK", 10, 125075},
	{"DDM", 3, 125076},
	{"PRODDING", 8, 125077},
	{"DOGFISH", 7, 125078},
	{"DUELIST", 7, 125079},
	{"GETHER", 6, 125080},
	{"VSCR", 4, 125081},
	{"TZRO", 4, 125082},
	{"MNAP", 4, 125083},
	{"LBYG", 4, 125084},
	{"GOAU", 4, 125085},
	{"CKOC", 4, 125086},
	{"FILLES", 6, 125087},
	{"WINTEL", 6, 125088},
	{"EDENS", 5, 125089},
	{"FERRUM", 6, 125090},
	{"BERGDORF", 8, 125091},
	{"TOLERABILITY", 12, 125092},
	{"UPSHUR", 6, 125093},
	{"RIGHTMOST", 9, 125094},
	{"MEMORYTEN", 9, 125095},
	{"CLARITHROMYCIN", 14, 125096},
	{"KETOCONAZOLE", 12, 125097},
	{"BOORTZ", 6, 125098},
	{"INOUT", 5, 125099},
	{"INCREAS", 7, 125100},
	{"CHILLIES", 8, 125101},
	{"MOORESTOWN", 10, 125102},
	{"PEOPLEPC", 8, 125103},
	{"ZZIA", 4, 125104},
	{"WPUT", 4, 125105},
	{"THMB", 4, 125106},
	{"THCB", 4, 125107},
	{"PBYB", 4, 125108},
	{"ORUD", 4, 125109},
	{"ONPB", 4, 125110},
	{"OFDW", 4, 125111},
	{"NGUK", 4, 125112},
	{"MJOS", 4, 125113},
	{"IROY", 4, 125114},
	{"HUKU", 4, 125115},
	{"HOUW", 4, 125116},
	{"GHEU", 4, 125117},
	{"FDUM", 4, 125118},
	{"FCNO", 4, 125119},
	{"LOWED", 5, 125120},
	{"KRELL", 5, 125121},
	{"UNIXODBC", 8, 125122},
	{"BREAKEVEN", 9, 125123},
	{"USURP", 5, 125124},
	{"PUTTIN", 6, 125125},
	{"METASTOCK", 9, 125126},
	{"ILLEGALARGUMENTEXCEPTION", 24, 125127},
	{"RANDWICK", 8, 125128},
	{"INSTANCEREF", 11, 125129},
	{"RECHECK", 7, 125130},
	{"MATEMATICA", 10, 125131},
	{"WWC", 3, 125132},
	{"ADIEMUS", 7, 125133},
	{"BANTRY", 6, 125134},
	{"HAZELL", 6, 125135},
	{"GERADE", 6, 125136},
	{"REUSABILITY", 11, 125137},
	{"TYBEE", 5, 125138},
	{"STAPH", 5, 125139},
	{"CATHAOIRLEACH", 13, 125140},
	{"GALAX", 5, 125141},
	{"CHUBS", 5, 125142},
	{"HANDERA", 7, 125143},
	{"STIMULATORY", 11, 125144},
	{"YUTAKA", 6, 125145},
	{"ACETONITRILE", 12, 125146},
	{"TRAVIATA", 8, 125147},
	{"PUM", 3, 125148},
	{"CARTY", 5, 125149},
	{"TRADUIRE", 8, 125150},
	{"IMMACULATELY", 12, 125151},
	{"PEREMPTORY", 10, 125152},
	{"ZONF", 4, 125153},
	{"YVEI", 4, 125154},
	{"XTSW", 4, 125155},
	{"UTYU", 4, 125156},
	{"TVRA", 4, 125157},
	{"TLLC", 4, 125158},
	{"OZAW", 4, 125159},
	{"LREO", 4, 125160},
	{"LOUA", 4, 125161},
	{"LBST", 4, 125162},
	{"IGUL", 4, 125163},
	{"HVOC", 4, 125164},
	{"FPOM", 4, 125165},
	{"DUTR", 4, 125166},
	{"DNBA", 4, 125167},
	{"BRCK", 4, 125168},
	{"ARKZ", 4, 125169},
	{"ZIGBEE", 6, 125170},
	{"UNMETERED", 9, 125171},
	{"APATITE", 7, 125172},
	{"AGGRO", 5, 125173},
	{"LACTAMASE", 9, 125174},
	{"MORTIS", 6, 125175},
	{"MORIA", 5, 125176},
	{"MORPHOGENETIC", 13, 125177},
	{"PROOFED", 7, 125178},
	{"TRIATHLETE", 10, 125179},
	{"UNRECORDED", 10, 125180},
	{"CANTU", 5, 125181},
	{"SEINER", 6, 125182},
	{"GALLIA", 6, 125183},
	{"CREMATORY", 9, 125184},
	{"CARDONA", 7, 125185},
	{"GLOSSES", 7, 125186},
	{"UNDILUTED", 9, 125187},
	{"HAYNE", 5, 125188},
	{"STRANRAER", 9, 125189},
	{"RWYN", 4, 125190},
	{"RNIF", 4, 125191},
	{"PAXT", 4, 125192},
	{"OIRB", 4, 125193},
	{"GOEB", 4, 125194},
	{"CSGE", 4, 125195},
	{"LORSQUE", 7, 125196},
	{"KAMAGRA", 7, 125197},
	{"GUTTERING", 9, 125198},
	{"FRONDS", 6, 125199},
	{"INTERPOSED", 10, 125200},
	{"LINEBACKERS", 11, 125201},
	{"FEELY", 5, 125202},
	{"LAPLACIAN", 9, 125203},
	{"BRAFF", 5, 125204},
	{"BIOCHEMIST", 10, 125205},
	{"SAFIN", 5, 125206},
	{"JUGGLERS", 8, 125207},
	{"SWAPPER", 7, 125208},
	{"SEMINYAK", 8, 125209},
	{"DELAVAN", 7, 125210},
	{"MSCONFIG", 8, 125211},
	{"YEVS", 4, 125212},
	{"ODGY", 4, 125213},
	{"KDIN", 4, 125214},
	{"FCZE", 4, 125215},
	{"DEMT", 4, 125216},
	{"CHRD", 4, 125217},
	{"AUQU", 4, 125218},
	{"APIM", 4, 125219},
	{"ALLZ", 4, 125220},
	{"BEEPING", 7, 125221},
	{"ACOUSTICALLY", 12, 125222},
	{"BURKHARD", 8, 125223},
	{"THUMBSUP", 8, 125224},
	{"PERP", 4, 125225},
	{"FCKEDITOR", 9, 125226},
	{"GILLY", 5, 125227},
	{"POMO", 4, 125228},
	{"AIRLESS", 7, 125229},
	{"WILKE", 5, 125230},
	{"BALLGAME", 8, 125231},
	{"WINNEMUCCA", 10, 125232},
	{"SLEEVING", 8, 125233},
	{"GEFEN", 5, 125234},
	{"DCB", 3, 125235},
	{"LIPA", 4, 125236},
	{"FLETCH", 6, 125237},
	{"VERI", 4, 125238},
	{"ADVERTISTER", 11, 125239},
	{"METHYLATED", 10, 125240},
	{"POWERLESSNESS", 13, 125241},
	{"DUMPSTERS", 9, 125242},
	{"HSING", 5, 125243},
	{"BULAWAYO", 8, 125244},
	{"FASTLINK", 8, 125245},
	{"MOVENPICK", 9, 125246},
	{"ISFAHAN", 7, 125247},
	{"BRIDGEVILLE", 11, 125248},
	{"YRDA", 4, 125249},
	{"TKMF", 4, 125250},
	{"SDUD", 4, 125251},
	{"RMYK", 4, 125252},
	{"OBSU", 4, 125253},
	{"NBAW", 4, 125254},
	{"MRPO", 4, 125255},
	{"IRJE", 4, 125256},
	{"FCSO", 4, 125257},
	{"EIFL", 4, 125258},
	{"EGBI", 4, 125259},
	{"EROTIKBILDER", 12, 125260},
	{"SARATOV", 7, 125261},
	{"SHARPSHOOTER", 12, 125262},
	{"CARRERE", 7, 125263},
	{"NIEVES", 6, 125264},
	{"DESSIN", 6, 125265},
	{"NEWSMAX", 7, 125266},
	{"CYBORGS", 7, 125267},
	{"PUBLICACIONES", 13, 125268},
	{"ABORIGINALS", 11, 125269},
	{"TAREK", 5, 125270},
	{"NAIVELY", 7, 125271},
	{"NOMINATIVE", 10, 125272},
	{"BUCYRUS", 7, 125273},
	{"REALLOCATE", 10, 125274},
	{"POLYMERASES", 11, 125275},
	{"LEELANAU", 8, 125276},
	{"LITIGATE", 8, 125277},
	{"YOSW", 4, 125278},
	{"MBAH", 4, 125279},
	{"KAZM", 4, 125280},
	{"IRMY", 4, 125281},
	{"IRAY", 4, 125282},
	{"IPQU", 4, 125283},
	{"GIFU", 4, 125284},
	{"FOXING", 6, 125285},
	{"NOLVADEX", 8, 125286},
	{"CLEAVES", 7, 125287},
	{"MURMANSK", 8, 125288},
	{"MOBILEPRO", 9, 125289},
	{"ENAMELS", 7, 125290},
	{"FILLIES", 7, 125291},
	{"BOMA", 4, 125292},
	{"HAMMONDS", 8, 125293},
	{"IPPC", 4, 125294},
	{"DOIVENT", 7, 125295},
	{"FLOORBOARDS", 11, 125296},
	{"MAGICA", 6, 125297},
	{"GAINSBOURG", 10, 125298},
	{"FORNO", 5, 125299},
	{"KAPOK", 5, 125300},
	{"PHPGW", 5, 125301},
	{"CONSOL", 6, 125302},
	{"AVENGING", 8, 125303},
	{"ZNER", 4, 125304},
	{"VMWA", 4, 125305},
	{"VANZ", 4, 125306},
	{"ULFF", 4, 125307},
	{"RAOV", 4, 125308},
	{"PBLU", 4, 125309},
	{"NPOD", 4, 125310},
	{"GNEB", 4, 125311},
	{"FONF", 4, 125312},
	{"CHAJ", 4, 125313},
	{"LINEMEN", 7, 125314},
	{"KAILASH", 7, 125315},
	{"LARLY", 5, 125316},
	{"BZW", 3, 125317},
	{"UNQUOTED", 8, 125318},
	{"PLOUGHED", 8, 125319},
	{"WLP", 3, 125320},
	{"SPRINTING", 9, 125321},
	{"SPITSBERGEN", 11, 125322},
	{"SEVERING", 8, 125323},
	{"TEXTCLICK", 9, 125324},
	{"IPTC", 4, 125325},
	{"SCORELAND", 9, 125326},
	{"HALLMARKED", 10, 125327},
	{"HOUSECALL", 9, 125328},
	{"FARRINGDON", 10, 125329},
	{"ALCHEMICAL", 10, 125330},
	{"OPORTO", 6, 125331},
	{"URSI", 4, 125332},
	{"LUP", 3, 125333},
	{"PVPGN", 5, 125334},
	{"TUNTURI", 7, 125335},
	{"TRANQUILIZERS", 13, 125336},
	{"ZHUA", 4, 125337},
	{"UBOW", 4, 125338},
	{"OFNC", 4, 125339},
	{"LONK", 4, 125340},
	{"LIPG", 4, 125341},
	{"EGYC", 4, 125342},
	{"PUBSUB", 6, 125343},
	{"PILGER", 6, 125344},
	{"OVERZICHT", 9, 125345},
	{"SKLAR", 5, 125346},
	{"STEELER", 7, 125347},
	{"CREMONA", 7, 125348},
	{"HINOJOSA", 8, 125349},
	{"SHARPSBURG", 10, 125350},
	{"NUKU", 4, 125351},
	{"KENNEBUNK", 9, 125352},
	{"CDRS", 4, 125353},
	{"MARTYRED", 8, 125354},
	{"AFFLICT", 7, 125355},
	{"UTELL", 5, 125356},
	{"CEILIDH", 7, 125357},
	{"ACRL", 4, 125358},
	{"MACUPDATE", 9, 125359},
	{"ALPHASON", 8, 125360},
	{"BENEFON", 7, 125361},
	{"NCPFS", 5, 125362},
	{"WINFORMS", 8, 125363},
	{"FICKBILDER", 10, 125364},
	{"THUSLY", 6, 125365},
	{"RVOY", 4, 125366},
	{"OECL", 4, 125367},
	{"JOYY", 4, 125368},
	{"EVOD", 4, 125369},
	{"EMOK", 4, 125370},
	{"ECBE", 4, 125371},
	{"BITG", 4, 125372},
	{"ACBR", 4, 125373},
	{"PASTEURIZED", 11, 125374},
	{"ADDUCTS", 7, 125375},
	{"CARTCART", 8, 125376},
	{"DBCH", 4, 125377},
	{"ANSELL", 6, 125378},
	{"MOLINO", 6, 125379},
	{"SHUTTERBUG", 10, 125380},
	{"HANRAHAN", 8, 125381},
	{"MITTED", 6, 125382},
	{"MASAYUKI", 8, 125383},
	{"DALAMAN", 7, 125384},
	{"OKEMOS", 6, 125385},
	{"FORGETTABLE", 11, 125386},
	{"LPFP", 4, 125387},
	{"DOMAINNAME", 10, 125388},
	{"CRAGS", 5, 125389},
	{"BODES", 5, 125390},
	{"UNREPENTANT", 11, 125391},
	{"BRACK", 5, 125392},
	{"ALLOA", 5, 125393},
	{"STINTS", 6, 125394},
	{"HEANET", 6, 125395},
	{"SICKER", 6, 125396},
	{"YUWE", 4, 125397},
	{"YHUT", 4, 125398},
	{"UIZE", 4, 125399},
	{"UERG", 4, 125400},
	{"OORY", 4, 125401},
	{"NKYR", 4, 125402},
	{"MSJA", 4, 125403},
	{"ISYM", 4, 125404},
	{"IKMM", 4, 125405},
	{"HMUT", 4, 125406},
	{"FTEV", 4, 125407},
	{"EFJA", 4, 125408},
	{"DCAG", 4, 125409},
	{"DAHY", 4, 125410},
	{"AXMINSTER", 9, 125411},
	{"MANGUM", 6, 125412},
	{"SUPE", 4, 125413},
	{"CMAKE", 5, 125414},
	{"DOUBLER", 7, 125415},
	{"KINESIN", 7, 125416},
	{"NAPOLEAN", 8, 125417},
	{"RAGNAR", 6, 125418},
	{"MIMICRY", 7, 125419},
	{"ANPISSEN", 8, 125420},
	{"SERVICEMARK", 11, 125421},
	{"HUMS", 4, 125422},
	{"GIBRAN", 6, 125423},
	{"PULLOVERS", 9, 125424},
	{"ERIKSEN", 7, 125425},
	{"INTERSECTED", 11, 125426},
	{"EXFOLIATION", 11, 125427},
	{"EXHAUSTIVELY", 12, 125428},
	{"TKYL", 4, 125429},
	{"SYPL", 4, 125430},
	{"OWDG", 4, 125431},
	{"OVGO", 4, 125432},
	{"OFDC", 4, 125433},
	{"OFBP", 4, 125434},
	{"NFLG", 4, 125435},
	{"LONZ", 4, 125436},
	{"LEWB", 4, 125437},
	{"IKWH", 4, 125438},
	{"IBYT", 4, 125439},
	{"GIEF", 4, 125440},
	{"FFBI", 4, 125441},
	{"EZAD", 4, 125442},
	{"AWTU", 4, 125443},
	{"AELY", 4, 125444},
	{"GREENFINGERS", 12, 125445},
	{"VBD", 3, 125446},
	{"TUSSEN", 6, 125447},
	{"VTKOBJECT", 9, 125448},
	{"RACECAR", 7, 125449},
	{"INDIGLO", 7, 125450},
	{"HOMED", 5, 125451},
	{"VACATING", 8, 125452},
	{"BREAKOUTS", 9, 125453},
	{"NUTECH", 6, 125454},
	{"NOVEDADES", 9, 125455},
	{"GRANULOMA", 9, 125456},
	{"CARPER", 6, 125457},
	{"TOMKINS", 7, 125458},
	{"PINKNEY", 7, 125459},
	{"JOLY", 4, 125460},
	{"WSRP", 4, 125461},
	{"XTGR", 4, 125462},
	{"WKSO", 4, 125463},
	{"IGOW", 4, 125464},
	{"GOCL", 4, 125465},
	{"CBOR", 4, 125466},
	{"BIRDCAGE", 8, 125467},
	{"REENACTMENT", 11, 125468},
	{"SUCCESFULLY", 11, 125469},
	{"VIRIDIAN", 8, 125470},
	{"LOGGERHEAD", 10, 125471},
	{"ASKIN", 5, 125472},
	{"WINCED", 6, 125473},
	{"IIIMF", 5, 125474},
	{"KAMIL", 5, 125475},
	{"VACS", 4, 125476},
	{"PETTERSSON", 10, 125477},
	{"OCCASSIONALLY", 13, 125478},
	{"STUDIA", 6, 125479},
	{"PEACEKEEPER", 11, 125480},
	{"LECLAIR", 7, 125481},
	{"WATERCRESS", 10, 125482},
	{"LUDO", 4, 125483},
	{"LITERATI", 8, 125484},
	{"GAFFER", 6, 125485},
	{"BINION", 6, 125486},
	{"YEPO", 4, 125487},
	{"WPEA", 4, 125488},
	{"TMIM", 4, 125489},
	{"PIAW", 4, 125490},
	{"OWDP", 4, 125491},
	{"NGHD", 4, 125492},
	{"LYNF", 4, 125493},
	{"LSJE", 4, 125494},
	{"JWIL", 4, 125495},
	{"ILQU", 4, 125496},
	{"DDCA", 4, 125497},
	{"PERIGEE", 7, 125498},
	{"ERUPTING", 8, 125499},
	{"MUNIZ", 5, 125500},
	{"ANGEWANDTE", 10, 125501},
	{"TROTTED", 7, 125502},
	{"HUNGRILY", 8, 125503},
	{"KCONFIG", 7, 125504},
	{"SCOLD", 5, 125505},
	{"TOPICSACTIVE", 12, 125506},
	{"FIREPROPERTYCHANGE", 18, 125507},
	{"SHUTOUTS", 8, 125508},
	{"WESTLEY", 7, 125509},
	{"AMRITA", 6, 125510},
	{"GREYHAWK", 8, 125511},
	{"FLOWMASTER", 10, 125512},
	{"EERDMANS", 8, 125513},
	{"MYSTERIO", 8, 125514},
	{"TUDE", 4, 125515},
	{"CHIRPING", 8, 125516},
	{"IMMATURITY", 10, 125517},
	{"DEWAN", 5, 125518},
	{"SEZIONE", 7, 125519},
	{"NEXSTAR", 7, 125520},
	{"TRESS", 5, 125521},
	{"DESIGNEES", 9, 125522},
	{"DELON", 5, 125523},
	{"MOURINHO", 8, 125524},
	{"MAGOO", 5, 125525},
	{"VAUNTED", 7, 125526},
	{"VENDO", 5, 125527},
	{"MITARBEITER", 11, 125528},
	{"WSCU", 4, 125529},
	{"QUAG", 4, 125530},
	{"OXFI", 4, 125531},
	{"OCEM", 4, 125532},
	{"ILUP", 4, 125533},
	{"FIXW", 4, 125534},
	{"EWUR", 4, 125535},
	{"CRYB", 4, 125536},
	{"IMVU", 4, 125537},
	{"ORANGEVALE", 10, 125538},
	{"PHUN", 4, 125539},
	{"NTERNATIONAL", 12, 125540},
	{"ASTRIDE", 7, 125541},
	{"ALCAZAR", 7, 125542},
	{"NOSTRO", 6, 125543},
	{"HDCP", 4, 125544},
	{"BONDHOLDERS", 11, 125545},
	{"SUNDARAM", 8, 125546},
	{"JACI", 4, 125547},
	{"DICHOTOMOUS", 11, 125548},
	{"SKILLETS", 8, 125549},
	{"GLITZY", 6, 125550},
	{"SZECHUAN", 8, 125551},
	{"TASTIC", 6, 125552},
	{"TWISTYS", 7, 125553},
	{"RUY", 3, 125554},
	{"PROUT", 5, 125555},
	{"DERMATOLOGIC", 12, 125556},
	{"PIPEX", 5, 125557},
	{"YRAF", 4, 125558},
	{"UFFG", 4, 125559},
	{"SOXY", 4, 125560},
	{"SMLI", 4, 125561},
	{"RKQU", 4, 125562},
	{"NGLD", 4, 125563},
	{"FKAI", 4, 125564},
	{"FFUP", 4, 125565},
	{"DSOG", 4, 125566},
	{"AIRK", 4, 125567},
	{"ADAQ", 4, 125568},
	{"RVV", 3, 125569},
	{"QUESTIONAIRE", 12, 125570},
	{"AUTOREGRESSIVE", 14, 125571},
	{"TENSIONER", 9, 125572},
	{"BUNG", 4, 125573},
	{"DELPHINIUM", 10, 125574},
	{"SELEC", 5, 125575},
	{"ZRZ", 3, 125576},
	{"ZMG", 3, 125577},
	{"ZLJ", 3, 125578},
	{"YXK", 3, 125579},
	{"VUX", 3, 125580},
	{"EMANCIPATED", 11, 125581},
	{"SUZAN", 5, 125582},
	{"ORDAIN", 6, 125583},
	{"UHURU", 5, 125584},
	{"PIKA", 4, 125585},
	{"CHINOIS", 7, 125586},
	{"LIBGCJ", 6, 125587},
	{"SPENCERS", 8, 125588},
	{"SALGADO", 7, 125589},
	{"ISOLEUCINE", 10, 125590},
	{"TERRANOVA", 9, 125591},
	{"ARTICOLO", 8, 125592},
	{"OCCLUSIVE", 9, 125593},
	{"DRAGONFORCE", 11, 125594},
	{"ACUSHNET", 8, 125595},
	{"VALLES", 6, 125596},
	{"RAPT", 4, 125597},
	{"CONJUNCTIVE", 11, 125598},
	{"WIRT", 4, 125599},
	{"OMARION", 7, 125600},
	{"APOPHIS", 7, 125601},
	{"XNUM", 4, 125602},
	{"NKJU", 4, 125603},
	{"NCIF", 4, 125604},
	{"MSWR", 4, 125605},
	{"FODI", 4, 125606},
	{"EYYE", 4, 125607},
	{"DOMV", 4, 125608},
	{"CHMR", 4, 125609},
	{"BTOG", 4, 125610},
	{"AGIB", 4, 125611},
	{"KRISTOL", 7, 125612},
	{"FOLIA", 5, 125613},
	{"SUBCULTURES", 11, 125614},
	{"SAWED", 5, 125615},
	{"MAREE", 5, 125616},
	{"RECEDED", 7, 125617},
	{"GAYOT", 5, 125618},
	{"ALGEMENE", 8, 125619},
	{"EMBOLDENED", 10, 125620},
	{"ATUL", 4, 125621},
	{"THEMATICALLY", 12, 125622},
	{"AMAZIN", 6, 125623},
	{"HALTERS", 7, 125624},
	{"SHERROD", 7, 125625},
	{"HELLIS", 6, 125626},
	{"EXPECTORANT", 11, 125627},
	{"PESSIMIST", 9, 125628},
	{"BALLA", 5, 125629},
	{"RESUSPENDED", 11, 125630},
	{"MULTISPORT", 10, 125631},
	{"FACK", 4, 125632},
	{"SEDATE", 6, 125633},
	{"MAHAYANA", 8, 125634},
	{"YOCL", 4, 125635},
	{"OMBF", 4, 125636},
	{"MDOR", 4, 125637},
	{"FECU", 4, 125638},
	{"DECF", 4, 125639},
	{"CICL", 4, 125640},
	{"BUSU", 4, 125641},
	{"AKHU", 4, 125642},
	{"RICANS", 6, 125643},
	{"OKAZAKI", 7, 125644},
	{"SUBORDER", 8, 125645},
	{"COMPLE", 6, 125646},
	{"AMBRA", 5, 125647},
	{"KLEINWALSERTAL", 14, 125648},
	{"DEPOSITIONAL", 12, 125649},
	{"KRISTAL", 7, 125650},
	{"COCKATIEL", 9, 125651},
	{"MRG", 3, 125652},
	{"CLOZAPINE", 9, 125653},
	{"FRANKING", 8, 125654},
	{"EGGSHELL", 8, 125655},
	{"PBP", 3, 125656},
	{"ESCHOOL", 7, 125657},
	{"DROW", 4, 125658},
	{"MINDSTORMS", 10, 125659},
	{"EUREX", 5, 125660},
	{"CONSIGNOR", 9, 125661},
	{"STOLTZ", 6, 125662},
	{"ZASSHI", 6, 125663},
	{"MUNG", 4, 125664},
	{"STAMMERED", 9, 125665},
	{"MONAURAL", 8, 125666},
	{"RESOUR", 6, 125667},
	{"CINEPLEX", 8, 125668},
	{"SUPPOSES", 8, 125669},
	{"ZZWO", 4, 125670},
	{"VRAN", 4, 125671},
	{"OYPE", 4, 125672},
	{"OSYL", 4, 125673},
	{"NKMC", 4, 125674},
	{"LRYF", 4, 125675},
	{"LITV", 4, 125676},
	{"GOAM", 4, 125677},
	{"CIVA", 4, 125678},
	{"AFIB", 4, 125679},
	{"IPRS", 4, 125680},
	{"PROMEGA", 7, 125681},
	{"LIBERALIZED", 11, 125682},
	{"IMPINGE", 7, 125683},
	{"SERIO", 5, 125684},
	{"SOLDOTNA", 8, 125685},
	{"SHOWGIRLS", 9, 125686},
	{"RUNABOUT", 8, 125687},
	{"GENTEEL", 7, 125688},
	{"COOMBE", 6, 125689},
	{"WAYCROSS", 8, 125690},
	{"ENGULF", 6, 125691},
	{"QUINTILES", 9, 125692},
	{"CYTOGENETICS", 12, 125693},
	{"HUGUENOT", 8, 125694},
	{"GLENSIDE", 8, 125695},
	{"SECONDARILY", 11, 125696},
	{"KEPLERIAN", 9, 125697},
	{"DREXLER", 7, 125698},
	{"MOISTURISER", 11, 125699},
	{"MILLBURN", 8, 125700},
	{"URFW", 4, 125701},
	{"RUCO", 4, 125702},
	{"ONZL", 4, 125703},
	{"OKTU", 4, 125704},
	{"OBFA", 4, 125705},
	{"NZAP", 4, 125706},
	{"NKOD", 4, 125707},
	{"FFCE", 4, 125708},
	{"DJAG", 4, 125709},
	{"CVIL", 4, 125710},
	{"CHYN", 4, 125711},
	{"AUMI", 4, 125712},
	{"INTRESTING", 10, 125713},
	{"DESPERADOS", 10, 125714},
	{"CONCATENATE", 11, 125715},
	{"INJEN", 5, 125716},
	{"EPICURUS", 8, 125717},
	{"BOURJOIS", 8, 125718},
	{"EVENTI", 6, 125719},
	{"TIDWELL", 7, 125720},
	{"CHAUFFEURS", 10, 125721},
	{"MAJORDOM", 8, 125722},
	{"ROUSSEL", 7, 125723},
	{"TRANSMEM", 8, 125724},
	{"GOUVERNEUR", 10, 125725},
	{"MAKEINFO", 8, 125726},
	{"UPU", 3, 125727},
	{"ROZI", 4, 125728},
	{"OYRO", 4, 125729},
	{"MRWE", 4, 125730},
	{"KDRU", 4, 125731},
	{"IFGR", 4, 125732},
	{"HURF", 4, 125733},
	{"HLUM", 4, 125734},
	{"HIFR", 4, 125735},
	{"FURU", 4, 125736},
	{"HANKERING", 9, 125737},
	{"DATASTORE", 9, 125738},
	{"HYPERCUBE", 9, 125739},
	{"INTRAMOLECULAR", 14, 125740},
	{"NORMANS", 7, 125741},
	{"ENUMERATING", 11, 125742},
	{"SPEEDER", 7, 125743},
	{"ORCHESTRATE", 11, 125744},
	{"FUJINON", 7, 125745},
	{"UNIPOLAR", 8, 125746},
	{"FRILLY", 6, 125747},
	{"UNICYCLE", 8, 125748},
	{"GUTTENBERG", 10, 125749},
	{"DIMOND", 6, 125750},
	{"CERAMICA", 8, 125751},
	{"THEISTS", 7, 125752},
	{"GILRS", 5, 125753},
	{"JAVEA", 5, 125754},
	{"HOMEROOM", 8, 125755},
	{"EIGRP", 5, 125756},
	{"SERACH", 6, 125757},
	{"NIGHTBREEDS", 11, 125758},
	{"ZLEF", 4, 125759},
	{"XRAC", 4, 125760},
	{"WAPL", 4, 125761},
	{"UCRO", 4, 125762},
	{"SYBI", 4, 125763},
	{"ROYG", 4, 125764},
	{"MUSG", 4, 125765},
	{"MSYA", 4, 125766},
	{"LNIK", 4, 125767},
	{"LKMO", 4, 125768},
	{"DGOM", 4, 125769},
	{"DDYG", 4, 125770},
	{"TOILING", 7, 125771},
	{"XBL", 3, 125772},
	{"ABSCESSES", 9, 125773},
	{"EMBRYOGENESIS", 13, 125774},
	{"NAKAI", 5, 125775},
	{"WIGMORE", 7, 125776},
	{"SEDDON", 6, 125777},
	{"MARKETOCRACY", 12, 125778},
	{"SUMM", 4, 125779},
	{"FOOTREST", 8, 125780},
	{"SOBOLEV", 7, 125781},
	{"LEVON", 5, 125782},
	{"TRISTA", 6, 125783},
	{"LORIN", 5, 125784},
	{"SPITEFUL", 8, 125785},
	{"LENINIST", 8, 125786},
	{"FUNKE", 5, 125787},
	{"WGAU", 4, 125788},
	{"UNUC", 4, 125789},
	{"MYJA", 4, 125790},
	{"LLMR", 4, 125791},
	{"FENF", 4, 125792},
	{"BAKS", 4, 125793},
	{"AYUK", 4, 125794},
	{"DEFAME", 6, 125795},
	{"AIRHEAD", 7, 125796},
	{"GATLIN", 6, 125797},
	{"GOVERNESS", 9, 125798},
	{"ROSHAN", 6, 125799},
	{"WCF", 3, 125800},
	{"STADIA", 6, 125801},
	{"SYSLOGD", 7, 125802},
	{"ALTERNATED", 10, 125803},
	{"TIGBLOGS", 8, 125804},
	{"MCCREA", 6, 125805},
	{"GOBO", 4, 125806},
	{"WHITTEMORE", 10, 125807},
	{"GRAMPIANS", 9, 125808},
	{"UTENTE", 6, 125809},
	{"BALLOU", 6, 125810},
	{"CANYONLANDS", 11, 125811},
	{"COLANDER", 8, 125812},
	{"ESPNSOCCERNET", 13, 125813},
	{"KUNTZ", 5, 125814},
	{"YSUT", 4, 125815},
	{"YAAL", 4, 125816},
	{"XTOC", 4, 125817},
	{"LPSF", 4, 125818},
	{"BYAQ", 4, 125819},
	{"TORTUGAS", 8, 125820},
	{"CROAK", 5, 125821},
	{"BSAC", 4, 125822},
	{"AMATORIALI", 10, 125823},
	{"INTRACOASTAL", 12, 125824},
	{"ABHOR", 5, 125825},
	{"ENNEAGRAM", 9, 125826},
	{"EARMARKS", 8, 125827},
	{"ROADRUNNERS", 11, 125828},
	{"PIKMIN", 6, 125829},
	{"JOBST", 5, 125830},
	{"LITTLEHAMPTON", 13, 125831},
	{"VOIDING", 7, 125832},
	{"MAREN", 5, 125833},
	{"PANKY", 5, 125834},
	{"SERIGRAPH", 9, 125835},
	{"COZAAR", 6, 125836},
	{"BOEK", 4, 125837},
	{"SPURTS", 6, 125838},
	{"CUBIST", 6, 125839},
	{"BRANDNEW", 8, 125840},
	{"DVG", 3, 125841},
	{"PEART", 5, 125842},
	{"ACCESSKEYS", 10, 125843},
	{"MUSHROOMHEAD", 12, 125844},
	{"ZEBULON", 7, 125845},
	{"WIEC", 4, 125846},
	{"WGEO", 4, 125847},
	{"VPAW", 4, 125848},
	{"VAMO", 4, 125849},
	{"MBUP", 4, 125850},
	{"KYSU", 4, 125851},
	{"HPED", 4, 125852},
	{"GGIT", 4, 125853},
	{"CFER", 4, 125854},
	{"LDPE", 4, 125855},
	{"COLLIES", 7, 125856},
	{"SCHUR", 5, 125857},
	{"REMAN", 5, 125858},
	{"KDB", 3, 125859},
	{"STABILISER", 10, 125860},
	{"HEADSPACE", 9, 125861},
	{"COOKMAN", 7, 125862},
	{"STAZIONE", 8, 125863},
	{"ZAMBOANGA", 9, 125864},
	{"DUDALEN", 7, 125865},
	{"XFER", 4, 125866},
	{"DOPEY", 5, 125867},
	{"QUIERES", 7, 125868},
	{"FACILITES", 9, 125869},
	{"KIDDE", 5, 125870},
	{"EPPY", 4, 125871},
	{"SMOTHERS", 8, 125872},
	{"ORNAMENTED", 10, 125873},
	{"FOXWORTHY", 9, 125874},
	{"DEVIOUSLY", 9, 125875},
	{"INEXORABLE", 10, 125876},
	{"ROEDER", 6, 125877},
	{"NORONHA", 7, 125878},
	{"CHERCHER", 8, 125879},
	{"THINSULATE", 10, 125880},
	{"KITANO", 6, 125881},
	{"HARMONIOUSLY", 12, 125882},
	{"CATALANO", 8, 125883},
	{"NIGHTFIRE", 9, 125884},
	{"RICARD", 6, 125885},
	{"APRILE", 6, 125886},
	{"XINW", 4, 125887},
	{"TURU", 4, 125888},
	{"TCFO", 4, 125889},
	{"SOYU", 4, 125890},
	{"ROGH", 4, 125891},
	{"RGIU", 4, 125892},
	{"NSPY", 4, 125893},
	{"GMUT", 4, 125894},
	{"FTYL", 4, 125895},
	{"ERCD", 4, 125896},
	{"EPRY", 4, 125897},
	{"BWEI", 4, 125898},
	{"BIGY", 4, 125899},
	{"BIJOUX", 6, 125900},
	{"WORSHIPING", 10, 125901},
	{"DLPPROJECTOR", 12, 125902},
	{"HEALTHWATCH", 11, 125903},
	{"AYMARA", 6, 125904},
	{"WILBRAHAM", 9, 125905},
	{"ALTADENA", 8, 125906},
	{"CORNWALLIS", 10, 125907},
	{"GEWICHT", 7, 125908},
	{"MYTHBUSTERS", 11, 125909},
	{"MICROFORMS", 10, 125910},
	{"LAUNDERED", 9, 125911},
	{"BESTEL", 6, 125912},
	{"HORNBAKER", 9, 125913},
	{"IMPROVISING", 11, 125914},
	{"VPER", 4, 125915},
	{"UNNW", 4, 125916},
	{"SMCH", 4, 125917},
	{"RXAN", 4, 125918},
	{"PPLC", 4, 125919},
	{"PBYF", 4, 125920},
	{"OYPL", 4, 125921},
	{"ORPF", 4, 125922},
	{"OBYB", 4, 125923},
	{"MAUC", 4, 125924},
	{"HYRU", 4, 125925},
	{"EILP", 4, 125926},
	{"DSKO", 4, 125927},
	{"TECHNI", 6, 125928},
	{"PEJMAN", 6, 125929},
	{"AUTOSPORT", 9, 125930},
	{"TROFF", 5, 125931},
	{"BIKRAM", 6, 125932},
	{"KAMPEN", 6, 125933},
	{"TIMP", 4, 125934},
	{"COOLLY", 6, 125935},
	{"PYOGENES", 8, 125936},
	{"DACOR", 5, 125937},
	{"LETOURNEAU", 10, 125938},
	{"PORTHOLE", 8, 125939},
	{"TRIPPLITE", 9, 125940},
	{"CORRES", 6, 125941},
	{"CRAWLABILITY", 12, 125942},
	{"PAOLINI", 7, 125943},
	{"TRIADS", 6, 125944},
	{"HYEON", 5, 125945},
	{"ACCOMPLI", 8, 125946},
	{"ZIEW", 4, 125947},
	{"UTYG", 4, 125948},
	{"TYIL", 4, 125949},
	{"TARQ", 4, 125950},
	{"RGTR", 4, 125951},
	{"REVM", 4, 125952},
	{"OPIG", 4, 125953},
	{"OCEP", 4, 125954},
	{"NDGW", 4, 125955},
	{"FFIB", 4, 125956},
	{"DUMW", 4, 125957},
	{"DTHG", 4, 125958},
	{"CIUD", 4, 125959},
	{"AUDL", 4, 125960},
	{"STRUMMING", 9, 125961},
	{"ROSINA", 6, 125962},
	{"LITHONIA", 8, 125963},
	{"AMBU", 4, 125964},
	{"TWEET", 5, 125965},
	{"GONZE", 5, 125966},
	{"DEMBSKI", 7, 125967},
	{"KUHL", 4, 125968},
	{"HOOBLY", 6, 125969},
	{"CANNULA", 7, 125970},
	{"LCB", 3, 125971},
	{"COTTONSEED", 10, 125972},
	{"ERBE", 4, 125973},
	{"TERRORIZE", 9, 125974},
	{"MCENROE", 7, 125975},
	{"GRAMMA", 6, 125976},
	{"REFORMULATION", 13, 125977},
	{"OSTEOMYELITIS", 13, 125978},
	{"VIEILLE", 7, 125979},
	{"LEERY", 5, 125980},
	{"OUELLETTE", 9, 125981},
	{"GROOVING", 8, 125982},
	{"SCHOPENHAUER", 12, 125983},
	{"YRIF", 4, 125984},
	{"VOFF", 4, 125985},
	{"VLOV", 4, 125986},
	{"SEYU", 4, 125987},
	{"OKBI", 4, 125988},
	{"OGPR", 4, 125989},
	{"NUMM", 4, 125990},
	{"IRKM", 4, 125991},
	{"EMTW", 4, 125992},
	{"DNAW", 4, 125993},
	{"DABNEY", 6, 125994},
	{"BEEKEEPER", 9, 125995},
	{"BETAINE", 7, 125996},
	{"GRAVURE", 7, 125997},
	{"ARCHIVERS", 9, 125998},
	{"SHEFF", 5, 125999},
	{"PROCRASTINATING", 15, 126000},
	{"NONRESIDENTS", 12, 126001},
	{"EDEBATE", 7, 126002},
	{"ELLOS", 5, 126003},
	{"OVERGROWTH", 10, 126004},
	{"HECHO", 5, 126005},
	{"INDENTINGNEWLINE", 16, 126006},
	{"IMSEAR", 6, 126007},
	{"PLAISTOW", 8, 126008},
	{"VERRY", 5, 126009},
	{"PROSODY", 7, 126010},
	{"HANNAFORD", 9, 126011},
	{"BATLEY", 6, 126012},
	{"XSAL", 4, 126013},
	{"PULV", 4, 126014},
	{"OBYF", 4, 126015},
	{"EDEJ", 4, 126016},
	{"AMUM", 4, 126017},
	{"ROWED", 5, 126018},
	{"LUTRON", 6, 126019},
	{"STYLINGS", 8, 126020},
	{"COMMITTAL", 9, 126021},
	{"RONMENTAL", 9, 126022},
	{"AZAM", 4, 126023},
	{"IMMA", 4, 126024},
	{"THEREMIN", 8, 126025},
	{"EXPLETIVE", 9, 126026},
	{"ELFIN", 5, 126027},
	{"IMPRESSIONISTS", 14, 126028},
	{"WIKIWEBMASTER", 13, 126029},
	{"BOOSEY", 6, 126030},
	{"PUNCHY", 6, 126031},
	{"EMOTE", 5, 126032},
	{"GRABBERS", 8, 126033},
	{"INGOTS", 6, 126034},
	{"MOUTHING", 8, 126035},
	{"BLOGGY", 6, 126036},
	{"UAMI", 4, 126037},
	{"TYOL", 4, 126038},
	{"RGBU", 4, 126039},
	{"PYBI", 4, 126040},
	{"POPF", 4, 126041},
	{"OEMM", 4, 126042},
	{"MAGP", 4, 126043},
	{"IVAD", 4, 126044},
	{"EYTY", 4, 126045},
	{"RIDDING", 7, 126046},
	{"COMMITTE", 8, 126047},
	{"SKUNKS", 6, 126048},
	{"UNIVERSITAIRE", 13, 126049},
	{"JANATA", 6, 126050},
	{"STANISLAW", 9, 126051},
	{"ASHTANGA", 8, 126052},
	{"MYEARTHLINK", 11, 126053},
	{"HAMPERING", 9, 126054},
	{"FILMFOUR", 8, 126055},
	{"BOLSTERING", 10, 126056},
	{"TRADENAMES", 10, 126057},
	{"GFR", 3, 126058},
	{"BATMOBILE", 9, 126059},
	{"TEGEN", 5, 126060},
	{"ORNAMENTALS", 11, 126061},
	{"ERAGON", 6, 126062},
	{"DEFERRALS", 9, 126063},
	{"EVIDENTIAL", 10, 126064},
	{"TROPPO", 6, 126065},
	{"GIER", 4, 126066},
	{"ESCALA", 6, 126067},
	{"MIDWEIGHT", 9, 126068},
	{"PINHEAD", 7, 126069},
	{"HUTU", 4, 126070},
	{"MEADS", 5, 126071},
	{"MYSPECIALSDIRECT", 16, 126072},
	{"EXHALED", 7, 126073},
	{"WWEM", 4, 126074},
	{"WCUL", 4, 126075},
	{"UIMP", 4, 126076},
	{"RPSD", 4, 126077},
	{"PKWA", 4, 126078},
	{"OYGA", 4, 126079},
	{"NVLA", 4, 126080},
	{"JUNS", 4, 126081},
	{"HAMV", 4, 126082},
	{"GHYD", 4, 126083},
	{"DEXL", 4, 126084},
	{"CSYN", 4, 126085},
	{"BACU", 4, 126086},
	{"INCUBATING", 10, 126087},
	{"LUXIST", 6, 126088},
	{"ERYKAH", 6, 126089},
	{"JERZEES", 7, 126090},
	{"EASYSPACE", 9, 126091},
	{"FOCUSRITE", 9, 126092},
	{"COLONIZE", 8, 126093},
	{"KANOTIX", 7, 126094},
	{"BCAA", 4, 126095},
	{"OZZFEST", 7, 126096},
	{"DEMOLISHING", 11, 126097},
	{"SZCZECIN", 8, 126098},
	{"JOBIM", 5, 126099},
	{"SPASTICITY", 10, 126100},
	{"UNDERTOW", 8, 126101},
	{"YLLD", 4, 126102},
	{"URDW", 4, 126103},
	{"UPTB", 4, 126104},
	{"RBSE", 4, 126105},
	{"PYCH", 4, 126106},
	{"ORNK", 4, 126107},
	{"NFLN", 4, 126108},
	{"FUSN", 4, 126109},
	{"FEGA", 4, 126110},
	{"EDMM", 4, 126111},
	{"COAP", 4, 126112},
	{"MADHOUSE", 8, 126113},
	{"LOUPE", 5, 126114},
	{"INFLUENT", 8, 126115},
	{"KIRIN", 5, 126116},
	{"JDEVELOPER", 10, 126117},
	{"SNIPPED", 7, 126118},
	{"OPENSERVER", 10, 126119},
	{"PRATIQUE", 8, 126120},
	{"CALABASH", 8, 126121},
	{"BETANCOURT", 10, 126122},
	{"TONGAN", 6, 126123},
	{"BRIGANTINE", 10, 126124},
	{"HUGIN", 5, 126125},
	{"VINEGARS", 8, 126126},
	{"RDX", 3, 126127},
	{"BURKHOLDERIA", 12, 126128},
	{"MILFHUNTERS", 11, 126129},
	{"HUEZ", 4, 126130},
	{"LATEROOMS", 9, 126131},
	{"ECONOLODGE", 10, 126132},
	{"CYCE", 4, 126133},
	{"JUMPY", 5, 126134},
	{"JIGGLE", 6, 126135},
	{"THUMNAILS", 9, 126136},
	{"HIPP", 4, 126137},
	{"INSTITUUT", 9, 126138},
	{"NEUROSPORA", 10, 126139},
	{"FITZHUGH", 8, 126140},
	{"OIKOS", 5, 126141},
	{"AVIEMORE", 8, 126142},
	{"TKINTER", 7, 126143},
	{"TOMMI", 5, 126144},
	{"RRTH", 4, 126145},
	{"KRYA", 4, 126146},
	{"KRUE", 4, 126147},
	{"KAFF", 4, 126148},
	{"HKOV", 4, 126149},
	{"FEFA", 4, 126150},
	{"EYPH", 4, 126151},
	{"EXUD", 4, 126152},
	{"BOYK", 4, 126153},
	{"AKSV", 4, 126154},
	{"TOMITA", 6, 126155},
	{"TRAVELSMITH", 11, 126156},
	{"LGC", 3, 126157},
	{"RIOTERS", 7, 126158},
	{"GBM", 3, 126159},
	{"WROC", 4, 126160},
	{"DVSX", 4, 126161},
	{"PERSECUTIONS", 12, 126162},
	{"DUFFELS", 7, 126163},
	{"ARRIVA", 6, 126164},
	{"MEDIACRAZY", 10, 126165},
	{"CRAMMING", 8, 126166},
	{"CHUCKLING", 9, 126167},
	{"CALCASIEU", 9, 126168},
	{"CASEDGE", 7, 126169},
	{"DISFIGURED", 10, 126170},
	{"MOUSSA", 6, 126171},
	{"HOLTER", 6, 126172},
	{"STRCASECMP", 10, 126173},
	{"REASSEMBLED", 11, 126174},
	{"BBEDIT", 6, 126175},
	{"DEPEW", 5, 126176},
	{"GUITARRA", 8, 126177},
	{"MERS", 4, 126178},
	{"ARTICULATIONS", 13, 126179},
	{"AMPERES", 7, 126180},
	{"MARGAUX", 7, 126181},
	{"JAVED", 5, 126182},
	{"YIJU", 4, 126183},
	{"WLBE", 4, 126184},
	{"PPAU", 4, 126185},
	{"LJAR", 4, 126186},
	{"KYOB", 4, 126187},
	{"IRMN", 4, 126188},
	{"IEMB", 4, 126189},
	{"GTHL", 4, 126190},
	{"GASJ", 4, 126191},
	{"FKMH", 4, 126192},
	{"EXIV", 4, 126193},
	{"EXAB", 4, 126194},
	{"CHTM", 4, 126195},
	{"POONS", 5, 126196},
	{"CITABLE", 7, 126197},
	{"WEATHERPIXIE", 12, 126198},
	{"HANDA", 5, 126199},
	{"CHIOS", 5, 126200},
	{"DOKKEN", 6, 126201},
	{"MARTINELLI", 10, 126202},
	{"GIRDERS", 7, 126203},
	{"PROVIGIL", 8, 126204},
	{"KOSTA", 5, 126205},
	{"MURO", 4, 126206},
	{"MOTORBOAT", 9, 126207},
	{"KLINK", 5, 126208},
	{"BUNDESBANK", 10, 126209},
	{"RUBIA", 5, 126210},
	{"EMPATHETIC", 10, 126211},
	{"WASTERS", 7, 126212},
	{"OREILLE", 7, 126213},
	{"VULGARE", 7, 126214},
	{"HEADPIECES", 10, 126215},
	{"DENPASAR", 8, 126216},
	{"ROBIE", 5, 126217},
	{"NAUVOO", 6, 126218},
	{"WENV", 4, 126219},
	{"TLEX", 4, 126220},
	{"MRKI", 4, 126221},
	{"KFER", 4, 126222},
	{"HYPL", 4, 126223},
	{"GZAG", 4, 126224},
	{"GEIC", 4, 126225},
	{"FKON", 4, 126226},
	{"GLENROTHES", 10, 126227},
	{"WILDSIDE", 8, 126228},
	{"EEPRODUCTCENTER", 15, 126229},
	{"OPENMP", 6, 126230},
	{"ARABICA", 7, 126231},
	{"PYLONS", 6, 126232},
	{"CRUNCHES", 8, 126233},
	{"SPHAGNUM", 8, 126234},
	{"LEEANN", 6, 126235},
	{"COREQUISITES", 12, 126236},
	{"INFIGHTING", 10, 126237},
	{"GROEP", 5, 126238},
	{"ELKIN", 5, 126239},
	{"HOTELIER", 8, 126240},
	{"RENFRO", 6, 126241},
	{"BRANAGH", 7, 126242},
	{"ZIPZOOMFLY", 10, 126243},
	{"TRANSCENDED", 11, 126244},
	{"TRATAMIENTO", 11, 126245},
	{"SUVARI", 6, 126246},
	{"MASPALOMAS", 10, 126247},
	{"BARAT", 5, 126248},
	{"WPLUG", 5, 126249},
	{"YRAH", 4, 126250},
	{"UGSD", 4, 126251},
	{"RKII", 4, 126252},
	{"REGP", 4, 126253},
	{"NKAK", 4, 126254},
	{"NJAG", 4, 126255},
	{"IUSJ", 4, 126256},
	{"FFSN", 4, 126257},
	{"EBCL", 4, 126258},
	{"LAFFY", 5, 126259},
	{"INTERMEZZO", 10, 126260},
	{"UCKFIELD", 8, 126261},
	{"MEMORYSTICK", 11, 126262},
	{"SELECTIN", 8, 126263},
	{"CUERPO", 6, 126264},
	{"BAXLEY", 6, 126265},
	{"STRNCPY", 7, 126266},
	{"REASSEMBLE", 10, 126267},
	{"PENTLAND", 8, 126268},
	{"NARAYANA", 8, 126269},
	{"AUBERGES", 8, 126270},
	{"LEGISLATING", 11, 126271},
	{"DEXTRAN", 7, 126272},
	{"GOYAL", 5, 126273},
	{"STATISTIQUE", 11, 126274},
	{"WPIA", 4, 126275},
	{"URAE", 4, 126276},
	{"RTIW", 4, 126277},
	{"MIXF", 4, 126278},
	{"MIPU", 4, 126279},
	{"IDLD", 4, 126280},
	{"CSAW", 4, 126281},
	{"NARAIN", 6, 126282},
	{"BIDETS", 6, 126283},
	{"FCCJ", 4, 126284},
	{"JEDIT", 5, 126285},
	{"HITOSHI", 7, 126286},
	{"ISHAM", 5, 126287},
	{"BRICKER", 7, 126288},
	{"COOKOUT", 7, 126289},
	{"PINBACK", 7, 126290},
	{"APPLEWORKS", 10, 126291},
	{"BORDELLO", 8, 126292},
	{"VIDEOTAPING", 11, 126293},
	{"FAINTEST", 8, 126294},
	{"BLEEK", 5, 126295},
	{"RUGGEDIZED", 10, 126296},
	{"MANAGEMENTS", 11, 126297},
	{"FISHBURNE", 9, 126298},
	{"SUBARACHNOID", 12, 126299},
	{"HSINCHU", 7, 126300},
	{"ADELA", 5, 126301},
	{"STRONGMAN", 9, 126302},
	{"GENITIVE", 8, 126303},
	{"DISALLOWANCE", 12, 126304},
	{"DIGITISED", 9, 126305},
	{"KITTITAS", 8, 126306},
	{"UNCAPPED", 8, 126307},
	{"CIVILE", 6, 126308},
	{"CARSWELL", 8, 126309},
	{"NOGGIN", 6, 126310},
	{"SHUTDOWNS", 9, 126311},
	{"OKSANA", 6, 126312},
	{"XICS", 4, 126313},
	{"WGLA", 4, 126314},
	{"PBYD", 4, 126315},
	{"LYNR", 4, 126316},
	{"LTSG", 4, 126317},
	{"LCKE", 4, 126318},
	{"KCEL", 4, 126319},
	{"IVAW", 4, 126320},
	{"IOFM", 4, 126321},
	{"GSED", 4, 126322},
	{"GGWA", 4, 126323},
	{"AKBO", 4, 126324},
	{"SHARERS", 7, 126325},
	{"FRAGS", 5, 126326},
	{"CORMACK", 7, 126327},
	{"ELOOK", 5, 126328},
	{"CONDIZIONI", 10, 126329},
	{"ILENE", 5, 126330},
	{"CAPTARIS", 8, 126331},
	{"REAC", 4, 126332},
	{"MEDIASTINAL", 11, 126333},
	{"PRODI", 5, 126334},
	{"MULTIGRID", 9, 126335},
	{"LABELER", 7, 126336},
	{"DAYPACK", 7, 126337},
	{"HAUPT", 5, 126338},
	{"MANIFESTOS", 10, 126339},
	{"MIKULSKI", 8, 126340},
	{"DIPOLES", 7, 126341},
	{"HAYAT", 5, 126342},
	{"WIKIWORDS", 9, 126343},
	{"QUOTTHE", 7, 126344},
	{"CUTENESS", 8, 126345},
	{"ZAVALA", 6, 126346},
	{"UGOD", 4, 126347},
	{"MBYI", 4, 126348},
	{"ENZU", 4, 126349},
	{"DDBE", 4, 126350},
	{"ALAQ", 4, 126351},
	{"AARL", 4, 126352},
	{"SIMD", 4, 126353},
	{"GUARANA", 7, 126354},
	{"LOCALWEATHER", 12, 126355},
	{"CHINGFORD", 9, 126356},
	{"ANRITSU", 7, 126357},
	{"KOMMUNIKATION", 13, 126358},
	{"NISBET", 6, 126359},
	{"VEDDER", 6, 126360},
	{"DISPERSIONS", 11, 126361},
	{"NUTZ", 4, 126362},
	{"SKATED", 6, 126363},
	{"TESTY", 5, 126364},
	{"SWINGMAN", 8, 126365},
	{"CEIVED", 6, 126366},
	{"RAKIM", 5, 126367},
	{"INSTALLFEST", 11, 126368},
	{"PHYSIOLOGIST", 12, 126369},
	{"YSAK", 4, 126370},
	{"YHEK", 4, 126371},
	{"RIXC", 4, 126372},
	{"PHLA", 4, 126373},
	{"MPMI", 4, 126374},
	{"KGOF", 4, 126375},
	{"JOBU", 4, 126376},
	{"IOCU", 4, 126377},
	{"HBYI", 4, 126378},
	{"DPUZ", 4, 126379},
	{"ANFB", 4, 126380},
	{"IMPRISON", 8, 126381},
	{"BERETS", 6, 126382},
	{"REPELLED", 8, 126383},
	{"PREAKNESS", 9, 126384},
	{"CSCW", 4, 126385},
	{"BEESTON", 7, 126386},
	{"BARBIES", 7, 126387},
	{"BAILY", 5, 126388},
	{"BREWPUB", 7, 126389},
	{"ABEND", 5, 126390},
	{"MARQUESS", 8, 126391},
	{"LACTIS", 6, 126392},
	{"YSGOLION", 8, 126393},
	{"TIPTRONIC", 9, 126394},
	{"PRECIPITATES", 12, 126395},
	{"NEWZ", 4, 126396},
	{"MORTISE", 7, 126397},
	{"NARDIN", 6, 126398},
	{"UNCONVINCING", 12, 126399},
	{"QUEM", 4, 126400},
	{"YRAG", 4, 126401},
	{"WBYN", 4, 126402},
	{"REZD", 4, 126403},
	{"PSFU", 4, 126404},
	{"PKIT", 4, 126405},
	{"NEUC", 4, 126406},
	{"BYLY", 4, 126407},
	{"BPHA", 4, 126408},
	{"UMMARY", 6, 126409},
	{"FIBRA", 5, 126410},
	{"TALLIS", 6, 126411},
	{"REORDERED", 9, 126412},
	{"ICEBOX", 6, 126413},
	{"CERR", 4, 126414},
	{"ULURU", 5, 126415},
	{"SCOUTER", 7, 126416},
	{"GRENACHE", 8, 126417},
	{"GAGGERS", 7, 126418},
	{"PHILCO", 6, 126419},
	{"DISBURSING", 10, 126420},
	{"SLEUTHS", 7, 126421},
	{"BRULEE", 6, 126422},
	{"RIJN", 4, 126423},
	{"METHICILLIN", 11, 126424},
	{"PLUNDERING", 10, 126425},
	{"KAVIAR", 6, 126426},
	{"ARAKI", 5, 126427},
	{"ABHORRENT", 9, 126428},
	{"VCJD", 4, 126429},
	{"BOLIN", 5, 126430},
	{"PROJEC", 6, 126431},
	{"DPTR", 4, 126432},
	{"BELATEDLY", 9, 126433},
	{"YBCE", 4, 126434},
	{"VBEC", 4, 126435},
	{"UENG", 4, 126436},
	{"TMEY", 4, 126437},
	{"TAWB", 4, 126438},
	{"NKPI", 4, 126439},
	{"NIXM", 4, 126440},
	{"MHYD", 4, 126441},
	{"IPGI", 4, 126442},
	{"GLEK", 4, 126443},
	{"FESK", 4, 126444},
	{"ETPC", 4, 126445},
	{"AWLT", 4, 126446},
	{"DIMERIZATION", 12, 126447},
	{"LUONG", 5, 126448},
	{"CCLRC", 5, 126449},
	{"GONADAL", 7, 126450},
	{"FRR", 3, 126451},
	{"COTILLION", 9, 126452},
	{"NEWSNIGHT", 9, 126453},
	{"GRANNYS", 7, 126454},
	{"FLOWMETERS", 10, 126455},
	{"GKRELLM", 7, 126456},
	{"STYMIED", 7, 126457},
	{"CASEROS", 7, 126458},
	{"REBELLIONS", 10, 126459},
	{"SYMPATHIZERS", 12, 126460},
	{"SMSC", 4, 126461},
	{"SCRIBBLING", 10, 126462},
	{"PHINEAS", 7, 126463},
	{"MELANESIA", 9, 126464},
	{"LINDENHURST", 11, 126465},
	{"FILMES", 6, 126466},
	{"XPLOR", 5, 126467},
	{"EMISSARY", 8, 126468},
	{"PALEOZOIC", 9, 126469},
	{"CHARIS", 6, 126470},
	{"MUSKRAT", 7, 126471},
	{"COMMUNIS", 8, 126472},
	{"YBYK", 4, 126473},
	{"XASU", 4, 126474},
	{"UKII", 4, 126475},
	{"GMYE", 4, 126476},
	{"GIFN", 4, 126477},
	{"FRIB", 4, 126478},
	{"FFSG", 4, 126479},
	{"ERKF", 4, 126480},
	{"EDIZ", 4, 126481},
	{"DLAL", 4, 126482},
	{"DDHE", 4, 126483},
	{"AWEW", 4, 126484},
	{"SOBIESKI", 8, 126485},
	{"HOOKSETT", 8, 126486},
	{"FAMI", 4, 126487},
	{"MCMEEL", 6, 126488},
	{"ARCHITECTUREWEEK", 16, 126489},
	{"SAIYAN", 6, 126490},
	{"BPF", 3, 126491},
	{"WEBFEEDS", 8, 126492},
	{"INHUMANITY", 10, 126493},
	{"SOUTHPAW", 8, 126494},
	{"JETFLASH", 8, 126495},
	{"GCF", 3, 126496},
	{"USCONTACT", 9, 126497},
	{"HUMBERT", 7, 126498},
	{"PODSAFE", 7, 126499},
	{"KACEY", 5, 126500},
	{"PRACA", 5, 126501},
	{"BELITTLE", 8, 126502},
	{"PRODGRP", 7, 126503},
	{"TAMARAC", 7, 126504},
	{"REPUDIATED", 10, 126505},
	{"UXDI", 4, 126506},
	{"RGMO", 4, 126507},
	{"RBEK", 4, 126508},
	{"PWEB", 4, 126509},
	{"OPMC", 4, 126510},
	{"ONXB", 4, 126511},
	{"NSUK", 4, 126512},
	{"NNBR", 4, 126513},
	{"BRUL", 4, 126514},
	{"BBIO", 4, 126515},
	{"AYMD", 4, 126516},
	{"DIVINA", 6, 126517},
	{"KUMI", 4, 126518},
	{"ALLOCA", 6, 126519},
	{"BTRIEVE", 7, 126520},
	{"ZOJIRUSHI", 9, 126521},
	{"CAIMAN", 6, 126522},
	{"LAROSE", 6, 126523},
	{"KEITHLEY", 8, 126524},
	{"NIMES", 5, 126525},
	{"WERSJA", 6, 126526},
	{"REHMAN", 6, 126527},
	{"PALAHNIUK", 9, 126528},
	{"IMPECCABLY", 10, 126529},
	{"MONONUCLEOSIS", 13, 126530},
	{"KAESER", 6, 126531},
	{"MUMBLES", 7, 126532},
	{"WESTBANK", 8, 126533},
	{"LEONIE", 6, 126534},
	{"MILLIKIN", 8, 126535},
	{"IPOWERWEB", 9, 126536},
	{"ADDIN", 5, 126537},
	{"NITROCELLULOSE", 14, 126538},
	{"AGAWAM", 6, 126539},
	{"OVERNITE", 8, 126540},
	{"RECOMMENDER", 11, 126541},
	{"SPECIALISM", 10, 126542},
	{"LITTMAN", 7, 126543},
	{"SXAV", 4, 126544},
	{"OLMW", 4, 126545},
	{"IFUR", 4, 126546},
	{"FGIB", 4, 126547},
	{"DVEC", 4, 126548},
	{"DUWA", 4, 126549},
	{"DKLE", 4, 126550},
	{"BROB", 4, 126551},
	{"AMVO", 4, 126552},
	{"BRAINED", 7, 126553},
	{"PYR", 3, 126554},
	{"CONCEPTUALIZED", 14, 126555},
	{"MONDRIAN", 8, 126556},
	{"TUNEUP", 6, 126557},
	{"PASTS", 5, 126558},
	{"LEXIKON", 7, 126559},
	{"ABSEILING", 9, 126560},
	{"SYMPATHETICALLY", 15, 126561},
	{"TEMPURA", 7, 126562},
	{"KANEKO", 6, 126563},
	{"PRIJZEN", 7, 126564},
	{"WDR", 3, 126565},
	{"NHMRC", 5, 126566},
	{"OCCURANCE", 9, 126567},
	{"MUKILTEO", 8, 126568},
	{"LASIX", 5, 126569},
	{"BANHART", 7, 126570},
	{"ENLARGMENT", 10, 126571},
	{"AWWWW", 5, 126572},
	{"CDPLAYER", 8, 126573},
	{"EMPTOR", 6, 126574},
	{"ALABASTRITE", 11, 126575},
	{"FLOATATION", 10, 126576},
	{"PERMET", 6, 126577},
	{"YHAC", 4, 126578},
	{"WARJ", 4, 126579},
	{"SKMW", 4, 126580},
	{"PDFF", 4, 126581},
	{"OVAF", 4, 126582},
	{"KTEM", 4, 126583},
	{"KPLE", 4, 126584},
	{"HSMU", 4, 126585},
	{"FTGO", 4, 126586},
	{"DRLA", 4, 126587},
	{"BOGD", 4, 126588},
	{"COMPOSES", 8, 126589},
	{"PEONIES", 7, 126590},
	{"PROSAFE", 7, 126591},
	{"EUROLEAGUE", 10, 126592},
	{"AOLSERVER", 9, 126593},
	{"SECUREDIGITAL", 13, 126594},
	{"KERSEY", 6, 126595},
	{"SAENZ", 5, 126596},
	{"OVERLEAF", 8, 126597},
	{"MANDRAKESOFT", 12, 126598},
	{"TAXMAN", 6, 126599},
	{"DIGITISATION", 12, 126600},
	{"RASP", 4, 126601},
	{"MYOSS", 5, 126602},
	{"SEEDERS", 7, 126603},
	{"BOBSLEIGH", 9, 126604},
	{"LIDDY", 5, 126605},
	{"SORIN", 5, 126606},
	{"MXL", 3, 126607},
	{"MELLEN", 6, 126608},
	{"VISITAS", 7, 126609},
	{"VEPS", 4, 126610},
	{"TUKR", 4, 126611},
	{"TADL", 4, 126612},
	{"SELJ", 4, 126613},
	{"RKVA", 4, 126614},
	{"RAYV", 4, 126615},
	{"ORRD", 4, 126616},
	{"EBSC", 4, 126617},
	{"STEPTOE", 7, 126618},
	{"LETICIA", 7, 126619},
	{"DEMYSTIFIED", 11, 126620},
	{"PETERSHAM", 9, 126621},
	{"COMERICA", 8, 126622},
	{"ALTURAS", 7, 126623},
	{"QUEENIE", 7, 126624},
	{"HEATHFIELD", 10, 126625},
	{"DYSART", 6, 126626},
	{"WHACKING", 8, 126627},
	{"AMADO", 5, 126628},
	{"INFIELDER", 9, 126629},
	{"DABEI", 5, 126630},
	{"FUCA", 4, 126631},
	{"HIRATA", 6, 126632},
	{"ERENCE", 6, 126633},
	{"LESKO", 5, 126634},
	{"GLIDDEN", 7, 126635},
	{"RADCLIFF", 8, 126636},
	{"KASHI", 5, 126637},
	{"BIORHYTHMS", 10, 126638},
	{"PAARE", 5, 126639},
	{"INTERLINKED", 11, 126640},
	{"UELN", 4, 126641},
	{"SUEU", 4, 126642},
	{"RGNO", 4, 126643},
	{"REVR", 4, 126644},
	{"IRIY", 4, 126645},
	{"IDKR", 4, 126646},
	{"PREGANT", 7, 126647},
	{"INTERLACE", 9, 126648},
	{"PJC", 3, 126649},
	{"STEALER", 7, 126650},
	{"HUMANOIDS", 9, 126651},
	{"LOACH", 5, 126652},
	{"INGLESINA", 9, 126653},
	{"PREPPY", 6, 126654},
	{"USHUAIA", 7, 126655},
	{"COBOURG", 7, 126656},
	{"ROLLICKING", 10, 126657},
	{"TELETHON", 8, 126658},
	{"NLUUG", 5, 126659},
	{"PARAMAGNETIC", 12, 126660},
	{"PRECONDITIONING", 15, 126661},
	{"MEMORISE", 8, 126662},
	{"OFFHAND", 7, 126663},
	{"CONSULTA", 8, 126664},
	{"UPEI", 4, 126665},
	{"DERS", 4, 126666},
	{"YGZ", 3, 126667},
	{"QQB", 3, 126668},
	{"PZF", 3, 126669},
	{"KZC", 3, 126670},
	{"CXG", 3, 126671},
	{"BXG", 3, 126672},
	{"BQG", 3, 126673},
	{"HARDCASTLE", 10, 126674},
	{"GERANIUMS", 9, 126675},
	{"HERBSTREIT", 10, 126676},
	{"UORL", 4, 126677},
	{"THMW", 4, 126678},
	{"IXKI", 4, 126679},
	{"IFIB", 4, 126680},
	{"GLIP", 4, 126681},
	{"GGPL", 4, 126682},
	{"AWCR", 4, 126683},
	{"ATYB", 4, 126684},
	{"AMTW", 4, 126685},
	{"AKME", 4, 126686},
	{"MCMICHAEL", 9, 126687},
	{"FARMSTEAD", 9, 126688},
	{"NIKWAX", 6, 126689},
	{"WELKOM", 6, 126690},
	{"MERIDIANS", 9, 126691},
	{"CEANN", 5, 126692},
	{"DOLLYWOOD", 9, 126693},
	{"RAWALPINDI", 10, 126694},
	{"TRANSPIRATION", 13, 126695},
	{"OTTERBEIN", 9, 126696},
	{"GPCRDB", 6, 126697},
	{"SUNCARE", 7, 126698},
	{"TRONICS", 7, 126699},
	{"PROTRUSION", 10, 126700},
	{"BASHFUL", 7, 126701},
	{"ALBACORE", 8, 126702},
	{"UNDERFLOW", 9, 126703},
	{"EVOCATION", 9, 126704},
	{"BARTRAM", 7, 126705},
	{"TABLEPLUGIN", 11, 126706},
	{"COGNITIVELY", 11, 126707},
	{"VIKTORIA", 8, 126708},
	{"DOZE", 4, 126709},
	{"STREPTOCOCCI", 12, 126710},
	{"MONOMERIC", 9, 126711},
	{"CURRANTS", 8, 126712},
	{"INFIX", 5, 126713},
	{"YGAU", 4, 126714},
	{"RBII", 4, 126715},
	{"PELG", 4, 126716},
	{"MWRE", 4, 126717},
	{"ICMY", 4, 126718},
	{"HUAW", 4, 126719},
	{"FSKA", 4, 126720},
	{"AKSHAY", 6, 126721},
	{"ENUMERATIONS", 12, 126722},
	{"STEEPEST", 8, 126723},
	{"LEAVIN", 6, 126724},
	{"MAXDB", 5, 126725},
	{"LIGHTNIN", 8, 126726},
	{"BOLSOVER", 8, 126727},
	{"MCCLENDON", 9, 126728},
	{"IRONMAIL", 8, 126729},
	{"DAUM", 4, 126730},
	{"LEDER", 5, 126731},
	{"CZECHOSLOVAKIAN", 15, 126732},
	{"SAILERS", 7, 126733},
	{"CONVEN", 6, 126734},
	{"CONTRIBU", 8, 126735},
	{"ZAHRA", 5, 126736},
	{"HEARTENING", 10, 126737},
	{"MRCS", 4, 126738},
	{"SCHLEICHER", 10, 126739},
	{"AFTERWORD", 9, 126740},
	{"YSEB", 4, 126741},
	{"UGOW", 4, 126742},
	{"RFIB", 4, 126743},
	{"NYUG", 4, 126744},
	{"MMCG", 4, 126745},
	{"MIKK", 4, 126746},
	{"MFUT", 4, 126747},
	{"LAXM", 4, 126748},
	{"COYN", 4, 126749},
	{"PRACTICA", 8, 126750},
	{"ROWNTREE", 8, 126751},
	{"TIMISOARA", 9, 126752},
	{"ABSOLVE", 7, 126753},
	{"LAMPSHADE", 9, 126754},
	{"SANTINI", 7, 126755},
	{"OPOIA", 5, 126756},
	{"HERTEL", 6, 126757},
	{"CONJECTURED", 11, 126758},
	{"MOYLE", 5, 126759},
	{"GRANDEST", 8, 126760},
	{"OPELOUSAS", 9, 126761},
	{"EROL", 4, 126762},
	{"DISINCENTIVES", 13, 126763},
	{"BARKERS", 7, 126764},
	{"KNIGHTON", 8, 126765},
	{"VDSL", 4, 126766},
	{"URBIS", 5, 126767},
	{"GEOPOTENTIAL", 12, 126768},
	{"OPPORTUNISM", 11, 126769},
	{"YNDH", 4, 126770},
	{"XTCL", 4, 126771},
	{"UKOR", 4, 126772},
	{"UBSN", 4, 126773},
	{"TUMG", 4, 126774},
	{"RKAW", 4, 126775},
	{"OAKM", 4, 126776},
	{"EKMT", 4, 126777},
	{"STELLENANGEBOTE", 15, 126778},
	{"PURPLES", 7, 126779},
	{"SIGPLAN", 7, 126780},
	{"INFOSHOP", 8, 126781},
	{"CLALLAM", 7, 126782},
	{"YOUNGGIRLS", 10, 126783},
	{"OPENAL", 6, 126784},
	{"CADOGAN", 7, 126785},
	{"EUROMONEY", 9, 126786},
	{"EOSINOPHILS", 11, 126787},
	{"RUNYON", 6, 126788},
	{"HIBBS", 5, 126789},
	{"CHOWK", 5, 126790},
	{"ADVANTIX", 8, 126791},
	{"KINSMEN", 7, 126792},
	{"JICA", 4, 126793},
	{"ABSORPTIVE", 10, 126794},
	{"LOADPARTS", 9, 126795},
	{"LIER", 4, 126796},
	{"FMCSA", 5, 126797},
	{"CIBER", 5, 126798},
	{"WEBBED", 6, 126799},
	{"WONK", 4, 126800},
	{"SEROLOGIC", 9, 126801},
	{"ENCAD", 5, 126802},
	{"GUADALCANAL", 11, 126803},
	{"ACETALDEHYDE", 12, 126804},
	{"MORELLO", 7, 126805},
	{"URNK", 4, 126806},
	{"SPUE", 4, 126807},
	{"PMSH", 4, 126808},
	{"MCOD", 4, 126809},
	{"KABY", 4, 126810},
	{"HRUD", 4, 126811},
	{"FLIL", 4, 126812},
	{"EMJO", 4, 126813},
	{"DRME", 4, 126814},
	{"BCWI", 4, 126815},
	{"AZYO", 4, 126816},
	{"BAUR", 4, 126817},
	{"PROCOL", 6, 126818},
	{"CURRITUCK", 9, 126819},
	{"LIRAS", 5, 126820},
	{"HEADTEACHERS", 12, 126821},
	{"GEODE", 5, 126822},
	{"SKLYAROV", 8, 126823},
	{"BAGNO", 5, 126824},
	{"NEURONES", 8, 126825},
	{"GRENADINE", 9, 126826},
	{"SLITTING", 8, 126827},
	{"LEXA", 4, 126828},
	{"TECHTRACKER", 11, 126829},
	{"PREECLAMPSIA", 12, 126830},
	{"CAPILENE", 8, 126831},
	{"KLAS", 4, 126832},
	{"SLAVIN", 6, 126833},
	{"IROCK", 5, 126834},
	{"NORIKO", 6, 126835},
	{"JANZEN", 6, 126836},
	{"GEAUGA", 6, 126837},
	{"SPORTBIKE", 9, 126838},
	{"CHAMBLISS", 9, 126839},
	{"FACTOIDS", 8, 126840},
	{"ACETYLATION", 11, 126841},
	{"ISOELECTRIC", 11, 126842},
	{"BRANHAM", 7, 126843},
	{"GRL", 3, 126844},
	{"XMUS", 4, 126845},
	{"WTEX", 4, 126846},
	{"UASW", 4, 126847},
	{"PBOU", 4, 126848},
	{"OJIB", 4, 126849},
	{"IODG", 4, 126850},
	{"IJER", 4, 126851},
	{"GUAA", 4, 126852},
	{"GINGKO", 6, 126853},
	{"WELK", 4, 126854},
	{"VALGRIND", 8, 126855},
	{"GRANDIS", 7, 126856},
	{"MASRI", 5, 126857},
	{"PIMPING", 7, 126858},
	{"BERGLUND", 8, 126859},
	{"YAYO", 4, 126860},
	{"SHIPWRECKED", 11, 126861},
	{"URACIL", 6, 126862},
	{"GDL", 3, 126863},
	{"RAKU", 4, 126864},
	{"VORONOI", 7, 126865},
	{"WELTERWEIGHT", 12, 126866},
	{"POSTERIORI", 10, 126867},
	{"EROTISCH", 8, 126868},
	{"AMIRA", 5, 126869},
	{"TACITLY", 7, 126870},
	{"GERONA", 6, 126871},
	{"AVONLEA", 7, 126872},
	{"SHUL", 4, 126873},
	{"FISCHERSPOONER", 14, 126874},
	{"XFAN", 4, 126875},
	{"UUMC", 4, 126876},
	{"OCTF", 4, 126877},
	{"NDOJ", 4, 126878},
	{"LKRU", 4, 126879},
	{"FDUC", 4, 126880},
	{"DJAL", 4, 126881},
	{"HILLENBRAND", 11, 126882},
	{"MAGNETIZED", 10, 126883},
	{"NEWBURG", 7, 126884},
	{"SALIENCE", 8, 126885},
	{"REVERBERATION", 13, 126886},
	{"LYUBOV", 6, 126887},
	{"SFTRET", 6, 126888},
	{"TROVA", 5, 126889},
	{"INDEPEN", 7, 126890},
	{"INTRINSICS", 10, 126891},
	{"KERRANG", 7, 126892},
	{"BUSINESSWIRE", 12, 126893},
	{"HAMBLETON", 9, 126894},
	{"PALMIERI", 8, 126895},
	{"CALENDARCALENDAR", 16, 126896},
	{"SAWFISH", 7, 126897},
	{"SAMMI", 5, 126898},
	{"TERADATA", 8, 126899},
	{"TOMMYS", 6, 126900},
	{"SPDC", 4, 126901},
	{"QUICKENING", 10, 126902},
	{"YAFRO", 5, 126903},
	{"RESHAPED", 8, 126904},
	{"XTAC", 4, 126905},
	{"VYTA", 4, 126906},
	{"UBYS", 4, 126907},
	{"TJAV", 4, 126908},
	{"OERU", 4, 126909},
	{"LBAH", 4, 126910},
	{"HIGP", 4, 126911},
	{"CSBI", 4, 126912},
	{"MILFRIDERS", 10, 126913},
	{"CLIK", 4, 126914},
	{"CHOLERAE", 8, 126915},
	{"WAAL", 4, 126916},
	{"DISNEYWORLD", 11, 126917},
	{"LETTERE", 7, 126918},
	{"KURKJIAN", 8, 126919},
	{"ROCKHOUNDS", 10, 126920},
	{"ARRI", 4, 126921},
	{"FANTA", 5, 126922},
	{"MISTOOK", 7, 126923},
	{"ASTRONOMIE", 10, 126924},
	{"HEADCOVERS", 10, 126925},
	{"ESCAP", 5, 126926},
	{"ZIPPING", 7, 126927},
	{"TANDON", 6, 126928},
	{"GERBERAS", 8, 126929},
	{"MESHED", 6, 126930},
	{"APPREHENSIONS", 13, 126931},
	{"TURKIYE", 7, 126932},
	{"ANYHOO", 6, 126933},
	{"SIMPSONVILLE", 12, 126934},
	{"EXHUMED", 7, 126935},
	{"OPPORTU", 7, 126936},
	{"XTGO", 4, 126937},
	{"WRTT", 4, 126938},
	{"WDWI", 4, 126939},
	{"VYSN", 4, 126940},
	{"UGCH", 4, 126941},
	{"UEEF", 4, 126942},
	{"SUFO", 4, 126943},
	{"RUZS", 4, 126944},
	{"PIDW", 4, 126945},
	{"OXBR", 4, 126946},
	{"NIXB", 4, 126947},
	{"LDYA", 4, 126948},
	{"HBLI", 4, 126949},
	{"FUNU", 4, 126950},
	{"MTSU", 4, 126951},
	{"MINIM", 5, 126952},
	{"AUNQUE", 6, 126953},
	{"SHUKLA", 6, 126954},
	{"TRUK", 4, 126955},
	{"TAPIA", 5, 126956},
	{"INKSTER", 7, 126957},
	{"KITZLER", 7, 126958},
	{"IMPERIALISTS", 12, 126959},
	{"CELESTINE", 9, 126960},
	{"NICKED", 6, 126961},
	{"FLM", 3, 126962},
	{"SCHOOLMASTER", 12, 126963},
	{"VERBIER", 7, 126964},
	{"DIVISORS", 8, 126965},
	{"CITRONELLA", 10, 126966},
	{"THROWAWAY", 9, 126967},
	{"STRAIGHTWAY", 11, 126968},
	{"CARAMELIZED", 11, 126969},
	{"RITY", 4, 126970},
	{"INFANTE", 7, 126971},
	{"SCBA", 4, 126972},
	{"WOMBLE", 6, 126973},
	{"SASOL", 5, 126974},
	{"KEETON", 6, 126975},
	{"JOYA", 4, 126976},
	{"LOKEN", 5, 126977},
	{"IMPRESSIONABLE", 14, 126978},
	{"GBLIST", 6, 126979},
	{"HAYTER", 6, 126980},
	{"GINGERLY", 8, 126981},
	{"APOLOGISED", 10, 126982},
	{"ACOM", 4, 126983},
	{"UHAU", 4, 126984},
	{"OSPY", 4, 126985},
	{"NKDU", 4, 126986},
	{"MYSQ", 4, 126987},
	{"IYUK", 4, 126988},
	{"FTSD", 4, 126989},
	{"FNOD", 4, 126990},
	{"DMIM", 4, 126991},
	{"AOPP", 4, 126992},
	{"LEEPER", 6, 126993},
	{"TACHO", 5, 126994},
	{"STORI", 5, 126995},
	{"SOLUCES", 7, 126996},
	{"FABRE", 5, 126997},
	{"PULS", 4, 126998},
	{"POLLEY", 6, 126999},
	{"EXPULSIONS", 10, 127000},
	{"RIVEN", 5, 127001},
	{"TAKETH", 6, 127002},
	{"CORNFIELD", 9, 127003},
	{"INTERFLORA", 10, 127004},
	{"FRETTING", 8, 127005},
	{"SUBZERO", 7, 127006},
	{"PAMLICO", 7, 127007},
	{"LEFTWICH", 8, 127008},
	{"FETTER", 6, 127009},
	{"AMALIE", 6, 127010},
	{"BABYZONE", 8, 127011},
	{"JEERS", 5, 127012},
	{"ENZYTE", 6, 127013},
	{"MANUFACTORY", 11, 127014},
	{"SOAKS", 5, 127015},
	{"PORCELAINE", 10, 127016},
	{"YSTB", 4, 127017},
	{"UVIR", 4, 127018},
	{"UKIW", 4, 127019},
	{"OULR", 4, 127020},
	{"OALV", 4, 127021},
	{"MTWE", 4, 127022},
	{"KKIS", 4, 127023},
	{"FFCI", 4, 127024},
	{"DKAB", 4, 127025},
	{"DGWA", 4, 127026},
	{"CSDU", 4, 127027},
	{"BENP", 4, 127028},
	{"BDID", 4, 127029},
	{"GTKHTML", 7, 127030},
	{"JARRED", 6, 127031},
	{"THEORIE", 7, 127032},
	{"PAKENHAM", 8, 127033},
	{"DELIMITATION", 12, 127034},
	{"MEGATRON", 8, 127035},
	{"LATIF", 5, 127036},
	{"UTRAN", 5, 127037},
	{"PRISMA", 6, 127038},
	{"ARMEN", 5, 127039},
	{"EROTASTECOM", 11, 127040},
	{"SIMPLENET", 9, 127041},
	{"BEWILDERMENT", 12, 127042},
	{"CONTRATO", 8, 127043},
	{"OPENWEBMAIL", 11, 127044},
	{"CHLORPYRIFOS", 12, 127045},
	{"MOONROOF", 8, 127046},
	{"LOVELINESS", 10, 127047},
	{"HIGHWOOD", 8, 127048},
	{"STILLWELL", 9, 127049},
	{"CALEA", 5, 127050},
	{"SURFICIAL", 9, 127051},
	{"VIOGNIER", 8, 127052},
	{"KINGFISH", 8, 127053},
	{"YLLF", 4, 127054},
	{"YBOI", 4, 127055},
	{"USUC", 4, 127056},
	{"UABE", 4, 127057},
	{"OLGU", 4, 127058},
	{"NKSJ", 4, 127059},
	{"MOPU", 4, 127060},
	{"HCOF", 4, 127061},
	{"ELAJ", 4, 127062},
	{"FIREBALLS", 9, 127063},
	{"GOBAIN", 6, 127064},
	{"ACANTHUS", 8, 127065},
	{"KAUL", 4, 127066},
	{"CORRELL", 7, 127067},
	{"NEXTDOOR", 8, 127068},
	{"REFRIGERANTS", 12, 127069},
	{"PRECAMBRIAN", 11, 127070},
	{"BLUEBIRDS", 9, 127071},
	{"MINISTERED", 10, 127072},
	{"BALONEY", 7, 127073},
	{"SABATIER", 8, 127074},
	{"INTELLIGIBILITY", 15, 127075},
	{"CIVICSPACE", 10, 127076},
	{"LUBIN", 5, 127077},
	{"IDIOMATIC", 9, 127078},
	{"XACA", 4, 127079},
	{"RIPK", 4, 127080},
	{"NEMR", 4, 127081},
	{"LIMD", 4, 127082},
	{"HMYE", 4, 127083},
	{"EUKM", 4, 127084},
	{"DMEU", 4, 127085},
	{"COMTEC", 6, 127086},
	{"JAWORSKI", 8, 127087},
	{"BAWUG", 5, 127088},
	{"FOOTINGS", 8, 127089},
	{"WAWA", 4, 127090},
	{"SCALPING", 8, 127091},
	{"LIDDED", 6, 127092},
	{"MENIFEE", 7, 127093},
	{"REINTRODUCE", 11, 127094},
	{"BRADFIELD", 9, 127095},
	{"EVALUE", 6, 127096},
	{"SUBTREES", 8, 127097},
	{"HARDBODY", 8, 127098},
	{"SUGA", 4, 127099},
	{"GFK", 3, 127100},
	{"NEUTRIK", 7, 127101},
	{"AUTOHARP", 8, 127102},
	{"ADAR", 4, 127103},
	{"EMBPERL", 7, 127104},
	{"SLAV", 4, 127105},
	{"DURDEN", 6, 127106},
	{"FREESE", 6, 127107},
	{"ATTICS", 6, 127108},
	{"INSTRUMENTALISTS", 16, 127109},
	{"WKIS", 4, 127110},
	{"RDEQ", 4, 127111},
	{"NKBL", 4, 127112},
	{"MRIE", 4, 127113},
	{"MBSE", 4, 127114},
	{"BFAI", 4, 127115},
	{"GREENBACK", 9, 127116},
	{"GLENFIELD", 9, 127117},
	{"WILHELMINA", 10, 127118},
	{"JOHNY", 5, 127119},
	{"DATATABLE", 9, 127120},
	{"OMELETS", 7, 127121},
	{"STILLSECURE", 11, 127122},
	{"MAGNI", 5, 127123},
	{"CPAC", 4, 127124},
	{"BAPTISTA", 8, 127125},
	{"KURTA", 5, 127126},
	{"HOULTON", 7, 127127},
	{"LIGHTSHIP", 9, 127128},
	{"HERBALISTS", 10, 127129},
	{"FINANCINGS", 10, 127130},
	{"INFURIATING", 11, 127131},
	{"DEBORA", 6, 127132},
	{"HITTIN", 6, 127133},
	{"RECOTON", 7, 127134},
	{"ODVD", 4, 127135},
	{"NOWQ", 4, 127136},
	{"NLIU", 4, 127137},
	{"MLYT", 4, 127138},
	{"GYGE", 4, 127139},
	{"PDGF", 4, 127140},
	{"HSYNC", 5, 127141},
	{"TABULOS", 7, 127142},
	{"BOUW", 4, 127143},
	{"HERMITS", 7, 127144},
	{"CHEEKTOWAGA", 11, 127145},
	{"OBSCENITIES", 11, 127146},
	{"RENWICK", 7, 127147},
	{"MANNION", 7, 127148},
	{"ILEC", 4, 127149},
	{"TYREE", 5, 127150},
	{"BKK", 3, 127151},
	{"PRESTRESSED", 11, 127152},
	{"GULLIES", 7, 127153},
	{"REFACTOR", 8, 127154},
	{"CSMA", 4, 127155},
	{"EXCLUS", 6, 127156},
	{"UNSHIELDED", 10, 127157},
	{"KAPPAB", 6, 127158},
	{"PRECALCULUS", 11, 127159},
	{"PANGAEA", 7, 127160},
	{"FAJITAS", 7, 127161},
	{"QUAERO", 6, 127162},
	{"KRAJEWSKI", 9, 127163},
	{"YHUD", 4, 127164},
	{"SPGA", 4, 127165},
	{"RODC", 4, 127166},
	{"RDYB", 4, 127167},
	{"OFUG", 4, 127168},
	{"MAEX", 4, 127169},
	{"HNPR", 4, 127170},
	{"FEBB", 4, 127171},
	{"EWOC", 4, 127172},
	{"EIFB", 4, 127173},
	{"DYFU", 4, 127174},
	{"BIFI", 4, 127175},
	{"MIRREN", 6, 127176},
	{"PREROGATIVES", 12, 127177},
	{"WEATHERSTRIP", 12, 127178},
	{"FALAFEL", 7, 127179},
	{"WHOPPER", 7, 127180},
	{"BLAK", 4, 127181},
	{"CHARGEBACK", 10, 127182},
	{"EMPLOIS", 7, 127183},
	{"FORECLOSE", 9, 127184},
	{"ZEROMANCER", 10, 127185},
	{"JURONG", 6, 127186},
	{"HISTOLOGICALLY", 14, 127187},
	{"TENNCARE", 8, 127188},
	{"KAMIK", 5, 127189},
	{"FLW", 3, 127190},
	{"ERCOT", 5, 127191},
	{"BANISHMENT", 10, 127192},
	{"VCAPS", 5, 127193},
	{"TEMPERING", 9, 127194},
	{"POTHOLE", 7, 127195},
	{"RROI", 4, 127196},
	{"RIXF", 4, 127197},
	{"OBCH", 4, 127198},
	{"NRER", 4, 127199},
	{"IXDO", 4, 127200},
	{"INRD", 4, 127201},
	{"FEBF", 4, 127202},
	{"EKGA", 4, 127203},
	{"ALMF", 4, 127204},
	{"KAMPF", 5, 127205},
	{"HYDER", 5, 127206},
	{"FALLACIOUS", 10, 127207},
	{"QUBITS", 6, 127208},
	{"ANTIPOLIS", 9, 127209},
	{"RENZO", 5, 127210},
	{"VESTMENTS", 9, 127211},
	{"HIRSH", 5, 127212},
	{"BULKHEADS", 9, 127213},
	{"MANAMA", 6, 127214},
	{"QUERCETIN", 9, 127215},
	{"MIXIN", 5, 127216},
	{"PROFITEERING", 12, 127217},
	{"MORSEL", 6, 127218},
	{"SUBNATIONAL", 11, 127219},
	{"LYALL", 5, 127220},
	{"REGI", 4, 127221},
	{"BLADECENTER", 11, 127222},
	{"ARALL", 5, 127223},
	{"RETFORD", 7, 127224},
	{"TURVY", 5, 127225},
	{"CAMPBELLS", 9, 127226},
	{"UTMB", 4, 127227},
	{"SHAREHOLDINGS", 13, 127228},
	{"FACULDADE", 9, 127229},
	{"ENDOVASCULAR", 12, 127230},
	{"NIFICANT", 8, 127231},
	{"CURVILINEAR", 11, 127232},
	{"MIRAFLORES", 10, 127233},
	{"FELINES", 7, 127234},
	{"SUGGS", 5, 127235},
	{"LENIENCY", 8, 127236},
	{"SHONEN", 6, 127237},
	{"WRYA", 4, 127238},
	{"OERW", 4, 127239},
	{"MCKN", 4, 127240},
	{"LMAF", 4, 127241},
	{"HUBR", 4, 127242},
	{"GOYE", 4, 127243},
	{"FHAG", 4, 127244},
	{"BWEB", 4, 127245},
	{"BMIL", 4, 127246},
	{"AFFG", 4, 127247},
	{"SHOBO", 5, 127248},
	{"CHANDLERS", 9, 127249},
	{"UNIVERSALS", 10, 127250},
	{"LODER", 5, 127251},
	{"GESICHTSBESAMUNG", 16, 127252},
	{"TIZIANO", 7, 127253},
	{"UNIFEM", 6, 127254},
	{"SILICATES", 9, 127255},
	{"PIZZAZZ", 7, 127256},
	{"YOUSEF", 6, 127257},
	{"BOWDITCH", 8, 127258},
	{"SITEDOWNLOAD", 12, 127259},
	{"SCRUPULOUS", 10, 127260},
	{"PROTRON", 7, 127261},
	{"THINNERS", 8, 127262},
	{"SNEED", 5, 127263},
	{"PINEDALE", 8, 127264},
	{"GADDIS", 6, 127265},
	{"HEGEMON", 7, 127266},
	{"ANTIPSYCHOTICS", 14, 127267},
	{"UNDERPASS", 9, 127268},
	{"ETHINYL", 7, 127269},
	{"WDOL", 4, 127270},
	{"WBEH", 4, 127271},
	{"VVIE", 4, 127272},
	{"RPCA", 4, 127273},
	{"OUEM", 4, 127274},
	{"OFLL", 4, 127275},
	{"MYRU", 4, 127276},
	{"KGIR", 4, 127277},
	{"HUDO", 4, 127278},
	{"ENKL", 4, 127279},
	{"BICW", 4, 127280},
	{"INTERNATIO", 10, 127281},
	{"SCHEMATICALLY", 13, 127282},
	{"EINAR", 5, 127283},
	{"FWP", 3, 127284},
	{"STUDER", 6, 127285},
	{"PLACEMARK", 9, 127286},
	{"APPLING", 7, 127287},
	{"SNOBS", 5, 127288},
	{"CARRICKFERGUS", 13, 127289},
	{"ACCELERATIONS", 13, 127290},
	{"RIVERSTONE", 10, 127291},
	{"FOUNTAINHEAD", 12, 127292},
	{"DEFLATOR", 8, 127293},
	{"HARDSHELL", 9, 127294},
	{"DERMATOLOGICAL", 14, 127295},
	{"CICA", 4, 127296},
	{"SCHENKER", 8, 127297},
	{"VENETA", 6, 127298},
	{"YUPPIES", 7, 127299},
	{"TOPOZONE", 8, 127300},
	{"CRITERIUM", 9, 127301},
	{"ENDSECTION", 10, 127302},
	{"PAPP", 4, 127303},
	{"SUBNETWORK", 10, 127304},
	{"ZAPO", 4, 127305},
	{"YIOW", 4, 127306},
	{"UMIK", 4, 127307},
	{"UBSG", 4, 127308},
	{"TLUR", 4, 127309},
	{"SKMH", 4, 127310},
	{"LROW", 4, 127311},
	{"KKAH", 4, 127312},
	{"FSIB", 4, 127313},
	{"EXGR", 4, 127314},
	{"EPDF", 4, 127315},
	{"HANSCOM", 7, 127316},
	{"PADDOCKS", 8, 127317},
	{"HELLMUTH", 8, 127318},
	{"WOODSMAN", 8, 127319},
	{"AKRAM", 5, 127320},
	{"DIGHTON", 7, 127321},
	{"AUDIOCABLE", 10, 127322},
	{"WYTHE", 5, 127323},
	{"BECKMANN", 8, 127324},
	{"TRIALWARE", 9, 127325},
	{"BIODEFENSE", 10, 127326},
	{"GAMESTORE", 9, 127327},
	{"PRESSINGS", 9, 127328},
	{"SOPORTE", 7, 127329},
	{"AUTECHRE", 8, 127330},
	{"CLEMMONS", 8, 127331},
	{"BOCCA", 5, 127332},
	{"TAXOL", 5, 127333},
	{"HOMELOANS", 9, 127334},
	{"HORGAN", 6, 127335},
	{"BINNEY", 6, 127336},
	{"AGUILA", 6, 127337},
	{"DICTA", 5, 127338},
	{"SCANMAKER", 9, 127339},
	{"SIPPS", 5, 127340},
	{"YVON", 4, 127341},
	{"CROSSDRESSER", 12, 127342},
	{"CHECHENS", 8, 127343},
	{"AJILON", 6, 127344},
	{"SUPERBREAK", 10, 127345},
	{"GAMEDAILY", 9, 127346},
	{"IKONBOARD", 9, 127347},
	{"DONNELLEY", 9, 127348},
	{"GUHA", 4, 127349},
	{"UDCH", 4, 127350},
	{"OELP", 4, 127351},
	{"MEISTEN", 7, 127352},
	{"ITKNOWLEDGE", 11, 127353},
	{"CORONERS", 8, 127354},
	{"KLICKITAT", 9, 127355},
	{"CORNYN", 6, 127356},
	{"REPAIRMAN", 9, 127357},
	{"CONJUNTO", 8, 127358},
	{"CAVALIERI", 9, 127359},
	{"TICINO", 6, 127360},
	{"SHIMA", 5, 127361},
	{"AUBERT", 6, 127362},
	{"MADONA", 6, 127363},
	{"CALWORKS", 8, 127364},
	{"CROISSANTS", 10, 127365},
	{"NAMIC", 5, 127366},
	{"GAMBAS", 6, 127367},
	{"LIPSTICKS", 9, 127368},
	{"RICHTIG", 7, 127369},
	{"FICE", 4, 127370},
	{"CLUMSILY", 8, 127371},
	{"UNCOMPRESS", 10, 127372},
	{"WINEFETCH", 9, 127373},
	{"HOMECLICK", 9, 127374},
	{"MICROG", 6, 127375},
	{"ARRANGERS", 9, 127376},
	{"ZIGZ", 4, 127377},
	{"YPMA", 4, 127378},
	{"YCOE", 4, 127379},
	{"WLAU", 4, 127380},
	{"VRED", 4, 127381},
	{"UNEY", 4, 127382},
	{"ODLY", 4, 127383},
	{"NDUO", 4, 127384},
	{"ISKG", 4, 127385},
	{"AXYA", 4, 127386},
	{"FREESTAR", 8, 127387},
	{"CATHOLIQUE", 10, 127388},
	{"SOMERTON", 8, 127389},
	{"LCRYPT", 6, 127390},
	{"HERMAPHRODITES", 14, 127391},
	{"ASHOKA", 6, 127392},
	{"AICP", 4, 127393},
	{"ACKLEY", 6, 127394},
	{"CALACANIS", 9, 127395},
	{"THRUWAY", 7, 127396},
	{"HIGGINBOTHAM", 12, 127397},
	{"PERON", 5, 127398},
	{"KEENEY", 6, 127399},
	{"PRATTVILLE", 10, 127400},
	{"BANKSIA", 7, 127401},
	{"DANAHER", 7, 127402},
	{"ENTEROCOCCUS", 12, 127403},
	{"OCONOMOWOC", 10, 127404},
	{"KINCARDINE", 10, 127405},
	{"YOUNGMAN", 8, 127406},
	{"STERILIZERS", 11, 127407},
	{"BISPHOSPHATE", 12, 127408},
	{"MILLIMETRES", 11, 127409},
	{"PICTUES", 7, 127410},
	{"TURPENTINE", 10, 127411},
	{"LPTHREAD", 8, 127412},
	{"ELLS", 4, 127413},
	{"KOICHI", 6, 127414},
	{"USAMA", 5, 127415},
	{"FUNCT", 5, 127416},
	{"BORRELIA", 8, 127417},
	{"XAML", 4, 127418},
	{"CUSSED", 6, 127419},
	{"HAGERMAN", 8, 127420},
	{"EVADED", 6, 127421},
	{"HARMONICAS", 10, 127422},
	{"SOURCECODE", 10, 127423},
	{"YAHY", 4, 127424},
	{"VAPA", 4, 127425},
	{"UZEL", 4, 127426},
	{"UELJ", 4, 127427},
	{"TLUM", 4, 127428},
	{"OKOP", 4, 127429},
	{"MPDA", 4, 127430},
	{"FAXC", 4, 127431},
	{"BUUREN", 6, 127432},
	{"BUSCANDO", 8, 127433},
	{"THICKETS", 8, 127434},
	{"CYBERNET", 8, 127435},
	{"DICEMBRE", 8, 127436},
	{"CLINK", 5, 127437},
	{"EMISSIVITY", 10, 127438},
	{"SPORK", 5, 127439},
	{"PONTCHARTRAIN", 13, 127440},
	{"PROJEKTE", 8, 127441},
	{"PERSONAGE", 9, 127442},
	{"GBX", 3, 127443},
	{"ACTUALIZATION", 13, 127444},
	{"NECTARINE", 9, 127445},
	{"ACDELCO", 7, 127446},
	{"RESPONSIBLITY", 13, 127447},
	{"LENORA", 6, 127448},
	{"DISCRIMINATIONS", 15, 127449},
	{"REENACT", 7, 127450},
	{"STEREOTACTIC", 12, 127451},
	{"WHEP", 4, 127452},
	{"UNYI", 4, 127453},
	{"MOBT", 4, 127454},
	{"GIOW", 4, 127455},
	{"GIJO", 4, 127456},
	{"FALZ", 4, 127457},
	{"EYNU", 4, 127458},
	{"DUEM", 4, 127459},
	{"DCWH", 4, 127460},
	{"DADP", 4, 127461},
	{"BNOW", 4, 127462},
	{"APEZ", 4, 127463},
	{"AGPU", 4, 127464},
	{"NDHUM", 5, 127465},
	{"CAVALLO", 7, 127466},
	{"CISG", 4, 127467},
	{"WILDSTORM", 9, 127468},
	{"DREDG", 5, 127469},
	{"CORLEONE", 8, 127470},
	{"VENDER", 6, 127471},
	{"GENSCAN", 7, 127472},
	{"ESTERASE", 8, 127473},
	{"DIPLOM", 6, 127474},
	{"METRIX", 6, 127475},
	{"VENABLE", 7, 127476},
	{"WHITESTONE", 10, 127477},
	{"TIMETABLING", 11, 127478},
	{"DAAR", 4, 127479},
	{"YATRA", 5, 127480},
	{"SOUNDPROOFING", 13, 127481},
	{"BOUCHE", 6, 127482},
	{"ZZAB", 4, 127483},
	{"YDYI", 4, 127484},
	{"WWRE", 4, 127485},
	{"RSIK", 4, 127486},
	{"PODG", 4, 127487},
	{"OLUP", 4, 127488},
	{"GNIM", 4, 127489},
	{"DRHI", 4, 127490},
	{"DOED", 4, 127491},
	{"DAEX", 4, 127492},
	{"DELINQUENTS", 11, 127493},
	{"CREUTZFELDT", 11, 127494},
	{"CHLORPROMAZINE", 14, 127495},
	{"BENEFITTING", 11, 127496},
	{"CRITIQUED", 9, 127497},
	{"PENDERGRASS", 11, 127498},
	{"FURLOUGH", 8, 127499},
	{"BUSSE", 5, 127500},
	{"ANGLETERRE", 10, 127501},
	{"SNARLING", 8, 127502},
	{"FLYORDIE", 8, 127503},
	{"SAMEDI", 6, 127504},
	{"CREAKING", 8, 127505},
	{"BEQUEATH", 8, 127506},
	{"TRAPANI", 7, 127507},
	{"BINKS", 5, 127508},
	{"SALVADORAN", 10, 127509},
	{"JETTING", 7, 127510},
	{"BRAZ", 4, 127511},
	{"SUBJUGATION", 11, 127512},
	{"BBBB", 4, 127513},
	{"KUMAMOTO", 8, 127514},
	{"SHEDD", 5, 127515},
	{"AMPA", 4, 127516},
	{"ISYNC", 5, 127517},
	{"CWP", 3, 127518},
	{"FELTING", 7, 127519},
	{"JAFFRAY", 7, 127520},
	{"VACHS", 5, 127521},
	{"RAYLENE", 7, 127522},
	{"GAPE", 4, 127523},
	{"PORFOLIO", 8, 127524},
	{"CLIFFSIDE", 9, 127525},
	{"COLORVISION", 11, 127526},
	{"VENEMA", 6, 127527},
	{"FABACEAE", 8, 127528},
	{"ALCALA", 6, 127529},
	{"YGUR", 4, 127530},
	{"UYTI", 4, 127531},
	{"RKYS", 4, 127532},
	{"MCOC", 4, 127533},
	{"LFOI", 4, 127534},
	{"IMYS", 4, 127535},
	{"HZER", 4, 127536},
	{"HBYF", 4, 127537},
	{"FTPU", 4, 127538},
	{"FBAH", 4, 127539},
	{"EAFB", 4, 127540},
	{"DECB", 4, 127541},
	{"ABCW", 4, 127542},
	{"NEWSREEL", 8, 127543},
	{"FINALISING", 10, 127544},
	{"CLOPIDOGREL", 11, 127545},
	{"INJECTS", 7, 127546},
	{"CALPINE", 7, 127547},
	{"SNAME", 5, 127548},
	{"CLASE", 5, 127549},
	{"BHUTTO", 6, 127550},
	{"THINGIE", 7, 127551},
	{"WILKIN", 6, 127552},
	{"NODULAR", 7, 127553},
	{"STILLBIRTH", 10, 127554},
	{"INTERNALIZE", 11, 127555},
	{"KIARIE", 6, 127556},
	{"CATALYZES", 9, 127557},
	{"UNQUESTIONABLE", 14, 127558},
	{"PRENDRE", 7, 127559},
	{"CONSERVES", 9, 127560},
	{"ETHIOPIC", 8, 127561},
	{"HOLLISTON", 9, 127562},
	{"EGUIDE", 6, 127563},
	{"ABIL", 4, 127564},
	{"CHLOROPLASTS", 12, 127565},
	{"IRRITATES", 9, 127566},
	{"MIKLOS", 6, 127567},
	{"RAGAZZA", 7, 127568},
	{"WYCHWOOD", 8, 127569},
	{"MEGALITH", 8, 127570},
	{"REUNITES", 8, 127571},
	{"MYLAN", 5, 127572},
	{"HANDWASHING", 11, 127573},
	{"BELLEFONTE", 10, 127574},
	{"TDIX", 4, 127575},
	{"PSTW", 4, 127576},
	{"PAWT", 4, 127577},
	{"MOTR", 4, 127578},
	{"MHAW", 4, 127579},
	{"LRUI", 4, 127580},
	{"LKWE", 4, 127581},
	{"KGUY", 4, 127582},
	{"IOQU", 4, 127583},
	{"IDRY", 4, 127584},
	{"EXSM", 4, 127585},
	{"EDRC", 4, 127586},
	{"DSSY", 4, 127587},
	{"ABUJ", 4, 127588},
	{"NEXTSTEP", 8, 127589},
	{"ATTENUATE", 9, 127590},
	{"BEETLEJUICE", 11, 127591},
	{"JUICING", 7, 127592},
	{"CHARMEUSE", 9, 127593},
	{"STOCHASTICS", 11, 127594},
	{"CONTATTACI", 10, 127595},
	{"DANDRIDGE", 9, 127596},
	{"UPGRADABLE", 10, 127597},
	{"VELOCE", 6, 127598},
	{"HOFFER", 6, 127599},
	{"INSMOD", 6, 127600},
	{"ALSIP", 5, 127601},
	{"SOLLY", 5, 127602},
	{"PLANTAS", 7, 127603},
	{"MORPHOLOGICALLY", 15, 127604},
	{"DEALNEWS", 8, 127605},
	{"EDISTO", 6, 127606},
	{"WHIGS", 5, 127607},
	{"WEIRS", 5, 127608},
	{"OPTORITE", 8, 127609},
	{"SHILL", 5, 127610},
	{"INTERREG", 8, 127611},
	{"ROEL", 4, 127612},
	{"YPHS", 4, 127613},
	{"YCOG", 4, 127614},
	{"UMCE", 4, 127615},
	{"UGUP", 4, 127616},
	{"TKAP", 4, 127617},
	{"TDUD", 4, 127618},
	{"PGUN", 4, 127619},
	{"MRRI", 4, 127620},
	{"LMVP", 4, 127621},
	{"HUVA", 4, 127622},
	{"GDRY", 4, 127623},
	{"FLCH", 4, 127624},
	{"BREO", 4, 127625},
	{"SCRITTO", 7, 127626},
	{"PCW", 3, 127627},
	{"VINTNERS", 8, 127628},
	{"SUNSEEKER", 9, 127629},
	{"DURKIN", 6, 127630},
	{"MARJORAM", 8, 127631},
	{"DESPATCHES", 10, 127632},
	{"WDFW", 4, 127633},
	{"CIRCULATORS", 11, 127634},
	{"BHUBANESWAR", 11, 127635},
	{"TOLLE", 5, 127636},
	{"ISOTONIC", 8, 127637},
	{"FEMS", 4, 127638},
	{"CONCESSIONAL", 12, 127639},
	{"APLENTY", 7, 127640},
	{"YOKOTA", 6, 127641},
	{"DEEDED", 6, 127642},
	{"WNWR", 4, 127643},
	{"VABI", 4, 127644},
	{"RAEC", 4, 127645},
	{"OLKV", 4, 127646},
	{"IVPO", 4, 127647},
	{"FSYA", 4, 127648},
	{"DRYH", 4, 127649},
	{"KRUMLOV", 7, 127650},
	{"WEBPRONEWS", 10, 127651},
	{"TITIAN", 6, 127652},
	{"AMARAL", 6, 127653},
	{"SPEICHER", 8, 127654},
	{"BOSSY", 5, 127655},
	{"TILIA", 5, 127656},
	{"SCHAMLIPPEN", 11, 127657},
	{"CHRISTER", 8, 127658},
	{"DBADMIN", 7, 127659},
	{"MILFRIDER", 9, 127660},
	{"CRESSWELL", 9, 127661},
	{"COLLIMATOR", 10, 127662},
	{"HIGHBALL", 8, 127663},
	{"CCDA", 4, 127664},
	{"PRESUPPOSITIONS", 15, 127665},
	{"NEUROSURGEON", 12, 127666},
	{"TRACHEOSTOMY", 12, 127667},
	{"GAINEY", 6, 127668},
	{"AETIOLOGY", 9, 127669},
	{"REITERATING", 11, 127670},
	{"EPITAXY", 7, 127671},
	{"CYNICS", 6, 127672},
	{"LELC", 4, 127673},
	{"KDAM", 4, 127674},
	{"KAYF", 4, 127675},
	{"IEFV", 4, 127676},
	{"GURK", 4, 127677},
	{"BOPR", 4, 127678},
	{"EPHONE", 6, 127679},
	{"ARRAS", 5, 127680},
	{"SPINELESS", 9, 127681},
	{"RICKI", 5, 127682},
	{"DITHER", 6, 127683},
	{"ESPAGNOL", 8, 127684},
	{"XCCESSORY", 9, 127685},
	{"FATHOMS", 7, 127686},
	{"AUSTRADE", 8, 127687},
	{"WEBMONKEY", 9, 127688},
	{"KIEFFER", 7, 127689},
	{"REAUTHORIZE", 11, 127690},
	{"PRINTEMPS", 9, 127691},
	{"BUSEY", 5, 127692},
	{"MONTECRISTO", 11, 127693},
	{"PRICERANGE", 10, 127694},
	{"NEUROPSYCHIATRIC", 16, 127695},
	{"MARRS", 5, 127696},
	{"IDEOLOGUES", 10, 127697},
	{"ELYSEE", 6, 127698},
	{"XHUM", 4, 127699},
	{"VREM", 4, 127700},
	{"UBHI", 4, 127701},
	{"TKEM", 4, 127702},
	{"RBEO", 4, 127703},
	{"PSYN", 4, 127704},
	{"MEIK", 4, 127705},
	{"KEKR", 4, 127706},
	{"HEKP", 4, 127707},
	{"FSEG", 4, 127708},
	{"EZUM", 4, 127709},
	{"EKCI", 4, 127710},
	{"EIDD", 4, 127711},
	{"GOTTSCHALK", 10, 127712},
	{"PHYSIC", 6, 127713},
	{"NUPTIAL", 7, 127714},
	{"SHOVELING", 9, 127715},
	{"GOLDENBERG", 10, 127716},
	{"MINNEHAHA", 9, 127717},
	{"NONRESPONSE", 11, 127718},
	{"WIREIMAGE", 9, 127719},
	{"UTENA", 5, 127720},
	{"THICKEST", 8, 127721},
	{"EXTERNE", 7, 127722},
	{"DAPHNIA", 7, 127723},
	{"BULBOUS", 7, 127724},
	{"THAKUR", 6, 127725},
	{"PARASITISM", 10, 127726},
	{"RECOMENDATIONS", 14, 127727},
	{"WHIST", 5, 127728},
	{"MUSSER", 6, 127729},
	{"CUERNAVACA", 10, 127730},
	{"HARRI", 5, 127731},
	{"COLLATERALIZED", 14, 127732},
	{"MIEUX", 5, 127733},
	{"DARAUF", 6, 127734},
	{"ZZAI", 4, 127735},
	{"SIPL", 4, 127736},
	{"MKID", 4, 127737},
	{"MEIP", 4, 127738},
	{"LPFA", 4, 127739},
	{"KVIR", 4, 127740},
	{"KEYJ", 4, 127741},
	{"HJAR", 4, 127742},
	{"GMAH", 4, 127743},
	{"CTXV", 4, 127744},
	{"CGIV", 4, 127745},
	{"STORAGES", 8, 127746},
	{"MARAE", 5, 127747},
	{"LINDT", 5, 127748},
	{"EXPOUND", 7, 127749},
	{"BIOGEOGRAPHIC", 13, 127750},
	{"MANDAL", 6, 127751},
	{"PEPPERELL", 9, 127752},
	{"EXHILARATION", 12, 127753},
	{"XWIKI", 5, 127754},
	{"HERC", 4, 127755},
	{"DESIGNZ", 7, 127756},
	{"NECKWEAR", 8, 127757},
	{"ZIEL", 4, 127758},
	{"BOSTWICK", 8, 127759},
	{"LORDSHIPS", 9, 127760},
	{"CHANCED", 7, 127761},
	{"ANTARTICA", 9, 127762},
	{"STONEWORK", 9, 127763},
	{"CAMOUFLAGED", 11, 127764},
	{"CROCO", 5, 127765},
	{"WAGENER", 7, 127766},
	{"YHOB", 4, 127767},
	{"UEUP", 4, 127768},
	{"TYMC", 4, 127769},
	{"RMUH", 4, 127770},
	{"OVBE", 4, 127771},
	{"OOPU", 4, 127772},
	{"NWIP", 4, 127773},
	{"MIBA", 4, 127774},
	{"LODU", 4, 127775},
	{"JAYR", 4, 127776},
	{"FMST", 4, 127777},
	{"FATD", 4, 127778},
	{"BAIB", 4, 127779},
	{"HUERTA", 6, 127780},
	{"LOCKBOX", 7, 127781},
	{"FOLICA", 6, 127782},
	{"FASTENINGS", 10, 127783},
	{"COMFREY", 7, 127784},
	{"SAYID", 5, 127785},
	{"FLANIGAN", 8, 127786},
	{"MILKMAN", 7, 127787},
	{"POLLSTERS", 9, 127788},
	{"INEXACT", 7, 127789},
	{"POLDER", 6, 127790},
	{"WARDELL", 7, 127791},
	{"EIDOLON", 7, 127792},
	{"IPMASQ", 6, 127793},
	{"REMODELERS", 10, 127794},
	{"LEARNDIRECT", 11, 127795},
	{"STARLINK", 8, 127796},
	{"BLAM", 4, 127797},
	{"HYOGO", 5, 127798},
	{"MCCRAE", 6, 127799},
	{"YDWI", 4, 127800},
	{"TYOC", 4, 127801},
	{"TXVI", 4, 127802},
	{"RAKK", 4, 127803},
	{"OFND", 4, 127804},
	{"NDNF", 4, 127805},
	{"DPYR", 4, 127806},
	{"DOGU", 4, 127807},
	{"CYEV", 4, 127808},
	{"CKOO", 4, 127809},
	{"CAMT", 4, 127810},
	{"BRAO", 4, 127811},
	{"ATDY", 4, 127812},
	{"LIVEDEAL", 8, 127813},
	{"PICTURS", 7, 127814},
	{"KETCH", 5, 127815},
	{"DOPA", 4, 127816},
	{"CODIFY", 6, 127817},
	{"JAME", 4, 127818},
	{"VSOLJ", 5, 127819},
	{"TREELESS", 8, 127820},
	{"IPMI", 4, 127821},
	{"ADORES", 6, 127822},
	{"ZXB", 3, 127823},
	{"ZRV", 3, 127824},
	{"XMV", 3, 127825},
	{"WZF", 3, 127826},
	{"WJV", 3, 127827},
	{"VWY", 3, 127828},
	{"VVK", 3, 127829},
	{"VJP", 3, 127830},
	{"RJX", 3, 127831},
	{"KQX", 3, 127832},
	{"JYW", 3, 127833},
	{"GQD", 3, 127834},
	{"FWQ", 3, 127835},
	{"MERKEZ", 6, 127836},
	{"SEPHARDIC", 9, 127837},
	{"SAMOYED", 7, 127838},
	{"BERENSON", 8, 127839},
	{"MELVYN", 6, 127840},
	{"RESOURCEFULNESS", 15, 127841},
	{"STEARIC", 7, 127842},
	{"AGROUND", 7, 127843},
	{"APPLIC", 6, 127844},
	{"LEGIAN", 6, 127845},
	{"SPLENDIDLY", 10, 127846},
	{"FEUILLE", 7, 127847},
	{"DOBIE", 5, 127848},
	{"ZLEW", 4, 127849},
	{"ZESR", 4, 127850},
	{"YDGE", 4, 127851},
	{"RURE", 4, 127852},
	{"IKUD", 4, 127853},
	{"FFYW", 4, 127854},
	{"DOZI", 4, 127855},
	{"AZYF", 4, 127856},
	{"INATTENTION", 11, 127857},
	{"INTEGRALLY", 10, 127858},
	{"OSGOODE", 7, 127859},
	{"ZOELLICK", 8, 127860},
	{"ENNISCORTHY", 11, 127861},
	{"PARKWOOD", 8, 127862},
	{"VAND", 4, 127863},
	{"TELECHARGE", 10, 127864},
	{"REDWING", 7, 127865},
	{"KITCH", 5, 127866},
	{"DISCOLORED", 10, 127867},
	{"INTERDEPENDENCIES", 17, 127868},
	{"ARSENAULT", 9, 127869},
	{"PUTCO", 5, 127870},
	{"SETANTA", 7, 127871},
	{"REDEVELOP", 9, 127872},
	{"UNIVERSITI", 10, 127873},
	{"TRAF", 4, 127874},
	{"CULLINAN", 8, 127875},
	{"HEDY", 4, 127876},
	{"YOGE", 4, 127877},
	{"VISJ", 4, 127878},
	{"UOWI", 4, 127879},
	{"UOFO", 4, 127880},
	{"TLAZ", 4, 127881},
	{"RMJU", 4, 127882},
	{"PIOL", 4, 127883},
	{"NIXL", 4, 127884},
	{"MWAK", 4, 127885},
	{"MBYE", 4, 127886},
	{"LEOG", 4, 127887},
	{"DUOW", 4, 127888},
	{"SINNING", 7, 127889},
	{"PRONUNCIATIONS", 14, 127890},
	{"MACSLASH", 8, 127891},
	{"JOUER", 5, 127892},
	{"UNTAGGED", 8, 127893},
	{"MAXEY", 5, 127894},
	{"FORESTALL", 9, 127895},
	{"VATER", 5, 127896},
	{"BELLMORE", 8, 127897},
	{"MANCUSO", 7, 127898},
	{"MOSELLE", 7, 127899},
	{"CORRINE", 7, 127900},
	{"JOAKIM", 6, 127901},
	{"MUCKING", 7, 127902},
	{"GNAWING", 7, 127903},
	{"PROLINK", 7, 127904},
	{"HASHIM", 6, 127905},
	{"ABTEILUNG", 9, 127906},
	{"GASSER", 6, 127907},
	{"FIMO", 4, 127908},
	{"DINWIDDIE", 9, 127909},
	{"UNCATEGORISED", 13, 127910},
	{"MALATHION", 9, 127911},
	{"BISWAS", 6, 127912},
	{"CRUDELY", 7, 127913},
	{"PREPPING", 8, 127914},
	{"CIOC", 4, 127915},
	{"BOUCLE", 6, 127916},
	{"TESTAMENTARY", 12, 127917},
	{"REPW", 4, 127918},
	{"OCQU", 4, 127919},
	{"NPEC", 4, 127920},
	{"JEMA", 4, 127921},
	{"EGUP", 4, 127922},
	{"DDSF", 4, 127923},
	{"CKEC", 4, 127924},
	{"ADOK", 4, 127925},
	{"CILIARY", 7, 127926},
	{"SAPLINGS", 8, 127927},
	{"MINARDI", 7, 127928},
	{"BAYBERRY", 8, 127929},
	{"BICEP", 5, 127930},
	{"ABSECON", 7, 127931},
	{"REUS", 4, 127932},
	{"MENACHEM", 8, 127933},
	{"OTHERWORLDLY", 12, 127934},
	{"MOLESTERS", 9, 127935},
	{"DESPAIRING", 10, 127936},
	{"PROFUSE", 7, 127937},
	{"DRD", 3, 127938},
	{"DISPELLING", 10, 127939},
	{"ATTAINMENTS", 11, 127940},
	{"UNSELECT", 8, 127941},
	{"VINCRISTINE", 11, 127942},
	{"ALLROAD", 7, 127943},
	{"SHERMANS", 8, 127944},
	{"INSTRUM", 7, 127945},
	{"YYMMDD", 6, 127946},
	{"SUGIYAMA", 8, 127947},
	{"MAROONS", 7, 127948},
	{"COUCHED", 7, 127949},
	{"ALOK", 4, 127950},
	{"BESTOWS", 7, 127951},
	{"FIRSTGATE", 9, 127952},
	{"MONEYBOOKERS", 12, 127953},
	{"INTERFEROMETRIC", 15, 127954},
	{"RICKETS", 7, 127955},
	{"YVAU", 4, 127956},
	{"TVBR", 4, 127957},
	{"RVAU", 4, 127958},
	{"RFSA", 4, 127959},
	{"OWLD", 4, 127960},
	{"OEDM", 4, 127961},
	{"LCOE", 4, 127962},
	{"GOPW", 4, 127963},
	{"FNEY", 4, 127964},
	{"ETYU", 4, 127965},
	{"DKOB", 4, 127966},
	{"CRAL", 4, 127967},
	{"CIMM", 4, 127968},
	{"BEIC", 4, 127969},
	{"APOM", 4, 127970},
	{"PULLERS", 7, 127971},
	{"COSTED", 6, 127972},
	{"CCCS", 4, 127973},
	{"HONORARIUM", 10, 127974},
	{"WAIPAHU", 7, 127975},
	{"TRADITIONALISTS", 15, 127976},
	{"TEXTDRIVE", 9, 127977},
	{"HIROSE", 6, 127978},
	{"CORYELL", 7, 127979},
	{"BASECAMP", 8, 127980},
	{"ANSEARCH", 8, 127981},
	{"DAYLESFORD", 10, 127982},
	{"PENARTH", 7, 127983},
	{"GEOCODING", 9, 127984},
	{"WOWS", 4, 127985},
	{"MOSSBERG", 8, 127986},
	{"KIWIFRUIT", 9, 127987},
	{"HOROLOGY", 8, 127988},
	{"SCHEDE", 6, 127989},
	{"PARTICULARITY", 13, 127990},
	{"OUNV", 4, 127991},
	{"MREB", 4, 127992},
	{"ESBC", 4, 127993},
	{"DTJR", 4, 127994},
	{"AOKL", 4, 127995},
	{"AKIP", 4, 127996},
	{"FLOODWATERS", 11, 127997},
	{"ASGARD", 6, 127998},
	{"SOFTS", 5, 127999},
	{"MONOPOLIST", 10, 128000},
	{"KNIGHTHOOD", 10, 128001},
	{"BLESSES", 7, 128002},
	{"PASTRANA", 8, 128003},
	{"STEBBINS", 8, 128004},
	{"PRODOTTO", 8, 128005},
	{"UMDNJ", 5, 128006},
	{"LDM", 3, 128007},
	{"DURE", 4, 128008},
	{"LUNES", 5, 128009},
	{"GRAPHIQUE", 9, 128010},
	{"BORDERLANDS", 11, 128011},
	{"STOOPING", 8, 128012},
	{"SICKENED", 8, 128013},
	{"GLOBETROTTERS", 13, 128014},
	{"WAVELAND", 8, 128015},
	{"REQUISITIONING", 14, 128016},
	{"CANTEENS", 8, 128017},
	{"FULDA", 5, 128018},
	{"GADFLYER", 8, 128019},
	{"BIOLA", 5, 128020},
	{"TRILUG", 6, 128021},
	{"THOROUGHFARES", 13, 128022},
	{"WDUE", 4, 128023},
	{"WBAB", 4, 128024},
	{"VPAT", 4, 128025},
	{"NPMS", 4, 128026},
	{"MPWO", 4, 128027},
	{"KKAT", 4, 128028},
	{"ILVY", 4, 128029},
	{"HSKY", 4, 128030},
	{"EUKP", 4, 128031},
	{"ATBP", 4, 128032},
	{"ELICITATION", 11, 128033},
	{"DONATELLO", 9, 128034},
	{"DURAL", 5, 128035},
	{"LOGA", 4, 128036},
	{"LOWENSTEIN", 10, 128037},
	{"PIERCY", 6, 128038},
	{"AGUSTA", 6, 128039},
	{"PENNILESS", 9, 128040},
	{"LAPIN", 5, 128041},
	{"THROMBOEMBOLISM", 15, 128042},
	{"IBADAN", 6, 128043},
	{"MOUNTLAKE", 9, 128044},
	{"ELLESSE", 7, 128045},
	{"HINWEISE", 8, 128046},
	{"ABROGATED", 9, 128047},
	{"PETERBILT", 9, 128048},
	{"KAZUMA", 6, 128049},
	{"GERMLINE", 8, 128050},
	{"DRUCK", 5, 128051},
	{"ZOPPINI", 7, 128052},
	{"RESON", 5, 128053},
	{"KINGSHIP", 8, 128054},
	{"SQUASHING", 9, 128055},
	{"ICPSR", 5, 128056},
	{"FAMILIENDICKE", 13, 128057},
	{"PUIS", 4, 128058},
	{"XTTU", 4, 128059},
	{"PYET", 4, 128060},
	{"PEZO", 4, 128061},
	{"OFQI", 4, 128062},
	{"MRSJ", 4, 128063},
	{"HRIK", 4, 128064},
	{"GEGG", 4, 128065},
	{"CYES", 4, 128066},
	{"CDSI", 4, 128067},
	{"HEHEHEHE", 8, 128068},
	{"DIMITRIOS", 9, 128069},
	{"ALGOL", 5, 128070},
	{"MANES", 5, 128071},
	{"CETACEANS", 9, 128072},
	{"TAMARINDO", 9, 128073},
	{"TECHREPORT", 10, 128074},
	{"MIKEM", 5, 128075},
	{"KARNES", 6, 128076},
	{"RETRENCHMENT", 12, 128077},
	{"PUNCTURES", 9, 128078},
	{"RELAPSING", 9, 128079},
	{"ARCADIAN", 8, 128080},
	{"MOBERLY", 7, 128081},
	{"CLAUD", 5, 128082},
	{"BOLLARDS", 8, 128083},
	{"SWART", 5, 128084},
	{"SAIYUKI", 7, 128085},
	{"RECONFIGURING", 13, 128086},
	{"ZIWA", 4, 128087},
	{"UVIL", 4, 128088},
	{"UMIR", 4, 128089},
	{"UGFI", 4, 128090},
	{"SUCT", 4, 128091},
	{"RROH", 4, 128092},
	{"LKBO", 4, 128093},
	{"KFLE", 4, 128094},
	{"IBMP", 4, 128095},
	{"EUTL", 4, 128096},
	{"MOBSTERS", 8, 128097},
	{"BIRTHDATES", 10, 128098},
	{"RANSON", 6, 128099},
	{"RMD", 3, 128100},
	{"GDBM", 4, 128101},
	{"MAGURA", 6, 128102},
	{"SCREED", 6, 128103},
	{"ESCHEW", 6, 128104},
	{"KEVAN", 5, 128105},
	{"KOHALA", 6, 128106},
	{"KANTER", 6, 128107},
	{"VANDA", 5, 128108},
	{"RONKONKOMA", 10, 128109},
	{"RQM", 3, 128110},
	{"UNICENTER", 9, 128111},
	{"VASTNESS", 8, 128112},
	{"AMNIOCENTESIS", 13, 128113},
	{"DYDD", 4, 128114},
	{"STEAKHOUSES", 11, 128115},
	{"BURDOCK", 7, 128116},
	{"ZAPP", 4, 128117},
	{"SPYRECON", 8, 128118},
	{"PERERA", 6, 128119},
	{"EXTERNALITY", 11, 128120},
	{"PAGANO", 6, 128121},
	{"YASUDA", 6, 128122},
	{"MCCARTHYISM", 11, 128123},
	{"SMALLBUSINESS", 13, 128124},
	{"INITIATIONS", 11, 128125},
	{"PRECIPITOUS", 11, 128126},
	{"BARNHILL", 8, 128127},
	{"DELEON", 6, 128128},
	{"OPPOSITIONS", 11, 128129},
	{"WALLIN", 6, 128130},
	{"DETACHMENTS", 11, 128131},
	{"SWIFTS", 6, 128132},
	{"TECNICO", 7, 128133},
	{"ZYBU", 4, 128134},
	{"XAME", 4, 128135},
	{"WUSI", 4, 128136},
	{"TCYR", 4, 128137},
	{"SYDA", 4, 128138},
	{"REYU", 4, 128139},
	{"RERY", 4, 128140},
	{"PIGA", 4, 128141},
	{"OXMO", 4, 128142},
	{"OIRF", 4, 128143},
	{"GMHA", 4, 128144},
	{"HARBISON", 8, 128145},
	{"VERSIONPRINTABLE", 16, 128146},
	{"SCHERZO", 7, 128147},
	{"YOUNIS", 6, 128148},
	{"CHROMATE", 8, 128149},
	{"ARSENALS", 8, 128150},
	{"IREDALE", 7, 128151},
	{"NYBERG", 6, 128152},
	{"HOOFD", 5, 128153},
	{"METRODOME", 9, 128154},
	{"CARPOOLING", 10, 128155},
	{"TRAMPING", 8, 128156},
	{"VIEJA", 5, 128157},
	{"HILUX", 5, 128158},
	{"LIBGNOMEUI", 10, 128159},
	{"MICROENTERPRISE", 15, 128160},
	{"THEREABOUTS", 11, 128161},
	{"LIDA", 4, 128162},
	{"DISCAPS", 7, 128163},
	{"QCP", 3, 128164},
	{"HAKAN", 5, 128165},
	{"BLOED", 5, 128166},
	{"KALO", 4, 128167},
	{"NEMETH", 6, 128168},
	{"WEALD", 5, 128169},
	{"RESULTAT", 8, 128170},
	{"ZTRA", 4, 128171},
	{"YLUK", 4, 128172},
	{"WDEB", 4, 128173},
	{"UBYT", 4, 128174},
	{"TAGB", 4, 128175},
	{"RBHI", 4, 128176},
	{"QWIT", 4, 128177},
	{"PEUG", 4, 128178},
	{"ARCM", 4, 128179},
	{"KAMEL", 5, 128180},
	{"BETROTHED", 9, 128181},
	{"MGCL", 4, 128182},
	{"POURQUOI", 8, 128183},
	{"OVERVALUED", 10, 128184},
	{"BLOOMERS", 8, 128185},
	{"ITERATING", 9, 128186},
	{"DISPELLED", 9, 128187},
	{"ROMAJI", 6, 128188},
	{"LOWFAT", 6, 128189},
	{"UNEXPLODED", 10, 128190},
	{"CACERES", 7, 128191},
	{"HOSSAIN", 7, 128192},
	{"DICEY", 5, 128193},
	{"INTERRUPTIBLE", 13, 128194},
	{"IMAGEMATE", 9, 128195},
	{"GYNNWYS", 7, 128196},
	{"HOCUS", 5, 128197},
	{"UPTM", 4, 128198},
	{"UIPE", 4, 128199},
	{"UGEU", 4, 128200},
	{"SKAK", 4, 128201},
	{"LAEV", 4, 128202},
	{"KKAD", 4, 128203},
	{"HBYW", 4, 128204},
	{"GUIO", 4, 128205},
	{"FEAD", 4, 128206},
	{"CELD", 4, 128207},
	{"AAQU", 4, 128208},
	{"PRENUPTIAL", 10, 128209},
	{"PIERROT", 7, 128210},
	{"TRETINOIN", 9, 128211},
	{"COLLECTIBL", 10, 128212},
	{"TATRA", 5, 128213},
	{"DUCA", 4, 128214},
	{"ADJAB", 5, 128215},
	{"UNITI", 5, 128216},
	{"SAMENESS", 8, 128217},
	{"LANDY", 5, 128218},
	{"GARMAN", 6, 128219},
	{"LYIN", 4, 128220},
	{"DISRAELI", 8, 128221},
	{"KUIPERS", 7, 128222},
	{"HENWOOD", 7, 128223},
	{"SCRUPLES", 8, 128224},
	{"COEXISTING", 10, 128225},
	{"SLEEPIN", 7, 128226},
	{"OKER", 4, 128227},
	{"ARAPAHO", 7, 128228},
	{"INTENSO", 7, 128229},
	{"GLOVED", 6, 128230},
	{"YOCE", 4, 128231},
	{"YCAF", 4, 128232},
	{"SOMC", 4, 128233},
	{"SKMT", 4, 128234},
	{"MRSK", 4, 128235},
	{"LSHM", 4, 128236},
	{"JAZE", 4, 128237},
	{"FROE", 4, 128238},
	{"ACAW", 4, 128239},
	{"TESTORS", 7, 128240},
	{"FIDELIS", 7, 128241},
	{"BOWHUNTING", 10, 128242},
	{"HOTNESS", 7, 128243},
	{"DODGES", 6, 128244},
	{"REBUFFED", 8, 128245},
	{"KINGWIN", 7, 128246},
	{"DOWDY", 5, 128247},
	{"VIRGILIO", 8, 128248},
	{"DECADAL", 7, 128249},
	{"TOMOGRAPHIC", 11, 128250},
	{"BRIARCLIFF", 10, 128251},
	{"CLAMORING", 9, 128252},
	{"NANDO", 5, 128253},
	{"GILDAN", 6, 128254},
	{"VCASH", 5, 128255},
	{"WORDSMITH", 9, 128256},
	{"AGUAS", 5, 128257},
	{"FIDUCIARIES", 11, 128258},
	{"GROUTING", 8, 128259},
	{"CHEVIOT", 7, 128260},
	{"YABD", 4, 128261},
	{"WLFO", 4, 128262},
	{"UPVO", 4, 128263},
	{"ULSL", 4, 128264},
	{"TUGO", 4, 128265},
	{"TOYL", 4, 128266},
	{"TAPW", 4, 128267},
	{"ROSV", 4, 128268},
	{"OGGR", 4, 128269},
	{"NFRY", 4, 128270},
	{"LSUA", 4, 128271},
	{"IPIL", 4, 128272},
	{"FLUL", 4, 128273},
	{"AKMI", 4, 128274},
	{"VISITATIONS", 11, 128275},
	{"KALMBACH", 8, 128276},
	{"SOUTHSEA", 8, 128277},
	{"ALICEBOT", 8, 128278},
	{"SANSOM", 6, 128279},
	{"MVSKIP", 6, 128280},
	{"POLYOLEFIN", 10, 128281},
	{"AFFINIA", 7, 128282},
	{"METROBLOGGING", 13, 128283},
	{"DOMINIOS", 8, 128284},
	{"RIVOLI", 6, 128285},
	{"RECKLESSNESS", 12, 128286},
	{"ATHEROS", 7, 128287},
	{"STIRRUPS", 8, 128288},
	{"MWD", 3, 128289},
	{"MUZAK", 5, 128290},
	{"CROSSPOINT", 10, 128291},
	{"EURATOM", 7, 128292},
	{"INTIMATED", 9, 128293},
	{"ALLSPICE", 8, 128294},
	{"DINGWALL", 8, 128295},
	{"SQUIRMING", 9, 128296},
	{"THUNDERSTRUCK", 13, 128297},
	{"PLEIADES", 8, 128298},
	{"SURREPTITIOUSLY", 15, 128299},
	{"HOMEBUILT", 9, 128300},
	{"SUSTANON", 8, 128301},
	{"CORANTO", 7, 128302},
	{"BRITIAN", 7, 128303},
	{"AMETURE", 7, 128304},
	{"FINERY", 6, 128305},
	{"UCTN", 4, 128306},
	{"TDVD", 4, 128307},
	{"SMSB", 4, 128308},
	{"RLGR", 4, 128309},
	{"PPIW", 4, 128310},
	{"PHDE", 4, 128311},
	{"OULH", 4, 128312},
	{"NIWR", 4, 128313},
	{"LMYO", 4, 128314},
	{"IYAW", 4, 128315},
	{"GSIW", 4, 128316},
	{"FCYP", 4, 128317},
	{"CRER", 4, 128318},
	{"COTU", 4, 128319},
	{"AVUT", 4, 128320},
	{"ABUE", 4, 128321},
	{"TUAL", 4, 128322},
	{"EGOV", 4, 128323},
	{"KABOOSE", 7, 128324},
	{"EREG", 4, 128325},
	{"MODERNA", 7, 128326},
	{"CLUBBERS", 8, 128327},
	{"HOUSEWEB", 8, 128328},
	{"RIALS", 5, 128329},
	{"RHONA", 5, 128330},
	{"EYAL", 4, 128331},
	{"AWDURDOD", 8, 128332},
	{"GENETICIST", 10, 128333},
	{"MONTEFIORE", 10, 128334},
	{"LANGEN", 6, 128335},
	{"DIBBLE", 6, 128336},
	{"AVVOCATO", 8, 128337},
	{"LINDANE", 7, 128338},
	{"SCITEC", 6, 128339},
	{"PROCRASTINATE", 13, 128340},
	{"TEKNIK", 6, 128341},
	{"TRANSITING", 10, 128342},
	{"ECOREGION", 9, 128343},
	{"UPSTARTS", 8, 128344},
	{"HORSETAIL", 9, 128345},
	{"ROLLAWAYS", 9, 128346},
	{"RNSV", 4, 128347},
	{"RAYK", 4, 128348},
	{"OAKD", 4, 128349},
	{"NLUR", 4, 128350},
	{"MBSB", 4, 128351},
	{"LEYY", 4, 128352},
	{"LAUP", 4, 128353},
	{"DIMF", 4, 128354},
	{"DIGB", 4, 128355},
	{"DDUX", 4, 128356},
	{"BRASHER", 7, 128357},
	{"TMAX", 4, 128358},
	{"YSTOD", 5, 128359},
	{"EUGENIE", 7, 128360},
	{"SEQUESTERED", 11, 128361},
	{"SCHLUCKEN", 9, 128362},
	{"CREATI", 6, 128363},
	{"DAYBEDS", 7, 128364},
	{"HIPSTERS", 8, 128365},
	{"DVDSANTA", 8, 128366},
	{"TECHNICALITY", 12, 128367},
	{"PROTECTANT", 10, 128368},
	{"VASC", 4, 128369},
	{"PHILLIPPE", 9, 128370},
	{"INDENTURED", 10, 128371},
	{"RBF", 3, 128372},
	{"GALADRIEL", 9, 128373},
	{"MDAEMON", 7, 128374},
	{"DODECYL", 7, 128375},
	{"COLAMCO", 7, 128376},
	{"CONTRAPTION", 11, 128377},
	{"SUNAPEE", 7, 128378},
	{"PHYSICOCHEMICAL", 15, 128379},
	{"MASATO", 6, 128380},
	{"TRUCCHI", 7, 128381},
	{"WETENSCHAPPEN", 13, 128382},
	{"HESITATING", 10, 128383},
	{"NEARY", 5, 128384},
	{"HISTOPATHOLOGICAL", 17, 128385},
	{"MISHNAH", 7, 128386},
	{"ZIMI", 4, 128387},
	{"ULSB", 4, 128388},
	{"UCIO", 4, 128389},
	{"LAWV", 4, 128390},
	{"KBUC", 4, 128391},
	{"FWEM", 4, 128392},
	{"EMDC", 4, 128393},
	{"EDCP", 4, 128394},
	{"AUWI", 4, 128395},
	{"BACCO", 5, 128396},
	{"PHOTOSHOW", 9, 128397},
	{"RELE", 4, 128398},
	{"DEADLOCKS", 9, 128399},
	{"ENUFF", 5, 128400},
	{"MASLOW", 6, 128401},
	{"TANNERS", 7, 128402},
	{"STOOPS", 6, 128403},
	{"CENOZOIC", 8, 128404},
	{"NANOSTRUCTURED", 14, 128405},
	{"RICERCHE", 8, 128406},
	{"LAHEY", 5, 128407},
	{"APLICACIONES", 12, 128408},
	{"DONLEY", 6, 128409},
	{"RUBBERRECRUITMENT", 17, 128410},
	{"INDUSTRYPACKAGING", 17, 128411},
	{"DUNGY", 5, 128412},
	{"PAOLANTONIO", 11, 128413},
	{"QUBE", 4, 128414},
	{"FARMVILLE", 9, 128415},
	{"AYKROYD", 7, 128416},
	{"SIDMOUTH", 8, 128417},
	{"SERVICESTEXTILES", 16, 128418},
	{"TRANSPORTPLASTICS", 17, 128419},
	{"PIXS", 4, 128420},
	{"KNOCKDOWN", 9, 128421},
	{"LUDLUM", 6, 128422},
	{"PROTEAM", 7, 128423},
	{"GOULET", 6, 128424},
	{"OTSUKA", 6, 128425},
	{"NUTHATCH", 8, 128426},
	{"XMP", 3, 128427},
	{"ELBARADEI", 9, 128428},
	{"SDLP", 4, 128429},
	{"UNIDAD", 6, 128430},
	{"SADP", 4, 128431},
	{"MRHU", 4, 128432},
	{"LSYA", 4, 128433},
	{"IUBE", 4, 128434},
	{"EIML", 4, 128435},
	{"DOWG", 4, 128436},
	{"DGWI", 4, 128437},
	{"CGLA", 4, 128438},
	{"AGUM", 4, 128439},
	{"ISUBSCRIBE", 10, 128440},
	{"SUBPARTS", 8, 128441},
	{"PRENOTA", 7, 128442},
	{"STIFFENING", 10, 128443},
	{"WIGGIN", 6, 128444},
	{"PDFLIB", 6, 128445},
	{"ENUMCLAW", 8, 128446},
	{"HAZELNUTS", 9, 128447},
	{"BOUDREAUX", 9, 128448},
	{"ERMENEGILDO", 11, 128449},
	{"SPURGE", 6, 128450},
	{"SOFABED", 7, 128451},
	{"DILLY", 5, 128452},
	{"SCRUTINIZING", 12, 128453},
	{"WORKUP", 6, 128454},
	{"GETID", 5, 128455},
	{"POSC", 4, 128456},
	{"KUOPIO", 6, 128457},
	{"ALLUDE", 6, 128458},
	{"SHAKA", 5, 128459},
	{"SPRAWLED", 8, 128460},
	{"INTERESSE", 9, 128461},
	{"MOLY", 4, 128462},
	{"BANBRIDGE", 9, 128463},
	{"SHOAIB", 6, 128464},
	{"KNUDSON", 7, 128465},
	{"NOTATIONAL", 10, 128466},
	{"TOMAR", 5, 128467},
	{"GAMBA", 5, 128468},
	{"YKAM", 4, 128469},
	{"UUNI", 4, 128470},
	{"USTQ", 4, 128471},
	{"TRSC", 4, 128472},
	{"NRYJ", 4, 128473},
	{"JARN", 4, 128474},
	{"FLEY", 4, 128475},
	{"CSBR", 4, 128476},
	{"AKRU", 4, 128477},
	{"PAQUETTE", 8, 128478},
	{"COMTECH", 7, 128479},
	{"ANTONELLI", 9, 128480},
	{"BRUCEI", 6, 128481},
	{"NETSUKE", 7, 128482},
	{"SALOU", 5, 128483},
	{"MERCREDI", 8, 128484},
	{"CHESSMASTER", 11, 128485},
	{"DURASOFT", 8, 128486},
	{"ARINC", 5, 128487},
	{"BIOCIDES", 8, 128488},
	{"FOLKY", 5, 128489},
	{"PROST", 5, 128490},
	{"ROOIBOS", 7, 128491},
	{"STRIPERS", 8, 128492},
	{"REAPPRAISAL", 11, 128493},
	{"VITON", 5, 128494},
	{"COURTED", 7, 128495},
	{"SYMPOSIUMS", 10, 128496},
	{"ENDORPHINS", 10, 128497},
	{"PROVIEW", 7, 128498},
	{"HEILMAN", 7, 128499},
	{"LINNEY", 6, 128500},
	{"MARADONA", 8, 128501},
	{"SCUFFS", 6, 128502},
	{"PARTICIPATIONS", 14, 128503},
	{"AQUIRED", 7, 128504},
	{"JOTSPOT", 7, 128505},
	{"DOBBY", 5, 128506},
	{"CONDONED", 8, 128507},
	{"ZMIR", 4, 128508},
	{"WOAB", 4, 128509},
	{"SIRD", 4, 128510},
	{"RUZI", 4, 128511},
	{"QWIL", 4, 128512},
	{"PORU", 4, 128513},
	{"NKBI", 4, 128514},
	{"LJAB", 4, 128515},
	{"ERVY", 4, 128516},
	{"CBON", 4, 128517},
	{"AUCI", 4, 128518},
	{"FRALEY", 6, 128519},
	{"UNSAVORY", 8, 128520},
	{"UMCP", 4, 128521},
	{"STUNS", 5, 128522},
	{"GEEKERY", 7, 128523},
	{"PARENTHETICAL", 13, 128524},
	{"MICROSTRUCTURES", 15, 128525},
	{"LIBOSP", 6, 128526},
	{"FABRICANTES", 11, 128527},
	{"BRASHEAR", 8, 128528},
	{"NOLEN", 5, 128529},
	{"AAACN", 5, 128530},
	{"REPACKAGING", 11, 128531},
	{"BLUEGILL", 8, 128532},
	{"GREENGUY", 8, 128533},
	{"PRSA", 4, 128534},
	{"DESERVEDLY", 10, 128535},
	{"SATION", 6, 128536},
	{"ALIQUAM", 7, 128537},
	{"BOARDSHORTS", 11, 128538},
	{"EXACTA", 6, 128539},
	{"SANJEEV", 7, 128540},
	{"BLACKBIRDS", 10, 128541},
	{"IKELITE", 7, 128542},
	{"MACLAINE", 8, 128543},
	{"VOWING", 6, 128544},
	{"SENDIT", 6, 128545},
	{"MICROBIOLOGIST", 14, 128546},
	{"BOARDGAMES", 10, 128547},
	{"UVEITIS", 7, 128548},
	{"LERMAN", 6, 128549},
	{"IVIEW", 5, 128550},
	{"TDOF", 4, 128551},
	{"PSYA", 4, 128552},
	{"ONKM", 4, 128553},
	{"JIMN", 4, 128554},
	{"IFYD", 4, 128555},
	{"HLOM", 4, 128556},
	{"BWEN", 4, 128557},
	{"BAWO", 4, 128558},
	{"KRANTZ", 6, 128559},
	{"PLYING", 6, 128560},
	{"PANGEA", 6, 128561},
	{"GANGRENE", 8, 128562},
	{"CHIPBOARD", 9, 128563},
	{"PURPLISH", 8, 128564},
	{"CODI", 4, 128565},
	{"NEPTUNES", 8, 128566},
	{"EARMARK", 7, 128567},
	{"KANAL", 5, 128568},
	{"CONKER", 6, 128569},
	{"STILLE", 6, 128570},
	{"RHINELAND", 9, 128571},
	{"SCHL", 4, 128572},
	{"SIMU", 4, 128573},
	{"REGATTAS", 8, 128574},
	{"COMPENSATOR", 11, 128575},
	{"ZATOICHI", 8, 128576},
	{"BORDETELLA", 10, 128577},
	{"PINEAPPLES", 10, 128578},
	{"VASTU", 5, 128579},
	{"ADEJE", 5, 128580},
	{"BINNS", 5, 128581},
	{"ISATORI", 7, 128582},
	{"WLYG", 4, 128583},
	{"UDDO", 4, 128584},
	{"TYJE", 4, 128585},
	{"TMLA", 4, 128586},
	{"PCHU", 4, 128587},
	{"NGUB", 4, 128588},
	{"MPDI", 4, 128589},
	{"LMLA", 4, 128590},
	{"LAHK", 4, 128591},
	{"ERLM", 4, 128592},
	{"DITQ", 4, 128593},
	{"METALLICITY", 11, 128594},
	{"RAPA", 4, 128595},
	{"CUVEE", 5, 128596},
	{"ENLIVEN", 7, 128597},
	{"BENELLI", 7, 128598},
	{"CORBUSIER", 9, 128599},
	{"VOLATILES", 9, 128600},
	{"DIGICOM", 7, 128601},
	{"MILLENCOLIN", 11, 128602},
	{"SUMI", 4, 128603},
	{"GLYCOLYSIS", 10, 128604},
	{"HEILONGJIANG", 12, 128605},
	{"CHRYSTAL", 8, 128606},
	{"HOLLOWED", 8, 128607},
	{"GRAVEN", 6, 128608},
	{"GERA", 4, 128609},
	{"REDNOVA", 7, 128610},
	{"LENGUA", 6, 128611},
	{"CRAVED", 6, 128612},
	{"FORMULATES", 10, 128613},
	{"HEUSEN", 6, 128614},
	{"SECRETING", 9, 128615},
	{"SERPS", 5, 128616},
	{"NEDIT", 5, 128617},
	{"POWERMAN", 8, 128618},
	{"ELISP", 5, 128619},
	{"SUBMERGE", 8, 128620},
	{"TTAFREEMEMORY", 13, 128621},
	{"MCW", 3, 128622},
	{"YYAD", 4, 128623},
	{"TSUW", 4, 128624},
	{"SMLA", 4, 128625},
	{"MOBU", 4, 128626},
	{"LEKR", 4, 128627},
	{"IMLY", 4, 128628},
	{"EIGR", 4, 128629},
	{"AWNY", 4, 128630},
	{"ALDK", 4, 128631},
	{"TTAGETMESSAGE", 13, 128632},
	{"WERRIBEE", 8, 128633},
	{"FRACAS", 6, 128634},
	{"ENVELOP", 7, 128635},
	{"HOLDSWORTH", 10, 128636},
	{"FILEUTILS", 9, 128637},
	{"LIEBMAN", 7, 128638},
	{"DUSTBIN", 7, 128639},
	{"XAPIAN", 6, 128640},
	{"JUGAR", 5, 128641},
	{"DISMOUNT", 8, 128642},
	{"MYOPATHY", 8, 128643},
	{"ASOCIACION", 10, 128644},
	{"HARRIGAN", 8, 128645},
	{"JACKETED", 8, 128646},
	{"GRUDGINGLY", 10, 128647},
	{"QUAE", 4, 128648},
	{"JETTED", 6, 128649},
	{"ZOOK", 4, 128650},
	{"MURILLO", 7, 128651},
	{"CHEAPO", 6, 128652},
	{"FRANKLYN", 8, 128653},
	{"TOPSFIELD", 9, 128654},
	{"STRPOS", 6, 128655},
	{"PORTUGUESA", 10, 128656},
	{"YDIO", 4, 128657},
	{"TGUS", 4, 128658},
	{"PTDI", 4, 128659},
	{"OAMY", 4, 128660},
	{"NUWA", 4, 128661},
	{"MERQ", 4, 128662},
	{"IXUN", 4, 128663},
	{"ENJR", 4, 128664},
	{"EKOK", 4, 128665},
	{"DUBR", 4, 128666},
	{"DALN", 4, 128667},
	{"SIKES", 5, 128668},
	{"KANANASKIS", 10, 128669},
	{"DALITS", 6, 128670},
	{"BAWDY", 5, 128671},
	{"MBEAN", 5, 128672},
	{"HYPERLIPIDEMIA", 14, 128673},
	{"JORGENSON", 9, 128674},
	{"GERSTEIN", 8, 128675},
	{"BOLE", 4, 128676},
	{"PENDULUMS", 9, 128677},
	{"COOGEE", 6, 128678},
	{"JACQUIE", 7, 128679},
	{"ERBA", 4, 128680},
	{"BIGINT", 6, 128681},
	{"BELIEVETH", 9, 128682},
	{"EGROUPS", 7, 128683},
	{"ABSOLUTLEY", 10, 128684},
	{"PRECEDENTE", 10, 128685},
	{"OVECHKIN", 8, 128686},
	{"USYR", 4, 128687},
	{"RJAG", 4, 128688},
	{"PPUL", 4, 128689},
	{"OXFR", 4, 128690},
	{"OFCT", 4, 128691},
	{"NCYK", 4, 128692},
	{"KMEI", 4, 128693},
	{"IPAU", 4, 128694},
	{"EAFY", 4, 128695},
	{"AFSP", 4, 128696},
	{"CIDADE", 6, 128697},
	{"CORVUS", 6, 128698},
	{"BLINKLIST", 9, 128699},
	{"UNAFRAID", 8, 128700},
	{"GREENVIEW", 9, 128701},
	{"STAMENS", 7, 128702},
	{"DELHOMME", 8, 128703},
	{"PSORIATIC", 9, 128704},
	{"PRUETT", 6, 128705},
	{"OSNAME", 6, 128706},
	{"LAUNDER", 7, 128707},
	{"GLIOBLASTOMA", 12, 128708},
	{"CLONECD", 7, 128709},
	{"SOUTHAM", 7, 128710},
	{"QUARLES", 7, 128711},
	{"MONTECARLO", 10, 128712},
	{"ANBAR", 5, 128713},
	{"CAPRIVI", 7, 128714},
	{"CELLED", 6, 128715},
	{"DEFROSTER", 9, 128716},
	{"OUKO", 4, 128717},
	{"ILEZ", 4, 128718},
	{"IGAY", 4, 128719},
	{"HDAU", 4, 128720},
	{"EFBR", 4, 128721},
	{"EDPP", 4, 128722},
	{"AMYD", 4, 128723},
	{"FACSIMILES", 10, 128724},
	{"ALCANTARA", 9, 128725},
	{"OMNIPOTENCE", 11, 128726},
	{"WEBLOGG", 7, 128727},
	{"IRRESPONSIBILITY", 16, 128728},
	{"APRICORN", 8, 128729},
	{"GUARANTORS", 10, 128730},
	{"WILBURN", 7, 128731},
	{"PRODNAV", 7, 128732},
	{"TUTSI", 5, 128733},
	{"OTWAY", 5, 128734},
	{"KAUSFILES", 9, 128735},
	{"WEATHERLY", 9, 128736},
	{"PONTIFICATE", 11, 128737},
	{"ZELF", 4, 128738},
	{"TOTALSTORAGE", 12, 128739},
	{"ELSTON", 6, 128740},
	{"SEAPORTS", 8, 128741},
	{"OUTAGAMIE", 9, 128742},
	{"DAYLILIES", 9, 128743},
	{"AERATOR", 7, 128744},
	{"MULTISTAGE", 10, 128745},
	{"CONSCIENTIOUSLY", 15, 128746},
	{"WBLU", 4, 128747},
	{"UYPR", 4, 128748},
	{"TTCU", 4, 128749},
	{"TDOP", 4, 128750},
	{"RUWH", 4, 128751},
	{"NSKU", 4, 128752},
	{"MYVA", 4, 128753},
	{"LKUN", 4, 128754},
	{"EEFW", 4, 128755},
	{"UNIQ", 4, 128756},
	{"BOOMED", 6, 128757},
	{"TBODY", 5, 128758},
	{"WINDSTOPPER", 11, 128759},
	{"DISTANCING", 10, 128760},
	{"ARTSCI", 6, 128761},
	{"POUCHETTE", 9, 128762},
	{"BASMATI", 7, 128763},
	{"TRANSIENTLY", 11, 128764},
	{"STRATTERA", 9, 128765},
	{"LAMPEN", 6, 128766},
	{"JUSSI", 5, 128767},
	{"UNLTD", 5, 128768},
	{"MOISES", 6, 128769},
	{"BEAUT", 5, 128770},
	{"SYSSRC", 6, 128771},
	{"JOUST", 5, 128772},
	{"JOELLE", 6, 128773},
	{"NEWBOLD", 7, 128774},
	{"BIOJAVA", 7, 128775},
	{"YUL", 3, 128776},
	{"NAGAI", 5, 128777},
	{"GRANDER", 7, 128778},
	{"ARRON", 5, 128779},
	{"VIERNES", 7, 128780},
	{"CONISTON", 8, 128781},
	{"WEPE", 4, 128782},
	{"VYBA", 4, 128783},
	{"RIIC", 4, 128784},
	{"NAVU", 4, 128785},
	{"MIVI", 4, 128786},
	{"GDOZ", 4, 128787},
	{"FABD", 4, 128788},
	{"METTA", 5, 128789},
	{"MOVIEMARZ", 9, 128790},
	{"PITLOCHRY", 9, 128791},
	{"SHACKLED", 8, 128792},
	{"HAUSDORFF", 9, 128793},
	{"RAGHAVAN", 8, 128794},
	{"FORUMSEARCH", 11, 128795},
	{"WALLCOVERING", 12, 128796},
	{"LACKLAND", 8, 128797},
	{"WEEDY", 5, 128798},
	{"FREEPLAY", 8, 128799},
	{"FLEISCHMAN", 10, 128800},
	{"CARMAX", 6, 128801},
	{"FRACTIONATED", 12, 128802},
	{"CBSA", 4, 128803},
	{"LIOTTA", 6, 128804},
	{"HUATULCO", 8, 128805},
	{"METRONOMES", 10, 128806},
	{"SALEABLE", 8, 128807},
	{"HITTITE", 7, 128808},
	{"LINOLENIC", 9, 128809},
	{"PHYTOCHEMICALS", 14, 128810},
	{"HADNT", 5, 128811},
	{"XICC", 4, 128812},
	{"VORG", 4, 128813},
	{"SCJO", 4, 128814},
	{"RAXT", 4, 128815},
	{"RAEV", 4, 128816},
	{"PPCO", 4, 128817},
	{"OUPV", 4, 128818},
	{"OBYG", 4, 128819},
	{"NOUL", 4, 128820},
	{"LDSV", 4, 128821},
	{"KOAL", 4, 128822},
	{"KIBU", 4, 128823},
	{"GOTJ", 4, 128824},
	{"EXTQ", 4, 128825},
	{"CPAL", 4, 128826},
	{"BEZIER", 6, 128827},
	{"SACRA", 5, 128828},
	{"BADD", 4, 128829},
	{"HOMEDE", 6, 128830},
	{"ULTRASONICS", 11, 128831},
	{"WOODHEAD", 8, 128832},
	{"SCHLIERSEE", 10, 128833},
	{"GRANULATION", 11, 128834},
	{"AUTOREPLY", 9, 128835},
	{"GROPE", 5, 128836},
	{"MEAKIN", 6, 128837},
	{"COGHLAN", 7, 128838},
	{"HOOTER", 6, 128839},
	{"CHIQUITA", 8, 128840},
	{"SUOMEN", 6, 128841},
	{"JOYTECH", 7, 128842},
	{"YANTRA", 6, 128843},
	{"SHACKS", 6, 128844},
	{"CPLS", 4, 128845},
	{"BOOED", 5, 128846},
	{"SPORTSFIGURES", 13, 128847},
	{"CARCINOID", 9, 128848},
	{"CRAW", 4, 128849},
	{"GRAHAMSTOWN", 11, 128850},
	{"RECOMMIT", 8, 128851},
	{"ECHTE", 5, 128852},
	{"PIMPED", 6, 128853},
	{"AIRDATE", 7, 128854},
	{"GASTROENTEROLOGISTS", 19, 128855},
	{"SCHROCK", 7, 128856},
	{"ABATTOIR", 8, 128857},
	{"XSUP", 4, 128858},
	{"XSOL", 4, 128859},
	{"WLUC", 4, 128860},
	{"UWEL", 4, 128861},
	{"THUK", 4, 128862},
	{"SOUZ", 4, 128863},
	{"RSOG", 4, 128864},
	{"OFIW", 4, 128865},
	{"NRYE", 4, 128866},
	{"LDLU", 4, 128867},
	{"ICOK", 4, 128868},
	{"HGUS", 4, 128869},
	{"GGSP", 4, 128870},
	{"IRONWORK", 8, 128871},
	{"CSIC", 4, 128872},
	{"EXTRUDER", 8, 128873},
	{"AITKIN", 6, 128874},
	{"DUTHIE", 6, 128875},
	{"GLOBALBX", 8, 128876},
	{"RYTHM", 5, 128877},
	{"VIRGEN", 6, 128878},
	{"GORKY", 5, 128879},
	{"BRIGHTENS", 9, 128880},
	{"MUERTOS", 7, 128881},
	{"PFF", 3, 128882},
	{"PALMITATE", 9, 128883},
	{"NAKATA", 6, 128884},
	{"NAVEEN", 6, 128885},
	{"FARP", 4, 128886},
	{"PAINTBALLING", 12, 128887},
	{"HELSTON", 7, 128888},
	{"UNICA", 5, 128889},
	{"GEORGIANS", 9, 128890},
	{"COLLIS", 6, 128891},
	{"TOPSHAM", 7, 128892},
	{"QEMA", 4, 128893},
	{"THERMALRIGHT", 12, 128894},
	{"NICORETTE", 9, 128895},
	{"JAILER", 6, 128896},
	{"YNGE", 4, 128897},
	{"UMYO", 4, 128898},
	{"UDUN", 4, 128899},
	{"PSBI", 4, 128900},
	{"OYPA", 4, 128901},
	{"OUVA", 4, 128902},
	{"LEKY", 4, 128903},
	{"KBYW", 4, 128904},
	{"IOGU", 4, 128905},
	{"FBAV", 4, 128906},
	{"DUMF", 4, 128907},
	{"BOBJ", 4, 128908},
	{"KONTAKTANZEIGE", 14, 128909},
	{"FOURSQUARE", 10, 128910},
	{"VICTIMISATION", 13, 128911},
	{"GLEICH", 6, 128912},
	{"HARTSVILLE", 10, 128913},
	{"SOLITAIRES", 10, 128914},
	{"JKR", 3, 128915},
	{"CHARA", 5, 128916},
	{"STAYTON", 7, 128917},
	{"ESCOLA", 6, 128918},
	{"BONSALL", 7, 128919},
	{"PRESB", 5, 128920},
	{"NYCRR", 5, 128921},
	{"JUNICHI", 7, 128922},
	{"RISERVATI", 9, 128923},
	{"TOLERATING", 10, 128924},
	{"BACKFLIP", 8, 128925},
	{"HAYDON", 6, 128926},
	{"BOROMIR", 7, 128927},
	{"RECEPTIVITY", 11, 128928},
	{"REFN", 4, 128929},
	{"OBJEC", 5, 128930},
	{"CRASNICK", 8, 128931},
	{"VIBRATES", 8, 128932},
	{"BATTERIA", 8, 128933},
	{"MOURA", 5, 128934},
	{"ANODISED", 8, 128935},
	{"GLADDEN", 7, 128936},
	{"XOFE", 4, 128937},
	{"OLZA", 4, 128938},
	{"MPFE", 4, 128939},
	{"MDOY", 4, 128940},
	{"LCAI", 4, 128941},
	{"JOSC", 4, 128942},
	{"INDQ", 4, 128943},
	{"FIXS", 4, 128944},
	{"FEUS", 4, 128945},
	{"DKAP", 4, 128946},
	{"DEXM", 4, 128947},
	{"CYHI", 4, 128948},
	{"BIWE", 4, 128949},
	{"AYEW", 4, 128950},
	{"AWGO", 4, 128951},
	{"AGORAPHOBIA", 11, 128952},
	{"SARCASTICALLY", 13, 128953},
	{"AMPHENOL", 8, 128954},
	{"TUFT", 4, 128955},
	{"ORLA", 4, 128956},
	{"QUICKENED", 9, 128957},
	{"GHAST", 5, 128958},
	{"REVERENT", 8, 128959},
	{"LEECHERS", 8, 128960},
	{"RETROFITTED", 11, 128961},
	{"NFIB", 4, 128962},
	{"MIDLET", 6, 128963},
	{"PINSKY", 6, 128964},
	{"BRAVED", 6, 128965},
	{"EMANATES", 8, 128966},
	{"BESUCHER", 8, 128967},
	{"JAUNE", 5, 128968},
	{"DNASE", 5, 128969},
	{"STUDIUM", 7, 128970},
	{"JOLI", 4, 128971},
	{"BOXWAVE", 7, 128972},
	{"FREIZEIT", 8, 128973},
	{"LUCCHESE", 8, 128974},
	{"COUNTERPARTIES", 14, 128975},
	{"HOODOO", 6, 128976},
	{"PRIONS", 6, 128977},
	{"RPSU", 4, 128978},
	{"RNHL", 4, 128979},
	{"OVOF", 4, 128980},
	{"BBRI", 4, 128981},
	{"ACTQ", 4, 128982},
	{"CHANHASSEN", 10, 128983},
	{"GEYSERS", 7, 128984},
	{"BECKONED", 8, 128985},
	{"CSCF", 4, 128986},
	{"BEDARD", 6, 128987},
	{"UNQUESTIONED", 12, 128988},
	{"PVRS", 4, 128989},
	{"TECHONWEB", 9, 128990},
	{"MIGRATOR", 8, 128991},
	{"ESTRUS", 6, 128992},
	{"SCRAWLED", 8, 128993},
	{"AFOUL", 5, 128994},
	{"BRG", 3, 128995},
	{"SEFER", 5, 128996},
	{"OBERWIESENTHAL", 14, 128997},
	{"SAVAGELY", 8, 128998},
	{"SANGEAN", 7, 128999},
	{"KODO", 4, 129000},
	{"XMLC", 4, 129001},
	{"CROSSWALKS", 10, 129002},
	{"PIXCATCHER", 10, 129003},
	{"MISSTATEMENTS", 13, 129004},
	{"VENANGO", 7, 129005},
	{"GSSAPI", 6, 129006},
	{"LASSITER", 8, 129007},
	{"OKLAHOMAN", 9, 129008},
	{"ODDWORLD", 8, 129009},
	{"VIEWREF", 7, 129010},
	{"ZZYI", 4, 129011},
	{"YJIN", 4, 129012},
	{"WTAR", 4, 129013},
	{"UBMO", 4, 129014},
	{"JRIN", 4, 129015},
	{"GNSR", 4, 129016},
	{"FLGA", 4, 129017},
	{"DDDE", 4, 129018},
	{"CSYO", 4, 129019},
	{"BSBO", 4, 129020},
	{"SILKE", 5, 129021},
	{"LABRET", 6, 129022},
	{"RUSSKAJA", 8, 129023},
	{"CEUTA", 5, 129024},
	{"GUNFIGHT", 8, 129025},
	{"MOTD", 4, 129026},
	{"VETTRIANO", 9, 129027},
	{"MERIDIONAL", 10, 129028},
	{"USURPED", 7, 129029},
	{"VIENTOS", 7, 129030},
	{"TAKURO", 6, 129031},
	{"XWV", 3, 129032},
	{"XBG", 3, 129033},
	{"WGZ", 3, 129034},
	{"UZQ", 3, 129035},
	{"QQR", 3, 129036},
	{"QQP", 3, 129037},
	{"QQL", 3, 129038},
	{"PZX", 3, 129039},
	{"MZX", 3, 129040},
	{"AQUARIEN", 8, 129041},
	{"NOKOMIS", 7, 129042},
	{"INFARMATION", 11, 129043},
	{"MICRONUTRIENT", 13, 129044},
	{"HAMES", 5, 129045},
	{"RACQUEL", 7, 129046},
	{"YUSM", 4, 129047},
	{"TOCB", 4, 129048},
	{"TCYL", 4, 129049},
	{"PBYO", 4, 129050},
	{"OPLY", 4, 129051},
	{"OPIP", 4, 129052},
	{"OEMW", 4, 129053},
	{"FJET", 4, 129054},
	{"FBYR", 4, 129055},
	{"DAAB", 4, 129056},
	{"CHRENKOFF", 9, 129057},
	{"INKWELL", 7, 129058},
	{"MAGNOLIOPHYTA", 13, 129059},
	{"OPALESCENT", 10, 129060},
	{"SWAPPERS", 8, 129061},
	{"MONSTROSITY", 11, 129062},
	{"ALSTROEMERIA", 12, 129063},
	{"CONTEMPTUOUS", 12, 129064},
	{"REORIENTATION", 13, 129065},
	{"BATAAN", 6, 129066},
	{"POCUS", 5, 129067},
	{"RECOGNIZER", 10, 129068},
	{"MSGFMT", 6, 129069},
	{"CORYNEBACTERIUM", 15, 129070},
	{"NEWTOWNABBEY", 12, 129071},
	{"KEYTRONIC", 9, 129072},
	{"ACKS", 4, 129073},
	{"CELLREF", 7, 129074},
	{"DEVOE", 5, 129075},
	{"CERTAINS", 8, 129076},
	{"AFGANISTAN", 10, 129077},
	{"MUNDAY", 6, 129078},
	{"YMSA", 4, 129079},
	{"UROO", 4, 129080},
	{"SKBY", 4, 129081},
	{"RPNE", 4, 129082},
	{"NSMR", 4, 129083},
	{"ICZA", 4, 129084},
	{"GULC", 4, 129085},
	{"EXBR", 4, 129086},
	{"CZER", 4, 129087},
	{"PREPEND", 7, 129088},
	{"PLACIDO", 7, 129089},
	{"SIKESTON", 8, 129090},
	{"ERSATZ", 6, 129091},
	{"XYLITOL", 7, 129092},
	{"HANCE", 5, 129093},
	{"RAVISHING", 9, 129094},
	{"UNISSUED", 8, 129095},
	{"AHARON", 6, 129096},
	{"DECONVOLUTION", 13, 129097},
	{"GRUMBLED", 8, 129098},
	{"MORIBUND", 8, 129099},
	{"KILLDEER", 8, 129100},
	{"TILLERS", 7, 129101},
	{"HBSAG", 5, 129102},
	{"CONCIERTO", 9, 129103},
	{"MAHAJAN", 7, 129104},
	{"ALIQUET", 7, 129105},
	{"LUNDIN", 6, 129106},
	{"TURNBERRY", 9, 129107},
	{"DISHEARTENING", 13, 129108},
	{"ORIGNAL", 7, 129109},
	{"MCCLATCHY", 9, 129110},
	{"ARCHPUNDIT", 10, 129111},
	{"YMIA", 4, 129112},
	{"UADL", 4, 129113},
	{"OLGY", 4, 129114},
	{"NIVY", 4, 129115},
	{"LPHT", 4, 129116},
	{"IOFL", 4, 129117},
	{"IEWU", 4, 129118},
	{"FBHA", 4, 129119},
	{"DTSU", 4, 129120},
	{"BOXG", 4, 129121},
	{"HYDRONIC", 8, 129122},
	{"PLAGIOCLASE", 11, 129123},
	{"MARKLE", 6, 129124},
	{"NUBILES", 7, 129125},
	{"NOBIS", 5, 129126},
	{"ADRANTS", 7, 129127},
	{"EPWORTH", 7, 129128},
	{"URIDINE", 7, 129129},
	{"INCORPORATIONS", 14, 129130},
	{"GIARDINI", 8, 129131},
	{"GREYSCALE", 9, 129132},
	{"CHANNELIZED", 11, 129133},
	{"PROTHROMBIN", 11, 129134},
	{"VERMICULITE", 11, 129135},
	{"EMDEON", 6, 129136},
	{"UGBO", 4, 129137},
	{"ROYJ", 4, 129138},
	{"REAQ", 4, 129139},
	{"PMJA", 4, 129140},
	{"MRDO", 4, 129141},
	{"KYFA", 4, 129142},
	{"JACU", 4, 129143},
	{"FPHE", 4, 129144},
	{"AAGU", 4, 129145},
	{"KUDO", 4, 129146},
	{"STOLZ", 5, 129147},
	{"OLOGY", 5, 129148},
	{"INTERSTING", 10, 129149},
	{"UNAVOIDABLY", 11, 129150},
	{"HELPLINES", 9, 129151},
	{"ALTHO", 5, 129152},
	{"PAGEHISTORY", 11, 129153},
	{"FONTWEIGHT", 10, 129154},
	{"MEDIOIMAGES", 11, 129155},
	{"BLEST", 5, 129156},
	{"MESAS", 5, 129157},
	{"TOURISTIQUES", 12, 129158},
	{"GOVINDA", 7, 129159},
	{"SPEZIAL", 7, 129160},
	{"BRIGHOUSE", 9, 129161},
	{"STAMOS", 6, 129162},
	{"EICHMANN", 8, 129163},
	{"DELE", 4, 129164},
	{"AMACAI", 6, 129165},
	{"BARAJAS", 7, 129166},
	{"MCSHANE", 7, 129167},
	{"MACHIAS", 7, 129168},
	{"MONTVALE", 8, 129169},
	{"HURSTON", 7, 129170},
	{"ELIAN", 5, 129171},
	{"KORI", 4, 129172},
	{"EROTASTEDE", 10, 129173},
	{"MENIAL", 6, 129174},
	{"BANNON", 6, 129175},
	{"CLAYEY", 6, 129176},
	{"JESSEN", 6, 129177},
	{"GAMECOCK", 8, 129178},
	{"MONOOXYGENASE", 13, 129179},
	{"UPSY", 4, 129180},
	{"TYAK", 4, 129181},
	{"REKD", 4, 129182},
	{"NIMG", 4, 129183},
	{"LKSR", 4, 129184},
	{"KSVA", 4, 129185},
	{"FTGA", 4, 129186},
	{"FRUC", 4, 129187},
	{"BJRN", 4, 129188},
	{"TEMAZEPAM", 9, 129189},
	{"MORPHOLOGIC", 11, 129190},
	{"SYNCHRONOUSLY", 13, 129191},
	{"CONSUMO", 7, 129192},
	{"AMENORRHEA", 10, 129193},
	{"DELIGHTING", 10, 129194},
	{"PADRAIG", 7, 129195},
	{"TUDALEN", 7, 129196},
	{"SURES", 5, 129197},
	{"CHIMIE", 6, 129198},
	{"VIELEN", 6, 129199},
	{"WASSILY", 7, 129200},
	{"GRATZ", 5, 129201},
	{"INEFFECTIVENESS", 15, 129202},
	{"FASCIITIS", 9, 129203},
	{"TRADUZIDA", 9, 129204},
	{"CONJURING", 9, 129205},
	{"ATSUSHI", 7, 129206},
	{"LAMPARD", 7, 129207},
	{"RUMPED", 6, 129208},
	{"NONEXCLUSIVE", 12, 129209},
	{"PICEA", 5, 129210},
	{"CAZA", 4, 129211},
	{"DISJUNCTIVE", 11, 129212},
	{"XONB", 4, 129213},
	{"VONP", 4, 129214},
	{"NGHP", 4, 129215},
	{"NDTC", 4, 129216},
	{"JOSM", 4, 129217},
	{"IMML", 4, 129218},
	{"HIZZ", 4, 129219},
	{"DIUN", 4, 129220},
	{"CUCK", 4, 129221},
	{"ATUG", 4, 129222},
	{"TELESERVICES", 12, 129223},
	{"DUTIFUL", 7, 129224},
	{"INSTIGATE", 9, 129225},
	{"LEGITIMIZE", 10, 129226},
	{"ABSURDITIES", 11, 129227},
	{"PBXFILEREFERENCE", 16, 129228},
	{"LEASEBACK", 9, 129229},
	{"CABEZA", 6, 129230},
	{"VEHEMENT", 8, 129231},
	{"GORDIAN", 7, 129232},
	{"COPAYMENTS", 10, 129233},
	{"KANNAPOLIS", 10, 129234},
	{"TAINAN", 6, 129235},
	{"EDIFICATION", 11, 129236},
	{"DANGERFIELD", 11, 129237},
	{"CAUSALLY", 8, 129238},
	{"LEOTARDS", 8, 129239},
	{"VISIONTEK", 9, 129240},
	{"VERGLEICH", 9, 129241},
	{"PHOTORESIST", 11, 129242},
	{"WATTERSON", 9, 129243},
	{"UNQUOTE", 7, 129244},
	{"KARO", 4, 129245},
	{"COLGAN", 6, 129246},
	{"FILTRE", 6, 129247},
	{"YITU", 4, 129248},
	{"XTUS", 4, 129249},
	{"XTEC", 4, 129250},
	{"VGOR", 4, 129251},
	{"TILV", 4, 129252},
	{"RRAO", 4, 129253},
	{"PYFA", 4, 129254},
	{"NNBU", 4, 129255},
	{"LASZ", 4, 129256},
	{"GYAD", 4, 129257},
	{"CKSQ", 4, 129258},
	{"AACQ", 4, 129259},
	{"FLINCH", 6, 129260},
	{"NEOWARE", 7, 129261},
	{"VASODILATOR", 11, 129262},
	{"PASTIES", 7, 129263},
	{"GAMBOA", 6, 129264},
	{"LOUISBURG", 9, 129265},
	{"WOODFIN", 7, 129266},
	{"DENTE", 5, 129267},
	{"THEORIZED", 9, 129268},
	{"DESPOT", 6, 129269},
	{"UTILISATEUR", 11, 129270},
	{"TRAVELOG", 8, 129271},
	{"MICHNET", 7, 129272},
	{"SALTA", 5, 129273},
	{"INTESTATE", 9, 129274},
	{"BUGGERS", 7, 129275},
	{"ICTY", 4, 129276},
	{"AFFAIRE", 7, 129277},
	{"EXCAVATE", 8, 129278},
	{"INSINCERE", 9, 129279},
	{"PLASTERS", 8, 129280},
	{"YRUG", 4, 129281},
	{"YPIG", 4, 129282},
	{"OAKC", 4, 129283},
	{"LMLE", 4, 129284},
	{"KSKA", 4, 129285},
	{"KACZ", 4, 129286},
	{"IRDJ", 4, 129287},
	{"DGAG", 4, 129288},
	{"SEVICE", 6, 129289},
	{"JORG", 4, 129290},
	{"MOLESKINE", 9, 129291},
	{"KOALAS", 6, 129292},
	{"AVENTURINE", 10, 129293},
	{"PAGECOMPUTER", 12, 129294},
	{"INGER", 5, 129295},
	{"VUELTA", 6, 129296},
	{"PRIVET", 6, 129297},
	{"TRANSUNION", 10, 129298},
	{"FGEE", 4, 129299},
	{"CARRETERA", 9, 129300},
	{"BECKONING", 9, 129301},
	{"UNCOMPENSATED", 13, 129302},
	{"RPD", 3, 129303},
	{"RETOOLING", 9, 129304},
	{"ZOFF", 4, 129305},
	{"WOSY", 4, 129306},
	{"SPWH", 4, 129307},
	{"RGPO", 4, 129308},
	{"OLBL", 4, 129309},
	{"NOVC", 4, 129310},
	{"NDWW", 4, 129311},
	{"PARADYNE", 8, 129312},
	{"LINKI", 5, 129313},
	{"SOCKADDR", 8, 129314},
	{"PLANED", 6, 129315},
	{"AAUP", 4, 129316},
	{"LATRINES", 8, 129317},
	{"FERGUSSON", 9, 129318},
	{"VIVANT", 6, 129319},
	{"MYPAL", 5, 129320},
	{"GREENBAUM", 9, 129321},
	{"ZADAR", 5, 129322},
	{"FLAM", 4, 129323},
	{"WARPLANES", 9, 129324},
	{"RUPIAHS", 7, 129325},
	{"KEATH", 5, 129326},
	{"PENSIONI", 8, 129327},
	{"KAPUR", 5, 129328},
	{"BLAHNIK", 7, 129329},
	{"FLEXOR", 6, 129330},
	{"PMMA", 4, 129331},
	{"LUXEON", 6, 129332},
	{"ACCULTURATION", 13, 129333},
	{"ZCAL", 4, 129334},
	{"ORZH", 4, 129335},
	{"KROD", 4, 129336},
	{"EFAF", 4, 129337},
	{"DDUG", 4, 129338},
	{"TREX", 4, 129339},
	{"VENDRE", 6, 129340},
	{"PMF", 3, 129341},
	{"ELDRITCH", 8, 129342},
	{"RAFFIA", 6, 129343},
	{"OLYMPISCH", 9, 129344},
	{"PREFORMATTED", 12, 129345},
	{"SANKT", 5, 129346},
	{"KIPPER", 6, 129347},
	{"CARAVANNING", 11, 129348},
	{"ARDA", 4, 129349},
	{"TALLMAN", 7, 129350},
	{"NUMERICS", 8, 129351},
	{"CROS", 4, 129352},
	{"MESG", 4, 129353},
	{"HINSHAW", 7, 129354},
	{"IGNIS", 5, 129355},
	{"BURGDORFERI", 11, 129356},
	{"BURIEN", 6, 129357},
	{"TRUSTEESHIP", 11, 129358},
	{"SDNY", 4, 129359},
	{"POSITIVISM", 10, 129360},
	{"KREATOR", 7, 129361},
	{"TIMESLOT", 8, 129362},
	{"DFSG", 4, 129363},
	{"BEGONE", 6, 129364},
	{"RYLC", 4, 129365},
	{"NDPY", 4, 129366},
	{"MSEQ", 4, 129367},
	{"LSSY", 4, 129368},
	{"LMTE", 4, 129369},
	{"LIXH", 4, 129370},
	{"KHEP", 4, 129371},
	{"KGUA", 4, 129372},
	{"HAWP", 4, 129373},
	{"GNDA", 4, 129374},
	{"EMVA", 4, 129375},
	{"EDCB", 4, 129376},
	{"DCHL", 4, 129377},
	{"BETAMAX", 7, 129378},
	{"VARIUS", 6, 129379},
	{"FDTL", 4, 129380},
	{"LUANGWA", 7, 129381},
	{"TUROK", 5, 129382},
	{"ANUNCIO", 7, 129383},
	{"MAKELAAR", 8, 129384},
	{"LUCIDITY", 8, 129385},
	{"FEUDS", 5, 129386},
	{"UNRWA", 5, 129387},
	{"ANGELZ", 6, 129388},
	{"TAIKO", 5, 129389},
	{"CHESTERTOWN", 11, 129390},
	{"DILANTIN", 8, 129391},
	{"DIAZINON", 8, 129392},
	{"TVNZ", 4, 129393},
	{"CHLOR", 5, 129394},
	{"BLACKBUG", 8, 129395},
	{"TELESTAR", 8, 129396},
	{"MCMURRY", 7, 129397},
	{"ATOMIX", 6, 129398},
	{"VIDEOPHONE", 10, 129399},
	{"COPROCESSOR", 11, 129400},
	{"BULGARIEN", 9, 129401},
	{"PWGSC", 5, 129402},
	{"COCHABAMBA", 10, 129403},
	{"COUNTERFACTUAL", 14, 129404},
	{"WPOT", 4, 129405},
	{"WOAF", 4, 129406},
	{"TIFD", 4, 129407},
	{"RTOX", 4, 129408},
	{"OGAG", 4, 129409},
	{"OBYI", 4, 129410},
	{"NDPT", 4, 129411},
	{"MPYO", 4, 129412},
	{"LUKY", 4, 129413},
	{"KYUS", 4, 129414},
	{"FUSU", 4, 129415},
	{"EZOD", 4, 129416},
	{"DMRA", 4, 129417},
	{"BPOP", 4, 129418},
	{"DELACROIX", 9, 129419},
	{"PUEDES", 6, 129420},
	{"ULTRIX", 6, 129421},
	{"SHEKNOWS", 8, 129422},
	{"ECOTOXICOLOGY", 13, 129423},
	{"BOLAN", 5, 129424},
	{"SABBAH", 6, 129425},
	{"TOQUE", 5, 129426},
	{"JAPA", 4, 129427},
	{"GAMBAR", 6, 129428},
	{"SHOOTIN", 7, 129429},
	{"SUITER", 6, 129430},
	{"GAUCHOS", 7, 129431},
	{"MARTES", 6, 129432},
	{"MACIAS", 6, 129433},
	{"DISTILL", 7, 129434},
	{"ATOKA", 5, 129435},
	{"SCITE", 5, 129436},
	{"JIKES", 5, 129437},
	{"PITZER", 6, 129438},
	{"WARBIRD", 7, 129439},
	{"WILLE", 5, 129440},
	{"TAHARI", 6, 129441},
	{"LEPTONS", 7, 129442},
	{"KRUPP", 5, 129443},
	{"RANDOMIZE", 9, 129444},
	{"HALEAKALA", 9, 129445},
	{"DRIFFIELD", 9, 129446},
	{"ACHESON", 7, 129447},
	{"BEATZ", 5, 129448},
	{"TILLOTSON", 9, 129449},
	{"ARCTAN", 6, 129450},
	{"LORBER", 6, 129451},
	{"WYAR", 4, 129452},
	{"WUPB", 4, 129453},
	{"UPFL", 4, 129454},
	{"TWAC", 4, 129455},
	{"RSHB", 4, 129456},
	{"OIRD", 4, 129457},
	{"NDYV", 4, 129458},
	{"LZAR", 4, 129459},
	{"LFAY", 4, 129460},
	{"CORSON", 6, 129461},
	{"PRIMI", 5, 129462},
	{"YAMI", 4, 129463},
	{"EUNOS", 5, 129464},
	{"ECASOUND", 8, 129465},
	{"MILKS", 5, 129466},
	{"ARCMIN", 6, 129467},
	{"MEQUON", 6, 129468},
	{"SDCL", 4, 129469},
	{"AEROFLOT", 8, 129470},
	{"KYBERNHSH", 9, 129471},
	{"LAKSHADWEEP", 11, 129472},
	{"HIVER", 5, 129473},
	{"INVITEES", 8, 129474},
	{"CHASKA", 6, 129475},
	{"CARMONA", 7, 129476},
	{"DRESCHER", 8, 129477},
	{"POINTDE", 7, 129478},
	{"WMES", 4, 129479},
	{"UXWA", 4, 129480},
	{"USUB", 4, 129481},
	{"UKYA", 4, 129482},
	{"TPUJ", 4, 129483},
	{"STYU", 4, 129484},
	{"PAMU", 4, 129485},
	{"NDHP", 4, 129486},
	{"APBY", 4, 129487},
	{"LATENESS", 8, 129488},
	{"LAPHAM", 6, 129489},
	{"SEWANEE", 7, 129490},
	{"SYNCHRONISE", 11, 129491},
	{"MERO", 4, 129492},
	{"TIDAK", 5, 129493},
	{"BEWDLEY", 7, 129494},
	{"DPORT", 5, 129495},
	{"MAINSTREET", 10, 129496},
	{"IRANI", 5, 129497},
	{"CALLXPRESS", 10, 129498},
	{"KENNAWAY", 8, 129499},
	{"RADIATA", 7, 129500},
	{"FORMALWEAR", 10, 129501},
	{"MAINICHI", 8, 129502},
	{"EXTRAPOLATING", 13, 129503},
	{"NTPD", 4, 129504},
	{"ALLEGRETTO", 10, 129505},
	{"DIER", 4, 129506},
	{"CONFECTIONERS", 13, 129507},
	{"CHANGELING", 10, 129508},
	{"BACKPORT", 8, 129509},
	{"CARMAGEDDON", 11, 129510},
	{"YYZ", 3, 129511},
	{"RAHXEPHON", 9, 129512},
	{"THYV", 4, 129513},
	{"RKIA", 4, 129514},
	{"REXB", 4, 129515},
	{"IXLO", 4, 129516},
	{"IPJO", 4, 129517},
	{"FSTG", 4, 129518},
	{"ARCF", 4, 129519},
	{"TUOMAS", 6, 129520},
	{"BIGWIG", 6, 129521},
	{"BUNNYMEN", 8, 129522},
	{"MAMET", 5, 129523},
	{"NUNNERY", 7, 129524},
	{"EMAILER", 7, 129525},
	{"SUPERS", 6, 129526},
	{"FOREFINGER", 10, 129527},
	{"OSTEEN", 6, 129528},
	{"CURRENTCONTROLSET", 17, 129529},
	{"FAIRLAWN", 8, 129530},
	{"BRAINDUMP", 9, 129531},
	{"GRUYTER", 7, 129532},
	{"ACRS", 4, 129533},
	{"TABLENAME", 9, 129534},
	{"PAREN", 5, 129535},
	{"RUDIMENTS", 9, 129536},
	{"EPOXIES", 7, 129537},
	{"TAGNAME", 7, 129538},
	{"ERWARTET", 8, 129539},
	{"VALI", 4, 129540},
	{"STARMAN", 7, 129541},
	{"COTONOU", 7, 129542},
	{"EPICURIOUS", 10, 129543},
	{"DIVERTICULITIS", 14, 129544},
	{"HEATHENS", 8, 129545},
	{"CELIBATE", 8, 129546},
	{"CRYER", 5, 129547},
	{"CHINABERRY", 10, 129548},
	{"SIMUL", 5, 129549},
	{"SHOPPINGCART", 12, 129550},
	{"ZLEZ", 4, 129551},
	{"VABA", 4, 129552},
	{"UZHO", 4, 129553},
	{"TKAZ", 4, 129554},
	{"OFYI", 4, 129555},
	{"NECY", 4, 129556},
	{"MUDO", 4, 129557},
	{"MNSW", 4, 129558},
	{"MIRH", 4, 129559},
	{"KEIV", 4, 129560},
	{"HMAU", 4, 129561},
	{"HAYK", 4, 129562},
	{"FTWR", 4, 129563},
	{"BIOW", 4, 129564},
	{"BHOW", 4, 129565},
	{"RINGGITS", 8, 129566},
	{"MERGEDFIELDS", 12, 129567},
	{"FIRA", 4, 129568},
	{"BANTON", 6, 129569},
	{"JIFFIES", 7, 129570},
	{"SCHISTOSOMIASIS", 15, 129571},
	{"RELAXERS", 8, 129572},
	{"THROWERS", 8, 129573},
	{"DISTURBINGLY", 12, 129574},
	{"CDEP", 4, 129575},
	{"WNFR", 4, 129576},
	{"SWAMPSCOTT", 10, 129577},
	{"ROSEA", 5, 129578},
	{"CLATTER", 7, 129579},
	{"DIETMAR", 7, 129580},
	{"WERD", 4, 129581},
	{"DOONESBURY", 10, 129582},
	{"SHANKLIN", 8, 129583},
	{"XMEN", 4, 129584},
	{"MALDI", 5, 129585},
	{"CORRODED", 8, 129586},
	{"KAMIGAWA", 8, 129587},
	{"POSTDOCS", 8, 129588},
	{"LOUGHTON", 8, 129589},
	{"FAULTLESS", 9, 129590},
	{"BLOCKSIZE", 9, 129591},
	{"AWKWARDNESS", 11, 129592},
	{"FASEB", 5, 129593},
	{"NONFINANCIAL", 12, 129594},
	{"TRANSAMINASE", 12, 129595},
	{"WKU", 3, 129596},
	{"ZLEO", 4, 129597},
	{"SYBO", 4, 129598},
	{"NMCE", 4, 129599},
	{"GQIN", 4, 129600},
	{"FTGE", 4, 129601},
	{"FFKI", 4, 129602},
	{"EACY", 4, 129603},
	{"AIGF", 4, 129604},
	{"PRAISEWORTHY", 12, 129605},
	{"KINSALE", 7, 129606},
	{"MOSCA", 5, 129607},
	{"LIVEXCAMS", 9, 129608},
	{"CCSDS", 5, 129609},
	{"SEIGNEUR", 8, 129610},
	{"CABI", 4, 129611},
	{"MANUFACTU", 9, 129612},
	{"GORGONZOLA", 10, 129613},
	{"HARTZ", 5, 129614},
	{"MMORPGS", 7, 129615},
	{"SYNALAR", 7, 129616},
	{"WOLFHOUND", 9, 129617},
	{"BRIDGESTREET", 12, 129618},
	{"POWERDSINE", 10, 129619},
	{"COFFEYVILLE", 11, 129620},
	{"ANAESTHETICS", 12, 129621},
	{"FUNERARY", 8, 129622},
	{"SUNSTAR", 7, 129623},
	{"BALATON", 7, 129624},
	{"SYMPHONIA", 9, 129625},
	{"POTTERIES", 9, 129626},
	{"CHIHUAHUAS", 10, 129627},
	{"WILKESBORO", 10, 129628},
	{"TRIBUTED", 8, 129629},
	{"GFZ", 3, 129630},
	{"LINCOLNTON", 10, 129631},
	{"HILDEGARD", 9, 129632},
	{"BROADMOOR", 9, 129633},
	{"PEPPERCORNS", 11, 129634},
	{"ZEDK", 4, 129635},
	{"SBAF", 4, 129636},
	{"RIFM", 4, 129637},
	{"LMHO", 4, 129638},
	{"GABD", 4, 129639},
	{"FPEP", 4, 129640},
	{"DJUI", 4, 129641},
	{"ACFI", 4, 129642},
	{"TATIONS", 7, 129643},
	{"TENSIONING", 10, 129644},
	{"SPIRONOLACTONE", 14, 129645},
	{"IMOLA", 5, 129646},
	{"AMCHAM", 6, 129647},
	{"BEAMISH", 7, 129648},
	{"TREFOIL", 7, 129649},
	{"RIPTIDE", 7, 129650},
	{"MODELINE", 8, 129651},
	{"INGAME", 6, 129652},
	{"PPENDIX", 7, 129653},
	{"COMEX", 5, 129654},
	{"THEOLOGICALLY", 13, 129655},
	{"FUKUYAMA", 8, 129656},
	{"RORSCHACH", 9, 129657},
	{"DETRACTS", 8, 129658},
	{"AZIENDA", 7, 129659},
	{"ARMAN", 5, 129660},
	{"MONIT", 5, 129661},
	{"STELLER", 7, 129662},
	{"LACAN", 5, 129663},
	{"PROFE", 5, 129664},
	{"FRAGE", 5, 129665},
	{"CILIA", 5, 129666},
	{"MARKIE", 6, 129667},
	{"TOLF", 4, 129668},
	{"LOSV", 4, 129669},
	{"KABS", 4, 129670},
	{"GOSD", 4, 129671},
	{"GNFE", 4, 129672},
	{"GITV", 4, 129673},
	{"BSGO", 4, 129674},
	{"EMACSPEAK", 9, 129675},
	{"SOUTHWOOD", 9, 129676},
	{"VAPOURS", 7, 129677},
	{"CLIMACOOL", 9, 129678},
	{"AUDE", 4, 129679},
	{"ACCUTRON", 8, 129680},
	{"ICEWIND", 7, 129681},
	{"GORP", 4, 129682},
	{"ALBERTANS", 9, 129683},
	{"RICKMANSWORTH", 13, 129684},
	{"BUNA", 4, 129685},
	{"PERSONALIZING", 13, 129686},
	{"NONWOVEN", 8, 129687},
	{"SALAR", 5, 129688},
	{"DEVELOPE", 8, 129689},
	{"OHIOLINK", 8, 129690},
	{"PROBERT", 7, 129691},
	{"QUINTE", 6, 129692},
	{"FRITSCH", 7, 129693},
	{"YSGL", 4, 129694},
	{"UELV", 4, 129695},
	{"RMAZ", 4, 129696},
	{"ODEK", 4, 129697},
	{"MDUB", 4, 129698},
	{"FYHE", 4, 129699},
	{"FJAV", 4, 129700},
	{"DMAZ", 4, 129701},
	{"CUTN", 4, 129702},
	{"BSIM", 4, 129703},
	{"MINETTE", 7, 129704},
	{"JAYCEES", 7, 129705},
	{"SUNDOWNER", 9, 129706},
	{"IDEC", 4, 129707},
	{"ARSCHLOCH", 9, 129708},
	{"ONESIES", 7, 129709},
	{"CUSTOMISING", 11, 129710},
	{"MASHPEE", 7, 129711},
	{"INHALANTS", 9, 129712},
	{"SANGIOVESE", 10, 129713},
	{"FIRINGS", 7, 129714},
	{"PERVERSIONS", 11, 129715},
	{"SPDT", 4, 129716},
	{"QUIPPED", 7, 129717},
	{"DELPHINE", 8, 129718},
	{"BRUDER", 6, 129719},
	{"GROU", 4, 129720},
	{"RENUMBER", 8, 129721},
	{"TUCANO", 6, 129722},
	{"METHYLMERCURY", 13, 129723},
	{"INTERRATIAL", 11, 129724},
	{"PINON", 5, 129725},
	{"SPECKLE", 7, 129726},
	{"CHIESA", 6, 129727},
	{"STATISTIEKEN", 12, 129728},
	{"INTERPOLATING", 13, 129729},
	{"MKD", 3, 129730},
	{"JESUP", 5, 129731},
	{"PTGE", 4, 129732},
	{"GAYW", 4, 129733},
	{"EWBC", 4, 129734},
	{"SNOTTY", 6, 129735},
	{"REMISS", 6, 129736},
	{"MSXML", 5, 129737},
	{"CATALINK", 8, 129738},
	{"LANGUISHING", 11, 129739},
	{"PONTIUS", 7, 129740},
	{"TECHSKILLS", 10, 129741},
	{"ANCHORESS", 9, 129742},
	{"COPPERHEAD", 10, 129743},
	{"KUDROW", 6, 129744},
	{"ENTRAILS", 8, 129745},
	{"AVERA", 5, 129746},
	{"SMTPD", 5, 129747},
	{"SMAC", 4, 129748},
	{"ERREUR", 6, 129749},
	{"SLINGING", 8, 129750},
	{"RELISHES", 8, 129751},
	{"UPRISINGS", 9, 129752},
	{"KARLIN", 6, 129753},
	{"MULTIBILLION", 12, 129754},
	{"VALUERAM", 8, 129755},
	{"SIDERED", 7, 129756},
	{"SUBSONIC", 8, 129757},
	{"AVIUM", 5, 129758},
	{"COTTLE", 6, 129759},
	{"BAKKEN", 6, 129760},
	{"COSSACK", 7, 129761},
	{"TBUZ", 4, 129762},
	{"RHEY", 4, 129763},
	{"MYLU", 4, 129764},
	{"GNLI", 4, 129765},
	{"DLAF", 4, 129766},
	{"BASB", 4, 129767},
	{"LYLES", 5, 129768},
	{"TIENG", 5, 129769},
	{"STRABISMUS", 10, 129770},
	{"GARNISHES", 9, 129771},
	{"WASSUP", 6, 129772},
	{"RUPA", 4, 129773},
	{"BOUGAINVILLE", 12, 129774},
	{"DIFFUSIVITY", 11, 129775},
	{"GWYNNE", 6, 129776},
	{"GENNY", 5, 129777},
	{"GOSSARD", 7, 129778},
	{"SULTANA", 7, 129779},
	{"PERIPLASMIC", 11, 129780},
	{"ATHEISTIC", 9, 129781},
	{"SYMPHONIE", 9, 129782},
	{"TAGESPASSWORT", 13, 129783},
	{"CUNEO", 5, 129784},
	{"OILILY", 6, 129785},
	{"UNFORGIVABLE", 12, 129786},
	{"HOECHST", 7, 129787},
	{"ADVENTURING", 11, 129788},
	{"COTTINGHAM", 10, 129789},
	{"DEFINITY", 8, 129790},
	{"MINIMOTO", 8, 129791},
	{"KINGSGATE", 9, 129792},
	{"TORTE", 5, 129793},
	{"THRASHED", 8, 129794},
	{"EMOTICONE", 9, 129795},
	{"KDEGRAPHICS", 11, 129796},
	{"CHARNOS", 7, 129797},
	{"YMCN", 4, 129798},
	{"WEBH", 4, 129799},
	{"UFOO", 4, 129800},
	{"TVIB", 4, 129801},
	{"TBAU", 4, 129802},
	{"PEXA", 4, 129803},
	{"NKUL", 4, 129804},
	{"LGAY", 4, 129805},
	{"HEPK", 4, 129806},
	{"DAMK", 4, 129807},
	{"BADV", 4, 129808},
	{"MCALPINE", 8, 129809},
	{"TOPSAIL", 7, 129810},
	{"MONEYMAKER", 10, 129811},
	{"CATAMARANS", 10, 129812},
	{"WASSERSTEIN", 11, 129813},
	{"HALFBAKERY", 10, 129814},
	{"STOXX", 5, 129815},
	{"THERMOPLASTICS", 14, 129816},
	{"REGENERATOR", 11, 129817},
	{"BACKLIGHTING", 12, 129818},
	{"POLISI", 6, 129819},
	{"FEEDDEMON", 9, 129820},
	{"CUED", 4, 129821},
	{"ORDERINGS", 9, 129822},
	{"SUEDTIROL", 9, 129823},
	{"ADRIAAN", 7, 129824},
	{"HOWICK", 6, 129825},
	{"MASSEUSE", 8, 129826},
	{"FAIRWEATHER", 11, 129827},
	{"PHETERMINE", 10, 129828},
	{"MIDSEASON", 9, 129829},
	{"MALTE", 5, 129830},
	{"SLOB", 4, 129831},
	{"SOLANGE", 7, 129832},
	{"THAKSIN", 7, 129833},
	{"ECOWAS", 6, 129834},
	{"CARIN", 5, 129835},
	{"ZHUG", 4, 129836},
	{"XTQU", 4, 129837},
	{"XSAY", 4, 129838},
	{"SCHP", 4, 129839},
	{"PURB", 4, 129840},
	{"MYOC", 4, 129841},
	{"GCOT", 4, 129842},
	{"GELMAN", 6, 129843},
	{"NFSD", 4, 129844},
	{"CGAP", 4, 129845},
	{"MUTUEL", 6, 129846},
	{"TIAMAT", 6, 129847},
	{"NALTREXONE", 10, 129848},
	{"APPROPRIATES", 12, 129849},
	{"ETHIOPIANS", 10, 129850},
	{"LESSING", 7, 129851},
	{"LWPOLYLINE", 10, 129852},
	{"PUBCRAWLER", 10, 129853},
	{"FQDN", 4, 129854},
	{"MOVIEGOERS", 10, 129855},
	{"KINDERDICKE", 11, 129856},
	{"MANASSEH", 8, 129857},
	{"KALMAR", 6, 129858},
	{"URETER", 6, 129859},
	{"DISGYBLION", 10, 129860},
	{"WEIBULL", 7, 129861},
	{"PERABO", 6, 129862},
	{"STABILISING", 11, 129863},
	{"GRAFITTI", 8, 129864},
	{"PROPELLANTS", 11, 129865},
	{"RAJAH", 5, 129866},
	{"PINAY", 5, 129867},
	{"PERSUASIONS", 11, 129868},
	{"STEPPES", 7, 129869},
	{"FINALY", 6, 129870},
	{"STEELWORKERS", 12, 129871},
	{"SHEATHED", 8, 129872},
	{"OSCILLATE", 9, 129873},
	{"URYY", 4, 129874},
	{"UKIC", 4, 129875},
	{"SAPC", 4, 129876},
	{"ONCK", 4, 129877},
	{"OJAR", 4, 129878},
	{"OFMW", 4, 129879},
	{"NRYU", 4, 129880},
	{"NMYY", 4, 129881},
	{"KYCL", 4, 129882},
	{"KLAA", 4, 129883},
	{"ETCF", 4, 129884},
	{"LLY", 3, 129885},
	{"MONARO", 6, 129886},
	{"DERIDED", 7, 129887},
	{"BIRDER", 6, 129888},
	{"VOCALLY", 7, 129889},
	{"FELTED", 6, 129890},
	{"SEEPING", 7, 129891},
	{"RETRIAL", 7, 129892},
	{"POLYFOON", 8, 129893},
	{"ALBERTON", 8, 129894},
	{"ENCROACH", 8, 129895},
	{"CHESLEY", 7, 129896},
	{"FLOTSAM", 7, 129897},
	{"CALLI", 5, 129898},
	{"CENTAURS", 8, 129899},
	{"CORRELATIVE", 11, 129900},
	{"NOLOGO", 6, 129901},
	{"KESHER", 6, 129902},
	{"FRITTERS", 8, 129903},
	{"MAIRE", 5, 129904},
	{"TELECOMMUTE", 11, 129905},
	{"KALAMATA", 8, 129906},
	{"YUNM", 4, 129907},
	{"YGUL", 4, 129908},
	{"PTMI", 4, 129909},
	{"PAOF", 4, 129910},
	{"OPVO", 4, 129911},
	{"LJES", 4, 129912},
	{"KMTH", 4, 129913},
	{"HAVR", 4, 129914},
	{"BDEC", 4, 129915},
	{"AKBY", 4, 129916},
	{"OUTED", 5, 129917},
	{"ULTI", 4, 129918},
	{"DIAMETRICALLY", 13, 129919},
	{"HANGOVERS", 9, 129920},
	{"FINANZINTERESSENLOSEN", 21, 129921},
	{"FASTED", 6, 129922},
	{"GERHARDT", 8, 129923},
	{"BALLWIN", 7, 129924},
	{"ASSOCIATI", 9, 129925},
	{"HUMMERS", 7, 129926},
	{"NEUTERING", 9, 129927},
	{"HEESCH", 6, 129928},
	{"FIILIS", 6, 129929},
	{"ALGUNOS", 7, 129930},
	{"CHACON", 6, 129931},
	{"ASTROCYTOMA", 11, 129932},
	{"TORCHIERE", 9, 129933},
	{"RYLANT", 6, 129934},
	{"POPT", 4, 129935},
	{"BFL", 3, 129936},
	{"YPOYRGOS", 8, 129937},
	{"SUMAN", 5, 129938},
	{"HEELYS", 6, 129939},
	{"KEFLEX", 6, 129940},
	{"FREAKISH", 8, 129941},
	{"WNKE", 4, 129942},
	{"RVAM", 4, 129943},
	{"RUZZ", 4, 129944},
	{"RCEJ", 4, 129945},
	{"LTMC", 4, 129946},
	{"IFFJ", 4, 129947},
	{"HELK", 4, 129948},
	{"EYSQ", 4, 129949},
	{"CSRO", 4, 129950},
	{"COMAL", 5, 129951},
	{"READIED", 7, 129952},
	{"ROLY", 4, 129953},
	{"EQUIDISTANT", 11, 129954},
	{"HYPOGLYCEMIC", 12, 129955},
	{"MAYNOOTH", 8, 129956},
	{"PUY", 3, 129957},
	{"DICKER", 6, 129958},
	{"GAZES", 5, 129959},
	{"DIPSTICK", 8, 129960},
	{"PALLBEARERS", 11, 129961},
	{"EXPERIENCIA", 11, 129962},
	{"VIRGINIANS", 10, 129963},
	{"AUTHEN", 6, 129964},
	{"RAINDROP", 8, 129965},
	{"ANTACID", 7, 129966},
	{"NANUET", 6, 129967},
	{"YLLL", 4, 129968},
	{"VSDE", 4, 129969},
	{"ULQU", 4, 129970},
	{"SMPA", 4, 129971},
	{"PPSH", 4, 129972},
	{"OYLO", 4, 129973},
	{"OAMM", 4, 129974},
	{"NVOW", 4, 129975},
	{"MMAO", 4, 129976},
	{"HNCR", 4, 129977},
	{"FVOC", 4, 129978},
	{"ETCM", 4, 129979},
	{"EJUB", 4, 129980},
	{"ACKZ", 4, 129981},
	{"VAPORIZER", 9, 129982},
	{"TWATS", 5, 129983},
	{"EXPT", 4, 129984},
	{"SHOWBOAT", 8, 129985},
	{"NEGLIGENTLY", 11, 129986},
	{"DUKAKIS", 7, 129987},
	{"HIBBARD", 7, 129988},
	{"IRLANDE", 7, 129989},
	{"SISTINE", 7, 129990},
	{"WEIRTON", 7, 129991},
	{"HILDRETH", 8, 129992},
	{"JEFE", 4, 129993},
	{"PEPPY", 5, 129994},
	{"VERNEY", 6, 129995},
	{"AUDIOCASSETTES", 14, 129996},
	{"ENTERPRI", 8, 129997},
	{"FUQUAY", 6, 129998},
	{"LMD", 3, 129999},
	{"MVPS", 4, 130000},
	{"WIMW", 4, 130001},
	{"WEOB", 4, 130002},
	{"VICD", 4, 130003},
	{"UOFE", 4, 130004},
	{"SUCA", 4, 130005},
	{"SLAF", 4, 130006},
	{"RMRB", 4, 130007},
	{"RGWO", 4, 130008},
	{"OYUZ", 4, 130009},
	{"MJEF", 4, 130010},
	{"LDIO", 4, 130011},
	{"GPIG", 4, 130012},
	{"FOXM", 4, 130013},
	{"EYSV", 4, 130014},
	{"ESYC", 4, 130015},
	{"ABEK", 4, 130016},
	{"IRRITATIONS", 11, 130017},
	{"AMPERAGE", 8, 130018},
	{"STUDENTSHIP", 11, 130019},
	{"FAMKE", 5, 130020},
	{"WETENSCHAP", 10, 130021},
	{"STASHED", 7, 130022},
	{"CHIYODA", 7, 130023},
	{"LEYTE", 5, 130024},
	{"SHARPREADER", 11, 130025},
	{"DOMA", 4, 130026},
	{"HELLWIG", 7, 130027},
	{"ALVEY", 5, 130028},
	{"NAGORNO", 7, 130029},
	{"HIGGINSON", 9, 130030},
	{"DESCRIPT", 8, 130031},
	{"CONTIKI", 7, 130032},
	{"BASILICATA", 10, 130033},
	{"COSTAR", 6, 130034},
	{"OSSINING", 8, 130035},
	{"THOTTBOT", 8, 130036},
	{"INTLTOOL", 8, 130037},
	{"KENDA", 5, 130038},
	{"HADDEN", 6, 130039},
	{"MONRO", 5, 130040},
	{"YHUB", 4, 130041},
	{"WDWH", 4, 130042},
	{"VREH", 4, 130043},
	{"TYGL", 4, 130044},
	{"SCWI", 4, 130045},
	{"MNIF", 4, 130046},
	{"LCYL", 4, 130047},
	{"HTYB", 4, 130048},
	{"HIDB", 4, 130049},
	{"GODN", 4, 130050},
	{"GICU", 4, 130051},
	{"DYIF", 4, 130052},
	{"CLYN", 4, 130053},
	{"BOFE", 4, 130054},
	{"BDOE", 4, 130055},
	{"YUGOSLAVIAN", 11, 130056},
	{"UNMOVED", 7, 130057},
	{"PROGRAMMATION", 13, 130058},
	{"ENDODONTICS", 11, 130059},
	{"STUNNER", 7, 130060},
	{"MIDMARKET", 9, 130061},
	{"FWEE", 4, 130062},
	{"STRONGSVILLE", 12, 130063},
	{"PYROTECHNIC", 11, 130064},
	{"GLUM", 4, 130065},
	{"FANCIER", 7, 130066},
	{"CWU", 3, 130067},
	{"ROOMIE", 6, 130068},
	{"JAMAAL", 6, 130069},
	{"HULSE", 5, 130070},
	{"MEDIAPLAYER", 11, 130071},
	{"REXEL", 5, 130072},
	{"GUMTREE", 7, 130073},
	{"UHRDE", 5, 130074},
	{"PSYCHODYNAMIC", 13, 130075},
	{"DEENA", 5, 130076},
	{"ALDINE", 6, 130077},
	{"ECOST", 5, 130078},
	{"SACHAR", 6, 130079},
	{"TALISMANS", 9, 130080},
	{"ANYONES", 7, 130081},
	{"HEMOSTASIS", 10, 130082},
	{"RLLE", 4, 130083},
	{"POGE", 4, 130084},
	{"OKAZ", 4, 130085},
	{"OFZU", 4, 130086},
	{"MUDF", 4, 130087},
	{"MEDQ", 4, 130088},
	{"LPDI", 4, 130089},
	{"HNRU", 4, 130090},
	{"FPAV", 4, 130091},
	{"FDHA", 4, 130092},
	{"AOUL", 4, 130093},
	{"BUNNELL", 7, 130094},
	{"PERPLEXITY", 10, 130095},
	{"PALLISER", 8, 130096},
	{"AMERIPRISE", 10, 130097},
	{"AREOLA", 6, 130098},
	{"PARTICULIER", 11, 130099},
	{"COLDFIRE", 8, 130100},
	{"SERIALIZER", 10, 130101},
	{"LOESS", 5, 130102},
	{"YUCAIPA", 7, 130103},
	{"NAVAN", 5, 130104},
	{"EDITBOXWIDTH", 12, 130105},
	{"INDEPENDENTE", 12, 130106},
	{"CRANBURY", 8, 130107},
	{"UBERSITE", 8, 130108},
	{"POTLATCH", 8, 130109},
	{"HARISH", 6, 130110},
	{"SEARH", 5, 130111},
	{"HUMIC", 5, 130112},
	{"ULC", 3, 130113},
	{"SHAREBUILDER", 12, 130114},
	{"FORMALISMS", 10, 130115},
	{"SULKY", 5, 130116},
	{"GUARDA", 6, 130117},
	{"GIANTESS", 8, 130118},
	{"DADDYS", 6, 130119},
	{"WINLOGON", 8, 130120},
	{"ZACI", 4, 130121},
	{"YOKU", 4, 130122},
	{"UMCU", 4, 130123},
	{"NCKS", 4, 130124},
	{"LKWO", 4, 130125},
	{"LEWF", 4, 130126},
	{"FBOH", 4, 130127},
	{"CKRY", 4, 130128},
	{"AXME", 4, 130129},
	{"AGSD", 4, 130130},
	{"AGOK", 4, 130131},
	{"AACK", 4, 130132},
	{"OBJDIR", 6, 130133},
	{"SIGNEDNESS", 10, 130134},
	{"CHOCOLATIER", 11, 130135},
	{"CASSATT", 7, 130136},
	{"DIETICIANS", 10, 130137},
	{"HANGARS", 7, 130138},
	{"ONECALL", 7, 130139},
	{"TCEQ", 4, 130140},
	{"SKYWARD", 7, 130141},
	{"WOEFUL", 6, 130142},
	{"FEMTOSECOND", 11, 130143},
	{"DOWNSIZED", 9, 130144},
	{"ANABEL", 6, 130145},
	{"SPARCSTATION", 12, 130146},
	{"AVDA", 4, 130147},
	{"LETTERSTYLE", 11, 130148},
	{"ROMY", 4, 130149},
	{"ALCESTER", 8, 130150},
	{"DENED", 5, 130151},
	{"SHAFTER", 7, 130152},
	{"MALFEASANCE", 11, 130153},
	{"BUSHCO", 6, 130154},
	{"DATION", 6, 130155},
	{"CLOWNING", 8, 130156},
	{"VANDALIZED", 10, 130157},
	{"WICKFORD", 8, 130158},
	{"GRUND", 5, 130159},
	{"CONVERTIR", 9, 130160},
	{"POLLUTER", 8, 130161},
	{"VALAIS", 6, 130162},
	{"ZAVI", 4, 130163},
	{"NZOL", 4, 130164},
	{"MJUM", 4, 130165},
	{"KAQU", 4, 130166},
	{"IXYA", 4, 130167},
	{"HYAG", 4, 130168},
	{"HACQ", 4, 130169},
	{"GHLU", 4, 130170},
	{"EALZ", 4, 130171},
	{"DRDR", 4, 130172},
	{"HEROICS", 7, 130173},
	{"MYELODYSPLASTIC", 15, 130174},
	{"EGGER", 5, 130175},
	{"WESTERNER", 9, 130176},
	{"ACUPUNCTURIST", 13, 130177},
	{"WFF", 3, 130178},
	{"CARDCAPTOR", 10, 130179},
	{"SYLVA", 5, 130180},
	{"TEKRAM", 6, 130181},
	{"DROOP", 5, 130182},
	{"BULLEN", 6, 130183},
	{"ARPACK", 6, 130184},
	{"DICTD", 5, 130185},
	{"NEQUE", 5, 130186},
	{"SPEEDWELL", 9, 130187},
	{"CAROLA", 6, 130188},
	{"SPAANS", 6, 130189},
	{"FAMOSA", 6, 130190},
	{"OVERDOSES", 9, 130191},
	{"DISLODGE", 8, 130192},
	{"VOYAGEUR", 8, 130193},
	{"TERENGGANU", 10, 130194},
	{"LINEHAN", 7, 130195},
	{"KEDAH", 5, 130196},
	{"RMGE", 4, 130197},
	{"ORFC", 4, 130198},
	{"NMOZ", 4, 130199},
	{"EBUA", 4, 130200},
	{"COWG", 4, 130201},
	{"SLOGGI", 6, 130202},
	{"TITHING", 7, 130203},
	{"MELKSHAM", 8, 130204},
	{"RECD", 4, 130205},
	{"MEHLMAN", 7, 130206},
	{"LAMPETER", 8, 130207},
	{"YVZ", 3, 130208},
	{"XWC", 3, 130209},
	{"UFX", 3, 130210},
	{"QDW", 3, 130211},
	{"GLZ", 3, 130212},
	{"FQV", 3, 130213},
	{"CJY", 3, 130214},
	{"LINLITHGOW", 10, 130215},
	{"WADED", 5, 130216},
	{"INDICT", 6, 130217},
	{"BARNEGAT", 8, 130218},
	{"OTICON", 6, 130219},
	{"MACCOLL", 7, 130220},
	{"ISINSTANCE", 10, 130221},
	{"PHORBOL", 7, 130222},
	{"CARSHALTON", 10, 130223},
	{"DIVALENT", 8, 130224},
	{"CUTEFTP", 7, 130225},
	{"USXI", 4, 130226},
	{"UMVA", 4, 130227},
	{"SAWJ", 4, 130228},
	{"POSP", 4, 130229},
	{"KGEO", 4, 130230},
	{"JRSA", 4, 130231},
	{"SOUTHAVEN", 9, 130232},
	{"FLORE", 5, 130233},
	{"GROOMERS", 8, 130234},
	{"UNACKNOWLEDGED", 14, 130235},
	{"REVISIONISM", 11, 130236},
	{"NYCE", 4, 130237},
	{"HARMONISE", 9, 130238},
	{"QUIETEST", 8, 130239},
	{"CARVEN", 6, 130240},
	{"SUPERFLY", 8, 130241},
	{"BLACKTHORNE", 11, 130242},
	{"APTITUDES", 9, 130243},
	{"OARD", 4, 130244},
	{"CACI", 4, 130245},
	{"BONNES", 6, 130246},
	{"DIRGAMES", 8, 130247},
	{"CONFUSIONS", 10, 130248},
	{"MANIACAL", 8, 130249},
	{"FARA", 4, 130250},
	{"ALIMENTARY", 10, 130251},
	{"GERBILS", 7, 130252},
	{"SPEEDED", 7, 130253},
	{"OUTIL", 5, 130254},
	{"SLICKS", 6, 130255},
	{"MARGI", 5, 130256},
	{"ISTVAN", 6, 130257},
	{"SLOVAKS", 7, 130258},
	{"TUBERCULIN", 10, 130259},
	{"SEEFELD", 7, 130260},
	{"YTVW", 4, 130261},
	{"YOWI", 4, 130262},
	{"YCYR", 4, 130263},
	{"XFOL", 4, 130264},
	{"UJIL", 4, 130265},
	{"RTLU", 4, 130266},
	{"QUHA", 4, 130267},
	{"NYOG", 4, 130268},
	{"LWIF", 4, 130269},
	{"HBYE", 4, 130270},
	{"ESDY", 4, 130271},
	{"DTHF", 4, 130272},
	{"CBSI", 4, 130273},
	{"ACTIONAID", 9, 130274},
	{"GINAC", 5, 130275},
	{"REPUBLIK", 8, 130276},
	{"RICHWOOD", 8, 130277},
	{"NESTER", 6, 130278},
	{"NURTURES", 8, 130279},
	{"DONGEN", 6, 130280},
	{"IRQS", 4, 130281},
	{"NEWNHAM", 7, 130282},
	{"MOTOREN", 7, 130283},
	{"OCCURENCES", 10, 130284},
	{"DILWORTH", 8, 130285},
	{"METROWEST", 9, 130286},
	{"OUTGROW", 7, 130287},
	{"SWANAGE", 7, 130288},
	{"WESTPHAL", 8, 130289},
	{"MEDIGAP", 7, 130290},
	{"ENCROACHMENTS", 13, 130291},
	{"DECLARER", 8, 130292},
	{"GUIDECRAFT", 10, 130293},
	{"FIERA", 5, 130294},
	{"MAINTAINABLE", 12, 130295},
	{"INEFFABLE", 9, 130296},
	{"HEARER", 6, 130297},
	{"RANCHERIA", 9, 130298},
	{"MICROPOWER", 10, 130299},
	{"ERATE", 5, 130300},
	{"MARUTI", 6, 130301},
	{"INTERATIAL", 10, 130302},
	{"NETBOOT", 7, 130303},
	{"AWAKES", 6, 130304},
	{"BASICLY", 7, 130305},
	{"BRAINIAC", 8, 130306},
	{"KURTH", 5, 130307},
	{"REPUBLIQUE", 10, 130308},
	{"UORD", 4, 130309},
	{"UCYA", 4, 130310},
	{"SYDO", 4, 130311},
	{"RGAC", 4, 130312},
	{"QBUT", 4, 130313},
	{"OFAX", 4, 130314},
	{"MPFA", 4, 130315},
	{"KIEY", 4, 130316},
	{"EFSD", 4, 130317},
	{"CNIG", 4, 130318},
	{"MOUSSAOUI", 9, 130319},
	{"MAGRITTE", 8, 130320},
	{"LEVERING", 8, 130321},
	{"COPPS", 5, 130322},
	{"JANOME", 6, 130323},
	{"CUPPA", 5, 130324},
	{"SADOMASOCHISM", 13, 130325},
	{"GENERIS", 7, 130326},
	{"ALTSCHUL", 8, 130327},
	{"SENEGALESE", 10, 130328},
	{"MULTISITE", 9, 130329},
	{"LEANNA", 6, 130330},
	{"ACCEDING", 8, 130331},
	{"TAMAS", 5, 130332},
	{"BUGSY", 5, 130333},
	{"MCKEESPORT", 10, 130334},
	{"ADABAS", 6, 130335},
	{"ALIEF", 5, 130336},
	{"MALMESBURY", 10, 130337},
	{"ZLEI", 4, 130338},
	{"YUPR", 4, 130339},
	{"XHOM", 4, 130340},
	{"TTPU", 4, 130341},
	{"SIFL", 4, 130342},
	{"PMFI", 4, 130343},
	{"PENQ", 4, 130344},
	{"PEGE", 4, 130345},
	{"OWMR", 4, 130346},
	{"OGWE", 4, 130347},
	{"NPAW", 4, 130348},
	{"MIUS", 4, 130349},
	{"LEGC", 4, 130350},
	{"LAPF", 4, 130351},
	{"INUY", 4, 130352},
	{"FFMU", 4, 130353},
	{"DGMA", 4, 130354},
	{"AYUG", 4, 130355},
	{"ALZI", 4, 130356},
	{"AGBO", 4, 130357},
	{"FLAKING", 7, 130358},
	{"KOFAX", 5, 130359},
	{"PROBITY", 7, 130360},
	{"FORMAS", 6, 130361},
	{"LIANE", 5, 130362},
	{"SCHOL", 5, 130363},
	{"EXELLENT", 8, 130364},
	{"GRUBS", 5, 130365},
	{"SEMILLON", 8, 130366},
	{"UNFLINCHING", 11, 130367},
	{"OPENWAVE", 8, 130368},
	{"MURMURING", 9, 130369},
	{"BERGH", 5, 130370},
	{"NONLOCAL", 8, 130371},
	{"JUNGEN", 6, 130372},
	{"NEODYS", 6, 130373},
	{"UVEX", 4, 130374},
	{"GENTRIFICATION", 14, 130375},
	{"GREENSTEIN", 10, 130376},
	{"TRIUMPHAL", 9, 130377},
	{"REDSHIFTS", 9, 130378},
	{"BCBGIRLS", 8, 130379},
	{"WILDEBEEST", 10, 130380},
	{"SUKHOTHAI", 9, 130381},
	{"LVOS", 4, 130382},
	{"EXAV", 4, 130383},
	{"DRKI", 4, 130384},
	{"ISSUANCES", 9, 130385},
	{"SEASONALE", 9, 130386},
	{"KLOTZ", 5, 130387},
	{"TINDALL", 7, 130388},
	{"MAHONY", 6, 130389},
	{"PANAVISE", 8, 130390},
	{"AFFABLE", 7, 130391},
	{"RESURGENT", 9, 130392},
	{"RENEGOTIATE", 11, 130393},
	{"DETERMINATIVE", 13, 130394},
	{"GALINDO", 7, 130395},
	{"SCHNABEL", 8, 130396},
	{"LANDLINES", 9, 130397},
	{"FORSCHUNGSZENTRUM", 17, 130398},
	{"BEERADVOCATE", 12, 130399},
	{"POUSADA", 7, 130400},
	{"SOMMELIER", 9, 130401},
	{"ACERNOTE", 8, 130402},
	{"YZEA", 4, 130403},
	{"YPSO", 4, 130404},
	{"UVRA", 4, 130405},
	{"UANJ", 4, 130406},
	{"TEUM", 4, 130407},
	{"NCDE", 4, 130408},
	{"LTIU", 4, 130409},
	{"STEPNEY", 7, 130410},
	{"CREDITCARDS", 11, 130411},
	{"PIMPERNEL", 9, 130412},
	{"HELPFULLY", 9, 130413},
	{"AFFY", 4, 130414},
	{"WORSHIPERS", 10, 130415},
	{"TEARDROPS", 9, 130416},
	{"PINNOCK", 7, 130417},
	{"SILBERMAN", 9, 130418},
	{"PILBARA", 7, 130419},
	{"PERICARDIAL", 11, 130420},
	{"FRONTENDS", 9, 130421},
	{"ULTIME", 6, 130422},
	{"THROMBOLYTIC", 12, 130423},
	{"CORLISS", 7, 130424},
	{"RUBRA", 5, 130425},
	{"ONCOGENES", 9, 130426},
	{"SAWGRASS", 8, 130427},
	{"GINGIVAL", 8, 130428},
	{"SOMONE", 6, 130429},
	{"VIGINA", 6, 130430},
	{"INVOLUTION", 10, 130431},
	{"SEARCHDE", 8, 130432},
	{"BNFL", 4, 130433},
	{"VANDERBURGH", 11, 130434},
	{"UNDERINSURED", 12, 130435},
	{"COUNTERMEASURE", 14, 130436},
	{"UMBB", 4, 130437},
	{"RIIV", 4, 130438},
	{"RBCH", 4, 130439},
	{"NDDS", 4, 130440},
	{"MKER", 4, 130441},
	{"LPHB", 4, 130442},
	{"BBSH", 4, 130443},
	{"BEUTIFUL", 8, 130444},
	{"AVONS", 5, 130445},
	{"LENCE", 5, 130446},
	{"REDDICK", 7, 130447},
	{"NOVELA", 6, 130448},
	{"RLM", 3, 130449},
	{"WINDEL", 6, 130450},
	{"FLAIL", 5, 130451},
	{"SELFRIDGE", 9, 130452},
	{"AKAKA", 5, 130453},
	{"SUMPTION", 8, 130454},
	{"MOLARS", 6, 130455},
	{"DISQUALIFYING", 13, 130456},
	{"BROYHILL", 8, 130457},
	{"FRCS", 4, 130458},
	{"ELAND", 5, 130459},
	{"VOLKSWAGON", 10, 130460},
	{"WHITSTABLE", 10, 130461},
	{"GLOBO", 5, 130462},
	{"VITALY", 6, 130463},
	{"SYSROUTED", 9, 130464},
	{"YOUN", 4, 130465},
	{"SEMIGROUP", 9, 130466},
	{"BROOKLANDS", 10, 130467},
	{"SHAKIR", 6, 130468},
	{"LOISIRS", 7, 130469},
	{"YUNV", 4, 130470},
	{"YGAZ", 4, 130471},
	{"YEGO", 4, 130472},
	{"TUMH", 4, 130473},
	{"TCWI", 4, 130474},
	{"KPUL", 4, 130475},
	{"HARJ", 4, 130476},
	{"GBYJ", 4, 130477},
	{"EVOM", 4, 130478},
	{"GREENOUGH", 9, 130479},
	{"SWHACK", 6, 130480},
	{"WAMSUTTA", 8, 130481},
	{"DISCRIMINATOR", 13, 130482},
	{"LORATADINE", 10, 130483},
	{"DISAGGREGATION", 14, 130484},
	{"CHUNGHWA", 8, 130485},
	{"LUMI", 4, 130486},
	{"POOK", 4, 130487},
	{"NORQUIST", 8, 130488},
	{"LCCN", 4, 130489},
	{"ADULTERATED", 11, 130490},
	{"NICODEMUS", 9, 130491},
	{"KARRATHA", 8, 130492},
	{"MATSUURA", 8, 130493},
	{"ARDOR", 5, 130494},
	{"WISSENSCHAFTEN", 14, 130495},
	{"SISKO", 5, 130496},
	{"PBASE", 5, 130497},
	{"PROOFREADER", 11, 130498},
	{"HEILBRONN", 9, 130499},
	{"XMLCHAR", 7, 130500},
	{"WIELKIE", 7, 130501},
	{"RELATO", 6, 130502},
	{"WEBCOM", 6, 130503},
	{"STEROLS", 7, 130504},
	{"MISSIVE", 7, 130505},
	{"SCOOPING", 8, 130506},
	{"MIDDLEBORO", 10, 130507},
	{"WMEE", 4, 130508},
	{"WLOA", 4, 130509},
	{"WJUD", 4, 130510},
	{"UODA", 4, 130511},
	{"RAHY", 4, 130512},
	{"PTLI", 4, 130513},
	{"LZOO", 4, 130514},
	{"LAGM", 4, 130515},
	{"CNAL", 4, 130516},
	{"BENV", 4, 130517},
	{"BBLO", 4, 130518},
	{"AHBR", 4, 130519},
	{"KAREENA", 7, 130520},
	{"DIDION", 6, 130521},
	{"TINNY", 5, 130522},
	{"BAGAN", 5, 130523},
	{"SEROVAR", 7, 130524},
	{"ASCENDS", 7, 130525},
	{"TAJIMA", 6, 130526},
	{"SPLINTERED", 10, 130527},
	{"AMEC", 4, 130528},
	{"TRANSACTING", 11, 130529},
	{"MINSKY", 6, 130530},
	{"OESOPHAGEAL", 11, 130531},
	{"RECOMPILING", 11, 130532},
	{"ANNOYINGLY", 10, 130533},
	{"STANLY", 6, 130534},
	{"REWRITERULE", 11, 130535},
	{"NOMINE", 6, 130536},
	{"GUYZ", 4, 130537},
	{"CHARPENTIER", 11, 130538},
	{"LBR", 3, 130539},
	{"FINEREADER", 10, 130540},
	{"CHOICEFORYOU", 12, 130541},
	{"DAHLE", 5, 130542},
	{"FAVICON", 7, 130543},
	{"CABOCHONS", 9, 130544},
	{"NUTCH", 5, 130545},
	{"ISENBERG", 8, 130546},
	{"BUSEN", 5, 130547},
	{"SATISFIABLE", 11, 130548},
	{"OUMY", 4, 130549},
	{"OMUK", 4, 130550},
	{"OKRU", 4, 130551},
	{"NZIP", 4, 130552},
	{"NMCF", 4, 130553},
	{"MYSF", 4, 130554},
	{"LLHY", 4, 130555},
	{"GNOU", 4, 130556},
	{"EAKV", 4, 130557},
	{"BANV", 4, 130558},
	{"AUGB", 4, 130559},
	{"WINDSWEPT", 9, 130560},
	{"LOAFING", 7, 130561},
	{"NEPHROL", 7, 130562},
	{"BEEMAN", 6, 130563},
	{"ROOSTING", 8, 130564},
	{"FLICKBALL", 9, 130565},
	{"WXP", 3, 130566},
	{"TALUS", 5, 130567},
	{"REPUBLICANISM", 13, 130568},
	{"GEOFIELD", 8, 130569},
	{"FENCHURCH", 9, 130570},
	{"AURALEX", 7, 130571},
	{"AERON", 5, 130572},
	{"NAVIONICS", 9, 130573},
	{"BUNE", 4, 130574},
	{"WAHRE", 5, 130575},
	{"FOIBLES", 7, 130576},
	{"CAPM", 4, 130577},
	{"WINGNUTS", 8, 130578},
	{"FANTASIZE", 9, 130579},
	{"DURES", 5, 130580},
	{"SAFIRE", 6, 130581},
	{"URZO", 4, 130582},
	{"PVID", 4, 130583},
	{"PPLU", 4, 130584},
	{"OXGA", 4, 130585},
	{"GAIU", 4, 130586},
	{"AWMU", 4, 130587},
	{"ARUE", 4, 130588},
	{"OCCLUDED", 8, 130589},
	{"CHOSES", 6, 130590},
	{"SQUATTER", 8, 130591},
	{"WISNIEWSKI", 10, 130592},
	{"AXCESS", 6, 130593},
	{"WALDEMAR", 8, 130594},
	{"COLOURLESS", 10, 130595},
	{"BROWNSTEIN", 10, 130596},
	{"GRZEGORZ", 8, 130597},
	{"JAUME", 5, 130598},
	{"SHIBBOLETH", 10, 130599},
	{"SALESPERSONS", 12, 130600},
	{"TUNISIE", 7, 130601},
	{"SAXENA", 6, 130602},
	{"CALORIEKING", 11, 130603},
	{"JOBBER", 6, 130604},
	{"DIMENSIONMAP", 12, 130605},
	{"EPIXTECH", 8, 130606},
	{"PREPERATION", 11, 130607},
	{"HULMAN", 6, 130608},
	{"UNYIELDING", 10, 130609},
	{"LIMITERS", 8, 130610},
	{"XBRL", 4, 130611},
	{"FLABBY", 6, 130612},
	{"TOXOPLASMA", 10, 130613},
	{"STIMPY", 6, 130614},
	{"BINGEN", 6, 130615},
	{"WALMSLEY", 8, 130616},
	{"YEEF", 4, 130617},
	{"YANX", 4, 130618},
	{"UVEW", 4, 130619},
	{"NYRS", 4, 130620},
	{"NUXS", 4, 130621},
	{"KCUS", 4, 130622},
	{"IRIF", 4, 130623},
	{"IKIK", 4, 130624},
	{"HHYD", 4, 130625},
	{"ERBW", 4, 130626},
	{"DMUG", 4, 130627},
	{"AYZA", 4, 130628},
	{"ALUZ", 4, 130629},
	{"SLURRED", 7, 130630},
	{"ENLARGES", 8, 130631},
	{"SPROUL", 6, 130632},
	{"BLANDING", 8, 130633},
	{"SOMATOSENSORY", 13, 130634},
	{"NORTHBOROUGH", 12, 130635},
	{"APACE", 5, 130636},
	{"JACE", 4, 130637},
	{"LORAL", 5, 130638},
	{"CURRIC", 6, 130639},
	{"DESPEJADO", 9, 130640},
	{"MOBILISING", 10, 130641},
	{"EGLIN", 5, 130642},
	{"PMU", 3, 130643},
	{"GERALDO", 7, 130644},
	{"STEPSON", 7, 130645},
	{"SIDEBOARDS", 10, 130646},
	{"DOKTOR", 6, 130647},
	{"ANORAK", 6, 130648},
	{"HARBORED", 8, 130649},
	{"EXPREF", 6, 130650},
	{"UNGZ", 4, 130651},
	{"CAROB", 5, 130652},
	{"ATLANTIQUE", 10, 130653},
	{"DEESIDE", 7, 130654},
	{"BULWARK", 7, 130655},
	{"STYL", 4, 130656},
	{"SHELTIE", 7, 130657},
	{"BERMONDSEY", 10, 130658},
	{"INDEXDIMENSIONMAP", 17, 130659},
	{"HOLGATE", 7, 130660},
	{"MANGOLD", 7, 130661},
	{"DDIM", 4, 130662},
	{"ANDRO", 5, 130663},
	{"GEODIMENSION", 12, 130664},
	{"WSTW", 4, 130665},
	{"OWUL", 4, 130666},
	{"IRKC", 4, 130667},
	{"EURN", 4, 130668},
	{"EBSP", 4, 130669},
	{"DSIW", 4, 130670},
	{"DIFL", 4, 130671},
	{"DEXB", 4, 130672},
	{"COCU", 4, 130673},
	{"SMARTNET", 8, 130674},
	{"FCNTL", 5, 130675},
	{"CHOISE", 6, 130676},
	{"PAULINKA", 8, 130677},
	{"SIMPLICIAL", 10, 130678},
	{"BEEFED", 6, 130679},
	{"MULTICOLORE", 11, 130680},
	{"GRECIA", 6, 130681},
	{"SPECULATES", 10, 130682},
	{"OPYRIGHT", 8, 130683},
	{"CLIPBOARDS", 10, 130684},
	{"HUBZONE", 7, 130685},
	{"PERVERS", 7, 130686},
	{"STRINGY", 7, 130687},
	{"MISUSING", 8, 130688},
	{"PECTED", 6, 130689},
	{"MATROSKA", 8, 130690},
	{"SERONT", 6, 130691},
	{"GERTZ", 5, 130692},
	{"MSSG", 4, 130693},
	{"ZSTR", 4, 130694},
	{"UPGU", 4, 130695},
	{"UJIM", 4, 130696},
	{"REZM", 4, 130697},
	{"OJAZ", 4, 130698},
	{"NYGL", 4, 130699},
	{"HECV", 4, 130700},
	{"FEXO", 4, 130701},
	{"EFUD", 4, 130702},
	{"DIUR", 4, 130703},
	{"BODYROCKERS", 11, 130704},
	{"BEFRIENDS", 9, 130705},
	{"TARGETTING", 10, 130706},
	{"LUISTER", 7, 130707},
	{"FRFE", 4, 130708},
	{"SONOROUS", 8, 130709},
	{"AUSTRALIANA", 11, 130710},
	{"WAITROSE", 8, 130711},
	{"ZANG", 4, 130712},
	{"YEADON", 6, 130713},
	{"ENDERLE", 7, 130714},
	{"COHABITING", 10, 130715},
	{"PARALYMPICS", 11, 130716},
	{"BREASTPLATE", 11, 130717},
	{"DRAUGHTS", 8, 130718},
	{"ZYL", 3, 130719},
	{"CONSECO", 7, 130720},
	{"SUPERCLUBS", 10, 130721},
	{"PORTSEA", 7, 130722},
	{"TRAVELNOW", 9, 130723},
	{"RESUPPLY", 8, 130724},
	{"AUXIN", 5, 130725},
	{"SETTEMBRE", 9, 130726},
	{"RECRUITTRACKER", 14, 130727},
	{"PABX", 4, 130728},
	{"BIOLOGIA", 8, 130729},
	{"HEAVED", 6, 130730},
	{"CABOOLTURE", 10, 130731},
	{"LAZARE", 6, 130732},
	{"LASERWRITER", 11, 130733},
	{"INDIVIDUALIST", 13, 130734},
	{"INTERCOMPANY", 12, 130735},
	{"AYCLIFFE", 8, 130736},
	{"SHINOBI", 7, 130737},
	{"YIME", 4, 130738},
	{"XADV", 4, 130739},
	{"WOJI", 4, 130740},
	{"PIAR", 4, 130741},
	{"OWLV", 4, 130742},
	{"NLUS", 4, 130743},
	{"IGEB", 4, 130744},
	{"HPLO", 4, 130745},
	{"HKUR", 4, 130746},
	{"FMOH", 4, 130747},
	{"FFYD", 4, 130748},
	{"DVDF", 4, 130749},
	{"FASHIONING", 10, 130750},
	{"BARRICHELLO", 11, 130751},
	{"DATADIMENSION", 13, 130752},
	{"BUSHWALKING", 11, 130753},
	{"ALEGRIA", 7, 130754},
	{"CHURNED", 7, 130755},
	{"PISTACHIOS", 10, 130756},
	{"MAGITRONIC", 10, 130757},
	{"PYNE", 4, 130758},
	{"MESSAGGI", 8, 130759},
	{"MFF", 3, 130760},
	{"IRONIES", 7, 130761},
	{"UNKOWN", 6, 130762},
	{"BORIC", 5, 130763},
	{"MICROSITES", 10, 130764},
	{"QVGA", 4, 130765},
	{"FOURCHANNEL", 11, 130766},
	{"DIGA", 4, 130767},
	{"MOUTHSHUT", 9, 130768},
	{"SOTEC", 5, 130769},
	{"MYCLASS", 7, 130770},
	{"CORRESPONDANCE", 14, 130771},
	{"RELIVING", 8, 130772},
	{"CONSTITUTIVELY", 14, 130773},
	{"FUSEBOX", 7, 130774},
	{"SUNCATCHER", 10, 130775},
	{"ACROBATS", 8, 130776},
	{"TRIBALS", 7, 130777},
	{"ANSLEY", 6, 130778},
	{"CYMORTH", 7, 130779},
	{"ULNI", 4, 130780},
	{"PELR", 4, 130781},
	{"KIMD", 4, 130782},
	{"DEMR", 4, 130783},
	{"ENDORPHIN", 9, 130784},
	{"MAINTAINANCE", 12, 130785},
	{"DAPPLED", 7, 130786},
	{"GALLIC", 6, 130787},
	{"ESTRELLAS", 9, 130788},
	{"NIUYUE", 6, 130789},
	{"PHOBIC", 6, 130790},
	{"WINSTAR", 7, 130791},
	{"VENGABOYS", 9, 130792},
	{"MYINT", 5, 130793},
	{"TURKIC", 6, 130794},
	{"TUBULE", 6, 130795},
	{"RAGLAND", 7, 130796},
	{"GRUEN", 5, 130797},
	{"NACK", 4, 130798},
	{"KAYO", 4, 130799},
	{"NONINSTITUTIONALIZED", 20, 130800},
	{"AZALEAS", 7, 130801},
	{"PATRIARCHATE", 12, 130802},
	{"CHATBOARDS", 10, 130803},
	{"WALTZING", 8, 130804},
	{"DINGELL", 7, 130805},
	{"THERMONUCLEAR", 13, 130806},
	{"THOROGOOD", 9, 130807},
	{"TACKING", 7, 130808},
	{"FIXTMB", 6, 130809},
	{"POLEMICS", 8, 130810},
	{"AINSLIE", 7, 130811},
	{"FEIGNED", 7, 130812},
	{"ZPER", 4, 130813},
	{"YUSB", 4, 130814},
	{"SUCR", 4, 130815},
	{"RGBO", 4, 130816},
	{"RGAG", 4, 130817},
	{"PHLO", 4, 130818},
	{"PAGL", 4, 130819},
	{"MOMH", 4, 130820},
	{"LETJ", 4, 130821},
	{"ITZF", 4, 130822},
	{"ADUD", 4, 130823},
	{"QUESO", 5, 130824},
	{"CELERA", 6, 130825},
	{"UNIG", 4, 130826},
	{"UDEB", 4, 130827},
	{"ESOPHAGITIS", 11, 130828},
	{"MEERA", 5, 130829},
	{"EJBS", 4, 130830},
	{"ARMRESTS", 8, 130831},
	{"DROSS", 5, 130832},
	{"WILLEBRAND", 10, 130833},
	{"MOORCROFT", 9, 130834},
	{"SOLIDITY", 8, 130835},
	{"EKMAN", 5, 130836},
	{"DOGE", 4, 130837},
	{"CAMPAGNA", 8, 130838},
	{"KLOTHS", 6, 130839},
	{"HOSPITALISATION", 15, 130840},
	{"DOCKYARD", 8, 130841},
	{"MORONGO", 7, 130842},
	{"LILL", 4, 130843},
	{"OPPORTUNIST", 11, 130844},
	{"NSCLC", 5, 130845},
	{"INDECISIVE", 10, 130846},
	{"GOODLETTSVILLE", 14, 130847},
	{"YUCKY", 5, 130848},
	{"BIOTECHNOLOGICAL", 16, 130849},
	{"RECURS", 6, 130850},
	{"DRIPPED", 7, 130851},
	{"DIOVAN", 6, 130852},
	{"OUCI", 4, 130853},
	{"NMEB", 4, 130854},
	{"GYPE", 4, 130855},
	{"GUEJ", 4, 130856},
	{"FELM", 4, 130857},
	{"EKPL", 4, 130858},
	{"BYCY", 4, 130859},
	{"NAUGATUCK", 9, 130860},
	{"FLORIDIANS", 10, 130861},
	{"SUPPORTO", 8, 130862},
	{"RBM", 3, 130863},
	{"INFOLITHIUM", 11, 130864},
	{"ALGHERO", 7, 130865},
	{"TOWANDA", 7, 130866},
	{"DUSHANBE", 8, 130867},
	{"OZAKI", 5, 130868},
	{"REFUEL", 6, 130869},
	{"REDEVELOPED", 11, 130870},
	{"HOLDERNESS", 10, 130871},
	{"ACCORDIAN", 9, 130872},
	{"EPICURE", 7, 130873},
	{"WINTERTON", 9, 130874},
	{"XARGS", 5, 130875},
	{"THURSO", 6, 130876},
	{"SPIERS", 6, 130877},
	{"NITPICKIT", 9, 130878},
	{"SORBENT", 7, 130879},
	{"CALFLORA", 8, 130880},
	{"REMEDIATE", 9, 130881},
	{"PODCASTER", 9, 130882},
	{"SANTOSH", 7, 130883},
	{"CINNABAR", 8, 130884},
	{"CKM", 3, 130885},
	{"PHOTOELECTRON", 13, 130886},
	{"YAGL", 4, 130887},
	{"ULCU", 4, 130888},
	{"PIVE", 4, 130889},
	{"NUCC", 4, 130890},
	{"EWLU", 4, 130891},
	{"AJUA", 4, 130892},
	{"MATHEWSON", 9, 130893},
	{"LEVITY", 6, 130894},
	{"REGULARITIES", 12, 130895},
	{"MILLBURY", 8, 130896},
	{"MAMMARIES", 9, 130897},
	{"SEMIN", 5, 130898},
	{"ADJUDICATING", 12, 130899},
	{"SEROTYPES", 9, 130900},
	{"MOULINEX", 8, 130901},
	{"LLYWODRAETH", 11, 130902},
	{"DENIZ", 5, 130903},
	{"LUREX", 5, 130904},
	{"JOURNEYING", 10, 130905},
	{"SPELLER", 7, 130906},
	{"HOWARDS", 7, 130907},
	{"CAZENOVIA", 9, 130908},
	{"OPPRESSOR", 9, 130909},
	{"FBB", 3, 130910},
	{"METRICAL", 8, 130911},
	{"SIERRAS", 7, 130912},
	{"BARTLE", 6, 130913},
	{"ANIMADOS", 8, 130914},
	{"TAMALES", 7, 130915},
	{"HAULS", 5, 130916},
	{"KOPF", 4, 130917},
	{"IMAGEREADY", 10, 130918},
	{"NOVUM", 5, 130919},
	{"AVAILBLE", 8, 130920},
	{"HERETIK", 7, 130921},
	{"SANDOZ", 6, 130922},
	{"WFUR", 4, 130923},
	{"OLKB", 4, 130924},
	{"NTDW", 4, 130925},
	{"MEDZ", 4, 130926},
	{"LBYV", 4, 130927},
	{"IVYT", 4, 130928},
	{"GIOC", 4, 130929},
	{"GGUM", 4, 130930},
	{"GAFG", 4, 130931},
	{"FAJE", 4, 130932},
	{"DARJ", 4, 130933},
	{"CTKE", 4, 130934},
	{"BJUS", 4, 130935},
	{"AUNF", 4, 130936},
	{"AOFV", 4, 130937},
	{"ZAZZLE", 6, 130938},
	{"LITTEL", 6, 130939},
	{"IMPERIA", 7, 130940},
	{"NGOC", 4, 130941},
	{"PPPP", 4, 130942},
	{"STARBLVD", 8, 130943},
	{"IMMEASURABLY", 12, 130944},
	{"HYGROMETER", 10, 130945},
	{"HAGGLING", 8, 130946},
	{"PELLEGRINO", 10, 130947},
	{"HOMEBUILDING", 12, 130948},
	{"GAFTON", 6, 130949},
	{"RISPERIDONE", 11, 130950},
	{"ECRITURE", 8, 130951},
	{"FOXTEL", 6, 130952},
	{"TUSSLE", 6, 130953},
	{"UROLOGIST", 9, 130954},
	{"ZERG", 4, 130955},
	{"TOUGHENED", 9, 130956},
	{"SUSANVILLE", 10, 130957},
	{"FIENDISH", 8, 130958},
	{"DIAPHRAGMS", 10, 130959},
	{"VITAMINA", 8, 130960},
	{"GLORIFICATION", 13, 130961},
	{"MOTHERSHIP", 10, 130962},
	{"WAYFARER", 8, 130963},
	{"ZZAL", 4, 130964},
	{"YECL", 4, 130965},
	{"VCOR", 4, 130966},
	{"OVLA", 4, 130967},
	{"JIBA", 4, 130968},
	{"IKUL", 4, 130969},
	{"HUER", 4, 130970},
	{"HIQU", 4, 130971},
	{"GDUS", 4, 130972},
	{"DYTU", 4, 130973},
	{"CIOF", 4, 130974},
	{"BEZE", 4, 130975},
	{"PASSERIFORMES", 13, 130976},
	{"DEATON", 6, 130977},
	{"FEDOROV", 7, 130978},
	{"FOREBRAIN", 9, 130979},
	{"REAMER", 6, 130980},
	{"ARABIANS", 8, 130981},
	{"EXPANSES", 8, 130982},
	{"DEMANAR", 7, 130983},
	{"PLESSIS", 7, 130984},
	{"PIERPONT", 8, 130985},
	{"GREN", 4, 130986},
	{"SEPP", 4, 130987},
	{"NUITS", 5, 130988},
	{"PATERNO", 7, 130989},
	{"ANTICONVULSANTS", 15, 130990},
	{"LUNAS", 5, 130991},
	{"DORKY", 5, 130992},
	{"CHIPMAN", 7, 130993},
	{"SATSUMA", 7, 130994},
	{"KUNUNURRA", 9, 130995},
	{"HYPOTHETICALLY", 14, 130996},
	{"TREMAINE", 8, 130997},
	{"SUPERCEDED", 10, 130998},
	{"HILLIS", 6, 130999},
	{"COTATI", 6, 131000},
	{"SERIWSY", 7, 131001},
	{"NEUHAUS", 7, 131002},
	{"DERVISH", 7, 131003},
	{"THYK", 4, 131004},
	{"SUWI", 4, 131005},
	{"PITD", 4, 131006},
	{"MYNU", 4, 131007},
	{"KNOV", 4, 131008},
	{"IRYU", 4, 131009},
	{"CIRQ", 4, 131010},
	{"BIBU", 4, 131011},
	{"IRREPRESSIBLE", 13, 131012},
	{"TAKAO", 5, 131013},
	{"GRUPPEN", 7, 131014},
	{"KANTO", 5, 131015},
	{"INTERROGATING", 13, 131016},
	{"MONADNOCK", 9, 131017},
	{"GENERALIZES", 11, 131018},
	{"READYING", 8, 131019},
	{"MAKRO", 5, 131020},
	{"LEIDER", 6, 131021},
	{"SIGINT", 6, 131022},
	{"BALER", 5, 131023},
	{"JOPPA", 5, 131024},
	{"TEMPOS", 6, 131025},
	{"WILTED", 6, 131026},
	{"MONONGAHELA", 11, 131027},
	{"ADANA", 5, 131028},
	{"MYABSOLUTEARTS", 14, 131029},
	{"EMOLUMENTS", 10, 131030},
	{"MODELLERS", 9, 131031},
	{"EGAL", 4, 131032},
	{"CONNED", 6, 131033},
	{"UUMA", 4, 131034},
	{"TRBI", 4, 131035},
	{"TPMD", 4, 131036},
	{"MRTO", 4, 131037},
	{"KIMN", 4, 131038},
	{"FRUD", 4, 131039},
	{"TANGRAM", 7, 131040},
	{"REFEREN", 7, 131041},
	{"CZECHOSLOVAK", 12, 131042},
	{"LEDSIGN", 7, 131043},
	{"TINFOIL", 7, 131044},
	{"MCUS", 4, 131045},
	{"HOODLUM", 7, 131046},
	{"DIVS", 4, 131047},
	{"JONGG", 5, 131048},
	{"HYPERGEOMETRIC", 14, 131049},
	{"SKYBOX", 6, 131050},
	{"CHELATE", 7, 131051},
	{"TYPHOONS", 8, 131052},
	{"BREADMAKERS", 11, 131053},
	{"MUTES", 5, 131054},
	{"THICH", 5, 131055},
	{"ACCOMPANIST", 11, 131056},
	{"LUU", 3, 131057},
	{"GRINDELWALD", 11, 131058},
	{"BRUCH", 5, 131059},
	{"OUTWIT", 6, 131060},
	{"MIDYEAR", 7, 131061},
	{"UNMEDIATED", 10, 131062},
	{"SIDETRACKED", 11, 131063},
	{"AGCA", 4, 131064},
	{"SERZONE", 7, 131065},
	{"MAGNESIA", 8, 131066},
	{"BONTHRONE", 9, 131067},
	{"PATRONIZE", 9, 131068},
	{"ODTU", 4, 131069},
	{"MSEG", 4, 131070},
	{"JAWO", 4, 131071},
	{"GGLY", 4, 131072},
	{"FGHO", 4, 131073},
	{"EFFJ", 4, 131074},
	{"EFBA", 4, 131075},
	{"AYEK", 4, 131076},
	{"BRITTO", 6, 131077},
	{"EERF", 4, 131078},
	{"IMPASSABLE", 10, 131079},
	{"JACKI", 5, 131080},
	{"TEMPOR", 6, 131081},
	{"INTERMATIC", 10, 131082},
	{"IPSILATERAL", 11, 131083},
	{"SERF", 4, 131084},
	{"GOLDSCHMIDT", 11, 131085},
	{"SUBTASK", 7, 131086},
	{"ULRIKE", 6, 131087},
	{"METROLYRICS", 11, 131088},
	{"KONING", 6, 131089},
	{"PELION", 6, 131090},
	{"BELGE", 5, 131091},
	{"CAPLE", 5, 131092},
	{"TRAVAN", 6, 131093},
	{"MARGERA", 7, 131094},
	{"BURIES", 6, 131095},
	{"BEDLINGTON", 10, 131096},
	{"VOBIS", 5, 131097},
	{"BOOZER", 6, 131098},
	{"GAELS", 5, 131099},
	{"REVAMPS", 7, 131100},
	{"SPONSE", 6, 131101},
	{"NICOTIANA", 9, 131102},
	{"YNYS", 4, 131103},
	{"EUROTUNNEL", 10, 131104},
	{"SIGNOR", 6, 131105},
	{"PHLEGM", 6, 131106},
	{"RESTE", 5, 131107},
	{"PROBA", 5, 131108},
	{"CONNECTIONLESS", 14, 131109},
	{"NATHANSON", 9, 131110},
	{"BULLYS", 6, 131111},
	{"PETAR", 5, 131112},
	{"XYRON", 5, 131113},
	{"SUBATOMIC", 9, 131114},
	{"PADDLER", 7, 131115},
	{"SCRUFF", 6, 131116},
	{"FLANKER", 7, 131117},
	{"RZEA", 4, 131118},
	{"RCTO", 4, 131119},
	{"LTZM", 4, 131120},
	{"KOPO", 4, 131121},
	{"IFIV", 4, 131122},
	{"GATJ", 4, 131123},
	{"FCOB", 4, 131124},
	{"EXDO", 4, 131125},
	{"CCTH", 4, 131126},
	{"BIDC", 4, 131127},
	{"BETB", 4, 131128},
	{"STAYIN", 6, 131129},
	{"FREEDMEN", 8, 131130},
	{"RENTLY", 6, 131131},
	{"HUSSERL", 7, 131132},
	{"RHYNE", 5, 131133},
	{"RAFFI", 5, 131134},
	{"GIGLIO", 6, 131135},
	{"CENTERWATCH", 11, 131136},
	{"OBLIGING", 8, 131137},
	{"FORDYCE", 7, 131138},
	{"AFILIAS", 7, 131139},
	{"HERMETICALLY", 12, 131140},
	{"HALOSCAN", 8, 131141},
	{"GRAVESTONES", 11, 131142},
	{"DECRYPTING", 10, 131143},
	{"UNCOMMONLY", 10, 131144},
	{"PRAXAIR", 7, 131145},
	{"NETZWERK", 8, 131146},
	{"JORGEN", 6, 131147},
	{"NUDGED", 6, 131148},
	{"DECIDABLE", 9, 131149},
	{"IONAWR", 6, 131150},
	{"INHOSPITABLE", 12, 131151},
	{"PPARC", 5, 131152},
	{"DISSENSION", 10, 131153},
	{"HALLUCINOGENIC", 14, 131154},
	{"YGIU", 4, 131155},
	{"XACO", 4, 131156},
	{"WENB", 4, 131157},
	{"UMEG", 4, 131158},
	{"RIUN", 4, 131159},
	{"NFCW", 4, 131160},
	{"NCKL", 4, 131161},
	{"MKIC", 4, 131162},
	{"GSJO", 4, 131163},
	{"EDUI", 4, 131164},
	{"DEZT", 4, 131165},
	{"BYZE", 4, 131166},
	{"BPIS", 4, 131167},
	{"ACZY", 4, 131168},
	{"LOOSELEAF", 9, 131169},
	{"SEARCHENGINES", 13, 131170},
	{"INTERWIKI", 9, 131171},
	{"CYTO", 4, 131172},
	{"PLAYFIELD", 9, 131173},
	{"COLESLAW", 8, 131174},
	{"ELVA", 4, 131175},
	{"MAYAGUEZ", 8, 131176},
	{"NEWTELLIGENCE", 13, 131177},
	{"INTERMINGLED", 12, 131178},
	{"TUAM", 4, 131179},
	{"CALANDER", 8, 131180},
	{"BELG", 4, 131181},
	{"CASERAS", 7, 131182},
	{"STANDART", 8, 131183},
	{"KOOKY", 5, 131184},
	{"DWARFED", 7, 131185},
	{"QFP", 3, 131186},
	{"LANGS", 5, 131187},
	{"ABSENTIA", 8, 131188},
	{"BUTTERWORTHS", 12, 131189},
	{"ULTEGRA", 7, 131190},
	{"OVERPRODUCTION", 14, 131191},
	{"STEREOGUM", 9, 131192},
	{"BACT", 4, 131193},
	{"DATLOW", 6, 131194},
	{"YMYE", 4, 131195},
	{"UTMS", 4, 131196},
	{"RIGT", 4, 131197},
	{"RCYT", 4, 131198},
	{"PEIM", 4, 131199},
	{"NUOF", 4, 131200},
	{"HLIL", 4, 131201},
	{"GIAG", 4, 131202},
	{"GAZO", 4, 131203},
	{"ECTQ", 4, 131204},
	{"CYOV", 4, 131205},
	{"CAQU", 4, 131206},
	{"BYIA", 4, 131207},
	{"CIPS", 4, 131208},
	{"KIAWAH", 6, 131209},
	{"RUBENSDAME", 10, 131210},
	{"TACROLIMUS", 10, 131211},
	{"ASTERS", 6, 131212},
	{"CLARIS", 6, 131213},
	{"WOWBB", 5, 131214},
	{"SPERMSWAP", 9, 131215},
	{"TERRAGEN", 8, 131216},
	{"STANZE", 6, 131217},
	{"NECROPOLIS", 10, 131218},
	{"QUINONES", 8, 131219},
	{"FAYLOR", 6, 131220},
	{"DISREGARDS", 10, 131221},
	{"BOXY", 4, 131222},
	{"SLASHFOOD", 9, 131223},
	{"GROSGRAIN", 9, 131224},
	{"ROXBURGHSHIRE", 13, 131225},
	{"DWD", 3, 131226},
	{"RITUALISTIC", 11, 131227},
	{"SURMOUNTED", 10, 131228},
	{"FUNWEBPRODUCTS", 14, 131229},
	{"DISSECTOR", 9, 131230},
	{"VERBIAGE", 8, 131231},
	{"ARKADELPHIA", 11, 131232},
	{"LONEY", 5, 131233},
	{"MOONSET", 7, 131234},
	{"CHUI", 4, 131235},
	{"MCKIE", 5, 131236},
	{"TAWAS", 5, 131237},
	{"HADFIELD", 8, 131238},
	{"BUNDT", 5, 131239},
	{"NONDISCLOSURE", 13, 131240},
	{"IMPELLED", 8, 131241},
	{"ELSPETH", 7, 131242},
	{"SALUTARY", 8, 131243},
	{"UANU", 4, 131244},
	{"OPJE", 4, 131245},
	{"OGYV", 4, 131246},
	{"KILG", 4, 131247},
	{"JANR", 4, 131248},
	{"CAYM", 4, 131249},
	{"SUFFERN", 7, 131250},
	{"DEFORM", 6, 131251},
	{"HAMWEATHER", 10, 131252},
	{"MEAC", 4, 131253},
	{"UMWELT", 6, 131254},
	{"LABORATORIO", 11, 131255},
	{"SJOGREN", 7, 131256},
	{"DAYPACKS", 8, 131257},
	{"CHEMISTRIES", 11, 131258},
	{"POSTPONES", 9, 131259},
	{"GRANDIN", 7, 131260},
	{"BRINGT", 6, 131261},
	{"MEDIAWEEK", 9, 131262},
	{"FROSTS", 6, 131263},
	{"IPECAC", 6, 131264},
	{"SITEMETER", 9, 131265},
	{"MESSICK", 7, 131266},
	{"ACHED", 5, 131267},
	{"NEWMONT", 7, 131268},
	{"JEUDI", 5, 131269},
	{"CAPITALISTIC", 12, 131270},
	{"METAOBJ", 7, 131271},
	{"ZADO", 4, 131272},
	{"UEYE", 4, 131273},
	{"TEZU", 4, 131274},
	{"RSPY", 4, 131275},
	{"RPRU", 4, 131276},
	{"OXDI", 4, 131277},
	{"LICJ", 4, 131278},
	{"IFGA", 4, 131279},
	{"EPTJ", 4, 131280},
	{"DUSN", 4, 131281},
	{"CWAV", 4, 131282},
	{"BOTB", 4, 131283},
	{"CLERC", 5, 131284},
	{"DEFILE", 6, 131285},
	{"QUENCE", 6, 131286},
	{"COLEEN", 6, 131287},
	{"BUCKMINSTER", 11, 131288},
	{"XYLEM", 5, 131289},
	{"LONGRIDGE", 9, 131290},
	{"PROPIEDAD", 9, 131291},
	{"DRAFTSMAN", 9, 131292},
	{"SHIGERU", 7, 131293},
	{"REALES", 6, 131294},
	{"DEBRIEF", 7, 131295},
	{"ROTATABLE", 9, 131296},
	{"INFANTICIDE", 11, 131297},
	{"RIBBING", 7, 131298},
	{"TALAVERA", 8, 131299},
	{"BRADYCARDIA", 11, 131300},
	{"CULKIN", 6, 131301},
	{"ROGERSVILLE", 11, 131302},
	{"ANSEHEN", 7, 131303},
	{"MAGHREB", 7, 131304},
	{"FOXGLOVE", 8, 131305},
	{"FUNKADELIC", 10, 131306},
	{"TERRESTRIS", 10, 131307},
	{"PORPHYRIA", 9, 131308},
	{"RECIP", 5, 131309},
	{"ZZTH", 4, 131310},
	{"WOBS", 4, 131311},
	{"OFGY", 4, 131312},
	{"LMMO", 4, 131313},
	{"LIUY", 4, 131314},
	{"KUZA", 4, 131315},
	{"HRLE", 4, 131316},
	{"HLGA", 4, 131317},
	{"HKRI", 4, 131318},
	{"GYSC", 4, 131319},
	{"GEIW", 4, 131320},
	{"EGBU", 4, 131321},
	{"CDUT", 4, 131322},
	{"BEAQ", 4, 131323},
	{"ASLD", 4, 131324},
	{"EFFECTUALLY", 11, 131325},
	{"WOOLEY", 6, 131326},
	{"CIGS", 4, 131327},
	{"ORITRON", 7, 131328},
	{"FRIENDLIES", 10, 131329},
	{"LOEWEN", 6, 131330},
	{"ISLANDIA", 8, 131331},
	{"FLRA", 4, 131332},
	{"TECHMEDIA", 9, 131333},
	{"TAGLIB", 6, 131334},
	{"UNPROVOKED", 10, 131335},
	{"CREWMEMBER", 10, 131336},
	{"CONFIGURATORS", 13, 131337},
	{"KERA", 4, 131338},
	{"APOCRYPHAL", 10, 131339},
	{"PALLID", 6, 131340},
	{"SUCCESSIONAL", 12, 131341},
	{"MAGIMIX", 7, 131342},
	{"BELICHICK", 9, 131343},
	{"LUMA", 4, 131344},
	{"TINIAN", 6, 131345},
	{"CHECKOUTS", 9, 131346},
	{"DELEN", 5, 131347},
	{"SULPHURIC", 9, 131348},
	{"ANTIPATHY", 9, 131349},
	{"KRUPA", 5, 131350},
	{"BORZOI", 6, 131351},
	{"WIMN", 4, 131352},
	{"SKDE", 4, 131353},
	{"RGSI", 4, 131354},
	{"LTCR", 4, 131355},
	{"IBMI", 4, 131356},
	{"ECSP", 4, 131357},
	{"DDPA", 4, 131358},
	{"BTWO", 4, 131359},
	{"AIFY", 4, 131360},
	{"SKINHEADS", 9, 131361},
	{"PERNAMBUCO", 10, 131362},
	{"VIZCAYA", 7, 131363},
	{"IROC", 4, 131364},
	{"BIENVENIDO", 10, 131365},
	{"WIETSE", 6, 131366},
	{"VALSE", 5, 131367},
	{"BROWNSBURG", 10, 131368},
	{"DOUCE", 5, 131369},
	{"DEOXYRIBONUCLEIC", 16, 131370},
	{"ALTIRIS", 7, 131371},
	{"DIDDLEY", 7, 131372},
	{"LXDIRECT", 8, 131373},
	{"INDIVIDUALISED", 14, 131374},
	{"STOREROOM", 9, 131375},
	{"MNCS", 4, 131376},
	{"DATEJUST", 8, 131377},
	{"BRADYGAMES", 10, 131378},
	{"EVERYTING", 9, 131379},
	{"WEOR", 4, 131380},
	{"RTIK", 4, 131381},
	{"RERJ", 4, 131382},
	{"PROVIDIAN", 9, 131383},
	{"CORNEL", 6, 131384},
	{"THEODORA", 8, 131385},
	{"KATHOLIEKE", 10, 131386},
	{"VERSIONED", 9, 131387},
	{"COMPUTERSHARE", 13, 131388},
	{"GLABROUS", 8, 131389},
	{"MARWARE", 7, 131390},
	{"SWEEX", 5, 131391},
	{"MADIKWE", 7, 131392},
	{"CESSES", 6, 131393},
	{"AFTERPARTY", 10, 131394},
	{"ISLAMISM", 8, 131395},
	{"DOWNTRACK", 9, 131396},
	{"BLEACHER", 8, 131397},
	{"PALER", 5, 131398},
	{"CONQUISTADOR", 12, 131399},
	{"WASTEBASKET", 11, 131400},
	{"LILIANA", 7, 131401},
	{"ALSOP", 5, 131402},
	{"CISM", 4, 131403},
	{"ARROWSMITH", 10, 131404},
	{"RIBERA", 6, 131405},
	{"CARBOPLATIN", 11, 131406},
	{"SPEEDLITE", 9, 131407},
	{"SIBEL", 5, 131408},
	{"MULHOUSE", 8, 131409},
	{"INGLY", 5, 131410},
	{"KOUFAX", 6, 131411},
	{"CUTER", 5, 131412},
	{"OVERCURRENT", 11, 131413},
	{"UNKNOWABLE", 10, 131414},
	{"EPISODIO", 8, 131415},
	{"SCHIELE", 7, 131416},
	{"HAUSMAN", 7, 131417},
	{"LOZENGE", 7, 131418},
	{"UMSN", 4, 131419},
	{"SILM", 4, 131420},
	{"SBYY", 4, 131421},
	{"PICV", 4, 131422},
	{"ODPH", 4, 131423},
	{"NUYA", 4, 131424},
	{"MIOR", 4, 131425},
	{"MDEG", 4, 131426},
	{"MCGL", 4, 131427},
	{"LIAV", 4, 131428},
	{"KOVO", 4, 131429},
	{"DUEU", 4, 131430},
	{"ADEZ", 4, 131431},
	{"ACZE", 4, 131432},
	{"ABAJ", 4, 131433},
	{"FORMWORK", 8, 131434},
	{"DANNII", 6, 131435},
	{"WOKS", 4, 131436},
	{"POLYIMIDE", 9, 131437},
	{"WERELD", 6, 131438},
	{"MAKEPEACE", 9, 131439},
	{"FERRANTE", 8, 131440},
	{"SCARIER", 7, 131441},
	{"JERALD", 6, 131442},
	{"WESTBOURNE", 10, 131443},
	{"STEELMAN", 8, 131444},
	{"ULATION", 7, 131445},
	{"TEASDALE", 8, 131446},
	{"USIC", 4, 131447},
	{"LIBIDN", 6, 131448},
	{"BROADBEACH", 10, 131449},
	{"ANIMACIONES", 11, 131450},
	{"EWART", 5, 131451},
	{"ATTAC", 5, 131452},
	{"CYMBALTA", 8, 131453},
	{"ZVL", 3, 131454},
	{"ZLZ", 3, 131455},
	{"ZFD", 3, 131456},
	{"WZC", 3, 131457},
	{"WBX", 3, 131458},
	{"QLV", 3, 131459},
	{"QGM", 3, 131460},
	{"QBQ", 3, 131461},
	{"PZD", 3, 131462},
	{"JZY", 3, 131463},
	{"JZG", 3, 131464},
	{"CVQ", 3, 131465},
	{"CJZ", 3, 131466},
	{"TOPSIDE", 7, 131467},
	{"DALMATION", 9, 131468},
	{"ROMEOVILLE", 10, 131469},
	{"STOCKPILED", 10, 131470},
	{"DISPLAYABLE", 11, 131471},
	{"COMPARATIF", 10, 131472},
	{"OFFING", 6, 131473},
	{"NHRC", 4, 131474},
	{"HONEYPOT", 8, 131475},
	{"YVEW", 4, 131476},
	{"WOSL", 4, 131477},
	{"WABR", 4, 131478},
	{"UTCM", 4, 131479},
	{"UMIP", 4, 131480},
	{"UAYT", 4, 131481},
	{"SXVI", 4, 131482},
	{"RSKR", 4, 131483},
	{"RIIF", 4, 131484},
	{"RGCH", 4, 131485},
	{"OVAU", 4, 131486},
	{"OLIU", 4, 131487},
	{"KUTH", 4, 131488},
	{"AUNM", 4, 131489},
	{"AFCW", 4, 131490},
	{"SIBUTRAMINE", 11, 131491},
	{"UPHEAVALS", 9, 131492},
	{"ALDGATE", 7, 131493},
	{"PHOTOBOX", 8, 131494},
	{"DEVSCRIPTS", 10, 131495},
	{"RECHARGES", 9, 131496},
	{"PLAGUING", 8, 131497},
	{"KOFFIE", 6, 131498},
	{"PLASTERERS", 10, 131499},
	{"INFEST", 6, 131500},
	{"DAMPIER", 7, 131501},
	{"WALLFLOWERS", 11, 131502},
	{"PLAYTEST", 8, 131503},
	{"RCONV", 5, 131504},
	{"CORINTHIA", 9, 131505},
	{"LORELAI", 7, 131506},
	{"TOURISTY", 8, 131507},
	{"CRIKEY", 6, 131508},
	{"HERAT", 5, 131509},
	{"HARDENS", 7, 131510},
	{"GEANT", 5, 131511},
	{"FRISK", 5, 131512},
	{"ALISTER", 7, 131513},
	{"LESVOS", 6, 131514},
	{"VECY", 4, 131515},
	{"RIKB", 4, 131516},
	{"MMEB", 4, 131517},
	{"LWAK", 4, 131518},
	{"LTZI", 4, 131519},
	{"LRUR", 4, 131520},
	{"LFET", 4, 131521},
	{"FTSR", 4, 131522},
	{"SEPARATISM", 10, 131523},
	{"OILER", 5, 131524},
	{"PAROLED", 7, 131525},
	{"GDYNIA", 6, 131526},
	{"AUDIOHOLICS", 11, 131527},
	{"IMAGERS", 7, 131528},
	{"COVALENTLY", 10, 131529},
	{"HOLYWOOD", 8, 131530},
	{"TONICS", 6, 131531},
	{"IDEATION", 8, 131532},
	{"PARTAGAS", 8, 131533},
	{"NATURADE", 8, 131534},
	{"SUPERIORE", 9, 131535},
	{"RESEACH", 7, 131536},
	{"EXPELLING", 9, 131537},
	{"ANGLETON", 8, 131538},
	{"REPLICATORS", 11, 131539},
	{"BESUCHE", 7, 131540},
	{"UINTA", 5, 131541},
	{"MAGIA", 5, 131542},
	{"UPSS", 4, 131543},
	{"YMAX", 4, 131544},
	{"UNIQUES", 7, 131545},
	{"UNSCOM", 6, 131546},
	{"ZZOL", 4, 131547},
	{"XIWA", 4, 131548},
	{"RBFO", 4, 131549},
	{"LALP", 4, 131550},
	{"FTBI", 4, 131551},
	{"FOGE", 4, 131552},
	{"BBHA", 4, 131553},
	{"AKYS", 4, 131554},
	{"ACSU", 4, 131555},
	{"TERRORIZING", 11, 131556},
	{"RODD", 4, 131557},
	{"STILO", 5, 131558},
	{"ROSCO", 5, 131559},
	{"NSLOOKUP", 8, 131560},
	{"BOOGER", 6, 131561},
	{"UNIVERSIDADES", 13, 131562},
	{"TELEFONE", 8, 131563},
	{"JAMZ", 4, 131564},
	{"MILAGE", 6, 131565},
	{"OBLIGES", 7, 131566},
	{"BENEDETTI", 9, 131567},
	{"PERTAINED", 9, 131568},
	{"PANIES", 6, 131569},
	{"TAUBER", 6, 131570},
	{"JDF", 3, 131571},
	{"BENEFICENT", 10, 131572},
	{"RZPD", 4, 131573},
	{"PETROGLYPHS", 11, 131574},
	{"KAPIL", 5, 131575},
	{"TAGUCHI", 7, 131576},
	{"YKAI", 4, 131577},
	{"WVIO", 4, 131578},
	{"SKMN", 4, 131579},
	{"OFWU", 4, 131580},
	{"LOEM", 4, 131581},
	{"DLUD", 4, 131582},
	{"DHYB", 4, 131583},
	{"CURU", 4, 131584},
	{"AWJU", 4, 131585},
	{"OCCULTISM", 9, 131586},
	{"KHAJURAHO", 9, 131587},
	{"LUXURIANT", 9, 131588},
	{"MULATTO", 7, 131589},
	{"KTLA", 4, 131590},
	{"NOREPLY", 7, 131591},
	{"JEPPESEN", 8, 131592},
	{"GIANNINI", 8, 131593},
	{"PLAUSIBLY", 9, 131594},
	{"DAILYKOS", 8, 131595},
	{"HONCHO", 6, 131596},
	{"BELGACOM", 8, 131597},
	{"STAPLING", 8, 131598},
	{"NEUROCHEM", 9, 131599},
	{"STORMONT", 8, 131600},
	{"DRIVESHAFT", 10, 131601},
	{"ONTARIANS", 9, 131602},
	{"RECUPERATION", 12, 131603},
	{"CONCUBINE", 9, 131604},
	{"NICHD", 5, 131605},
	{"EDWINA", 6, 131606},
	{"GUTTERMOUTH", 11, 131607},
	{"CELLA", 5, 131608},
	{"TAKAYAMA", 8, 131609},
	{"WHITT", 5, 131610},
	{"LLEWELYN", 8, 131611},
	{"UNFOCUSED", 9, 131612},
	{"XTPH", 4, 131613},
	{"WAXE", 4, 131614},
	{"UGUL", 4, 131615},
	{"UAWH", 4, 131616},
	{"RUCC", 4, 131617},
	{"RDUD", 4, 131618},
	{"LMFA", 4, 131619},
	{"LLAZ", 4, 131620},
	{"KBYD", 4, 131621},
	{"GMFO", 4, 131622},
	{"FESD", 4, 131623},
	{"DKUN", 4, 131624},
	{"BYHY", 4, 131625},
	{"THINKFREE", 9, 131626},
	{"BRAAI", 5, 131627},
	{"COMPLIMENTING", 13, 131628},
	{"EMERITI", 7, 131629},
	{"DJM", 3, 131630},
	{"PREMARKET", 9, 131631},
	{"PALIT", 5, 131632},
	{"GETENV", 6, 131633},
	{"MULTIAGE", 8, 131634},
	{"GARZIK", 6, 131635},
	{"COURTLY", 7, 131636},
	{"RFR", 3, 131637},
	{"DAMPNESS", 8, 131638},
	{"CIRCULATOR", 10, 131639},
	{"FYFE", 4, 131640},
	{"FLOURESCENT", 11, 131641},
	{"DLSW", 4, 131642},
	{"HYLANDS", 7, 131643},
	{"LIGHTHEADEDNESS", 15, 131644},
	{"DELIV", 5, 131645},
	{"KALYAN", 6, 131646},
	{"PHOTOREALISTIC", 14, 131647},
	{"DOWNSIZE", 8, 131648},
	{"SHURA", 5, 131649},
	{"MALPENSA", 8, 131650},
	{"TARJA", 5, 131651},
	{"YMYM", 4, 131652},
	{"YAFG", 4, 131653},
	{"UGUI", 4, 131654},
	{"UCBE", 4, 131655},
	{"SCYL", 4, 131656},
	{"RVEZ", 4, 131657},
	{"RRSC", 4, 131658},
	{"RKAK", 4, 131659},
	{"OAPB", 4, 131660},
	{"NEUB", 4, 131661},
	{"NCBY", 4, 131662},
	{"MUMH", 4, 131663},
	{"LYNL", 4, 131664},
	{"LKET", 4, 131665},
	{"KTRY", 4, 131666},
	{"ECPL", 4, 131667},
	{"DYNI", 4, 131668},
	{"BUKH", 4, 131669},
	{"AZZY", 4, 131670},
	{"KAMPONG", 7, 131671},
	{"EXERCICES", 9, 131672},
	{"DAISUKE", 7, 131673},
	{"FRONTLINES", 10, 131674},
	{"WANGARATTA", 10, 131675},
	{"TRANSFERT", 9, 131676},
	{"FASTNET", 7, 131677},
	{"HAMAD", 5, 131678},
	{"PUMAS", 5, 131679},
	{"MARAT", 5, 131680},
	{"HUSTED", 6, 131681},
	{"EMPT", 4, 131682},
	{"SPECIALSPARTS", 13, 131683},
	{"COLEBROOK", 9, 131684},
	{"INTERNISTS", 10, 131685},
	{"SILVERSMITH", 11, 131686},
	{"SUNBRIDGE", 9, 131687},
	{"DORVAL", 6, 131688},
	{"ZUSAMMEN", 8, 131689},
	{"PETERMAN", 8, 131690},
	{"PHALLIC", 7, 131691},
	{"PLATITUDES", 10, 131692},
	{"GOVAN", 5, 131693},
	{"ZACC", 4, 131694},
	{"WOOV", 4, 131695},
	{"UTTF", 4, 131696},
	{"UOFR", 4, 131697},
	{"PIDU", 4, 131698},
	{"NLUB", 4, 131699},
	{"MURB", 4, 131700},
	{"DOXT", 4, 131701},
	{"CREH", 4, 131702},
	{"JOAQUIM", 7, 131703},
	{"SERRES", 6, 131704},
	{"POSTMA", 6, 131705},
	{"MUSEU", 5, 131706},
	{"PIGWEED", 7, 131707},
	{"KAPOLEI", 7, 131708},
	{"PORPHYRY", 8, 131709},
	{"ZONG", 4, 131710},
	{"PVL", 3, 131711},
	{"EXERCICE", 8, 131712},
	{"DEVIATING", 9, 131713},
	{"LEUKOTRIENE", 11, 131714},
	{"BWL", 3, 131715},
	{"CYSYLLTIADAU", 12, 131716},
	{"AMBICOM", 7, 131717},
	{"EUROPAGES", 9, 131718},
	{"RAMAT", 5, 131719},
	{"FUJIMOTO", 8, 131720},
	{"COPAINS", 7, 131721},
	{"BREAKNECK", 9, 131722},
	{"CATAMOUNTS", 10, 131723},
	{"SHOFAR", 6, 131724},
	{"VIXIE", 5, 131725},
	{"MYRIAM", 6, 131726},
	{"ANIPIKE", 7, 131727},
	{"GRAYDON", 7, 131728},
	{"SUMMERHILL", 10, 131729},
	{"MESENCHYMAL", 11, 131730},
	{"TAUNTED", 7, 131731},
	{"DANEMARK", 8, 131732},
	{"XDID", 4, 131733},
	{"VAJI", 4, 131734},
	{"UBAG", 4, 131735},
	{"THYJ", 4, 131736},
	{"REKC", 4, 131737},
	{"MSYN", 4, 131738},
	{"LPWO", 4, 131739},
	{"FONB", 4, 131740},
	{"ETVP", 4, 131741},
	{"EGPR", 4, 131742},
	{"DSHY", 4, 131743},
	{"DADN", 4, 131744},
	{"CCOH", 4, 131745},
	{"ANCW", 4, 131746},
	{"ERNESTINE", 9, 131747},
	{"RILA", 4, 131748},
	{"METUCHEN", 8, 131749},
	{"HUED", 4, 131750},
	{"SCREENSELECT", 12, 131751},
	{"SACKETT", 7, 131752},
	{"FLON", 4, 131753},
	{"LINKLATER", 9, 131754},
	{"JEFFS", 5, 131755},
	{"BERRYVILLE", 10, 131756},
	{"REXBURG", 7, 131757},
	{"SAMET", 5, 131758},
	{"BRECKINRIDGE", 12, 131759},
	{"HINDUSTANI", 10, 131760},
	{"GOLDILOCKS", 10, 131761},
	{"FOMA", 4, 131762},
	{"CHELATING", 9, 131763},
	{"LACLEDE", 7, 131764},
	{"CATAPULTED", 10, 131765},
	{"DETROL", 6, 131766},
	{"TINCTURES", 9, 131767},
	{"BUBBLED", 7, 131768},
	{"MSMAIL", 6, 131769},
	{"DISKO", 5, 131770},
	{"OROMO", 5, 131771},
	{"UOPR", 4, 131772},
	{"OPID", 4, 131773},
	{"KSKN", 4, 131774},
	{"HAUV", 4, 131775},
	{"CCFL", 4, 131776},
	{"TIENES", 6, 131777},
	{"MEMENTOS", 8, 131778},
	{"SOLOING", 7, 131779},
	{"CASEWORKERS", 11, 131780},
	{"TERATOLOGY", 10, 131781},
	{"KORTE", 5, 131782},
	{"ASKJEEVES", 9, 131783},
	{"SEMICOLONS", 10, 131784},
	{"CGRID", 5, 131785},
	{"USHERING", 8, 131786},
	{"WALLSEND", 8, 131787},
	{"MORTIFIED", 9, 131788},
	{"ILOILO", 6, 131789},
	{"CURATION", 8, 131790},
	{"UPTURNED", 8, 131791},
	{"MECHANIZATION", 13, 131792},
	{"SIEVES", 6, 131793},
	{"PRESSLY", 7, 131794},
	{"UNDERAPPRECIATED", 16, 131795},
	{"TILGHMAN", 8, 131796},
	{"SUBTYPING", 9, 131797},
	{"DYNALINK", 8, 131798},
	{"AZTLAN", 6, 131799},
	{"ALMERA", 6, 131800},
	{"TIENDAS", 7, 131801},
	{"SUNROOMS", 8, 131802},
	{"CORDAGE", 7, 131803},
	{"HOBBLED", 7, 131804},
	{"BMF", 3, 131805},
	{"CHRISTENSON", 11, 131806},
	{"CRESTA", 6, 131807},
	{"XENOSAGA", 8, 131808},
	{"LICQ", 4, 131809},
	{"DIGIBETA", 8, 131810},
	{"YPOD", 4, 131811},
	{"OXLA", 4, 131812},
	{"OCHM", 4, 131813},
	{"LVOW", 4, 131814},
	{"LEWM", 4, 131815},
	{"KUPY", 4, 131816},
	{"KGLO", 4, 131817},
	{"HRAV", 4, 131818},
	{"EKVI", 4, 131819},
	{"COFW", 4, 131820},
	{"BAOR", 4, 131821},
	{"AKAV", 4, 131822},
	{"LOATH", 5, 131823},
	{"GOALTENDING", 11, 131824},
	{"GAGNER", 6, 131825},
	{"NIBBLING", 8, 131826},
	{"MULTIVARIABLE", 13, 131827},
	{"MOUN", 4, 131828},
	{"UNSOPHISTICATED", 15, 131829},
	{"GESTURED", 8, 131830},
	{"KOMPASS", 7, 131831},
	{"PAKI", 4, 131832},
	{"NIGHTIE", 7, 131833},
	{"MEATLESS", 8, 131834},
	{"XCP", 3, 131835},
	{"TANNINGCAM", 10, 131836},
	{"LIVVE", 5, 131837},
	{"DILLO", 5, 131838},
	{"WINDOM", 6, 131839},
	{"CHUTNEYS", 8, 131840},
	{"INSTITUTIONALLY", 15, 131841},
	{"WORDPAD", 7, 131842},
	{"REMAP", 5, 131843},
	{"VEXING", 6, 131844},
	{"SUPLS", 5, 131845},
	{"ANTISERA", 8, 131846},
	{"ROTAX", 5, 131847},
	{"WIDD", 4, 131848},
	{"UKAC", 4, 131849},
	{"TCPR", 4, 131850},
	{"SMYI", 4, 131851},
	{"PYTR", 4, 131852},
	{"OYBR", 4, 131853},
	{"MCOE", 4, 131854},
	{"MBYO", 4, 131855},
	{"IOPU", 4, 131856},
	{"GMPH", 4, 131857},
	{"FMUM", 4, 131858},
	{"FARY", 4, 131859},
	{"ERPF", 4, 131860},
	{"AMIU", 4, 131861},
	{"AFKA", 4, 131862},
	{"LONGA", 5, 131863},
	{"DIGRESSION", 10, 131864},
	{"ASTONISH", 8, 131865},
	{"VALIDATORS", 10, 131866},
	{"RUTGER", 6, 131867},
	{"DYNASTIC", 8, 131868},
	{"NEVES", 5, 131869},
	{"TOPLINE", 7, 131870},
	{"OBSER", 5, 131871},
	{"CALPERS", 7, 131872},
	{"COGNIZANCE", 10, 131873},
	{"SAVORING", 8, 131874},
	{"WOODBURNING", 11, 131875},
	{"HARLEQUINS", 10, 131876},
	{"MERCATO", 7, 131877},
	{"CROSSBOWS", 9, 131878},
	{"WPP", 3, 131879},
	{"PIQUET", 6, 131880},
	{"DANNA", 5, 131881},
	{"VCM", 3, 131882},
	{"BINDI", 5, 131883},
	{"ORGN", 4, 131884},
	{"LOVELIEST", 9, 131885},
	{"INHOFE", 6, 131886},
	{"CASBAH", 6, 131887},
	{"SYSLINUX", 8, 131888},
	{"VAGINITIS", 9, 131889},
	{"PARLIN", 6, 131890},
	{"NEARNESS", 8, 131891},
	{"ARCOS", 5, 131892},
	{"KONSOLE", 7, 131893},
	{"JESTERS", 7, 131894},
	{"JAMIL", 5, 131895},
	{"VOWT", 4, 131896},
	{"UICO", 4, 131897},
	{"TIWR", 4, 131898},
	{"SKIK", 4, 131899},
	{"SJUA", 4, 131900},
	{"SECF", 4, 131901},
	{"RLUR", 4, 131902},
	{"RITV", 4, 131903},
	{"OUKR", 4, 131904},
	{"OGME", 4, 131905},
	{"MBMA", 4, 131906},
	{"KJAV", 4, 131907},
	{"ISMV", 4, 131908},
	{"IFYR", 4, 131909},
	{"FANX", 4, 131910},
	{"COMJ", 4, 131911},
	{"SRILANKA", 8, 131912},
	{"ARCHNAME", 8, 131913},
	{"JERRI", 5, 131914},
	{"PHISHERS", 8, 131915},
	{"KAVEH", 5, 131916},
	{"ZUIKO", 5, 131917},
	{"TUTORED", 7, 131918},
	{"LANDFORM", 8, 131919},
	{"PROCURATOR", 10, 131920},
	{"LEFTISM", 7, 131921},
	{"WIKIVERSION", 11, 131922},
	{"CFTR", 4, 131923},
	{"FISHFINDERS", 11, 131924},
	{"PLAINTIVE", 9, 131925},
	{"DOTADOS", 7, 131926},
	{"MISTING", 7, 131927},
	{"EXULT", 5, 131928},
	{"CLAPS", 5, 131929},
	{"DALSA", 5, 131930},
	{"AMIDALA", 7, 131931},
	{"ZAPATISTAS", 10, 131932},
	{"DISREPUTABLE", 12, 131933},
	{"BIOGRAPHIE", 10, 131934},
	{"STRIKEOUT", 9, 131935},
	{"NSPCC", 5, 131936},
	{"BOOBIE", 6, 131937},
	{"ALCON", 5, 131938},
	{"SERAPH", 6, 131939},
	{"PSEUDOGENE", 10, 131940},
	{"AVORIAZ", 7, 131941},
	{"VFM", 3, 131942},
	{"YOWH", 4, 131943},
	{"YOWA", 4, 131944},
	{"WIPH", 4, 131945},
	{"WASZ", 4, 131946},
	{"UTJI", 4, 131947},
	{"UKUO", 4, 131948},
	{"TLOP", 4, 131949},
	{"SKAZ", 4, 131950},
	{"RUAT", 4, 131951},
	{"PALJ", 4, 131952},
	{"NBAV", 4, 131953},
	{"IBIR", 4, 131954},
	{"ETPM", 4, 131955},
	{"EIPC", 4, 131956},
	{"DVAM", 4, 131957},
	{"DJAD", 4, 131958},
	{"AMYH", 4, 131959},
	{"PUTMAN", 6, 131960},
	{"ULTRAEDIT", 9, 131961},
	{"SARONGS", 7, 131962},
	{"KEBABS", 6, 131963},
	{"DNSSEC", 6, 131964},
	{"THYMIC", 6, 131965},
	{"DRESSMAKER", 10, 131966},
	{"XKB", 3, 131967},
	{"METEOROBS", 9, 131968},
	{"REAFFIRMATION", 13, 131969},
	{"MARCHETTI", 9, 131970},
	{"WEBCOUNTER", 10, 131971},
	{"BALULE", 6, 131972},
	{"GOLDSWORTHY", 11, 131973},
	{"GIRI", 4, 131974},
	{"NORADRENALINE", 13, 131975},
	{"CBG", 3, 131976},
	{"RAMIRO", 6, 131977},
	{"MAXLENGTH", 9, 131978},
	{"FEHLER", 6, 131979},
	{"IBIBLIO", 7, 131980},
	{"BOOKCLUB", 8, 131981},
	{"PUBLICAN", 8, 131982},
	{"STARTEAM", 8, 131983},
	{"BULLOCH", 7, 131984},
	{"WTOY", 4, 131985},
	{"WDOZ", 4, 131986},
	{"RAHG", 4, 131987},
	{"OBDI", 4, 131988},
	{"ISRD", 4, 131989},
	{"DCZE", 4, 131990},
	{"CYPH", 4, 131991},
	{"AUXW", 4, 131992},
	{"ANFF", 4, 131993},
	{"VENTION", 7, 131994},
	{"YREKA", 5, 131995},
	{"BOYCOTTED", 9, 131996},
	{"SERNA", 5, 131997},
	{"SMOKESCREEN", 11, 131998},
	{"LORUS", 5, 131999},
	{"AMMONS", 6, 132000},
	{"PARMER", 6, 132001},
	{"MOVIMIENTO", 10, 132002},
	{"AFTERIMAGE", 10, 132003},
	{"PRECLUDING", 10, 132004},
	{"MODLES", 6, 132005},
	{"ARROWHEADS", 10, 132006},
	{"ANALFICK", 8, 132007},
	{"WCP", 3, 132008},
	{"REFL", 4, 132009},
	{"PRECEEDING", 10, 132010},
	{"DEBUTANTE", 9, 132011},
	{"OGUNQUIT", 8, 132012},
	{"DOLTON", 6, 132013},
	{"KREUZ", 5, 132014},
	{"SAVVIS", 6, 132015},
	{"TECHCRUNCH", 10, 132016},
	{"HEDONISTIC", 10, 132017},
	{"AILERON", 7, 132018},
	{"DEREHAM", 7, 132019},
	{"TPEB", 4, 132020},
	{"PPUN", 4, 132021},
	{"OYKI", 4, 132022},
	{"NKSV", 4, 132023},
	{"NJRA", 4, 132024},
	{"NGLT", 4, 132025},
	{"KOWE", 4, 132026},
	{"JINK", 4, 132027},
	{"FKIE", 4, 132028},
	{"CWEN", 4, 132029},
	{"GREYMATTER", 10, 132030},
	{"AUTOSURF", 8, 132031},
	{"REANALYSIS", 10, 132032},
	{"QUESADA", 7, 132033},
	{"MODULENAME", 10, 132034},
	{"CLEOCIN", 7, 132035},
	{"REBUFFS", 7, 132036},
	{"PICURES", 7, 132037},
	{"FOUT", 4, 132038},
	{"REICHSTAG", 9, 132039},
	{"UNIVE", 5, 132040},
	{"INFOCENTER", 10, 132041},
	{"REFRACTORIES", 12, 132042},
	{"WOCHE", 5, 132043},
	{"MUP", 3, 132044},
	{"HANDMAID", 8, 132045},
	{"CAMPBELTOWN", 11, 132046},
	{"YANMAR", 6, 132047},
	{"TOLTEC", 6, 132048},
	{"PIPET", 5, 132049},
	{"AGRICULTURA", 11, 132050},
	{"KLAAS", 5, 132051},
	{"CHEMISES", 8, 132052},
	{"CALPE", 5, 132053},
	{"BOEHLERT", 8, 132054},
	{"TMOC", 4, 132055},
	{"SUKR", 4, 132056},
	{"MCSH", 4, 132057},
	{"LKNA", 4, 132058},
	{"KACL", 4, 132059},
	{"FJOK", 4, 132060},
	{"EMIB", 4, 132061},
	{"DTWH", 4, 132062},
	{"DOIR", 4, 132063},
	{"BYOW", 4, 132064},
	{"BAVI", 4, 132065},
	{"ADUI", 4, 132066},
	{"SPUTTER", 7, 132067},
	{"YELLOWTAIL", 10, 132068},
	{"WEISBERG", 8, 132069},
	{"LIBGCC", 6, 132070},
	{"NYSTROM", 7, 132071},
	{"CEMS", 4, 132072},
	{"PETROBRAS", 9, 132073},
	{"PIMENTEL", 8, 132074},
	{"OBSESSIVELY", 11, 132075},
	{"HAVERFORDWEST", 13, 132076},
	{"HANDILY", 7, 132077},
	{"PIQUA", 5, 132078},
	{"JUDGEMENTAL", 11, 132079},
	{"VLAS", 4, 132080},
	{"OSHIMA", 6, 132081},
	{"BOXFORD", 7, 132082},
	{"CONSUELO", 8, 132083},
	{"RYOKO", 5, 132084},
	{"LEADERBOARDS", 12, 132085},
	{"KHAYYAM", 7, 132086},
	{"BRITBLOG", 8, 132087},
	{"GARP", 4, 132088},
	{"PAREKH", 6, 132089},
	{"FRAUDSTERS", 10, 132090},
	{"PRESALE", 7, 132091},
	{"BOYLES", 6, 132092},
	{"PEGG", 4, 132093},
	{"IMPOSTOR", 8, 132094},
	{"NOMEN", 5, 132095},
	{"RECEP", 5, 132096},
	{"VITERBI", 7, 132097},
	{"OSFLASH", 7, 132098},
	{"MEDECINE", 8, 132099},
	{"SHARAN", 6, 132100},
	{"ZTOL", 4, 132101},
	{"ZEBY", 4, 132102},
	{"YGAB", 4, 132103},
	{"TIBM", 4, 132104},
	{"SYPE", 4, 132105},
	{"ROEW", 4, 132106},
	{"PLYV", 4, 132107},
	{"NUXB", 4, 132108},
	{"NSUV", 4, 132109},
	{"MIPA", 4, 132110},
	{"MBYN", 4, 132111},
	{"LNEL", 4, 132112},
	{"JAYG", 4, 132113},
	{"FATG", 4, 132114},
	{"ETCP", 4, 132115},
	{"MYCORRHIZAL", 11, 132116},
	{"PONDEROUS", 9, 132117},
	{"YUJI", 4, 132118},
	{"CROZAT", 6, 132119},
	{"AGNUS", 5, 132120},
	{"MISHANDLING", 11, 132121},
	{"TANDARTS", 8, 132122},
	{"SHOPPES", 7, 132123},
	{"EVAPORATING", 11, 132124},
	{"KEEFER", 6, 132125},
	{"BANISTER", 8, 132126},
	{"MAISONS", 7, 132127},
	{"SCRUPULOUSLY", 12, 132128},
	{"JAMBA", 5, 132129},
	{"MITTWEIDA", 9, 132130},
	{"DICKED", 6, 132131},
	{"PLAISIR", 7, 132132},
	{"SEVIS", 5, 132133},
	{"WATERWORLD", 10, 132134},
	{"CHECKUPS", 8, 132135},
	{"FLOODGATES", 10, 132136},
	{"INTRUDING", 9, 132137},
	{"TECHNOBABBLE", 12, 132138},
	{"FCRA", 4, 132139},
	{"RATIONALIST", 11, 132140},
	{"BLAT", 4, 132141},
	{"CULTURING", 9, 132142},
	{"BAPTIZE", 7, 132143},
	{"ESQUECEU", 8, 132144},
	{"YUPL", 4, 132145},
	{"XEDN", 4, 132146},
	{"WSJO", 4, 132147},
	{"ULYK", 4, 132148},
	{"RIFP", 4, 132149},
	{"JRGE", 4, 132150},
	{"JONM", 4, 132151},
	{"DEAJ", 4, 132152},
	{"AWFA", 4, 132153},
	{"AQWI", 4, 132154},
	{"AQIR", 4, 132155},
	{"IMMIGRATE", 9, 132156},
	{"CROSSMAN", 8, 132157},
	{"CARBONACEOUS", 12, 132158},
	{"ADCS", 4, 132159},
	{"QUIXOTIC", 8, 132160},
	{"COMENIUS", 8, 132161},
	{"HINCHEY", 7, 132162},
	{"SCAMPI", 6, 132163},
	{"SARCH", 5, 132164},
	{"ATHLETICISM", 11, 132165},
	{"DBY", 3, 132166},
	{"FIORENTINA", 10, 132167},
	{"TRAYLOR", 7, 132168},
	{"CONSTRUING", 10, 132169},
	{"MCGREW", 6, 132170},
	{"WILLISON", 8, 132171},
	{"MISREADING", 10, 132172},
	{"MOLINARD", 8, 132173},
	{"HASLEMERE", 9, 132174},
	{"PERETZ", 6, 132175},
	{"DEMAILLE", 8, 132176},
	{"WLSW", 4, 132177},
	{"VICM", 4, 132178},
	{"UIDR", 4, 132179},
	{"TVEC", 4, 132180},
	{"RCST", 4, 132181},
	{"PGIN", 4, 132182},
	{"LWEK", 4, 132183},
	{"LLYZ", 4, 132184},
	{"IGOC", 4, 132185},
	{"GHKA", 4, 132186},
	{"FMYI", 4, 132187},
	{"DRYG", 4, 132188},
	{"AVGA", 4, 132189},
	{"GRANDVILLE", 10, 132190},
	{"NASOPHARYNGEAL", 14, 132191},
	{"SPECIALSSERVICE", 15, 132192},
	{"WOLFIE", 6, 132193},
	{"COATESVILLE", 11, 132194},
	{"MEDCO", 5, 132195},
	{"GOEBBELS", 8, 132196},
	{"LEVAN", 5, 132197},
	{"FATIGUES", 8, 132198},
	{"ASAPH", 5, 132199},
	{"RELAXER", 7, 132200},
	{"PRINCESSE", 9, 132201},
	{"NOTHER", 6, 132202},
	{"KAZE", 4, 132203},
	{"UNEQUALED", 9, 132204},
	{"GAMETAB", 7, 132205},
	{"SWAZI", 5, 132206},
	{"DELISTED", 8, 132207},
	{"WINX", 4, 132208},
	{"PAIUTE", 6, 132209},
	{"FRANCHE", 7, 132210},
	{"EJOURNAL", 8, 132211},
	{"YOMIURI", 7, 132212},
	{"PLUCKY", 6, 132213},
	{"DESSINS", 7, 132214},
	{"OCCUPANCIES", 11, 132215},
	{"EUSEBIUS", 8, 132216},
	{"FILEMANAGER", 11, 132217},
	{"HORNING", 7, 132218},
	{"MACLENNAN", 9, 132219},
	{"UNTIDY", 6, 132220},
	{"LOGGIA", 6, 132221},
	{"ENDUROX", 7, 132222},
	{"CLEETHORPES", 11, 132223},
	{"HOBBIE", 6, 132224},
	{"ZAOF", 4, 132225},
	{"WTUC", 4, 132226},
	{"TKMA", 4, 132227},
	{"TBEQ", 4, 132228},
	{"SIMR", 4, 132229},
	{"PJUN", 4, 132230},
	{"OSFL", 4, 132231},
	{"OCUO", 4, 132232},
	{"OCIL", 4, 132233},
	{"MLUN", 4, 132234},
	{"MEMM", 4, 132235},
	{"LAEX", 4, 132236},
	{"GCUB", 4, 132237},
	{"DDMI", 4, 132238},
	{"BAOBAB", 6, 132239},
	{"TUTANKHAMUN", 11, 132240},
	{"TRABAJOS", 8, 132241},
	{"RILKE", 5, 132242},
	{"CONAWAY", 7, 132243},
	{"ATWELL", 6, 132244},
	{"ORTHOPHOTO", 10, 132245},
	{"ISHTAR", 6, 132246},
	{"TRIBESMEN", 9, 132247},
	{"REDDOT", 6, 132248},
	{"FIUMICINO", 9, 132249},
	{"OKROOMMATE", 10, 132250},
	{"SUBSIST", 7, 132251},
	{"SUBFAMILIES", 11, 132252},
	{"RENSHAW", 7, 132253},
	{"CHEETHAM", 8, 132254},
	{"NETIQ", 5, 132255},
	{"MILITARIES", 10, 132256},
	{"MARCAS", 6, 132257},
	{"KITSON", 6, 132258},
	{"LMG", 3, 132259},
	{"LAPA", 4, 132260},
	{"ZENWORKS", 8, 132261},
	{"TIONED", 6, 132262},
	{"ANCASTER", 8, 132263},
	{"YGOW", 4, 132264},
	{"YDOZ", 4, 132265},
	{"XOFL", 4, 132266},
	{"UNIB", 4, 132267},
	{"TUGL", 4, 132268},
	{"TCYF", 4, 132269},
	{"SCOY", 4, 132270},
	{"RSSF", 4, 132271},
	{"RCAG", 4, 132272},
	{"PMER", 4, 132273},
	{"PBYR", 4, 132274},
	{"GGIG", 4, 132275},
	{"FTMU", 4, 132276},
	{"EILC", 4, 132277},
	{"ECUC", 4, 132278},
	{"DRSH", 4, 132279},
	{"AMYM", 4, 132280},
	{"NUTTERS", 7, 132281},
	{"AUGEN", 5, 132282},
	{"MESSNER", 7, 132283},
	{"BEHOLDING", 9, 132284},
	{"MULTICELLULAR", 13, 132285},
	{"DUAN", 4, 132286},
	{"PAPEETE", 7, 132287},
	{"AUREA", 5, 132288},
	{"SCARFS", 6, 132289},
	{"LEVE", 4, 132290},
	{"XLOGMASTER", 10, 132291},
	{"SHALLOWS", 8, 132292},
	{"HUMA", 4, 132293},
	{"HUMBUCKER", 9, 132294},
	{"CEDARWOOD", 9, 132295},
	{"MINIX", 5, 132296},
	{"GUNSMITH", 8, 132297},
	{"ERSTEN", 6, 132298},
	{"TABLAS", 6, 132299},
	{"RITHM", 5, 132300},
	{"OCCASIONI", 9, 132301},
	{"FRESHPATENTS", 12, 132302},
	{"ELENE", 5, 132303},
	{"CLERKENWELL", 11, 132304},
	{"DEBRECEN", 8, 132305},
	{"ADJUVANTS", 9, 132306},
	{"WOOK", 4, 132307},
	{"JETSKI", 6, 132308},
	{"COMTEX", 6, 132309},
	{"YAHW", 4, 132310},
	{"UVIG", 4, 132311},
	{"UBOP", 4, 132312},
	{"TZED", 4, 132313},
	{"OFCN", 4, 132314},
	{"NKJA", 4, 132315},
	{"NCIK", 4, 132316},
	{"GBUG", 4, 132317},
	{"FSOY", 4, 132318},
	{"FLUD", 4, 132319},
	{"CTIW", 4, 132320},
	{"BEAGLES", 7, 132321},
	{"PHLEBOTOMY", 10, 132322},
	{"ORDOVICIAN", 10, 132323},
	{"DEBUGGED", 8, 132324},
	{"CLOSEPATH", 9, 132325},
	{"ALTAI", 5, 132326},
	{"FREEADVICE", 10, 132327},
	{"MCCARTER", 8, 132328},
	{"ASRG", 4, 132329},
	{"LAQUINTA", 8, 132330},
	{"GLYCOSIDES", 10, 132331},
	{"SUNDECK", 7, 132332},
	{"MCVEY", 5, 132333},
	{"RUBUS", 5, 132334},
	{"GOMER", 5, 132335},
	{"MININOVA", 8, 132336},
	{"PERSHORE", 8, 132337},
	{"RXBOARD", 7, 132338},
	{"DIRKSEN", 7, 132339},
	{"FINGERSTYLE", 11, 132340},
	{"UNJUSTIFIABLE", 13, 132341},
	{"CLOVERLEAF", 10, 132342},
	{"TRNG", 4, 132343},
	{"GROWLS", 6, 132344},
	{"HALKIDIKI", 9, 132345},
	{"NONETYPE", 8, 132346},
	{"XBEF", 4, 132347},
	{"PUSG", 4, 132348},
	{"NUFO", 4, 132349},
	{"NLIZ", 4, 132350},
	{"MPRU", 4, 132351},
	{"LFOX", 4, 132352},
	{"DKMF", 4, 132353},
	{"DGAD", 4, 132354},
	{"DCFO", 4, 132355},
	{"POSTEN", 6, 132356},
	{"SAUCIER", 7, 132357},
	{"SPORTED", 7, 132358},
	{"QUAKING", 7, 132359},
	{"REDBOOKS", 8, 132360},
	{"ALLTRIG", 7, 132361},
	{"FROTHING", 8, 132362},
	{"NIDULANS", 8, 132363},
	{"SPEWS", 5, 132364},
	{"GALAS", 5, 132365},
	{"REFRAINING", 10, 132366},
	{"COMMINGLED", 10, 132367},
	{"ISTOCK", 6, 132368},
	{"APPROVERS", 9, 132369},
	{"BALDRIDGE", 9, 132370},
	{"VETCH", 5, 132371},
	{"NUCLIDE", 7, 132372},
	{"VIBRA", 5, 132373},
	{"SHANLEY", 7, 132374},
	{"FAIRBANK", 8, 132375},
	{"ROADFLY", 7, 132376},
	{"DEORE", 5, 132377},
	{"COASTING", 8, 132378},
	{"MINISH", 6, 132379},
	{"MYPET", 5, 132380},
	{"THROUGHLY", 9, 132381},
	{"RISKIER", 7, 132382},
	{"LUNCHBOXES", 10, 132383},
	{"SKYBLOG", 7, 132384},
	{"HHONORS", 7, 132385},
	{"RIVIERES", 8, 132386},
	{"YWIG", 4, 132387},
	{"UKUL", 4, 132388},
	{"SZAR", 4, 132389},
	{"RSUZ", 4, 132390},
	{"ORBC", 4, 132391},
	{"OFVU", 4, 132392},
	{"NUTP", 4, 132393},
	{"MTED", 4, 132394},
	{"FRHY", 4, 132395},
	{"EMWR", 4, 132396},
	{"DIEJ", 4, 132397},
	{"CIDC", 4, 132398},
	{"CEYW", 4, 132399},
	{"BSDU", 4, 132400},
	{"FIQH", 4, 132401},
	{"SWAC", 4, 132402},
	{"STRONY", 6, 132403},
	{"LOGEMENT", 8, 132404},
	{"CARRS", 5, 132405},
	{"PREGGY", 6, 132406},
	{"SHOREWALL", 9, 132407},
	{"COLLIERVILLE", 12, 132408},
	{"GOITER", 6, 132409},
	{"BEFALLEN", 8, 132410},
	{"SNOPES", 6, 132411},
	{"ELECTROCUTION", 13, 132412},
	{"WINKELWAGEN", 11, 132413},
	{"KINDERN", 7, 132414},
	{"GRRRR", 5, 132415},
	{"PERRYS", 6, 132416},
	{"MASAHIRO", 8, 132417},
	{"ROBBS", 5, 132418},
	{"THIRDPARTY", 10, 132419},
	{"ALLEVIATES", 10, 132420},
	{"ALLWEDDOL", 9, 132421},
	{"MICROSCOPICALLY", 15, 132422},
	{"IGREP", 5, 132423},
	{"DEFIBRILLATION", 14, 132424},
	{"HORTA", 5, 132425},
	{"VGAN", 4, 132426},
	{"UATL", 4, 132427},
	{"RZIM", 4, 132428},
	{"RKEB", 4, 132429},
	{"RFST", 4, 132430},
	{"RBLY", 4, 132431},
	{"EFAG", 4, 132432},
	{"BWON", 4, 132433},
	{"BCUN", 4, 132434},
	{"APAZ", 4, 132435},
	{"MENTEE", 6, 132436},
	{"ANIMISM", 7, 132437},
	{"ASQUITH", 7, 132438},
	{"TOLER", 5, 132439},
	{"DEUTZ", 5, 132440},
	{"EDDINGS", 7, 132441},
	{"CONCILIATORY", 12, 132442},
	{"PARKMAN", 7, 132443},
	{"STIFFEN", 7, 132444},
	{"EDREF", 5, 132445},
	{"CREDIBLY", 8, 132446},
	{"ROMANOV", 7, 132447},
	{"INFOWEB", 7, 132448},
	{"SCHEMATA", 8, 132449},
	{"TOXICITIES", 10, 132450},
	{"XSTREAM", 7, 132451},
	{"BURE", 4, 132452},
	{"SILTATION", 9, 132453},
	{"LOUVERS", 7, 132454},
	{"LOGBOOKS", 8, 132455},
	{"DRAWCORD", 8, 132456},
	{"LIGH", 4, 132457},
	{"SHOWMAN", 7, 132458},
	{"WSBL", 4, 132459},
	{"UBDO", 4, 132460},
	{"RTKO", 4, 132461},
	{"POPG", 4, 132462},
	{"OVWI", 4, 132463},
	{"OUIC", 4, 132464},
	{"OJUA", 4, 132465},
	{"OFRM", 4, 132466},
	{"NGAX", 4, 132467},
	{"IPVA", 4, 132468},
	{"GHMC", 4, 132469},
	{"DIBN", 4, 132470},
	{"AMYG", 4, 132471},
	{"WEBTEST", 7, 132472},
	{"OFFICIATED", 10, 132473},
	{"KONSTANZ", 8, 132474},
	{"HARMER", 6, 132475},
	{"AAMIR", 5, 132476},
	{"BRIDGEVIEW", 10, 132477},
	{"KAMRAN", 6, 132478},
	{"VALORE", 6, 132479},
	{"CLIPARTS", 8, 132480},
	{"WITCHY", 6, 132481},
	{"DISTEMPER", 9, 132482},
	{"SAVUTI", 6, 132483},
	{"SUBTERFUGE", 10, 132484},
	{"DUATHLON", 8, 132485},
	{"SYNCYTIAL", 9, 132486},
	{"OILING", 6, 132487},
	{"PSALMIST", 8, 132488},
	{"MAXAM", 5, 132489},
	{"LAVORI", 6, 132490},
	{"AZEVEDO", 7, 132491},
	{"DIREKTZUGANG", 12, 132492},
	{"ALIMENTOS", 9, 132493},
	{"NONRECURRING", 12, 132494},
	{"RIDGID", 6, 132495},
	{"NEFERTITI", 9, 132496},
	{"BISMARK", 7, 132497},
	{"CONVER", 6, 132498},
	{"XMEA", 4, 132499},
	{"VYWO", 4, 132500},
	{"RDEH", 4, 132501},
	{"KTIC", 4, 132502},
	{"ISUD", 4, 132503},
	{"ILDJ", 4, 132504},
	{"IGFE", 4, 132505},
	{"GJEA", 4, 132506},
	{"EXOP", 4, 132507},
	{"EUSK", 4, 132508},
	{"ALRS", 4, 132509},
	{"JEDE", 4, 132510},
	{"COMPOSITOR", 10, 132511},
	{"VISUALIZZA", 10, 132512},
	{"BEURS", 5, 132513},
	{"CONNEAUT", 8, 132514},
	{"ASPIRED", 7, 132515},
	{"RUNNELS", 7, 132516},
	{"HEMEROCALLIS", 12, 132517},
	{"MATCHDAY", 8, 132518},
	{"PAYPHONES", 9, 132519},
	{"MATHILDE", 8, 132520},
	{"PINGU", 5, 132521},
	{"TYLKO", 5, 132522},
	{"LOWTHER", 7, 132523},
	{"LOHMANN", 7, 132524},
	{"IRBY", 4, 132525},
	{"METROLINK", 9, 132526},
	{"PAGEINFO", 8, 132527},
	{"MCGREEVEY", 9, 132528},
	{"VILLALOBOS", 10, 132529},
	{"PLANTAE", 7, 132530},
	{"PUES", 4, 132531},
	{"SYSVINIT", 8, 132532},
	{"ANTIK", 5, 132533},
	{"LAZARO", 6, 132534},
	{"PETTIS", 6, 132535},
	{"WUPR", 4, 132536},
	{"WIGW", 4, 132537},
	{"UGSL", 4, 132538},
	{"SKPO", 4, 132539},
	{"NIKW", 4, 132540},
	{"FFAY", 4, 132541},
	{"EAKK", 4, 132542},
	{"DRSE", 4, 132543},
	{"DHEV", 4, 132544},
	{"DEEW", 4, 132545},
	{"CELW", 4, 132546},
	{"ACMO", 4, 132547},
	{"MOUVEMENT", 9, 132548},
	{"HILLFORT", 8, 132549},
	{"OMRI", 4, 132550},
	{"MAVICANET", 9, 132551},
	{"SCANMAIL", 8, 132552},
	{"ADLON", 5, 132553},
	{"RERIO", 5, 132554},
	{"SKELLY", 6, 132555},
	{"FRANKY", 6, 132556},
	{"INCLUDEFONT", 11, 132557},
	{"BEISPIEL", 8, 132558},
	{"PICTOGRAMS", 10, 132559},
	{"SALUKI", 6, 132560},
	{"DONAT", 5, 132561},
	{"BILAYERS", 8, 132562},
	{"MONATSABO", 9, 132563},
	{"MEMBERSMEMBERLIST", 17, 132564},
	{"PENITENT", 8, 132565},
	{"PWW", 3, 132566},
	{"SYME", 4, 132567},
	{"LARC", 4, 132568},
	{"STOUR", 5, 132569},
	{"NUTZUNGSBEDINGUNGEN", 19, 132570},
	{"TRAL", 4, 132571},
	{"TOYED", 5, 132572},
	{"MCMAHAN", 7, 132573},
	{"STRM", 4, 132574},
	{"ANGLAISE", 8, 132575},
	{"LAMENTATION", 11, 132576},
	{"UPF", 3, 132577},
	{"SPECIALI", 8, 132578},
	{"NEUROS", 6, 132579},
	{"MONTEITH", 8, 132580},
	{"NETVISTA", 8, 132581},
	{"DOORMATS", 8, 132582},
	{"TUNC", 4, 132583},
	{"MENASHA", 7, 132584},
	{"EXTOL", 5, 132585},
	{"LONGBOARDS", 10, 132586},
	{"XFOU", 4, 132587},
	{"TPAM", 4, 132588},
	{"RZAS", 4, 132589},
	{"RAMV", 4, 132590},
	{"PSEF", 4, 132591},
	{"OMZE", 4, 132592},
	{"LESX", 4, 132593},
	{"IYAZ", 4, 132594},
	{"ICYN", 4, 132595},
	{"AUDY", 4, 132596},
	{"SUBHASH", 7, 132597},
	{"APPORTION", 9, 132598},
	{"KQV", 3, 132599},
	{"MARMARA", 7, 132600},
	{"GAUDET", 6, 132601},
	{"TORBEN", 6, 132602},
	{"BASSWOOD", 8, 132603},
	{"PATRIMONY", 9, 132604},
	{"GOEDKOPE", 8, 132605},
	{"LECTURESHIP", 11, 132606},
	{"TONKS", 5, 132607},
	{"MASUDA", 6, 132608},
	{"EXEPT", 5, 132609},
	{"MERICAN", 7, 132610},
	{"DOWNTRODDEN", 11, 132611},
	{"ISTRIA", 6, 132612},
	{"VOLCKER", 7, 132613},
	{"CRAFTSPEOPLE", 12, 132614},
	{"SEAWALL", 7, 132615},
	{"KOPETE", 6, 132616},
	{"CURLERS", 7, 132617},
	{"SHANES", 6, 132618},
	{"BISLEY", 6, 132619},
	{"BATAM", 5, 132620},
	{"STRIX", 5, 132621},
	{"YGEI", 4, 132622},
	{"UXIA", 4, 132623},
	{"TVAP", 4, 132624},
	{"RZOO", 4, 132625},
	{"ROKH", 4, 132626},
	{"REWV", 4, 132627},
	{"OUNK", 4, 132628},
	{"OIRP", 4, 132629},
	{"MAXR", 4, 132630},
	{"LVOR", 4, 132631},
	{"IUJI", 4, 132632},
	{"HBYL", 4, 132633},
	{"CASON", 5, 132634},
	{"MONDAVI", 7, 132635},
	{"GIFF", 4, 132636},
	{"BELGIANS", 8, 132637},
	{"SANITIZE", 8, 132638},
	{"LAMBEAU", 7, 132639},
	{"PAPUAN", 6, 132640},
	{"BIGGAR", 6, 132641},
	{"EMMITT", 6, 132642},
	{"BERUBE", 6, 132643},
	{"EXTERNSHIP", 10, 132644},
	{"TEMPFILE", 8, 132645},
	{"LAMICTAL", 8, 132646},
	{"PROMULGATING", 12, 132647},
	{"INTEGRINS", 9, 132648},
	{"FILEPATH", 8, 132649},
	{"STRATHAM", 8, 132650},
	{"JSTL", 4, 132651},
	{"ATRPMS", 6, 132652},
	{"VECTIS", 6, 132653},
	{"DEMEROL", 7, 132654},
	{"COODER", 6, 132655},
	{"SPEWED", 6, 132656},
	{"AMANITA", 7, 132657},
	{"JAMB", 4, 132658},
	{"KNAVE", 5, 132659},
	{"FUNCTIONARIES", 13, 132660},
	{"SOLIDER", 7, 132661},
	{"TOYBOX", 6, 132662},
	{"BHASKAR", 7, 132663},
	{"TELEFLEX", 8, 132664},
	{"HOMEOPATHICS", 12, 132665},
	{"BANFFSHIRE", 10, 132666},
	{"AVICA", 5, 132667},
	{"GHULAM", 6, 132668},
	{"URJE", 4, 132669},
	{"SCIU", 4, 132670},
	{"RMUG", 4, 132671},
	{"RLWE", 4, 132672},
	{"MOPA", 4, 132673},
	{"LMHU", 4, 132674},
	{"LEAX", 4, 132675},
	{"ILDV", 4, 132676},
	{"HYSM", 4, 132677},
	{"ESCF", 4, 132678},
	{"EMUH", 4, 132679},
	{"DSPY", 4, 132680},
	{"DRGO", 4, 132681},
	{"DMRH", 4, 132682},
	{"APUE", 4, 132683},
	{"SNOWPACK", 8, 132684},
	{"CONCESSIONARY", 13, 132685},
	{"CROUP", 5, 132686},
	{"LEENKS", 6, 132687},
	{"MULTISYSTEM", 11, 132688},
	{"HIRD", 4, 132689},
	{"TOYZ", 4, 132690},
	{"OSSETIA", 7, 132691},
	{"NUBLADO", 7, 132692},
	{"HUMPERDINCK", 11, 132693},
	{"HOCKNEY", 7, 132694},
	{"GUSTING", 7, 132695},
	{"MULTISWITCHES", 13, 132696},
	{"DERA", 4, 132697},
	{"QUINTIN", 7, 132698},
	{"HAREWOOD", 8, 132699},
	{"BROADCLOTH", 10, 132700},
	{"DISUSE", 6, 132701},
	{"LEVELER", 7, 132702},
	{"REELED", 6, 132703},
	{"HUTCHESON", 9, 132704},
	{"HERCEPTIN", 9, 132705},
	{"BALLING", 7, 132706},
	{"TANJUNG", 7, 132707},
	{"LAYOVER", 7, 132708},
	{"RZYZ", 4, 132709},
	{"OUSZ", 4, 132710},
	{"OKOB", 4, 132711},
	{"NZUR", 4, 132712},
	{"NGRD", 4, 132713},
	{"LUEY", 4, 132714},
	{"KSYE", 4, 132715},
	{"JAIP", 4, 132716},
	{"DRRI", 4, 132717},
	{"AHFR", 4, 132718},
	{"SUPERDUPERCLUB", 14, 132719},
	{"PENNS", 5, 132720},
	{"INEPTITUDE", 10, 132721},
	{"ILMI", 4, 132722},
	{"QUIRE", 5, 132723},
	{"PLEASURING", 10, 132724},
	{"CLASSLESS", 9, 132725},
	{"BIOFORCE", 8, 132726},
	{"MAUGHAM", 7, 132727},
	{"SLACKING", 8, 132728},
	{"ALKALOID", 8, 132729},
	{"WEBHOSTINGTALK", 14, 132730},
	{"GLITTERY", 8, 132731},
	{"HENSEL", 6, 132732},
	{"VICARIOUSLY", 11, 132733},
	{"AMENDATORY", 10, 132734},
	{"POWERTECH", 9, 132735},
	{"ASYMPTOTICS", 11, 132736},
	{"GOETH", 5, 132737},
	{"DEFAULTPLUGIN", 13, 132738},
	{"WIMC", 4, 132739},
	{"UERM", 4, 132740},
	{"RYNS", 4, 132741},
	{"PTSR", 4, 132742},
	{"PETD", 4, 132743},
	{"OVMI", 4, 132744},
	{"OMUG", 4, 132745},
	{"OLMC", 4, 132746},
	{"MPNO", 4, 132747},
	{"HDOZ", 4, 132748},
	{"GKEL", 4, 132749},
	{"ERRB", 4, 132750},
	{"ERCB", 4, 132751},
	{"AHLB", 4, 132752},
	{"ACEX", 4, 132753},
	{"YDYCH", 5, 132754},
	{"MCNEELY", 7, 132755},
	{"DIGGY", 5, 132756},
	{"QUESTAR", 7, 132757},
	{"HANDEDNESS", 10, 132758},
	{"FERNALD", 7, 132759},
	{"BETANEWS", 8, 132760},
	{"CALIFORNICA", 11, 132761},
	{"BRAGS", 5, 132762},
	{"UNMOUNT", 7, 132763},
	{"SANDVIK", 7, 132764},
	{"SENSHI", 6, 132765},
	{"APPALACHIANS", 12, 132766},
	{"TETRAHEDRAL", 11, 132767},
	{"ACORD", 5, 132768},
	{"LIPGLOSS", 8, 132769},
	{"GREWAL", 6, 132770},
	{"LOCALNAME", 9, 132771},
	{"BEXLEYHEATH", 11, 132772},
	{"FASCINATE", 9, 132773},
	{"UNHANDLED", 9, 132774},
	{"CFIA", 4, 132775},
	{"DESDEMONA", 9, 132776},
	{"CONSTRICTED", 11, 132777},
	{"APPEALABLE", 10, 132778},
	{"OPPO", 4, 132779},
	{"KOTAKU", 6, 132780},
	{"GARISH", 6, 132781},
	{"DRESSLER", 8, 132782},
	{"CAMPANA", 7, 132783},
	{"BBSRC", 5, 132784},
	{"PAPPA", 5, 132785},
	{"XERI", 4, 132786},
	{"REVL", 4, 132787},
	{"RAKL", 4, 132788},
	{"OGCH", 4, 132789},
	{"MWEC", 4, 132790},
	{"ICYG", 4, 132791},
	{"HPBI", 4, 132792},
	{"DKES", 4, 132793},
	{"ACEQ", 4, 132794},
	{"NIDDK", 5, 132795},
	{"VML", 3, 132796},
	{"ZVZ", 3, 132797},
	{"ZPZ", 3, 132798},
	{"ZLV", 3, 132799},
	{"ZCV", 3, 132800},
	{"ZBZ", 3, 132801},
	{"XZM", 3, 132802},
	{"WZP", 3, 132803},
	{"WQL", 3, 132804},
	{"VZM", 3, 132805},
	{"VJB", 3, 132806},
	{"KQM", 3, 132807},
	{"JZW", 3, 132808},
	{"JLV", 3, 132809},
	{"JGK", 3, 132810},
	{"GZV", 3, 132811},
	{"GKX", 3, 132812},
	{"CWX", 3, 132813},
	{"BZG", 3, 132814},
	{"BVZ", 3, 132815},
	{"BGV", 3, 132816},
	{"HCFC", 4, 132817},
	{"JARA", 4, 132818},
	{"WETASKIWIN", 10, 132819},
	{"PAVONI", 6, 132820},
	{"WERROR", 6, 132821},
	{"BARONET", 7, 132822},
	{"KIEHL", 5, 132823},
	{"ATRESIA", 7, 132824},
	{"OXIDIZER", 8, 132825},
	{"NLAIAGENT", 9, 132826},
	{"PRECOR", 6, 132827},
	{"GILAD", 5, 132828},
	{"CCCP", 4, 132829},
	{"BASHAM", 6, 132830},
	{"PBUILDER", 8, 132831},
	{"BOMBASTIC", 9, 132832},
	{"BERICHTE", 8, 132833},
	{"CLIM", 4, 132834},
	{"BAILS", 5, 132835},
	{"DESTINO", 7, 132836},
	{"TURNOFF", 7, 132837},
	{"HANNIFIN", 8, 132838},
	{"URUI", 4, 132839},
	{"SUFA", 4, 132840},
	{"SCUO", 4, 132841},
	{"PYDA", 4, 132842},
	{"MUPB", 4, 132843},
	{"KCAV", 4, 132844},
	{"HSYR", 4, 132845},
	{"EZKO", 4, 132846},
	{"DMAB", 4, 132847},
	{"CILG", 4, 132848},
	{"BROV", 4, 132849},
	{"AXCH", 4, 132850},
	{"AUWE", 4, 132851},
	{"ASRY", 4, 132852},
	{"FRANCIE", 7, 132853},
	{"WEBFORMS", 8, 132854},
	{"HUMES", 5, 132855},
	{"BRANNAN", 7, 132856},
	{"NEWSRADIO", 9, 132857},
	{"MOATS", 5, 132858},
	{"AIRLOCK", 7, 132859},
	{"CHRISTOF", 8, 132860},
	{"MYSOCIETY", 9, 132861},
	{"SCOFFED", 7, 132862},
	{"MALLARDS", 8, 132863},
	{"THIEVING", 8, 132864},
	{"IPATH", 5, 132865},
	{"SOUNDCHECK", 10, 132866},
	{"MINDE", 5, 132867},
	{"AUPAIR", 6, 132868},
	{"DUSIT", 5, 132869},
	{"GAHANNA", 7, 132870},
	{"COMBINER", 8, 132871},
	{"ERLING", 6, 132872},
	{"WOLFEBORO", 9, 132873},
	{"TOGG", 4, 132874},
	{"TBYY", 4, 132875},
	{"RMCN", 4, 132876},
	{"REPF", 4, 132877},
	{"NSMD", 4, 132878},
	{"ISCF", 4, 132879},
	{"GOQU", 4, 132880},
	{"GIEP", 4, 132881},
	{"FOGL", 4, 132882},
	{"EWYN", 4, 132883},
	{"CEKO", 4, 132884},
	{"AVOD", 4, 132885},
	{"COSMONAUT", 9, 132886},
	{"INVESTI", 7, 132887},
	{"UNCRITIQUED", 11, 132888},
	{"THINKE", 6, 132889},
	{"MULTICORE", 9, 132890},
	{"ELECTROTECHNICAL", 16, 132891},
	{"BLOWBACK", 8, 132892},
	{"DIRKS", 5, 132893},
	{"HARTWIG", 7, 132894},
	{"SNARLED", 7, 132895},
	{"NEWSLINK", 8, 132896},
	{"GARCHING", 8, 132897},
	{"HAGRID", 6, 132898},
	{"BIOMOLECULES", 12, 132899},
	{"UNEARTHLY", 9, 132900},
	{"SUNHELP", 7, 132901},
	{"BACTEREMIA", 10, 132902},
	{"PREDESTINATION", 14, 132903},
	{"AALTO", 5, 132904},
	{"FIDUCIAL", 8, 132905},
	{"LECTED", 6, 132906},
	{"INCLUDERESOURCE", 15, 132907},
	{"ZAPHOD", 6, 132908},
	{"FORESHADOWING", 13, 132909},
	{"FOUN", 4, 132910},
	{"RADS", 4, 132911},
	{"AMERIC", 6, 132912},
	{"KNOWHOW", 7, 132913},
	{"ALBERTI", 7, 132914},
	{"VERBINDUNG", 10, 132915},
	{"REGULUS", 7, 132916},
	{"ZEPHYRHILLS", 11, 132917},
	{"TRANSCODER", 10, 132918},
	{"SIDDIQUI", 8, 132919},
	{"VIDI", 4, 132920},
	{"WHYS", 4, 132921},
	{"JATON", 5, 132922},
	{"THOMSONFN", 9, 132923},
	{"EZINEARTICLES", 13, 132924},
	{"EXTRAMARITAL", 12, 132925},
	{"RADIOGRAPH", 10, 132926},
	{"YCAK", 4, 132927},
	{"VEHY", 4, 132928},
	{"URFC", 4, 132929},
	{"RIEZ", 4, 132930},
	{"RAYJ", 4, 132931},
	{"POBA", 4, 132932},
	{"PEUP", 4, 132933},
	{"MYSY", 4, 132934},
	{"GOKE", 4, 132935},
	{"GFOX", 4, 132936},
	{"GAYF", 4, 132937},
	{"FJIN", 4, 132938},
	{"FIDU", 4, 132939},
	{"FDIL", 4, 132940},
	{"WEBFEED", 7, 132941},
	{"QINETIQ", 7, 132942},
	{"VODA", 4, 132943},
	{"PREMADE", 7, 132944},
	{"NOTECARD", 8, 132945},
	{"GENECARDS", 9, 132946},
	{"EKLUND", 6, 132947},
	{"GUILDPACT", 9, 132948},
	{"THEMSELF", 8, 132949},
	{"WOODWEB", 7, 132950},
	{"GRAFICA", 7, 132951},
	{"EJERCICIOS", 10, 132952},
	{"DREAMSCAPE", 10, 132953},
	{"STROMA", 6, 132954},
	{"OLIGOPOLY", 9, 132955},
	{"TROUVE", 6, 132956},
	{"FRANKENMUTH", 11, 132957},
	{"SCROLLABLE", 10, 132958},
	{"TANIGUCHI", 9, 132959},
	{"TRICHLOROETHYLENE", 17, 132960},
	{"SALESFORCE", 10, 132961},
	{"MARKKU", 6, 132962},
	{"RAPIDES", 7, 132963},
	{"PROSPECTORS", 11, 132964},
	{"PARTYS", 6, 132965},
	{"KNARESBOROUGH", 13, 132966},
	{"SUPERVALU", 9, 132967},
	{"WINBOND", 7, 132968},
	{"CCAC", 4, 132969},
	{"TLEQ", 4, 132970},
	{"SDEW", 4, 132971},
	{"OYJO", 4, 132972},
	{"NDNG", 4, 132973},
	{"LNIU", 4, 132974},
	{"JONW", 4, 132975},
	{"IXAC", 4, 132976},
	{"IWOJ", 4, 132977},
	{"HUNW", 4, 132978},
	{"GDED", 4, 132979},
	{"DUOA", 4, 132980},
	{"BYSF", 4, 132981},
	{"NORMANTON", 9, 132982},
	{"NEWTOWNARDS", 11, 132983},
	{"HASHMAP", 7, 132984},
	{"SEHWAG", 6, 132985},
	{"SOUTHCENTRAL", 12, 132986},
	{"SIMONDS", 7, 132987},
	{"GLOBALSAT", 9, 132988},
	{"LANGUID", 7, 132989},
	{"HISTONES", 8, 132990},
	{"RUGGIERO", 8, 132991},
	{"REVILED", 7, 132992},
	{"SUBTTL", 6, 132993},
	{"PAPERMAKING", 11, 132994},
	{"COVERLET", 8, 132995},
	{"NETFINITY", 9, 132996},
	{"ANACHRONISTIC", 13, 132997},
	{"SMOOTHES", 8, 132998},
	{"ERGY", 4, 132999},
	{"LUSTIG", 6, 133000},
	{"MIDSIZED", 8, 133001},
	{"BARBI", 5, 133002},
	{"BRINGEN", 7, 133003},
	{"PUNO", 4, 133004},
	{"TTHHEE", 6, 133005},
	{"STARKLY", 7, 133006},
	{"KEYSERVER", 9, 133007},
	{"VERNIS", 6, 133008},
	{"SPANN", 5, 133009},
	{"HDDS", 4, 133010},
	{"RATTY", 5, 133011},
	{"POLARTEC", 8, 133012},
	{"TVAM", 4, 133013},
	{"SILD", 4, 133014},
	{"RYRH", 4, 133015},
	{"NIGL", 4, 133016},
	{"IPAK", 4, 133017},
	{"HUDI", 4, 133018},
	{"HIRM", 4, 133019},
	{"JIHADISTS", 9, 133020},
	{"JEJUNI", 6, 133021},
	{"BELTRAMI", 8, 133022},
	{"WISNER", 6, 133023},
	{"FEARFULLY", 9, 133024},
	{"BROMYARD", 8, 133025},
	{"DUNPHY", 6, 133026},
	{"FINGERLESS", 10, 133027},
	{"AVSIM", 5, 133028},
	{"INTERMIX", 8, 133029},
	{"ALERO", 5, 133030},
	{"STELLENT", 8, 133031},
	{"MECHANIX", 8, 133032},
	{"SECRETARIATS", 12, 133033},
	{"IMPERSONATING", 13, 133034},
	{"RONSTAN", 7, 133035},
	{"OUTDOORSMAN", 11, 133036},
	{"GUENTER", 7, 133037},
	{"SMOOTHEST", 9, 133038},
	{"MORCHEEBA", 9, 133039},
	{"DANCESPORT", 10, 133040},
	{"MESOSCOPIC", 10, 133041},
	{"LYNBROOK", 8, 133042},
	{"GALLEGO", 7, 133043},
	{"PHALAENOPSIS", 12, 133044},
	{"CLOGGS", 6, 133045},
	{"ROSITA", 6, 133046},
	{"HUTTO", 5, 133047},
	{"YJOA", 4, 133048},
	{"RNMY", 4, 133049},
	{"PRIY", 4, 133050},
	{"PHAF", 4, 133051},
	{"NTMD", 4, 133052},
	{"LFGE", 4, 133053},
	{"KPAU", 4, 133054},
	{"JRHA", 4, 133055},
	{"JOND", 4, 133056},
	{"HYJO", 4, 133057},
	{"FYAT", 4, 133058},
	{"CYVE", 4, 133059},
	{"AMIZ", 4, 133060},
	{"COPP", 4, 133061},
	{"KLIMA", 5, 133062},
	{"KAWAII", 6, 133063},
	{"MUSKETEER", 9, 133064},
	{"UNHINDERED", 10, 133065},
	{"MEANDERS", 8, 133066},
	{"LDAS", 4, 133067},
	{"FIDDLES", 7, 133068},
	{"FAISALABAD", 10, 133069},
	{"CODDINGTON", 10, 133070},
	{"RETROFITS", 9, 133071},
	{"FURLONGS", 8, 133072},
	{"PILAF", 5, 133073},
	{"KERRIE", 6, 133074},
	{"ANCIENNE", 8, 133075},
	{"NEUROFIBROMATOSIS", 17, 133076},
	{"ABEC", 4, 133077},
	{"ARRAIGNED", 9, 133078},
	{"CRITICISES", 10, 133079},
	{"LIQUIDE", 7, 133080},
	{"TABULATE", 8, 133081},
	{"QUEANBEYAN", 10, 133082},
	{"FOGGING", 7, 133083},
	{"NIZLOPI", 7, 133084},
	{"RYAA", 4, 133085},
	{"PYMO", 4, 133086},
	{"PYME", 4, 133087},
	{"ORNV", 4, 133088},
	{"NDBT", 4, 133089},
	{"KLYU", 4, 133090},
	{"KAIK", 4, 133091},
	{"HEKB", 4, 133092},
	{"GGSM", 4, 133093},
	{"FCCO", 4, 133094},
	{"EFSM", 4, 133095},
	{"CKOT", 4, 133096},
	{"BDAN", 4, 133097},
	{"WHITEWASHED", 11, 133098},
	{"CASSVILLE", 9, 133099},
	{"FUMARATE", 8, 133100},
	{"GILDING", 7, 133101},
	{"DIEDRICH", 8, 133102},
	{"CARVIN", 6, 133103},
	{"TWINING", 7, 133104},
	{"SHIMADA", 7, 133105},
	{"YOUNGMODELS", 11, 133106},
	{"BSCW", 4, 133107},
	{"PYM", 3, 133108},
	{"ADEM", 4, 133109},
	{"CHERWELL", 8, 133110},
	{"SICKEST", 7, 133111},
	{"DISHACCESSORY", 13, 133112},
	{"RACIONAIS", 9, 133113},
	{"ONLNE", 5, 133114},
	{"RAFFAELE", 8, 133115},
	{"EXPLICATION", 11, 133116},
	{"LEDYARD", 7, 133117},
	{"VIOLETTE", 8, 133118},
	{"FORMATED", 8, 133119},
	{"SCREE", 5, 133120},
	{"OUTLAWING", 9, 133121},
	{"HUMANELY", 8, 133122},
	{"LAMPASAS", 8, 133123},
	{"MUESTRA", 7, 133124},
	{"MEINEKE", 7, 133125},
	{"IFRIENDS", 8, 133126},
	{"ESGIC", 5, 133127},
	{"BREAKABLE", 9, 133128},
	{"STRUTHERS", 9, 133129},
	{"COLMES", 6, 133130},
	{"TUGG", 4, 133131},
	{"TGYM", 4, 133132},
	{"RWIE", 4, 133133},
	{"OMPK", 4, 133134},
	{"ODRG", 4, 133135},
	{"MUDB", 4, 133136},
	{"LMCH", 4, 133137},
	{"EKCR", 4, 133138},
	{"DRKE", 4, 133139},
	{"CKEP", 4, 133140},
	{"BULS", 4, 133141},
	{"ESCORTSERVICE", 13, 133142},
	{"FINDORY", 7, 133143},
	{"AERIS", 5, 133144},
	{"JUNGFRAU", 8, 133145},
	{"VERDAD", 6, 133146},
	{"KANKER", 6, 133147},
	{"RAINSTORM", 9, 133148},
	{"JEDEC", 5, 133149},
	{"JAVAMAIL", 8, 133150},
	{"DOWNTO", 6, 133151},
	{"WILLEMS", 7, 133152},
	{"UNCOORDINATED", 13, 133153},
	{"PERRINE", 7, 133154},
	{"CORNHILL", 8, 133155},
	{"GIULIANA", 8, 133156},
	{"GANHE", 5, 133157},
	{"CASAL", 5, 133158},
	{"LAMER", 5, 133159},
	{"TELETYPE", 8, 133160},
	{"OUTLAND", 7, 133161},
	{"SCHWARZWALD", 11, 133162},
	{"INCOMPLETELY", 12, 133163},
	{"PHRASAL", 7, 133164},
	{"HEILEMANN", 9, 133165},
	{"VIRT", 4, 133166},
	{"CSFB", 4, 133167},
	{"NCKUM", 5, 133168},
	{"KILOWATTS", 9, 133169},
	{"PEWAUKEE", 8, 133170},
	{"OPENDIR", 7, 133171},
	{"CLISP", 5, 133172},
	{"SIGMOID", 7, 133173},
	{"STINKIN", 7, 133174},
	{"DEFECTORS", 9, 133175},
	{"YSIB", 4, 133176},
	{"YLUR", 4, 133177},
	{"WSDR", 4, 133178},
	{"WNOL", 4, 133179},
	{"VTIM", 4, 133180},
	{"VICR", 4, 133181},
	{"PEJU", 4, 133182},
	{"MYWR", 4, 133183},
	{"LSNU", 4, 133184},
	{"LKDA", 4, 133185},
	{"LFEI", 4, 133186},
	{"KKIE", 4, 133187},
	{"HUNB", 4, 133188},
	{"DZEN", 4, 133189},
	{"DFOE", 4, 133190},
	{"ADDV", 4, 133191},
	{"GAIETY", 6, 133192},
	{"GADOLINIUM", 10, 133193},
	{"ACOLYTE", 7, 133194},
	{"DLF", 3, 133195},
	{"HANNU", 5, 133196},
	{"AZONIC", 6, 133197},
	{"SKOLELINUX", 10, 133198},
	{"LOGMEIN", 7, 133199},
	{"HINDMARSH", 9, 133200},
	{"NORBURY", 7, 133201},
	{"HEMSLEY", 7, 133202},
	{"ALTEN", 5, 133203},
	{"MPCA", 4, 133204},
	{"FFG", 3, 133205},
	{"NONDETERMINISTIC", 16, 133206},
	{"CADS", 4, 133207},
	{"REPLIE", 6, 133208},
	{"CERISE", 6, 133209},
	{"ROPPONGI", 8, 133210},
	{"FRANGIPANI", 10, 133211},
	{"UTTERMOST", 9, 133212},
	{"ARISTOPHANES", 12, 133213},
	{"WOODCARVING", 11, 133214},
	{"YADKIN", 6, 133215},
	{"NUDY", 4, 133216},
	{"ICALLY", 6, 133217},
	{"ILLMATIC", 8, 133218},
	{"LETITIA", 7, 133219},
	{"REPROGRAPHICS", 13, 133220},
	{"DISTFILES", 9, 133221},
	{"IMPERATOR", 9, 133222},
	{"OVERTHREW", 9, 133223},
	{"EXOYN", 5, 133224},
	{"BANJA", 5, 133225},
	{"YRSH", 4, 133226},
	{"YNWH", 4, 133227},
	{"XHUN", 4, 133228},
	{"XBEN", 4, 133229},
	{"UMBF", 4, 133230},
	{"UKAK", 4, 133231},
	{"UIDH", 4, 133232},
	{"RSGM", 4, 133233},
	{"REZK", 4, 133234},
	{"PYRU", 4, 133235},
	{"PVAN", 4, 133236},
	{"PJIM", 4, 133237},
	{"OVFO", 4, 133238},
	{"NGKM", 4, 133239},
	{"IRKD", 4, 133240},
	{"IFRU", 4, 133241},
	{"HOUM", 4, 133242},
	{"GJAY", 4, 133243},
	{"BNAM", 4, 133244},
	{"AGHU", 4, 133245},
	{"LIFECYCLES", 10, 133246},
	{"AEOLIAN", 7, 133247},
	{"KAGOSHIMA", 9, 133248},
	{"KARNAK", 6, 133249},
	{"GUNNY", 5, 133250},
	{"NXREST", 6, 133251},
	{"LAVE", 4, 133252},
	{"ADCP", 4, 133253},
	{"CASTLECOPS", 10, 133254},
	{"DIELECTRICS", 11, 133255},
	{"LILLIES", 7, 133256},
	{"HEADSTOCK", 9, 133257},
	{"LONDOLOZI", 9, 133258},
	{"CRABGRASS", 9, 133259},
	{"BLAYLOCK", 8, 133260},
	{"FROWNS", 6, 133261},
	{"CANDLEBOX", 9, 133262},
	{"GODOT", 5, 133263},
	{"FABRICIUS", 9, 133264},
	{"CAPUCCI", 7, 133265},
	{"REALISTS", 8, 133266},
	{"WILA", 4, 133267},
	{"RCYN", 4, 133268},
	{"OYRI", 4, 133269},
	{"OKGA", 4, 133270},
	{"OGMI", 4, 133271},
	{"OELU", 4, 133272},
	{"LIJS", 4, 133273},
	{"LFGR", 4, 133274},
	{"GURY", 4, 133275},
	{"BYIC", 4, 133276},
	{"ACBU", 4, 133277},
	{"PHONEY", 6, 133278},
	{"LYNTON", 6, 133279},
	{"EISLEY", 6, 133280},
	{"TAUB", 4, 133281},
	{"PICKERINGTON", 12, 133282},
	{"DOKUWIKI", 8, 133283},
	{"UNDERWARE", 9, 133284},
	{"SHEEPISH", 8, 133285},
	{"AUTORADIO", 9, 133286},
	{"HIMSA", 5, 133287},
	{"SEDATED", 7, 133288},
	{"CFX", 3, 133289},
	{"PLETED", 6, 133290},
	{"DIFERENTES", 10, 133291},
	{"ALPHAS", 6, 133292},
	{"LOBEL", 5, 133293},
	{"BUNCE", 5, 133294},
	{"ENCEPHALOMYELITIS", 17, 133295},
	{"WIESENTHAL", 10, 133296},
	{"HEYER", 5, 133297},
	{"MIAMISBURG", 10, 133298},
	{"VERSIJA", 7, 133299},
	{"XPD", 3, 133300},
	{"GUNSMOKE", 8, 133301},
	{"MBF", 3, 133302},
	{"WBR", 3, 133303},
	{"WAMY", 4, 133304},
	{"SCAK", 4, 133305},
	{"PADF", 4, 133306},
	{"KNOF", 4, 133307},
	{"FEUG", 4, 133308},
	{"FABC", 4, 133309},
	{"EVYT", 4, 133310},
	{"ARMV", 4, 133311},
	{"CHINON", 6, 133312},
	{"UPHOLSTERERS", 12, 133313},
	{"SCHWUL", 6, 133314},
	{"OBJECTIVIST", 11, 133315},
	{"AFTERSHOCKS", 11, 133316},
	{"ORNETTE", 7, 133317},
	{"ANTIC", 5, 133318},
	{"WORLAND", 7, 133319},
	{"ABED", 4, 133320},
	{"EDIFYING", 8, 133321},
	{"KENNET", 6, 133322},
	{"ROTARIANS", 9, 133323},
	{"NUBILE", 6, 133324},
	{"ANDIS", 5, 133325},
	{"DREADFULLY", 10, 133326},
	{"HOLTZMAN", 8, 133327},
	{"SADDER", 6, 133328},
	{"EXPRESSIONIST", 13, 133329},
	{"PRODUCTIONHUB", 13, 133330},
	{"HIRER", 5, 133331},
	{"RAVAGE", 6, 133332},
	{"MYDOOM", 6, 133333},
	{"OWNAGE", 6, 133334},
	{"UNCOOL", 6, 133335},
	{"GERAINT", 7, 133336},
	{"DESPRE", 6, 133337},
	{"ACITYDISCOUNT", 13, 133338},
	{"OLICY", 5, 133339},
	{"GEKO", 4, 133340},
	{"STEFANIA", 8, 133341},
	{"CONTEMPTIBLE", 12, 133342},
	{"MUGGED", 6, 133343},
	{"DENTIN", 6, 133344},
	{"CROSSTOWN", 9, 133345},
	{"UNFAILING", 9, 133346},
	{"GRANDIA", 7, 133347},
	{"SPRINGVALE", 10, 133348},
	{"BEAUCHESNE", 10, 133349},
	{"FOWLS", 5, 133350},
	{"COOLUM", 6, 133351},
	{"ACETYLCHOLINESTERASE", 20, 133352},
	{"YNCI", 4, 133353},
	{"XFRA", 4, 133354},
	{"UKST", 4, 133355},
	{"SYGA", 4, 133356},
	{"RAJK", 4, 133357},
	{"LHAC", 4, 133358},
	{"GORV", 4, 133359},
	{"FFBL", 4, 133360},
	{"CENR", 4, 133361},
	{"DYERSBURG", 9, 133362},
	{"WPF", 3, 133363},
	{"STATISTICHE", 11, 133364},
	{"WEAVERVILLE", 11, 133365},
	{"SAFELIST", 8, 133366},
	{"ARAMCO", 6, 133367},
	{"UNTOWARD", 8, 133368},
	{"GASKIN", 6, 133369},
	{"GLOSTER", 7, 133370},
	{"INVIGORATE", 10, 133371},
	{"NITZSCHNER", 10, 133372},
	{"KARGER", 6, 133373},
	{"HAMMERSLEY", 10, 133374},
	{"COONS", 5, 133375},
	{"VENU", 4, 133376},
	{"STRACE", 6, 133377},
	{"QUICKDRAW", 9, 133378},
	{"DHIMMI", 6, 133379},
	{"CLUBMOM", 7, 133380},
	{"AISLING", 7, 133381},
	{"PLOR", 4, 133382},
	{"SZKO", 4, 133383},
	{"RESIZER", 7, 133384},
	{"YLYI", 4, 133385},
	{"VDTH", 4, 133386},
	{"RTPM", 4, 133387},
	{"PNER", 4, 133388},
	{"PHEB", 4, 133389},
	{"NZAB", 4, 133390},
	{"LOUF", 4, 133391},
	{"FHAU", 4, 133392},
	{"FFTU", 4, 133393},
	{"FERK", 4, 133394},
	{"ERIY", 4, 133395},
	{"DUXB", 4, 133396},
	{"DRAKKAR", 7, 133397},
	{"ACRYLONITRILE", 13, 133398},
	{"DORRIS", 6, 133399},
	{"BERMS", 5, 133400},
	{"CLERGYMEN", 9, 133401},
	{"TYCE", 4, 133402},
	{"AUTOSYNC", 8, 133403},
	{"TRUC", 4, 133404},
	{"PRINC", 5, 133405},
	{"IWAY", 4, 133406},
	{"CHLORITE", 8, 133407},
	{"TRINH", 5, 133408},
	{"ELECTRONIQUE", 12, 133409},
	{"TALMAGE", 7, 133410},
	{"DECORAH", 7, 133411},
	{"PETROLIA", 8, 133412},
	{"VEJA", 4, 133413},
	{"FIEL", 4, 133414},
	{"NUDIE", 5, 133415},
	{"ENDEAVOURING", 12, 133416},
	{"SUBCOMMAND", 10, 133417},
	{"PATENTEE", 8, 133418},
	{"TROUBLEMAKER", 12, 133419},
	{"THYSSENKRUPP", 12, 133420},
	{"MCGINN", 6, 133421},
	{"FABRICA", 7, 133422},
	{"ZZYS", 4, 133423},
	{"UNOD", 4, 133424},
	{"ROYN", 4, 133425},
	{"IDUL", 4, 133426},
	{"EYTW", 4, 133427},
	{"ATMM", 4, 133428},
	{"FISTER", 6, 133429},
	{"DISLODGED", 9, 133430},
	{"CUSH", 4, 133431},
	{"ERVING", 6, 133432},
	{"MINITAB", 7, 133433},
	{"INSTITUTIONALISED", 17, 133434},
	{"SMBD", 4, 133435},
	{"STUF", 4, 133436},
	{"BOWNESS", 7, 133437},
	{"OSVERS", 6, 133438},
	{"HONEYCUTT", 9, 133439},
	{"CASSE", 5, 133440},
	{"EDUCAT", 6, 133441},
	{"DECOMPILE", 9, 133442},
	{"MJG", 3, 133443},
	{"BCDB", 4, 133444},
	{"SYLWADAU", 8, 133445},
	{"BROWNLOW", 8, 133446},
	{"MARO", 4, 133447},
	{"OVERCHARGING", 12, 133448},
	{"FILMOGRAPHIES", 13, 133449},
	{"MANLIUS", 7, 133450},
	{"KGM", 3, 133451},
	{"SUBPROJECTS", 11, 133452},
	{"PEEKED", 6, 133453},
	{"BRIDWELL", 8, 133454},
	{"SYNONYMY", 8, 133455},
	{"BELLWETHER", 10, 133456},
	{"CUSIP", 5, 133457},
	{"SUNREX", 6, 133458},
	{"PRUEBA", 6, 133459},
	{"DUOFOLD", 7, 133460},
	{"LINENSOURCE", 11, 133461},
	{"OBVIATE", 7, 133462},
	{"SUPERGRAVITY", 12, 133463},
	{"SYNCML", 6, 133464},
	{"ZAKAT", 5, 133465},
	{"ANTICO", 6, 133466},
	{"JUSTER", 6, 133467},
	{"LEMAN", 5, 133468},
	{"CUPSYS", 6, 133469},
	{"BOLDCHAT", 8, 133470},
	{"UTUT", 4, 133471},
	{"TZFO", 4, 133472},
	{"RMSK", 4, 133473},
	{"MOER", 4, 133474},
	{"LIDN", 4, 133475},
	{"KTAY", 4, 133476},
	{"KPOC", 4, 133477},
	{"HIPQ", 4, 133478},
	{"FYAG", 4, 133479},
	{"FCAE", 4, 133480},
	{"FBIK", 4, 133481},
	{"DRRE", 4, 133482},
	{"ATYC", 4, 133483},
	{"MUNK", 4, 133484},
	{"GAGING", 6, 133485},
	{"GRIGG", 5, 133486},
	{"SUNNYBROOK", 10, 133487},
	{"DEFLORATION", 11, 133488},
	{"REPRESENTATIVENESS", 18, 133489},
	{"SKACHAT", 7, 133490},
	{"GNOKII", 6, 133491},
	{"GETTERS", 7, 133492},
	{"GENOM", 5, 133493},
	{"DVERSION", 8, 133494},
	{"ILKESTON", 8, 133495},
	{"MAILDROP", 8, 133496},
	{"KINGSBRIDGE", 11, 133497},
	{"PUNTOS", 6, 133498},
	{"CONEJO", 6, 133499},
	{"UEBER", 5, 133500},
	{"DOCURAMA", 8, 133501},
	{"PRIMERO", 7, 133502},
	{"SAUGERTIES", 10, 133503},
	{"KASCO", 5, 133504},
	{"GMPLS", 5, 133505},
	{"LOCKETT", 7, 133506},
	{"SENGUPTA", 8, 133507},
	{"SCIF", 4, 133508},
	{"SALUTING", 8, 133509},
	{"LABILE", 6, 133510},
	{"BEGUILING", 9, 133511},
	{"BAYONETS", 8, 133512},
	{"EMARKETER", 9, 133513},
	{"CUSHY", 5, 133514},
	{"CASTIGLIONE", 11, 133515},
	{"ANNUALISED", 10, 133516},
	{"RAMSDEN", 7, 133517},
	{"SHEAFFER", 8, 133518},
	{"MASTERCOOK", 10, 133519},
	{"BACKSLASHES", 11, 133520},
	{"NIEDERLANDE", 11, 133521},
	{"HARVEYS", 7, 133522},
	{"WILF", 4, 133523},
	{"ROISSY", 6, 133524},
	{"UCKJ", 4, 133525},
	{"UAPA", 4, 133526},
	{"TOBB", 4, 133527},
	{"OMKR", 4, 133528},
	{"OMJI", 4, 133529},
	{"ETMR", 4, 133530},
	{"ECLY", 4, 133531},
	{"AGFR", 4, 133532},
	{"MTASC", 5, 133533},
	{"ALCIONE", 7, 133534},
	{"TROMPE", 6, 133535},
	{"RACETRACKS", 10, 133536},
	{"FLAVIUS", 7, 133537},
	{"BACKROUND", 9, 133538},
	{"TAQUERIA", 8, 133539},
	{"BUTIK", 5, 133540},
	{"GUNZIP", 6, 133541},
	{"FRMD", 4, 133542},
	{"INDETERMINACY", 13, 133543},
	{"BONNELL", 7, 133544},
	{"MOBILISED", 9, 133545},
	{"TWENTYONE", 9, 133546},
	{"PLAYFULNESS", 11, 133547},
	{"IRRATIONALITY", 13, 133548},
	{"PHOTOMETER", 10, 133549},
	{"BANDANNA", 8, 133550},
	{"WHODUNIT", 8, 133551},
	{"CONFLUENT", 9, 133552},
	{"ANSATZ", 6, 133553},
	{"MAMBOSERVER", 11, 133554},
	{"BEARY", 5, 133555},
	{"WOLFSBURG", 9, 133556},
	{"ORDE", 4, 133557},
	{"DOCKERY", 7, 133558},
	{"DEEL", 4, 133559},
	{"BRID", 4, 133560},
	{"LERNEN", 6, 133561},
	{"XOND", 4, 133562},
	{"XMOV", 4, 133563},
	{"OIFW", 4, 133564},
	{"OGSU", 4, 133565},
	{"MAGY", 4, 133566},
	{"LTQU", 4, 133567},
	{"LMPA", 4, 133568},
	{"LBKG", 4, 133569},
	{"GEEQ", 4, 133570},
	{"DXIA", 4, 133571},
	{"DOOW", 4, 133572},
	{"MISTRIAL", 8, 133573},
	{"LAFONTAINE", 10, 133574},
	{"WILDING", 7, 133575},
	{"PALUSTRIS", 9, 133576},
	{"UNPLEASURABLE", 13, 133577},
	{"MAINSCREEN", 10, 133578},
	{"LALLY", 5, 133579},
	{"ANTHRACENE", 10, 133580},
	{"MOLLUSCA", 8, 133581},
	{"BTOB", 4, 133582},
	{"HUSKS", 5, 133583},
	{"HAMMILL", 7, 133584},
	{"MONTAGNA", 8, 133585},
	{"SANKEY", 6, 133586},
	{"BINATONE", 8, 133587},
	{"IMPINGEMENT", 11, 133588},
	{"REDECORATING", 12, 133589},
	{"HABSBURG", 8, 133590},
	{"COURISTAN", 9, 133591},
	{"STORYEMAIL", 10, 133592},
	{"MEGAMIX", 7, 133593},
	{"ARUP", 4, 133594},
	{"SERVERPROTECT", 13, 133595},
	{"BECKON", 6, 133596},
	{"RIDGEVILLE", 10, 133597},
	{"FIDLER", 6, 133598},
	{"XILL", 4, 133599},
	{"WSRU", 4, 133600},
	{"VSAL", 4, 133601},
	{"VEKO", 4, 133602},
	{"UVAS", 4, 133603},
	{"RPTE", 4, 133604},
	{"RKJA", 4, 133605},
	{"RFRY", 4, 133606},
	{"LPBA", 4, 133607},
	{"KIEQ", 4, 133608},
	{"KAYM", 4, 133609},
	{"ILSV", 4, 133610},
	{"DDYK", 4, 133611},
	{"RAVED", 5, 133612},
	{"UBU", 3, 133613},
	{"HERREN", 6, 133614},
	{"GRAPPA", 6, 133615},
	{"FEITH", 5, 133616},
	{"AUDIE", 5, 133617},
	{"ANFANG", 6, 133618},
	{"TRAILBLAZING", 12, 133619},
	{"REDRAWN", 7, 133620},
	{"JEWELLED", 8, 133621},
	{"MEDIATIONS", 10, 133622},
	{"ILOCANO", 7, 133623},
	{"NONCOMMUTATIVE", 14, 133624},
	{"TENSIONED", 9, 133625},
	{"HAUNTINGS", 9, 133626},
	{"MARTIE", 6, 133627},
	{"CONGLOMERATION", 14, 133628},
	{"CHAY", 4, 133629},
	{"REAPS", 5, 133630},
	{"PROMT", 5, 133631},
	{"COVERTEC", 8, 133632},
	{"LONGSTREET", 10, 133633},
	{"FATTO", 5, 133634},
	{"ACCI", 4, 133635},
	{"TRAUM", 5, 133636},
	{"ARCE", 4, 133637},
	{"ZYZE", 4, 133638},
	{"YHEU", 4, 133639},
	{"WROM", 4, 133640},
	{"TAGM", 4, 133641},
	{"OCWI", 4, 133642},
	{"JCPE", 4, 133643},
	{"HICV", 4, 133644},
	{"GSTM", 4, 133645},
	{"FUGL", 4, 133646},
	{"DOSR", 4, 133647},
	{"CYAB", 4, 133648},
	{"AVAK", 4, 133649},
	{"AKIVA", 5, 133650},
	{"TALABANI", 8, 133651},
	{"TEANNA", 6, 133652},
	{"GANDELMAN", 9, 133653},
	{"INTERLOCKED", 11, 133654},
	{"DELISH", 6, 133655},
	{"SSCANF", 6, 133656},
	{"BOTTOMLEY", 9, 133657},
	{"ROEHAMPTON", 10, 133658},
	{"LANOLIN", 7, 133659},
	{"COWHER", 6, 133660},
	{"MEDFIELD", 8, 133661},
	{"PHILBIN", 7, 133662},
	{"IMMUNOCOMPROMISED", 17, 133663},
	{"WYK", 3, 133664},
	{"CBK", 3, 133665},
	{"NATIONMASTER", 12, 133666},
	{"CAPILANO", 8, 133667},
	{"STRINGERS", 9, 133668},
	{"FULFORD", 7, 133669},
	{"FAMILIAS", 8, 133670},
	{"TOURN", 5, 133671},
	{"PREMONITION", 11, 133672},
	{"AUTORADIOGRAPHY", 15, 133673},
	{"RMRM", 4, 133674},
	{"KFED", 4, 133675},
	{"DEEY", 4, 133676},
	{"CLYB", 4, 133677},
	{"CUTTS", 5, 133678},
	{"QUADRICEPS", 10, 133679},
	{"SPEEDTEST", 9, 133680},
	{"REDIRECTOR", 10, 133681},
	{"CABE", 4, 133682},
	{"BULBOPHYLLUM", 12, 133683},
	{"TURNAROUNDS", 11, 133684},
	{"HOULIHAN", 8, 133685},
	{"URANTIA", 7, 133686},
	{"RECUT", 5, 133687},
	{"JUR", 3, 133688},
	{"LUGZ", 4, 133689},
	{"SURETIES", 8, 133690},
	{"MIRAME", 6, 133691},
	{"DIGIKAM", 7, 133692},
	{"NEEDCONTRACTOR", 14, 133693},
	{"DABBLE", 6, 133694},
	{"CESTA", 5, 133695},
	{"DONNINGTON", 10, 133696},
	{"ULTRATEC", 8, 133697},
	{"VALORES", 7, 133698},
	{"MLAS", 4, 133699},
	{"MONTRE", 6, 133700},
	{"GRUNTING", 8, 133701},
	{"REMODELER", 9, 133702},
	{"HARPO", 5, 133703},
	{"TONNER", 6, 133704},
	{"OVERZEALOUS", 11, 133705},
	{"BAUBLES", 7, 133706},
	{"VYUS", 4, 133707},
	{"UTKU", 4, 133708},
	{"RYMR", 4, 133709},
	{"RPWI", 4, 133710},
	{"HUCA", 4, 133711},
	{"EZBR", 4, 133712},
	{"EAPD", 4, 133713},
	{"AVYN", 4, 133714},
	{"AUDB", 4, 133715},
	{"PERSONAGES", 10, 133716},
	{"ACTES", 5, 133717},
	{"BIOGEOCHEMISTRY", 15, 133718},
	{"ELLADA", 6, 133719},
	{"YOKOGAWA", 8, 133720},
	{"CABRINI", 7, 133721},
	{"MISL", 4, 133722},
	{"DOWS", 4, 133723},
	{"EXIGENCIES", 10, 133724},
	{"DEPEN", 5, 133725},
	{"TARAS", 5, 133726},
	{"SCRIM", 5, 133727},
	{"SANITARIUM", 10, 133728},
	{"EGYPTOLOGY", 10, 133729},
	{"ALBOM", 5, 133730},
	{"GWY", 3, 133731},
	{"SULZER", 6, 133732},
	{"HEIGHTENS", 9, 133733},
	{"DEFVAR", 6, 133734},
	{"BACILLI", 7, 133735},
	{"PANTALLA", 8, 133736},
	{"MARVELED", 8, 133737},
	{"TOSCANO", 7, 133738},
	{"YRRH", 4, 133739},
	{"YLOD", 4, 133740},
	{"ULOB", 4, 133741},
	{"PHBA", 4, 133742},
	{"PCOP", 4, 133743},
	{"OCAF", 4, 133744},
	{"OAKF", 4, 133745},
	{"LOUH", 4, 133746},
	{"KIDG", 4, 133747},
	{"IGAF", 4, 133748},
	{"GOEX", 4, 133749},
	{"EYUR", 4, 133750},
	{"EDLS", 4, 133751},
	{"CIOR", 4, 133752},
	{"AVIM", 4, 133753},
	{"APEJ", 4, 133754},
	{"SWALLOWTAIL", 11, 133755},
	{"GILTS", 5, 133756},
	{"FLATSCREEN", 10, 133757},
	{"PYNCHON", 7, 133758},
	{"GRF", 3, 133759},
	{"MRAD", 4, 133760},
	{"EDICIONES", 9, 133761},
	{"PELOPONNESIAN", 13, 133762},
	{"PROPOFOL", 8, 133763},
	{"BUTTES", 6, 133764},
	{"WINSTED", 7, 133765},
	{"PRAGMAS", 7, 133766},
	{"GOTHA", 5, 133767},
	{"ALGINATE", 8, 133768},
	{"SEARCHBOX", 9, 133769},
	{"INCOMMUNICADO", 13, 133770},
	{"YGOP", 4, 133771},
	{"WVIR", 4, 133772},
	{"TALZ", 4, 133773},
	{"SCDS", 4, 133774},
	{"RIDV", 4, 133775},
	{"QWHI", 4, 133776},
	{"POOD", 4, 133777},
	{"MPYA", 4, 133778},
	{"IEFK", 4, 133779},
	{"IDZE", 4, 133780},
	{"FFFL", 4, 133781},
	{"ENLW", 4, 133782},
	{"EIFU", 4, 133783},
	{"ECDR", 4, 133784},
	{"LCF", 3, 133785},
	{"FOSSILIZED", 10, 133786},
	{"UNHEATED", 8, 133787},
	{"CHITIN", 6, 133788},
	{"WAFFEN", 6, 133789},
	{"NISMO", 5, 133790},
	{"UNSUBSCRIPTION", 14, 133791},
	{"CULTIVATOR", 10, 133792},
	{"CRIMPER", 7, 133793},
	{"NIHIL", 5, 133794},
	{"BAUGHMAN", 8, 133795},
	{"ABERNETHY", 9, 133796},
	{"ERITH", 5, 133797},
	{"OVINE", 5, 133798},
	{"TARUN", 5, 133799},
	{"SEATPOST", 8, 133800},
	{"QUINTUS", 7, 133801},
	{"CRUCIFY", 7, 133802},
	{"FALSIFYING", 10, 133803},
	{"THABO", 5, 133804},
	{"SPECIFI", 7, 133805},
	{"FEARON", 6, 133806},
	{"BEEVILLE", 8, 133807},
	{"UNSAID", 6, 133808},
	{"COLORES", 7, 133809},
	{"SUCCHIA", 7, 133810},
	{"SUMATRIPTAN", 11, 133811},
	{"RIVERDEEP", 9, 133812},
	{"MEDSERV", 7, 133813},
	{"ZEAP", 4, 133814},
	{"UDOY", 4, 133815},
	{"PYSO", 4, 133816},
	{"PELD", 4, 133817},
	{"MNWH", 4, 133818},
	{"KBRU", 4, 133819},
	{"HGIF", 4, 133820},
	{"HBRY", 4, 133821},
	{"GRAG", 4, 133822},
	{"FTYB", 4, 133823},
	{"DMRP", 4, 133824},
	{"CCAH", 4, 133825},
	{"ALLUME", 6, 133826},
	{"JULIENNE", 8, 133827},
	{"DOWNPLAYED", 10, 133828},
	{"MIRADOR", 7, 133829},
	{"GAZETTED", 8, 133830},
	{"VOXILLA", 7, 133831},
	{"BOULANGER", 9, 133832},
	{"FONCTIONS", 9, 133833},
	{"WALLICE", 7, 133834},
	{"MYECLIPSE", 9, 133835},
	{"UNTIE", 5, 133836},
	{"CASSINO", 7, 133837},
	{"STORKCRAFT", 10, 133838},
	{"DRACUT", 6, 133839},
	{"KISCO", 5, 133840},
	{"DOWNLOA", 7, 133841},
	{"KUMHO", 5, 133842},
	{"ONPOINT", 7, 133843},
	{"FERREDOXIN", 10, 133844},
	{"AMUR", 4, 133845},
	{"INSTIGATOR", 10, 133846},
	{"VIZSLA", 6, 133847},
	{"FATHERED", 8, 133848},
	{"MALEATE", 7, 133849},
	{"INDU", 4, 133850},
	{"INCREMENTING", 12, 133851},
	{"PANZA", 5, 133852},
	{"GIRT", 4, 133853},
	{"INTERPROCESS", 12, 133854},
	{"SERONO", 6, 133855},
	{"DIVINORUM", 9, 133856},
	{"ZUNA", 4, 133857},
	{"YEED", 4, 133858},
	{"VEMR", 4, 133859},
	{"TYZO", 4, 133860},
	{"TRUJ", 4, 133861},
	{"RKTU", 4, 133862},
	{"OTUC", 4, 133863},
	{"OPHU", 4, 133864},
	{"NMRM", 4, 133865},
	{"LBOF", 4, 133866},
	{"KUTT", 4, 133867},
	{"GBUF", 4, 133868},
	{"FINU", 4, 133869},
	{"FBYP", 4, 133870},
	{"ESKL", 4, 133871},
	{"EEPJ", 4, 133872},
	{"EDZH", 4, 133873},
	{"DKET", 4, 133874},
	{"AWAU", 4, 133875},
	{"ABEB", 4, 133876},
	{"ESKOM", 5, 133877},
	{"MATHENY", 7, 133878},
	{"ANNUL", 5, 133879},
	{"LANKY", 5, 133880},
	{"KUCH", 4, 133881},
	{"VISES", 5, 133882},
	{"SAMARKAND", 9, 133883},
	{"REAVES", 6, 133884},
	{"MONDADORI", 9, 133885},
	{"COMMITTER", 9, 133886},
	{"ILLA", 4, 133887},
	{"MCKENNEY", 8, 133888},
	{"BLUSHES", 7, 133889},
	{"SHEWED", 6, 133890},
	{"ARDSLEY", 7, 133891},
	{"PREGAME", 7, 133892},
	{"ARECIBO", 7, 133893},
	{"EQUIVALENCES", 12, 133894},
	{"EAVESDROP", 9, 133895},
	{"SMPS", 4, 133896},
	{"OUTDO", 5, 133897},
	{"GLOBALISM", 9, 133898},
	{"LIVEVIDEO", 9, 133899},
	{"VBOX", 4, 133900},
	{"MOOREHEAD", 9, 133901},
	{"FEBURARY", 8, 133902},
	{"ELETTRONICA", 11, 133903},
	{"GNUBG", 5, 133904},
	{"BODHI", 5, 133905},
	{"SYCAMORES", 9, 133906},
	{"OBSERVA", 7, 133907},
	{"ELKAY", 5, 133908},
	{"DUPRI", 5, 133909},
	{"LIPPMAN", 7, 133910},
	{"YDUP", 4, 133911},
	{"XTOW", 4, 133912},
	{"XENG", 4, 133913},
	{"URUD", 4, 133914},
	{"TIFG", 4, 133915},
	{"TFUM", 4, 133916},
	{"SREX", 4, 133917},
	{"RYHY", 4, 133918},
	{"OZAK", 4, 133919},
	{"NDRT", 4, 133920},
	{"EZPA", 4, 133921},
	{"CDIE", 4, 133922},
	{"APCL", 4, 133923},
	{"AXIALLY", 7, 133924},
	{"TRUANT", 6, 133925},
	{"SHRIEKED", 8, 133926},
	{"PICOLINATE", 10, 133927},
	{"HOMEBUSH", 8, 133928},
	{"ADOLESCENTES", 12, 133929},
	{"LAWES", 5, 133930},
	{"XMLHTTPREQUEST", 14, 133931},
	{"VDP", 3, 133932},
	{"COLBORNE", 8, 133933},
	{"INSTRUMENTALITIES", 17, 133934},
	{"OFFICIANT", 9, 133935},
	{"ENDPAPERS", 9, 133936},
	{"FAMILIARIZATION", 15, 133937},
	{"DERAILMENT", 10, 133938},
	{"DONIZETTI", 9, 133939},
	{"BANKEN", 6, 133940},
	{"JPGS", 4, 133941},
	{"PSAP", 4, 133942},
	{"NATRONA", 7, 133943},
	{"PEROXIDES", 9, 133944},
	{"REGER", 5, 133945},
	{"BROMELAIN", 9, 133946},
	{"RAYMER", 6, 133947},
	{"EMIRATE", 7, 133948},
	{"ADZAM", 5, 133949},
	{"WESTWORD", 8, 133950},
	{"XSMI", 4, 133951},
	{"WHYJ", 4, 133952},
	{"WELB", 4, 133953},
	{"USCW", 4, 133954},
	{"OUMR", 4, 133955},
	{"NMRB", 4, 133956},
	{"MIBU", 4, 133957},
	{"EPQU", 4, 133958},
	{"DIBM", 4, 133959},
	{"ABAP", 4, 133960},
	{"ERMINE", 6, 133961},
	{"INVENTIVENESS", 13, 133962},
	{"SHALES", 6, 133963},
	{"BELLTOWN", 8, 133964},
	{"SOFTKEY", 7, 133965},
	{"CORROBORATION", 13, 133966},
	{"MICRONICS", 9, 133967},
	{"GRATUITAMENTE", 13, 133968},
	{"MAVS", 4, 133969},
	{"BEDMINSTER", 10, 133970},
	{"BACKPLATE", 9, 133971},
	{"TEETERING", 9, 133972},
	{"GARA", 4, 133973},
	{"BLEEPING", 8, 133974},
	{"STEINMAN", 8, 133975},
	{"BRANDNAME", 9, 133976},
	{"CATTRALL", 8, 133977},
	{"NANCIAL", 7, 133978},
	{"SWIPED", 6, 133979},
	{"GRAMEEN", 7, 133980},
	{"STRABANE", 8, 133981},
	{"COTTONTAIL", 10, 133982},
	{"JUGE", 4, 133983},
	{"TANGOWIRE", 9, 133984},
	{"CIRCE", 5, 133985},
	{"ZESD", 4, 133986},
	{"XERW", 4, 133987},
	{"TADY", 4, 133988},
	{"RADG", 4, 133989},
	{"OPJA", 4, 133990},
	{"KASG", 4, 133991},
	{"GBOI", 4, 133992},
	{"FFYI", 4, 133993},
	{"FAKN", 4, 133994},
	{"COMV", 4, 133995},
	{"ABBU", 4, 133996},
	{"GAIJIN", 6, 133997},
	{"MLV", 3, 133998},
	{"WFAA", 4, 133999},
	{"CAPITULATION", 12, 134000},
	{"BATEMANS", 8, 134001},
	{"ASPIRANT", 8, 134002},
	{"PRONOGRAPHY", 11, 134003},
	{"TUNNEY", 6, 134004},
	{"AIRBRUSHED", 10, 134005},
	{"DEHRADUN", 8, 134006},
	{"ACDBBLOCKTABLERECORD", 20, 134007},
	{"BURDON", 6, 134008},
	{"GERMINAL", 8, 134009},
	{"VIDEOCARDS", 10, 134010},
	{"TUNINGS", 7, 134011},
	{"TOPBACK", 7, 134012},
	{"STEYR", 5, 134013},
	{"ALEKSANDAR", 10, 134014},
	{"KDENETWORK", 10, 134015},
	{"ALEMANIA", 8, 134016},
	{"WICCANS", 7, 134017},
	{"OPENEXR", 7, 134018},
	{"AFMC", 4, 134019},
	{"ZWON", 4, 134020},
	{"YPTU", 4, 134021},
	{"VANJ", 4, 134022},
	{"TCUN", 4, 134023},
	{"PGLO", 4, 134024},
	{"OPGI", 4, 134025},
	{"OLYU", 4, 134026},
	{"NFCS", 4, 134027},
	{"MVPO", 4, 134028},
	{"LBHA", 4, 134029},
	{"GMYR", 4, 134030},
	{"FBOI", 4, 134031},
	{"EGDE", 4, 134032},
	{"DKIE", 4, 134033},
	{"CKNU", 4, 134034},
	{"BIOTECHNOLOGIES", 15, 134035},
	{"PARL", 4, 134036},
	{"BASTIA", 6, 134037},
	{"FACH", 4, 134038},
	{"PESTIS", 6, 134039},
	{"RESPONSI", 8, 134040},
	{"VIHAR", 5, 134041},
	{"REDICULOUS", 10, 134042},
	{"PASSAGEWAYS", 11, 134043},
	{"VINDICATE", 9, 134044},
	{"DORKS", 5, 134045},
	{"STICH", 5, 134046},
	{"UNDERSCORING", 12, 134047},
	{"KATAHDIN", 8, 134048},
	{"CHANNELLING", 11, 134049},
	{"THYROTROPIN", 11, 134050},
	{"CORRESP", 7, 134051},
	{"REMIXING", 8, 134052},
	{"WINFAX", 6, 134053},
	{"GUANACASTE", 10, 134054},
	{"REPELLING", 9, 134055},
	{"SFOR", 4, 134056},
	{"SLUMPING", 8, 134057},
	{"YSQL", 4, 134058},
	{"ULFB", 4, 134059},
	{"QWES", 4, 134060},
	{"PREU", 4, 134061},
	{"NUBB", 4, 134062},
	{"MBBA", 4, 134063},
	{"LMLI", 4, 134064},
	{"LELB", 4, 134065},
	{"FIMI", 4, 134066},
	{"LSDA", 4, 134067},
	{"WIEGAND", 7, 134068},
	{"MULAYAM", 7, 134069},
	{"PVDF", 4, 134070},
	{"POULIN", 6, 134071},
	{"MFJ", 3, 134072},
	{"SUKKOT", 6, 134073},
	{"RULEZ", 5, 134074},
	{"INTERNODE", 9, 134075},
	{"MORBUS", 6, 134076},
	{"HYPERCARD", 9, 134077},
	{"ECHELONS", 8, 134078},
	{"INITSCRIPTS", 11, 134079},
	{"PROYECT", 7, 134080},
	{"OMNIVIEW", 8, 134081},
	{"KHOBAR", 6, 134082},
	{"GESUCHT", 7, 134083},
	{"FALLIBLE", 8, 134084},
	{"PANTHEISM", 9, 134085},
	{"HENSTRIDGE", 10, 134086},
	{"GERO", 4, 134087},
	{"ADVANSTAR", 9, 134088},
	{"PROLONGS", 8, 134089},
	{"ENOENT", 6, 134090},
	{"STRUTTING", 9, 134091},
	{"JAWBREAKER", 10, 134092},
	{"CLNS", 4, 134093},
	{"TOMV", 4, 134094},
	{"RHIV", 4, 134095},
	{"RAIP", 4, 134096},
	{"PBES", 4, 134097},
	{"OAWR", 4, 134098},
	{"MLYC", 4, 134099},
	{"MBEX", 4, 134100},
	{"KIAP", 4, 134101},
	{"DOOV", 4, 134102},
	{"DKOT", 4, 134103},
	{"CBSR", 4, 134104},
	{"NEUSTADT", 8, 134105},
	{"STENTING", 8, 134106},
	{"BOLDT", 5, 134107},
	{"KLEBSIELLA", 10, 134108},
	{"ITRONIX", 7, 134109},
	{"JPACKAGE", 8, 134110},
	{"PLOUGHSHARES", 12, 134111},
	{"INCALCULABLE", 12, 134112},
	{"CAGAYAN", 7, 134113},
	{"LASVEGAS", 8, 134114},
	{"GLAMUROSA", 9, 134115},
	{"VAGAS", 5, 134116},
	{"PEARLESCENT", 11, 134117},
	{"BARRO", 5, 134118},
	{"TIJD", 4, 134119},
	{"POMPIDOU", 8, 134120},
	{"MAXIE", 5, 134121},
	{"SOLILOQUY", 9, 134122},
	{"MAMMY", 5, 134123},
	{"BEAKS", 5, 134124},
	{"NIOXIN", 6, 134125},
	{"IKEBANA", 7, 134126},
	{"BREASTMILK", 10, 134127},
	{"ORGANON", 7, 134128},
	{"SCHUHFETISCH", 12, 134129},
	{"GOULDING", 8, 134130},
	{"DYNAMIX", 7, 134131},
	{"WPHA", 4, 134132},
	{"UCLO", 4, 134133},
	{"UAWI", 4, 134134},
	{"ODGL", 4, 134135},
	{"LUZE", 4, 134136},
	{"HEMQ", 4, 134137},
	{"BCRO", 4, 134138},
	{"BATV", 4, 134139},
	{"AKHR", 4, 134140},
	{"TRAIU", 5, 134141},
	{"SUNNYDALE", 9, 134142},
	{"BANFIELD", 8, 134143},
	{"TRANSPOSASE", 11, 134144},
	{"BLOODSTOCK", 10, 134145},
	{"COLORIMETRIC", 12, 134146},
	{"PREGUNTAS", 9, 134147},
	{"CARESSES", 8, 134148},
	{"STENCILING", 10, 134149},
	{"WATERCOOLING", 12, 134150},
	{"COLLINGS", 8, 134151},
	{"SLIPMATS", 8, 134152},
	{"HEXES", 5, 134153},
	{"NUMISMATICS", 11, 134154},
	{"INFUSING", 8, 134155},
	{"SLIMDEVICES", 11, 134156},
	{"COCKRELL", 8, 134157},
	{"GUSTAF", 6, 134158},
	{"NUDA", 4, 134159},
	{"VEGANISM", 8, 134160},
	{"FORB", 4, 134161},
	{"ZFF", 3, 134162},
	{"ZCK", 3, 134163},
	{"YBX", 3, 134164},
	{"VXQ", 3, 134165},
	{"VKK", 3, 134166},
	{"GVJ", 3, 134167},
	{"CVZ", 3, 134168},
	{"BZK", 3, 134169},
	{"BPZ", 3, 134170},
	{"QUELLO", 6, 134171},
	{"INDOLENT", 8, 134172},
	{"URSUS", 5, 134173},
	{"SCINTILLATOR", 12, 134174},
	{"MYELOGENOUS", 11, 134175},
	{"STACKERS", 8, 134176},
	{"ZZAW", 4, 134177},
	{"YOSB", 4, 134178},
	{"YKAH", 4, 134179},
	{"XTLI", 4, 134180},
	{"UYGO", 4, 134181},
	{"ULUP", 4, 134182},
	{"UEGU", 4, 134183},
	{"PDAU", 4, 134184},
	{"ODIW", 4, 134185},
	{"LUEU", 4, 134186},
	{"JARM", 4, 134187},
	{"HUXL", 4, 134188},
	{"HRBI", 4, 134189},
	{"GYAP", 4, 134190},
	{"GULE", 4, 134191},
	{"GIOM", 4, 134192},
	{"FDIO", 4, 134193},
	{"AUVA", 4, 134194},
	{"NIQUE", 5, 134195},
	{"KOSSUTH", 7, 134196},
	{"BITTERN", 7, 134197},
	{"QUAYSIDE", 8, 134198},
	{"SHOBOU", 6, 134199},
	{"LITESPEED", 9, 134200},
	{"MEANDERINGS", 11, 134201},
	{"MYFACES", 7, 134202},
	{"BANNS", 5, 134203},
	{"INFLU", 5, 134204},
	{"RAFA", 4, 134205},
	{"ZORKMIDDEN", 10, 134206},
	{"COPCO", 5, 134207},
	{"THISTLES", 8, 134208},
	{"SAVAPOINT", 9, 134209},
	{"ORCHESTRATING", 13, 134210},
	{"DUNOON", 6, 134211},
	{"SIGSEGV", 7, 134212},
	{"IDIOSYNCRASIES", 14, 134213},
	{"GAROTA", 6, 134214},
	{"TAMPICO", 7, 134215},
	{"TEAMTALK", 8, 134216},
	{"MAZAR", 5, 134217},
	{"ASPARAGINE", 10, 134218},
	{"INDUCEMENTS", 11, 134219},
	{"FULMER", 6, 134220},
	{"PTRELEMENT", 10, 134221},
	{"GARCH", 5, 134222},
	{"ENNUI", 5, 134223},
	{"MACAPAGAL", 9, 134224},
	{"FAIRBURN", 8, 134225},
	{"DAYSTAR", 7, 134226},
	{"ABETTED", 7, 134227},
	{"ZILO", 4, 134228},
	{"WHEB", 4, 134229},
	{"UIZS", 4, 134230},
	{"TIBB", 4, 134231},
	{"SMRI", 4, 134232},
	{"PWAY", 4, 134233},
	{"MIEB", 4, 134234},
	{"FKIS", 4, 134235},
	{"DFEV", 4, 134236},
	{"HEBDEN", 6, 134237},
	{"XFONTS", 6, 134238},
	{"KRISTIANSAND", 12, 134239},
	{"SCREENCAPS", 10, 134240},
	{"DROME", 5, 134241},
	{"MCPHAIL", 7, 134242},
	{"CAMPESTRIS", 10, 134243},
	{"RIED", 4, 134244},
	{"HOMPAGE", 7, 134245},
	{"EUROSTILE", 9, 134246},
	{"SILVICULTURAL", 13, 134247},
	{"KISER", 5, 134248},
	{"MAGELLANS", 9, 134249},
	{"PRIF", 4, 134250},
	{"VALPROIC", 8, 134251},
	{"GAMETIME", 8, 134252},
	{"HALFTONE", 8, 134253},
	{"EXPENDING", 9, 134254},
	{"BONHOEFFER", 10, 134255},
	{"SPORTSNET", 9, 134256},
	{"TENNESSE", 8, 134257},
	{"LETCHER", 7, 134258},
	{"BLUESKY", 7, 134259},
	{"DESENVOLVIMENTO", 15, 134260},
	{"STRANDING", 9, 134261},
	{"LARTC", 5, 134262},
	{"REYNOLDSBURG", 12, 134263},
	{"INTENTIONALITY", 14, 134264},
	{"YHEJ", 4, 134265},
	{"WWIF", 4, 134266},
	{"UCRI", 4, 134267},
	{"SAYK", 4, 134268},
	{"ROPK", 4, 134269},
	{"RBIV", 4, 134270},
	{"RAXL", 4, 134271},
	{"PAGU", 4, 134272},
	{"OYUK", 4, 134273},
	{"OFPT", 4, 134274},
	{"NAGP", 4, 134275},
	{"MROY", 4, 134276},
	{"MCAV", 4, 134277},
	{"ERRT", 4, 134278},
	{"AUTOMATIQUE", 11, 134279},
	{"DEVALUED", 8, 134280},
	{"ACCUSATIVE", 10, 134281},
	{"SWELTERING", 10, 134282},
	{"PUSEY", 5, 134283},
	{"OUTPACE", 7, 134284},
	{"GAMEWORLD", 9, 134285},
	{"COHESIVENESS", 12, 134286},
	{"CONTRI", 6, 134287},
	{"MARCOTTE", 8, 134288},
	{"OZMA", 4, 134289},
	{"VERDIGRIS", 9, 134290},
	{"HEIGL", 5, 134291},
	{"BIOCONTROL", 10, 134292},
	{"NEWSISFREE", 10, 134293},
	{"BEDFELLOWS", 10, 134294},
	{"HEMPEL", 6, 134295},
	{"CHATSERV", 8, 134296},
	{"EMPLOYABLE", 10, 134297},
	{"DAYWEAR", 7, 134298},
	{"TOLLEY", 6, 134299},
	{"TESTENV", 7, 134300},
	{"PREZZYBOX", 9, 134301},
	{"MORELIA", 7, 134302},
	{"DISTRICTWIDE", 12, 134303},
	{"EPHARMACIST", 11, 134304},
	{"EBERLE", 6, 134305},
	{"PURER", 5, 134306},
	{"OGIG", 4, 134307},
	{"LUMR", 4, 134308},
	{"LKOW", 4, 134309},
	{"IZWH", 4, 134310},
	{"FLDQ", 4, 134311},
	{"EVCO", 4, 134312},
	{"EFIJ", 4, 134313},
	{"DUGL", 4, 134314},
	{"ADYY", 4, 134315},
	{"WESTFALIA", 9, 134316},
	{"HEDGEROWS", 9, 134317},
	{"HYDROGRAPHY", 11, 134318},
	{"PRODUCTID", 9, 134319},
	{"FLATBUSH", 8, 134320},
	{"TOPICCLASSIFICATION", 19, 134321},
	{"EQUILIBRATION", 13, 134322},
	{"KADE", 4, 134323},
	{"MMB", 3, 134324},
	{"CHATTEN", 7, 134325},
	{"NARROWEST", 9, 134326},
	{"REVVING", 7, 134327},
	{"TYGER", 5, 134328},
	{"OMAP", 4, 134329},
	{"EXIGENT", 7, 134330},
	{"SQUIDS", 6, 134331},
	{"REBOUNDER", 9, 134332},
	{"GIOVANI", 7, 134333},
	{"ADVFN", 5, 134334},
	{"CGF", 3, 134335},
	{"ADWEEK", 6, 134336},
	{"ICEM", 4, 134337},
	{"DISAPPROVING", 12, 134338},
	{"RLD", 3, 134339},
	{"MESES", 5, 134340},
	{"TEITELBAUM", 10, 134341},
	{"MOOLOOLABA", 10, 134342},
	{"BACTERICIDAL", 12, 134343},
	{"YEEP", 4, 134344},
	{"RCAW", 4, 134345},
	{"FISG", 4, 134346},
	{"EXYA", 4, 134347},
	{"EMSJ", 4, 134348},
	{"DTHD", 4, 134349},
	{"DLOP", 4, 134350},
	{"DIAJ", 4, 134351},
	{"MANNIX", 6, 134352},
	{"PREMIA", 6, 134353},
	{"TAUZIN", 6, 134354},
	{"MICROMARK", 9, 134355},
	{"INTERROGATIVE", 13, 134356},
	{"DEADPAN", 7, 134357},
	{"SHEEDY", 6, 134358},
	{"ANFIELD", 7, 134359},
	{"SPACINGS", 8, 134360},
	{"CDSINGLE", 8, 134361},
	{"MCX", 3, 134362},
	{"SQUEALING", 9, 134363},
	{"MENNO", 5, 134364},
	{"DRAWABLE", 8, 134365},
	{"FEVERISHLY", 10, 134366},
	{"ZEROED", 6, 134367},
	{"BRADYKININ", 10, 134368},
	{"SNEAKED", 7, 134369},
	{"PACIFICORP", 10, 134370},
	{"CODEWORD", 8, 134371},
	{"GENISOY", 7, 134372},
	{"ELMENDORF", 9, 134373},
	{"TOCCOA", 6, 134374},
	{"OBRAS", 5, 134375},
	{"HUGBINE", 7, 134376},
	{"DROWNS", 6, 134377},
	{"BOGALUSA", 8, 134378},
	{"VOINOVICH", 9, 134379},
	{"DISCRETELY", 10, 134380},
	{"REPURCHASED", 11, 134381},
	{"ZMAD", 4, 134382},
	{"SKPA", 4, 134383},
	{"LTJU", 4, 134384},
	{"LDYS", 4, 134385},
	{"ISCJ", 4, 134386},
	{"FKAZ", 4, 134387},
	{"CYFE", 4, 134388},
	{"AZYM", 4, 134389},
	{"HATCHBACKS", 10, 134390},
	{"PERELMAN", 8, 134391},
	{"ONLOAD", 6, 134392},
	{"NOSTRI", 6, 134393},
	{"WAGONEER", 8, 134394},
	{"SHORTHAIRED", 11, 134395},
	{"AUTOGUIDE", 9, 134396},
	{"UDATE", 5, 134397},
	{"TRAVE", 5, 134398},
	{"ALIGHIERI", 9, 134399},
	{"SWALES", 6, 134400},
	{"ACCOMODATING", 12, 134401},
	{"VIRO", 4, 134402},
	{"GROH", 4, 134403},
	{"COLAS", 5, 134404},
	{"REMAPPING", 9, 134405},
	{"MOSSIMO", 7, 134406},
	{"BEAUVOIR", 8, 134407},
	{"CASELLA", 7, 134408},
	{"DUBLINERS", 9, 134409},
	{"HELLOWORLD", 10, 134410},
	{"PERSUASIVELY", 12, 134411},
	{"ALVIS", 5, 134412},
	{"GETSIZE", 7, 134413},
	{"ENERGON", 7, 134414},
	{"WWEP", 4, 134415},
	{"SBCO", 4, 134416},
	{"RYMP", 4, 134417},
	{"RKAZ", 4, 134418},
	{"PGUY", 4, 134419},
	{"MNCH", 4, 134420},
	{"MIXS", 4, 134421},
	{"MIFR", 4, 134422},
	{"IXAP", 4, 134423},
	{"IGSD", 4, 134424},
	{"FNIK", 4, 134425},
	{"CHHY", 4, 134426},
	{"CCYC", 4, 134427},
	{"CASV", 4, 134428},
	{"AYGL", 4, 134429},
	{"AWIZ", 4, 134430},
	{"AWIK", 4, 134431},
	{"WILLIMANTIC", 11, 134432},
	{"URNA", 4, 134433},
	{"MATHEMATIC", 10, 134434},
	{"LANTOS", 6, 134435},
	{"MUNSTERS", 8, 134436},
	{"MIDCAP", 6, 134437},
	{"KEMPSTER", 8, 134438},
	{"KANNAN", 6, 134439},
	{"CHORLTON", 8, 134440},
	{"SATLUG", 6, 134441},
	{"FANBOYS", 7, 134442},
	{"WALLOON", 7, 134443},
	{"XJELL", 5, 134444},
	{"JURI", 4, 134445},
	{"SIMSON", 6, 134446},
	{"FLOURS", 6, 134447},
	{"HUACHUCA", 8, 134448},
	{"SEPTICEMIA", 10, 134449},
	{"METAMODEL", 9, 134450},
	{"LINUXCONF", 9, 134451},
	{"GLR", 3, 134452},
	{"FUNDACION", 9, 134453},
	{"SQUALOR", 7, 134454},
	{"NICEVILLE", 9, 134455},
	{"REASSESSED", 10, 134456},
	{"HYPERPLANE", 10, 134457},
	{"INNERHTML", 9, 134458},
	{"LYOPHILIZED", 11, 134459},
	{"ROSEY", 5, 134460},
	{"QUADRILATERAL", 13, 134461},
	{"LAKAI", 5, 134462},
	{"PANELLED", 8, 134463},
	{"GARONNE", 7, 134464},
	{"PRASHANT", 8, 134465},
	{"PRETREATED", 10, 134466},
	{"DENITRIFICATION", 15, 134467},
	{"OSSIAN", 6, 134468},
	{"AYODHYA", 7, 134469},
	{"PERFORMACE", 10, 134470},
	{"BOSCOV", 6, 134471},
	{"YLAV", 4, 134472},
	{"LIUK", 4, 134473},
	{"KISJ", 4, 134474},
	{"HUNR", 4, 134475},
	{"ENGP", 4, 134476},
	{"ECYR", 4, 134477},
	{"CPLU", 4, 134478},
	{"TANNENBAUM", 10, 134479},
	{"GRACILIS", 8, 134480},
	{"ACOMODATION", 11, 134481},
	{"KANAB", 5, 134482},
	{"PERISTALTIC", 11, 134483},
	{"IGUAZU", 6, 134484},
	{"ZUTONS", 6, 134485},
	{"PYGMALION", 9, 134486},
	{"SAMMO", 5, 134487},
	{"BRIDGMAN", 8, 134488},
	{"BULKING", 7, 134489},
	{"VIOLATIVE", 9, 134490},
	{"CRANBOURNE", 10, 134491},
	{"FABRICANT", 9, 134492},
	{"OBJS", 4, 134493},
	{"CADDIS", 6, 134494},
	{"CHAPLET", 7, 134495},
	{"CLINCHER", 8, 134496},
	{"NARRATE", 7, 134497},
	{"PAINLESSLY", 10, 134498},
	{"PELEUS", 6, 134499},
	{"RELEASERS", 9, 134500},
	{"PROPERTYGUIDE", 13, 134501},
	{"LEGWORK", 7, 134502},
	{"NULLIFIED", 9, 134503},
	{"LAYPERSON", 9, 134504},
	{"RADIOISOTOPE", 12, 134505},
	{"LONERGAN", 8, 134506},
	{"FERRI", 5, 134507},
	{"MONTGOMERYSHIRE", 15, 134508},
	{"MYOFASCIAL", 10, 134509},
	{"HOMINIDAE", 9, 134510},
	{"JURIDIQUE", 9, 134511},
	{"HESIOD", 6, 134512},
	{"PERSE", 5, 134513},
	{"ZCAM", 4, 134514},
	{"WLRE", 4, 134515},
	{"UPSK", 4, 134516},
	{"UIRA", 4, 134517},
	{"OBME", 4, 134518},
	{"LPHM", 4, 134519},
	{"KMDA", 4, 134520},
	{"IELV", 4, 134521},
	{"HYFE", 4, 134522},
	{"FEWJ", 4, 134523},
	{"BSDA", 4, 134524},
	{"ABMI", 4, 134525},
	{"DAHLONEGA", 9, 134526},
	{"CENTREPIECE", 11, 134527},
	{"MAMAN", 5, 134528},
	{"TREACHER", 8, 134529},
	{"ASCENDER", 8, 134530},
	{"BOUGAINVILLEA", 13, 134531},
	{"PARAPLEGIA", 10, 134532},
	{"SECY", 4, 134533},
	{"MENINGITIDIS", 12, 134534},
	{"BLEAT", 5, 134535},
	{"SPEEDBALL", 9, 134536},
	{"RIDENOUR", 8, 134537},
	{"COOPS", 5, 134538},
	{"MAREBITO", 8, 134539},
	{"GLORIFYING", 10, 134540},
	{"MORAYSHIRE", 10, 134541},
	{"ZIPCODES", 8, 134542},
	{"INVENTORYSHOW", 13, 134543},
	{"BACTEROIDES", 11, 134544},
	{"FDOT", 4, 134545},
	{"LANEGAN", 7, 134546},
	{"STRADDLES", 9, 134547},
	{"LCPL", 4, 134548},
	{"LOCARNO", 7, 134549},
	{"XELC", 4, 134550},
	{"UGAA", 4, 134551},
	{"UDAW", 4, 134552},
	{"SRAU", 4, 134553},
	{"RIIP", 4, 134554},
	{"PJAM", 4, 134555},
	{"PENK", 4, 134556},
	{"OWMC", 4, 134557},
	{"OBIB", 4, 134558},
	{"MUPD", 4, 134559},
	{"KVIN", 4, 134560},
	{"JOUS", 4, 134561},
	{"HIKU", 4, 134562},
	{"GPOV", 4, 134563},
	{"FWEF", 4, 134564},
	{"ARPN", 4, 134565},
	{"GLEAMED", 7, 134566},
	{"BRENNA", 6, 134567},
	{"CARMACK", 7, 134568},
	{"VALIANTLY", 9, 134569},
	{"LONGSHORE", 9, 134570},
	{"STEEDS", 6, 134571},
	{"MACROBIOTIC", 11, 134572},
	{"ELLI", 4, 134573},
	{"NEGERI", 6, 134574},
	{"HOTELLER", 8, 134575},
	{"INFALLIBILITY", 13, 134576},
	{"REROUTE", 7, 134577},
	{"MOUNTBATTEN", 11, 134578},
	{"MORONI", 6, 134579},
	{"HOGAR", 5, 134580},
	{"MUNICATION", 10, 134581},
	{"METALCORE", 9, 134582},
	{"PHOTOLOG", 8, 134583},
	{"BENSENVILLE", 11, 134584},
	{"AIRPARK", 7, 134585},
	{"MAZEN", 5, 134586},
	{"VOLL", 4, 134587},
	{"ALTES", 5, 134588},
	{"FRANCISCANS", 11, 134589},
	{"SPOR", 4, 134590},
	{"PEDALING", 8, 134591},
	{"PODE", 4, 134592},
	{"TRICKIER", 8, 134593},
	{"INVES", 5, 134594},
	{"EXACERBATING", 12, 134595},
	{"RFAD", 4, 134596},
	{"MISQ", 4, 134597},
	{"LEGP", 4, 134598},
	{"ELPV", 4, 134599},
	{"COFK", 4, 134600},
	{"BULU", 4, 134601},
	{"QUASHED", 7, 134602},
	{"COMPORT", 7, 134603},
	{"WNYC", 4, 134604},
	{"TRAILERING", 10, 134605},
	{"BENIFITS", 8, 134606},
	{"WASTER", 6, 134607},
	{"MALHEUR", 7, 134608},
	{"OVERDO", 6, 134609},
	{"RAGUSA", 6, 134610},
	{"BIENVILLE", 9, 134611},
	{"DAVILA", 6, 134612},
	{"IPFIX", 5, 134613},
	{"APPROP", 6, 134614},
	{"CWAO", 4, 134615},
	{"LAFOURCHE", 9, 134616},
	{"ADAMANTLY", 9, 134617},
	{"KENNAN", 6, 134618},
	{"NEOLIBERALISM", 13, 134619},
	{"PREPEI", 6, 134620},
	{"RAVENCLAW", 9, 134621},
	{"CQWW", 4, 134622},
	{"ADSP", 4, 134623},
	{"MYTHOLOGIES", 11, 134624},
	{"OFTEL", 5, 134625},
	{"KAMUELA", 7, 134626},
	{"UNSCRIPTED", 10, 134627},
	{"KYOKO", 5, 134628},
	{"HERBIVORE", 9, 134629},
	{"BLOIS", 5, 134630},
	{"PAPPY", 5, 134631},
	{"SUPPOSITORY", 11, 134632},
	{"UNDERESTIMATING", 15, 134633},
	{"TAILGATER", 9, 134634},
	{"RONGE", 5, 134635},
	{"PHOENIXVILLE", 12, 134636},
	{"JENKIN", 6, 134637},
	{"CHINEESE", 8, 134638},
	{"SUGARCRM", 8, 134639},
	{"STYLEDATA", 9, 134640},
	{"BREWTON", 7, 134641},
	{"YABC", 4, 134642},
	{"WEDK", 4, 134643},
	{"VONF", 4, 134644},
	{"UBAP", 4, 134645},
	{"TMYK", 4, 134646},
	{"RARL", 4, 134647},
	{"PARB", 4, 134648},
	{"OUNM", 4, 134649},
	{"MJEW", 4, 134650},
	{"MBIB", 4, 134651},
	{"LBEQ", 4, 134652},
	{"IFMR", 4, 134653},
	{"FAXT", 4, 134654},
	{"EZEM", 4, 134655},
	{"DAKR", 4, 134656},
	{"COAF", 4, 134657},
	{"BTFR", 4, 134658},
	{"ATLB", 4, 134659},
	{"RADISHES", 8, 134660},
	{"CHIVERS", 7, 134661},
	{"NEUROTROPHIC", 12, 134662},
	{"LIPINSKI", 8, 134663},
	{"TANKA", 5, 134664},
	{"HOSTERS", 7, 134665},
	{"GUAGES", 6, 134666},
	{"BALDRIGE", 8, 134667},
	{"MCDONAGH", 8, 134668},
	{"ZYLOPRIM", 8, 134669},
	{"STENSON", 7, 134670},
	{"SAMBURU", 7, 134671},
	{"EXECU", 5, 134672},
	{"POLLINATED", 10, 134673},
	{"GREENWELL", 9, 134674},
	{"TAUBMAN", 7, 134675},
	{"AOYAMA", 6, 134676},
	{"DEEMING", 7, 134677},
	{"MULTIKEY", 8, 134678},
	{"RNLI", 4, 134679},
	{"MIRVIS", 6, 134680},
	{"KARIMOV", 7, 134681},
	{"FRIGHTENINGLY", 13, 134682},
	{"CONFORMIST", 10, 134683},
	{"PACIFICO", 8, 134684},
	{"WILFRIED", 8, 134685},
	{"MASLIN", 6, 134686},
	{"FLACCID", 7, 134687},
	{"PHOTODYNAMIC", 12, 134688},
	{"DEVASTATE", 9, 134689},
	{"WEBCAL", 6, 134690},
	{"XONR", 4, 134691},
	{"XACC", 4, 134692},
	{"UCUT", 4, 134693},
	{"OEFR", 4, 134694},
	{"HIRW", 4, 134695},
	{"GDPA", 4, 134696},
	{"FSLU", 4, 134697},
	{"DFOG", 4, 134698},
	{"AYNU", 4, 134699},
	{"ASMM", 4, 134700},
	{"ARAX", 4, 134701},
	{"AFUG", 4, 134702},
	{"DRIERS", 6, 134703},
	{"FREDAG", 6, 134704},
	{"UNECE", 5, 134705},
	{"GOSTOSA", 7, 134706},
	{"MORESO", 6, 134707},
	{"ZDENEK", 6, 134708},
	{"AGGRESSORS", 10, 134709},
	{"JABBERD", 7, 134710},
	{"BLOGDOM", 7, 134711},
	{"ISTEP", 5, 134712},
	{"EMILION", 7, 134713},
	{"MCINNES", 7, 134714},
	{"RATEBEER", 8, 134715},
	{"PUTRID", 6, 134716},
	{"DISPLAYNAME", 11, 134717},
	{"WEBPREFSTOPIC", 13, 134718},
	{"WASCHK", 6, 134719},
	{"UNGUARDED", 9, 134720},
	{"COLLIDERS", 9, 134721},
	{"SIROTA", 6, 134722},
	{"PRODDED", 7, 134723},
	{"ATTRA", 5, 134724},
	{"TGPS", 4, 134725},
	{"YMYR", 4, 134726},
	{"YASQ", 4, 134727},
	{"WIIW", 4, 134728},
	{"TPLY", 4, 134729},
	{"SYPO", 4, 134730},
	{"OVIG", 4, 134731},
	{"NGTZ", 4, 134732},
	{"MDOL", 4, 134733},
	{"CPUT", 4, 134734},
	{"DRYSUITS", 8, 134735},
	{"COLLINEAR", 9, 134736},
	{"VERGES", 6, 134737},
	{"MACPHAIL", 8, 134738},
	{"OBLITERATION", 12, 134739},
	{"OLIGOMERS", 9, 134740},
	{"HOMAN", 5, 134741},
	{"FASTS", 5, 134742},
	{"PLOSSL", 6, 134743},
	{"IDEFENSE", 8, 134744},
	{"STERNER", 7, 134745},
	{"KURSE", 5, 134746},
	{"TELCOMM", 7, 134747},
	{"VILLEGAS", 8, 134748},
	{"SALVAME", 7, 134749},
	{"CYGDRIVE", 8, 134750},
	{"INTERNIST", 9, 134751},
	{"ACHEIVE", 7, 134752},
	{"POCHETTE", 8, 134753},
	{"MUTCD", 5, 134754},
	{"KIRSCHNER", 9, 134755},
	{"BABOR", 5, 134756},
	{"SHIRIN", 6, 134757},
	{"DOWNSTATE", 9, 134758},
	{"DESTINYS", 8, 134759},
	{"BROADSHEET", 10, 134760},
	{"JIMBARAN", 8, 134761},
	{"HOLGUIN", 7, 134762},
	{"JUVE", 4, 134763},
	{"KINSKI", 6, 134764},
	{"BAMHI", 5, 134765},
	{"LEVENGER", 8, 134766},
	{"WOMANLY", 7, 134767},
	{"DATAPILOT", 9, 134768},
	{"WITWATERSRAND", 13, 134769},
	{"ULSK", 4, 134770},
	{"UBEP", 4, 134771},
	{"TODC", 4, 134772},
	{"SKYG", 4, 134773},
	{"SJAG", 4, 134774},
	{"RLEQ", 4, 134775},
	{"PBOR", 4, 134776},
	{"NFLB", 4, 134777},
	{"NBCU", 4, 134778},
	{"IMTU", 4, 134779},
	{"HECG", 4, 134780},
	{"CHIJ", 4, 134781},
	{"AYTV", 4, 134782},
	{"NALL", 4, 134783},
	{"BIRNEY", 6, 134784},
	{"SURMISED", 8, 134785},
	{"SSCP", 4, 134786},
	{"ACCELEROMETERS", 14, 134787},
	{"ARROUND", 7, 134788},
	{"JAROD", 5, 134789},
	{"URES", 4, 134790},
	{"NORTHWARDS", 10, 134791},
	{"COOTER", 6, 134792},
	{"MAYEST", 6, 134793},
	{"MANEY", 5, 134794},
	{"CHORIZO", 7, 134795},
	{"OUTWITH", 7, 134796},
	{"KARINE", 6, 134797},
	{"JUDICIOUSLY", 11, 134798},
	{"UPTHU", 5, 134799},
	{"KENG", 4, 134800},
	{"PLG", 3, 134801},
	{"WHITEHURST", 10, 134802},
	{"SARABANDE", 9, 134803},
	{"KINGDON", 7, 134804},
	{"PNEUMOTHORAX", 12, 134805},
	{"HYPERSENSITIVE", 14, 134806},
	{"PHOTOSENSITIVE", 14, 134807},
	{"ROSENBERGER", 11, 134808},
	{"REUNITING", 9, 134809},
	{"WJOI", 4, 134810},
	{"URDT", 4, 134811},
	{"RBAM", 4, 134812},
	{"NIFB", 4, 134813},
	{"MRSF", 4, 134814},
	{"LDII", 4, 134815},
	{"EUWA", 4, 134816},
	{"EGBO", 4, 134817},
	{"BEKS", 4, 134818},
	{"RIDGED", 6, 134819},
	{"EXCEEDANCES", 11, 134820},
	{"ODDSCHECKER", 11, 134821},
	{"CAREERCONNECTION", 16, 134822},
	{"CACH", 4, 134823},
	{"WORSHIPPER", 10, 134824},
	{"ALLENS", 6, 134825},
	{"HAMRICK", 7, 134826},
	{"DIDEROT", 7, 134827},
	{"RUTS", 4, 134828},
	{"SEVERABLE", 9, 134829},
	{"NOAEL", 5, 134830},
	{"ADDUSER", 7, 134831},
	{"REGRETTING", 10, 134832},
	{"FIBROID", 7, 134833},
	{"REHYDRATION", 11, 134834},
	{"TISBURY", 7, 134835},
	{"FRICKE", 6, 134836},
	{"POJKVAN", 7, 134837},
	{"SCOLDING", 8, 134838},
	{"BAYNE", 5, 134839},
	{"INTDIR", 6, 134840},
	{"SPCH", 4, 134841},
	{"AMBERLEY", 8, 134842},
	{"BOSPHORUS", 9, 134843},
	{"AMPUTATIONS", 11, 134844},
	{"FCD", 3, 134845},
	{"DISTRIBUTORSHIP", 15, 134846},
	{"DIMPLED", 7, 134847},
	{"SERVICEMARKS", 12, 134848},
	{"DARON", 5, 134849},
	{"WSRI", 4, 134850},
	{"SYDI", 4, 134851},
	{"PARH", 4, 134852},
	{"NKOK", 4, 134853},
	{"LKEV", 4, 134854},
	{"IFKI", 4, 134855},
	{"HUKO", 4, 134856},
	{"FBYH", 4, 134857},
	{"DODU", 4, 134858},
	{"DAQA", 4, 134859},
	{"BIKA", 4, 134860},
	{"AYVS", 4, 134861},
	{"ALBC", 4, 134862},
	{"MASSING", 7, 134863},
	{"MOISTURIZE", 10, 134864},
	{"OFFEN", 5, 134865},
	{"LORDE", 5, 134866},
	{"GDF", 3, 134867},
	{"WHITELAW", 8, 134868},
	{"NORELL", 6, 134869},
	{"GISUSER", 7, 134870},
	{"ULAN", 4, 134871},
	{"LEATHERY", 8, 134872},
	{"BRICOLAGE", 9, 134873},
	{"RZB", 3, 134874},
	{"LUBAVITCH", 9, 134875},
	{"HJEM", 4, 134876},
	{"CABALLOS", 8, 134877},
	{"RAJENDRA", 8, 134878},
	{"ARVO", 4, 134879},
	{"SERUSERS", 8, 134880},
	{"SNORKELS", 8, 134881},
	{"PAINESVILLE", 11, 134882},
	{"RECEIVERANALOG", 14, 134883},
	{"AUDITIONED", 10, 134884},
	{"DANIELL", 7, 134885},
	{"SATTLER", 7, 134886},
	{"PACKINGS", 8, 134887},
	{"ENDOSCOPE", 9, 134888},
	{"MANULIFE", 8, 134889},
	{"HARROP", 6, 134890},
	{"MOONBATS", 8, 134891},
	{"PALENQUE", 8, 134892},
	{"ELLERSLIE", 9, 134893},
	{"MEMORANDUMS", 11, 134894},
	{"BURSON", 6, 134895},
	{"APOSTROPHES", 11, 134896},
	{"GOOLGE", 6, 134897},
	{"RATIONALIZED", 12, 134898},
	{"ELECTROENCEPHALOGRAPHY", 22, 134899},
	{"YAOM", 4, 134900},
	{"URIY", 4, 134901},
	{"RIEJ", 4, 134902},
	{"MIAF", 4, 134903},
	{"LIXT", 4, 134904},
	{"LBUF", 4, 134905},
	{"JEDA", 4, 134906},
	{"HYCR", 4, 134907},
	{"FFCU", 4, 134908},
	{"FESM", 4, 134909},
	{"EKEX", 4, 134910},
	{"BITV", 4, 134911},
	{"ASMB", 4, 134912},
	{"GRIMACE", 7, 134913},
	{"BRIBING", 7, 134914},
	{"PENNELL", 7, 134915},
	{"COMPING", 7, 134916},
	{"ABRS", 4, 134917},
	{"ADDERS", 6, 134918},
	{"GOFFSTOWN", 9, 134919},
	{"BECKI", 5, 134920},
	{"AIPAC", 5, 134921},
	{"GUARDSMAN", 9, 134922},
	{"MISCOMMUNICATION", 16, 134923},
	{"HAMMAMET", 8, 134924},
	{"IMCS", 4, 134925},
	{"TULLOCH", 7, 134926},
	{"UNBECOMING", 10, 134927},
	{"BOATBUILDING", 12, 134928},
	{"BRIDLES", 7, 134929},
	{"RINALDO", 7, 134930},
	{"DEJECTED", 8, 134931},
	{"MADINAH", 7, 134932},
	{"ATENEO", 6, 134933},
	{"PANNIER", 7, 134934},
	{"VIRIONS", 7, 134935},
	{"PAROTID", 7, 134936},
	{"TORZ", 4, 134937},
	{"MIXB", 4, 134938},
	{"FFHU", 4, 134939},
	{"ERBD", 4, 134940},
	{"BFAM", 4, 134941},
	{"ZEOLITES", 8, 134942},
	{"MEGALITHS", 9, 134943},
	{"GETTIMEOFDAY", 12, 134944},
	{"CYLON", 5, 134945},
	{"CHUCKIE", 7, 134946},
	{"SLOVOED", 7, 134947},
	{"EROTIQUE", 8, 134948},
	{"EMBARGOED", 9, 134949},
	{"TARKAN", 6, 134950},
	{"YOKOYAMA", 8, 134951},
	{"PILLING", 7, 134952},
	{"VOSGES", 6, 134953},
	{"EXIDE", 5, 134954},
	{"COMELY", 6, 134955},
	{"PROW", 4, 134956},
	{"ENTERNAL", 8, 134957},
	{"BAGLIONI", 8, 134958},
	{"SPRIG", 5, 134959},
	{"CHISELED", 8, 134960},
	{"PCSWITCH", 8, 134961},
	{"NEWHART", 7, 134962},
	{"HOMEODOMAIN", 11, 134963},
	{"CHAGAS", 6, 134964},
	{"BISTROS", 7, 134965},
	{"LABO", 4, 134966},
	{"APULIA", 6, 134967},
	{"DREHER", 6, 134968},
	{"EMPATHIC", 8, 134969},
	{"BABETTE", 7, 134970},
	{"OVATE", 5, 134971},
	{"ORIGI", 5, 134972},
	{"TULLAHOMA", 9, 134973},
	{"OLYMPIQUE", 9, 134974},
	{"PIRILLO", 7, 134975},
	{"MINIMISES", 9, 134976},
	{"ITERATES", 8, 134977},
	{"IMPAC", 5, 134978},
	{"BATHHOUSE", 9, 134979},
	{"YIVA", 4, 134980},
	{"RROV", 4, 134981},
	{"NUKO", 4, 134982},
	{"NJOL", 4, 134983},
	{"LYOS", 4, 134984},
	{"LPEX", 4, 134985},
	{"FNAK", 4, 134986},
	{"EVWH", 4, 134987},
	{"ECFI", 4, 134988},
	{"DYAK", 4, 134989},
	{"AMAQ", 4, 134990},
	{"PRIYANKA", 8, 134991},
	{"BAKBONE", 7, 134992},
	{"SQUANDER", 8, 134993},
	{"BLANKED", 7, 134994},
	{"SWARMED", 7, 134995},
	{"PUKING", 6, 134996},
	{"WIELDS", 6, 134997},
	{"DARS", 4, 134998},
	{"CHADWICKS", 9, 134999},
	{"LIBRARYREF", 10, 135000},
	{"BONEFISH", 8, 135001},
	{"GELIJKWAARDIGE", 14, 135002},
	{"JUTTA", 5, 135003},
	{"LLANDRINDOD", 11, 135004},
	{"DRAGOONS", 8, 135005},
	{"APIDOCS", 7, 135006},
	{"GENOTYPIC", 9, 135007},
	{"BASKETBALLS", 11, 135008},
	{"BOSCOLO", 7, 135009},
	{"GAZPACHO", 8, 135010},
	{"LIEBIG", 6, 135011},
	{"SCAD", 4, 135012},
	{"FIBERBOARD", 10, 135013},
	{"SHIRA", 5, 135014},
	{"DANIO", 5, 135015},
	{"TELLUS", 6, 135016},
	{"SETPAGEDEVICE", 13, 135017},
	{"SEISMOLOGICAL", 13, 135018},
	{"SPECFILE", 8, 135019},
	{"MONKTON", 7, 135020},
	{"SHAFTED", 7, 135021},
	{"YORI", 4, 135022},
	{"HELPCONTENTS", 12, 135023},
	{"YCEI", 4, 135024},
	{"URSV", 4, 135025},
	{"UDBR", 4, 135026},
	{"SOLM", 4, 135027},
	{"SDIX", 4, 135028},
	{"RKBI", 4, 135029},
	{"IVAJ", 4, 135030},
	{"HMYR", 4, 135031},
	{"EYLU", 4, 135032},
	{"BIRG", 4, 135033},
	{"BHPB", 4, 135034},
	{"ABIW", 4, 135035},
	{"EUTHANIZED", 10, 135036},
	{"LEARNI", 6, 135037},
	{"PLANETILUG", 10, 135038},
	{"HYDRODERM", 9, 135039},
	{"STEWARTS", 8, 135040},
	{"BRUNE", 5, 135041},
	{"LANDHOLDERS", 11, 135042},
	{"DACE", 4, 135043},
	{"LIPODYSTROPHY", 13, 135044},
	{"CRADLED", 7, 135045},
	{"COMPARABLY", 10, 135046},
	{"DREADS", 6, 135047},
	{"SPURRING", 8, 135048},
	{"ADVANTA", 7, 135049},
	{"PROTRACTOR", 10, 135050},
	{"GOLDRUSH", 8, 135051},
	{"SOLLTE", 6, 135052},
	{"PLAYTHING", 9, 135053},
	{"SINGLETRACK", 11, 135054},
	{"DTOR", 4, 135055},
	{"UNORIGINAL", 10, 135056},
	{"PRAVASTATIN", 11, 135057},
	{"TROLLED", 7, 135058},
	{"PANDER", 6, 135059},
	{"CALFSKIN", 8, 135060},
	{"STAMM", 5, 135061},
	{"PINNACOR", 8, 135062},
	{"ABOMINATIONS", 12, 135063},
	{"OFBIZ", 5, 135064},
	{"EARTHWEB", 8, 135065},
	{"YOBR", 4, 135066},
	{"UIGA", 4, 135067},
	{"UERD", 4, 135068},
	{"TDMI", 4, 135069},
	{"STKM", 4, 135070},
	{"LUSV", 4, 135071},
	{"HZAD", 4, 135072},
	{"HYGA", 4, 135073},
	{"EPHJ", 4, 135074},
	{"DNED", 4, 135075},
	{"KAWARTHA", 8, 135076},
	{"UNDERDEVELOPMENT", 16, 135077},
	{"SUNCATCHERS", 11, 135078},
	{"CAMPINGS", 8, 135079},
	{"VIENE", 5, 135080},
	{"BIONAIRE", 8, 135081},
	{"HALLMAN", 7, 135082},
	{"BRIXHAM", 7, 135083},
	{"KLAGENFURT", 10, 135084},
	{"TAREE", 5, 135085},
	{"TOTEMS", 6, 135086},
	{"ERDMAN", 6, 135087},
	{"REESTABLISHED", 13, 135088},
	{"TRIC", 4, 135089},
	{"STRANGLING", 10, 135090},
	{"CULTIVATORS", 11, 135091},
	{"BRACKS", 6, 135092},
	{"BASTING", 7, 135093},
	{"ADALINE", 7, 135094},
	{"STATISTCS", 9, 135095},
	{"WESTJET", 7, 135096},
	{"INSIGNIFICANCE", 14, 135097},
	{"CLARKSDALE", 10, 135098},
	{"MINIATURIZATION", 15, 135099},
	{"YMTH", 4, 135100},
	{"UZCO", 4, 135101},
	{"TABW", 4, 135102},
	{"RYPS", 4, 135103},
	{"OKFE", 4, 135104},
	{"MYED", 4, 135105},
	{"JAQU", 4, 135106},
	{"HRIP", 4, 135107},
	{"DVAT", 4, 135108},
	{"DUEH", 4, 135109},
	{"DRSI", 4, 135110},
	{"DIMC", 4, 135111},
	{"CAAG", 4, 135112},
	{"BYUR", 4, 135113},
	{"RIYALS", 6, 135114},
	{"MARACAIBO", 9, 135115},
	{"BOOKVIEW", 8, 135116},
	{"RIGGINS", 7, 135117},
	{"ICTP", 4, 135118},
	{"MODERATO", 8, 135119},
	{"WHITLAM", 7, 135120},
	{"SOAPBLOX", 8, 135121},
	{"DECEIVER", 8, 135122},
	{"NEKROMANTIX", 11, 135123},
	{"SCIROCCO", 8, 135124},
	{"PISSY", 5, 135125},
	{"SPOKESPEOPLE", 12, 135126},
	{"CADMAN", 6, 135127},
	{"SELLA", 5, 135128},
	{"GPRA", 4, 135129},
	{"ALEISTER", 8, 135130},
	{"STRATAGENE", 10, 135131},
	{"RAUSCHER", 8, 135132},
	{"MANDINGO", 8, 135133},
	{"VARIABLENAME", 12, 135134},
	{"CARTOGRAPHER", 12, 135135},
	{"GPUS", 4, 135136},
	{"HELLE", 5, 135137},
	{"RADIATIONS", 10, 135138},
	{"ADACHI", 6, 135139},
	{"ENTERPRIS", 9, 135140},
	{"GRANTMAKERS", 11, 135141},
	{"SUBSAMPLE", 9, 135142},
	{"WITHTHE", 7, 135143},
	{"LEVELTEN", 8, 135144},
	{"NANTICOKE", 9, 135145},
	{"BRITZ", 5, 135146},
	{"SPUTTERED", 9, 135147},
	{"RIVERO", 6, 135148},
	{"DRGS", 4, 135149},
	{"VIBRO", 5, 135150},
	{"FAITES", 6, 135151},
	{"HARTUNG", 7, 135152},
	{"KAWA", 4, 135153},
	{"MERRIER", 7, 135154},
	{"INDUCER", 7, 135155},
	{"SIMPLES", 7, 135156},
	{"RUGGLES", 7, 135157},
	{"MIEL", 4, 135158},
	{"IMAGINATIVELY", 13, 135159},
	{"CYMDEITHASOL", 12, 135160},
	{"STDIO", 5, 135161},
	{"TITMUSS", 7, 135162},
	{"TUMD", 4, 135163},
	{"RDGL", 4, 135164},
	{"PSJO", 4, 135165},
	{"MPBO", 4, 135166},
	{"LEGD", 4, 135167},
	{"KALR", 4, 135168},
	{"HDIL", 4, 135169},
	{"ALPM", 4, 135170},
	{"RYDERS", 6, 135171},
	{"TINDERBUILD", 11, 135172},
	{"SUBSIDES", 8, 135173},
	{"NOBLER", 6, 135174},
	{"FIRSTCLASS", 10, 135175},
	{"MICHAELMAS", 10, 135176},
	{"KATHA", 5, 135177},
	{"UNCOLLECTED", 11, 135178},
	{"ISOPROTERENOL", 13, 135179},
	{"WAMU", 4, 135180},
	{"PERGO", 5, 135181},
	{"WIEERS", 6, 135182},
	{"MALABSORPTION", 13, 135183},
	{"PHOTOBOOK", 9, 135184},
	{"BILDUNG", 7, 135185},
	{"IMAKE", 5, 135186},
	{"TELEMARKETER", 12, 135187},
	{"TANGANYIKA", 10, 135188},
	{"ACCEPTORS", 9, 135189},
	{"HOWLED", 6, 135190},
	{"SUBTITRARI", 10, 135191},
	{"WILLESDEN", 9, 135192},
	{"QUENCES", 7, 135193},
	{"SMAIL", 5, 135194},
	{"MADA", 4, 135195},
	{"GULLET", 6, 135196},
	{"COMPOSTED", 9, 135197},
	{"INDEXOF", 7, 135198},
	{"BLANCHED", 8, 135199},
	{"YGIG", 4, 135200},
	{"YDTH", 4, 135201},
	{"WWCO", 4, 135202},
	{"VWER", 4, 135203},
	{"OMRH", 4, 135204},
	{"KYGR", 4, 135205},
	{"FLNE", 4, 135206},
	{"FCOG", 4, 135207},
	{"CITG", 4, 135208},
	{"SILVERBACK", 10, 135209},
	{"FURNISHERS", 10, 135210},
	{"FINNIGAN", 8, 135211},
	{"RAINA", 5, 135212},
	{"ALLEMAND", 8, 135213},
	{"SULFIDES", 8, 135214},
	{"ACDBPOLYLINE", 12, 135215},
	{"VEGETAL", 7, 135216},
	{"ELMAR", 5, 135217},
	{"IRONSIDE", 8, 135218},
	{"INDIRECTION", 11, 135219},
	{"CARTREF", 7, 135220},
	{"KUBO", 4, 135221},
	{"WENCESLAS", 9, 135222},
	{"UNEQUALLED", 10, 135223},
	{"CHRISM", 6, 135224},
	{"DEANNE", 6, 135225},
	{"BEDELL", 6, 135226},
	{"SOURCETREE", 10, 135227},
	{"SPACEBAR", 8, 135228},
	{"FLORIO", 6, 135229},
	{"NELSPRUIT", 9, 135230},
	{"CICELY", 6, 135231},
	{"AUBADE", 6, 135232},
	{"CABBIE", 6, 135233},
	{"PASTEBIN", 8, 135234},
	{"MIMETIC", 7, 135235},
	{"ACUPUNCTURISTS", 14, 135236},
	{"CATSUIT", 7, 135237},
	{"COMPETI", 7, 135238},
	{"ZADD", 4, 135239},
	{"UBRU", 4, 135240},
	{"PSYT", 4, 135241},
	{"PLYK", 4, 135242},
	{"PHYN", 4, 135243},
	{"MRSU", 4, 135244},
	{"LWEV", 4, 135245},
	{"KROE", 4, 135246},
	{"IFVI", 4, 135247},
	{"GREJ", 4, 135248},
	{"GHKN", 4, 135249},
	{"EKHU", 4, 135250},
	{"EBBO", 4, 135251},
	{"DIFB", 4, 135252},
	{"HEMOCHROMATOSIS", 15, 135253},
	{"REINCARNATED", 12, 135254},
	{"BRUM", 4, 135255},
	{"CHITRA", 6, 135256},
	{"HELCOM", 6, 135257},
	{"ESTRIN", 6, 135258},
	{"VETOES", 6, 135259},
	{"PROVIDENCIALES", 14, 135260},
	{"DEPENDENCES", 11, 135261},
	{"MENSES", 6, 135262},
	{"BARWICK", 7, 135263},
	{"LIASON", 6, 135264},
	{"BARRELL", 7, 135265},
	{"AGANA", 5, 135266},
	{"STARDATE", 8, 135267},
	{"XOSOFT", 6, 135268},
	{"VISUALISER", 10, 135269},
	{"GIRLCAMS", 8, 135270},
	{"DAUBERT", 7, 135271},
	{"ALONGS", 6, 135272},
	{"COSTO", 5, 135273},
	{"XFAIL", 5, 135274},
	{"KATTEN", 6, 135275},
	{"PEROXISOME", 10, 135276},
	{"CIRCULON", 8, 135277},
	{"APOLLON", 7, 135278},
	{"SATCOM", 6, 135279},
	{"ARUNDHATI", 9, 135280},
	{"RUBBERY", 7, 135281},
	{"SEVERNA", 7, 135282},
	{"AZIONE", 6, 135283},
	{"SUBFOLDER", 9, 135284},
	{"STORMREACH", 10, 135285},
	{"ZILC", 4, 135286},
	{"RLAZ", 4, 135287},
	{"OBBC", 4, 135288},
	{"IGAG", 4, 135289},
	{"GORJ", 4, 135290},
	{"DKRO", 4, 135291},
	{"RELO", 4, 135292},
	{"TEMPERAMENTAL", 13, 135293},
	{"MIRABILIS", 9, 135294},
	{"DYSKINESIA", 10, 135295},
	{"DALLY", 5, 135296},
	{"COLLISIONAL", 11, 135297},
	{"NCVO", 4, 135298},
	{"FRATELLI", 8, 135299},
	{"SORAYA", 6, 135300},
	{"KENPO", 5, 135301},
	{"MALAYS", 6, 135302},
	{"SPOOKED", 7, 135303},
	{"NAUSEOUS", 8, 135304},
	{"STOMPIN", 7, 135305},
	{"MESODERM", 8, 135306},
	{"ATTRACTANT", 10, 135307},
	{"BRANDISHING", 11, 135308},
	{"CREWMAN", 7, 135309},
	{"LIQUORICE", 9, 135310},
	{"TAILPIPE", 8, 135311},
	{"YMIN", 4, 135312},
	{"WAGS", 4, 135313},
	{"PULLBACK", 8, 135314},
	{"PAHANG", 6, 135315},
	{"DRAGONBALLZ", 11, 135316},
	{"AINSLEY", 7, 135317},
	{"CHRONICLER", 10, 135318},
	{"TWIKIMETADATA", 13, 135319},
	{"OZTIVO", 6, 135320},
	{"ORBH", 4, 135321},
	{"DLUB", 4, 135322},
	{"CSOV", 4, 135323},
	{"CJOC", 4, 135324},
	{"RIBONUCLEIC", 11, 135325},
	{"SETTLOR", 7, 135326},
	{"PALEONTOLOGICAL", 15, 135327},
	{"ALLEM", 5, 135328},
	{"GATION", 6, 135329},
	{"CHARSETS", 8, 135330},
	{"AUBE", 4, 135331},
	{"DIAGRAMMING", 11, 135332},
	{"AIRBASE", 7, 135333},
	{"MCMILLEN", 8, 135334},
	{"POTENCIES", 9, 135335},
	{"MITHRIL", 7, 135336},
	{"STEPFAMILY", 10, 135337},
	{"COSC", 4, 135338},
	{"INFILTRATES", 11, 135339},
	{"BTREE", 5, 135340},
	{"HARTNELL", 8, 135341},
	{"SECUR", 5, 135342},
	{"DISPROVED", 9, 135343},
	{"MULTISPECTRAL", 13, 135344},
	{"DUNCRAFT", 8, 135345},
	{"JUSTINIAN", 9, 135346},
	{"IPLAY", 5, 135347},
	{"PHOTOALBUM", 10, 135348},
	{"BLACKHOLE", 9, 135349},
	{"KONINKLIJKE", 11, 135350},
	{"ENGINEERINGTALK", 15, 135351},
	{"CHARBONNEAU", 11, 135352},
	{"MIDGLEY", 7, 135353},
	{"WEBTOOLS", 8, 135354},
	{"DEBUTANTES", 10, 135355},
	{"FONTNAME", 8, 135356},
	{"XTYP", 4, 135357},
	{"XDRI", 4, 135358},
	{"WITP", 4, 135359},
	{"UENU", 4, 135360},
	{"OLUI", 4, 135361},
	{"MLYR", 4, 135362},
	{"KELF", 4, 135363},
	{"ERXI", 4, 135364},
	{"ECFR", 4, 135365},
	{"COMPLI", 6, 135366},
	{"SOLER", 5, 135367},
	{"SIMPL", 5, 135368},
	{"SCHORR", 6, 135369},
	{"MCNAMEE", 7, 135370},
	{"WHITENER", 8, 135371},
	{"PAPAI", 5, 135372},
	{"YOURISH", 7, 135373},
	{"RELASE", 6, 135374},
	{"CHANGCHUN", 9, 135375},
	{"LUTTE", 5, 135376},
	{"LOVESEATS", 9, 135377},
	{"STOICHIOMETRIC", 14, 135378},
	{"REGULAREXPRESSION", 17, 135379},
	{"DGC", 3, 135380},
	{"REYNALDO", 8, 135381},
	{"PONENTS", 7, 135382},
	{"STOURPORT", 9, 135383},
	{"WITMER", 6, 135384},
	{"DOBBIN", 6, 135385},
	{"VENTAS", 6, 135386},
	{"JUNICHIRO", 9, 135387},
	{"HENNY", 5, 135388},
	{"MAIM", 4, 135389},
	{"HOLYWELL", 8, 135390},
	{"REDBIRD", 7, 135391},
	{"WPOO", 4, 135392},
	{"WPIL", 4, 135393},
	{"TCWE", 4, 135394},
	{"SGAD", 4, 135395},
	{"RGMI", 4, 135396},
	{"RAGD", 4, 135397},
	{"NADL", 4, 135398},
	{"MMWI", 4, 135399},
	{"LBAO", 4, 135400},
	{"JUDS", 4, 135401},
	{"EXRI", 4, 135402},
	{"EMUE", 4, 135403},
	{"DHAF", 4, 135404},
	{"CVAN", 4, 135405},
	{"CGEA", 4, 135406},
	{"CDST", 4, 135407},
	{"BWOO", 4, 135408},
	{"TALMUDIC", 8, 135409},
	{"ALDOLASE", 8, 135410},
	{"SPEEDLIGHT", 10, 135411},
	{"COQUETTE", 8, 135412},
	{"OFER", 4, 135413},
	{"MENGE", 5, 135414},
	{"VERMOUTH", 8, 135415},
	{"FRAKTUR", 7, 135416},
	{"INNARDS", 7, 135417},
	{"COCHLEA", 7, 135418},
	{"VIDOE", 5, 135419},
	{"BACKGEMON", 9, 135420},
	{"IPIX", 4, 135421},
	{"ZAKARIA", 7, 135422},
	{"REMARKING", 9, 135423},
	{"AUDIOPHILES", 11, 135424},
	{"WUNDERLICH", 10, 135425},
	{"COBWEB", 6, 135426},
	{"COLIFORMS", 9, 135427},
	{"BUHLER", 6, 135428},
	{"FREGE", 5, 135429},
	{"PSPS", 4, 135430},
	{"BARKIN", 6, 135431},
	{"PISSEN", 6, 135432},
	{"LOCALIZING", 10, 135433},
	{"DIPL", 4, 135434},
	{"EXTREMO", 7, 135435},
	{"PRELOVED", 8, 135436},
	{"CIERA", 5, 135437},
	{"ZZYA", 4, 135438},
	{"ZOWA", 4, 135439},
	{"YGYM", 4, 135440},
	{"XGOL", 4, 135441},
	{"WPLO", 4, 135442},
	{"VODI", 4, 135443},
	{"UASP", 4, 135444},
	{"TOGB", 4, 135445},
	{"RUMK", 4, 135446},
	{"PIEP", 4, 135447},
	{"OKIW", 4, 135448},
	{"NFSY", 4, 135449},
	{"MIXC", 4, 135450},
	{"KBOD", 4, 135451},
	{"IMEQ", 4, 135452},
	{"GIPA", 4, 135453},
	{"EMCP", 4, 135454},
	{"EBNP", 4, 135455},
	{"CDEG", 4, 135456},
	{"MULTILATERALISM", 15, 135457},
	{"HEPWORTH", 8, 135458},
	{"SORIA", 5, 135459},
	{"WORLDWIDESHOW", 13, 135460},
	{"SPICA", 5, 135461},
	{"MARITA", 6, 135462},
	{"MASTERWORK", 10, 135463},
	{"SHOOP", 5, 135464},
	{"FOUAD", 5, 135465},
	{"CHAKRABORTY", 11, 135466},
	{"PUNCTUALLY", 10, 135467},
	{"PEPA", 4, 135468},
	{"GFF", 3, 135469},
	{"ACCURACIES", 10, 135470},
	{"SAFEBUY", 7, 135471},
	{"ANNOTATING", 10, 135472},
	{"KUANG", 5, 135473},
	{"ALEXI", 5, 135474},
	{"UNWILLINGLY", 11, 135475},
	{"SULEIMAN", 8, 135476},
	{"NARDI", 5, 135477},
	{"TWOP", 4, 135478},
	{"MTOOLS", 6, 135479},
	{"TEXTDATA", 8, 135480},
	{"DUCES", 5, 135481},
	{"CHESSINGTON", 11, 135482},
	{"UPSON", 5, 135483},
	{"INFLICTS", 8, 135484},
	{"CADEAU", 6, 135485},
	{"OPORTUNIDADES", 13, 135486},
	{"LOCMAN", 6, 135487},
	{"UNDOUBTED", 9, 135488},
	{"ONECLE", 6, 135489},
	{"BIOTICS", 7, 135490},
	{"SIMONSEN", 8, 135491},
	{"UYDO", 4, 135492},
	{"UMNH", 4, 135493},
	{"UAME", 4, 135494},
	{"KAIB", 4, 135495},
	{"IDSJ", 4, 135496},
	{"HDUC", 4, 135497},
	{"DWEO", 4, 135498},
	{"CYMC", 4, 135499},
	{"METALL", 6, 135500},
	{"TINGS", 5, 135501},
	{"RGC", 3, 135502},
	{"SPAZIO", 6, 135503},
	{"DATAMATION", 10, 135504},
	{"CHOLECYSTECTOMY", 15, 135505},
	{"ENTERICA", 8, 135506},
	{"LINKY", 5, 135507},
	{"URUMQI", 6, 135508},
	{"FORMLESS", 8, 135509},
	{"BEGLEITSERVICE", 14, 135510},
	{"CARNIVALE", 9, 135511},
	{"CLUBHOUSES", 10, 135512},
	{"BAYLESS", 7, 135513},
	{"AVOCET", 6, 135514},
	{"FRIDLEY", 7, 135515},
	{"ANTEPRIMA", 9, 135516},
	{"SHIPMATES", 9, 135517},
	{"FERRED", 6, 135518},
	{"VICB", 4, 135519},
	{"SZEW", 4, 135520},
	{"SLOL", 4, 135521},
	{"SIPU", 4, 135522},
	{"LYOM", 4, 135523},
	{"GRIA", 4, 135524},
	{"GPUP", 4, 135525},
	{"GNEF", 4, 135526},
	{"DRKA", 4, 135527},
	{"ENGLISCHE", 9, 135528},
	{"COBBS", 5, 135529},
	{"BAROLO", 6, 135530},
	{"CHANDON", 7, 135531},
	{"STARTTIME", 9, 135532},
	{"KARS", 4, 135533},
	{"GASSED", 6, 135534},
	{"REMAILER", 8, 135535},
	{"ATLANTICA", 9, 135536},
	{"PLAATS", 6, 135537},
	{"MARABOU", 7, 135538},
	{"INKANDSTUFF", 11, 135539},
	{"SHORN", 5, 135540},
	{"DOUBTFULLY", 10, 135541},
	{"NAUMANN", 7, 135542},
	{"CONSEQUAT", 9, 135543},
	{"WHORING", 7, 135544},
	{"ADJUSTABILITY", 13, 135545},
	{"GANOKSIN", 8, 135546},
	{"ACETAL", 6, 135547},
	{"POLAK", 5, 135548},
	{"TYPHUS", 6, 135549},
	{"RHWNG", 5, 135550},
	{"GASSING", 7, 135551},
	{"YMYO", 4, 135552},
	{"OUYE", 4, 135553},
	{"OUAV", 4, 135554},
	{"KOUS", 4, 135555},
	{"CNER", 4, 135556},
	{"CHYR", 4, 135557},
	{"AKEZ", 4, 135558},
	{"NOMEX", 5, 135559},
	{"RETICENT", 8, 135560},
	{"GOCKEL", 6, 135561},
	{"DABBLING", 8, 135562},
	{"WELTER", 6, 135563},
	{"FAGOR", 5, 135564},
	{"LANDE", 5, 135565},
	{"ZWU", 3, 135566},
	{"ZGD", 3, 135567},
	{"ZBV", 3, 135568},
	{"YKX", 3, 135569},
	{"XKX", 3, 135570},
	{"XJM", 3, 135571},
	{"XDZ", 3, 135572},
	{"WZG", 3, 135573},
	{"UVJ", 3, 135574},
	{"RQY", 3, 135575},
	{"QUG", 3, 135576},
	{"PJV", 3, 135577},
	{"MQD", 3, 135578},
	{"JYK", 3, 135579},
	{"CZZ", 3, 135580},
	{"BDQ", 3, 135581},
	{"DAYLIGHTING", 11, 135582},
	{"SONICBLUE", 9, 135583},
	{"SALTZMAN", 8, 135584},
	{"SVIZZERA", 8, 135585},
	{"FROMLIST", 8, 135586},
	{"DEPRECIABLE", 11, 135587},
	{"HICKOK", 6, 135588},
	{"TILSON", 6, 135589},
	{"NEGATING", 8, 135590},
	{"LOCHABER", 8, 135591},
	{"EXERTIONS", 9, 135592},
	{"MULTILAYERED", 12, 135593},
	{"GREENTREE", 9, 135594},
	{"KAPAMA", 6, 135595},
	{"INSEL", 5, 135596},
	{"POSTION", 7, 135597},
	{"EROTISCHE", 9, 135598},
	{"CASSELBERRY", 11, 135599},
	{"UMIF", 4, 135600},
	{"PTEV", 4, 135601},
	{"OBSG", 4, 135602},
	{"FPLY", 4, 135603},
	{"FFQU", 4, 135604},
	{"EDWY", 4, 135605},
	{"CULLIGAN", 8, 135606},
	{"BRUSHY", 6, 135607},
	{"WMAP", 4, 135608},
	{"HOPSCOTCH", 9, 135609},
	{"BEREAN", 6, 135610},
	{"PLOYMENT", 8, 135611},
	{"CHEAPASS", 8, 135612},
	{"VILAMOURA", 9, 135613},
	{"WALLBOARD", 9, 135614},
	{"SPRACHEN", 8, 135615},
	{"HARAM", 5, 135616},
	{"PITTSTON", 8, 135617},
	{"CLOW", 4, 135618},
	{"RENESAS", 7, 135619},
	{"HYPERNEWS", 9, 135620},
	{"JEBEL", 5, 135621},
	{"JOSIP", 5, 135622},
	{"ECKER", 5, 135623},
	{"PHILPOTT", 8, 135624},
	{"CREVE", 5, 135625},
	{"ORMSBY", 6, 135626},
	{"ICCS", 4, 135627},
	{"RETENTIVE", 9, 135628},
	{"CRJ", 3, 135629},
	{"SUPORT", 6, 135630},
	{"WFIT", 4, 135631},
	{"TJUA", 4, 135632},
	{"RKUT", 4, 135633},
	{"PCIR", 4, 135634},
	{"LTYV", 4, 135635},
	{"LIHU", 4, 135636},
	{"HEPW", 4, 135637},
	{"EZBA", 4, 135638},
	{"ECUF", 4, 135639},
	{"BYSR", 4, 135640},
	{"BRAP", 4, 135641},
	{"SULFITE", 7, 135642},
	{"NIKOLAS", 7, 135643},
	{"EMBARGOES", 9, 135644},
	{"MICROFORMATS", 12, 135645},
	{"GERDA", 5, 135646},
	{"RELAPSES", 8, 135647},
	{"GBIT", 4, 135648},
	{"VSWR", 4, 135649},
	{"FLEXIBILITIES", 13, 135650},
	{"KEYFRAME", 8, 135651},
	{"DELRIN", 6, 135652},
	{"BLOMBERG", 8, 135653},
	{"WELKER", 6, 135654},
	{"SPIRALLING", 10, 135655},
	{"INFTY", 5, 135656},
	{"PLODDING", 8, 135657},
	{"MCDOWALL", 8, 135658},
	{"SPEEDBOAT", 9, 135659},
	{"PBAR", 4, 135660},
	{"ORALS", 5, 135661},
	{"SZEGED", 6, 135662},
	{"JJM", 3, 135663},
	{"BOOKMOBILE", 10, 135664},
	{"LOVASTATIN", 10, 135665},
	{"BLOGSTREAM", 10, 135666},
	{"EKTRON", 6, 135667},
	{"PUDSEY", 6, 135668},
	{"ARCSOFT", 7, 135669},
	{"OAKLEIGH", 8, 135670},
	{"TALLAPOOSA", 10, 135671},
	{"ZWOLLE", 6, 135672},
	{"TOKYU", 5, 135673},
	{"SIDEWALLS", 9, 135674},
	{"DESERTER", 8, 135675},
	{"WOTD", 4, 135676},
	{"WBIE", 4, 135677},
	{"VYDR", 4, 135678},
	{"VDEV", 4, 135679},
	{"UTZS", 4, 135680},
	{"UIDB", 4, 135681},
	{"TPMN", 4, 135682},
	{"PCTO", 4, 135683},
	{"OXYM", 4, 135684},
	{"OLSJ", 4, 135685},
	{"OLMY", 4, 135686},
	{"NDBP", 4, 135687},
	{"NCAW", 4, 135688},
	{"IKBE", 4, 135689},
	{"EYOK", 4, 135690},
	{"ESWU", 4, 135691},
	{"EOMB", 4, 135692},
	{"EMJA", 4, 135693},
	{"ACUD", 4, 135694},
	{"EXUDE", 5, 135695},
	{"RENDING", 7, 135696},
	{"BALAKRISHNAN", 12, 135697},
	{"POLYPHENOLS", 11, 135698},
	{"REALIZABLE", 10, 135699},
	{"HOUSATONIC", 10, 135700},
	{"GAILLARD", 8, 135701},
	{"TRASHCAN", 8, 135702},
	{"TKGATE", 6, 135703},
	{"STOMATITIS", 10, 135704},
	{"CONCOMITANTLY", 13, 135705},
	{"CONSIGN", 7, 135706},
	{"HOMESTEADING", 12, 135707},
	{"MANTLES", 7, 135708},
	{"NEATNESS", 8, 135709},
	{"ADORNMENTS", 10, 135710},
	{"DRAMATICS", 9, 135711},
	{"CREATEOBJECT", 12, 135712},
	{"XFACES", 6, 135713},
	{"RUPPERT", 7, 135714},
	{"VALUER", 6, 135715},
	{"BRITANNIC", 9, 135716},
	{"PERMITTEES", 10, 135717},
	{"JOHNSONVILLE", 12, 135718},
	{"LUTAR", 5, 135719},
	{"MCV", 3, 135720},
	{"GROSBEAK", 8, 135721},
	{"BECHER", 6, 135722},
	{"UNBELIEVER", 10, 135723},
	{"KITCHENETTES", 12, 135724},
	{"ULLAMCORPER", 11, 135725},
	{"RMQ", 3, 135726},
	{"XINHUANET", 9, 135727},
	{"YSMC", 4, 135728},
	{"YEGY", 4, 135729},
	{"WOIL", 4, 135730},
	{"VICF", 4, 135731},
	{"SYFR", 4, 135732},
	{"RLPA", 4, 135733},
	{"OABB", 4, 135734},
	{"NHLD", 4, 135735},
	{"LOAV", 4, 135736},
	{"LIMY", 4, 135737},
	{"KWAG", 4, 135738},
	{"ICRY", 4, 135739},
	{"PARADING", 8, 135740},
	{"CRABMEAT", 8, 135741},
	{"BLUEWALKER", 10, 135742},
	{"AMERIPLAN", 9, 135743},
	{"GUERILLAS", 9, 135744},
	{"BRECCIA", 7, 135745},
	{"FAUSTUS", 7, 135746},
	{"RELAUNCHED", 10, 135747},
	{"CURIOUSER", 9, 135748},
	{"SHOWGIRL", 8, 135749},
	{"VERSAR", 6, 135750},
	{"FLUTICASONE", 11, 135751},
	{"BACKHOUSE", 9, 135752},
	{"BIOGEN", 6, 135753},
	{"GODLEY", 6, 135754},
	{"CRIMESTOPPERS", 13, 135755},
	{"PRIORITISING", 12, 135756},
	{"KIARA", 5, 135757},
	{"DECOMPOSES", 10, 135758},
	{"VICO", 4, 135759},
	{"ROSELYN", 7, 135760},
	{"SPAZ", 4, 135761},
	{"UNCONVINCED", 11, 135762},
	{"DEYOUNG", 7, 135763},
	{"SUPREMO", 7, 135764},
	{"HULTON", 6, 135765},
	{"CAMEROUN", 8, 135766},
	{"QUOC", 4, 135767},
	{"QUANTIFIES", 10, 135768},
	{"HYPERPARATHYROIDISM", 19, 135769},
	{"FILIBUSTERS", 11, 135770},
	{"QUICKBASE", 9, 135771},
	{"FUSSBALL", 8, 135772},
	{"FUGU", 4, 135773},
	{"PROCESSOBJECT", 13, 135774},
	{"MRV", 3, 135775},
	{"ZAPPED", 6, 135776},
	{"CELESTIA", 8, 135777},
	{"HONKING", 7, 135778},
	{"DBLE", 4, 135779},
	{"VETL", 4, 135780},
	{"TZVA", 4, 135781},
	{"SRIR", 4, 135782},
	{"RSJI", 4, 135783},
	{"RCAK", 4, 135784},
	{"PTSL", 4, 135785},
	{"OXPA", 4, 135786},
	{"ODTY", 4, 135787},
	{"NCUE", 4, 135788},
	{"MFOX", 4, 135789},
	{"LUPG", 4, 135790},
	{"DEXG", 4, 135791},
	{"MOVIS", 5, 135792},
	{"CLONTARF", 8, 135793},
	{"LAUDANSKI", 9, 135794},
	{"EXPERIMENTERS", 13, 135795},
	{"GAMIN", 5, 135796},
	{"CRAZIES", 7, 135797},
	{"CONFEDERATED", 12, 135798},
	{"SETLINEWIDTH", 12, 135799},
	{"LAYCOCK", 7, 135800},
	{"SURFS", 5, 135801},
	{"MISHIMA", 7, 135802},
	{"GALI", 4, 135803},
	{"AXISYMMETRIC", 12, 135804},
	{"JOICO", 5, 135805},
	{"GAPPING", 7, 135806},
	{"WALKERTON", 9, 135807},
	{"JIGGY", 5, 135808},
	{"JUVENTUD", 8, 135809},
	{"RUTHERGLEN", 10, 135810},
	{"MAANDAG", 7, 135811},
	{"EDITTABLEPLUGIN", 15, 135812},
	{"BUENAVENTURA", 12, 135813},
	{"DSELECT", 7, 135814},
	{"ALDACTONE", 9, 135815},
	{"LUME", 4, 135816},
	{"SPELLCHECKER", 12, 135817},
	{"QUIREMENTS", 10, 135818},
	{"PSEUDOSCIENCE", 13, 135819},
	{"NEUROGENIC", 10, 135820},
	{"CIBOOKMARK", 10, 135821},
	{"SOFTSPOTS", 9, 135822},
	{"CRYPTOPSY", 9, 135823},
	{"PROPSMART", 9, 135824},
	{"ZINGER", 6, 135825},
	{"CAHOOT", 6, 135826},
	{"WORKLIFE", 8, 135827},
	{"NESDIS", 6, 135828},
	{"SELMAN", 6, 135829},
	{"CMDB", 4, 135830},
	{"CORDER", 6, 135831},
	{"YNAK", 4, 135832},
	{"SOMW", 4, 135833},
	{"SDOF", 4, 135834},
	{"ESDW", 4, 135835},
	{"ERUW", 4, 135836},
	{"ECYS", 4, 135837},
	{"CZAN", 4, 135838},
	{"CREK", 4, 135839},
	{"BEIW", 4, 135840},
	{"BRAINWASH", 9, 135841},
	{"SPOSI", 5, 135842},
	{"CANDIDS", 7, 135843},
	{"FACTFILE", 8, 135844},
	{"FABRICANTS", 10, 135845},
	{"OSWALDO", 7, 135846},
	{"REINSURERS", 10, 135847},
	{"MULTIETHNIC", 11, 135848},
	{"LANDA", 5, 135849},
	{"THEOCRATIC", 10, 135850},
	{"DRINKABLE", 9, 135851},
	{"CORMORANTS", 10, 135852},
	{"AMBLE", 5, 135853},
	{"OVERWHELMS", 10, 135854},
	{"AUTOPSIES", 9, 135855},
	{"ASCP", 4, 135856},
	{"PLUMMETING", 10, 135857},
	{"HOPP", 4, 135858},
	{"PEJORATIVE", 10, 135859},
	{"FIVER", 5, 135860},
	{"FAVA", 4, 135861},
	{"BUSHEY", 6, 135862},
	{"NICOLL", 6, 135863},
	{"HALIDES", 7, 135864},
	{"EMBANKMENTS", 11, 135865},
	{"FFORDD", 6, 135866},
	{"PURGES", 6, 135867},
	{"CHUNKED", 7, 135868},
	{"YNAU", 4, 135869},
	{"WBOX", 4, 135870},
	{"SKEM", 4, 135871},
	{"PYLA", 4, 135872},
	{"MCRY", 4, 135873},
	{"HMYA", 4, 135874},
	{"GIGU", 4, 135875},
	{"GGYO", 4, 135876},
	{"EPBS", 4, 135877},
	{"CKEO", 4, 135878},
	{"QUANTO", 6, 135879},
	{"IFINDEX", 7, 135880},
	{"METAMORA", 8, 135881},
	{"UPTEMPO", 7, 135882},
	{"CALLOSUM", 8, 135883},
	{"HALVING", 7, 135884},
	{"SOWERS", 6, 135885},
	{"PDZ", 3, 135886},
	{"METATALK", 8, 135887},
	{"THOMPSONS", 9, 135888},
	{"NETTWERK", 8, 135889},
	{"AMITE", 5, 135890},
	{"ENGELSK", 7, 135891},
	{"AURUM", 5, 135892},
	{"SPECULATOR", 10, 135893},
	{"SUCESSFUL", 9, 135894},
	{"OAKFIELD", 8, 135895},
	{"IMPATIENS", 9, 135896},
	{"PANICKING", 9, 135897},
	{"MINTEL", 6, 135898},
	{"BIPHENYL", 8, 135899},
	{"CONFECTION", 10, 135900},
	{"DOCUTILS", 8, 135901},
	{"APPARANTLY", 10, 135902},
	{"QBASIC", 6, 135903},
	{"THINGIES", 8, 135904},
	{"STIRI", 5, 135905},
	{"GROGGY", 6, 135906},
	{"VALVULAR", 8, 135907},
	{"YUGL", 4, 135908},
	{"VRIN", 4, 135909},
	{"UOWA", 4, 135910},
	{"PJOI", 4, 135911},
	{"PITG", 4, 135912},
	{"OKSY", 4, 135913},
	{"MOMD", 4, 135914},
	{"LOFQ", 4, 135915},
	{"LMNE", 4, 135916},
	{"FLYU", 4, 135917},
	{"ACCOUNTABILITIES", 16, 135918},
	{"DANDER", 6, 135919},
	{"MADMEN", 6, 135920},
	{"LISTLESS", 8, 135921},
	{"MORGANE", 7, 135922},
	{"SHELVE", 6, 135923},
	{"KOPEN", 5, 135924},
	{"WHEATEN", 7, 135925},
	{"FREEDB", 6, 135926},
	{"COURTSIDE", 9, 135927},
	{"ARUGULA", 7, 135928},
	{"REMUNERATED", 11, 135929},
	{"DRYCLEANING", 11, 135930},
	{"MRU", 3, 135931},
	{"COPPERAS", 8, 135932},
	{"CATIE", 5, 135933},
	{"VADIS", 5, 135934},
	{"KIRALAMA", 8, 135935},
	{"PAPANDREOU", 10, 135936},
	{"LUMBERJACKS", 11, 135937},
	{"HUDGINS", 7, 135938},
	{"DEPRECATING", 11, 135939},
	{"SHAND", 5, 135940},
	{"EQUALISATION", 12, 135941},
	{"POOPER", 6, 135942},
	{"STUNNEL", 7, 135943},
	{"UKOS", 4, 135944},
	{"SMEV", 4, 135945},
	{"OKAK", 4, 135946},
	{"OFPN", 4, 135947},
	{"NYEP", 4, 135948},
	{"LCAG", 4, 135949},
	{"GVOW", 4, 135950},
	{"FYBE", 4, 135951},
	{"DAEW", 4, 135952},
	{"CSMU", 4, 135953},
	{"CORH", 4, 135954},
	{"CIFO", 4, 135955},
	{"BAWE", 4, 135956},
	{"SUFF", 4, 135957},
	{"PRAVEEN", 7, 135958},
	{"INTERNATI", 9, 135959},
	{"CONTACTCONTACT", 14, 135960},
	{"PROFESSORIAL", 12, 135961},
	{"MENNONITES", 10, 135962},
	{"CERAMIDE", 8, 135963},
	{"INEEL", 5, 135964},
	{"DUCAL", 5, 135965},
	{"ENDOR", 5, 135966},
	{"DYADIC", 6, 135967},
	{"FASSA", 5, 135968},
	{"MUSEVENI", 8, 135969},
	{"DOWNCAST", 8, 135970},
	{"ALPER", 5, 135971},
	{"EIREANN", 7, 135972},
	{"MUTI", 4, 135973},
	{"ADATA", 5, 135974},
	{"HYPERTHREADING", 14, 135975},
	{"BOURDIEU", 8, 135976},
	{"BLOODSTONE", 10, 135977},
	{"SYLVESTRE", 9, 135978},
	{"LENNARD", 7, 135979},
	{"EDLUG", 5, 135980},
	{"WORLDCHANGING", 13, 135981},
	{"COBA", 4, 135982},
	{"DIRECTI", 7, 135983},
	{"ZAFA", 4, 135984},
	{"YRSA", 4, 135985},
	{"TKAY", 4, 135986},
	{"RIOK", 4, 135987},
	{"IYUA", 4, 135988},
	{"GUSL", 4, 135989},
	{"GICJ", 4, 135990},
	{"DIGH", 4, 135991},
	{"AJAK", 4, 135992},
	{"AAUD", 4, 135993},
	{"ABBOX", 5, 135994},
	{"SPOLETO", 7, 135995},
	{"COMPEX", 6, 135996},
	{"DECAPITATION", 12, 135997},
	{"CHAOSIUM", 8, 135998},
	{"EPOXIDE", 7, 135999},
	{"TAVERNIER", 9, 136000},
	{"RAINHAM", 7, 136001},
	{"GARSTANG", 8, 136002},
	{"TEDIUM", 6, 136003},
	{"BOLDEN", 6, 136004},
	{"MINETA", 6, 136005},
	{"ORAM", 4, 136006},
	{"ARCHEOLOGISTS", 13, 136007},
	{"IMPLEMEN", 8, 136008},
	{"SHORTLAND", 9, 136009},
	{"MEDINDIA", 8, 136010},
	{"WRENTHAM", 8, 136011},
	{"SEAMANSHIP", 10, 136012},
	{"ITRACONAZOLE", 12, 136013},
	{"ICSC", 4, 136014},
	{"TRIBBLE", 7, 136015},
	{"BADDEST", 7, 136016},
	{"SDSDB", 5, 136017},
	{"VPOPMAIL", 8, 136018},
	{"ORTHOGONALITY", 13, 136019},
	{"SIGNON", 6, 136020},
	{"HAIRLOSS", 8, 136021},
	{"GASCOIGNE", 9, 136022},
	{"POMEGRANATES", 12, 136023},
	{"BOUTIN", 6, 136024},
	{"DEJAN", 5, 136025},
	{"IMEX", 4, 136026},
	{"NAYSAYERS", 9, 136027},
	{"BONDSMAN", 8, 136028},
	{"REQD", 4, 136029},
	{"MALLING", 7, 136030},
	{"UEAU", 4, 136031},
	{"TDUA", 4, 136032},
	{"RMPU", 4, 136033},
	{"RDIH", 4, 136034},
	{"PAOR", 4, 136035},
	{"OXJE", 4, 136036},
	{"OFXA", 4, 136037},
	{"MBBE", 4, 136038},
	{"LFSB", 4, 136039},
	{"FGUR", 4, 136040},
	{"EGDR", 4, 136041},
	{"CYJO", 4, 136042},
	{"COPW", 4, 136043},
	{"BSAB", 4, 136044},
	{"ABJE", 4, 136045},
	{"LYNNFIELD", 9, 136046},
	{"SUNSPREE", 8, 136047},
	{"SPORTIVE", 8, 136048},
	{"HEWSON", 6, 136049},
	{"HARMONIUM", 9, 136050},
	{"ISTREAM", 7, 136051},
	{"TROMA", 5, 136052},
	{"COLDSTREAM", 10, 136053},
	{"MAULANA", 7, 136054},
	{"YAMBOL", 6, 136055},
	{"DATINGBUZZ", 10, 136056},
	{"MIFFED", 6, 136057},
	{"RAMPED", 6, 136058},
	{"WATCHMAKING", 11, 136059},
	{"LUPAH", 5, 136060},
	{"ONLIE", 5, 136061},
	{"SIRDAR", 6, 136062},
	{"LASAGNE", 7, 136063},
	{"GROB", 4, 136064},
	{"STILTON", 7, 136065},
	{"NEWSROOMS", 9, 136066},
	{"RATIONALIZING", 13, 136067},
	{"EJAY", 4, 136068},
	{"TURAN", 5, 136069},
	{"PERRAULT", 8, 136070},
	{"TELEFONIE", 9, 136071},
	{"UOFT", 4, 136072},
	{"THORDIS", 7, 136073},
	{"BKSVOL", 6, 136074},
	{"WIREFLY", 7, 136075},
	{"AIRGUNS", 7, 136076},
	{"OBERG", 5, 136077},
	{"LATRINE", 7, 136078},
	{"FLYBACK", 7, 136079},
	{"HAUG", 4, 136080},
	{"COMUNIDADES", 11, 136081},
	{"GIOIELLI", 8, 136082},
	{"PETROVA", 7, 136083},
	{"KNIFES", 6, 136084},
	{"UCUR", 4, 136085},
	{"SZAM", 4, 136086},
	{"RLIU", 4, 136087},
	{"OIMG", 4, 136088},
	{"MULH", 4, 136089},
	{"LEZE", 4, 136090},
	{"IGEW", 4, 136091},
	{"GOYL", 4, 136092},
	{"GIMB", 4, 136093},
	{"AGOZ", 4, 136094},
	{"BLAKESLEE", 9, 136095},
	{"UNDESERVED", 10, 136096},
	{"UNEXPLAINABLE", 13, 136097},
	{"CHINASTAR", 9, 136098},
	{"SHADEGG", 7, 136099},
	{"TWEEZER", 7, 136100},
	{"WASHROOMS", 9, 136101},
	{"MULTIPROCESSORS", 15, 136102},
	{"WIDOWMAKER", 10, 136103},
	{"GULPING", 7, 136104},
	{"AUDIOTAPES", 10, 136105},
	{"BEELINE", 7, 136106},
	{"IMPLICATES", 10, 136107},
	{"AUTOART", 7, 136108},
	{"PRINCIPALITIES", 14, 136109},
	{"AIDER", 5, 136110},
	{"CUERVO", 6, 136111},
	{"DBMAIL", 6, 136112},
	{"EXCELLING", 9, 136113},
	{"GAMETES", 7, 136114},
	{"ASHLYN", 6, 136115},
	{"OLDBURY", 7, 136116},
	{"MISADVENTURE", 12, 136117},
	{"LYTE", 4, 136118},
	{"ADPT", 4, 136119},
	{"ZWIN", 4, 136120},
	{"SCWH", 4, 136121},
	{"RBWI", 4, 136122},
	{"PECE", 4, 136123},
	{"MCEW", 4, 136124},
	{"KCER", 4, 136125},
	{"IRRH", 4, 136126},
	{"IKLE", 4, 136127},
	{"DUOT", 4, 136128},
	{"AXAR", 4, 136129},
	{"GGCGG", 5, 136130},
	{"ANTITERRORISM", 13, 136131},
	{"JUX", 3, 136132},
	{"ANGLEBOOKS", 10, 136133},
	{"TEKSYSTEMS", 10, 136134},
	{"SUBHEAD", 7, 136135},
	{"MEINER", 6, 136136},
	{"ROND", 4, 136137},
	{"LAMBO", 5, 136138},
	{"KEWEENAW", 8, 136139},
	{"ABOVEMENTIONED", 14, 136140},
	{"DRAMATISTS", 10, 136141},
	{"MILITAR", 7, 136142},
	{"CARBOXYLATE", 11, 136143},
	{"NASCITA", 7, 136144},
	{"FWC", 3, 136145},
	{"WHATLEY", 7, 136146},
	{"CONGRES", 7, 136147},
	{"SEQUOYAH", 8, 136148},
	{"SERVILE", 7, 136149},
	{"LEGIONNAIRES", 12, 136150},
	{"NETINET", 7, 136151},
	{"PACIFISTS", 9, 136152},
	{"PINTAIL", 7, 136153},
	{"NTUM", 4, 136154},
	{"KREFELD", 7, 136155},
	{"SAARINEN", 8, 136156},
	{"XTOG", 4, 136157},
	{"WOAU", 4, 136158},
	{"WESB", 4, 136159},
	{"OYSV", 4, 136160},
	{"OXRA", 4, 136161},
	{"KDOL", 4, 136162},
	{"KAYH", 4, 136163},
	{"IPIF", 4, 136164},
	{"HEVW", 4, 136165},
	{"GYHO", 4, 136166},
	{"GYFA", 4, 136167},
	{"AZZU", 4, 136168},
	{"BLOODIED", 8, 136169},
	{"KUDU", 4, 136170},
	{"CAMPBELLSVILLE", 14, 136171},
	{"MERLYN", 6, 136172},
	{"ANACOSTIA", 9, 136173},
	{"WEATHERSTRIPPING", 16, 136174},
	{"BENZOIC", 7, 136175},
	{"APER", 4, 136176},
	{"HOMESITES", 9, 136177},
	{"FRIEDLAND", 9, 136178},
	{"FAMILIARIS", 10, 136179},
	{"CHICKPEA", 8, 136180},
	{"BFC", 3, 136181},
	{"CUJO", 4, 136182},
	{"RICKETY", 7, 136183},
	{"CALLENDER", 9, 136184},
	{"ENCHANTMENTS", 12, 136185},
	{"CALIB", 5, 136186},
	{"ANDHERI", 7, 136187},
	{"FUORI", 5, 136188},
	{"GLOBALIZING", 11, 136189},
	{"PUPULAR", 7, 136190},
	{"PFLEGE", 6, 136191},
	{"SECONDO", 7, 136192},
	{"MOSTAR", 6, 136193},
	{"LYELL", 5, 136194},
	{"CREB", 4, 136195},
	{"DUCKETT", 7, 136196},
	{"LAGGARDS", 8, 136197},
	{"PPOS", 4, 136198},
	{"MARZIPAN", 8, 136199},
	{"FIGURA", 6, 136200},
	{"REWRITER", 8, 136201},
	{"GLYCOSYLATED", 12, 136202},
	{"KNOWLEGE", 8, 136203},
	{"UNSELECTED", 10, 136204},
	{"PANZERS", 7, 136205},
	{"NONWOVENS", 9, 136206},
	{"ABDUR", 5, 136207},
	{"CASTRATED", 9, 136208},
	{"VYHE", 4, 136209},
	{"UCDA", 4, 136210},
	{"SYCR", 4, 136211},
	{"SHYL", 4, 136212},
	{"OLKP", 4, 136213},
	{"EFGO", 4, 136214},
	{"EASTWEST", 8, 136215},
	{"MYFRAPPR", 8, 136216},
	{"HAMED", 5, 136217},
	{"BRACKLEY", 8, 136218},
	{"NAIDOO", 6, 136219},
	{"WOODCHUCK", 9, 136220},
	{"DATUK", 5, 136221},
	{"GUIDELIVE", 9, 136222},
	{"HOULE", 5, 136223},
	{"PROSAIC", 7, 136224},
	{"INDEPENDIENTE", 13, 136225},
	{"AGNULA", 6, 136226},
	{"NIGHTSTANDS", 11, 136227},
	{"TERRILL", 7, 136228},
	{"ORIGINALES", 10, 136229},
	{"DUBH", 4, 136230},
	{"BULLMASTIFF", 11, 136231},
	{"KILTER", 6, 136232},
	{"DIADEM", 6, 136233},
	{"TECCHANNEL", 10, 136234},
	{"SEAWIFS", 7, 136235},
	{"OFRECE", 6, 136236},
	{"BEDEUTUNG", 9, 136237},
	{"SORKIN", 6, 136238},
	{"TUMWATER", 8, 136239},
	{"CYBEX", 5, 136240},
	{"ANOXIC", 6, 136241},
	{"INFILTRATOR", 11, 136242},
	{"SINCEREST", 9, 136243},
	{"BHAWAN", 6, 136244},
	{"SPANKIN", 7, 136245},
	{"CAVALO", 6, 136246},
	{"SKINNYCORP", 10, 136247},
	{"SAGEN", 5, 136248},
	{"ANSETT", 6, 136249},
	{"YNOU", 4, 136250},
	{"ULSF", 4, 136251},
	{"LALF", 4, 136252},
	{"LAHC", 4, 136253},
	{"FTYW", 4, 136254},
	{"EMCU", 4, 136255},
	{"ELPJ", 4, 136256},
	{"BEDY", 4, 136257},
	{"SPEEDMASTER", 11, 136258},
	{"VISAYAS", 7, 136259},
	{"GUU", 3, 136260},
	{"OKEY", 4, 136261},
	{"SYSOPT", 6, 136262},
	{"NPOWER", 6, 136263},
	{"FLORY", 5, 136264},
	{"TITTLE", 6, 136265},
	{"OBSESS", 6, 136266},
	{"SPAC", 4, 136267},
	{"HOMEWORKS", 9, 136268},
	{"IMPRUDENT", 9, 136269},
	{"KEER", 4, 136270},
	{"CATAPULTS", 9, 136271},
	{"CAMPI", 5, 136272},
	{"TROU", 4, 136273},
	{"FEUCHTE", 7, 136274},
	{"NANNIE", 6, 136275},
	{"BLUEYONDER", 10, 136276},
	{"COLECCION", 9, 136277},
	{"BIMODAL", 7, 136278},
	{"RESTYLANE", 9, 136279},
	{"MUZYKA", 6, 136280},
	{"TAXIWAY", 7, 136281},
	{"EDGEWORTH", 9, 136282},
	{"DJUMA", 5, 136283},
	{"ZLAT", 4, 136284},
	{"YCBS", 4, 136285},
	{"WWCA", 4, 136286},
	{"UEHR", 4, 136287},
	{"TPIZ", 4, 136288},
	{"TAML", 4, 136289},
	{"LEGF", 4, 136290},
	{"JAYT", 4, 136291},
	{"HCUB", 4, 136292},
	{"DYKA", 4, 136293},
	{"CFEL", 4, 136294},
	{"THURLOW", 7, 136295},
	{"GESTURING", 9, 136296},
	{"VLIET", 5, 136297},
	{"CATRIONA", 8, 136298},
	{"DELIBERATED", 11, 136299},
	{"MUSSETTE", 8, 136300},
	{"MEGASITIO", 9, 136301},
	{"MCCLUNG", 7, 136302},
	{"FRASCATI", 8, 136303},
	{"SHARYN", 6, 136304},
	{"ALOU", 4, 136305},
	{"SNUBBED", 7, 136306},
	{"SUFFOCATE", 9, 136307},
	{"HOSPITALISED", 12, 136308},
	{"DEHYDRATOR", 10, 136309},
	{"POLYFONISKE", 11, 136310},
	{"PSYCHONAUTS", 11, 136311},
	{"EVRY", 4, 136312},
	{"HUMERUS", 7, 136313},
	{"WOODGATE", 8, 136314},
	{"CSUN", 4, 136315},
	{"MOMSON", 6, 136316},
	{"CLATSOP", 7, 136317},
	{"FRIESIAN", 8, 136318},
	{"SATHER", 6, 136319},
	{"PERETTI", 7, 136320},
	{"SEAFORTH", 8, 136321},
	{"APPLAUDING", 10, 136322},
	{"EPITHETS", 8, 136323},
	{"INTERVENORS", 11, 136324},
	{"JOWOOD", 6, 136325},
	{"POLING", 6, 136326},
	{"CHORAM", 6, 136327},
	{"MCDAVID", 7, 136328},
	{"SPORULATION", 11, 136329},
	{"XCAS", 4, 136330},
	{"TMYJ", 4, 136331},
	{"TECY", 4, 136332},
	{"SIFD", 4, 136333},
	{"KYLL", 4, 136334},
	{"KEEY", 4, 136335},
	{"HOBV", 4, 136336},
	{"HBID", 4, 136337},
	{"FIBU", 4, 136338},
	{"EMHU", 4, 136339},
	{"DUFO", 4, 136340},
	{"BLYY", 4, 136341},
	{"AOYU", 4, 136342},
	{"AFWH", 4, 136343},
	{"UNDERSIZED", 10, 136344},
	{"FLOUNDERING", 11, 136345},
	{"HIRSCHFELD", 10, 136346},
	{"BGC", 3, 136347},
	{"LCDR", 4, 136348},
	{"PRESERVER", 9, 136349},
	{"BARGIN", 6, 136350},
	{"KNOWEST", 7, 136351},
	{"SNIFFERS", 8, 136352},
	{"LOREENA", 7, 136353},
	{"BHARATI", 7, 136354},
	{"REVOLTS", 7, 136355},
	{"GOLIAD", 6, 136356},
	{"INCD", 4, 136357},
	{"FLATLAND", 8, 136358},
	{"ESPY", 4, 136359},
	{"BOURRET", 7, 136360},
	{"FRES", 4, 136361},
	{"FRAPPRGROUPS", 12, 136362},
	{"MACAQUES", 8, 136363},
	{"SUBP", 4, 136364},
	{"HOBBYHURE", 9, 136365},
	{"FRAPPRPHOTOS", 12, 136366},
	{"MORAIRA", 7, 136367},
	{"SHULER", 6, 136368},
	{"RUMS", 4, 136369},
	{"BELINEA", 7, 136370},
	{"BALLIN", 6, 136371},
	{"LEMBRETES", 9, 136372},
	{"VAYA", 4, 136373},
	{"YUSP", 4, 136374},
	{"WDIA", 4, 136375},
	{"VROS", 4, 136376},
	{"REZR", 4, 136377},
	{"PGTH", 4, 136378},
	{"OFHP", 4, 136379},
	{"LRAB", 4, 136380},
	{"LKPO", 4, 136381},
	{"GUGL", 4, 136382},
	{"GLDQ", 4, 136383},
	{"PEDY", 4, 136384},
	{"GOLDWING", 8, 136385},
	{"LAGWAGON", 8, 136386},
	{"BENVENUTO", 9, 136387},
	{"STEPDAUGHTER", 12, 136388},
	{"BERINGER", 8, 136389},
	{"MAYE", 4, 136390},
	{"DEREN", 5, 136391},
	{"HALLOW", 6, 136392},
	{"WHARVES", 7, 136393},
	{"CINELLI", 7, 136394},
	{"GANHARAM", 8, 136395},
	{"SIGLER", 6, 136396},
	{"BJARNE", 6, 136397},
	{"SPRI", 4, 136398},
	{"SWRCB", 5, 136399},
	{"KITSUNE", 7, 136400},
	{"TUXES", 5, 136401},
	{"BORODIN", 7, 136402},
	{"SETSIZE", 7, 136403},
	{"TOMEI", 5, 136404},
	{"KUNDE", 5, 136405},
	{"CANVASSED", 9, 136406},
	{"SKYLER", 6, 136407},
	{"BACI", 4, 136408},
	{"QUATERNION", 10, 136409},
	{"LABWARE", 7, 136410},
	{"PRZEZ", 5, 136411},
	{"LIGONIER", 8, 136412},
	{"STANDOUTS", 9, 136413},
	{"WRAPUP", 6, 136414},
	{"WGRI", 4, 136415},
	{"URVY", 4, 136416},
	{"OFLB", 4, 136417},
	{"IMVO", 4, 136418},
	{"GUDA", 4, 136419},
	{"GFOS", 4, 136420},
	{"FSFA", 4, 136421},
	{"CPEA", 4, 136422},
	{"ALCD", 4, 136423},
	{"VENTI", 5, 136424},
	{"LIVESTRIP", 9, 136425},
	{"JUDICATA", 8, 136426},
	{"BIOSENSOR", 9, 136427},
	{"UNMITIGATED", 11, 136428},
	{"GOERING", 7, 136429},
	{"GARCIAPARRA", 11, 136430},
	{"HOMEBOY", 7, 136431},
	{"PMM", 3, 136432},
	{"ZULULAND", 8, 136433},
	{"MOSSMAN", 7, 136434},
	{"TEXTES", 6, 136435},
	{"ORIENTALISM", 11, 136436},
	{"SZUKAJ", 6, 136437},
	{"DEKE", 4, 136438},
	{"UNPLAYED", 8, 136439},
	{"MODIFICA", 8, 136440},
	{"CLASSICA", 8, 136441},
	{"MINC", 4, 136442},
	{"DRAVEN", 6, 136443},
	{"SCREENPRINTING", 14, 136444},
	{"WHINED", 6, 136445},
	{"SASHES", 6, 136446},
	{"WAKULLA", 7, 136447},
	{"RESTENOSIS", 10, 136448},
	{"RIJEKA", 6, 136449},
	{"ISELIN", 6, 136450},
	{"RAHWAY", 6, 136451},
	{"FRL", 3, 136452},
	{"ABBREVIATE", 10, 136453},
	{"PICTORIALS", 10, 136454},
	{"NOTIFYTOPIC", 11, 136455},
	{"DATEX", 5, 136456},
	{"SABOT", 5, 136457},
	{"PERPETUATES", 11, 136458},
	{"IEPM", 4, 136459},
	{"HAMAMATSU", 9, 136460},
	{"AUBUCHON", 8, 136461},
	{"CEASAR", 6, 136462},
	{"MATRIARCH", 9, 136463},
	{"ASSAIL", 6, 136464},
	{"VYEQ", 4, 136465},
	{"SKSY", 4, 136466},
	{"RMOA", 4, 136467},
	{"OLAJ", 4, 136468},
	{"MRIO", 4, 136469},
	{"FGIN", 4, 136470},
	{"BSBR", 4, 136471},
	{"BLAIRGOWRIE", 11, 136472},
	{"KABA", 4, 136473},
	{"HEIKE", 5, 136474},
	{"FLIRTATION", 10, 136475},
	{"SAUGATUCK", 9, 136476},
	{"RECONSTITUTE", 12, 136477},
	{"WARBIRDS", 8, 136478},
	{"UNTERHALTUNG", 12, 136479},
	{"PICSFREE", 8, 136480},
	{"KERSTEN", 7, 136481},
	{"TENSED", 6, 136482},
	{"LAFITTE", 7, 136483},
	{"BARBEDOR", 8, 136484},
	{"STRIATAL", 8, 136485},
	{"KCR", 3, 136486},
	{"FLOORSTANDING", 13, 136487},
	{"KAPRUN", 6, 136488},
	{"MADUROS", 7, 136489},
	{"VICOPROFEN", 10, 136490},
	{"ANDROSCOGGIN", 12, 136491},
	{"METROPOL", 8, 136492},
	{"COURTIERS", 9, 136493},
	{"ANKARO", 6, 136494},
	{"MCCLUSKEY", 9, 136495},
	{"PLEXI", 5, 136496},
	{"PIGGOTT", 7, 136497},
	{"DILLION", 7, 136498},
	{"COLLAGENASE", 11, 136499},
	{"IACUC", 5, 136500},
	{"CARBONIFEROUS", 13, 136501},
	{"KIMO", 4, 136502},
	{"ECHUCA", 6, 136503},
	{"ERRMSG", 6, 136504},
	{"ZZAD", 4, 136505},
	{"YDVD", 4, 136506},
	{"XUDE", 4, 136507},
	{"WAIM", 4, 136508},
	{"VIOF", 4, 136509},
	{"RRST", 4, 136510},
	{"RQUH", 4, 136511},
	{"OYGE", 4, 136512},
	{"IVAM", 4, 136513},
	{"GMEH", 4, 136514},
	{"FCTH", 4, 136515},
	{"EGUB", 4, 136516},
	{"SINEPLEX", 8, 136517},
	{"BOOTLE", 6, 136518},
	{"BRILLANT", 8, 136519},
	{"BUCETATION", 10, 136520},
	{"ANABAENA", 8, 136521},
	{"LANKFORD", 8, 136522},
	{"BEPPE", 5, 136523},
	{"KERNING", 7, 136524},
	{"CREAN", 5, 136525},
	{"BRUISER", 7, 136526},
	{"AURIGA", 6, 136527},
	{"VERSENDEN", 9, 136528},
	{"MEDVED", 6, 136529},
	{"GENCIRCLES", 10, 136530},
	{"ZANTREX", 7, 136531},
	{"MESSANGER", 9, 136532},
	{"JUEVES", 6, 136533},
	{"BARDWELL", 8, 136534},
	{"EQUANIMITY", 10, 136535},
	{"TRABUCO", 7, 136536},
	{"POSIES", 6, 136537},
	{"CEIBA", 5, 136538},
	{"HOREB", 5, 136539},
	{"RESEALABLE", 10, 136540},
	{"AGITATORS", 9, 136541},
	{"WSEP", 4, 136542},
	{"UVAI", 4, 136543},
	{"UIBB", 4, 136544},
	{"RLOM", 4, 136545},
	{"RGSW", 4, 136546},
	{"MNOD", 4, 136547},
	{"KDUN", 4, 136548},
	{"IVCO", 4, 136549},
	{"FBRY", 4, 136550},
	{"EFSL", 4, 136551},
	{"POWERWEB", 8, 136552},
	{"MORK", 4, 136553},
	{"MERRION", 7, 136554},
	{"VENERATED", 9, 136555},
	{"CURS", 4, 136556},
	{"STOWAGE", 7, 136557},
	{"PROBLOGGER", 10, 136558},
	{"SUBCLINICAL", 11, 136559},
	{"GRUMBLES", 8, 136560},
	{"KOERNER", 7, 136561},
	{"BINATIONAL", 10, 136562},
	{"FRUSTRATES", 10, 136563},
	{"YAKUTAT", 7, 136564},
	{"SPELLFORCE", 10, 136565},
	{"LACRIMOSA", 9, 136566},
	{"FAMIL", 5, 136567},
	{"NEPHROLOGISTS", 13, 136568},
	{"MERGANSER", 9, 136569},
	{"CONTRAS", 7, 136570},
	{"ADRIANNA", 8, 136571},
	{"TAPP", 4, 136572},
	{"GLAMOR", 6, 136573},
	{"ASSIMILATING", 12, 136574},
	{"JOURNE", 6, 136575},
	{"ATOLADINHA", 10, 136576},
	{"GGGG", 4, 136577},
	{"ELECTROLITE", 11, 136578},
	{"WEBSEITE", 8, 136579},
	{"RIMSKY", 6, 136580},
	{"PROUDEST", 8, 136581},
	{"UNSC", 4, 136582},
	{"COFOUNDER", 9, 136583},
	{"SCRAM", 5, 136584},
	{"HIXON", 5, 136585},
	{"MANHUNTER", 9, 136586},
	{"DLY", 3, 136587},
	{"WWWK", 4, 136588},
	{"PHFR", 4, 136589},
	{"LUPW", 4, 136590},
	{"GIVO", 4, 136591},
	{"FEBM", 4, 136592},
	{"DALJ", 4, 136593},
	{"SETZM", 5, 136594},
	{"DOUGAN", 6, 136595},
	{"FANCIERS", 8, 136596},
	{"DAWLISH", 7, 136597},
	{"REVISTAS", 8, 136598},
	{"CORRIGENDUM", 11, 136599},
	{"DYNAMOMETER", 11, 136600},
	{"KOTHARI", 7, 136601},
	{"SUBJUNCTIVE", 11, 136602},
	{"HARUN", 5, 136603},
	{"DUFRESNE", 8, 136604},
	{"KROHN", 5, 136605},
	{"ABALOU", 6, 136606},
	{"KONTAKTA", 8, 136607},
	{"KEMAH", 5, 136608},
	{"MANDRAKELINUX", 13, 136609},
	{"ALDERLEY", 8, 136610},
	{"SOKOLOV", 7, 136611},
	{"SERVS", 5, 136612},
	{"AIRBRUSHING", 11, 136613},
	{"THORAC", 6, 136614},
	{"POSTGAME", 8, 136615},
	{"NEERING", 7, 136616},
	{"FIREFIGHT", 9, 136617},
	{"BROWDER", 7, 136618},
	{"PERISHING", 9, 136619},
	{"INAUGURATE", 10, 136620},
	{"YURMAN", 6, 136621},
	{"NANOSECOND", 10, 136622},
	{"NONEMPLOYERS", 12, 136623},
	{"XTLA", 4, 136624},
	{"URFF", 4, 136625},
	{"UBUQ", 4, 136626},
	{"SKML", 4, 136627},
	{"NGIU", 4, 136628},
	{"MRWH", 4, 136629},
	{"MNWI", 4, 136630},
	{"MIAP", 4, 136631},
	{"LMCD", 4, 136632},
	{"GOSK", 4, 136633},
	{"FFAK", 4, 136634},
	{"ERRW", 4, 136635},
	{"ERCN", 4, 136636},
	{"DYYE", 4, 136637},
	{"CILU", 4, 136638},
	{"DATAS", 5, 136639},
	{"TARTARUS", 8, 136640},
	{"KAPAMILYA", 9, 136641},
	{"UNDEREMPLOYED", 13, 136642},
	{"SCREAMO", 7, 136643},
	{"TEKNO", 5, 136644},
	{"WALI", 4, 136645},
	{"KWARGS", 6, 136646},
	{"STONEFLY", 8, 136647},
	{"SLAVS", 5, 136648},
	{"LIBRES", 6, 136649},
	{"COUNTERINTUITIVE", 16, 136650},
	{"NOISELESS", 9, 136651},
	{"EXTENSIONAL", 11, 136652},
	{"CAYLEY", 6, 136653},
	{"PRIMM", 5, 136654},
	{"VLADISLAV", 9, 136655},
	{"PREECE", 6, 136656},
	{"LENYA", 5, 136657},
	{"WORSHIPFUL", 10, 136658},
	{"LINNEA", 6, 136659},
	{"PROLITE", 7, 136660},
	{"DGD", 3, 136661},
	{"VARTAN", 6, 136662},
	{"DUPUY", 5, 136663},
	{"CALIFOR", 7, 136664},
	{"AMORES", 6, 136665},
	{"WARLOCKS", 8, 136666},
	{"FRIDERIC", 8, 136667},
	{"OCAMPO", 6, 136668},
	{"ZEPI", 4, 136669},
	{"VULA", 4, 136670},
	{"UKSH", 4, 136671},
	{"TLIZ", 4, 136672},
	{"ROVN", 4, 136673},
	{"PACW", 4, 136674},
	{"ORGD", 4, 136675},
	{"OMZA", 4, 136676},
	{"OFML", 4, 136677},
	{"OEBL", 4, 136678},
	{"ODJA", 4, 136679},
	{"NKUT", 4, 136680},
	{"FURD", 4, 136681},
	{"ETGL", 4, 136682},
	{"DOUL", 4, 136683},
	{"COFN", 4, 136684},
	{"TRUNKED", 7, 136685},
	{"DXB", 3, 136686},
	{"NUTTIN", 6, 136687},
	{"LASKY", 5, 136688},
	{"FATEH", 5, 136689},
	{"SPURNED", 7, 136690},
	{"MELVINS", 7, 136691},
	{"ARNAGE", 6, 136692},
	{"PHARMD", 6, 136693},
	{"ANTENNACABLE", 12, 136694},
	{"PERCALE", 7, 136695},
	{"GENJI", 5, 136696},
	{"PICTOU", 6, 136697},
	{"JAWED", 5, 136698},
	{"COMMATE", 7, 136699},
	{"UNDERCOUNTER", 12, 136700},
	{"SEADOO", 6, 136701},
	{"DCG", 3, 136702},
	{"SELIM", 5, 136703},
	{"SWAKOPMUND", 10, 136704},
	{"BOTTEGA", 7, 136705},
	{"HECATOMB", 8, 136706},
	{"LEGALESE", 8, 136707},
	{"FLV", 3, 136708},
	{"ABRAXAS", 7, 136709},
	{"MOYES", 5, 136710},
	{"MIDSTREAM", 9, 136711},
	{"HALLOCK", 7, 136712},
	{"WESTCLIFF", 9, 136713},
	{"OAKMONT", 7, 136714},
	{"CURTAILING", 10, 136715},
	{"REMOTECONTROLS", 14, 136716},
	{"IMMUNOGENICITY", 14, 136717},
	{"MACROCODE", 9, 136718},
	{"SPIELZEUG", 9, 136719},
	{"GRAYSLAKE", 9, 136720},
	{"ATRACCIONES", 11, 136721},
	{"YNMO", 4, 136722},
	{"YKRO", 4, 136723},
	{"WCIR", 4, 136724},
	{"UUMI", 4, 136725},
	{"TLAL", 4, 136726},
	{"SYPI", 4, 136727},
	{"SCYN", 4, 136728},
	{"OGDI", 4, 136729},
	{"MRNE", 4, 136730},
	{"MMCK", 4, 136731},
	{"IVWA", 4, 136732},
	{"ILDK", 4, 136733},
	{"HRIB", 4, 136734},
	{"GUPJ", 4, 136735},
	{"GMCA", 4, 136736},
	{"CDSO", 4, 136737},
	{"AGRIGENTO", 9, 136738},
	{"CHASTISED", 9, 136739},
	{"BRUCKHEIMER", 11, 136740},
	{"CODINOME", 8, 136741},
	{"ZEALANDER", 9, 136742},
	{"LEVENTHAL", 9, 136743},
	{"DONNCHA", 7, 136744},
	{"TAMBLYN", 7, 136745},
	{"GUIDRY", 6, 136746},
	{"MONTALCINO", 10, 136747},
	{"CRYOPRESERVATION", 16, 136748},
	{"MYQUICKRESPONSE", 15, 136749},
	{"GURTEEN", 7, 136750},
	{"COMMAX", 6, 136751},
	{"MACOM", 5, 136752},
	{"NABOO", 5, 136753},
	{"PONZI", 5, 136754},
	{"IMUS", 4, 136755},
	{"NALBANDIAN", 10, 136756},
	{"MUSCULATURE", 11, 136757},
	{"SPARKLERS", 9, 136758},
	{"DEPORTATIONS", 12, 136759},
	{"TELEMANN", 8, 136760},
	{"ULNAR", 5, 136761},
	{"LOME", 4, 136762},
	{"FETZER", 6, 136763},
	{"BOLSHOI", 7, 136764},
	{"CONTROLLABILITY", 15, 136765},
	{"CPUID", 5, 136766},
	{"DAILYMOTION", 11, 136767},
	{"UNDERPERFORMING", 15, 136768},
	{"MENSEN", 6, 136769},
	{"ZICH", 4, 136770},
	{"MITFORD", 7, 136771},
	{"SUPPRIMER", 9, 136772},
	{"INCRIMINATION", 13, 136773},
	{"MAGO", 4, 136774},
	{"FORETHOUGHT", 11, 136775},
	{"SHOUP", 5, 136776},
	{"PALAEONTOLOGY", 13, 136777},
	{"WGOE", 4, 136778},
	{"RZHU", 4, 136779},
	{"RMTI", 4, 136780},
	{"OKSJ", 4, 136781},
	{"LNFL", 4, 136782},
	{"GNPE", 4, 136783},
	{"FGAV", 4, 136784},
	{"EKGR", 4, 136785},
	{"DRTO", 4, 136786},
	{"AUFE", 4, 136787},
	{"SMALLTOWN", 9, 136788},
	{"VISCERA", 7, 136789},
	{"CLANBASE", 8, 136790},
	{"BATESON", 7, 136791},
	{"KENYANS", 7, 136792},
	{"ADICTS", 6, 136793},
	{"TMPGENC", 7, 136794},
	{"LOBED", 5, 136795},
	{"ARGOUML", 7, 136796},
	{"SMIRKED", 7, 136797},
	{"JDR", 3, 136798},
	{"CROSSHAIRS", 10, 136799},
	{"MIYAKO", 6, 136800},
	{"COOPERATORS", 11, 136801},
	{"EXCITABILITY", 12, 136802},
	{"MAKEFONT", 8, 136803},
	{"CHECKFREE", 9, 136804},
	{"SUBPOPULATION", 13, 136805},
	{"MADDER", 6, 136806},
	{"CFSP", 4, 136807},
	{"PALMCORDER", 10, 136808},
	{"COLUMBIANS", 10, 136809},
	{"AMBI", 4, 136810},
	{"DIRECTORYS", 10, 136811},
	{"IFOR", 4, 136812},
	{"UNSCREW", 7, 136813},
	{"SKANSKA", 7, 136814},
	{"GRAVEYARDS", 10, 136815},
	{"UXFO", 4, 136816},
	{"UDMI", 4, 136817},
	{"TOCD", 4, 136818},
	{"SMPO", 4, 136819},
	{"OLTF", 4, 136820},
	{"LVAB", 4, 136821},
	{"LKME", 4, 136822},
	{"KANB", 4, 136823},
	{"HLIQ", 4, 136824},
	{"EGTR", 4, 136825},
	{"DZAM", 4, 136826},
	{"CMID", 4, 136827},
	{"BMEA", 4, 136828},
	{"ALUB", 4, 136829},
	{"EXTERMINATED", 12, 136830},
	{"VAGUS", 5, 136831},
	{"TSING", 5, 136832},
	{"METTE", 5, 136833},
	{"WYNTER", 6, 136834},
	{"CEPHALOSPORINS", 14, 136835},
	{"OLUME", 5, 136836},
	{"BRONZED", 7, 136837},
	{"CRAMPTON", 8, 136838},
	{"TEACHERWEB", 10, 136839},
	{"ANGEW", 5, 136840},
	{"BASENJI", 7, 136841},
	{"FREECHAT", 8, 136842},
	{"WORKBENCHES", 11, 136843},
	{"TOPHER", 6, 136844},
	{"LUUP", 4, 136845},
	{"DCX", 3, 136846},
	{"OGRAVE", 6, 136847},
	{"GLAZIERS", 8, 136848},
	{"YOGIC", 5, 136849},
	{"MINUTOS", 7, 136850},
	{"RUNIT", 5, 136851},
	{"PHARMACOGENETICS", 16, 136852},
	{"WINDSCREENS", 11, 136853},
	{"OAMC", 4, 136854},
	{"FEMBOMB", 7, 136855},
	{"MARKMAN", 7, 136856},
	{"BEALLS", 6, 136857},
	{"CWMBRAN", 7, 136858},
	{"GRIMY", 5, 136859},
	{"TELEVUE", 7, 136860},
	{"INKCLUB", 7, 136861},
	{"MYTIGHTS", 8, 136862},
	{"MAGNAFLOW", 9, 136863},
	{"AMANTADINE", 10, 136864},
	{"POSTPAID", 8, 136865},
	{"PEXI", 4, 136866},
	{"NMPH", 4, 136867},
	{"NIKL", 4, 136868},
	{"NGOX", 4, 136869},
	{"NFUM", 4, 136870},
	{"MRCR", 4, 136871},
	{"LTDH", 4, 136872},
	{"EUBO", 4, 136873},
	{"APFE", 4, 136874},
	{"ANCM", 4, 136875},
	{"COSTUMER", 8, 136876},
	{"HOTELBESUCH", 11, 136877},
	{"PROPORTIONING", 13, 136878},
	{"CAPPIELLO", 9, 136879},
	{"SUBTOTALS", 9, 136880},
	{"MUSICALES", 9, 136881},
	{"HELADOS", 7, 136882},
	{"PEPTIDASES", 10, 136883},
	{"CACA", 4, 136884},
	{"EFFECTORS", 9, 136885},
	{"KOTZEBUE", 8, 136886},
	{"OULTON", 6, 136887},
	{"JARNO", 5, 136888},
	{"COAXIALCABLE", 12, 136889},
	{"LODGEMENT", 9, 136890},
	{"EREZ", 4, 136891},
	{"DFD", 3, 136892},
	{"LASCIVIOUS", 10, 136893},
	{"CAFFERTY", 8, 136894},
	{"PACI", 4, 136895},
	{"PANTON", 6, 136896},
	{"GOBBLES", 7, 136897},
	{"GAWLER", 6, 136898},
	{"TETSUO", 6, 136899},
	{"SUNDIN", 6, 136900},
	{"COMSTAR", 7, 136901},
	{"CHELSEY", 7, 136902},
	{"WORKTOPS", 8, 136903},
	{"ILLE", 4, 136904},
	{"MAXENT", 6, 136905},
	{"KARN", 4, 136906},
	{"DANTES", 6, 136907},
	{"SUGARCULT", 9, 136908},
	{"PALOUSE", 7, 136909},
	{"YYAM", 4, 136910},
	{"XTDR", 4, 136911},
	{"PPAM", 4, 136912},
	{"LPRU", 4, 136913},
	{"LMOG", 4, 136914},
	{"LFMU", 4, 136915},
	{"GNVI", 4, 136916},
	{"ENCC", 4, 136917},
	{"EIKK", 4, 136918},
	{"DXAN", 4, 136919},
	{"DFEU", 4, 136920},
	{"AXMI", 4, 136921},
	{"TAIJI", 5, 136922},
	{"ASPALPHA", 8, 136923},
	{"BIOPHARMA", 9, 136924},
	{"JENKINSON", 9, 136925},
	{"ASTHMATICS", 10, 136926},
	{"GABEL", 5, 136927},
	{"FORTINET", 8, 136928},
	{"CHICKASHA", 9, 136929},
	{"DUMBING", 7, 136930},
	{"MLL", 3, 136931},
	{"STIGA", 5, 136932},
	{"GRAPPLES", 8, 136933},
	{"LAWWEB", 6, 136934},
	{"HARY", 4, 136935},
	{"DISPASSIONATE", 13, 136936},
	{"JAMAR", 5, 136937},
	{"MYLEX", 5, 136938},
	{"HAMAN", 5, 136939},
	{"RAPALA", 6, 136940},
	{"UNIONIZATION", 12, 136941},
	{"PPAR", 4, 136942},
	{"MOOK", 4, 136943},
	{"ARCAM", 5, 136944},
	{"BREEDLOVE", 9, 136945},
	{"BONHEUR", 7, 136946},
	{"BILLUPS", 7, 136947},
	{"VESTAS", 6, 136948},
	{"TELARUS", 7, 136949},
	{"YNBR", 4, 136950},
	{"XARI", 4, 136951},
	{"WWMA", 4, 136952},
	{"UNJI", 4, 136953},
	{"TAWF", 4, 136954},
	{"MRAY", 4, 136955},
	{"MADK", 4, 136956},
	{"KLOU", 4, 136957},
	{"HTYD", 4, 136958},
	{"HEWJ", 4, 136959},
	{"DUPJ", 4, 136960},
	{"DSGT", 4, 136961},
	{"APMI", 4, 136962},
	{"BRINGER", 7, 136963},
	{"BEADBOARD", 9, 136964},
	{"APLASTIC", 8, 136965},
	{"CASITA", 6, 136966},
	{"JPANEL", 6, 136967},
	{"METHYLPREDNISOLONE", 18, 136968},
	{"SUPERNATANTS", 12, 136969},
	{"TOKUGAWA", 8, 136970},
	{"SCARECROWS", 10, 136971},
	{"EINSTELLUNGEN", 13, 136972},
	{"UNRECOVERABLE", 13, 136973},
	{"GAMEGEAR", 8, 136974},
	{"DEMIC", 5, 136975},
	{"MARYJANE", 8, 136976},
	{"CHARMINGLY", 10, 136977},
	{"TRWY", 4, 136978},
	{"GUNK", 4, 136979},
	{"VPD", 3, 136980},
	{"OCONNOR", 7, 136981},
	{"BOYDEN", 6, 136982},
	{"DRILLERS", 8, 136983},
	{"BRECHIN", 7, 136984},
	{"LEINART", 7, 136985},
	{"UNDERGEAR", 9, 136986},
	{"YOSU", 4, 136987},
	{"UISJ", 4, 136988},
	{"MGLE", 4, 136989},
	{"KATJ", 4, 136990},
	{"KANM", 4, 136991},
	{"FTIP", 4, 136992},
	{"FAHM", 4, 136993},
	{"DRGR", 4, 136994},
	{"DPLY", 4, 136995},
	{"DNAL", 4, 136996},
	{"AZZR", 4, 136997},
	{"AZYE", 4, 136998},
	{"KLASSIKER", 9, 136999},
	{"FARRER", 6, 137000},
	{"WETTEST", 7, 137001},
	{"PROCRASTINATOR", 14, 137002},
	{"CHESHUNT", 8, 137003},
	{"WIKIQUOTE", 9, 137004},
	{"RURALBOOKSHOP", 13, 137005},
	{"GLIMPSED", 8, 137006},
	{"PIDGEON", 7, 137007},
	{"FISERV", 6, 137008},
	{"PARTAKING", 9, 137009},
	{"GERAL", 5, 137010},
	{"CHILDMINDER", 11, 137011},
	{"FIREBRAND", 9, 137012},
	{"TISHOMINGO", 10, 137013},
	{"BATHYMETRIC", 11, 137014},
	{"FAIRFORD", 8, 137015},
	{"NEWSBOYS", 8, 137016},
	{"NEUROANATOMY", 12, 137017},
	{"DEPRECATION", 11, 137018},
	{"CONNERS", 7, 137019},
	{"BOOTYTALK", 9, 137020},
	{"INTIMATION", 10, 137021},
	{"ZPK", 3, 137022},
	{"YQQ", 3, 137023},
	{"YGQ", 3, 137024},
	{"YBQ", 3, 137025},
	{"VJV", 3, 137026},
	{"VFJ", 3, 137027},
	{"UQP", 3, 137028},
	{"QLG", 3, 137029},
	{"MJZ", 3, 137030},
	{"LGZ", 3, 137031},
	{"KQL", 3, 137032},
	{"DVQ", 3, 137033},
	{"BZL", 3, 137034},
	{"BFQ", 3, 137035},
	{"VIRION", 6, 137036},
	{"PREHEARING", 10, 137037},
	{"CHEQUERED", 9, 137038},
	{"BORNSTEIN", 9, 137039},
	{"ZEEV", 4, 137040},
	{"GLIMMERING", 10, 137041},
	{"MCKINLAY", 8, 137042},
	{"FLOODLIGHT", 10, 137043},
	{"ZAPR", 4, 137044},
	{"YXIA", 4, 137045},
	{"VAOR", 4, 137046},
	{"UIPS", 4, 137047},
	{"QCAN", 4, 137048},
	{"MOAL", 4, 137049},
	{"MFAV", 4, 137050},
	{"MBOH", 4, 137051},
	{"GJEF", 4, 137052},
	{"FYPR", 4, 137053},
	{"AYEG", 4, 137054},
	{"AMCOR", 5, 137055},
	{"ALPHONSO", 8, 137056},
	{"ROBI", 4, 137057},
	{"SPACEK", 6, 137058},
	{"PRULE", 5, 137059},
	{"WWWW", 4, 137060},
	{"OTTOBRE", 7, 137061},
	{"HAVNT", 5, 137062},
	{"FALLA", 5, 137063},
	{"EROSCENTER", 10, 137064},
	{"POOLEY", 6, 137065},
	{"ODONATA", 7, 137066},
	{"DISBELIEVE", 10, 137067},
	{"KRUSH", 5, 137068},
	{"FIREGL", 6, 137069},
	{"NINER", 5, 137070},
	{"DEBUTING", 8, 137071},
	{"IMRE", 4, 137072},
	{"SCIENTOLOGIST", 13, 137073},
	{"BREVET", 6, 137074},
	{"NEWSMAGAZINE", 12, 137075},
	{"GHOSTING", 8, 137076},
	{"STRYPER", 7, 137077},
	{"GOLDFIELD", 9, 137078},
	{"DARF", 4, 137079},
	{"NICKELL", 7, 137080},
	{"HALDIMAND", 9, 137081},
	{"CORTICOSTERONE", 14, 137082},
	{"SYNERGISTICALLY", 15, 137083},
	{"URSULINE", 8, 137084},
	{"ALLPORT", 7, 137085},
	{"GUILLORY", 8, 137086},
	{"YUHA", 4, 137087},
	{"XOFN", 4, 137088},
	{"UMQU", 4, 137089},
	{"UEAV", 4, 137090},
	{"SUMW", 4, 137091},
	{"ROXT", 4, 137092},
	{"RJEC", 4, 137093},
	{"OMTV", 4, 137094},
	{"MNDE", 4, 137095},
	{"MKOS", 4, 137096},
	{"KALD", 4, 137097},
	{"ITZY", 4, 137098},
	{"HICG", 4, 137099},
	{"CUTJ", 4, 137100},
	{"AKLY", 4, 137101},
	{"JBC", 3, 137102},
	{"WOCHENSCHR", 10, 137103},
	{"RETRACTING", 10, 137104},
	{"AKIYAMA", 7, 137105},
	{"PREDISPOSE", 10, 137106},
	{"TROYES", 6, 137107},
	{"PHYSICALS", 9, 137108},
	{"VIRTUALDUB", 10, 137109},
	{"CHARLESWORTH", 12, 137110},
	{"XPERIENCE", 9, 137111},
	{"KORSAKOV", 8, 137112},
	{"EXTERMINATING", 13, 137113},
	{"RETRANSMISSIONS", 15, 137114},
	{"REVOLTED", 8, 137115},
	{"PERV", 4, 137116},
	{"GYNECOMASTIA", 12, 137117},
	{"BUNCHED", 7, 137118},
	{"TOWNLEY", 7, 137119},
	{"BESOIN", 6, 137120},
	{"WIKIHOW", 7, 137121},
	{"SCRUTINISED", 11, 137122},
	{"HOUSLEY", 7, 137123},
	{"ALLEZ", 5, 137124},
	{"PREDISPOSING", 12, 137125},
	{"FUSIVE", 6, 137126},
	{"TREASURENET", 11, 137127},
	{"TABELLA", 7, 137128},
	{"LEFF", 4, 137129},
	{"DIAGRAMMATIC", 12, 137130},
	{"STRDUP", 6, 137131},
	{"THALAMIC", 8, 137132},
	{"DINSMORE", 8, 137133},
	{"UYAD", 4, 137134},
	{"UOMN", 4, 137135},
	{"TAUL", 4, 137136},
	{"RNGI", 4, 137137},
	{"OXAF", 4, 137138},
	{"OOMK", 4, 137139},
	{"OFRB", 4, 137140},
	{"OCWA", 4, 137141},
	{"NDRW", 4, 137142},
	{"LYEG", 4, 137143},
	{"LUXA", 4, 137144},
	{"LLAX", 4, 137145},
	{"LEWW", 4, 137146},
	{"GHIB", 4, 137147},
	{"ELCD", 4, 137148},
	{"ARJEN", 5, 137149},
	{"BERNARDI", 8, 137150},
	{"TOKENIZER", 9, 137151},
	{"HERDED", 6, 137152},
	{"YOKOSUKA", 8, 137153},
	{"PALAEOLITHIC", 12, 137154},
	{"MOLISE", 6, 137155},
	{"GIGE", 4, 137156},
	{"TTAGETELEMENTTYPE", 17, 137157},
	{"ATHANASIUS", 10, 137158},
	{"OCEANO", 6, 137159},
	{"GEMACHT", 7, 137160},
	{"SECTARIANISM", 12, 137161},
	{"LANZ", 4, 137162},
	{"LITERA", 6, 137163},
	{"LEBESGUE", 8, 137164},
	{"CHEAM", 5, 137165},
	{"CHARTWELL", 9, 137166},
	{"PHENTERMIN", 10, 137167},
	{"LINKLOG", 7, 137168},
	{"LITIGATING", 10, 137169},
	{"GENTING", 7, 137170},
	{"YAIR", 4, 137171},
	{"IMELDA", 6, 137172},
	{"FUSIBLE", 7, 137173},
	{"MYTISCOVER", 10, 137174},
	{"ANARCHIC", 8, 137175},
	{"DELIBERATING", 12, 137176},
	{"WILMS", 5, 137177},
	{"PRESENTATIONAL", 14, 137178},
	{"ZONM", 4, 137179},
	{"YNOY", 4, 137180},
	{"YGUS", 4, 137181},
	{"OMHY", 4, 137182},
	{"OAUC", 4, 137183},
	{"BUGT", 4, 137184},
	{"BFRE", 4, 137185},
	{"REGINE", 6, 137186},
	{"HUMAINES", 8, 137187},
	{"BLOGSPOTTING", 12, 137188},
	{"LONDONER", 8, 137189},
	{"AESCHYLUS", 9, 137190},
	{"CHAPPLE", 7, 137191},
	{"KIMONOS", 7, 137192},
	{"CALVI", 5, 137193},
	{"DEREFERENCE", 11, 137194},
	{"DONNYBROOK", 10, 137195},
	{"LIBJPEG", 7, 137196},
	{"PLANTAGENET", 11, 137197},
	{"TELEFOONS", 9, 137198},
	{"TIMMERMAN", 9, 137199},
	{"COMPONENTES", 11, 137200},
	{"STONEGATE", 9, 137201},
	{"WARDLE", 6, 137202},
	{"FAJR", 4, 137203},
	{"CHAFFIN", 7, 137204},
	{"SAMMONS", 7, 137205},
	{"EPISCOPALIAN", 12, 137206},
	{"UNTERTITEL", 10, 137207},
	{"MINIATURIZED", 12, 137208},
	{"SHOWBREAD", 9, 137209},
	{"WHARE", 5, 137210},
	{"ENDIVE", 6, 137211},
	{"SKANEATELES", 11, 137212},
	{"MUDGEE", 6, 137213},
	{"APWA", 4, 137214},
	{"YNCW", 4, 137215},
	{"XSOM", 4, 137216},
	{"RKWR", 4, 137217},
	{"RBHU", 4, 137218},
	{"PDAR", 4, 137219},
	{"OZEM", 4, 137220},
	{"OOCR", 4, 137221},
	{"FYSO", 4, 137222},
	{"BLOGGIES", 8, 137223},
	{"ANTIMICROBIALS", 14, 137224},
	{"SESSIONID", 9, 137225},
	{"PELOPONNESE", 11, 137226},
	{"RESUBMISSION", 12, 137227},
	{"WADENA", 6, 137228},
	{"FANLESS", 7, 137229},
	{"SALZMAN", 7, 137230},
	{"RISHON", 6, 137231},
	{"KOREAS", 6, 137232},
	{"SERP", 4, 137233},
	{"GRINT", 5, 137234},
	{"ZWAR", 4, 137235},
	{"OOPSURL", 7, 137236},
	{"VIDEOCASSETTES", 14, 137237},
	{"UNDERPAYMENT", 12, 137238},
	{"SOLDAT", 6, 137239},
	{"BIRGER", 6, 137240},
	{"BOTERO", 6, 137241},
	{"RIZZOLI", 7, 137242},
	{"BETAMETHASONE", 13, 137243},
	{"THUCYDIDES", 10, 137244},
	{"MULTIAGENT", 10, 137245},
	{"ESPERO", 6, 137246},
	{"TOMMASO", 7, 137247},
	{"BARBERTON", 9, 137248},
	{"BAKLAVA", 7, 137249},
	{"WUPD", 4, 137250},
	{"PNEV", 4, 137251},
	{"OCYB", 4, 137252},
	{"LIAJ", 4, 137253},
	{"LAWK", 4, 137254},
	{"IZCA", 4, 137255},
	{"FKNE", 4, 137256},
	{"EGWO", 4, 137257},
	{"DSIK", 4, 137258},
	{"DCPR", 4, 137259},
	{"ALPC", 4, 137260},
	{"BPG", 3, 137261},
	{"DIOPTER", 7, 137262},
	{"FILEREF", 7, 137263},
	{"REPUDIATE", 9, 137264},
	{"OVERLORDS", 9, 137265},
	{"DESTABILIZATION", 15, 137266},
	{"BRYDEN", 6, 137267},
	{"KFREE", 5, 137268},
	{"ESSARY", 6, 137269},
	{"UNSPENT", 7, 137270},
	{"ADVISABILITY", 12, 137271},
	{"LOPE", 4, 137272},
	{"TENDINITIS", 10, 137273},
	{"PREARRANGED", 11, 137274},
	{"CORNICHE", 8, 137275},
	{"FESTERING", 9, 137276},
	{"HERITABLE", 9, 137277},
	{"LEMURS", 6, 137278},
	{"MCKEEVER", 8, 137279},
	{"EXTRADITED", 10, 137280},
	{"LAURINBURG", 10, 137281},
	{"BURRS", 5, 137282},
	{"MARTHAS", 7, 137283},
	{"STREAMWOOD", 10, 137284},
	{"XOFW", 4, 137285},
	{"VASB", 4, 137286},
	{"UPOT", 4, 137287},
	{"TVBU", 4, 137288},
	{"RAAU", 4, 137289},
	{"OLSV", 4, 137290},
	{"OAKU", 4, 137291},
	{"NMPS", 4, 137292},
	{"NGXU", 4, 137293},
	{"EZEF", 4, 137294},
	{"EKJU", 4, 137295},
	{"CJEW", 4, 137296},
	{"FLCL", 4, 137297},
	{"BACKSPLASH", 10, 137298},
	{"TOROS", 5, 137299},
	{"RELINQUISHING", 13, 137300},
	{"MIDSOMER", 8, 137301},
	{"FLOCKHART", 9, 137302},
	{"HALFLIFE", 8, 137303},
	{"NOVY", 4, 137304},
	{"AUTOMAT", 7, 137305},
	{"TICTACTOE", 9, 137306},
	{"BEVO", 4, 137307},
	{"DESSA", 5, 137308},
	{"IOWANS", 6, 137309},
	{"IRRI", 4, 137310},
	{"ELDERHOSTEL", 11, 137311},
	{"SEVERS", 6, 137312},
	{"AJUNG", 5, 137313},
	{"GARNETS", 7, 137314},
	{"STREETLIGHTS", 12, 137315},
	{"KOSDAQ", 6, 137316},
	{"YAMAKAWA", 8, 137317},
	{"MERCIA", 6, 137318},
	{"LOAMY", 5, 137319},
	{"FURIES", 6, 137320},
	{"YTYL", 4, 137321},
	{"VJOH", 4, 137322},
	{"UJAC", 4, 137323},
	{"TOGM", 4, 137324},
	{"ROAP", 4, 137325},
	{"QWHY", 4, 137326},
	{"PTDU", 4, 137327},
	{"PDTA", 4, 137328},
	{"NUPU", 4, 137329},
	{"NGGM", 4, 137330},
	{"LTMU", 4, 137331},
	{"FEPH", 4, 137332},
	{"CRDO", 4, 137333},
	{"FORSIDE", 7, 137334},
	{"ERRS", 4, 137335},
	{"HAPLOID", 7, 137336},
	{"DICHLORO", 8, 137337},
	{"ARGGHHH", 7, 137338},
	{"INTERLEAVE", 10, 137339},
	{"TCPA", 4, 137340},
	{"FORMBY", 6, 137341},
	{"PIQUED", 6, 137342},
	{"TRIUMVIRATE", 11, 137343},
	{"ORANJESTAD", 10, 137344},
	{"JINKS", 5, 137345},
	{"MATTISON", 8, 137346},
	{"LYSANDER", 8, 137347},
	{"MERIMBULA", 9, 137348},
	{"TRANGO", 6, 137349},
	{"WALKABLE", 8, 137350},
	{"FDU", 3, 137351},
	{"BIZZARO", 7, 137352},
	{"REALCLEARPOLITICS", 17, 137353},
	{"JML", 3, 137354},
	{"LLEYTON", 7, 137355},
	{"PRIVATO", 7, 137356},
	{"ALBENA", 6, 137357},
	{"GARFINKEL", 9, 137358},
	{"ASTRALWERKS", 11, 137359},
	{"CFF", 3, 137360},
	{"XOFTSPY", 7, 137361},
	{"LWIDTH", 6, 137362},
	{"TMBG", 4, 137363},
	{"UNIMPEDED", 9, 137364},
	{"BIDDY", 5, 137365},
	{"GARMONT", 7, 137366},
	{"PRESSLEY", 8, 137367},
	{"NOLEGGIO", 8, 137368},
	{"APOLITICAL", 10, 137369},
	{"EPIDEMIOLOGISTS", 15, 137370},
	{"WNEF", 4, 137371},
	{"SHCY", 4, 137372},
	{"RMCM", 4, 137373},
	{"ORTQ", 4, 137374},
	{"NMYK", 4, 137375},
	{"KUSO", 4, 137376},
	{"ITYZ", 4, 137377},
	{"IRUV", 4, 137378},
	{"FOXD", 4, 137379},
	{"ERDJ", 4, 137380},
	{"DAGH", 4, 137381},
	{"APHF", 4, 137382},
	{"COMPRIS", 7, 137383},
	{"THEOPHILUS", 10, 137384},
	{"BASHO", 5, 137385},
	{"ARCINFO", 7, 137386},
	{"SOUTHTOWN", 9, 137387},
	{"LSTYLE", 6, 137388},
	{"SUPERMOTO", 9, 137389},
	{"EQUIVARIANT", 11, 137390},
	{"CRONY", 5, 137391},
	{"ROUP", 4, 137392},
	{"WINAPI", 6, 137393},
	{"CHICKAMAUGA", 11, 137394},
	{"SUNSOLVE", 8, 137395},
	{"ENDOPEPTIDASES", 14, 137396},
	{"STREAMABLE", 10, 137397},
	{"SAMBO", 5, 137398},
	{"CASTROVILLE", 11, 137399},
	{"MCKELLAR", 8, 137400},
	{"STELLEN", 7, 137401},
	{"ROGOFF", 6, 137402},
	{"EDDYVILLE", 9, 137403},
	{"WIPP", 4, 137404},
	{"WOLLSTONECRAFT", 14, 137405},
	{"DIATONIC", 8, 137406},
	{"FFICE", 5, 137407},
	{"INSTAR", 6, 137408},
	{"MCFERRIN", 8, 137409},
	{"ADAMSVILLE", 10, 137410},
	{"PROFESSES", 9, 137411},
	{"SUCKA", 5, 137412},
	{"HORACIO", 7, 137413},
	{"COLPOSCOPY", 10, 137414},
	{"XTYO", 4, 137415},
	{"UNOM", 4, 137416},
	{"ULYV", 4, 137417},
	{"UDMU", 4, 137418},
	{"SSWU", 4, 137419},
	{"RIXM", 4, 137420},
	{"RAGW", 4, 137421},
	{"NWVA", 4, 137422},
	{"LDEU", 4, 137423},
	{"KMUN", 4, 137424},
	{"FELB", 4, 137425},
	{"EUFA", 4, 137426},
	{"EDMV", 4, 137427},
	{"DIGD", 4, 137428},
	{"BBCP", 4, 137429},
	{"ATVC", 4, 137430},
	{"STICKLER", 8, 137431},
	{"NXPG", 4, 137432},
	{"WHEREWITHAL", 11, 137433},
	{"WACA", 4, 137434},
	{"COOBER", 6, 137435},
	{"MCNUTT", 6, 137436},
	{"TRIAMCINOLONE", 13, 137437},
	{"PAPERBOY", 8, 137438},
	{"BEDWORTH", 8, 137439},
	{"SHRIEKS", 7, 137440},
	{"MARGARETHA", 10, 137441},
	{"SOFTWARETOP", 11, 137442},
	{"ANGLOPHONE", 10, 137443},
	{"CDDL", 4, 137444},
	{"ASPNUM", 6, 137445},
	{"SMALLCAP", 8, 137446},
	{"SARTORIUS", 9, 137447},
	{"BETHE", 5, 137448},
	{"BACKFIRED", 9, 137449},
	{"OMINOUSLY", 9, 137450},
	{"MACCABEES", 9, 137451},
	{"ALLL", 4, 137452},
	{"EXPLORATORIUM", 13, 137453},
	{"SEAHAWK", 7, 137454},
	{"HALPIN", 6, 137455},
	{"SWAGS", 5, 137456},
	{"VALUTA", 6, 137457},
	{"CROSSCUTTING", 12, 137458},
	{"TZOR", 4, 137459},
	{"RWEP", 4, 137460},
	{"RFAK", 4, 137461},
	{"REZB", 4, 137462},
	{"OFLS", 4, 137463},
	{"NYMY", 4, 137464},
	{"NXRA", 4, 137465},
	{"NDJP", 4, 137466},
	{"LPNO", 4, 137467},
	{"GIOL", 4, 137468},
	{"FGUL", 4, 137469},
	{"FESB", 4, 137470},
	{"EJIL", 4, 137471},
	{"EDDN", 4, 137472},
	{"CCRA", 4, 137473},
	{"RHIZOMES", 8, 137474},
	{"KAHAN", 5, 137475},
	{"TRAJAN", 6, 137476},
	{"KRANKENVERSICHERUNG", 19, 137477},
	{"JARIG", 5, 137478},
	{"CAER", 4, 137479},
	{"MUNIR", 5, 137480},
	{"PROSTITUIERTEN", 14, 137481},
	{"ABLUTION", 8, 137482},
	{"POLITI", 6, 137483},
	{"BALTI", 5, 137484},
	{"LOUGHLIN", 8, 137485},
	{"RICKETTSIA", 10, 137486},
	{"HAMADA", 6, 137487},
	{"BRINKS", 6, 137488},
	{"WINDBREAKER", 11, 137489},
	{"DUFFS", 5, 137490},
	{"RANDIS", 6, 137491},
	{"MYCOTOXINS", 10, 137492},
	{"HANDCUFF", 8, 137493},
	{"VBAC", 4, 137494},
	{"KENEDY", 6, 137495},
	{"CORTLANDT", 9, 137496},
	{"GOWEN", 5, 137497},
	{"PALMAR", 6, 137498},
	{"SIRB", 4, 137499},
	{"RIJE", 4, 137500},
	{"OYRA", 4, 137501},
	{"ONMP", 4, 137502},
	{"MYOV", 4, 137503},
	{"MLUK", 4, 137504},
	{"MILM", 4, 137505},
	{"MBOE", 4, 137506},
	{"LPSL", 4, 137507},
	{"HURP", 4, 137508},
	{"HRUP", 4, 137509},
	{"GOCI", 4, 137510},
	{"GCAV", 4, 137511},
	{"EGGB", 4, 137512},
	{"BFRA", 4, 137513},
	{"AWSG", 4, 137514},
	{"WORLDCUP", 8, 137515},
	{"DEMURE", 6, 137516},
	{"LETTERKENNY", 11, 137517},
	{"HASHCASH", 8, 137518},
	{"VERSCHIL", 8, 137519},
	{"URBANO", 6, 137520},
	{"CEPHALIC", 8, 137521},
	{"NEOWIN", 6, 137522},
	{"BIRDBATH", 8, 137523},
	{"ATHENE", 6, 137524},
	{"IMPLEMENTA", 10, 137525},
	{"REPONSE", 7, 137526},
	{"VACUOUS", 7, 137527},
	{"MCANDREW", 8, 137528},
	{"ZILOG", 5, 137529},
	{"COHERENCY", 9, 137530},
	{"NETNEWS", 7, 137531},
	{"GRIDDLES", 8, 137532},
	{"CAPPER", 6, 137533},
	{"YENC", 4, 137534},
	{"JETSON", 6, 137535},
	{"SCHIMMEL", 8, 137536},
	{"NEURORADIOLOGY", 14, 137537},
	{"EQUILATERAL", 11, 137538},
	{"SWOPE", 5, 137539},
	{"DEMAREST", 8, 137540},
	{"ARCHULETA", 9, 137541},
	{"HASIDIC", 7, 137542},
	{"NURBS", 5, 137543},
	{"PARASOLS", 8, 137544},
	{"VELOSO", 6, 137545},
	{"CLAR", 4, 137546},
	{"SCIENC", 6, 137547},
	{"WCBS", 4, 137548},
	{"YOCA", 4, 137549},
	{"XUND", 4, 137550},
	{"RRRE", 4, 137551},
	{"MFON", 4, 137552},
	{"GOPN", 4, 137553},
	{"EAMQ", 4, 137554},
	{"CSLU", 4, 137555},
	{"ZBRUSH", 6, 137556},
	{"WILK", 4, 137557},
	{"UNDERESTIMATES", 14, 137558},
	{"TRINI", 5, 137559},
	{"GCB", 3, 137560},
	{"PELOTON", 7, 137561},
	{"BOOKNOTES", 9, 137562},
	{"MUNITION", 8, 137563},
	{"BOHOL", 5, 137564},
	{"COMORBID", 8, 137565},
	{"CUSICK", 6, 137566},
	{"GERAGHTY", 8, 137567},
	{"CULBERSON", 9, 137568},
	{"CADR", 4, 137569},
	{"HELOC", 5, 137570},
	{"GARMISCH", 8, 137571},
	{"DICHROISM", 9, 137572},
	{"COLORIZED", 9, 137573},
	{"PETRY", 5, 137574},
	{"KAHANA", 6, 137575},
	{"GELFAND", 7, 137576},
	{"GEEKGOLD", 8, 137577},
	{"ALVORD", 6, 137578},
	{"BIBLIOPOLIS", 11, 137579},
	{"WESTY", 5, 137580},
	{"RADIOSURGERY", 12, 137581},
	{"PERSISTANT", 10, 137582},
	{"VEERED", 6, 137583},
	{"TEARY", 5, 137584},
	{"WRL", 3, 137585},
	{"NOVARA", 6, 137586},
	{"COOLA", 5, 137587},
	{"ZMAT", 4, 137588},
	{"YBUB", 4, 137589},
	{"UFKI", 4, 137590},
	{"UDSB", 4, 137591},
	{"RYKU", 4, 137592},
	{"PSYM", 4, 137593},
	{"NLER", 4, 137594},
	{"MOSD", 4, 137595},
	{"GGAD", 4, 137596},
	{"EDNB", 4, 137597},
	{"EAFW", 4, 137598},
	{"APEK", 4, 137599},
	{"ALIJ", 4, 137600},
	{"SOWER", 5, 137601},
	{"GREETER", 7, 137602},
	{"SCARRY", 6, 137603},
	{"WARDRIVING", 10, 137604},
	{"AEROS", 5, 137605},
	{"RIVERDANCE", 10, 137606},
	{"TECTURA", 7, 137607},
	{"TMCNET", 6, 137608},
	{"JONGE", 5, 137609},
	{"WEATHERBY", 9, 137610},
	{"SOURCEBOOKS", 11, 137611},
	{"DUCKLINGS", 9, 137612},
	{"CLUBE", 5, 137613},
	{"DELINEATES", 10, 137614},
	{"RESONATED", 9, 137615},
	{"SERFDOM", 7, 137616},
	{"PESQUISA", 8, 137617},
	{"PAWNBROKERS", 11, 137618},
	{"LPRNG", 5, 137619},
	{"AIESEC", 6, 137620},
	{"JANINA", 6, 137621},
	{"GOSSIPS", 7, 137622},
	{"AVIFILE", 7, 137623},
	{"TEGRETOL", 8, 137624},
	{"AILEY", 5, 137625},
	{"KIDDUSH", 7, 137626},
	{"HARAJUKU", 8, 137627},
	{"RAWLINSON", 9, 137628},
	{"SCUFFLE", 7, 137629},
	{"UDOD", 4, 137630},
	{"RTNU", 4, 137631},
	{"OKQU", 4, 137632},
	{"LSSM", 4, 137633},
	{"LKVI", 4, 137634},
	{"HUKR", 4, 137635},
	{"GJUR", 4, 137636},
	{"EDNR", 4, 137637},
	{"DEZD", 4, 137638},
	{"DCOX", 4, 137639},
	{"PURLEY", 6, 137640},
	{"RGP", 3, 137641},
	{"WALLFLOWER", 10, 137642},
	{"FORMALIZING", 11, 137643},
	{"ENOMEM", 6, 137644},
	{"EFTPOS", 6, 137645},
	{"YOAKUM", 6, 137646},
	{"UMCOR", 5, 137647},
	{"UNCRITICAL", 10, 137648},
	{"MARINELLI", 9, 137649},
	{"INFATUATED", 10, 137650},
	{"ARTIFICAL", 9, 137651},
	{"MILLINOCKET", 11, 137652},
	{"TOLLWAY", 7, 137653},
	{"HUMOUROUS", 9, 137654},
	{"STORMER", 7, 137655},
	{"ROBILLARD", 9, 137656},
	{"RECOMIENDA", 10, 137657},
	{"WILDLANDS", 9, 137658},
	{"WITHINGTON", 10, 137659},
	{"HOUSEBREAKING", 13, 137660},
	{"TENENBAUMS", 10, 137661},
	{"ORLD", 4, 137662},
	{"LINGFIELD", 9, 137663},
	{"DAREN", 5, 137664},
	{"CYGNET", 6, 137665},
	{"RHYTHMICALLY", 12, 137666},
	{"DAWE", 4, 137667},
	{"HAUGHEY", 7, 137668},
	{"DISQUES", 7, 137669},
	{"ISABELA", 7, 137670},
	{"TILDA", 5, 137671},
	{"LOADRUNNER", 10, 137672},
	{"TONSIL", 6, 137673},
	{"ROKDIM", 6, 137674},
	{"REAKTOR", 7, 137675},
	{"JOMASHOP", 8, 137676},
	{"RIOTOUS", 7, 137677},
	{"BURSTEIN", 8, 137678},
	{"FLORETS", 7, 137679},
	{"SWIX", 4, 137680},
	{"SONGFACTS", 9, 137681},
	{"TSLY", 4, 137682},
	{"TMRO", 4, 137683},
	{"RNJE", 4, 137684},
	{"OOKQ", 4, 137685},
	{"NBCO", 4, 137686},
	{"MTUN", 4, 137687},
	{"LFJU", 4, 137688},
	{"IZEJ", 4, 137689},
	{"IIPL", 4, 137690},
	{"EZUL", 4, 137691},
	{"CYVI", 4, 137692},
	{"CTTU", 4, 137693},
	{"BAJI", 4, 137694},
	{"NAVIN", 5, 137695},
	{"KAIJU", 5, 137696},
	{"FNORD", 5, 137697},
	{"DISAPOINTED", 11, 137698},
	{"SILICO", 6, 137699},
	{"REALARCADE", 10, 137700},
	{"NEWCOMBE", 8, 137701},
	{"GOLDBLUM", 8, 137702},
	{"GREETERS", 8, 137703},
	{"THROMBOTIC", 10, 137704},
	{"MIRNA", 5, 137705},
	{"UNIWILL", 7, 137706},
	{"MARTELLI", 8, 137707},
	{"PROMEDIA", 8, 137708},
	{"CHKCONFIG", 9, 137709},
	{"PARKHOTEL", 9, 137710},
	{"HANDTOOLS", 9, 137711},
	{"BARTOLI", 7, 137712},
	{"DOCETAXEL", 9, 137713},
	{"SCHNEIDLER", 10, 137714},
	{"DIRECTORSHIP", 12, 137715},
	{"POKHARA", 7, 137716},
	{"DURRELL", 7, 137717},
	{"BRAVADA", 7, 137718},
	{"FASHIONISTA", 11, 137719},
	{"ALAMY", 5, 137720},
	{"BALOGH", 6, 137721},
	{"TENGA", 5, 137722},
	{"ABROGATE", 8, 137723},
	{"WIRKSWORTH", 10, 137724},
	{"EMBITTERED", 10, 137725},
	{"WITHSTANDS", 10, 137726},
	{"HERING", 6, 137727},
	{"ZICA", 4, 137728},
	{"WLVI", 4, 137729},
	{"UPCU", 4, 137730},
	{"MPOM", 4, 137731},
	{"LTGA", 4, 137732},
	{"KKIT", 4, 137733},
	{"JETW", 4, 137734},
	{"GUCC", 4, 137735},
	{"SASUKE", 6, 137736},
	{"PARAMETRIZATION", 15, 137737},
	{"UNLEAVENED", 10, 137738},
	{"NUCLEOLAR", 9, 137739},
	{"LWLAN", 5, 137740},
	{"LINDISFARNE", 11, 137741},
	{"HUZZAH", 6, 137742},
	{"OSOYOOS", 7, 137743},
	{"MIREILLE", 8, 137744},
	{"TSUEN", 5, 137745},
	{"VECES", 5, 137746},
	{"THEGAME", 7, 137747},
	{"STOCKADE", 8, 137748},
	{"PARECE", 6, 137749},
	{"STARFORCE", 9, 137750},
	{"DETERMINABLE", 12, 137751},
	{"NORRIE", 6, 137752},
	{"DECONSTRUCT", 11, 137753},
	{"CLINKER", 7, 137754},
	{"BUSHMEN", 7, 137755},
	{"STRAWMAN", 8, 137756},
	{"DEGREASER", 9, 137757},
	{"SNAGIT", 6, 137758},
	{"GOOGLISM", 8, 137759},
	{"BIPHASIC", 8, 137760},
	{"PINKETT", 7, 137761},
	{"BABYLONIA", 9, 137762},
	{"KIDDO", 5, 137763},
	{"HUEBNER", 7, 137764},
	{"VELODYNE", 8, 137765},
	{"DOWNRIVER", 9, 137766},
	{"DJGPP", 5, 137767},
	{"TEMPTS", 6, 137768},
	{"FOOTSCRAY", 9, 137769},
	{"FAZE", 4, 137770},
	{"YROP", 4, 137771},
	{"UNCY", 4, 137772},
	{"SKIG", 4, 137773},
	{"RDJI", 4, 137774},
	{"QBAL", 4, 137775},
	{"OGSG", 4, 137776},
	{"NMOF", 4, 137777},
	{"LSHP", 4, 137778},
	{"HILY", 4, 137779},
	{"FTVS", 4, 137780},
	{"EVYW", 4, 137781},
	{"ERLD", 4, 137782},
	{"CELH", 4, 137783},
	{"BIPL", 4, 137784},
	{"BBOM", 4, 137785},
	{"AMNC", 4, 137786},
	{"ANGUSTIFOLIA", 12, 137787},
	{"TEMPEL", 6, 137788},
	{"PENMAN", 6, 137789},
	{"BELCONNEN", 9, 137790},
	{"WEBOBJECTS", 10, 137791},
	{"PFW", 3, 137792},
	{"ERDF", 4, 137793},
	{"PLAYMAN", 7, 137794},
	{"BOMBE", 5, 137795},
	{"FONTPATH", 8, 137796},
	{"MICROSYSTEM", 11, 137797},
	{"GOMERY", 6, 137798},
	{"DECLASSIFICATION", 16, 137799},
	{"ZAMBRANO", 8, 137800},
	{"FRIENDLYPRINTER", 15, 137801},
	{"RECRUTING", 9, 137802},
	{"TEMPEH", 6, 137803},
	{"TARBALLS", 8, 137804},
	{"MICROSTRIP", 10, 137805},
	{"WATERPROOFS", 11, 137806},
	{"GLAAD", 5, 137807},
	{"UPMINSTER", 9, 137808},
	{"MAQUILADORA", 11, 137809},
	{"FREEPOST", 8, 137810},
	{"HOLUX", 5, 137811},
	{"HENCHMAN", 8, 137812},
	{"UUR", 3, 137813},
	{"REDBACK", 7, 137814},
	{"PATROLMAN", 9, 137815},
	{"DEVOLVE", 7, 137816},
	{"ROBOCUP", 7, 137817},
	{"BASILISK", 8, 137818},
	{"ZRAT", 4, 137819},
	{"XTOM", 4, 137820},
	{"PCTH", 4, 137821},
	{"NKPU", 4, 137822},
	{"MEOD", 4, 137823},
	{"LDYI", 4, 137824},
	{"IKSC", 4, 137825},
	{"AMPJ", 4, 137826},
	{"NUKED", 5, 137827},
	{"FELDSTEIN", 9, 137828},
	{"KITAMURA", 8, 137829},
	{"VAMC", 4, 137830},
	{"BALDERDASH", 10, 137831},
	{"SANDBAR", 7, 137832},
	{"INTERNATIONA", 12, 137833},
	{"ENRIQUEZ", 8, 137834},
	{"SATYR", 5, 137835},
	{"FEARLESSLY", 10, 137836},
	{"BASHER", 6, 137837},
	{"PSIONIC", 7, 137838},
	{"VITALI", 6, 137839},
	{"AJAR", 4, 137840},
	{"TOBACCOS", 8, 137841},
	{"MINIGOLF", 8, 137842},
	{"PAMPAS", 6, 137843},
	{"AMUNDSEN", 8, 137844},
	{"WEIRDER", 7, 137845},
	{"SOCIOLINGUISTICS", 16, 137846},
	{"BAUDRILLARD", 11, 137847},
	{"AMEDEO", 6, 137848},
	{"KROSS", 5, 137849},
	{"ALTRA", 5, 137850},
	{"KIYOSHI", 7, 137851},
	{"EDGEWEAR", 8, 137852},
	{"FFICIENCY", 9, 137853},
	{"WLD", 3, 137854},
	{"ASHWELL", 7, 137855},
	{"TETRAODON", 9, 137856},
	{"SUPPERS", 7, 137857},
	{"HYPERTRANSPORT", 14, 137858},
	{"YPIF", 4, 137859},
	{"UACY", 4, 137860},
	{"TXAV", 4, 137861},
	{"TAYD", 4, 137862},
	{"RROE", 4, 137863},
	{"PAHU", 4, 137864},
	{"OCHY", 4, 137865},
	{"MJOE", 4, 137866},
	{"MIBO", 4, 137867},
	{"LMIE", 4, 137868},
	{"IGKI", 4, 137869},
	{"DAAU", 4, 137870},
	{"AEMB", 4, 137871},
	{"WESTMAN", 7, 137872},
	{"GWINN", 5, 137873},
	{"ARCHBOLD", 8, 137874},
	{"COALESCENCE", 11, 137875},
	{"EDMONSON", 8, 137876},
	{"REMITTING", 9, 137877},
	{"GOUNOD", 6, 137878},
	{"PCDATA", 6, 137879},
	{"FLUTTERED", 9, 137880},
	{"UNTRUSTWORTHY", 13, 137881},
	{"PARES", 5, 137882},
	{"MAMBER", 6, 137883},
	{"EXHORTED", 8, 137884},
	{"RECURVE", 7, 137885},
	{"GOSWAMI", 7, 137886},
	{"COPPERPLATE", 11, 137887},
	{"WINKY", 5, 137888},
	{"BITNET", 6, 137889},
	{"PKU", 3, 137890},
	{"GRAYED", 6, 137891},
	{"VOXELS", 6, 137892},
	{"ZISSOU", 6, 137893},
	{"ANTIGONISH", 10, 137894},
	{"ZEDY", 4, 137895},
	{"XRYA", 4, 137896},
	{"WSUG", 4, 137897},
	{"VYDA", 4, 137898},
	{"UDDW", 4, 137899},
	{"RUKR", 4, 137900},
	{"OGIF", 4, 137901},
	{"OFRD", 4, 137902},
	{"MJET", 4, 137903},
	{"HEQB", 4, 137904},
	{"FGOS", 4, 137905},
	{"DDSB", 4, 137906},
	{"CJAN", 4, 137907},
	{"RAVINES", 7, 137908},
	{"FIRECRACKERS", 12, 137909},
	{"JYOTI", 5, 137910},
	{"CRUCIS", 6, 137911},
	{"DIGIC", 5, 137912},
	{"EDGEMONT", 8, 137913},
	{"FEDERALISTS", 11, 137914},
	{"YOKES", 5, 137915},
	{"WAREWULF", 8, 137916},
	{"JAYDEN", 6, 137917},
	{"WINCHELL", 8, 137918},
	{"DATAVIZ", 7, 137919},
	{"ALLERGAN", 8, 137920},
	{"DETOXIFYING", 11, 137921},
	{"UNABASHEDLY", 11, 137922},
	{"SINDY", 5, 137923},
	{"HOWITZER", 8, 137924},
	{"NACHLIN", 7, 137925},
	{"INTELLIJ", 8, 137926},
	{"STRAWN", 6, 137927},
	{"OVERTURNS", 9, 137928},
	{"SPANX", 5, 137929},
	{"ZISW", 4, 137930},
	{"TGMT", 4, 137931},
	{"TAVR", 4, 137932},
	{"RKKA", 4, 137933},
	{"PTAX", 4, 137934},
	{"PCEL", 4, 137935},
	{"OWEU", 4, 137936},
	{"OFQA", 4, 137937},
	{"LSHL", 4, 137938},
	{"EVOG", 4, 137939},
	{"ELMR", 4, 137940},
	{"EDKL", 4, 137941},
	{"BHUN", 4, 137942},
	{"MYOGLOBIN", 9, 137943},
	{"NESSES", 6, 137944},
	{"COPYWRITE", 9, 137945},
	{"TALLYGENICOM", 12, 137946},
	{"LANTHANUM", 9, 137947},
	{"DIVERTS", 7, 137948},
	{"INTERJECTION", 12, 137949},
	{"NETIC", 5, 137950},
	{"WEBGUIDE", 8, 137951},
	{"MANSUR", 6, 137952},
	{"SPRINGWOOD", 10, 137953},
	{"SANDSTONES", 10, 137954},
	{"STOCKY", 6, 137955},
	{"FRAWLEY", 7, 137956},
	{"AZNAR", 5, 137957},
	{"OCTROI", 6, 137958},
	{"SIDCUP", 6, 137959},
	{"BLACKLISTS", 10, 137960},
	{"LEMOINE", 7, 137961},
	{"ARCHITECTED", 11, 137962},
	{"BAZAARS", 7, 137963},
	{"PELLEGRINI", 10, 137964},
	{"ROFF", 4, 137965},
	{"HIMMEL", 6, 137966},
	{"SAPHIR", 6, 137967},
	{"ELASTIN", 7, 137968},
	{"LEXISONE", 8, 137969},
	{"GREATE", 6, 137970},
	{"PDES", 4, 137971},
	{"ZASP", 4, 137972},
	{"YIPO", 4, 137973},
	{"WNKN", 4, 137974},
	{"UYUP", 4, 137975},
	{"UACU", 4, 137976},
	{"RSUV", 4, 137977},
	{"KETJ", 4, 137978},
	{"GOHU", 4, 137979},
	{"GLOY", 4, 137980},
	{"GGOW", 4, 137981},
	{"FFIM", 4, 137982},
	{"FCAK", 4, 137983},
	{"DTCO", 4, 137984},
	{"DIRV", 4, 137985},
	{"BEOC", 4, 137986},
	{"HAGLEY", 6, 137987},
	{"GEOSYSTEMS", 10, 137988},
	{"ICEROCKET", 9, 137989},
	{"STRENUOUSLY", 11, 137990},
	{"BANNOCKBURN", 11, 137991},
	{"STREPTAVIDIN", 12, 137992},
	{"AKTION", 6, 137993},
	{"ANDPOP", 6, 137994},
	{"LEFTHAND", 8, 137995},
	{"HARNAD", 6, 137996},
	{"KELLYS", 6, 137997},
	{"MANDER", 6, 137998},
	{"HEPES", 5, 137999},
	{"ANASTASIO", 9, 138000},
	{"KANEBO", 6, 138001},
	{"SKATEPARKS", 10, 138002},
	{"NEOCONSERVATIVE", 15, 138003},
	{"CECH", 4, 138004},
	{"MANUALI", 7, 138005},
	{"SHARPENS", 8, 138006},
	{"NAGATA", 6, 138007},
	{"WILDNESS", 8, 138008},
	{"STRANGLERS", 10, 138009},
	{"WXWINDOWS", 9, 138010},
	{"VIBRATER", 8, 138011},
	{"SYNERGISM", 9, 138012},
	{"CRIDER", 6, 138013},
	{"ALEUTIANS", 9, 138014},
	{"MCGANN", 6, 138015},
	{"CRABBE", 6, 138016},
	{"LOMITA", 6, 138017},
	{"WICKLIFFE", 9, 138018},
	{"YSTD", 4, 138019},
	{"YBAU", 4, 138020},
	{"SDWE", 4, 138021},
	{"RCKE", 4, 138022},
	{"NOVD", 4, 138023},
	{"DDNU", 4, 138024},
	{"CVOI", 4, 138025},
	{"BIEG", 4, 138026},
	{"TOBIT", 5, 138027},
	{"ARCHITECTING", 12, 138028},
	{"BEDI", 4, 138029},
	{"COMPENSATIONS", 13, 138030},
	{"TIKET", 5, 138031},
	{"NOVELLAS", 8, 138032},
	{"LILIA", 5, 138033},
	{"NITIES", 6, 138034},
	{"ACADEMICIANS", 12, 138035},
	{"CNOOC", 5, 138036},
	{"LAXITY", 6, 138037},
	{"KELANTAN", 8, 138038},
	{"ERETZ", 5, 138039},
	{"NATURALLYSPEAKING", 17, 138040},
	{"DEATHLY", 7, 138041},
	{"SHARRON", 7, 138042},
	{"DESPREZ", 7, 138043},
	{"OWYHEE", 6, 138044},
	{"TIMESAVING", 10, 138045},
	{"UNLOVED", 7, 138046},
	{"CHRISTAN", 8, 138047},
	{"BLAKEMORE", 9, 138048},
	{"CHICKWEED", 9, 138049},
	{"BALKED", 6, 138050},
	{"INTIMO", 6, 138051},
	{"EASYNET", 7, 138052},
	{"WHER", 4, 138053},
	{"FREESTATE", 9, 138054},
	{"TSYU", 4, 138055},
	{"SKWE", 4, 138056},
	{"NKVE", 4, 138057},
	{"NGBH", 4, 138058},
	{"IKCO", 4, 138059},
	{"DAZI", 4, 138060},
	{"FIPA", 4, 138061},
	{"FAIRYLAND", 9, 138062},
	{"CHETWYND", 8, 138063},
	{"CLARINDA", 8, 138064},
	{"BACHELET", 8, 138065},
	{"CLAVA", 5, 138066},
	{"MYND", 4, 138067},
	{"GURE", 4, 138068},
	{"EXER", 4, 138069},
	{"ADAMA", 5, 138070},
	{"SOURCEMEDIA", 11, 138071},
	{"MELILLA", 7, 138072},
	{"WCL", 3, 138073},
	{"TWOMEY", 6, 138074},
	{"LIFEBOATS", 9, 138075},
	{"SMOOTHWALL", 10, 138076},
	{"MINIGAMES", 9, 138077},
	{"COLQUITT", 8, 138078},
	{"TIPPIN", 6, 138079},
	{"CRYONICS", 8, 138080},
	{"ONGC", 4, 138081},
	{"GLYCOSYL", 8, 138082},
	{"CRUTCHER", 8, 138083},
	{"RAILCAR", 7, 138084},
	{"DTORONTO", 8, 138085},
	{"ESECT", 5, 138086},
	{"FERNSEHEN", 9, 138087},
	{"MUKESH", 6, 138088},
	{"INTERDEV", 8, 138089},
	{"PRESTWICH", 9, 138090},
	{"CMLENZ", 6, 138091},
	{"KRAFFT", 6, 138092},
	{"SLLO", 4, 138093},
	{"PONK", 4, 138094},
	{"KILR", 4, 138095},
	{"JAGI", 4, 138096},
	{"FAKA", 4, 138097},
	{"EPHK", 4, 138098},
	{"EMGM", 4, 138099},
	{"EFUZ", 4, 138100},
	{"EDKY", 4, 138101},
	{"EACM", 4, 138102},
	{"BERZ", 4, 138103},
	{"AWTW", 4, 138104},
	{"AJWA", 4, 138105},
	{"BALAAM", 6, 138106},
	{"GUNSHIP", 7, 138107},
	{"VITIS", 5, 138108},
	{"FOOK", 4, 138109},
	{"HAMAR", 5, 138110},
	{"SLOWDOWNS", 9, 138111},
	{"GALILEI", 7, 138112},
	{"VLF", 3, 138113},
	{"MILLETT", 7, 138114},
	{"AMEL", 4, 138115},
	{"INDUSTRIALLY", 12, 138116},
	{"STINGERS", 8, 138117},
	{"SCRIPTA", 7, 138118},
	{"MCMC", 4, 138119},
	{"ARTURIA", 7, 138120},
	{"HASSELT", 7, 138121},
	{"INFOSYSTEMS", 11, 138122},
	{"CATHOUSE", 8, 138123},
	{"COLONIE", 7, 138124},
	{"REKINDLED", 9, 138125},
	{"CSREES", 6, 138126},
	{"UJIW", 4, 138127},
	{"UGUN", 4, 138128},
	{"TUWA", 4, 138129},
	{"SMBO", 4, 138130},
	{"RCEK", 4, 138131},
	{"GYLO", 4, 138132},
	{"GHSY", 4, 138133},
	{"ETVM", 4, 138134},
	{"DEZB", 4, 138135},
	{"KIBBLE", 6, 138136},
	{"DRAMS", 5, 138137},
	{"ENTREAT", 7, 138138},
	{"MAILSTOP", 8, 138139},
	{"KISSER", 6, 138140},
	{"PRODUCTNAME", 11, 138141},
	{"BLOGROLLS", 9, 138142},
	{"ASHBURNHAM", 10, 138143},
	{"LYRLCS", 6, 138144},
	{"STRICH", 6, 138145},
	{"HODGKINSON", 10, 138146},
	{"MORENAS", 7, 138147},
	{"PUBLICISTS", 10, 138148},
	{"DOWNINGTOWN", 11, 138149},
	{"ZAKI", 4, 138150},
	{"IYRICS", 6, 138151},
	{"INTERVERTEBRAL", 14, 138152},
	{"CINEMARK", 8, 138153},
	{"KAYSERI", 7, 138154},
	{"KHODORKOVSKY", 12, 138155},
	{"NONCOMPETITIVE", 14, 138156},
	{"EHRENREICH", 10, 138157},
	{"WALLASEY", 8, 138158},
	{"GRAAL", 5, 138159},
	{"BRAINLESS", 9, 138160},
	{"BUSING", 6, 138161},
	{"AKADEMIKS", 9, 138162},
	{"BOLLES", 6, 138163},
	{"KUK", 3, 138164},
	{"EARTHMOVING", 11, 138165},
	{"CAMPEGGIO", 9, 138166},
	{"ANNIHILATOR", 11, 138167},
	{"ZAVA", 4, 138168},
	{"WPIN", 4, 138169},
	{"VSFO", 4, 138170},
	{"VRIL", 4, 138171},
	{"UNJO", 4, 138172},
	{"UABA", 4, 138173},
	{"SYUN", 4, 138174},
	{"NGHB", 4, 138175},
	{"MEVS", 4, 138176},
	{"MEKM", 4, 138177},
	{"LEXV", 4, 138178},
	{"GNAZ", 4, 138179},
	{"AWAJ", 4, 138180},
	{"FLOODWAY", 8, 138181},
	{"BARCLAYCARD", 11, 138182},
	{"JARRAH", 6, 138183},
	{"ENOUGHT", 7, 138184},
	{"BLOGDIGGER", 10, 138185},
	{"HENNIG", 6, 138186},
	{"SOUCI", 5, 138187},
	{"SCCP", 4, 138188},
	{"ABLUM", 5, 138189},
	{"PLACATE", 7, 138190},
	{"STORCH", 6, 138191},
	{"CADUCEUS", 8, 138192},
	{"QUENT", 5, 138193},
	{"BIOFILMS", 8, 138194},
	{"LEHTINEN", 8, 138195},
	{"PORTADOWN", 9, 138196},
	{"WAHPETON", 8, 138197},
	{"CESSING", 7, 138198},
	{"ISLEWORTH", 9, 138199},
	{"HUCKABEES", 9, 138200},
	{"REENACTED", 9, 138201},
	{"ANGELIS", 7, 138202},
	{"NOCHES", 6, 138203},
	{"SUBINTERFACE", 12, 138204},
	{"FDCS", 4, 138205},
	{"CAMPECHE", 8, 138206},
	{"ESTADISTICAS", 12, 138207},
	{"WFLE", 4, 138208},
	{"UNAY", 4, 138209},
	{"RKTV", 4, 138210},
	{"RFTO", 4, 138211},
	{"PIEB", 4, 138212},
	{"OLUK", 4, 138213},
	{"NDUV", 4, 138214},
	{"NDGN", 4, 138215},
	{"HUAM", 4, 138216},
	{"GMYA", 4, 138217},
	{"EKGB", 4, 138218},
	{"CRUF", 4, 138219},
	{"BSYO", 4, 138220},
	{"ALTOVA", 6, 138221},
	{"IMAGEURL", 8, 138222},
	{"FRAZEE", 6, 138223},
	{"PREQUALIFIED", 12, 138224},
	{"COCKING", 7, 138225},
	{"DAMIANA", 7, 138226},
	{"FOBS", 4, 138227},
	{"REVIEWABLE", 10, 138228},
	{"SORVINO", 7, 138229},
	{"IMMUNOCHEMISTRY", 15, 138230},
	{"ECHIDNE", 7, 138231},
	{"DIMIA", 5, 138232},
	{"DTSTART", 7, 138233},
	{"GATEWOOD", 8, 138234},
	{"IRKS", 4, 138235},
	{"HAMTARO", 7, 138236},
	{"ODEL", 4, 138237},
	{"NACHI", 5, 138238},
	{"ROLLERBLADING", 13, 138239},
	{"BRAMHALL", 8, 138240},
	{"RAILED", 6, 138241},
	{"LEMOND", 6, 138242},
	{"COEDUCATIONAL", 13, 138243},
	{"BIGBUTTS", 8, 138244},
	{"OCELOT", 6, 138245},
	{"ALSHANETSKY", 11, 138246},
	{"ABOUNDING", 9, 138247},
	{"CRISPER", 7, 138248},
	{"EVDB", 4, 138249},
	{"FOUNT", 5, 138250},
	{"BEAKERS", 7, 138251},
	{"AMBIDEXTROUS", 12, 138252},
	{"COGSWELL", 8, 138253},
	{"POACHER", 7, 138254},
	{"BLUMARINE", 9, 138255},
	{"YURE", 4, 138256},
	{"WDAL", 4, 138257},
	{"SEYV", 4, 138258},
	{"ROAG", 4, 138259},
	{"RGSS", 4, 138260},
	{"OEBB", 4, 138261},
	{"NBUZ", 4, 138262},
	{"LOUB", 4, 138263},
	{"LOEX", 4, 138264},
	{"KATK", 4, 138265},
	{"IDYN", 4, 138266},
	{"FKOL", 4, 138267},
	{"COKI", 4, 138268},
	{"CLIJ", 4, 138269},
	{"CDTH", 4, 138270},
	{"ABSD", 4, 138271},
	{"INVISIBLY", 9, 138272},
	{"TEMASEK", 7, 138273},
	{"UNDUPLICATED", 12, 138274},
	{"KOGA", 4, 138275},
	{"BRFSS", 5, 138276},
	{"JAHAN", 5, 138277},
	{"DRL", 3, 138278},
	{"RAFAL", 5, 138279},
	{"FANZINES", 8, 138280},
	{"MEANY", 5, 138281},
	{"WEBSERVERS", 10, 138282},
	{"SYSTEMES", 8, 138283},
	{"LITHE", 5, 138284},
	{"DILLEY", 6, 138285},
	{"OLBERMANN", 9, 138286},
	{"COVARIATE", 9, 138287},
	{"DONIPHAN", 8, 138288},
	{"NIEMI", 5, 138289},
	{"MONETA", 6, 138290},
	{"ANSER", 5, 138291},
	{"HIMMLER", 7, 138292},
	{"INTERCEDE", 9, 138293},
	{"POLYTOPE", 8, 138294},
	{"BICYCLIST", 9, 138295},
	{"EXCERCISES", 10, 138296},
	{"TUSKS", 5, 138297},
	{"SUPERLATIVES", 12, 138298},
	{"STORMREADY", 10, 138299},
	{"GENERALI", 8, 138300},
	{"CERTIFIABLE", 11, 138301},
	{"XICT", 4, 138302},
	{"WLSH", 4, 138303},
	{"TPOM", 4, 138304},
	{"RMTW", 4, 138305},
	{"PIFO", 4, 138306},
	{"OMUD", 4, 138307},
	{"MUDT", 4, 138308},
	{"MLSC", 4, 138309},
	{"MJOU", 4, 138310},
	{"MBYG", 4, 138311},
	{"LFAH", 4, 138312},
	{"GURS", 4, 138313},
	{"GIEV", 4, 138314},
	{"FGAB", 4, 138315},
	{"ARYZ", 4, 138316},
	{"LEKKER", 6, 138317},
	{"ADJUNCTIVE", 10, 138318},
	{"INTERFUND", 9, 138319},
	{"PAYOLA", 6, 138320},
	{"FFLUSH", 6, 138321},
	{"ACUERDO", 7, 138322},
	{"BOURBONNAIS", 11, 138323},
	{"BACALL", 6, 138324},
	{"PLEBISCITE", 10, 138325},
	{"LAMBERTVILLE", 12, 138326},
	{"VAASA", 5, 138327},
	{"HOSANNA", 7, 138328},
	{"HATTEN", 6, 138329},
	{"REVVED", 6, 138330},
	{"AYRTON", 6, 138331},
	{"FRIZZELL", 8, 138332},
	{"SUBGRADE", 8, 138333},
	{"PHOSPHATASES", 12, 138334},
	{"CRR", 3, 138335},
	{"RAPH", 4, 138336},
	{"OVERLAYING", 10, 138337},
	{"ONTOGENY", 8, 138338},
	{"ELONEX", 6, 138339},
	{"BLUSTERY", 8, 138340},
	{"COURTIER", 8, 138341},
	{"PRESCOT", 7, 138342},
	{"LINKERS", 7, 138343},
	{"VAPORIZATION", 12, 138344},
	{"BLOTTED", 7, 138345},
	{"ALASKANS", 8, 138346},
	{"AEROBATICS", 10, 138347},
	{"SNOWMELT", 8, 138348},
	{"CGL", 3, 138349},
	{"COPULATION", 10, 138350},
	{"IMPETUOUS", 9, 138351},
	{"AEROCOOL", 8, 138352},
	{"POZOSTA", 7, 138353},
	{"LIKENS", 6, 138354},
	{"UFAM", 4, 138355},
	{"STYK", 4, 138356},
	{"PHLI", 4, 138357},
	{"PCST", 4, 138358},
	{"OAMF", 4, 138359},
	{"OAKV", 4, 138360},
	{"MNWA", 4, 138361},
	{"KHOF", 4, 138362},
	{"GVAS", 4, 138363},
	{"FANK", 4, 138364},
	{"EPMC", 4, 138365},
	{"EKMS", 4, 138366},
	{"DKLA", 4, 138367},
	{"CHIRURGIA", 9, 138368},
	{"LEAGUERS", 8, 138369},
	{"RPTS", 4, 138370},
	{"THINKQUEST", 10, 138371},
	{"SONGTEKSTEN", 11, 138372},
	{"PAROXYSMAL", 10, 138373},
	{"GRAMMES", 7, 138374},
	{"MEMB", 4, 138375},
	{"ENVISAT", 7, 138376},
	{"SPRINGERLINK", 12, 138377},
	{"PROCPS", 6, 138378},
	{"ARBORIST", 8, 138379},
	{"ALTRIA", 6, 138380},
	{"UNCARING", 8, 138381},
	{"STARTPAGINA", 11, 138382},
	{"SHROUDS", 7, 138383},
	{"PICSTOP", 7, 138384},
	{"OMNIPAGE", 8, 138385},
	{"ALFRETON", 8, 138386},
	{"MARTINSON", 9, 138387},
	{"LOVEFILM", 8, 138388},
	{"AMBERGRIS", 9, 138389},
	{"CARDIGANSHIRE", 13, 138390},
	{"HELLEN", 6, 138391},
	{"CLEARNESS", 9, 138392},
	{"RCWA", 4, 138393},
	{"OYFI", 4, 138394},
	{"OBAW", 4, 138395},
	{"NWWI", 4, 138396},
	{"MMOM", 4, 138397},
	{"HCRY", 4, 138398},
	{"GUYY", 4, 138399},
	{"EZEC", 4, 138400},
	{"EJAL", 4, 138401},
	{"AYIP", 4, 138402},
	{"AOLD", 4, 138403},
	{"TRUYEN", 6, 138404},
	{"OPENBEOS", 8, 138405},
	{"EMBROIDER", 9, 138406},
	{"PRORATION", 9, 138407},
	{"LARGS", 5, 138408},
	{"OBFUSCATED", 10, 138409},
	{"FIFRA", 5, 138410},
	{"BELORUSSIA", 10, 138411},
	{"TALLAGHT", 8, 138412},
	{"AWAD", 4, 138413},
	{"MALMAISON", 9, 138414},
	{"BITSY", 5, 138415},
	{"FEUGIAT", 7, 138416},
	{"PIRANHAS", 8, 138417},
	{"DIOL", 4, 138418},
	{"CATEGORISE", 10, 138419},
	{"COXON", 5, 138420},
	{"EMOLLIENT", 9, 138421},
	{"NETGUIDE", 8, 138422},
	{"DEFAZIO", 7, 138423},
	{"HOSTETLER", 9, 138424},
	{"HUBBUB", 6, 138425},
	{"ROBED", 5, 138426},
	{"SOLHEIM", 7, 138427},
	{"URUK", 4, 138428},
	{"UNCHANGEABLE", 12, 138429},
	{"FLOS", 4, 138430},
	{"BENAVIDES", 9, 138431},
	{"CHOROID", 7, 138432},
	{"WOSW", 4, 138433},
	{"VYVE", 4, 138434},
	{"VSPR", 4, 138435},
	{"UZNE", 4, 138436},
	{"UTBC", 4, 138437},
	{"UEEM", 4, 138438},
	{"RCHQ", 4, 138439},
	{"ORFT", 4, 138440},
	{"NGCD", 4, 138441},
	{"LJAI", 4, 138442},
	{"LGOM", 4, 138443},
	{"HURY", 4, 138444},
	{"ECHY", 4, 138445},
	{"ECHV", 4, 138446},
	{"CASY", 4, 138447},
	{"AJJA", 4, 138448},
	{"ACFR", 4, 138449},
	{"PROX", 4, 138450},
	{"REENACTING", 10, 138451},
	{"TSMC", 4, 138452},
	{"NACIMIENTO", 10, 138453},
	{"IPEDS", 5, 138454},
	{"YKQ", 3, 138455},
	{"XVY", 3, 138456},
	{"XKF", 3, 138457},
	{"VKG", 3, 138458},
	{"QXG", 3, 138459},
	{"QUK", 3, 138460},
	{"JYC", 3, 138461},
	{"GZG", 3, 138462},
	{"CQV", 3, 138463},
	{"BWK", 3, 138464},
	{"CHINENSIS", 9, 138465},
	{"CHRISMAN", 8, 138466},
	{"WUNSCH", 6, 138467},
	{"LIGHTSTREAM", 11, 138468},
	{"OBJEXT", 6, 138469},
	{"EMPFEHLEN", 9, 138470},
	{"KEMPF", 5, 138471},
	{"CORAOPOLIS", 10, 138472},
	{"BIOPOLYMERS", 11, 138473},
	{"MAGISTERIAL", 11, 138474},
	{"TATTING", 7, 138475},
	{"CIDE", 4, 138476},
	{"DROOPY", 6, 138477},
	{"BOOR", 4, 138478},
	{"RECITES", 7, 138479},
	{"MARAH", 5, 138480},
	{"ANGUISHED", 9, 138481},
	{"ROSSLARE", 8, 138482},
	{"AILLEURS", 8, 138483},
	{"CRYS", 4, 138484},
	{"POSTOPERATIVELY", 15, 138485},
	{"YNAB", 4, 138486},
	{"WUSU", 4, 138487},
	{"VOFT", 4, 138488},
	{"THMD", 4, 138489},
	{"SDOV", 4, 138490},
	{"RMVA", 4, 138491},
	{"REZN", 4, 138492},
	{"PSGI", 4, 138493},
	{"PDIN", 4, 138494},
	{"OBGE", 4, 138495},
	{"NZAF", 4, 138496},
	{"LVAU", 4, 138497},
	{"KIMR", 4, 138498},
	{"GNGR", 4, 138499},
	{"FEGI", 4, 138500},
	{"FBAM", 4, 138501},
	{"EMUZ", 4, 138502},
	{"AWPU", 4, 138503},
	{"AMUG", 4, 138504},
	{"ODED", 4, 138505},
	{"MYCOBACTERIA", 12, 138506},
	{"METEORIC", 8, 138507},
	{"CGY", 3, 138508},
	{"BLOGSCANADA", 11, 138509},
	{"LTYPE", 5, 138510},
	{"WCD", 3, 138511},
	{"GETHOSTBYNAME", 13, 138512},
	{"ACFT", 4, 138513},
	{"RABIAR", 6, 138514},
	{"JACOPO", 6, 138515},
	{"IMMERSING", 9, 138516},
	{"EQUALLED", 8, 138517},
	{"RHEOLOGICAL", 11, 138518},
	{"UNREPRESENTED", 13, 138519},
	{"MARON", 5, 138520},
	{"CINEMACLOCK", 11, 138521},
	{"THREEPOINTGAIN", 14, 138522},
	{"PALABRA", 7, 138523},
	{"PELTS", 5, 138524},
	{"ARITHMETICAL", 12, 138525},
	{"BAYFRONT", 8, 138526},
	{"MACAWS", 6, 138527},
	{"TERRARIUM", 9, 138528},
	{"RINKER", 6, 138529},
	{"KERKOVE", 7, 138530},
	{"INNOTEK", 7, 138531},
	{"HINMAN", 6, 138532},
	{"MPIRT", 5, 138533},
	{"ROYALLY", 7, 138534},
	{"EGROUP", 6, 138535},
	{"WEHU", 4, 138536},
	{"VIAV", 4, 138537},
	{"UATU", 4, 138538},
	{"SKYK", 4, 138539},
	{"MVEE", 4, 138540},
	{"MOPR", 4, 138541},
	{"LBOI", 4, 138542},
	{"FEYA", 4, 138543},
	{"EXIG", 4, 138544},
	{"DAFYDD", 6, 138545},
	{"DATIVE", 6, 138546},
	{"RUD", 3, 138547},
	{"CHEEVER", 7, 138548},
	{"NADEZHDA", 8, 138549},
	{"RETRAIN", 7, 138550},
	{"BLASTN", 6, 138551},
	{"POESIA", 6, 138552},
	{"INSGESAMT", 9, 138553},
	{"MUSGROVE", 8, 138554},
	{"SMITHKLINE", 10, 138555},
	{"INITIALISED", 11, 138556},
	{"QUICKSHOP", 9, 138557},
	{"KOMBI", 5, 138558},
	{"DIFFRACTIVE", 11, 138559},
	{"ASHWOOD", 7, 138560},
	{"MOLLE", 5, 138561},
	{"PSAC", 4, 138562},
	{"NUOVI", 5, 138563},
	{"ALLPOP", 6, 138564},
	{"CERNER", 6, 138565},
	{"BLEOMYCIN", 9, 138566},
	{"SWORDPLAY", 9, 138567},
	{"HANRO", 5, 138568},
	{"NERGY", 5, 138569},
	{"SIRENA", 6, 138570},
	{"EINRICHTUNGEN", 13, 138571},
	{"PLANTES", 7, 138572},
	{"MAHABHARATA", 11, 138573},
	{"USMS", 4, 138574},
	{"MONTMORENCY", 11, 138575},
	{"ZZAM", 4, 138576},
	{"YNAD", 4, 138577},
	{"WISV", 4, 138578},
	{"TSKM", 4, 138579},
	{"RAQC", 4, 138580},
	{"OZAD", 4, 138581},
	{"MRLO", 4, 138582},
	{"MIGE", 4, 138583},
	{"MDUT", 4, 138584},
	{"KUKL", 4, 138585},
	{"GUEY", 4, 138586},
	{"ERDV", 4, 138587},
	{"EKVA", 4, 138588},
	{"DUKI", 4, 138589},
	{"DOXE", 4, 138590},
	{"DJOL", 4, 138591},
	{"AWKM", 4, 138592},
	{"AUNR", 4, 138593},
	{"AGDI", 4, 138594},
	{"BLINDFOLDS", 10, 138595},
	{"MIYUKI", 6, 138596},
	{"GARNERS", 7, 138597},
	{"BOLOGNESE", 9, 138598},
	{"BRITNY", 6, 138599},
	{"QUINOA", 6, 138600},
	{"NOBR", 4, 138601},
	{"NEPHROTIC", 9, 138602},
	{"MANALAPAN", 9, 138603},
	{"AUTOFILL", 8, 138604},
	{"ISABELL", 7, 138605},
	{"SCUBABOARD", 10, 138606},
	{"SHERIF", 6, 138607},
	{"AUTHORISES", 10, 138608},
	{"FLORICULTURE", 12, 138609},
	{"STRFTIME", 8, 138610},
	{"ARBITRON", 8, 138611},
	{"MINDERS", 7, 138612},
	{"LOGOER", 6, 138613},
	{"MECHELEN", 8, 138614},
	{"PRJ", 3, 138615},
	{"KAMINSKY", 8, 138616},
	{"MINOCYCLINE", 11, 138617},
	{"ZWICK", 5, 138618},
	{"PHENTRAMINE", 11, 138619},
	{"BAHAI", 5, 138620},
	{"WAVEFUNCTION", 12, 138621},
	{"INCLU", 5, 138622},
	{"EYEWASH", 7, 138623},
	{"TOPCOAT", 7, 138624},
	{"CHANGZHOU", 9, 138625},
	{"VINUM", 5, 138626},
	{"SILVERFISH", 10, 138627},
	{"HOBSONS", 7, 138628},
	{"DISHONORABLE", 12, 138629},
	{"CCLEANER", 8, 138630},
	{"QUADRUPLED", 10, 138631},
	{"THWARTING", 9, 138632},
	{"ANTIGO", 6, 138633},
	{"VENISE", 6, 138634},
	{"SOSIG", 5, 138635},
	{"CRACKPOT", 8, 138636},
	{"XPPMATH", 7, 138637},
	{"WWST", 4, 138638},
	{"UORC", 4, 138639},
	{"LDSJ", 4, 138640},
	{"KPUN", 4, 138641},
	{"FLUP", 4, 138642},
	{"ARUF", 4, 138643},
	{"SCURRYING", 9, 138644},
	{"ZEIGE", 5, 138645},
	{"BRACERS", 7, 138646},
	{"HOTLE", 5, 138647},
	{"DISCRIPTION", 11, 138648},
	{"DIARIOS", 7, 138649},
	{"YURY", 4, 138650},
	{"STOCKPOT", 8, 138651},
	{"KHERSON", 7, 138652},
	{"MICROGRAPH", 10, 138653},
	{"GUZZLER", 7, 138654},
	{"PHOTOSYSTEM", 11, 138655},
	{"DEVENS", 6, 138656},
	{"POGGIO", 6, 138657},
	{"BGR", 3, 138658},
	{"HURENVERZEICHNIS", 16, 138659},
	{"FROSTINGS", 9, 138660},
	{"BIGS", 4, 138661},
	{"SUBVERTED", 9, 138662},
	{"VIDEOCABLE", 10, 138663},
	{"HETEROGENOUS", 12, 138664},
	{"REWINDING", 9, 138665},
	{"FEEDLOTS", 8, 138666},
	{"DHCPD", 5, 138667},
	{"IMPREGNATION", 12, 138668},
	{"BISIMULATION", 12, 138669},
	{"SINGLETS", 8, 138670},
	{"CAPAC", 5, 138671},
	{"INSERM", 6, 138672},
	{"FLUORIDES", 9, 138673},
	{"WULFF", 5, 138674},
	{"TMPDEPFILE", 10, 138675},
	{"PRINTINGS", 9, 138676},
	{"MINIMALISTIC", 12, 138677},
	{"RESISTO", 7, 138678},
	{"SILICOSIS", 9, 138679},
	{"RETRIEVABLE", 11, 138680},
	{"SKANKY", 6, 138681},
	{"CHARITON", 8, 138682},
	{"YMYH", 4, 138683},
	{"VDRA", 4, 138684},
	{"SUGU", 4, 138685},
	{"LOBY", 4, 138686},
	{"KOKT", 4, 138687},
	{"ILLZ", 4, 138688},
	{"IFBI", 4, 138689},
	{"DKAH", 4, 138690},
	{"AMBT", 4, 138691},
	{"IXWIDTH", 7, 138692},
	{"BIRKIN", 6, 138693},
	{"IYWIDTH", 7, 138694},
	{"LAVENDAR", 8, 138695},
	{"MALTOSE", 7, 138696},
	{"KAVANAUGH", 9, 138697},
	{"ROOKERY", 7, 138698},
	{"KDP", 3, 138699},
	{"PASTORE", 7, 138700},
	{"PSFILE", 6, 138701},
	{"URBINO", 6, 138702},
	{"ENSINA", 6, 138703},
	{"SALVA", 5, 138704},
	{"AUTOMATICS", 10, 138705},
	{"MILBLOGS", 8, 138706},
	{"POEMAS", 6, 138707},
	{"CAOLAN", 6, 138708},
	{"IMMOLATION", 10, 138709},
	{"BITZI", 5, 138710},
	{"SCIP", 4, 138711},
	{"NYSSA", 5, 138712},
	{"CRAIGIE", 7, 138713},
	{"EFFETS", 6, 138714},
	{"BROADSWORD", 10, 138715},
	{"BLAXPLOITATION", 14, 138716},
	{"COLIMA", 6, 138717},
	{"INCONSISTENTLY", 14, 138718},
	{"PLANETOUT", 9, 138719},
	{"NRSV", 4, 138720},
	{"BYES", 4, 138721},
	{"MANUALES", 8, 138722},
	{"OREOS", 5, 138723},
	{"CHROMO", 6, 138724},
	{"TZKE", 4, 138725},
	{"PPII", 4, 138726},
	{"ORXU", 4, 138727},
	{"NEMD", 4, 138728},
	{"ERPB", 4, 138729},
	{"DECM", 4, 138730},
	{"BLANKLY", 7, 138731},
	{"BEAUDOIN", 8, 138732},
	{"TOTALBET", 8, 138733},
	{"GARNEAU", 7, 138734},
	{"TWIKISITE", 9, 138735},
	{"NAMAZU", 6, 138736},
	{"ZEPP", 4, 138737},
	{"MERRIE", 6, 138738},
	{"AURAS", 5, 138739},
	{"LITY", 4, 138740},
	{"WHINES", 6, 138741},
	{"TRIVET", 6, 138742},
	{"SCANF", 5, 138743},
	{"TYPHI", 5, 138744},
	{"PASTERNAK", 9, 138745},
	{"MISSLE", 6, 138746},
	{"BONFIRES", 8, 138747},
	{"CHANTRY", 7, 138748},
	{"SCRIPOPHILY", 11, 138749},
	{"MERCEDEZ", 8, 138750},
	{"BRINTON", 7, 138751},
	{"COVERDELL", 9, 138752},
	{"METABOLIFE", 10, 138753},
	{"OSVALDO", 7, 138754},
	{"ALLT", 4, 138755},
	{"TECHNOTE", 8, 138756},
	{"IBURST", 6, 138757},
	{"SPIRITUALIZED", 13, 138758},
	{"OCCASSIONAL", 11, 138759},
	{"LINDOWS", 7, 138760},
	{"ANDERSONS", 9, 138761},
	{"FURUKAWA", 8, 138762},
	{"ZORR", 4, 138763},
	{"XRIV", 4, 138764},
	{"WDCO", 4, 138765},
	{"SORQ", 4, 138766},
	{"RSHP", 4, 138767},
	{"RRIK", 4, 138768},
	{"ROBP", 4, 138769},
	{"PHBU", 4, 138770},
	{"LOBV", 4, 138771},
	{"DMOA", 4, 138772},
	{"AYEF", 4, 138773},
	{"CHUL", 4, 138774},
	{"DIVERGES", 8, 138775},
	{"MCNARY", 6, 138776},
	{"AUDIOSOURCE", 11, 138777},
	{"LEITNER", 7, 138778},
	{"VBCRLF", 6, 138779},
	{"SUDHIAN", 7, 138780},
	{"LIFEVIEW", 8, 138781},
	{"CLOUDLESS", 9, 138782},
	{"KEWLBOX", 7, 138783},
	{"CONFLAGRATION", 13, 138784},
	{"RECORDATION", 11, 138785},
	{"XENOPHON", 8, 138786},
	{"GENERAC", 7, 138787},
	{"CHARRON", 7, 138788},
	{"ENDOCRINOLOGISTS", 16, 138789},
	{"REZNOR", 6, 138790},
	{"KAVITA", 6, 138791},
	{"FONDANT", 7, 138792},
	{"SYMFWNA", 7, 138793},
	{"KORA", 4, 138794},
	{"PROSOLUTION", 11, 138795},
	{"STEREN", 6, 138796},
	{"GARTON", 6, 138797},
	{"BEVIS", 5, 138798},
	{"RESER", 5, 138799},
	{"GALTON", 6, 138800},
	{"REGIONALE", 9, 138801},
	{"FALMER", 6, 138802},
	{"YSIP", 4, 138803},
	{"XALO", 4, 138804},
	{"VOYW", 4, 138805},
	{"UXWH", 4, 138806},
	{"OVDI", 4, 138807},
	{"NMLB", 4, 138808},
	{"NKVI", 4, 138809},
	{"NDGB", 4, 138810},
	{"MGAZ", 4, 138811},
	{"MBBU", 4, 138812},
	{"LPTA", 4, 138813},
	{"LKAP", 4, 138814},
	{"KBYI", 4, 138815},
	{"IOBY", 4, 138816},
	{"GUAC", 4, 138817},
	{"FWAK", 4, 138818},
	{"FIXF", 4, 138819},
	{"FANJ", 4, 138820},
	{"ENDQ", 4, 138821},
	{"DCES", 4, 138822},
	{"BYMS", 4, 138823},
	{"BTRU", 4, 138824},
	{"BTOU", 4, 138825},
	{"AFEY", 4, 138826},
	{"NFIP", 4, 138827},
	{"UNDERMOUNT", 10, 138828},
	{"SKIED", 5, 138829},
	{"SAPHIRE", 7, 138830},
	{"PRNN", 4, 138831},
	{"SHAUKAT", 7, 138832},
	{"DETHRONED", 9, 138833},
	{"COURMAYEUR", 10, 138834},
	{"CHAPITRE", 8, 138835},
	{"ATHENEUM", 8, 138836},
	{"UXGA", 4, 138837},
	{"SPIRITUS", 8, 138838},
	{"MARKSMANSHIP", 12, 138839},
	{"BACKPLANES", 10, 138840},
	{"TAVIS", 5, 138841},
	{"GENEDLAETHOL", 12, 138842},
	{"VESTIGE", 7, 138843},
	{"SEEDLESS", 8, 138844},
	{"CARDI", 5, 138845},
	{"ENSONIQ", 7, 138846},
	{"MORTICIA", 8, 138847},
	{"TORRY", 5, 138848},
	{"ARTERITIS", 9, 138849},
	{"BRITTA", 6, 138850},
	{"SHOEING", 7, 138851},
	{"MCADAM", 6, 138852},
	{"BACLOFEN", 8, 138853},
	{"COURRIER", 8, 138854},
	{"CHEERFULNESS", 12, 138855},
	{"BATHTIME", 8, 138856},
	{"EGOISM", 6, 138857},
	{"FORNARINA", 9, 138858},
	{"KAPITI", 6, 138859},
	{"XIVE", 4, 138860},
	{"XCUP", 4, 138861},
	{"UXDE", 4, 138862},
	{"PJOE", 4, 138863},
	{"PIGI", 4, 138864},
	{"ONCC", 4, 138865},
	{"NPIZ", 4, 138866},
	{"MPUM", 4, 138867},
	{"IVYA", 4, 138868},
	{"GSKN", 4, 138869},
	{"GKER", 4, 138870},
	{"ETVW", 4, 138871},
	{"ECYY", 4, 138872},
	{"DAUE", 4, 138873},
	{"BAOF", 4, 138874},
	{"APEY", 4, 138875},
	{"UCK", 3, 138876},
	{"PROGRESO", 8, 138877},
	{"CATACLYSM", 9, 138878},
	{"HARRIED", 7, 138879},
	{"TRANSSHIPMENT", 13, 138880},
	{"GRIDLAB", 7, 138881},
	{"DISSIPATING", 11, 138882},
	{"MERWE", 5, 138883},
	{"HIROMI", 6, 138884},
	{"VILLIAN", 7, 138885},
	{"HOBBYNUTTE", 10, 138886},
	{"RIMBAUD", 7, 138887},
	{"STUDENTIN", 9, 138888},
	{"POSITIONER", 10, 138889},
	{"RANGEMAX", 8, 138890},
	{"HARRASS", 7, 138891},
	{"GUTMANN", 7, 138892},
	{"WYTHEVILLE", 10, 138893},
	{"BONHAMS", 7, 138894},
	{"REDSHIRT", 8, 138895},
	{"PINPOINTING", 11, 138896},
	{"GEEKBUDDIES", 11, 138897},
	{"RABY", 4, 138898},
	{"CEFN", 4, 138899},
	{"MILLMAN", 7, 138900},
	{"PKP", 3, 138901},
	{"OWASSO", 6, 138902},
	{"CUORE", 5, 138903},
	{"FORUMSNEW", 9, 138904},
	{"MILLSAPS", 8, 138905},
	{"DAVINA", 6, 138906},
	{"PANTO", 5, 138907},
	{"KAKE", 4, 138908},
	{"FATHERLESS", 10, 138909},
	{"INTVAL", 6, 138910},
	{"CERTIFIER", 9, 138911},
	{"DARIAN", 6, 138912},
	{"ACCLIMATION", 11, 138913},
	{"PUEDO", 5, 138914},
	{"GROEN", 5, 138915},
	{"GOMORRAH", 8, 138916},
	{"YLLR", 4, 138917},
	{"UIRM", 4, 138918},
	{"UEZD", 4, 138919},
	{"PTMY", 4, 138920},
	{"OGBR", 4, 138921},
	{"OFOG", 4, 138922},
	{"OBDU", 4, 138923},
	{"NGNB", 4, 138924},
	{"JAYF", 4, 138925},
	{"GNCR", 4, 138926},
	{"EZUR", 4, 138927},
	{"EXRY", 4, 138928},
	{"ERVU", 4, 138929},
	{"DUOR", 4, 138930},
	{"BSPI", 4, 138931},
	{"BCSN", 4, 138932},
	{"ATUW", 4, 138933},
	{"AIJU", 4, 138934},
	{"AMBICO", 6, 138935},
	{"ADDINS", 6, 138936},
	{"FLEISHER", 8, 138937},
	{"POWERMAX", 8, 138938},
	{"ANDOR", 5, 138939},
	{"ADVAITA", 7, 138940},
	{"SEERS", 5, 138941},
	{"STINGRAYS", 9, 138942},
	{"STOCKLIST", 9, 138943},
	{"KOMI", 4, 138944},
	{"CRETAN", 6, 138945},
	{"CAPSULAR", 8, 138946},
	{"ROUMANIA", 8, 138947},
	{"TWIKIGROUPS", 11, 138948},
	{"BABYDOLLS", 9, 138949},
	{"PENTEL", 6, 138950},
	{"PATHO", 5, 138951},
	{"EVANGELICALISM", 14, 138952},
	{"BODYSTOCKINGS", 13, 138953},
	{"BLUBBER", 7, 138954},
	{"ACCOMADATIONS", 13, 138955},
	{"APPEASED", 8, 138956},
	{"MATTES", 6, 138957},
	{"PHUONG", 6, 138958},
	{"KARTHIK", 7, 138959},
	{"BEGUM", 5, 138960},
	{"SOLARIUMS", 9, 138961},
	{"COAXED", 6, 138962},
	{"BOSSTONES", 9, 138963},
	{"PAGEANTRY", 9, 138964},
	{"BENZWORLD", 9, 138965},
	{"KDL", 3, 138966},
	{"ALACER", 6, 138967},
	{"HETTINGER", 9, 138968},
	{"POLITECH", 8, 138969},
	{"RACHMAD", 7, 138970},
	{"CASTELLON", 9, 138971},
	{"YLEJ", 4, 138972},
	{"YHAG", 4, 138973},
	{"WTIR", 4, 138974},
	{"WSKE", 4, 138975},
	{"UBBR", 4, 138976},
	{"SDYS", 4, 138977},
	{"RYUT", 4, 138978},
	{"RUBT", 4, 138979},
	{"RIDN", 4, 138980},
	{"OCMA", 4, 138981},
	{"GYTA", 4, 138982},
	{"AZZG", 4, 138983},
	{"AWPL", 4, 138984},
	{"AWNJ", 4, 138985},
	{"AWKT", 4, 138986},
	{"AKDU", 4, 138987},
	{"CTBT", 4, 138988},
	{"ICONOCLAST", 10, 138989},
	{"COORDI", 6, 138990},
	{"FAROOQ", 6, 138991},
	{"DISPARAGE", 9, 138992},
	{"ASSEM", 5, 138993},
	{"GONORRHOEAE", 11, 138994},
	{"MCREYNOLDS", 10, 138995},
	{"PREACHIN", 8, 138996},
	{"WEBGUI", 6, 138997},
	{"TRISTE", 6, 138998},
	{"VERBOTEN", 8, 138999},
	{"JACARANDA", 9, 139000},
	{"CHIMED", 6, 139001},
	{"NEWSVAC", 7, 139002},
	{"RINGBACK", 8, 139003},
	{"TEJANO", 6, 139004},
	{"COAUTHORS", 9, 139005},
	{"LUSSO", 5, 139006},
	{"LISTPROCESSOR", 13, 139007},
	{"KLONG", 5, 139008},
	{"TIKAL", 5, 139009},
	{"PORRO", 5, 139010},
	{"PHRASEOLOGY", 11, 139011},
	{"CHESSBOARD", 10, 139012},
	{"FGD", 3, 139013},
	{"FFFFCC", 6, 139014},
	{"QUADRANGLES", 11, 139015},
	{"BEATA", 5, 139016},
	{"TECHIMO", 7, 139017},
	{"ENZYMOL", 7, 139018},
	{"VERDIENEN", 9, 139019},
	{"GSIFTP", 6, 139020},
	{"GIDS", 4, 139021},
	{"ESTERRETT", 9, 139022},
	{"TOKG", 4, 139023},
	{"SPDF", 4, 139024},
	{"RUAS", 4, 139025},
	{"PRSQ", 4, 139026},
	{"PEAM", 4, 139027},
	{"OMYJ", 4, 139028},
	{"NWIG", 4, 139029},
	{"MKEY", 4, 139030},
	{"MDED", 4, 139031},
	{"LAIG", 4, 139032},
	{"FLSC", 4, 139033},
	{"FASF", 4, 139034},
	{"AFCE", 4, 139035},
	{"ZEDONG", 6, 139036},
	{"MEMOIRE", 7, 139037},
	{"ANYDAY", 6, 139038},
	{"XPOINTER", 8, 139039},
	{"MORASS", 6, 139040},
	{"GBROWSE", 7, 139041},
	{"REPAINTING", 10, 139042},
	{"ANTONE", 6, 139043},
	{"KINESTHETIC", 11, 139044},
	{"SELLARS", 7, 139045},
	{"MEGAUPLOAD", 10, 139046},
	{"INTIMES", 7, 139047},
	{"CLUCK", 5, 139048},
	{"SURED", 5, 139049},
	{"PRABANG", 7, 139050},
	{"CELESTICA", 9, 139051},
	{"WEBSEARCHADVANCED", 17, 139052},
	{"VERIFIERS", 9, 139053},
	{"PNAC", 4, 139054},
	{"KOBOLD", 6, 139055},
	{"DANMARKS", 8, 139056},
	{"RIGHTING", 8, 139057},
	{"SCHOENFELD", 10, 139058},
	{"KIAMA", 5, 139059},
	{"SEDAKA", 6, 139060},
	{"ACCTS", 5, 139061},
	{"INPUTSLOT", 9, 139062},
	{"ZOMBO", 5, 139063},
	{"GETATTR", 7, 139064},
	{"FUELWOOD", 8, 139065},
	{"MARLY", 5, 139066},
	{"DFF", 3, 139067},
	{"SUNET", 5, 139068},
	{"PIONS", 5, 139069},
	{"VADODARA", 8, 139070},
	{"PINKIE", 6, 139071},
	{"CUTTY", 5, 139072},
	{"MSCS", 4, 139073},
	{"BREAKUPS", 8, 139074},
	{"GATTON", 6, 139075},
	{"MAIDENFORM", 10, 139076},
	{"RAMPAGING", 9, 139077},
	{"EMLYN", 5, 139078},
	{"YAOF", 4, 139079},
	{"XFAL", 4, 139080},
	{"TMUD", 4, 139081},
	{"ROYU", 4, 139082},
	{"RLAH", 4, 139083},
	{"OLMB", 4, 139084},
	{"OCHF", 4, 139085},
	{"LYOA", 4, 139086},
	{"FSYL", 4, 139087},
	{"EMRP", 4, 139088},
	{"EILG", 4, 139089},
	{"EDYK", 4, 139090},
	{"DRMU", 4, 139091},
	{"CDAL", 4, 139092},
	{"BYAE", 4, 139093},
	{"BTOL", 4, 139094},
	{"ARXS", 4, 139095},
	{"MODER", 5, 139096},
	{"TRAVELLERSPOINT", 15, 139097},
	{"DESSUS", 6, 139098},
	{"STATISTICSTOPIC", 15, 139099},
	{"PESTANA", 7, 139100},
	{"SOUTHBEACH", 10, 139101},
	{"CONUNDRUMS", 10, 139102},
	{"MONTEIL", 7, 139103},
	{"BARAGA", 6, 139104},
	{"MEMBRANOUS", 10, 139105},
	{"WEBTOPICEDITTEMPLATE", 20, 139106},
	{"STRIDING", 8, 139107},
	{"NONFEDERAL", 10, 139108},
	{"PATES", 5, 139109},
	{"TOILETING", 9, 139110},
	{"EFNET", 5, 139111},
	{"SOUTIEN", 7, 139112},
	{"DECS", 4, 139113},
	{"VPON", 4, 139114},
	{"PCINU", 5, 139115},
	{"HOXTON", 6, 139116},
	{"MEUCCI", 6, 139117},
	{"SEUG", 4, 139118},
	{"SEGW", 4, 139119},
	{"PYPA", 4, 139120},
	{"PSAU", 4, 139121},
	{"OZZO", 4, 139122},
	{"MHUG", 4, 139123},
	{"KYAB", 4, 139124},
	{"KAFK", 4, 139125},
	{"IXPI", 4, 139126},
	{"FJAY", 4, 139127},
	{"DHUA", 4, 139128},
	{"CIOW", 4, 139129},
	{"NEPENTHES", 9, 139130},
	{"STIRRER", 7, 139131},
	{"TUBEROUS", 8, 139132},
	{"CALLIGRAPHIC", 12, 139133},
	{"SILLIMAN", 8, 139134},
	{"PANELLING", 9, 139135},
	{"SLUMPS", 6, 139136},
	{"BANDLEADER", 10, 139137},
	{"BRAVING", 7, 139138},
	{"NAZCA", 5, 139139},
	{"EPARTMENT", 9, 139140},
	{"BBG", 3, 139141},
	{"LONGREACH", 9, 139142},
	{"WATERBODIES", 11, 139143},
	{"COLECTIVO", 9, 139144},
	{"PURKINJE", 8, 139145},
	{"SHUSWAP", 7, 139146},
	{"PRAYERFUL", 9, 139147},
	{"SPIEGELMAN", 10, 139148},
	{"BODYSUITS", 9, 139149},
	{"HOMEBASE", 8, 139150},
	{"EJECTIONS", 9, 139151},
	{"RAAD", 4, 139152},
	{"DLD", 3, 139153},
	{"RENCE", 5, 139154},
	{"ZCLA", 4, 139155},
	{"YNNC", 4, 139156},
	{"TTCR", 4, 139157},
	{"SSUZ", 4, 139158},
	{"RDRM", 4, 139159},
	{"PETL", 4, 139160},
	{"OZYA", 4, 139161},
	{"NWIM", 4, 139162},
	{"MURU", 4, 139163},
	{"LKTR", 4, 139164},
	{"IDYS", 4, 139165},
	{"EEWR", 4, 139166},
	{"BSGR", 4, 139167},
	{"QUOTIENTS", 9, 139168},
	{"TRANSFIXED", 10, 139169},
	{"UNDERCARRIAGE", 13, 139170},
	{"PERSPEX", 7, 139171},
	{"BALLE", 5, 139172},
	{"TORCHED", 7, 139173},
	{"BASHES", 6, 139174},
	{"GLIOMAS", 7, 139175},
	{"HOSTER", 6, 139176},
	{"LEAVEN", 6, 139177},
	{"SAYLE", 5, 139178},
	{"NESHAP", 6, 139179},
	{"GANODERMA", 9, 139180},
	{"ECONOMICA", 9, 139181},
	{"TAUCK", 5, 139182},
	{"SCOLAIRE", 8, 139183},
	{"IOWEGIAN", 8, 139184},
	{"SOLWAY", 6, 139185},
	{"MNEMOC", 6, 139186},
	{"WENTZ", 5, 139187},
	{"PROFANTASY", 10, 139188},
	{"ORLOWSKI", 8, 139189},
	{"LOUT", 4, 139190},
	{"TOSHIO", 6, 139191},
	{"TREF", 4, 139192},
	{"IMMUNOLOGISTS", 13, 139193},
	{"CURVEBALL", 9, 139194},
	{"TUCKING", 7, 139195},
	{"SUPERCHICKEN", 12, 139196},
	{"UNWARY", 6, 139197},
	{"SEIJI", 5, 139198},
	{"ALDERGROVE", 10, 139199},
	{"PRETENSES", 9, 139200},
	{"DEHYDROGENASES", 14, 139201},
	{"SADHANA", 7, 139202},
	{"HERRINGS", 8, 139203},
	{"ZBAL", 4, 139204},
	{"WVAN", 4, 139205},
	{"WDSW", 4, 139206},
	{"VWRI", 4, 139207},
	{"UHIR", 4, 139208},
	{"TUFC", 4, 139209},
	{"RWEF", 4, 139210},
	{"OVYC", 4, 139211},
	{"OPYF", 4, 139212},
	{"OOMV", 4, 139213},
	{"MNIM", 4, 139214},
	{"MLEI", 4, 139215},
	{"MIRM", 4, 139216},
	{"HNDR", 4, 139217},
	{"GIFE", 4, 139218},
	{"GIEG", 4, 139219},
	{"FGLI", 4, 139220},
	{"ECRT", 4, 139221},
	{"DDHO", 4, 139222},
	{"AZYD", 4, 139223},
	{"AXLO", 4, 139224},
	{"APCR", 4, 139225},
	{"BUDDEN", 6, 139226},
	{"CUBIT", 5, 139227},
	{"EUROPEO", 7, 139228},
	{"SCHWALBE", 8, 139229},
	{"VAMPYRE", 7, 139230},
	{"JOYBEE", 6, 139231},
	{"ETTORE", 6, 139232},
	{"LABORNET", 8, 139233},
	{"BROMBERG", 8, 139234},
	{"SMARTFTP", 8, 139235},
	{"SUPRISINGLY", 11, 139236},
	{"PARCELLS", 8, 139237},
	{"BEGETS", 6, 139238},
	{"GROUNDLESS", 10, 139239},
	{"GHAR", 4, 139240},
	{"PRANCING", 8, 139241},
	{"VSYA", 4, 139242},
	{"LETSSINGIT", 10, 139243},
	{"DPY", 3, 139244},
	{"MEGUIAR", 7, 139245},
	{"DVF", 3, 139246},
	{"AMELIORATION", 12, 139247},
	{"WARK", 4, 139248},
	{"BEELD", 5, 139249},
	{"TOOLBOXES", 9, 139250},
	{"ERRORED", 7, 139251},
	{"GRAEMEL", 7, 139252},
	{"BKG", 3, 139253},
	{"CATARRHINI", 10, 139254},
	{"FLOODLIT", 8, 139255},
	{"FPG", 3, 139256},
	{"STAHLGRUBERRING", 15, 139257},
	{"XAMO", 4, 139258},
	{"POOC", 4, 139259},
	{"LNCA", 4, 139260},
	{"KYMI", 4, 139261},
	{"KBYF", 4, 139262},
	{"IRIZ", 4, 139263},
	{"HUPD", 4, 139264},
	{"GMEF", 4, 139265},
	{"EBSU", 4, 139266},
	{"DWIM", 4, 139267},
	{"BYSQ", 4, 139268},
	{"BUCI", 4, 139269},
	{"REPETITIOUS", 11, 139270},
	{"BIVALVE", 7, 139271},
	{"LICENCIA", 8, 139272},
	{"CMAQ", 4, 139273},
	{"LEGISLATIONS", 12, 139274},
	{"FEBBRAIO", 8, 139275},
	{"PRESSURISED", 11, 139276},
	{"DGR", 3, 139277},
	{"FORIEGN", 7, 139278},
	{"PRESTRESSING", 12, 139279},
	{"KYUSS", 5, 139280},
	{"NAVPOD", 6, 139281},
	{"HEALTHLINE", 10, 139282},
	{"COOLSCAN", 8, 139283},
	{"COLOSTOMY", 9, 139284},
	{"BICKEL", 6, 139285},
	{"HENRYK", 6, 139286},
	{"FROMAN", 6, 139287},
	{"UNIMPLEMENTED", 13, 139288},
	{"RECA", 4, 139289},
	{"HOLIDAYMAKERS", 13, 139290},
	{"HEATLEY", 7, 139291},
	{"EXTRACTABLE", 11, 139292},
	{"CONSER", 6, 139293},
	{"BROME", 5, 139294},
	{"BEZAHLEN", 8, 139295},
	{"TWEEDIE", 7, 139296},
	{"SCHOOLTOOL", 10, 139297},
	{"OLIGOCENE", 9, 139298},
	{"CERS", 4, 139299},
	{"HAQUE", 5, 139300},
	{"EPICA", 5, 139301},
	{"MIGHTIER", 8, 139302},
	{"LWF", 3, 139303},
	{"ENTHRONED", 9, 139304},
	{"ZDEL", 4, 139305},
	{"YPEV", 4, 139306},
	{"WUPL", 4, 139307},
	{"UMJU", 4, 139308},
	{"SZIM", 4, 139309},
	{"SILR", 4, 139310},
	{"RPIK", 4, 139311},
	{"RDYF", 4, 139312},
	{"PJUM", 4, 139313},
	{"HAYF", 4, 139314},
	{"GMOF", 4, 139315},
	{"EZIL", 4, 139316},
	{"EFBO", 4, 139317},
	{"DJIG", 4, 139318},
	{"BSUM", 4, 139319},
	{"POSTON", 6, 139320},
	{"ECRM", 4, 139321},
	{"OVERBURDENED", 12, 139322},
	{"DECRIED", 7, 139323},
	{"CRUICKSHANK", 11, 139324},
	{"POSSIBLITY", 10, 139325},
	{"REAMED", 6, 139326},
	{"DWINDLE", 7, 139327},
	{"TELEFONEROTIK", 13, 139328},
	{"MIGLIORI", 8, 139329},
	{"QURESHI", 7, 139330},
	{"WPD", 3, 139331},
	{"APPA", 4, 139332},
	{"MULTIPLEXES", 11, 139333},
	{"BARBA", 5, 139334},
	{"WHOLESALES", 10, 139335},
	{"VINCA", 5, 139336},
	{"ANUNTURI", 8, 139337},
	{"NZXT", 4, 139338},
	{"LINDAU", 6, 139339},
	{"BETER", 5, 139340},
	{"ONEAL", 5, 139341},
	{"SUJETS", 6, 139342},
	{"NATURALES", 9, 139343},
	{"HYPERFINE", 9, 139344},
	{"ACQUIESCE", 9, 139345},
	{"ALLOWWEBVIEW", 12, 139346},
	{"VERHOEVEN", 9, 139347},
	{"FOER", 4, 139348},
	{"DEPFILE", 7, 139349},
	{"ALACRITY", 8, 139350},
	{"INTERCONNECTEDNESS", 18, 139351},
	{"LOGISYS", 7, 139352},
	{"WORKAHOLIC", 10, 139353},
	{"EXTER", 5, 139354},
	{"DRAWBRIDGE", 10, 139355},
	{"REMCO", 5, 139356},
	{"INDEPENDANCE", 12, 139357},
	{"ZONL", 4, 139358},
	{"XPOW", 4, 139359},
	{"TVIK", 4, 139360},
	{"TTDR", 4, 139361},
	{"RFCA", 4, 139362},
	{"MEPM", 4, 139363},
	{"LTGU", 4, 139364},
	{"LPTI", 4, 139365},
	{"LLKO", 4, 139366},
	{"JOVA", 4, 139367},
	{"IKHM", 4, 139368},
	{"HALJ", 4, 139369},
	{"FUAN", 4, 139370},
	{"EZME", 4, 139371},
	{"ERKC", 4, 139372},
	{"ENYW", 4, 139373},
	{"DUMN", 4, 139374},
	{"DRSU", 4, 139375},
	{"CROK", 4, 139376},
	{"BODD", 4, 139377},
	{"ADKO", 4, 139378},
	{"GUDE", 4, 139379},
	{"GEOGRAPHICS", 11, 139380},
	{"OVERHAULING", 11, 139381},
	{"GEOMODEL", 8, 139382},
	{"QUIZZED", 7, 139383},
	{"GIRLE", 5, 139384},
	{"LOCATIVE", 8, 139385},
	{"ACAPPELLA", 9, 139386},
	{"ADVANCEDTCA", 11, 139387},
	{"NAYAK", 5, 139388},
	{"JEMS", 4, 139389},
	{"CALLANDER", 9, 139390},
	{"TAPSCOTT", 8, 139391},
	{"SUBSEVEN", 8, 139392},
	{"ZIMBABWEANS", 11, 139393},
	{"DISKUSSION", 10, 139394},
	{"ANOXIA", 6, 139395},
	{"MISR", 4, 139396},
	{"MDU", 3, 139397},
	{"SARUMAN", 7, 139398},
	{"PULVERIZED", 10, 139399},
	{"PENINSULAS", 10, 139400},
	{"KINYO", 5, 139401},
	{"TEACHERVISION", 13, 139402},
	{"MURPHEY", 7, 139403},
	{"HARDT", 5, 139404},
	{"BIOCHEMICALS", 12, 139405},
	{"WYBIERZ", 7, 139406},
	{"BLOGGIN", 7, 139407},
	{"CUTOFFS", 7, 139408},
	{"HOLIER", 6, 139409},
	{"SITENAME", 8, 139410},
	{"OVERSTOCKED", 11, 139411},
	{"JWR", 3, 139412},
	{"MAUER", 5, 139413},
	{"USYL", 4, 139414},
	{"SAMK", 4, 139415},
	{"PVAR", 4, 139416},
	{"PTHW", 4, 139417},
	{"PDOO", 4, 139418},
	{"MHIR", 4, 139419},
	{"IAWR", 4, 139420},
	{"EUBU", 4, 139421},
	{"EFSR", 4, 139422},
	{"DUOP", 4, 139423},
	{"DGKI", 4, 139424},
	{"REALL", 5, 139425},
	{"TICKETFAST", 10, 139426},
	{"YHWH", 4, 139427},
	{"VOUT", 4, 139428},
	{"TECTION", 7, 139429},
	{"HYPODERMIC", 10, 139430},
	{"SIGNIF", 6, 139431},
	{"SELOUS", 6, 139432},
	{"AMMAR", 5, 139433},
	{"BONECRUSHER", 11, 139434},
	{"SEGMENTING", 10, 139435},
	{"JEWELLERYNOW", 12, 139436},
	{"NONEQUILIBRIUM", 14, 139437},
	{"EVERARD", 7, 139438},
	{"BRIGG", 5, 139439},
	{"JIZZED", 6, 139440},
	{"CHUGACH", 7, 139441},
	{"RENDEROSITY", 11, 139442},
	{"HEATHERS", 8, 139443},
	{"PIXY", 4, 139444},
	{"COOMA", 5, 139445},
	{"TITJOBS", 7, 139446},
	{"CARF", 4, 139447},
	{"DREAMGIRL", 9, 139448},
	{"STRATEGIE", 9, 139449},
	{"EPICENTRE", 9, 139450},
	{"IGAMES", 6, 139451},
	{"KURODA", 6, 139452},
	{"HARDESTY", 8, 139453},
	{"MUGGING", 7, 139454},
	{"GASBUDDY", 8, 139455},
	{"BRP", 3, 139456},
	{"FFR", 3, 139457},
	{"AUROBINDO", 9, 139458},
	{"SCOTTSBORO", 10, 139459},
	{"RESOUCES", 8, 139460},
	{"SPARKMAN", 8, 139461},
	{"ZESL", 4, 139462},
	{"WCOP", 4, 139463},
	{"UVEJ", 4, 139464},
	{"SMRO", 4, 139465},
	{"PGEO", 4, 139466},
	{"PACP", 4, 139467},
	{"NGTD", 4, 139468},
	{"NDLD", 4, 139469},
	{"LFNA", 4, 139470},
	{"GGYP", 4, 139471},
	{"GAYD", 4, 139472},
	{"FFSY", 4, 139473},
	{"DSUV", 4, 139474},
	{"CGAI", 4, 139475},
	{"BROP", 4, 139476},
	{"BEOL", 4, 139477},
	{"BBTH", 4, 139478},
	{"WIREHAIRED", 10, 139479},
	{"DNEPROPETROVSK", 14, 139480},
	{"UNZIPPING", 9, 139481},
	{"UNCIVIL", 7, 139482},
	{"COTON", 5, 139483},
	{"DEHYDRATASE", 11, 139484},
	{"SARASWATI", 9, 139485},
	{"CREDE", 5, 139486},
	{"COMMERCIALE", 11, 139487},
	{"SCEGLI", 6, 139488},
	{"MANASQUAN", 9, 139489},
	{"PUPPETEER", 9, 139490},
	{"KAZOO", 5, 139491},
	{"DVCPRO", 6, 139492},
	{"ARPU", 4, 139493},
	{"NONDESCRIPT", 11, 139494},
	{"BENFIELD", 8, 139495},
	{"BULA", 4, 139496},
	{"EMPLOYES", 8, 139497},
	{"CHECKOFF", 8, 139498},
	{"WWOW", 4, 139499},
	{"SUWH", 4, 139500},
	{"POZN", 4, 139501},
	{"LGEL", 4, 139502},
	{"LBIK", 4, 139503},
	{"KUBR", 4, 139504},
	{"FSSU", 4, 139505},
	{"EWKA", 4, 139506},
	{"DMEP", 4, 139507},
	{"DADG", 4, 139508},
	{"CROH", 4, 139509},
	{"BUXT", 4, 139510},
	{"BOTF", 4, 139511},
	{"ARLK", 4, 139512},
	{"FURR", 4, 139513},
	{"FREESWAN", 8, 139514},
	{"AZATHIOPRINE", 12, 139515},
	{"TEMPERAMENTS", 12, 139516},
	{"PROVA", 5, 139517},
	{"PHOTOFINISHING", 14, 139518},
	{"BLG", 3, 139519},
	{"DOLMEN", 6, 139520},
	{"CONSULTER", 9, 139521},
	{"RIBONUCLEOPROTEIN", 17, 139522},
	{"SIMPLETON", 9, 139523},
	{"HSRP", 4, 139524},
	{"BUILDPACKAGE", 12, 139525},
	{"ARANDA", 6, 139526},
	{"GONADS", 6, 139527},
	{"MISTRY", 6, 139528},
	{"BRUTES", 6, 139529},
	{"HOWSOEVER", 9, 139530},
	{"SLAX", 4, 139531},
	{"KAWAMURA", 8, 139532},
	{"LEDERMAN", 8, 139533},
	{"PUTUMAYO", 8, 139534},
	{"GENETICISTS", 11, 139535},
	{"NOVEMBRO", 8, 139536},
	{"SLEAFORD", 8, 139537},
	{"NYSTAGMUS", 9, 139538},
	{"VMX", 3, 139539},
	{"GIVERNY", 7, 139540},
	{"BREAKDANCE", 10, 139541},
	{"BROOKSHIRE", 10, 139542},
	{"AUTODATA", 8, 139543},
	{"NIOBRARA", 8, 139544},
	{"SUNRIVER", 8, 139545},
	{"ZETR", 4, 139546},
	{"WORP", 4, 139547},
	{"VAVI", 4, 139548},
	{"THBB", 4, 139549},
	{"RTZM", 4, 139550},
	{"OJAY", 4, 139551},
	{"NWAU", 4, 139552},
	{"KKIC", 4, 139553},
	{"KAIW", 4, 139554},
	{"HIMQ", 4, 139555},
	{"FNFL", 4, 139556},
	{"CSRU", 4, 139557},
	{"ARJI", 4, 139558},
	{"DENYWEBVIEW", 11, 139559},
	{"NELSONS", 7, 139560},
	{"INNOPOCKET", 10, 139561},
	{"LIMAVADY", 8, 139562},
	{"UNSYMPATHETIC", 13, 139563},
	{"HAILSHAM", 8, 139564},
	{"CAHOKIA", 7, 139565},
	{"PANHELLENIC", 11, 139566},
	{"BOGGLES", 7, 139567},
	{"VASU", 4, 139568},
	{"SNIFFS", 6, 139569},
	{"EXPECTANCIES", 12, 139570},
	{"GRANDIFLORA", 11, 139571},
	{"NONRELATIVES", 12, 139572},
	{"ATURE", 5, 139573},
	{"COMMIES", 7, 139574},
	{"LINDALE", 7, 139575},
	{"PAQUETES", 8, 139576},
	{"NUTRABOLICS", 11, 139577},
	{"ICFTU", 5, 139578},
	{"VELLORE", 7, 139579},
	{"STSCI", 5, 139580},
	{"SISTEM", 6, 139581},
	{"CALLAO", 6, 139582},
	{"DIAGEO", 6, 139583},
	{"REPOR", 5, 139584},
	{"XTPE", 4, 139585},
	{"WJUN", 4, 139586},
	{"RRWH", 4, 139587},
	{"PVOL", 4, 139588},
	{"OXIF", 4, 139589},
	{"NJIL", 4, 139590},
	{"HFAB", 4, 139591},
	{"FMTH", 4, 139592},
	{"FBUE", 4, 139593},
	{"DUSL", 4, 139594},
	{"DSTB", 4, 139595},
	{"DRYN", 4, 139596},
	{"BEYB", 4, 139597},
	{"ASDW", 4, 139598},
	{"WIVENHOE", 8, 139599},
	{"SKLAVIN", 7, 139600},
	{"BOSCA", 5, 139601},
	{"YOPER", 5, 139602},
	{"JAPS", 4, 139603},
	{"JOINTER", 7, 139604},
	{"GOMA", 4, 139605},
	{"BLACKSHEAR", 10, 139606},
	{"SCHACHTER", 9, 139607},
	{"CATOOSA", 7, 139608},
	{"MCDEVITT", 8, 139609},
	{"JERMYN", 6, 139610},
	{"COBDEN", 6, 139611},
	{"ASSICURAZIONE", 13, 139612},
	{"GAMETECH", 8, 139613},
	{"DICO", 4, 139614},
	{"WOODCUTS", 8, 139615},
	{"DALEVILLE", 9, 139616},
	{"NEWSHOUNDS", 10, 139617},
	{"MULTIPOLE", 9, 139618},
	{"MORISON", 7, 139619},
	{"GAFFE", 5, 139620},
	{"HOSTINGDATA", 11, 139621},
	{"REJOINDER", 9, 139622},
	{"SYSCO", 5, 139623},
	{"POCKER", 6, 139624},
	{"NATIONHOOD", 10, 139625},
	{"DIFFERENTIATOR", 14, 139626},
	{"AUTOMART", 8, 139627},
	{"PARTSTORE", 9, 139628},
	{"GOOOD", 5, 139629},
	{"CONDESCENSION", 13, 139630},
	{"ANTONELA", 8, 139631},
	{"ZILH", 4, 139632},
	{"XINM", 4, 139633},
	{"WSOW", 4, 139634},
	{"SKYV", 4, 139635},
	{"OBIF", 4, 139636},
	{"NJOV", 4, 139637},
	{"MUNF", 4, 139638},
	{"MLEW", 4, 139639},
	{"LHYG", 4, 139640},
	{"HBYO", 4, 139641},
	{"BSCL", 4, 139642},
	{"AWAZ", 4, 139643},
	{"ANWY", 4, 139644},
	{"CHUGGING", 8, 139645},
	{"CPSHOP", 6, 139646},
	{"CELLULITIS", 10, 139647},
	{"ENDPAPER", 8, 139648},
	{"REEXAMINE", 9, 139649},
	{"BABYSTRICH", 10, 139650},
	{"RUDIN", 5, 139651},
	{"DAUR", 4, 139652},
	{"TROUBLEMAKERS", 13, 139653},
	{"MARKEL", 6, 139654},
	{"MUTO", 4, 139655},
	{"MARISOL", 7, 139656},
	{"KEMPSEY", 7, 139657},
	{"CONSERVATORS", 12, 139658},
	{"ZENEGRA", 7, 139659},
	{"SOONG", 5, 139660},
	{"NULLPOINTEREXCEPTION", 20, 139661},
	{"HARTREE", 7, 139662},
	{"TIETEN", 6, 139663},
	{"SIUC", 4, 139664},
	{"VIVICA", 6, 139665},
	{"CEPHALOPODS", 11, 139666},
	{"MAJORA", 6, 139667},
	{"KYOLIC", 6, 139668},
	{"PETRUCCI", 8, 139669},
	{"EUROCONTROL", 11, 139670},
	{"PARTHA", 6, 139671},
	{"CALVADOS", 8, 139672},
	{"NEWSTEAD", 8, 139673},
	{"ATLUS", 5, 139674},
	{"NUCLEOSIDES", 11, 139675},
	{"OTHERNESS", 9, 139676},
	{"IRONWORKS", 9, 139677},
	{"BAUMGARTEN", 10, 139678},
	{"GOALKEEPERS", 11, 139679},
	{"DILATE", 6, 139680},
	{"ALBANESE", 8, 139681},
	{"MAGAZINECITY", 12, 139682},
	{"OYAMA", 5, 139683},
	{"HAUSFELD", 8, 139684},
	{"SKIPJACK", 8, 139685},
	{"PROTRUDE", 8, 139686},
	{"ZZOA", 4, 139687},
	{"WYMA", 4, 139688},
	{"UHIG", 4, 139689},
	{"UDOG", 4, 139690},
	{"UCKK", 4, 139691},
	{"SBEU", 4, 139692},
	{"ICZS", 4, 139693},
	{"GHSR", 4, 139694},
	{"DDGR", 4, 139695},
	{"BCOA", 4, 139696},
	{"AJID", 4, 139697},
	{"AUSFX", 5, 139698},
	{"RASCH", 5, 139699},
	{"AUTOMOBILIA", 11, 139700},
	{"IONISING", 8, 139701},
	{"IGBT", 4, 139702},
	{"SUPERDISH", 9, 139703},
	{"TOKICO", 6, 139704},
	{"LEAKEY", 6, 139705},
	{"IRRESISTABLE", 12, 139706},
	{"SCRAPPER", 8, 139707},
	{"FADEAWAY", 8, 139708},
	{"PHPXREF", 7, 139709},
	{"SEASONIC", 8, 139710},
	{"PLURALS", 7, 139711},
	{"NUOVE", 5, 139712},
	{"TIBER", 5, 139713},
	{"FREEECARDS", 10, 139714},
	{"CEPH", 4, 139715},
	{"BABYCENTRE", 10, 139716},
	{"SPAREN", 6, 139717},
	{"UNCERTIFIED", 11, 139718},
	{"CALFED", 6, 139719},
	{"VIETH", 5, 139720},
	{"KANGA", 5, 139721},
	{"BERARD", 6, 139722},
	{"BEKANNTSCHAFT", 13, 139723},
	{"TACX", 4, 139724},
	{"ORMSKIRK", 8, 139725},
	{"FEUER", 5, 139726},
	{"FELATIO", 7, 139727},
	{"GLAST", 5, 139728},
	{"ASSISTIR", 8, 139729},
	{"GEBHARDT", 8, 139730},
	{"YVAG", 4, 139731},
	{"YOPA", 4, 139732},
	{"YLOH", 4, 139733},
	{"XCRI", 4, 139734},
	{"WLSU", 4, 139735},
	{"WGON", 4, 139736},
	{"TMMA", 4, 139737},
	{"TDRM", 4, 139738},
	{"RDEK", 4, 139739},
	{"NFLL", 4, 139740},
	{"NFCE", 4, 139741},
	{"MCEE", 4, 139742},
	{"LNDA", 4, 139743},
	{"KKAM", 4, 139744},
	{"EUWI", 4, 139745},
	{"ERAX", 4, 139746},
	{"DUPV", 4, 139747},
	{"BUSG", 4, 139748},
	{"WOODLAKE", 8, 139749},
	{"HIGDON", 6, 139750},
	{"PLR", 3, 139751},
	{"SECOURS", 7, 139752},
	{"ATARAX", 6, 139753},
	{"SKILFULLY", 9, 139754},
	{"PHOSPHOPROTEIN", 14, 139755},
	{"GRADWELL", 8, 139756},
	{"RADISON", 7, 139757},
	{"HUCKABEE", 8, 139758},
	{"GRAZIANO", 8, 139759},
	{"CYSWLLT", 7, 139760},
	{"ZVON", 4, 139761},
	{"ABOLITIONISTS", 13, 139762},
	{"FARRAKHAN", 9, 139763},
	{"REGISTRE", 8, 139764},
	{"GUAY", 4, 139765},
	{"AKOCOMMENT", 10, 139766},
	{"PREPROGRAMMED", 13, 139767},
	{"POINTWISE", 9, 139768},
	{"EUROMONITOR", 11, 139769},
	{"LEMAIRE", 7, 139770},
	{"FLUSTERED", 9, 139771},
	{"KIRCHHOFF", 9, 139772},
	{"PHOTOLYSIS", 10, 139773},
	{"DITTON", 6, 139774},
	{"POWDERPUFF", 10, 139775},
	{"FROOMKIN", 8, 139776},
	{"PENFOLD", 7, 139777},
	{"FCF", 3, 139778},
	{"TURB", 4, 139779},
	{"POISONINGS", 10, 139780},
	{"MUFFY", 5, 139781},
	{"STARSHIPS", 9, 139782},
	{"FRUITVALE", 9, 139783},
	{"LFG", 3, 139784},
	{"NAROPA", 6, 139785},
	{"CEDING", 6, 139786},
	{"NONNUDE", 7, 139787},
	{"TANDEMS", 7, 139788},
	{"REGRESSED", 9, 139789},
	{"TELCORDIA", 9, 139790},
	{"ALGEBRAICALLY", 13, 139791},
	{"COMPACTLY", 9, 139792},
	{"BASANTI", 7, 139793},
	{"LASSES", 6, 139794},
	{"ZILB", 4, 139795},
	{"URPS", 4, 139796},
	{"PLCA", 4, 139797},
	{"NPEG", 4, 139798},
	{"NMAW", 4, 139799},
	{"MCOW", 4, 139800},
	{"LYRS", 4, 139801},
	{"HUMV", 4, 139802},
	{"GMTH", 4, 139803},
	{"FASQ", 4, 139804},
	{"EGBR", 4, 139805},
	{"EBAZ", 4, 139806},
	{"DVAG", 4, 139807},
	{"DCLY", 4, 139808},
	{"AUNP", 4, 139809},
	{"BURANA", 6, 139810},
	{"RECIEVES", 8, 139811},
	{"KUNGFU", 6, 139812},
	{"EPIGENETIC", 10, 139813},
	{"HALOTHANE", 9, 139814},
	{"FONDAZIONE", 10, 139815},
	{"LOGINNAME", 9, 139816},
	{"CORSAGE", 7, 139817},
	{"ILBO", 4, 139818},
	{"AMEROCK", 7, 139819},
	{"SEYED", 5, 139820},
	{"LABOURED", 8, 139821},
	{"NETTER", 6, 139822},
	{"ADGRUNTS", 8, 139823},
	{"REVIER", 6, 139824},
	{"ENUMERATES", 10, 139825},
	{"TWIGGY", 6, 139826},
	{"YMCHWIL", 7, 139827},
	{"STERILIZE", 9, 139828},
	{"PREWITT", 7, 139829},
	{"UNRELIABILITY", 13, 139830},
	{"CLARIAN", 7, 139831},
	{"EVOLUTIONARILY", 14, 139832},
	{"INTERVENTIONIST", 15, 139833},
	{"DALAL", 5, 139834},
	{"COLLIMATION", 11, 139835},
	{"PIJN", 4, 139836},
	{"RHIZOBIUM", 9, 139837},
	{"DECIR", 5, 139838},
	{"RAYBAN", 6, 139839},
	{"PCPN", 4, 139840},
	{"FILESERVER", 10, 139841},
	{"BLACKMUN", 8, 139842},
	{"PROTEOBACTERIA", 14, 139843},
	{"LEITE", 5, 139844},
	{"DUBIN", 5, 139845},
	{"UTILI", 5, 139846},
	{"MADBALL", 7, 139847},
	{"EVALU", 5, 139848},
	{"RELINQUISHMENT", 14, 139849},
	{"XKIL", 4, 139850},
	{"WSJA", 4, 139851},
	{"VDOF", 4, 139852},
	{"TFID", 4, 139853},
	{"NOMP", 4, 139854},
	{"KYOW", 4, 139855},
	{"HLCO", 4, 139856},
	{"EZFI", 4, 139857},
	{"ERBJ", 4, 139858},
	{"CGAN", 4, 139859},
	{"CDPL", 4, 139860},
	{"BESQ", 4, 139861},
	{"GOLDMEMBER", 10, 139862},
	{"MORNINGWOOD", 11, 139863},
	{"AIRWOLF", 7, 139864},
	{"APPROPRI", 8, 139865},
	{"CLOTHIER", 8, 139866},
	{"SALL", 4, 139867},
	{"ALUG", 4, 139868},
	{"GOLLANCZ", 8, 139869},
	{"SPAMBOT", 7, 139870},
	{"EXPUNGED", 8, 139871},
	{"CESSION", 7, 139872},
	{"IMPOVERISHMENT", 14, 139873},
	{"LIKEN", 5, 139874},
	{"BELLEVIEW", 9, 139875},
	{"FORFEITS", 8, 139876},
	{"ROADY", 5, 139877},
	{"WASECA", 6, 139878},
	{"CLUBCARD", 8, 139879},
	{"MADDISON", 8, 139880},
	{"UNRECOGNIZABLE", 14, 139881},
	{"HEEDING", 7, 139882},
	{"WAKKA", 5, 139883},
	{"PICC", 4, 139884},
	{"NODELIST", 8, 139885},
	{"VIVIANE", 7, 139886},
	{"URIU", 4, 139887},
	{"RMSV", 4, 139888},
	{"RIBM", 4, 139889},
	{"RCOX", 4, 139890},
	{"MSLU", 4, 139891},
	{"KHAG", 4, 139892},
	{"REVENU", 6, 139893},
	{"HELDER", 6, 139894},
	{"VIRGINIANA", 10, 139895},
	{"RECURSE", 7, 139896},
	{"SCHOOLDAY", 9, 139897},
	{"CRIMINALIZE", 11, 139898},
	{"SCOIL", 5, 139899},
	{"MAGNUSSEN", 9, 139900},
	{"VERDER", 6, 139901},
	{"NOSEY", 5, 139902},
	{"CAESAREA", 8, 139903},
	{"VIDO", 4, 139904},
	{"STYLISTICALLY", 13, 139905},
	{"CARLILE", 7, 139906},
	{"SANDCASTLE", 10, 139907},
	{"NETCONF", 7, 139908},
	{"CONGENERS", 9, 139909},
	{"WXYZ", 4, 139910},
	{"NATURELLE", 9, 139911},
	{"PFLAG", 5, 139912},
	{"IPRISM", 6, 139913},
	{"MISCELLANOUS", 12, 139914},
	{"MAGMATIC", 8, 139915},
	{"DGL", 3, 139916},
	{"PLICATION", 9, 139917},
	{"WORDLESS", 8, 139918},
	{"DBR", 3, 139919},
	{"GALLILEUS", 9, 139920},
	{"REPLANTING", 10, 139921},
	{"UPPITY", 6, 139922},
	{"UHCI", 4, 139923},
	{"TINSELTOWN", 10, 139924},
	{"CMDS", 4, 139925},
	{"OPIC", 4, 139926},
	{"OLAM", 4, 139927},
	{"AULA", 4, 139928},
	{"CHEP", 4, 139929},
	{"BLAKENEY", 8, 139930},
	{"RESTURANTS", 10, 139931},
	{"FLIPBOOK", 8, 139932},
	{"SLEEPILY", 8, 139933},
	{"COSABELLA", 9, 139934},
	{"BUILDBOT", 8, 139935},
	{"PROWLING", 8, 139936},
	{"KNOCKOUTS", 9, 139937},
	{"SELLECK", 7, 139938},
	{"PAMUK", 5, 139939},
	{"YLCH", 4, 139940},
	{"UETU", 4, 139941},
	{"UDHU", 4, 139942},
	{"RUCA", 4, 139943},
	{"PMAM", 4, 139944},
	{"OLUX", 4, 139945},
	{"NJUB", 4, 139946},
	{"NBYZ", 4, 139947},
	{"MSGU", 4, 139948},
	{"LVIT", 4, 139949},
	{"KLYJ", 4, 139950},
	{"HEJC", 4, 139951},
	{"GHSD", 4, 139952},
	{"EYMY", 4, 139953},
	{"AXSC", 4, 139954},
	{"WDF", 3, 139955},
	{"QUALLS", 6, 139956},
	{"CRESCENTA", 9, 139957},
	{"CHEMILUMINESCENCE", 17, 139958},
	{"LAMPSHADES", 10, 139959},
	{"HOLMDEL", 7, 139960},
	{"DISSING", 7, 139961},
	{"STAGLIANO", 9, 139962},
	{"MAGELLANIC", 10, 139963},
	{"ULTRAFILTRATION", 15, 139964},
	{"KAURI", 5, 139965},
	{"LETTUCES", 8, 139966},
	{"DELISLE", 7, 139967},
	{"THRESHOLDING", 12, 139968},
	{"HARMONIE", 8, 139969},
	{"KYPE", 4, 139970},
	{"ELUDES", 6, 139971},
	{"REVELRY", 7, 139972},
	{"SURROGACY", 9, 139973},
	{"DEFACE", 6, 139974},
	{"ZHIVAGO", 7, 139975},
	{"BURDETTE", 8, 139976},
	{"CHAMBRAY", 8, 139977},
	{"PROPENSITIES", 12, 139978},
	{"RETRACTS", 8, 139979},
	{"DARR", 4, 139980},
	{"WITOLD", 6, 139981},
	{"MIMICKED", 8, 139982},
	{"EXPS", 4, 139983},
	{"METAPHASE", 9, 139984},
	{"BASHKIR", 7, 139985},
	{"ESUPPORT", 8, 139986},
	{"CHAMINADE", 9, 139987},
	{"SNOWBABIES", 10, 139988},
	{"MARGARETS", 9, 139989},
	{"YJAK", 4, 139990},
	{"XERR", 4, 139991},
	{"VEEU", 4, 139992},
	{"UONC", 4, 139993},
	{"UAPR", 4, 139994},
	{"ROXF", 4, 139995},
	{"OFBS", 4, 139996},
	{"MIWE", 4, 139997},
	{"LMOP", 4, 139998},
	{"IIFR", 4, 139999},
	{"CUPV", 4, 140000},
	{"CAMW", 4, 140001},
	{"BOFW", 4, 140002},
	{"DEZEMBRO", 8, 140003},
	{"WORKSAFE", 8, 140004},
	{"NIZED", 5, 140005},
	{"CAMCHAT", 7, 140006},
	{"SALADIN", 7, 140007},
	{"ALGUNAS", 7, 140008},
	{"MAYANS", 6, 140009},
	{"BOOMAN", 6, 140010},
	{"BETTI", 5, 140011},
	{"NOOBS", 5, 140012},
	{"TECHWYSE", 8, 140013},
	{"UNAFFORDABLE", 12, 140014},
	{"AREF", 4, 140015},
	{"REGA", 4, 140016},
	{"UNINJURED", 9, 140017},
	{"BADAJOZ", 7, 140018},
	{"ICHIGO", 6, 140019},
	{"RIVAGE", 6, 140020},
	{"MUGU", 4, 140021},
	{"INVESTEC", 8, 140022},
	{"HOGGING", 7, 140023},
	{"PSYCHOBILLY", 11, 140024},
	{"PROJO", 5, 140025},
	{"WEIGAND", 7, 140026},
	{"GYNAECOLOGICAL", 14, 140027},
	{"NEWVALUE", 8, 140028},
	{"BUCKTHORN", 9, 140029},
	{"WHITTON", 7, 140030},
	{"POPULAIRE", 9, 140031},
	{"LOWCARB", 7, 140032},
	{"HAYWIRE", 7, 140033},
	{"DATABASED", 9, 140034},
	{"WORDLIST", 8, 140035},
	{"DESU", 4, 140036},
	{"CLIENTI", 7, 140037},
	{"ROSALIA", 7, 140038},
	{"STORYBOOKS", 10, 140039},
	{"MONTLY", 6, 140040},
	{"PASTORALISTS", 12, 140041},
	{"WWWYAHOO", 8, 140042},
	{"STRONGARM", 9, 140043},
	{"LIGATED", 7, 140044},
	{"YODH", 4, 140045},
	{"UYAF", 4, 140046},
	{"SPFO", 4, 140047},
	{"RKMY", 4, 140048},
	{"RCYW", 4, 140049},
	{"NAUP", 4, 140050},
	{"MTAY", 4, 140051},
	{"LAHL", 4, 140052},
	{"DSGL", 4, 140053},
	{"CPHY", 4, 140054},
	{"CEEG", 4, 140055},
	{"CDOR", 4, 140056},
	{"APHB", 4, 140057},
	{"CLATHRIN", 8, 140058},
	{"YUKIO", 5, 140059},
	{"LIEF", 4, 140060},
	{"DAYWATCH", 8, 140061},
	{"XANTHIA", 7, 140062},
	{"REINTERPRETATION", 16, 140063},
	{"LITIGIOUS", 9, 140064},
	{"TODDY", 5, 140065},
	{"PERIMETERS", 10, 140066},
	{"WORLDWORKS", 10, 140067},
	{"MALIC", 5, 140068},
	{"DORSETT", 7, 140069},
	{"ANNEXIN", 7, 140070},
	{"DISHEARTENED", 12, 140071},
	{"BICONE", 6, 140072},
	{"RUINOUS", 7, 140073},
	{"VOLUMEN", 7, 140074},
	{"OVERAGE", 7, 140075},
	{"MESIC", 5, 140076},
	{"DOMENICA", 8, 140077},
	{"SPOOR", 5, 140078},
	{"STEREOPHILE", 11, 140079},
	{"UPANISHADS", 10, 140080},
	{"MARLIES", 7, 140081},
	{"URY", 3, 140082},
	{"ZGG", 3, 140083},
	{"WGJ", 3, 140084},
	{"UQL", 3, 140085},
	{"KQK", 3, 140086},
	{"JQB", 3, 140087},
	{"DXQ", 3, 140088},
	{"CLQ", 3, 140089},
	{"CODEPAGE", 8, 140090},
	{"DOKUMENTATION", 13, 140091},
	{"SYMONE", 6, 140092},
	{"EIGENE", 6, 140093},
	{"BEWITCHING", 10, 140094},
	{"STEIGENBERGER", 13, 140095},
	{"ETZIONI", 7, 140096},
	{"AFFILIATEVISTA", 14, 140097},
	{"BNWOT", 5, 140098},
	{"PONDERINGS", 10, 140099},
	{"PROTOPIC", 8, 140100},
	{"ENGRISH", 7, 140101},
	{"KDD", 3, 140102},
	{"YKJA", 4, 140103},
	{"WFLY", 4, 140104},
	{"UTIU", 4, 140105},
	{"UTCT", 4, 140106},
	{"RAFC", 4, 140107},
	{"INMD", 4, 140108},
	{"GSIV", 4, 140109},
	{"FEKI", 4, 140110},
	{"FCUP", 4, 140111},
	{"ERFT", 4, 140112},
	{"ECWE", 4, 140113},
	{"DSKG", 4, 140114},
	{"BGAM", 4, 140115},
	{"AYKH", 4, 140116},
	{"AHGR", 4, 140117},
	{"SKALA", 5, 140118},
	{"FISTIN", 6, 140119},
	{"SNOWBLIND", 9, 140120},
	{"DISCI", 5, 140121},
	{"GFSO", 4, 140122},
	{"WKSU", 4, 140123},
	{"ELEFUN", 6, 140124},
	{"RECLOSABLE", 10, 140125},
	{"ICEHOUSE", 8, 140126},
	{"LUGGING", 7, 140127},
	{"ANNOUNCMENTS", 12, 140128},
	{"INDIVIDU", 8, 140129},
	{"GEAC", 4, 140130},
	{"PROTOMAP", 8, 140131},
	{"COCKERMOUTH", 11, 140132},
	{"CHRISTOLOGY", 11, 140133},
	{"PETES", 5, 140134},
	{"EQUALIZING", 10, 140135},
	{"DEVOS", 5, 140136},
	{"WADS", 4, 140137},
	{"CHEMI", 5, 140138},
	{"BACKSTOP", 8, 140139},
	{"WANTAGH", 7, 140140},
	{"GEHALT", 6, 140141},
	{"JACQUET", 7, 140142},
	{"KDEGAMES", 8, 140143},
	{"MCRYPT", 6, 140144},
	{"MCCHESNEY", 9, 140145},
	{"SUCEUSE", 7, 140146},
	{"READIN", 6, 140147},
	{"NAWAZ", 5, 140148},
	{"CARELL", 6, 140149},
	{"LEADOFF", 7, 140150},
	{"ACCUSERS", 8, 140151},
	{"SUNSHADE", 8, 140152},
	{"GOODLIFE", 8, 140153},
	{"BEAKED", 6, 140154},
	{"SWOP", 4, 140155},
	{"SYNAPTICS", 9, 140156},
	{"CUIR", 4, 140157},
	{"XORT", 4, 140158},
	{"WIMG", 4, 140159},
	{"UKIO", 4, 140160},
	{"RGME", 4, 140161},
	{"RDKO", 4, 140162},
	{"NPBS", 4, 140163},
	{"MPMM", 4, 140164},
	{"MIPO", 4, 140165},
	{"HYIL", 4, 140166},
	{"FEAP", 4, 140167},
	{"CEXI", 4, 140168},
	{"BSUS", 4, 140169},
	{"AWMY", 4, 140170},
	{"AQFO", 4, 140171},
	{"LATHAN", 6, 140172},
	{"DOILY", 5, 140173},
	{"COLTER", 6, 140174},
	{"CAREERJOURNAL", 13, 140175},
	{"HERP", 4, 140176},
	{"CRASSA", 6, 140177},
	{"DMSP", 4, 140178},
	{"MAINTE", 6, 140179},
	{"GRAAFF", 6, 140180},
	{"SUOMEA", 6, 140181},
	{"CAMBIAR", 7, 140182},
	{"LUVERNE", 7, 140183},
	{"TELEADAPT", 9, 140184},
	{"CLEVELEYS", 9, 140185},
	{"WOWED", 5, 140186},
	{"RATEABLE", 8, 140187},
	{"WOCHENENDE", 10, 140188},
	{"REORGANIZATIONS", 15, 140189},
	{"CANDYMAN", 8, 140190},
	{"YAEL", 4, 140191},
	{"PARTSORDER", 10, 140192},
	{"CUTTLEFISH", 10, 140193},
	{"BIBIONE", 7, 140194},
	{"WIGTOWNSHIRE", 12, 140195},
	{"SHEPLERS", 8, 140196},
	{"JOMTIEN", 7, 140197},
	{"TRAINOR", 7, 140198},
	{"TACTICALLY", 10, 140199},
	{"ROADSIDES", 9, 140200},
	{"LEUKEMIAS", 9, 140201},
	{"FURROWS", 7, 140202},
	{"THRONGS", 7, 140203},
	{"AMARTH", 6, 140204},
	{"MCMINN", 6, 140205},
	{"NANOWIRES", 9, 140206},
	{"SOMMAIRE", 8, 140207},
	{"SARCOPHAGUS", 11, 140208},
	{"PARSHAS", 7, 140209},
	{"CHALMETTE", 9, 140210},
	{"FIORINA", 7, 140211},
	{"DOZING", 6, 140212},
	{"YMCM", 4, 140213},
	{"YICH", 4, 140214},
	{"UYGE", 4, 140215},
	{"TYIR", 4, 140216},
	{"SROP", 4, 140217},
	{"SMAZ", 4, 140218},
	{"RRIW", 4, 140219},
	{"OMOX", 4, 140220},
	{"LVAM", 4, 140221},
	{"LKSY", 4, 140222},
	{"IMOK", 4, 140223},
	{"GJAS", 4, 140224},
	{"ENKY", 4, 140225},
	{"DJOC", 4, 140226},
	{"COYW", 4, 140227},
	{"BTPR", 4, 140228},
	{"BADK", 4, 140229},
	{"AJEF", 4, 140230},
	{"HARDBOARD", 9, 140231},
	{"SCRIBBLER", 9, 140232},
	{"REVUES", 6, 140233},
	{"TOCCATA", 7, 140234},
	{"BRAHAM", 6, 140235},
	{"TONALITY", 8, 140236},
	{"CAMRA", 5, 140237},
	{"ATSIC", 5, 140238},
	{"CHINK", 5, 140239},
	{"MORR", 4, 140240},
	{"ALBO", 4, 140241},
	{"HUBICKA", 7, 140242},
	{"CENTURYTEL", 10, 140243},
	{"WEBMAGIC", 8, 140244},
	{"REPROGRAM", 9, 140245},
	{"LIKENESSES", 10, 140246},
	{"CNNTOGO", 7, 140247},
	{"CSCS", 4, 140248},
	{"CITIESSAVE", 10, 140249},
	{"SATAY", 5, 140250},
	{"COURTROOMS", 10, 140251},
	{"ALYCE", 5, 140252},
	{"RUTHVEN", 7, 140253},
	{"FOODIES", 7, 140254},
	{"FLIC", 4, 140255},
	{"PAULE", 5, 140256},
	{"DJMRBILL", 8, 140257},
	{"PERVADING", 9, 140258},
	{"RELOC", 5, 140259},
	{"TVIV", 4, 140260},
	{"SPYT", 4, 140261},
	{"RCIG", 4, 140262},
	{"NGRB", 4, 140263},
	{"LYZO", 4, 140264},
	{"LSEU", 4, 140265},
	{"KPON", 4, 140266},
	{"IMJE", 4, 140267},
	{"HAWF", 4, 140268},
	{"GHGL", 4, 140269},
	{"GDOY", 4, 140270},
	{"CSRI", 4, 140271},
	{"BYSB", 4, 140272},
	{"BREZ", 4, 140273},
	{"MARIONETTES", 11, 140274},
	{"KUTI", 4, 140275},
	{"SCIRUS", 6, 140276},
	{"GLAMOUROUS", 10, 140277},
	{"WYNYARD", 7, 140278},
	{"OLLE", 4, 140279},
	{"CAXTON", 6, 140280},
	{"INODES", 6, 140281},
	{"TUSCARORA", 9, 140282},
	{"PAMS", 4, 140283},
	{"SOAMES", 6, 140284},
	{"LAPTOPSHOP", 10, 140285},
	{"DROPSHIPPERS", 12, 140286},
	{"FERMENTING", 10, 140287},
	{"MEDEM", 5, 140288},
	{"BROADSTAIRS", 11, 140289},
	{"NEGREANU", 8, 140290},
	{"CONSIGLIO", 9, 140291},
	{"CARNEROS", 8, 140292},
	{"BEIDEN", 6, 140293},
	{"HARPIST", 7, 140294},
	{"SHOVES", 6, 140295},
	{"ACSM", 4, 140296},
	{"WALDROP", 7, 140297},
	{"GREENSBERG", 10, 140298},
	{"PWB", 3, 140299},
	{"CONSEJOS", 8, 140300},
	{"RUPTURES", 8, 140301},
	{"JUDIE", 5, 140302},
	{"ASSOCIATIVITY", 13, 140303},
	{"BLITHE", 6, 140304},
	{"PARALYZE", 8, 140305},
	{"GENISTEIN", 9, 140306},
	{"TOXICANTS", 9, 140307},
	{"UWCH", 4, 140308},
	{"SDCC", 4, 140309},
	{"SILVERFAST", 10, 140310},
	{"BOXBOROUGH", 10, 140311},
	{"ANTITHETICAL", 12, 140312},
	{"OJEDA", 5, 140313},
	{"HOLABIRD", 8, 140314},
	{"PROFFITT", 8, 140315},
	{"YPEU", 4, 140316},
	{"YEMM", 4, 140317},
	{"XORI", 4, 140318},
	{"XJEW", 4, 140319},
	{"PHUG", 4, 140320},
	{"OWSQ", 4, 140321},
	{"OMAQ", 4, 140322},
	{"OKCE", 4, 140323},
	{"NKAV", 4, 140324},
	{"MIFE", 4, 140325},
	{"MEYS", 4, 140326},
	{"LKCH", 4, 140327},
	{"IMLU", 4, 140328},
	{"HWEM", 4, 140329},
	{"EKDR", 4, 140330},
	{"DGIE", 4, 140331},
	{"DCYL", 4, 140332},
	{"AVSK", 4, 140333},
	{"ORDWAY", 6, 140334},
	{"TONOWANDA", 9, 140335},
	{"KAZI", 4, 140336},
	{"TILLING", 7, 140337},
	{"CRIMPED", 7, 140338},
	{"HEREUNTO", 8, 140339},
	{"RUMNEY", 6, 140340},
	{"STADION", 7, 140341},
	{"HUNTR", 5, 140342},
	{"SOCIAAL", 7, 140343},
	{"DAAD", 4, 140344},
	{"CHOCOBO", 7, 140345},
	{"STACKPOLE", 9, 140346},
	{"QUICKSTEP", 9, 140347},
	{"MEDLOCK", 7, 140348},
	{"SHASTRI", 7, 140349},
	{"LANGUISH", 8, 140350},
	{"DRUMM", 5, 140351},
	{"SIGHTSEER", 9, 140352},
	{"TEMPERATUR", 10, 140353},
	{"SETLISTS", 8, 140354},
	{"FEATHERY", 8, 140355},
	{"BOREANAZ", 8, 140356},
	{"BEATSTREET", 10, 140357},
	{"REASONER", 8, 140358},
	{"CRANMER", 7, 140359},
	{"DROGAS", 6, 140360},
	{"INHOUD", 6, 140361},
	{"ADORNING", 8, 140362},
	{"BOBBITT", 7, 140363},
	{"GAILY", 5, 140364},
	{"RETELL", 6, 140365},
	{"HARBOURSIDE", 11, 140366},
	{"INTERSPECIFIC", 13, 140367},
	{"BOXSETS", 7, 140368},
	{"VAAP", 4, 140369},
	{"UOIR", 4, 140370},
	{"UMUR", 4, 140371},
	{"TPEC", 4, 140372},
	{"RZYN", 4, 140373},
	{"PTYW", 4, 140374},
	{"PELU", 4, 140375},
	{"NDUH", 4, 140376},
	{"LTKE", 4, 140377},
	{"LRAR", 4, 140378},
	{"KGOA", 4, 140379},
	{"HYVO", 4, 140380},
	{"EUMG", 4, 140381},
	{"EMEZ", 4, 140382},
	{"DONZ", 4, 140383},
	{"CYJU", 4, 140384},
	{"WEIB", 4, 140385},
	{"SIDINGS", 7, 140386},
	{"VARIETALS", 9, 140387},
	{"FBODAILY", 8, 140388},
	{"PENSTEMON", 9, 140389},
	{"OUTPUTSTREAM", 12, 140390},
	{"GIUGNO", 6, 140391},
	{"BYUNG", 5, 140392},
	{"WLUG", 4, 140393},
	{"DEVEREAUX", 9, 140394},
	{"CRANIOSACRAL", 12, 140395},
	{"ENVIADA", 7, 140396},
	{"MAGRUDER", 8, 140397},
	{"TIMSS", 5, 140398},
	{"SALUKIS", 7, 140399},
	{"DRUMBEAT", 8, 140400},
	{"FERGAL", 6, 140401},
	{"INFORMAION", 10, 140402},
	{"BURANI", 6, 140403},
	{"TIMEZONES", 9, 140404},
	{"BELGIEN", 7, 140405},
	{"MURIDAE", 7, 140406},
	{"JUBILATION", 10, 140407},
	{"IRFANVIEW", 9, 140408},
	{"GGF", 3, 140409},
	{"STORKS", 6, 140410},
	{"RUNNYMEDE", 9, 140411},
	{"PROSTHODONTICS", 14, 140412},
	{"HYFFORDDIANT", 12, 140413},
	{"MONOID", 6, 140414},
	{"QUICKSHIP", 9, 140415},
	{"TRANSMEDIA", 10, 140416},
	{"GLENDIVE", 8, 140417},
	{"NARENDRA", 8, 140418},
	{"CLINCHING", 9, 140419},
	{"FACP", 4, 140420},
	{"BROCKOVICH", 10, 140421},
	{"KAROLINA", 8, 140422},
	{"PHOTOPLUS", 9, 140423},
	{"YVEF", 4, 140424},
	{"WEIZ", 4, 140425},
	{"ROVW", 4, 140426},
	{"RIXR", 4, 140427},
	{"PSYR", 4, 140428},
	{"LMBO", 4, 140429},
	{"KONV", 4, 140430},
	{"JOCE", 4, 140431},
	{"FDUA", 4, 140432},
	{"EYGL", 4, 140433},
	{"EUDB", 4, 140434},
	{"EPPP", 4, 140435},
	{"CEUM", 4, 140436},
	{"PLAYACAR", 8, 140437},
	{"DUHAMEL", 7, 140438},
	{"HANGUP", 6, 140439},
	{"ZELJKO", 6, 140440},
	{"ARTOIS", 6, 140441},
	{"WASHCLOTHS", 10, 140442},
	{"DIVISON", 7, 140443},
	{"DUDEK", 5, 140444},
	{"ZEROING", 7, 140445},
	{"TROPICALS", 9, 140446},
	{"PASTICHE", 8, 140447},
	{"SANDPIPERS", 10, 140448},
	{"ARCING", 6, 140449},
	{"XENOPHOBIC", 10, 140450},
	{"DONNERSTAG", 10, 140451},
	{"ACCOUTREMENTS", 13, 140452},
	{"LUNDQUIST", 9, 140453},
	{"WACKOS", 6, 140454},
	{"LITTLEWOOD", 10, 140455},
	{"REIKO", 5, 140456},
	{"XACH", 4, 140457},
	{"BONAFIDE", 8, 140458},
	{"IOSCO", 5, 140459},
	{"DOSIMETER", 9, 140460},
	{"ABEYANCE", 8, 140461},
	{"BSDI", 4, 140462},
	{"LIBERATORS", 10, 140463},
	{"WOODIE", 6, 140464},
	{"MEADOR", 6, 140465},
	{"MINORU", 6, 140466},
	{"PATRA", 5, 140467},
	{"OPENDTV", 7, 140468},
	{"CAPGEMINI", 9, 140469},
	{"CIUDADES", 8, 140470},
	{"XPCOM", 5, 140471},
	{"TRELLISES", 9, 140472},
	{"ROSENDAHL", 9, 140473},
	{"SITESCOPE", 9, 140474},
	{"AEROFLEX", 8, 140475},
	{"SHANTOU", 7, 140476},
	{"ENFIN", 5, 140477},
	{"UNEZ", 4, 140478},
	{"UDOP", 4, 140479},
	{"ROIM", 4, 140480},
	{"OZYS", 4, 140481},
	{"OUXS", 4, 140482},
	{"OUCK", 4, 140483},
	{"OMIB", 4, 140484},
	{"AYKO", 4, 140485},
	{"ANGQ", 4, 140486},
	{"SUIVI", 5, 140487},
	{"SLAVEGIRL", 9, 140488},
	{"HARTS", 5, 140489},
	{"BIENVENIDOS", 11, 140490},
	{"SEROPOSITIVE", 12, 140491},
	{"KLUDGE", 6, 140492},
	{"EMMERDALE", 9, 140493},
	{"FORESTLAND", 10, 140494},
	{"SNAGGING", 8, 140495},
	{"VIVIUN", 6, 140496},
	{"INIQUITIES", 10, 140497},
	{"INCINERATED", 11, 140498},
	{"ORNSTEIN", 8, 140499},
	{"MATC", 4, 140500},
	{"OBJECTIF", 8, 140501},
	{"NADIE", 5, 140502},
	{"SYNTACTICAL", 11, 140503},
	{"CITYLINE", 8, 140504},
	{"ROYLE", 5, 140505},
	{"MUSTELA", 7, 140506},
	{"PURRING", 7, 140507},
	{"UNDERUSED", 9, 140508},
	{"SQUINTING", 9, 140509},
	{"CLICKY", 6, 140510},
	{"SIMITIS", 7, 140511},
	{"ROSEHILL", 8, 140512},
	{"COTTEN", 6, 140513},
	{"CONTROLL", 8, 140514},
	{"AMLODIPINE", 10, 140515},
	{"BOONTON", 7, 140516},
	{"INVALIDATING", 12, 140517},
	{"OSCODA", 6, 140518},
	{"ALLYL", 5, 140519},
	{"STROLLS", 7, 140520},
	{"SAMUS", 5, 140521},
	{"GENTIAN", 7, 140522},
	{"ZZEL", 4, 140523},
	{"ZEAM", 4, 140524},
	{"YWEK", 4, 140525},
	{"XTHD", 4, 140526},
	{"WACL", 4, 140527},
	{"TAUK", 4, 140528},
	{"RUBR", 4, 140529},
	{"PMBE", 4, 140530},
	{"PHAW", 4, 140531},
	{"PEZZ", 4, 140532},
	{"KIOR", 4, 140533},
	{"KFOC", 4, 140534},
	{"GSSL", 4, 140535},
	{"EYUC", 4, 140536},
	{"EMFL", 4, 140537},
	{"BIDH", 4, 140538},
	{"BBYE", 4, 140539},
	{"AKBL", 4, 140540},
	{"IMPRESSIONISTIC", 15, 140541},
	{"HORTIPLEX", 9, 140542},
	{"ENCUENTRA", 9, 140543},
	{"CUCINE", 6, 140544},
	{"SIDEREAL", 8, 140545},
	{"ENSCRIPT", 8, 140546},
	{"FORSKNING", 9, 140547},
	{"ALPHAJET", 8, 140548},
	{"ROMO", 4, 140549},
	{"LOVINA", 6, 140550},
	{"FLAGELLAR", 9, 140551},
	{"JIBE", 4, 140552},
	{"HEMOGLOBINS", 11, 140553},
	{"PRIVATHUREN", 11, 140554},
	{"CICADAS", 7, 140555},
	{"SHAGGED", 7, 140556},
	{"GRANTSVILLE", 11, 140557},
	{"PHALLUS", 7, 140558},
	{"GRADATIONS", 10, 140559},
	{"INDENTING", 9, 140560},
	{"BUX", 3, 140561},
	{"NASTIES", 7, 140562},
	{"EGER", 4, 140563},
	{"WEBSTERS", 8, 140564},
	{"GRESS", 5, 140565},
	{"CONOCER", 7, 140566},
	{"VSED", 4, 140567},
	{"DECAMERON", 9, 140568},
	{"DONDERDAG", 9, 140569},
	{"DELAFIELD", 9, 140570},
	{"MOLEST", 6, 140571},
	{"ENVIRONMEN", 10, 140572},
	{"VICG", 4, 140573},
	{"ULKR", 4, 140574},
	{"TOYM", 4, 140575},
	{"TMUM", 4, 140576},
	{"MATJ", 4, 140577},
	{"KSGU", 4, 140578},
	{"HYIF", 4, 140579},
	{"GIMI", 4, 140580},
	{"FGLU", 4, 140581},
	{"EZMI", 4, 140582},
	{"ETYJ", 4, 140583},
	{"AWKH", 4, 140584},
	{"AKYE", 4, 140585},
	{"TOMSK", 5, 140586},
	{"ASIANA", 6, 140587},
	{"FORAMEN", 7, 140588},
	{"APPETIZING", 10, 140589},
	{"ENCAMPED", 8, 140590},
	{"BUNGY", 5, 140591},
	{"BRAEMAR", 7, 140592},
	{"INTAGLIO", 8, 140593},
	{"DOORKNOB", 8, 140594},
	{"USMAN", 5, 140595},
	{"PUBLICADO", 9, 140596},
	{"RMAN", 4, 140597},
	{"EGRETS", 6, 140598},
	{"BEHAR", 5, 140599},
	{"BODYWEIGHT", 10, 140600},
	{"TRIFLES", 7, 140601},
	{"ETHOLOGY", 8, 140602},
	{"MOUNTAINSMITH", 13, 140603},
	{"SUBPAGES", 8, 140604},
	{"WHOOSH", 6, 140605},
	{"BACKCOURT", 9, 140606},
	{"VFUNC", 5, 140607},
	{"GOBY", 4, 140608},
	{"HENGE", 5, 140609},
	{"EGREMONT", 8, 140610},
	{"LOCKUPS", 7, 140611},
	{"MESMERIZE", 9, 140612},
	{"NUTCRACKERS", 11, 140613},
	{"MYFI", 4, 140614},
	{"ZEPL", 4, 140615},
	{"YHUL", 4, 140616},
	{"WISJ", 4, 140617},
	{"VDON", 4, 140618},
	{"TOKW", 4, 140619},
	{"LIZS", 4, 140620},
	{"LGDP", 4, 140621},
	{"KOBR", 4, 140622},
	{"EPCE", 4, 140623},
	{"DUSG", 4, 140624},
	{"COWM", 4, 140625},
	{"AWGA", 4, 140626},
	{"SAMMLUNG", 8, 140627},
	{"HTTPCLIENT", 10, 140628},
	{"DERSHOWITZ", 10, 140629},
	{"HOTDOGS", 7, 140630},
	{"REISENDEN", 9, 140631},
	{"TWSOCKET", 8, 140632},
	{"EXTRACORPOREAL", 14, 140633},
	{"TRANSCRIPTIONIST", 16, 140634},
	{"JOGOS", 5, 140635},
	{"JANKOWSKI", 9, 140636},
	{"DOWNDRAFT", 9, 140637},
	{"LANGAGE", 7, 140638},
	{"GLACIATION", 10, 140639},
	{"DOWMLOAD", 8, 140640},
	{"RADIOLARIA", 10, 140641},
	{"HMCS", 4, 140642},
	{"WILCOXON", 8, 140643},
	{"PBARS", 5, 140644},
	{"SIGGY", 5, 140645},
	{"BLUSHINGBUYER", 13, 140646},
	{"PICCOLA", 7, 140647},
	{"OOZES", 5, 140648},
	{"IMPORTANTES", 11, 140649},
	{"ADDO", 4, 140650},
	{"SUITING", 7, 140651},
	{"HILDE", 5, 140652},
	{"HESITATES", 9, 140653},
	{"RAMAZZOTTI", 10, 140654},
	{"LICKER", 6, 140655},
	{"MERSENNE", 8, 140656},
	{"INTENSIFIER", 11, 140657},
	{"DAXTER", 6, 140658},
	{"SOUNDBOARDS", 11, 140659},
	{"PARALYTIC", 9, 140660},
	{"YZOO", 4, 140661},
	{"TAPD", 4, 140662},
	{"ROAB", 4, 140663},
	{"PFOC", 4, 140664},
	{"NDJR", 4, 140665},
	{"MEUL", 4, 140666},
	{"FESF", 4, 140667},
	{"FELK", 4, 140668},
	{"FBYC", 4, 140669},
	{"ARIQ", 4, 140670},
	{"VILLARS", 7, 140671},
	{"UDY", 3, 140672},
	{"KERNELTRAP", 10, 140673},
	{"HOLLENBECK", 10, 140674},
	{"EASTWARDS", 9, 140675},
	{"SUBTITLING", 10, 140676},
	{"SYMS", 4, 140677},
	{"KWAJALEIN", 9, 140678},
	{"LANDESK", 7, 140679},
	{"BHARATPUR", 9, 140680},
	{"FOXCROFT", 8, 140681},
	{"COLAC", 5, 140682},
	{"ASININE", 7, 140683},
	{"SVILUPPO", 8, 140684},
	{"PARSIMONIOUS", 12, 140685},
	{"LAWMAN", 6, 140686},
	{"DAYAN", 5, 140687},
	{"UUU", 3, 140688},
	{"TRUY", 4, 140689},
	{"PAYRATE", 7, 140690},
	{"DAIGAKU", 7, 140691},
	{"PINAFORE", 8, 140692},
	{"STARTX", 6, 140693},
	{"HAMP", 4, 140694},
	{"GELL", 4, 140695},
	{"RUCHED", 6, 140696},
	{"AYUTTHAYA", 9, 140697},
	{"WILLINGTON", 10, 140698},
	{"RUFIO", 5, 140699},
	{"FALKNER", 7, 140700},
	{"ASSEMBLYWOMAN", 13, 140701},
	{"SIDEKICKS", 9, 140702},
	{"SOAKER", 6, 140703},
	{"BANKNORTH", 9, 140704},
	{"ALWYN", 5, 140705},
	{"HOTROD", 6, 140706},
	{"ALBERTINE", 9, 140707},
	{"WRITEN", 6, 140708},
	{"PROKARYOTES", 11, 140709},
	{"DISPOSER", 8, 140710},
	{"CLIX", 4, 140711},
	{"SPANNEN", 7, 140712},
	{"GETHSEMANE", 10, 140713},
	{"YMYL", 4, 140714},
	{"YMUD", 4, 140715},
	{"VMAN", 4, 140716},
	{"VASF", 4, 140717},
	{"UKAH", 4, 140718},
	{"UGIE", 4, 140719},
	{"UFRA", 4, 140720},
	{"TYMD", 4, 140721},
	{"TODV", 4, 140722},
	{"SUSV", 4, 140723},
	{"STRD", 4, 140724},
	{"RTGL", 4, 140725},
	{"PMPR", 4, 140726},
	{"MNDA", 4, 140727},
	{"MIRB", 4, 140728},
	{"LOVO", 4, 140729},
	{"GOWC", 4, 140730},
	{"FCWI", 4, 140731},
	{"EUAW", 4, 140732},
	{"BIRL", 4, 140733},
	{"COUNTEREXAMPLE", 14, 140734},
	{"NEUROPATHOLOGY", 14, 140735},
	{"ZARDOZ", 6, 140736},
	{"SOUTHCOAST", 10, 140737},
	{"FEVERFEW", 8, 140738},
	{"THERMOGENIC", 11, 140739},
	{"HAKKA", 5, 140740},
	{"INTIMA", 6, 140741},
	{"HENNER", 6, 140742},
	{"ZIMBRA", 6, 140743},
	{"SCHADE", 6, 140744},
	{"NECROPSY", 8, 140745},
	{"EHRENBERG", 9, 140746},
	{"TONINO", 6, 140747},
	{"SUBSIDISE", 9, 140748},
	{"UPRIVER", 7, 140749},
	{"KOOPMAN", 7, 140750},
	{"DACHAU", 6, 140751},
	{"SOUTHWESTERLY", 13, 140752},
	{"HOSTESSES", 9, 140753},
	{"POLITISCHE", 10, 140754},
	{"SUBVERTING", 10, 140755},
	{"SHOTOKAN", 8, 140756},
	{"FOREKNOWLEDGE", 13, 140757},
	{"KERREY", 6, 140758},
	{"GALLEYS", 7, 140759},
	{"GODFATHERS", 10, 140760},
	{"DINSDAG", 7, 140761},
	{"CHAPPED", 7, 140762},
	{"ACCESIBLE", 9, 140763},
	{"ZEUP", 4, 140764},
	{"YLAH", 4, 140765},
	{"TKMM", 4, 140766},
	{"SMEP", 4, 140767},
	{"PASR", 4, 140768},
	{"OOXF", 4, 140769},
	{"OEGG", 4, 140770},
	{"OBFU", 4, 140771},
	{"NBCP", 4, 140772},
	{"KICL", 4, 140773},
	{"JBUR", 4, 140774},
	{"FOKI", 4, 140775},
	{"DTYI", 4, 140776},
	{"AJPA", 4, 140777},
	{"BIRRA", 5, 140778},
	{"SUDAFED", 7, 140779},
	{"BUFO", 4, 140780},
	{"BODEGAS", 7, 140781},
	{"POTAWATOMI", 10, 140782},
	{"COURRIEL", 8, 140783},
	{"CRITICA", 7, 140784},
	{"VENKATESH", 9, 140785},
	{"GRUP", 4, 140786},
	{"EXTROPY", 7, 140787},
	{"EVENTHOUGH", 10, 140788},
	{"SUNNING", 7, 140789},
	{"AMIGAS", 6, 140790},
	{"INSTALATION", 11, 140791},
	{"ILEANA", 6, 140792},
	{"KHONG", 5, 140793},
	{"FARCICAL", 8, 140794},
	{"TWEENIES", 8, 140795},
	{"INDENTS", 7, 140796},
	{"PROFESSORSHIPS", 14, 140797},
	{"VICS", 4, 140798},
	{"TANENBAUM", 9, 140799},
	{"QUMRAN", 6, 140800},
	{"JEMEZ", 5, 140801},
	{"PORTERFIELD", 11, 140802},
	{"GOOGLR", 6, 140803},
	{"SEMICLASSICAL", 13, 140804},
	{"WEEL", 4, 140805},
	{"BOERICKE", 8, 140806},
	{"NATALYA", 7, 140807},
	{"AACSB", 5, 140808},
	{"TOILED", 6, 140809},
	{"MAKINO", 6, 140810},
	{"YTYR", 4, 140811},
	{"WNEG", 4, 140812},
	{"WGAT", 4, 140813},
	{"VENZ", 4, 140814},
	{"UYDI", 4, 140815},
	{"PPWI", 4, 140816},
	{"PADG", 4, 140817},
	{"OVJO", 4, 140818},
	{"NRAZ", 4, 140819},
	{"LAOP", 4, 140820},
	{"KAUD", 4, 140821},
	{"IFBY", 4, 140822},
	{"EZPR", 4, 140823},
	{"DRJE", 4, 140824},
	{"DPWA", 4, 140825},
	{"CYBI", 4, 140826},
	{"WAITH", 5, 140827},
	{"FIGO", 4, 140828},
	{"MAITAKE", 7, 140829},
	{"GOBS", 4, 140830},
	{"KAVARNA", 7, 140831},
	{"CPSU", 4, 140832},
	{"REPROCESSED", 11, 140833},
	{"HONSHU", 6, 140834},
	{"PLACEBOS", 8, 140835},
	{"WITTNAUER", 9, 140836},
	{"EQUITATION", 10, 140837},
	{"BLYTHEVILLE", 11, 140838},
	{"AUTOPARTS", 9, 140839},
	{"INCITED", 7, 140840},
	{"MEROPS", 6, 140841},
	{"ERRSTR", 6, 140842},
	{"SUPERYACHT", 10, 140843},
	{"RAZE", 4, 140844},
	{"BOHANNON", 8, 140845},
	{"QPL", 3, 140846},
	{"FORMATING", 9, 140847},
	{"GRASSI", 6, 140848},
	{"REALLOC", 7, 140849},
	{"SHEBANG", 7, 140850},
	{"KLUGE", 5, 140851},
	{"ECITY", 5, 140852},
	{"CAETANO", 7, 140853},
	{"DILUTIVE", 8, 140854},
	{"HOMEABC", 7, 140855},
	{"MARUI", 5, 140856},
	{"GUISES", 6, 140857},
	{"UNOBLIGATED", 11, 140858},
	{"COLORANTS", 9, 140859},
	{"UNIREZ", 6, 140860},
	{"RROF", 4, 140861},
	{"RFBO", 4, 140862},
	{"NSPM", 4, 140863},
	{"NDVS", 4, 140864},
	{"KMIT", 4, 140865},
	{"JAMT", 4, 140866},
	{"FVEL", 4, 140867},
	{"DYEI", 4, 140868},
	{"DETF", 4, 140869},
	{"CTYL", 4, 140870},
	{"KNOWLEDGES", 10, 140871},
	{"CANOLFAN", 8, 140872},
	{"RHYTHMICAL", 10, 140873},
	{"BORATE", 6, 140874},
	{"RECTRON", 7, 140875},
	{"CASTELO", 7, 140876},
	{"ELECTROMYOGRAPHY", 16, 140877},
	{"THUMNAIL", 8, 140878},
	{"RPTR", 4, 140879},
	{"MOWAT", 5, 140880},
	{"BRUJERIA", 8, 140881},
	{"FBM", 3, 140882},
	{"FEEDSTOCKS", 10, 140883},
	{"FOOTSWITCH", 10, 140884},
	{"CONGRESSO", 9, 140885},
	{"FINANZEN", 8, 140886},
	{"GENEON", 6, 140887},
	{"RIPPLED", 7, 140888},
	{"CHAMA", 5, 140889},
	{"ANDRIES", 7, 140890},
	{"ALSAPLAYER", 10, 140891},
	{"STURTEVANT", 10, 140892},
	{"CYSTINE", 7, 140893},
	{"APARTADO", 8, 140894},
	{"FILTRO", 6, 140895},
	{"HYDRAZINE", 9, 140896},
	{"TRESSES", 7, 140897},
	{"LUBY", 4, 140898},
	{"KOUROS", 6, 140899},
	{"ICBC", 4, 140900},
	{"EXTLIB", 6, 140901},
	{"EANGLER", 7, 140902},
	{"SPENCO", 6, 140903},
	{"SPERO", 5, 140904},
	{"HOMECAM", 7, 140905},
	{"COLLIDES", 8, 140906},
	{"HALLORAN", 8, 140907},
	{"OYFA", 4, 140908},
	{"OVIK", 4, 140909},
	{"MPDU", 4, 140910},
	{"MPCL", 4, 140911},
	{"LPEE", 4, 140912},
	{"HPIP", 4, 140913},
	{"GQUO", 4, 140914},
	{"EADZ", 4, 140915},
	{"DTUS", 4, 140916},
	{"DAOP", 4, 140917},
	{"CPLE", 4, 140918},
	{"BELN", 4, 140919},
	{"GAMEOLOGY", 9, 140920},
	{"PDK", 3, 140921},
	{"AGITATING", 9, 140922},
	{"FINKE", 5, 140923},
	{"HERRIOT", 7, 140924},
	{"ESCAPIST", 8, 140925},
	{"GUNSHOTS", 8, 140926},
	{"BREATHTAKINGLY", 14, 140927},
	{"HABERSHAM", 9, 140928},
	{"ELECTORATES", 11, 140929},
	{"ORIANA", 6, 140930},
	{"OBORN", 5, 140931},
	{"FRANKNESS", 9, 140932},
	{"FELDENKRAIS", 11, 140933},
	{"CQU", 3, 140934},
	{"CHRISTIAAN", 10, 140935},
	{"PARTENAIRE", 10, 140936},
	{"CPW", 3, 140937},
	{"CASTILIAN", 9, 140938},
	{"UKIP", 4, 140939},
	{"CHEEKED", 7, 140940},
	{"SUDOC", 5, 140941},
	{"BUNSEN", 6, 140942},
	{"CLUBMAC", 7, 140943},
	{"GLENDON", 7, 140944},
	{"TRAVAILS", 8, 140945},
	{"TATTY", 5, 140946},
	{"SHAPESHIFTER", 12, 140947},
	{"PARASOFT", 8, 140948},
	{"CADEAUX", 7, 140949},
	{"EEVL", 4, 140950},
	{"MAART", 5, 140951},
	{"BUENAS", 6, 140952},
	{"BERE", 4, 140953},
	{"TERCENTENARY", 12, 140954},
	{"TARBORO", 7, 140955},
	{"OSTERMAN", 8, 140956},
	{"WEBSEND", 7, 140957},
	{"WALSER", 6, 140958},
	{"KAMAKURA", 8, 140959},
	{"SUSUMU", 6, 140960},
	{"JUNIPERUS", 9, 140961},
	{"TAMMIE", 6, 140962},
	{"SILVANA", 7, 140963},
	{"LINESMAN", 8, 140964},
	{"SULLE", 5, 140965},
	{"ROTLICHTVIERTEL", 15, 140966},
	{"LIPPMANN", 8, 140967},
	{"BUJOLD", 6, 140968},
	{"ZYCO", 4, 140969},
	{"YRHE", 4, 140970},
	{"WAXI", 4, 140971},
	{"UPDT", 4, 140972},
	{"PDIE", 4, 140973},
	{"OKEJ", 4, 140974},
	{"ODGK", 4, 140975},
	{"KORV", 4, 140976},
	{"GTOZ", 4, 140977},
	{"DHIB", 4, 140978},
	{"ABCF", 4, 140979},
	{"DEVCON", 6, 140980},
	{"ISLAMICFINDER", 13, 140981},
	{"MAURI", 5, 140982},
	{"WOENSDAG", 8, 140983},
	{"RECOMENDACIONES", 15, 140984},
	{"BECKFORD", 8, 140985},
	{"FUERA", 5, 140986},
	{"KAHL", 4, 140987},
	{"BOTTON", 6, 140988},
	{"PBB", 3, 140989},
	{"BELEW", 5, 140990},
	{"GRANDDAUGHTERS", 14, 140991},
	{"PTARMIGAN", 9, 140992},
	{"PICKGUARD", 9, 140993},
	{"BADR", 4, 140994},
	{"ACKROYD", 7, 140995},
	{"ELLISTON", 8, 140996},
	{"SKYLAB", 6, 140997},
	{"FAWR", 4, 140998},
	{"OGATA", 5, 140999},
	{"STONEHAVEN", 10, 141000},
	{"PENTAIR", 7, 141001},
	{"MORLAND", 7, 141002},
	{"LEONHARDT", 9, 141003},
	{"MOVISTAR", 8, 141004},
	{"DOMESTICA", 9, 141005},
	{"ULAZ", 4, 141006},
	{"TSPY", 4, 141007},
	{"NBUB", 4, 141008},
	{"MCDU", 4, 141009},
	{"LLZO", 4, 141010},
	{"BOSL", 4, 141011},
	{"APYC", 4, 141012},
	{"OUTLIVED", 8, 141013},
	{"DETERS", 6, 141014},
	{"PITRE", 5, 141015},
	{"CROOM", 5, 141016},
	{"ABNEY", 5, 141017},
	{"FABIA", 5, 141018},
	{"EAKIN", 5, 141019},
	{"CURFEWS", 7, 141020},
	{"BARRETO", 7, 141021},
	{"WOLFSHEIM", 9, 141022},
	{"SUBPROCESS", 10, 141023},
	{"HOOKE", 5, 141024},
	{"PENICILLINS", 11, 141025},
	{"WATERTON", 8, 141026},
	{"REPULSE", 7, 141027},
	{"JARDIM", 6, 141028},
	{"CHAKOTAY", 8, 141029},
	{"TAMALE", 6, 141030},
	{"BEARBEITEN", 10, 141031},
	{"CSCE", 4, 141032},
	{"RATTRAY", 7, 141033},
	{"DIVOT", 5, 141034},
	{"AUGURI", 6, 141035},
	{"ULTRASOUNDS", 11, 141036},
	{"RAVENWOOD", 9, 141037},
	{"BASALTIC", 8, 141038},
	{"ROFECOXIB", 9, 141039},
	{"GIGABEAT", 8, 141040},
	{"RONEY", 5, 141041},
	{"NAPP", 4, 141042},
	{"COUNTERSPY", 10, 141043},
	{"LIBGNOMECANVAS", 14, 141044},
	{"NOCONA", 6, 141045},
	{"SIEVERS", 7, 141046},
	{"COMPUTADOR", 10, 141047},
	{"AGCO", 4, 141048},
	{"WSBI", 4, 141049},
	{"WNGL", 4, 141050},
	{"WMUT", 4, 141051},
	{"WLLO", 4, 141052},
	{"UGMO", 4, 141053},
	{"RUZC", 4, 141054},
	{"RIFC", 4, 141055},
	{"RGVI", 4, 141056},
	{"PHFA", 4, 141057},
	{"KBAG", 4, 141058},
	{"IZBU", 4, 141059},
	{"FIFY", 4, 141060},
	{"DAZO", 4, 141061},
	{"CWEE", 4, 141062},
	{"ARAQ", 4, 141063},
	{"HUBLOT", 6, 141064},
	{"YILMAZ", 6, 141065},
	{"SPACEPORT", 9, 141066},
	{"ADDA", 4, 141067},
	{"MADDOG", 6, 141068},
	{"SENSORIMOTOR", 12, 141069},
	{"DOGFIGHT", 8, 141070},
	{"HINTER", 6, 141071},
	{"SUTTA", 5, 141072},
	{"KELLEN", 6, 141073},
	{"KURE", 4, 141074},
	{"JMIS", 4, 141075},
	{"UFFICIALE", 9, 141076},
	{"JOURNEYER", 9, 141077},
	{"FONTFAMILY", 10, 141078},
	{"SEKAI", 5, 141079},
	{"SALIH", 5, 141080},
	{"DINAN", 5, 141081},
	{"GOVERNORATE", 11, 141082},
	{"POLITECNICO", 11, 141083},
	{"TASERS", 6, 141084},
	{"DIRNEN", 6, 141085},
	{"VECTORWORKS", 11, 141086},
	{"HAMDI", 5, 141087},
	{"GAZER", 5, 141088},
	{"STEPHANOPOULOS", 14, 141089},
	{"VERSANDKOSTEN", 13, 141090},
	{"MIDDLING", 8, 141091},
	{"METAMORPHOSES", 13, 141092},
	{"COSTAL", 6, 141093},
	{"MINIBUFFER", 10, 141094},
	{"ZEAF", 4, 141095},
	{"UKIH", 4, 141096},
	{"UDBO", 4, 141097},
	{"TWIK", 4, 141098},
	{"TMHZ", 4, 141099},
	{"SRAK", 4, 141100},
	{"ROOC", 4, 141101},
	{"RLJA", 4, 141102},
	{"RKIV", 4, 141103},
	{"RGAW", 4, 141104},
	{"REIJ", 4, 141105},
	{"OUPJ", 4, 141106},
	{"OFSB", 4, 141107},
	{"MUDH", 4, 141108},
	{"MLBA", 4, 141109},
	{"LPNE", 4, 141110},
	{"LEZH", 4, 141111},
	{"GULB", 4, 141112},
	{"GAIG", 4, 141113},
	{"FUSK", 4, 141114},
	{"ECBU", 4, 141115},
	{"AVLA", 4, 141116},
	{"CTRS", 4, 141117},
	{"INACTIVATE", 10, 141118},
	{"CARLI", 5, 141119},
	{"URALS", 5, 141120},
	{"SPEEDWAGON", 10, 141121},
	{"PETFOODDIRECT", 13, 141122},
	{"GOSUB", 5, 141123},
	{"CHALLAH", 7, 141124},
	{"KILSYTH", 7, 141125},
	{"URETERAL", 8, 141126},
	{"DIACRITICS", 10, 141127},
	{"ANTIHERO", 8, 141128},
	{"SHACKNEWS", 9, 141129},
	{"MOORMAN", 7, 141130},
	{"FREEWILL", 8, 141131},
	{"DEUM", 4, 141132},
	{"ERHARD", 6, 141133},
	{"TECHSOUP", 8, 141134},
	{"HARUKI", 6, 141135},
	{"MINSTRELS", 9, 141136},
	{"PRNT", 4, 141137},
	{"FOXFIRE", 7, 141138},
	{"AFONSO", 6, 141139},
	{"SCHWULE", 7, 141140},
	{"ISLAMI", 6, 141141},
	{"ZFX", 3, 141142},
	{"PATTR", 5, 141143},
	{"PERSONAE", 8, 141144},
	{"ADMINISTRATE", 12, 141145},
	{"DRUNKNMUNKY", 11, 141146},
	{"PROXIMATELY", 11, 141147},
	{"FOURTHLY", 8, 141148},
	{"BLAVATSKY", 9, 141149},
	{"MESSERMEISTER", 13, 141150},
	{"PRECEEDED", 9, 141151},
	{"VALO", 4, 141152},
	{"AYDIN", 5, 141153},
	{"MUTATOR", 7, 141154},
	{"CIRO", 4, 141155},
	{"ACTIONPERFORMED", 15, 141156},
	{"UZIE", 4, 141157},
	{"UOBU", 4, 141158},
	{"UERF", 4, 141159},
	{"MALZ", 4, 141160},
	{"LUFK", 4, 141161},
	{"LSTM", 4, 141162},
	{"LDSQ", 4, 141163},
	{"KTUN", 4, 141164},
	{"KAVO", 4, 141165},
	{"IODJ", 4, 141166},
	{"IEXC", 4, 141167},
	{"HCAD", 4, 141168},
	{"GSVA", 4, 141169},
	{"FYBU", 4, 141170},
	{"EOMU", 4, 141171},
	{"CEDQ", 4, 141172},
	{"ICDL", 4, 141173},
	{"SPIROMETRY", 10, 141174},
	{"SKULLCAP", 8, 141175},
	{"DTSC", 4, 141176},
	{"MATTAPOISETT", 12, 141177},
	{"ENGLANDER", 9, 141178},
	{"NOBILIS", 7, 141179},
	{"GASCOYNE", 8, 141180},
	{"LISTENABLE", 10, 141181},
	{"DEEGAN", 6, 141182},
	{"QUALIA", 6, 141183},
	{"ROTTIE", 6, 141184},
	{"KNIGHTED", 8, 141185},
	{"PFR", 3, 141186},
	{"ZAPPING", 7, 141187},
	{"JAYME", 5, 141188},
	{"MALCONTENT", 10, 141189},
	{"BROSSEAU", 8, 141190},
	{"TORCHLIGHT", 10, 141191},
	{"DFR", 3, 141192},
	{"EMBARRASSINGLY", 14, 141193},
	{"TENIENDO", 8, 141194},
	{"FORMALS", 7, 141195},
	{"EPOCA", 5, 141196},
	{"BAYPORT", 7, 141197},
	{"GRATISSOLARIUM", 14, 141198},
	{"NOLITA", 6, 141199},
	{"GLASSWORKS", 10, 141200},
	{"EMANATED", 8, 141201},
	{"SOUTHERNER", 10, 141202},
	{"RIVOTRIL", 8, 141203},
	{"RUAPEHU", 7, 141204},
	{"FUNDUS", 6, 141205},
	{"BLOODIEST", 9, 141206},
	{"FINDMYNEAREST", 13, 141207},
	{"GIAMATTI", 8, 141208},
	{"GLOSSED", 7, 141209},
	{"OLBIA", 5, 141210},
	{"WIXOM", 5, 141211},
	{"TATARSTAN", 9, 141212},
	{"PERSEVERED", 10, 141213},
	{"HOMILIES", 8, 141214},
	{"SERVICEMAN", 10, 141215},
	{"TSKU", 4, 141216},
	{"PPAH", 4, 141217},
	{"MILH", 4, 141218},
	{"LTYN", 4, 141219},
	{"LNBA", 4, 141220},
	{"LDVD", 4, 141221},
	{"KYPL", 4, 141222},
	{"KAFU", 4, 141223},
	{"JADS", 4, 141224},
	{"IDZA", 4, 141225},
	{"FHAC", 4, 141226},
	{"EZDO", 4, 141227},
	{"EGMI", 4, 141228},
	{"CBSW", 4, 141229},
	{"BTSW", 4, 141230},
	{"BCLO", 4, 141231},
	{"AMUI", 4, 141232},
	{"AGIU", 4, 141233},
	{"ACDR", 4, 141234},
	{"MOSIER", 6, 141235},
	{"MOONBEAM", 8, 141236},
	{"CHUD", 4, 141237},
	{"PIXELATED", 9, 141238},
	{"HEDDA", 5, 141239},
	{"UNELECTED", 9, 141240},
	{"AUSTRALIE", 9, 141241},
	{"BAGUETTES", 9, 141242},
	{"ALLYSIN", 7, 141243},
	{"HOUNDED", 7, 141244},
	{"ORIFICES", 8, 141245},
	{"HAREL", 5, 141246},
	{"EXCLAIMING", 10, 141247},
	{"AGREGAR", 7, 141248},
	{"CLUTTERING", 10, 141249},
	{"NORTHEASTERLY", 13, 141250},
	{"CEGUI", 5, 141251},
	{"BUTTED", 6, 141252},
	{"SANDBAKKELS", 11, 141253},
	{"SANDRINE", 8, 141254},
	{"LIVECAMCHAT", 11, 141255},
	{"CHALKS", 6, 141256},
	{"MASSAGEN", 8, 141257},
	{"JAMBASE", 7, 141258},
	{"PRONOS", 6, 141259},
	{"LONGINGS", 8, 141260},
	{"BOTNET", 6, 141261},
	{"BHARATIYA", 9, 141262},
	{"BENARD", 6, 141263},
	{"GRATUIS", 7, 141264},
	{"TWIGG", 5, 141265},
	{"ELINKS", 6, 141266},
	{"GALILEAN", 8, 141267},
	{"FINECAM", 7, 141268},
	{"AYANT", 5, 141269},
	{"VOYURE", 6, 141270},
	{"SIDEBAND", 8, 141271},
	{"GADLING", 7, 141272},
	{"CHICS", 5, 141273},
	{"THRESHER", 8, 141274},
	{"BINNED", 6, 141275},
	{"AURON", 5, 141276},
	{"KOLE", 4, 141277},
	{"DOMINICANS", 10, 141278},
	{"KAAZA", 5, 141279},
	{"XEDV", 4, 141280},
	{"VYDO", 4, 141281},
	{"UPEW", 4, 141282},
	{"SWEJ", 4, 141283},
	{"ROYK", 4, 141284},
	{"RLSV", 4, 141285},
	{"RAEP", 4, 141286},
	{"NYOK", 4, 141287},
	{"IZIK", 4, 141288},
	{"INPY", 4, 141289},
	{"ICDY", 4, 141290},
	{"FTYD", 4, 141291},
	{"BBYK", 4, 141292},
	{"AZZH", 4, 141293},
	{"GMK", 3, 141294},
	{"JAVADOCS", 8, 141295},
	{"WITCHBLADE", 10, 141296},
	{"BRONXVILLE", 10, 141297},
	{"ALEDO", 5, 141298},
	{"ALLEYWAY", 8, 141299},
	{"SUPV", 4, 141300},
	{"GADD", 4, 141301},
	{"OVERCHARGE", 10, 141302},
	{"PREHOSPITAL", 11, 141303},
	{"KEIZAI", 6, 141304},
	{"LINENUM", 7, 141305},
	{"ULVERSTON", 9, 141306},
	{"PILANESBERG", 11, 141307},
	{"BOONDOCKING", 11, 141308},
	{"MINDMANAGER", 11, 141309},
	{"EVANGEL", 7, 141310},
	{"HELMSMAN", 8, 141311},
	{"VAJRA", 5, 141312},
	{"LIVEABOARD", 10, 141313},
	{"SYNCED", 6, 141314},
	{"ROBARDS", 7, 141315},
	{"INSTITUTIONALIZE", 16, 141316},
	{"BARTZ", 5, 141317},
	{"ZYGOTE", 6, 141318},
	{"MEDITATED", 9, 141319},
	{"ROBUSTLY", 8, 141320},
	{"SMARTYPANTS", 11, 141321},
	{"CAUDILL", 7, 141322},
	{"YVIB", 4, 141323},
	{"YTUM", 4, 141324},
	{"VFIL", 4, 141325},
	{"UROE", 4, 141326},
	{"UBAO", 4, 141327},
	{"TCYT", 4, 141328},
	{"RXUA", 4, 141329},
	{"RURO", 4, 141330},
	{"RLLI", 4, 141331},
	{"PVIE", 4, 141332},
	{"ORFW", 4, 141333},
	{"NKCU", 4, 141334},
	{"KIEK", 4, 141335},
	{"HSYD", 4, 141336},
	{"GYSY", 4, 141337},
	{"FIWI", 4, 141338},
	{"FDAD", 4, 141339},
	{"EDHP", 4, 141340},
	{"DTHM", 4, 141341},
	{"DSIV", 4, 141342},
	{"BEYH", 4, 141343},
	{"WALHALLA", 8, 141344},
	{"MYBB", 4, 141345},
	{"PNEUMOCYSTIS", 12, 141346},
	{"HAMMONS", 7, 141347},
	{"KOZHIKODE", 9, 141348},
	{"CHORDAL", 7, 141349},
	{"GRADU", 5, 141350},
	{"TRIUMF", 6, 141351},
	{"ENTUITIVE", 9, 141352},
	{"SHUDDERING", 10, 141353},
	{"CHERT", 5, 141354},
	{"VMPS", 4, 141355},
	{"SHUCKS", 6, 141356},
	{"HOMESTEADS", 10, 141357},
	{"ABROGATION", 10, 141358},
	{"WPX", 3, 141359},
	{"JUSTICIA", 8, 141360},
	{"WYSOCKI", 7, 141361},
	{"COXX", 4, 141362},
	{"ADDUCT", 6, 141363},
	{"SPATIOTEMPORAL", 14, 141364},
	{"HISHAM", 6, 141365},
	{"ASHMAN", 6, 141366},
	{"MULTIPROCESSING", 15, 141367},
	{"JUTTING", 7, 141368},
	{"NOORDWIJK", 9, 141369},
	{"RECODING", 8, 141370},
	{"CCACHE", 6, 141371},
	{"TRAJES", 6, 141372},
	{"IMBA", 4, 141373},
	{"DELIVERER", 9, 141374},
	{"KNECHT", 6, 141375},
	{"UZZS", 4, 141376},
	{"OXYT", 4, 141377},
	{"OGMO", 4, 141378},
	{"ODIB", 4, 141379},
	{"MWOL", 4, 141380},
	{"MKAL", 4, 141381},
	{"INJR", 4, 141382},
	{"ERKG", 4, 141383},
	{"EKUK", 4, 141384},
	{"COFV", 4, 141385},
	{"CKIH", 4, 141386},
	{"AMCK", 4, 141387},
	{"ARCUS", 5, 141388},
	{"PLURIBUS", 8, 141389},
	{"YTTRIUM", 7, 141390},
	{"PANAX", 5, 141391},
	{"RELENZA", 7, 141392},
	{"AENEID", 6, 141393},
	{"WEDDINGBELLER", 13, 141394},
	{"PEOPL", 5, 141395},
	{"SPENGLER", 8, 141396},
	{"INTERUNIVERSITY", 15, 141397},
	{"ARIELLE", 7, 141398},
	{"DANANG", 6, 141399},
	{"ALLOPATHIC", 10, 141400},
	{"UKRPROMR", 8, 141401},
	{"HEDGEROW", 8, 141402},
	{"DTRACE", 6, 141403},
	{"YOURDIRTYMIND", 13, 141404},
	{"SUBPROGRAMS", 11, 141405},
	{"BUDESONIDE", 10, 141406},
	{"FEDERACION", 10, 141407},
	{"MILITIAMEN", 10, 141408},
	{"EMBALMING", 9, 141409},
	{"FMEA", 4, 141410},
	{"MBONE", 5, 141411},
	{"NOWELL", 6, 141412},
	{"KEIM", 4, 141413},
	{"VININGS", 7, 141414},
	{"HISTOCHEMICAL", 13, 141415},
	{"GIFTCARDS", 9, 141416},
	{"EXTRADITE", 9, 141417},
	{"YEBY", 4, 141418},
	{"VCOU", 4, 141419},
	{"UXSA", 4, 141420},
	{"UPVA", 4, 141421},
	{"UMIH", 4, 141422},
	{"SMPE", 4, 141423},
	{"RYCY", 4, 141424},
	{"RSLY", 4, 141425},
	{"RBIW", 4, 141426},
	{"RAHK", 4, 141427},
	{"OALQ", 4, 141428},
	{"MUTC", 4, 141429},
	{"LPSK", 4, 141430},
	{"LDUK", 4, 141431},
	{"KHEB", 4, 141432},
	{"JASW", 4, 141433},
	{"ILKN", 4, 141434},
	{"HNDU", 4, 141435},
	{"GHJE", 4, 141436},
	{"FCOE", 4, 141437},
	{"EKFE", 4, 141438},
	{"DATQ", 4, 141439},
	{"SOFTBOUND", 9, 141440},
	{"VEHEMENCE", 9, 141441},
	{"TEEMA", 5, 141442},
	{"IMMANENT", 8, 141443},
	{"NEUHEITEN", 9, 141444},
	{"BEFELL", 6, 141445},
	{"CORDY", 5, 141446},
	{"ENREGISTREMENT", 14, 141447},
	{"ELEKTRONISCHE", 13, 141448},
	{"DESIGNCON", 9, 141449},
	{"ORGANOCHLORINE", 14, 141450},
	{"UNFUNNY", 7, 141451},
	{"CORTI", 5, 141452},
	{"HAGEDORN", 8, 141453},
	{"SANHEDRIN", 9, 141454},
	{"KLAR", 4, 141455},
	{"STRATHFIELD", 11, 141456},
	{"DIPOLAR", 7, 141457},
	{"BOSONIC", 7, 141458},
	{"HOLSTON", 7, 141459},
	{"MARKETSHARE", 11, 141460},
	{"NEIGE", 5, 141461},
	{"FORMIC", 6, 141462},
	{"FISHGUARD", 9, 141463},
	{"WOODWORKS", 9, 141464},
	{"ROUS", 4, 141465},
	{"SPINLOCK", 8, 141466},
	{"SNEERED", 7, 141467},
	{"RAMANUJAN", 9, 141468},
	{"PINAR", 5, 141469},
	{"PREPENDED", 9, 141470},
	{"COVENS", 6, 141471},
	{"WHITESBORO", 10, 141472},
	{"SUMBRELLA", 9, 141473},
	{"CHATTELS", 8, 141474},
	{"VACUOLE", 7, 141475},
	{"THKY", 4, 141476},
	{"SMTR", 4, 141477},
	{"PALV", 4, 141478},
	{"ORPD", 4, 141479},
	{"OKPH", 4, 141480},
	{"LBSO", 4, 141481},
	{"INYG", 4, 141482},
	{"ILJE", 4, 141483},
	{"IGYE", 4, 141484},
	{"HWEV", 4, 141485},
	{"GVON", 4, 141486},
	{"GSOY", 4, 141487},
	{"ECTX", 4, 141488},
	{"DTAV", 4, 141489},
	{"CUBB", 4, 141490},
	{"AUGC", 4, 141491},
	{"TYMOSHENKO", 10, 141492},
	{"DREADLOCKS", 10, 141493},
	{"PINCHER", 7, 141494},
	{"CHURCHVILLE", 11, 141495},
	{"REALCITIES", 10, 141496},
	{"BIOCOMPATIBLE", 13, 141497},
	{"HOTLES", 6, 141498},
	{"ELECTROVOICE", 12, 141499},
	{"SULFOXIDE", 9, 141500},
	{"STATUSBAR", 9, 141501},
	{"BRAMBLES", 8, 141502},
	{"SOHAM", 5, 141503},
	{"IMPERILED", 9, 141504},
	{"GGU", 3, 141505},
	{"BONIN", 5, 141506},
	{"VITILIGO", 8, 141507},
	{"GAMBLES", 7, 141508},
	{"POWERCENTER", 11, 141509},
	{"DISEMBARK", 9, 141510},
	{"TRADESTATION", 12, 141511},
	{"NADEL", 5, 141512},
	{"THREADID", 8, 141513},
	{"PONSONBY", 8, 141514},
	{"LINCOLNWOOD", 11, 141515},
	{"GIFTSET", 7, 141516},
	{"ECCLESIOLOGY", 12, 141517},
	{"AICHE", 5, 141518},
	{"INSERISCI", 9, 141519},
	{"SECEDE", 6, 141520},
	{"CARSEAT", 7, 141521},
	{"PRINCI", 6, 141522},
	{"ACCESSDANCE", 11, 141523},
	{"KORY", 4, 141524},
	{"SITUA", 5, 141525},
	{"STUDENTINNEN", 12, 141526},
	{"LYLA", 4, 141527},
	{"GRAVENHURST", 11, 141528},
	{"ZZWI", 4, 141529},
	{"WIIR", 4, 141530},
	{"VEYU", 4, 141531},
	{"URPC", 4, 141532},
	{"SPNR", 4, 141533},
	{"RGTE", 4, 141534},
	{"ORCD", 4, 141535},
	{"MULO", 4, 141536},
	{"LBIC", 4, 141537},
	{"ITUC", 4, 141538},
	{"FTGI", 4, 141539},
	{"ERKB", 4, 141540},
	{"DPSA", 4, 141541},
	{"CALVERTON", 9, 141542},
	{"AMPLI", 5, 141543},
	{"QUICKUTZ", 8, 141544},
	{"POTENTIALITY", 12, 141545},
	{"TUBB", 4, 141546},
	{"UNMIXED", 7, 141547},
	{"HUSAYN", 6, 141548},
	{"RESETTLED", 9, 141549},
	{"BUZZY", 5, 141550},
	{"GRIEVES", 7, 141551},
	{"CTIME", 5, 141552},
	{"PINOS", 5, 141553},
	{"ONCOGENIC", 9, 141554},
	{"DOGGIES", 7, 141555},
	{"DAHLIAS", 7, 141556},
	{"PERDITA", 7, 141557},
	{"BAFO", 4, 141558},
	{"IRREVERSIBLY", 12, 141559},
	{"XWEM", 4, 141560},
	{"PRISES", 6, 141561},
	{"FREEDOWNLOAD", 12, 141562},
	{"PGF", 3, 141563},
	{"WEBOPEDIA", 9, 141564},
	{"NICCOLO", 7, 141565},
	{"NOIMAGE", 7, 141566},
	{"VUARNET", 7, 141567},
	{"RECUPERATE", 10, 141568},
	{"STRIATED", 8, 141569},
	{"LRM", 3, 141570},
	{"CHIMICA", 7, 141571},
	{"TRADOC", 6, 141572},
	{"TUMBLES", 7, 141573},
	{"SOGENANNTEN", 11, 141574},
	{"RLP", 3, 141575},
	{"MTETRA", 6, 141576},
	{"GRUNGY", 6, 141577},
	{"WBZ", 3, 141578},
	{"MAILINGLISTS", 12, 141579},
	{"EKATERINA", 9, 141580},
	{"ZROY", 4, 141581},
	{"VEXI", 4, 141582},
	{"URUB", 4, 141583},
	{"PCER", 4, 141584},
	{"OFMF", 4, 141585},
	{"MSUT", 4, 141586},
	{"KBIN", 4, 141587},
	{"ITZD", 4, 141588},
	{"HEJD", 4, 141589},
	{"FWRA", 4, 141590},
	{"EFOY", 4, 141591},
	{"DMAO", 4, 141592},
	{"COJU", 4, 141593},
	{"BNIZ", 4, 141594},
	{"AZUS", 4, 141595},
	{"AZAF", 4, 141596},
	{"AVIU", 4, 141597},
	{"BRONZING", 8, 141598},
	{"OBJECTIFS", 9, 141599},
	{"MCDUFFIE", 8, 141600},
	{"SILVERTIDE", 10, 141601},
	{"ADCOM", 5, 141602},
	{"LANGDALE", 8, 141603},
	{"MANGLING", 8, 141604},
	{"DESIGNWORKSHOP", 14, 141605},
	{"SUMIT", 5, 141606},
	{"ELUCIDATING", 11, 141607},
	{"UNLOCKABLE", 10, 141608},
	{"ONBASE", 6, 141609},
	{"SKATEBOARDER", 12, 141610},
	{"MAHAFFEY", 8, 141611},
	{"JIMS", 4, 141612},
	{"MARYLIN", 7, 141613},
	{"AUTOWEB", 7, 141614},
	{"ICAZA", 5, 141615},
	{"SNUGGLING", 9, 141616},
	{"SHANDS", 6, 141617},
	{"PAIK", 4, 141618},
	{"PARNASSUS", 9, 141619},
	{"FROGMAN", 7, 141620},
	{"WOODGRAIN", 9, 141621},
	{"ANGELFISH", 9, 141622},
	{"THREEWAY", 8, 141623},
	{"EXTRAGALACTIC", 13, 141624},
	{"ALCS", 4, 141625},
	{"GREATFUL", 8, 141626},
	{"FILTRATE", 8, 141627},
	{"RML", 3, 141628},
	{"FLYAWAY", 7, 141629},
	{"DEBARRED", 8, 141630},
	{"GUPTILL", 7, 141631},
	{"YESK", 4, 141632},
	{"WKSD", 4, 141633},
	{"WDOG", 4, 141634},
	{"NFLM", 4, 141635},
	{"MSVO", 4, 141636},
	{"MAUP", 4, 141637},
	{"KKUR", 4, 141638},
	{"KILF", 4, 141639},
	{"KEJI", 4, 141640},
	{"GGYW", 4, 141641},
	{"ENGX", 4, 141642},
	{"CRSQ", 4, 141643},
	{"CBCR", 4, 141644},
	{"DANDELIONS", 10, 141645},
	{"GRISTMILL", 9, 141646},
	{"ROBITUSSIN", 10, 141647},
	{"GIPSON", 6, 141648},
	{"PEPTIDYL", 8, 141649},
	{"REPOSITIONED", 12, 141650},
	{"OSTELLI", 7, 141651},
	{"ABYSSINIAN", 10, 141652},
	{"GOALTENDERS", 11, 141653},
	{"EXCITON", 7, 141654},
	{"WAYFINDING", 10, 141655},
	{"NOUR", 4, 141656},
	{"MALER", 5, 141657},
	{"POCOCK", 6, 141658},
	{"SUBKEY", 6, 141659},
	{"SHANKEY", 7, 141660},
	{"PICUTRES", 8, 141661},
	{"SYLVIAN", 7, 141662},
	{"HAYDOCK", 7, 141663},
	{"BULGARIANS", 10, 141664},
	{"DEFNYDDIO", 9, 141665},
	{"CDROMS", 6, 141666},
	{"DURR", 4, 141667},
	{"PARTICIPA", 9, 141668},
	{"LAMMERS", 7, 141669},
	{"BLOGCRITIC", 10, 141670},
	{"MORELL", 6, 141671},
	{"APOLOGIA", 8, 141672},
	{"DISCWASHER", 10, 141673},
	{"PROVINCIALLY", 12, 141674},
	{"NATIONALIZATION", 15, 141675},
	{"WYNONNA", 7, 141676},
	{"SPKR", 4, 141677},
	{"PSEUDORANDOM", 12, 141678},
	{"AIMHIGHER", 9, 141679},
	{"KAZU", 4, 141680},
	{"WCRU", 4, 141681},
	{"VWOU", 4, 141682},
	{"TVDE", 4, 141683},
	{"TVBE", 4, 141684},
	{"TTMU", 4, 141685},
	{"TLUD", 4, 141686},
	{"STCD", 4, 141687},
	{"RIEX", 4, 141688},
	{"NKGI", 4, 141689},
	{"JOYG", 4, 141690},
	{"IFJU", 4, 141691},
	{"FTCU", 4, 141692},
	{"CCIV", 4, 141693},
	{"BMEN", 4, 141694},
	{"APSK", 4, 141695},
	{"ROCKETED", 8, 141696},
	{"YOSHINO", 7, 141697},
	{"LAUR", 4, 141698},
	{"COAXING", 7, 141699},
	{"PROTECTORATES", 13, 141700},
	{"ARGY", 4, 141701},
	{"PUNDITRY", 8, 141702},
	{"MARSHY", 6, 141703},
	{"INTERA", 6, 141704},
	{"TERRES", 6, 141705},
	{"NAVIGATES", 9, 141706},
	{"ARTAGNAN", 8, 141707},
	{"WORMER", 6, 141708},
	{"BLOGG", 5, 141709},
	{"PERSPECT", 8, 141710},
	{"TANTUS", 6, 141711},
	{"OKEHAMPTON", 10, 141712},
	{"DEVICENET", 9, 141713},
	{"BURRIDGE", 8, 141714},
	{"PREYING", 7, 141715},
	{"EROTIEK", 7, 141716},
	{"MARCOM", 6, 141717},
	{"PIKESVILLE", 10, 141718},
	{"SILVSTEDT", 9, 141719},
	{"FRIZZ", 5, 141720},
	{"URIEL", 5, 141721},
	{"STRAIGHTAWAY", 12, 141722},
	{"KILE", 4, 141723},
	{"GRASPS", 6, 141724},
	{"GUIDER", 6, 141725},
	{"EVORA", 5, 141726},
	{"ZONP", 4, 141727},
	{"YNAZ", 4, 141728},
	{"TEWK", 4, 141729},
	{"RRCO", 4, 141730},
	{"RIOJ", 4, 141731},
	{"OGGO", 4, 141732},
	{"NGUG", 4, 141733},
	{"NBCR", 4, 141734},
	{"MUSF", 4, 141735},
	{"LDUB", 4, 141736},
	{"KUZN", 4, 141737},
	{"HTYL", 4, 141738},
	{"HTYC", 4, 141739},
	{"EYKJ", 4, 141740},
	{"ERXE", 4, 141741},
	{"DBYX", 4, 141742},
	{"ADKH", 4, 141743},
	{"MIDO", 4, 141744},
	{"KOSOVAR", 7, 141745},
	{"HUSLER", 6, 141746},
	{"CRYOSTAT", 8, 141747},
	{"ZINNIA", 6, 141748},
	{"SPATULAS", 8, 141749},
	{"PRIMARK", 7, 141750},
	{"HSRC", 4, 141751},
	{"DONLOAD", 7, 141752},
	{"AMGYLCHEDD", 10, 141753},
	{"KHUN", 4, 141754},
	{"HINDLEY", 7, 141755},
	{"FINLUX", 6, 141756},
	{"VIREN", 5, 141757},
	{"PFRAME", 6, 141758},
	{"GEMCITABINE", 11, 141759},
	{"TWIKIINSTALLATIONGUIDE", 22, 141760},
	{"SUBSISTING", 10, 141761},
	{"CBU", 3, 141762},
	{"MACOMBER", 8, 141763},
	{"MELCHER", 7, 141764},
	{"FREUNDE", 7, 141765},
	{"STRIVED", 7, 141766},
	{"FEYENOORD", 9, 141767},
	{"ZATERDAG", 8, 141768},
	{"RUKH", 4, 141769},
	{"RXD", 3, 141770},
	{"METAMORPHISM", 12, 141771},
	{"JOBBOOM", 7, 141772},
	{"FAMOSOS", 7, 141773},
	{"DIALECTICS", 10, 141774},
	{"HEALTHCHECK", 11, 141775},
	{"SECONDARIES", 11, 141776},
	{"LEICHHARDT", 10, 141777},
	{"BLADDERS", 8, 141778},
	{"OVEREXPRESSED", 13, 141779},
	{"ZEAD", 4, 141780},
	{"YLLW", 4, 141781},
	{"UJOI", 4, 141782},
	{"TEUB", 4, 141783},
	{"SLOM", 4, 141784},
	{"SIML", 4, 141785},
	{"RIKW", 4, 141786},
	{"OKDR", 4, 141787},
	{"KBAU", 4, 141788},
	{"HYPI", 4, 141789},
	{"EAXL", 4, 141790},
	{"BRIGADOON", 9, 141791},
	{"CALLEE", 6, 141792},
	{"ZJC", 3, 141793},
	{"ZFY", 3, 141794},
	{"YVX", 3, 141795},
	{"XFG", 3, 141796},
	{"WGX", 3, 141797},
	{"VZD", 3, 141798},
	{"VJL", 3, 141799},
	{"QXC", 3, 141800},
	{"QFG", 3, 141801},
	{"QDY", 3, 141802},
	{"PXK", 3, 141803},
	{"MFZ", 3, 141804},
	{"JZK", 3, 141805},
	{"JZF", 3, 141806},
	{"JRZ", 3, 141807},
	{"JGV", 3, 141808},
	{"GQQ", 3, 141809},
	{"FQG", 3, 141810},
	{"DZJ", 3, 141811},
	{"BFZ", 3, 141812},
	{"SHERINGHAM", 10, 141813},
	{"LARG", 4, 141814},
	{"WHITH", 5, 141815},
	{"OXIDIZERS", 9, 141816},
	{"KRIPKE", 6, 141817},
	{"TIGHE", 5, 141818},
	{"PIPIT", 5, 141819},
	{"EIDER", 5, 141820},
	{"PRYDE", 5, 141821},
	{"AVIONS", 6, 141822},
	{"THUMBNAILED", 11, 141823},
	{"JUNTO", 5, 141824},
	{"PONTY", 5, 141825},
	{"RAILROADER", 10, 141826},
	{"BLOEMEN", 7, 141827},
	{"SOMETOPIC", 9, 141828},
	{"MAGNEX", 6, 141829},
	{"BUDDYICONS", 10, 141830},
	{"WALLSTREET", 10, 141831},
	{"WLM", 3, 141832},
	{"ELASTASE", 8, 141833},
	{"MATERI", 6, 141834},
	{"LATIUM", 6, 141835},
	{"OLEFINS", 7, 141836},
	{"TEXTOS", 6, 141837},
	{"AUDIX", 5, 141838},
	{"SHUTTERED", 9, 141839},
	{"HAUSBESUCH", 10, 141840},
	{"ALCHEMISTS", 10, 141841},
	{"DINAMO", 6, 141842},
	{"NOVAS", 5, 141843},
	{"BADNARIK", 8, 141844},
	{"CYCLOSPORIN", 11, 141845},
	{"IWASAKI", 7, 141846},
	{"WINTERFEST", 10, 141847},
	{"YDEH", 4, 141848},
	{"WIFS", 4, 141849},
	{"UIXO", 4, 141850},
	{"UFIE", 4, 141851},
	{"THDW", 4, 141852},
	{"SGTJ", 4, 141853},
	{"RGOG", 4, 141854},
	{"RCKS", 4, 141855},
	{"PYNO", 4, 141856},
	{"NKYB", 4, 141857},
	{"MECY", 4, 141858},
	{"KSEY", 4, 141859},
	{"EMUF", 4, 141860},
	{"DKMN", 4, 141861},
	{"CHYL", 4, 141862},
	{"CELC", 4, 141863},
	{"BURW", 4, 141864},
	{"FERNWOOD", 8, 141865},
	{"GAMESPACE", 9, 141866},
	{"LIVECHATS", 9, 141867},
	{"ROTLICHT", 8, 141868},
	{"TICKETSON", 9, 141869},
	{"OPENEJB", 7, 141870},
	{"MOROSE", 6, 141871},
	{"KURA", 4, 141872},
	{"FECTS", 5, 141873},
	{"POORE", 5, 141874},
	{"XSMALL", 6, 141875},
	{"PAINTSHOP", 9, 141876},
	{"BEETROOT", 8, 141877},
	{"FOUNDLOCALLY", 12, 141878},
	{"BESTSOLAR", 9, 141879},
	{"BLINKIES", 8, 141880},
	{"RUFFINI", 7, 141881},
	{"SENTATION", 9, 141882},
	{"REGRETFULLY", 11, 141883},
	{"STRETFORD", 9, 141884},
	{"GUGLIELMO", 9, 141885},
	{"STRAYLIGHT", 10, 141886},
	{"LARI", 4, 141887},
	{"MARZ", 4, 141888},
	{"MOSTAFA", 7, 141889},
	{"SANDBLASTED", 11, 141890},
	{"PKB", 3, 141891},
	{"PLAINSBORO", 10, 141892},
	{"INTERLOCKS", 10, 141893},
	{"DEPARDIEU", 9, 141894},
	{"RADIOLABELED", 12, 141895},
	{"OVERHANGS", 9, 141896},
	{"PRALINE", 7, 141897},
	{"BRERETON", 8, 141898},
	{"CHICKPEAS", 9, 141899},
	{"YDUG", 4, 141900},
	{"WYCO", 4, 141901},
	{"MNEU", 4, 141902},
	{"MKOR", 4, 141903},
	{"MFUE", 4, 141904},
	{"MAPB", 4, 141905},
	{"ALGD", 4, 141906},
	{"AFFITTO", 7, 141907},
	{"ABBEYS", 6, 141908},
	{"MICRODATA", 9, 141909},
	{"DUTCHMEN", 8, 141910},
	{"FREETHOUGHT", 11, 141911},
	{"AGITATE", 7, 141912},
	{"PONENT", 6, 141913},
	{"ESPEN", 5, 141914},
	{"WINOOSKI", 8, 141915},
	{"ABDICATION", 10, 141916},
	{"MISALIGNED", 10, 141917},
	{"MUZIC", 5, 141918},
	{"CANAVAN", 7, 141919},
	{"LCDPROC", 7, 141920},
	{"AGROCHEMICALS", 13, 141921},
	{"SCOTTI", 6, 141922},
	{"THYSSEN", 7, 141923},
	{"NSSDC", 5, 141924},
	{"APPLEWOOD", 9, 141925},
	{"DISCONTENTS", 11, 141926},
	{"AIRPOWER", 8, 141927},
	{"BIOGRAFIE", 9, 141928},
	{"CAREFULL", 8, 141929},
	{"KEMET", 5, 141930},
	{"SHINDIG", 7, 141931},
	{"SWAINSON", 8, 141932},
	{"PENNSAUKEN", 10, 141933},
	{"NEROLI", 6, 141934},
	{"SOUTHBURY", 9, 141935},
	{"MONOKINI", 8, 141936},
	{"SURFNET", 7, 141937},
	{"LUDDITE", 7, 141938},
	{"QUARTZITE", 9, 141939},
	{"MARCHESE", 8, 141940},
	{"MCQ", 3, 141941},
	{"GALV", 4, 141942},
	{"MONTEPULCIANO", 13, 141943},
	{"UNDERESTIMATION", 15, 141944},
	{"XTVI", 4, 141945},
	{"WJAM", 4, 141946},
	{"TKOB", 4, 141947},
	{"SOXR", 4, 141948},
	{"OBPO", 4, 141949},
	{"LUEK", 4, 141950},
	{"HNCU", 4, 141951},
	{"GJAZ", 4, 141952},
	{"DHOD", 4, 141953},
	{"AWUS", 4, 141954},
	{"BOTANISTS", 9, 141955},
	{"FARAMIR", 7, 141956},
	{"BOHEMIANS", 9, 141957},
	{"BOVA", 4, 141958},
	{"PHENERGAN", 9, 141959},
	{"ANILLOS", 7, 141960},
	{"MIKKI", 5, 141961},
	{"LOCS", 4, 141962},
	{"UPLO", 4, 141963},
	{"LARDNER", 7, 141964},
	{"BESTER", 6, 141965},
	{"ONTIME", 6, 141966},
	{"PILA", 4, 141967},
	{"CONSETT", 7, 141968},
	{"ALIGNER", 7, 141969},
	{"CHRISTIES", 9, 141970},
	{"FLAKED", 6, 141971},
	{"CHISTES", 7, 141972},
	{"EUTELSAT", 8, 141973},
	{"BLUEJ", 5, 141974},
	{"BLIR", 4, 141975},
	{"HAVAIANAS", 9, 141976},
	{"RATTLER", 7, 141977},
	{"AVAILABE", 8, 141978},
	{"SINALOA", 7, 141979},
	{"DIMARZIO", 8, 141980},
	{"MOVIESTARS", 10, 141981},
	{"PASIR", 5, 141982},
	{"ALEKS", 5, 141983},
	{"BALLADE", 7, 141984},
	{"RECTLY", 6, 141985},
	{"HYBRIDISATION", 13, 141986},
	{"MULTIRESOLUTION", 15, 141987},
	{"KRITIKEN", 8, 141988},
	{"SHEAVE", 6, 141989},
	{"USUI", 4, 141990},
	{"MOVX", 4, 141991},
	{"FOREHEADS", 9, 141992},
	{"EUREKALERT", 10, 141993},
	{"REPLACER", 8, 141994},
	{"MOTTRAM", 7, 141995},
	{"RAFW", 4, 141996},
	{"PMIK", 4, 141997},
	{"NUPN", 4, 141998},
	{"NAVR", 4, 141999},
	{"MIUN", 4, 142000},
	{"IXBR", 4, 142001},
	{"FLYG", 4, 142002},
	{"ETYK", 4, 142003},
	{"EMLY", 4, 142004},
	{"NARRATING", 9, 142005},
	{"GERONTOLOGICAL", 14, 142006},
	{"MAXMEM", 6, 142007},
	{"GERING", 6, 142008},
	{"HOLBROOKE", 9, 142009},
	{"HDPARM", 6, 142010},
	{"SHELLI", 6, 142011},
	{"QUETTA", 6, 142012},
	{"CONCEPTUALIZING", 15, 142013},
	{"WABI", 4, 142014},
	{"SCANDISK", 8, 142015},
	{"REROUTING", 9, 142016},
	{"BANANEWEIZEN", 12, 142017},
	{"VENUTO", 6, 142018},
	{"GREELY", 6, 142019},
	{"PHPGWAPI", 8, 142020},
	{"BORGIA", 6, 142021},
	{"PEDANT", 6, 142022},
	{"STUBBORNNESS", 12, 142023},
	{"GROUCH", 6, 142024},
	{"ZOOBAB", 6, 142025},
	{"DAVIDSO", 7, 142026},
	{"EXTENSOR", 8, 142027},
	{"KABILA", 6, 142028},
	{"CCSA", 4, 142029},
	{"LACERATIONS", 11, 142030},
	{"EYESORE", 7, 142031},
	{"SLAMMIN", 7, 142032},
	{"KEMER", 5, 142033},
	{"HAVANESE", 8, 142034},
	{"GETDATA", 7, 142035},
	{"PENNSYLVANIANS", 14, 142036},
	{"CMAS", 4, 142037},
	{"EMMYS", 5, 142038},
	{"CELLOS", 6, 142039},
	{"CESSPOOL", 8, 142040},
	{"ROTHMANS", 8, 142041},
	{"REWRITECOND", 11, 142042},
	{"LIFO", 4, 142043},
	{"STIRRERS", 8, 142044},
	{"DYEABLE", 7, 142045},
	{"USERPREFERENCES", 15, 142046},
	{"BANALITY", 8, 142047},
	{"ZENJ", 4, 142048},
	{"YOTR", 4, 142049},
	{"YMNO", 4, 142050},
	{"VAFL", 4, 142051},
	{"OWEJ", 4, 142052},
	{"ORBM", 4, 142053},
	{"MVIO", 4, 142054},
	{"MLAP", 4, 142055},
	{"LYOD", 4, 142056},
	{"IVIZ", 4, 142057},
	{"IJAM", 4, 142058},
	{"GSYE", 4, 142059},
	{"FXAN", 4, 142060},
	{"EFUJ", 4, 142061},
	{"DTHY", 4, 142062},
	{"DRFO", 4, 142063},
	{"CYBERAGE", 8, 142064},
	{"DMW", 3, 142065},
	{"VEDI", 4, 142066},
	{"QUESTING", 8, 142067},
	{"HOLROYD", 7, 142068},
	{"PINECONE", 8, 142069},
	{"PIGGIES", 7, 142070},
	{"ERODES", 6, 142071},
	{"PIZARRO", 7, 142072},
	{"NATIONALIZED", 12, 142073},
	{"STREETLIGHT", 11, 142074},
	{"DISTANTLY", 9, 142075},
	{"SAMARRA", 7, 142076},
	{"DAIOH", 5, 142077},
	{"HUMAINE", 7, 142078},
	{"WICKENBURG", 10, 142079},
	{"XSPEC", 5, 142080},
	{"NILLY", 5, 142081},
	{"TECHTV", 6, 142082},
	{"KUCERA", 6, 142083},
	{"FINANCEMENT", 11, 142084},
	{"ELMSFORD", 8, 142085},
	{"VIRTUELLE", 9, 142086},
	{"GROENING", 8, 142087},
	{"FILEDESCRIPTOR", 14, 142088},
	{"MODELLI", 7, 142089},
	{"LPF", 3, 142090},
	{"TOTOWA", 6, 142091},
	{"BOOKEMAIL", 9, 142092},
	{"MILDENHALL", 10, 142093},
	{"CUSSLER", 7, 142094},
	{"PHONEADD", 8, 142095},
	{"YUTH", 4, 142096},
	{"VYSU", 4, 142097},
	{"TMEU", 4, 142098},
	{"RIKL", 4, 142099},
	{"ORRB", 4, 142100},
	{"MIRG", 4, 142101},
	{"LADN", 4, 142102},
	{"KYOP", 4, 142103},
	{"GUSG", 4, 142104},
	{"FVUL", 4, 142105},
	{"ERHM", 4, 142106},
	{"EDFC", 4, 142107},
	{"EBTD", 4, 142108},
	{"CCWA", 4, 142109},
	{"BGRE", 4, 142110},
	{"AZYL", 4, 142111},
	{"AXAD", 4, 142112},
	{"AJUDA", 5, 142113},
	{"JABER", 5, 142114},
	{"BIOG", 4, 142115},
	{"MCCAFFERTY", 10, 142116},
	{"PLANETCCRMA", 11, 142117},
	{"RIDGEVIEW", 9, 142118},
	{"LGL", 3, 142119},
	{"CONAKRY", 7, 142120},
	{"QUEASY", 6, 142121},
	{"AVERTING", 8, 142122},
	{"TAPEWORM", 8, 142123},
	{"ZONDAG", 6, 142124},
	{"PYRE", 4, 142125},
	{"SHALLOT", 7, 142126},
	{"MAPC", 4, 142127},
	{"FRISBEES", 8, 142128},
	{"COMPND", 6, 142129},
	{"ORKS", 4, 142130},
	{"PARALLELING", 11, 142131},
	{"HANMER", 6, 142132},
	{"FAUBOURG", 8, 142133},
	{"BENDIS", 6, 142134},
	{"SAVATAGE", 8, 142135},
	{"REGIONALIZATION", 15, 142136},
	{"KVIRC", 5, 142137},
	{"ZREP", 4, 142138},
	{"ZMOD", 4, 142139},
	{"ZLAN", 4, 142140},
	{"XTHL", 4, 142141},
	{"WREX", 4, 142142},
	{"WPAP", 4, 142143},
	{"WILO", 4, 142144},
	{"UDIF", 4, 142145},
	{"STVC", 4, 142146},
	{"SJUI", 4, 142147},
	{"OYGR", 4, 142148},
	{"NGUJ", 4, 142149},
	{"LUOY", 4, 142150},
	{"LTYU", 4, 142151},
	{"HAFG", 4, 142152},
	{"GINZ", 4, 142153},
	{"FESL", 4, 142154},
	{"EEPQ", 4, 142155},
	{"DYAI", 4, 142156},
	{"DJAB", 4, 142157},
	{"BFIL", 4, 142158},
	{"AJAF", 4, 142159},
	{"MADI", 4, 142160},
	{"CENTROMERE", 10, 142161},
	{"WOOED", 5, 142162},
	{"VORSCHAU", 8, 142163},
	{"GROLIER", 7, 142164},
	{"CHEMOTACTIC", 11, 142165},
	{"WHQL", 4, 142166},
	{"MEZA", 4, 142167},
	{"SARCOMAS", 8, 142168},
	{"ENCL", 4, 142169},
	{"DFEE", 4, 142170},
	{"RAME", 4, 142171},
	{"CHALKY", 6, 142172},
	{"TEAMSTER", 8, 142173},
	{"COMBATTING", 10, 142174},
	{"ZDV", 3, 142175},
	{"SYMB", 4, 142176},
	{"CULLODEN", 8, 142177},
	{"PRIVATHURE", 10, 142178},
	{"BEACHED", 7, 142179},
	{"CAMPDEN", 7, 142180},
	{"SOLARI", 6, 142181},
	{"FRINGING", 8, 142182},
	{"IGRP", 4, 142183},
	{"MULTINOMIAL", 11, 142184},
	{"RINGSPUN", 8, 142185},
	{"PANSAT", 6, 142186},
	{"BVBA", 4, 142187},
	{"RANDA", 5, 142188},
	{"GENCE", 5, 142189},
	{"LUSTMODELLE", 11, 142190},
	{"INFORMASJON", 11, 142191},
	{"XIME", 4, 142192},
	{"UPJA", 4, 142193},
	{"UJIS", 4, 142194},
	{"PHDD", 4, 142195},
	{"PALN", 4, 142196},
	{"NKYI", 4, 142197},
	{"KOBL", 4, 142198},
	{"KKEY", 4, 142199},
	{"IYAG", 4, 142200},
	{"ISPP", 4, 142201},
	{"IMPB", 4, 142202},
	{"IJIM", 4, 142203},
	{"IDUM", 4, 142204},
	{"GDIL", 4, 142205},
	{"DTIF", 4, 142206},
	{"BPSA", 4, 142207},
	{"BMAD", 4, 142208},
	{"LAFF", 4, 142209},
	{"ARPS", 4, 142210},
	{"MONTANO", 7, 142211},
	{"GLANS", 5, 142212},
	{"THOUSANDTH", 10, 142213},
	{"AGEISM", 6, 142214},
	{"ASLAM", 5, 142215},
	{"INTERLOCAL", 10, 142216},
	{"SULT", 4, 142217},
	{"MIXX", 4, 142218},
	{"OUTDOORGEAR", 11, 142219},
	{"ZLWK", 4, 142220},
	{"OMMUNITY", 8, 142221},
	{"WOLOF", 5, 142222},
	{"BENDABLE", 8, 142223},
	{"RESONATING", 10, 142224},
	{"OETIKER", 7, 142225},
	{"REGROUPING", 10, 142226},
	{"SEGREGATING", 11, 142227},
	{"FLEXURE", 7, 142228},
	{"SOLUTES", 7, 142229},
	{"DOAK", 4, 142230},
	{"APPRENTISSAGE", 13, 142231},
	{"HAMTON", 6, 142232},
	{"JAGR", 4, 142233},
	{"SACRILEGE", 9, 142234},
	{"DGMARKET", 8, 142235},
	{"KRISHNAMURTHY", 13, 142236},
	{"REIDSVILLE", 10, 142237},
	{"TINUE", 5, 142238},
	{"OLDSMAR", 7, 142239},
	{"RWTH", 4, 142240},
	{"GABLER", 6, 142241},
	{"WACHOWSKI", 9, 142242},
	{"PWEE", 4, 142243},
	{"NZAV", 4, 142244},
	{"NDTB", 4, 142245},
	{"LPIR", 4, 142246},
	{"DGWE", 4, 142247},
	{"AGHR", 4, 142248},
	{"AFEK", 4, 142249},
	{"PAPERBOUND", 10, 142250},
	{"PRESSTHINK", 10, 142251},
	{"HIATAL", 6, 142252},
	{"ZOOBOOKS", 8, 142253},
	{"MUNDELL", 7, 142254},
	{"FAJARDO", 7, 142255},
	{"DEMAGOGUE", 9, 142256},
	{"HOLDIN", 6, 142257},
	{"FDB", 3, 142258},
	{"TIAGO", 5, 142259},
	{"RAUSCH", 6, 142260},
	{"QUDS", 4, 142261},
	{"PULPS", 5, 142262},
	{"GRATTON", 7, 142263},
	{"TALIAFERRO", 10, 142264},
	{"DEMEAN", 6, 142265},
	{"AURELIO", 7, 142266},
	{"CHANGEMENT", 10, 142267},
	{"QUAKECON", 8, 142268},
	{"OBELIX", 6, 142269},
	{"NOTETAKER", 9, 142270},
	{"NISHIMOTO", 9, 142271},
	{"WHITEWOOD", 9, 142272},
	{"FOREBEARS", 9, 142273},
	{"STIPULATING", 11, 142274},
	{"MORTY", 5, 142275},
	{"SCINTIGRAPHY", 12, 142276},
	{"EFORCITY", 8, 142277},
	{"NORTHSHIRE", 10, 142278},
	{"BITER", 5, 142279},
	{"GLYCERALDEHYDE", 14, 142280},
	{"VARMOD", 6, 142281},
	{"PECKINPAH", 9, 142282},
	{"WIDMER", 6, 142283},
	{"XISG", 4, 142284},
	{"UYSK", 4, 142285},
	{"UUMS", 4, 142286},
	{"RGPE", 4, 142287},
	{"QARA", 4, 142288},
	{"NZEB", 4, 142289},
	{"NDML", 4, 142290},
	{"LIJI", 4, 142291},
	{"KIFE", 4, 142292},
	{"HKAM", 4, 142293},
	{"GVIT", 4, 142294},
	{"GRIO", 4, 142295},
	{"FYAM", 4, 142296},
	{"ELNY", 4, 142297},
	{"EDBH", 4, 142298},
	{"BETM", 4, 142299},
	{"ACTEL", 5, 142300},
	{"PROPPING", 8, 142301},
	{"PREVIN", 6, 142302},
	{"CLEARTOUCH", 10, 142303},
	{"MSTP", 4, 142304},
	{"SUIVANTES", 9, 142305},
	{"DISCOUNTSOFFERS", 15, 142306},
	{"EPCRA", 5, 142307},
	{"BARTERING", 9, 142308},
	{"BECAS", 5, 142309},
	{"OMSK", 4, 142310},
	{"LEITZ", 5, 142311},
	{"BIERMAN", 7, 142312},
	{"PROPANOL", 8, 142313},
	{"UNINSTALLERS", 12, 142314},
	{"BACKLINE", 8, 142315},
	{"STORABLE", 8, 142316},
	{"YANNIS", 6, 142317},
	{"WOLSEY", 6, 142318},
	{"EXPANDERS", 9, 142319},
	{"ANDEL", 5, 142320},
	{"SHRINKWRAP", 10, 142321},
	{"GREENLANDIC", 11, 142322},
	{"STUDLEY", 7, 142323},
	{"ALPHAWORKS", 10, 142324},
	{"PROVOLONE", 9, 142325},
	{"AIGHT", 5, 142326},
	{"TRUFFAUT", 8, 142327},
	{"STRAIGHTER", 10, 142328},
	{"IPED", 4, 142329},
	{"WEIRDLY", 7, 142330},
	{"PONTEVEDRA", 10, 142331},
	{"MENAI", 5, 142332},
	{"JXJ", 3, 142333},
	{"STRESSOR", 8, 142334},
	{"YFEU", 4, 142335},
	{"WIDM", 4, 142336},
	{"VOIG", 4, 142337},
	{"UIGL", 4, 142338},
	{"SVYI", 4, 142339},
	{"MUSR", 4, 142340},
	{"LEFS", 4, 142341},
	{"KRIP", 4, 142342},
	{"IFMU", 4, 142343},
	{"HUPM", 4, 142344},
	{"FEYJ", 4, 142345},
	{"FCED", 4, 142346},
	{"EWUL", 4, 142347},
	{"DHUE", 4, 142348},
	{"CEMD", 4, 142349},
	{"APPP", 4, 142350},
	{"WASC", 4, 142351},
	{"POMPTON", 7, 142352},
	{"RAPPORTEURS", 11, 142353},
	{"ALLISTER", 8, 142354},
	{"MEDIATYPE", 9, 142355},
	{"VORIGE", 6, 142356},
	{"BBY", 3, 142357},
	{"AROUNDS", 7, 142358},
	{"UNDERMINER", 10, 142359},
	{"VRIJDAG", 7, 142360},
	{"OVERSTOCKS", 10, 142361},
	{"WINBIND", 7, 142362},
	{"CRYOGENICS", 10, 142363},
	{"KERNERSVILLE", 12, 142364},
	{"BROODS", 6, 142365},
	{"LIKERT", 6, 142366},
	{"ADIPOCYTES", 10, 142367},
	{"GUARENTEED", 10, 142368},
	{"MAXTHON", 7, 142369},
	{"SKINTIGHT", 9, 142370},
	{"EROWID", 6, 142371},
	{"FREUDENHAUS", 11, 142372},
	{"CYCLAMEN", 8, 142373},
	{"ANBERLIN", 8, 142374},
	{"STILETTOS", 9, 142375},
	{"REJOICES", 8, 142376},
	{"CALETA", 6, 142377},
	{"TURTON", 6, 142378},
	{"SPOTLIGHTED", 11, 142379},
	{"HEMATOLOGICAL", 13, 142380},
	{"MCDADE", 6, 142381},
	{"BANSAL", 6, 142382},
	{"SUMMERY", 7, 142383},
	{"STOPPARD", 8, 142384},
	{"PANNIERS", 8, 142385},
	{"MIDTERMS", 8, 142386},
	{"CONVERTORS", 10, 142387},
	{"SMALLINT", 8, 142388},
	{"KELTON", 6, 142389},
	{"FANZONE", 7, 142390},
	{"INFOSERVE", 9, 142391},
	{"HOTEIS", 6, 142392},
	{"CLEMENTI", 8, 142393},
	{"ZORT", 4, 142394},
	{"WLWA", 4, 142395},
	{"WDSI", 4, 142396},
	{"WATB", 4, 142397},
	{"UYSY", 4, 142398},
	{"UOCA", 4, 142399},
	{"UITV", 4, 142400},
	{"SGAG", 4, 142401},
	{"RBUZ", 4, 142402},
	{"PYPE", 4, 142403},
	{"NGMT", 4, 142404},
	{"NFAK", 4, 142405},
	{"LZAC", 4, 142406},
	{"JRTO", 4, 142407},
	{"HEDQ", 4, 142408},
	{"DJAW", 4, 142409},
	{"LIMBER", 6, 142410},
	{"BLACKBAUD", 9, 142411},
	{"CARAPACE", 8, 142412},
	{"EZUTILS", 7, 142413},
	{"VENTILATE", 9, 142414},
	{"CPV", 3, 142415},
	{"HABLAR", 6, 142416},
	{"MAHOMET", 7, 142417},
	{"BARDIC", 6, 142418},
	{"JINNAH", 6, 142419},
	{"NMAX", 4, 142420},
	{"DOULAS", 6, 142421},
	{"EARDRUM", 7, 142422},
	{"RESELLS", 7, 142423},
	{"FEARN", 5, 142424},
	{"FIREBAUGH", 9, 142425},
	{"TELEGRAPHY", 10, 142426},
	{"HERPETOLOGY", 11, 142427},
	{"REFOCUSING", 10, 142428},
	{"SONIQUE", 7, 142429},
	{"MISOPROSTOL", 11, 142430},
	{"WACC", 4, 142431},
	{"DUNMOW", 6, 142432},
	{"LONGWAVE", 8, 142433},
	{"LEHRE", 5, 142434},
	{"EDUCACION", 9, 142435},
	{"CARMELA", 7, 142436},
	{"NORTHWESTERLY", 13, 142437},
	{"BEDAZZLED", 9, 142438},
	{"RAIFFEISEN", 10, 142439},
	{"BCIT", 4, 142440},
	{"PSYCHOPHYSIOLOGY", 16, 142441},
	{"ILLY", 4, 142442},
	{"ELASTICS", 8, 142443},
	{"RANUNCULUS", 10, 142444},
	{"CASTLEREAGH", 11, 142445},
	{"HALONG", 6, 142446},
	{"NECROTIZING", 11, 142447},
	{"ASPCA", 5, 142448},
	{"ZZOU", 4, 142449},
	{"UEMP", 4, 142450},
	{"PYDO", 4, 142451},
	{"MRGI", 4, 142452},
	{"MLAG", 4, 142453},
	{"IPKI", 4, 142454},
	{"IDAJ", 4, 142455},
	{"DZAR", 4, 142456},
	{"DLOF", 4, 142457},
	{"DKAU", 4, 142458},
	{"APIF", 4, 142459},
	{"GREYMOUTH", 9, 142460},
	{"SPIELER", 7, 142461},
	{"DOETH", 5, 142462},
	{"BIRDLAND", 8, 142463},
	{"MONASTICISM", 11, 142464},
	{"VANDYKE", 7, 142465},
	{"SFIST", 5, 142466},
	{"KUP", 3, 142467},
	{"GOLDERS", 7, 142468},
	{"VERSCHIEDENEN", 13, 142469},
	{"FADO", 4, 142470},
	{"ULTRAFINE", 9, 142471},
	{"OUTROS", 6, 142472},
	{"COFFEESHOP", 10, 142473},
	{"ULLMANN", 7, 142474},
	{"STRANGLER", 9, 142475},
	{"RESPIRABLE", 10, 142476},
	{"LEGALISTIC", 10, 142477},
	{"CLUTE", 5, 142478},
	{"OSELTAMIVIR", 11, 142479},
	{"VCALENDAR", 9, 142480},
	{"WEBOBILL", 8, 142481},
	{"SUPERGROUP", 10, 142482},
	{"MUSICALITY", 10, 142483},
	{"GAMEFLY", 7, 142484},
	{"CHAMELEONS", 10, 142485},
	{"WINDCHIME", 9, 142486},
	{"STABENOW", 8, 142487},
	{"CHRYSOSTOM", 10, 142488},
	{"BLACKFEET", 9, 142489},
	{"REITH", 5, 142490},
	{"TONOPAH", 7, 142491},
	{"WAISTCOATS", 10, 142492},
	{"PRACTIONERS", 11, 142493},
	{"NOATUN", 6, 142494},
	{"ZZR", 3, 142495},
	{"SANYA", 5, 142496},
	{"ZOOLANDER", 9, 142497},
	{"DONEGAN", 7, 142498},
	{"KENTROX", 7, 142499},
	{"WWWV", 4, 142500},
	{"RUZW", 4, 142501},
	{"RUPM", 4, 142502},
	{"RHYB", 4, 142503},
	{"PODR", 4, 142504},
	{"PMSO", 4, 142505},
	{"OFKW", 4, 142506},
	{"LKYO", 4, 142507},
	{"HTYW", 4, 142508},
	{"GYFU", 4, 142509},
	{"GSUD", 4, 142510},
	{"FSEQ", 4, 142511},
	{"DNDI", 4, 142512},
	{"DIMV", 4, 142513},
	{"DCEC", 4, 142514},
	{"AXIW", 4, 142515},
	{"ATDW", 4, 142516},
	{"AMYP", 4, 142517},
	{"WAHID", 5, 142518},
	{"BELGA", 5, 142519},
	{"TRANSITIVITY", 12, 142520},
	{"WIKIPREFSTOPIC", 14, 142521},
	{"MCKIM", 5, 142522},
	{"DEEDEE", 6, 142523},
	{"PFILE", 5, 142524},
	{"SCRIPTABLE", 10, 142525},
	{"RAAK", 4, 142526},
	{"EMDEN", 5, 142527},
	{"KATZMAN", 7, 142528},
	{"USATODAY", 8, 142529},
	{"BLES", 4, 142530},
	{"MONTAGES", 8, 142531},
	{"SWEENY", 6, 142532},
	{"ROOMSHARE", 9, 142533},
	{"ALIANZA", 7, 142534},
	{"SUPPOR", 6, 142535},
	{"CONRAIL", 7, 142536},
	{"IMGREFURL", 9, 142537},
	{"HINDIII", 7, 142538},
	{"PATISSERIE", 10, 142539},
	{"VALLEYVIEW", 10, 142540},
	{"GILLARD", 7, 142541},
	{"CHALKED", 7, 142542},
	{"POSTHARVEST", 11, 142543},
	{"BBQS", 4, 142544},
	{"MIGHTIEST", 9, 142545},
	{"WALKUP", 6, 142546},
	{"BOTHS", 5, 142547},
	{"MARVELOUSLY", 11, 142548},
	{"VCCI", 4, 142549},
	{"BOZELL", 6, 142550},
	{"STRANGULATION", 13, 142551},
	{"CROSSBONES", 10, 142552},
	{"BAILIFFS", 8, 142553},
	{"PUSSI", 5, 142554},
	{"LAXMI", 5, 142555},
	{"RINSES", 6, 142556},
	{"STUBBLEFIELD", 12, 142557},
	{"SINGLING", 8, 142558},
	{"ZYST", 4, 142559},
	{"ZIEM", 4, 142560},
	{"YOVA", 4, 142561},
	{"YLGR", 4, 142562},
	{"TBBC", 4, 142563},
	{"SCDE", 4, 142564},
	{"RIKR", 4, 142565},
	{"RFEU", 4, 142566},
	{"ORBP", 4, 142567},
	{"NAMG", 4, 142568},
	{"KGAI", 4, 142569},
	{"HEJV", 4, 142570},
	{"GBIA", 4, 142571},
	{"BFOO", 4, 142572},
	{"CADILLACS", 9, 142573},
	{"GOOGGLE", 7, 142574},
	{"INFIRMITIES", 11, 142575},
	{"BASALTS", 7, 142576},
	{"BADDIES", 7, 142577},
	{"TANEY", 5, 142578},
	{"DENIGRATE", 9, 142579},
	{"PROTEOGLYCAN", 12, 142580},
	{"PERICARDITIS", 12, 142581},
	{"WELLBORE", 8, 142582},
	{"UNRUH", 5, 142583},
	{"PODGORICA", 9, 142584},
	{"BALLYMONEY", 10, 142585},
	{"MOUTHFEEL", 9, 142586},
	{"LEVERETT", 8, 142587},
	{"DECORA", 6, 142588},
	{"SLUGFEST", 8, 142589},
	{"GAYDAR", 6, 142590},
	{"GAMEHOUSE", 9, 142591},
	{"DUPLIN", 6, 142592},
	{"ALEF", 4, 142593},
	{"ZATCH", 5, 142594},
	{"JOINTING", 8, 142595},
	{"DIPHENYL", 8, 142596},
	{"CLEVIS", 6, 142597},
	{"SHEZONGO", 8, 142598},
	{"PRINEVILLE", 10, 142599},
	{"MAUR", 4, 142600},
	{"HOMEBUYING", 10, 142601},
	{"YCIA", 4, 142602},
	{"WBUC", 4, 142603},
	{"UERL", 4, 142604},
	{"RGSM", 4, 142605},
	{"PUPH", 4, 142606},
	{"PBOY", 4, 142607},
	{"MSHR", 4, 142608},
	{"HOTELBESUCHE", 12, 142609},
	{"BROWNSTONER", 11, 142610},
	{"BELLCORE", 8, 142611},
	{"LAGU", 4, 142612},
	{"AMERICANUS", 10, 142613},
	{"POZE", 4, 142614},
	{"ILLUM", 5, 142615},
	{"ABOOT", 5, 142616},
	{"SIDWELL", 7, 142617},
	{"ARGOMENTO", 9, 142618},
	{"JOLTED", 6, 142619},
	{"TADASHI", 7, 142620},
	{"DRUCKVERSION", 12, 142621},
	{"FOUNDA", 6, 142622},
	{"MANNE", 5, 142623},
	{"INSERATE", 8, 142624},
	{"BREAKFREE", 9, 142625},
	{"XPERTVISION", 11, 142626},
	{"HOTWHEELS", 9, 142627},
	{"JACOBITE", 8, 142628},
	{"VIENDO", 6, 142629},
	{"NCPA", 4, 142630},
	{"BIOTEC", 6, 142631},
	{"PRIDDY", 6, 142632},
	{"GREENMAN", 8, 142633},
	{"VIDUALS", 7, 142634},
	{"SPINOFFS", 8, 142635},
	{"ROBITAILLE", 10, 142636},
	{"GRANNIE", 7, 142637},
	{"COSTANZO", 8, 142638},
	{"ALGONA", 6, 142639},
	{"SACKLER", 7, 142640},
	{"ASIANTHUMBS", 11, 142641},
	{"FRECKLED", 8, 142642},
	{"TAGLIBS", 7, 142643},
	{"APXS", 4, 142644},
	{"RECORDLABEL", 11, 142645},
	{"ZOOW", 4, 142646},
	{"XOFO", 4, 142647},
	{"WKSR", 4, 142648},
	{"WDOR", 4, 142649},
	{"UEAW", 4, 142650},
	{"REZP", 4, 142651},
	{"RELK", 4, 142652},
	{"RBYY", 4, 142653},
	{"ODDG", 4, 142654},
	{"FRAH", 4, 142655},
	{"ECOK", 4, 142656},
	{"DRGE", 4, 142657},
	{"CBAI", 4, 142658},
	{"CAIM", 4, 142659},
	{"CAHU", 4, 142660},
	{"BCWE", 4, 142661},
	{"CANNABINOID", 11, 142662},
	{"CWL", 3, 142663},
	{"GONSALVES", 9, 142664},
	{"GOLFO", 5, 142665},
	{"DUSAN", 5, 142666},
	{"BILDERBERG", 10, 142667},
	{"PIATT", 5, 142668},
	{"LARY", 4, 142669},
	{"THORSON", 7, 142670},
	{"MISDIAGNOSED", 12, 142671},
	{"CYBERCAFES", 10, 142672},
	{"HARTSON", 7, 142673},
	{"PLENIPOTENTIARY", 15, 142674},
	{"TITICACA", 8, 142675},
	{"MAGLEV", 6, 142676},
	{"ANUCCI", 6, 142677},
	{"PHILISTINE", 10, 142678},
	{"CITICORP", 8, 142679},
	{"VERANSTALTUNGEN", 15, 142680},
	{"GAMBLED", 7, 142681},
	{"CHAUVIN", 7, 142682},
	{"BELLIS", 6, 142683},
	{"TENNER", 6, 142684},
	{"ROHC", 4, 142685},
	{"INDINAVIR", 9, 142686},
	{"HACHETTE", 8, 142687},
	{"APARTAMENTO", 11, 142688},
	{"DISCMAN", 7, 142689},
	{"MESSERSCHMITT", 13, 142690},
	{"DARTER", 6, 142691},
	{"BOLEN", 5, 142692},
	{"PANARACER", 9, 142693},
	{"HOTSCRIPTS", 10, 142694},
	{"OCKHAM", 6, 142695},
	{"WIGHTMAN", 8, 142696},
	{"LINDOS", 6, 142697},
	{"YUSO", 4, 142698},
	{"TYYA", 4, 142699},
	{"TADP", 4, 142700},
	{"RTZH", 4, 142701},
	{"OLND", 4, 142702},
	{"LMMU", 4, 142703},
	{"IGNK", 4, 142704},
	{"IFIK", 4, 142705},
	{"EBCH", 4, 142706},
	{"DVEI", 4, 142707},
	{"DATAOBJECT", 10, 142708},
	{"WARPS", 5, 142709},
	{"CVSUP", 5, 142710},
	{"KDEARTWORK", 10, 142711},
	{"MAROONED", 8, 142712},
	{"HOTELSUPERPORTAL", 16, 142713},
	{"CHALEUR", 7, 142714},
	{"INVERTS", 7, 142715},
	{"MTVU", 4, 142716},
	{"IDUS", 4, 142717},
	{"ELWELL", 6, 142718},
	{"UNIMAGINATIVE", 13, 142719},
	{"CODS", 4, 142720},
	{"FERRARIS", 8, 142721},
	{"AMARYL", 6, 142722},
	{"MCGLADREY", 9, 142723},
	{"JOYEUX", 6, 142724},
	{"CRISWELL", 8, 142725},
	{"SWASHBUCKLING", 13, 142726},
	{"DARRIAN", 7, 142727},
	{"OLYMP", 5, 142728},
	{"NYLA", 4, 142729},
	{"CRSP", 4, 142730},
	{"HINDMAN", 7, 142731},
	{"GRATIFY", 7, 142732},
	{"TRAGER", 6, 142733},
	{"FLAMETHROWER", 12, 142734},
	{"ZIPP", 4, 142735},
	{"ZYWI", 4, 142736},
	{"ZTUR", 4, 142737},
	{"ZPRE", 4, 142738},
	{"UXBR", 4, 142739},
	{"REUZ", 4, 142740},
	{"PPDE", 4, 142741},
	{"OLNB", 4, 142742},
	{"LMIA", 4, 142743},
	{"LDAJ", 4, 142744},
	{"HNQU", 4, 142745},
	{"HEUV", 4, 142746},
	{"GSGU", 4, 142747},
	{"EVIZ", 4, 142748},
	{"AUXP", 4, 142749},
	{"VERISON", 7, 142750},
	{"PMK", 3, 142751},
	{"KEYDATA", 7, 142752},
	{"HYDRAULICALLY", 13, 142753},
	{"SMOKIE", 6, 142754},
	{"DAUPHINE", 8, 142755},
	{"JOSSIP", 6, 142756},
	{"QUINTUM", 7, 142757},
	{"CONJUNCT", 8, 142758},
	{"IANYWHERE", 9, 142759},
	{"DESKWRITER", 10, 142760},
	{"HIPPA", 5, 142761},
	{"ALKANES", 7, 142762},
	{"WRF", 3, 142763},
	{"THEROUX", 7, 142764},
	{"FNMOC", 5, 142765},
	{"PADEN", 5, 142766},
	{"KAARTJES", 8, 142767},
	{"AUTOMETER", 9, 142768},
	{"PROOFREADERS", 12, 142769},
	{"BANJUL", 6, 142770},
	{"MEUSE", 5, 142771},
	{"HATLEY", 6, 142772},
	{"MEGUMI", 6, 142773},
	{"HUWELIJK", 8, 142774},
	{"JAHIA", 5, 142775},
	{"KASPAR", 6, 142776},
	{"CERTAINTIES", 11, 142777},
	{"ZACATECAS", 9, 142778},
	{"BOLING", 6, 142779},
	{"RCON", 4, 142780},
	{"OVERPRINT", 9, 142781},
	{"PROGEN", 6, 142782},
	{"KWORLD", 6, 142783},
	{"FITTINGLY", 9, 142784},
	{"BIOTITE", 7, 142785},
	{"TRINITARIAN", 11, 142786},
	{"ZTHR", 4, 142787},
	{"YZAC", 4, 142788},
	{"UGDI", 4, 142789},
	{"TUML", 4, 142790},
	{"TAJM", 4, 142791},
	{"PPYV", 4, 142792},
	{"PITP", 4, 142793},
	{"OVIB", 4, 142794},
	{"LLTD", 4, 142795},
	{"LLIJ", 4, 142796},
	{"LKAF", 4, 142797},
	{"LAOU", 4, 142798},
	{"KALC", 4, 142799},
	{"IRTD", 4, 142800},
	{"HREU", 4, 142801},
	{"GBHA", 4, 142802},
	{"EIFD", 4, 142803},
	{"BTAL", 4, 142804},
	{"BAIM", 4, 142805},
	{"CHENIN", 6, 142806},
	{"DIFFI", 5, 142807},
	{"DIENSTEN", 8, 142808},
	{"VAGA", 4, 142809},
	{"EXERCISERS", 10, 142810},
	{"SYNANTHSH", 9, 142811},
	{"ACOMMODATION", 12, 142812},
	{"DIFFERNT", 8, 142813},
	{"INDICTABLE", 10, 142814},
	{"WEEKES", 6, 142815},
	{"WONKS", 5, 142816},
	{"EMILIANO", 8, 142817},
	{"DADRA", 5, 142818},
	{"STARLINGS", 9, 142819},
	{"WORLDSCOPE", 10, 142820},
	{"PERIODONTITIS", 13, 142821},
	{"CARDING", 7, 142822},
	{"COFFEEHOUSES", 12, 142823},
	{"FALKEN", 6, 142824},
	{"ELEMENTTYPE", 11, 142825},
	{"KUR", 3, 142826},
	{"SHOWERHEADS", 11, 142827},
	{"HALSOFT", 7, 142828},
	{"ENQUEUE", 7, 142829},
	{"ABDUCT", 6, 142830},
	{"CDKEY", 5, 142831},
	{"DEIMOS", 6, 142832},
	{"CHABERT", 7, 142833},
	{"EXOCYTOSIS", 10, 142834},
	{"ANNALEN", 7, 142835},
	{"SHORTSIGHTED", 12, 142836},
	{"AMERISTAR", 9, 142837},
	{"OPERANT", 7, 142838},
	{"ORCUTT", 6, 142839},
	{"XOFD", 4, 142840},
	{"VIME", 4, 142841},
	{"UNGQ", 4, 142842},
	{"SMCE", 4, 142843},
	{"RPCH", 4, 142844},
	{"ODVO", 4, 142845},
	{"NKIP", 4, 142846},
	{"MDUM", 4, 142847},
	{"LCUB", 4, 142848},
	{"JIRE", 4, 142849},
	{"FNBC", 4, 142850},
	{"YOUSEFZADEH", 11, 142851},
	{"HENEAGE", 7, 142852},
	{"EMMS", 4, 142853},
	{"SEDUM", 5, 142854},
	{"DMAE", 4, 142855},
	{"GELATINE", 8, 142856},
	{"FAIRLEY", 7, 142857},
	{"HIGLEY", 6, 142858},
	{"UNDID", 5, 142859},
	{"GREENFORD", 9, 142860},
	{"PARAGOULD", 9, 142861},
	{"INFRINGER", 9, 142862},
	{"ZWAN", 4, 142863},
	{"HUBBA", 5, 142864},
	{"KILBY", 5, 142865},
	{"GOSHAWK", 7, 142866},
	{"UNCG", 4, 142867},
	{"INDEMNITIES", 11, 142868},
	{"QUELQUE", 7, 142869},
	{"DHLWSE", 6, 142870},
	{"POSSUMS", 7, 142871},
	{"BEKIJK", 6, 142872},
	{"MAULE", 5, 142873},
	{"PUBLICK", 7, 142874},
	{"FOMC", 4, 142875},
	{"UINTAH", 6, 142876},
	{"PARENCHYMA", 10, 142877},
	{"ELECTIONEERING", 14, 142878},
	{"SADDLEBAG", 9, 142879},
	{"NYHEDER", 7, 142880},
	{"LANDUSE", 7, 142881},
	{"ZDEC", 4, 142882},
	{"WOER", 4, 142883},
	{"UETB", 4, 142884},
	{"TFIB", 4, 142885},
	{"RYOM", 4, 142886},
	{"RYEG", 4, 142887},
	{"OWYS", 4, 142888},
	{"OUGB", 4, 142889},
	{"OCHP", 4, 142890},
	{"NGKY", 4, 142891},
	{"MEMN", 4, 142892},
	{"LMAZ", 4, 142893},
	{"KOWL", 4, 142894},
	{"GRYI", 4, 142895},
	{"EZBU", 4, 142896},
	{"EOWU", 4, 142897},
	{"CYGA", 4, 142898},
	{"BAAB", 4, 142899},
	{"AXDI", 4, 142900},
	{"AMYF", 4, 142901},
	{"WEDGIE", 6, 142902},
	{"OPTARG", 6, 142903},
	{"CLIST", 5, 142904},
	{"MANALI", 6, 142905},
	{"PURRS", 5, 142906},
	{"HAMMEL", 6, 142907},
	{"SOUK", 4, 142908},
	{"DUNKELD", 7, 142909},
	{"SYRINGAE", 8, 142910},
	{"CAMTASIA", 8, 142911},
	{"MATTOX", 6, 142912},
	{"BREES", 5, 142913},
	{"PACHELBEL", 9, 142914},
	{"MUTING", 6, 142915},
	{"RESSOURCE", 9, 142916},
	{"MUNT", 4, 142917},
	{"CHICOUTIMI", 10, 142918},
	{"MATRIC", 6, 142919},
	{"REUVEN", 6, 142920},
	{"ARINSAL", 7, 142921},
	{"BARYSHNIKOV", 11, 142922},
	{"HILTI", 5, 142923},
	{"MILSTEIN", 8, 142924},
	{"BETEL", 5, 142925},
	{"MOISTEN", 7, 142926},
	{"MUSIQ", 5, 142927},
	{"BRICKLAYER", 10, 142928},
	{"SPECIALORDER", 12, 142929},
	{"WHITECOURT", 10, 142930},
	{"JESSOP", 6, 142931},
	{"EXTECH", 6, 142932},
	{"ADARA", 5, 142933},
	{"ZSER", 4, 142934},
	{"YKYL", 4, 142935},
	{"TMPS", 4, 142936},
	{"REZF", 4, 142937},
	{"RCAO", 4, 142938},
	{"PPSL", 4, 142939},
	{"MRAH", 4, 142940},
	{"GGLU", 4, 142941},
	{"DRBO", 4, 142942},
	{"DAEU", 4, 142943},
	{"CDWI", 4, 142944},
	{"CDUE", 4, 142945},
	{"BYLL", 4, 142946},
	{"BRUB", 4, 142947},
	{"AQIM", 4, 142948},
	{"LOGGERHEADS", 11, 142949},
	{"FORINTS", 7, 142950},
	{"MOORHEN", 7, 142951},
	{"CENTRALIZING", 12, 142952},
	{"LAPPEENRANTA", 12, 142953},
	{"THROMBUS", 8, 142954},
	{"DEMORALIZED", 11, 142955},
	{"NUTRACEUTICAL", 13, 142956},
	{"DALNET", 6, 142957},
	{"VIOLAS", 6, 142958},
	{"PAVLOVA", 7, 142959},
	{"TRANSACTIVATION", 15, 142960},
	{"PEOPLED", 7, 142961},
	{"DIGTAL", 6, 142962},
	{"EXTRAVIEW", 9, 142963},
	{"MARACAS", 7, 142964},
	{"SHADOWBANE", 10, 142965},
	{"SUFFI", 5, 142966},
	{"MOBLOGUK", 8, 142967},
	{"WONKY", 5, 142968},
	{"MARKETCENTER", 12, 142969},
	{"FERBER", 6, 142970},
	{"LIBGDA", 6, 142971},
	{"INFOBOX", 7, 142972},
	{"SWOOPED", 7, 142973},
	{"INSTANTIATING", 13, 142974},
	{"DORS", 4, 142975},
	{"HETEROZYGOSITY", 14, 142976},
	{"DOCTORED", 8, 142977},
	{"VAUCLUSE", 8, 142978},
	{"AGENZIA", 7, 142979},
	{"TOTALJOBS", 9, 142980},
	{"SOURED", 6, 142981},
	{"MERK", 4, 142982},
	{"REALFOOTY", 9, 142983},
	{"BLOCKADES", 9, 142984},
	{"LEATHERCRAFT", 12, 142985},
	{"FOLKLORIC", 9, 142986},
	{"ZEPPLIN", 7, 142987},
	{"SWSOFT", 6, 142988},
	{"REMICADE", 8, 142989},
	{"HOTSHOTS", 8, 142990},
	{"DELFINO", 7, 142991},
	{"YDOV", 4, 142992},
	{"XYTH", 4, 142993},
	{"WOFJ", 4, 142994},
	{"RHOG", 4, 142995},
	{"PURM", 4, 142996},
	{"PAFU", 4, 142997},
	{"NGQB", 4, 142998},
	{"LVAW", 4, 142999},
	{"KULO", 4, 143000},
	{"KIOW", 4, 143001},
	{"KIKN", 4, 143002},
	{"IPTY", 4, 143003},
	{"HAWB", 4, 143004},
	{"EMUJ", 4, 143005},
	{"BYEG", 4, 143006},
	{"BUKO", 4, 143007},
	{"AWEC", 4, 143008},
	{"TANANA", 6, 143009},
	{"REDHAWK", 7, 143010},
	{"SMAUG", 5, 143011},
	{"DETERRENTS", 10, 143012},
	{"LINKWORLD", 9, 143013},
	{"SKEL", 4, 143014},
	{"GIESSEN", 7, 143015},
	{"DIGWYDDIADAU", 12, 143016},
	{"SLUDGES", 7, 143017},
	{"HIGHBRIDGE", 10, 143018},
	{"MONDALE", 7, 143019},
	{"KAYSER", 6, 143020},
	{"MODERNISTS", 10, 143021},
	{"OPTICON", 7, 143022},
	{"FLANGER", 7, 143023},
	{"ARMEY", 5, 143024},
	{"BOYZONE", 7, 143025},
	{"UWC", 3, 143026},
	{"KITWARE", 7, 143027},
	{"QUIETED", 7, 143028},
	{"CHUTZPAH", 8, 143029},
	{"AQUIRE", 6, 143030},
	{"LAURELL", 7, 143031},
	{"LIFESAVERS", 10, 143032},
	{"UNWED", 5, 143033},
	{"FARREL", 6, 143034},
	{"ROHYPNOL", 8, 143035},
	{"ALBUMEN", 7, 143036},
	{"STEMMER", 7, 143037},
	{"INFLATOR", 8, 143038},
	{"COVELL", 6, 143039},
	{"BLACKMON", 8, 143040},
	{"DURRANT", 7, 143041},
	{"RZEPA", 5, 143042},
	{"CLAIROL", 7, 143043},
	{"SOFTWAREMOST", 12, 143044},
	{"ANJUTA", 6, 143045},
	{"WDAS", 4, 143046},
	{"USYH", 4, 143047},
	{"ULJU", 4, 143048},
	{"UBAU", 4, 143049},
	{"RBMA", 4, 143050},
	{"NTVW", 4, 143051},
	{"NGHR", 4, 143052},
	{"LDAK", 4, 143053},
	{"GMUD", 4, 143054},
	{"ADSV", 4, 143055},
	{"WPG", 3, 143056},
	{"CANALI", 6, 143057},
	{"WIDOWERS", 8, 143058},
	{"SYNCS", 5, 143059},
	{"TURED", 5, 143060},
	{"NONUMMY", 7, 143061},
	{"WPDB", 4, 143062},
	{"PUBLICO", 7, 143063},
	{"ANGIOGENIC", 10, 143064},
	{"PYTHIA", 6, 143065},
	{"BODYSTOCKING", 12, 143066},
	{"EROTIKKONTAKTE", 14, 143067},
	{"EWOK", 4, 143068},
	{"BLIMEY", 6, 143069},
	{"PENTHOUSES", 10, 143070},
	{"ENCIRCLE", 8, 143071},
	{"CARMELITE", 9, 143072},
	{"ANGES", 5, 143073},
	{"PHOTORECEPTORS", 14, 143074},
	{"QUAR", 4, 143075},
	{"EXHORT", 6, 143076},
	{"AKTIENGESELLSCHAFT", 18, 143077},
	{"DAKIN", 5, 143078},
	{"RAMROD", 6, 143079},
	{"SANDBACH", 8, 143080},
	{"OLMOS", 5, 143081},
	{"UCM", 3, 143082},
	{"SENTENTIA", 9, 143083},
	{"TOILETTENCAM", 12, 143084},
	{"MUSTARDS", 8, 143085},
	{"PRIVATCAM", 9, 143086},
	{"JUJITSU", 7, 143087},
	{"HERBED", 6, 143088},
	{"IUMA", 4, 143089},
	{"GAIR", 4, 143090},
	{"MOSCONE", 7, 143091},
	{"PEEPERS", 7, 143092},
	{"YLAF", 4, 143093},
	{"XTYS", 4, 143094},
	{"XTAD", 4, 143095},
	{"XGAI", 4, 143096},
	{"WBOW", 4, 143097},
	{"RKNY", 4, 143098},
	{"RIBC", 4, 143099},
	{"OBTU", 4, 143100},
	{"NTVC", 4, 143101},
	{"LENQ", 4, 143102},
	{"KYIT", 4, 143103},
	{"IDCY", 4, 143104},
	{"ERZU", 4, 143105},
	{"VOYAGERS", 8, 143106},
	{"MCCANDLESS", 10, 143107},
	{"DOTLRN", 6, 143108},
	{"WEEVILS", 7, 143109},
	{"TENDRILS", 8, 143110},
	{"NEANDERTHALS", 12, 143111},
	{"LOIRA", 5, 143112},
	{"SNCF", 4, 143113},
	{"HMRC", 4, 143114},
	{"RETOUCH", 7, 143115},
	{"DOWNLOADE", 9, 143116},
	{"RIPRAP", 6, 143117},
	{"RATCHETS", 8, 143118},
	{"SPADINA", 7, 143119},
	{"AWRR", 4, 143120},
	{"GLOBEINVESTOR", 13, 143121},
	{"SULFOLOBUS", 10, 143122},
	{"OCTEK", 5, 143123},
	{"ARSED", 5, 143124},
	{"RUSHER", 6, 143125},
	{"NULLIFICATION", 13, 143126},
	{"YBOR", 4, 143127},
	{"GRM", 3, 143128},
	{"CHINCHILLAS", 11, 143129},
	{"BUCKED", 6, 143130},
	{"LECTION", 7, 143131},
	{"LOOKAHEAD", 9, 143132},
	{"YOLEN", 5, 143133},
	{"MICROSCALE", 10, 143134},
	{"LOGICA", 6, 143135},
	{"SUPPORTABLE", 11, 143136},
	{"OSTENSIBLE", 10, 143137},
	{"GLAN", 4, 143138},
	{"RIVEST", 6, 143139},
	{"BURGOYNE", 8, 143140},
	{"HMDA", 4, 143141},
	{"DRINKTEC", 8, 143142},
	{"EXACERBATES", 11, 143143},
	{"DERR", 4, 143144},
	{"YMYD", 4, 143145},
	{"VNIK", 4, 143146},
	{"SPYF", 4, 143147},
	{"RPPA", 4, 143148},
	{"OFGT", 4, 143149},
	{"NNYY", 4, 143150},
	{"IDUK", 4, 143151},
	{"HEKD", 4, 143152},
	{"BFAC", 4, 143153},
	{"BEZI", 4, 143154},
	{"BABR", 4, 143155},
	{"GELSENKIRCHEN", 13, 143156},
	{"SUBLETTE", 8, 143157},
	{"MALARIAL", 8, 143158},
	{"REDING", 6, 143159},
	{"SENATES", 7, 143160},
	{"DIORAMAS", 8, 143161},
	{"PBXBUILDFILE", 12, 143162},
	{"KINCARDINESHIRE", 15, 143163},
	{"EXASPERATION", 12, 143164},
	{"EVAC", 4, 143165},
	{"FOURCHE", 7, 143166},
	{"BELPER", 6, 143167},
	{"VENTILATORY", 11, 143168},
	{"BICICLETAS", 10, 143169},
	{"REPLOGLE", 8, 143170},
	{"SPEZIA", 6, 143171},
	{"STUMPY", 6, 143172},
	{"LIVENESS", 8, 143173},
	{"OTOLARYNGOL", 11, 143174},
	{"MERCURIO", 8, 143175},
	{"JEDEN", 5, 143176},
	{"WHEREON", 7, 143177},
	{"LORN", 4, 143178},
	{"ENTENTE", 7, 143179},
	{"COUSHATTA", 9, 143180},
	{"SOMERSAULT", 10, 143181},
	{"METATARSAL", 10, 143182},
	{"HOWSON", 6, 143183},
	{"MARIBOR", 7, 143184},
	{"FILOSOFIA", 9, 143185},
	{"UNSUBSCRIBED", 12, 143186},
	{"SIMMERED", 8, 143187},
	{"GRAMME", 6, 143188},
	{"CONTRUCTION", 11, 143189},
	{"LKM", 3, 143190},
	{"JAKOVLJEVIC", 11, 143191},
	{"PEDI", 4, 143192},
	{"BLCH", 4, 143193},
	{"MAINSAIL", 8, 143194},
	{"DOWELS", 6, 143195},
	{"PLACAS", 6, 143196},
	{"DROPPIN", 7, 143197},
	{"CALTEX", 6, 143198},
	{"RIGH", 4, 143199},
	{"PHENTERAMINE", 12, 143200},
	{"CRESSON", 7, 143201},
	{"YWIE", 4, 143202},
	{"YIFC", 4, 143203},
	{"YANZ", 4, 143204},
	{"SYAD", 4, 143205},
	{"SIXU", 4, 143206},
	{"OLEQ", 4, 143207},
	{"NVIK", 4, 143208},
	{"LEKU", 4, 143209},
	{"HLUS", 4, 143210},
	{"GEOW", 4, 143211},
	{"ECDU", 4, 143212},
	{"DKMM", 4, 143213},
	{"CEYI", 4, 143214},
	{"AUWO", 4, 143215},
	{"ATKY", 4, 143216},
	{"AALU", 4, 143217},
	{"COSMID", 6, 143218},
	{"HODGEPODGE", 10, 143219},
	{"BOOMBOXES", 9, 143220},
	{"PROMPTNESS", 10, 143221},
	{"MULTICOLOUR", 11, 143222},
	{"FALTERS", 7, 143223},
	{"RESUSCITATE", 11, 143224},
	{"RETRAITE", 8, 143225},
	{"LANGAUGE", 8, 143226},
	{"EXCOMMUNICATED", 14, 143227},
	{"HEGARTY", 7, 143228},
	{"CIRCULATIONS", 12, 143229},
	{"CHAFFEY", 7, 143230},
	{"XYIENCE", 7, 143231},
	{"BLOGBUILDER", 11, 143232},
	{"SCOTTSBURG", 10, 143233},
	{"PLAYMAKER", 9, 143234},
	{"SCHLESSER", 9, 143235},
	{"NUTRA", 5, 143236},
	{"MITNICK", 7, 143237},
	{"BERCY", 5, 143238},
	{"SGILIAU", 7, 143239},
	{"CARLENE", 7, 143240},
	{"TERVUREN", 8, 143241},
	{"SPOOLING", 8, 143242},
	{"WINAVI", 6, 143243},
	{"BENEDIKT", 8, 143244},
	{"DISTRACTS", 9, 143245},
	{"SCALDING", 8, 143246},
	{"BIBLIOTHEK", 10, 143247},
	{"CLUED", 5, 143248},
	{"SPRINGBORO", 10, 143249},
	{"BUILDD", 6, 143250},
	{"CAVITE", 6, 143251},
	{"NEWNAME", 7, 143252},
	{"YRAJ", 4, 143253},
	{"YEOU", 4, 143254},
	{"YDAH", 4, 143255},
	{"UKPR", 4, 143256},
	{"TOGD", 4, 143257},
	{"SUCL", 4, 143258},
	{"SBIP", 4, 143259},
	{"OUPY", 4, 143260},
	{"NKVA", 4, 143261},
	{"MTIG", 4, 143262},
	{"MRDU", 4, 143263},
	{"MPYR", 4, 143264},
	{"IFCR", 4, 143265},
	{"GZHU", 4, 143266},
	{"GAPC", 4, 143267},
	{"EXLU", 4, 143268},
	{"EDDC", 4, 143269},
	{"CIDW", 4, 143270},
	{"BGET", 4, 143271},
	{"STOREKEEPER", 11, 143272},
	{"MAHABLOG", 8, 143273},
	{"MUSKETS", 7, 143274},
	{"SEARLES", 7, 143275},
	{"BURDA", 5, 143276},
	{"CPQ", 3, 143277},
	{"CAMCHATS", 8, 143278},
	{"PIDS", 4, 143279},
	{"BRUNELLO", 8, 143280},
	{"UGLIER", 6, 143281},
	{"NORTHSHIELD", 11, 143282},
	{"SUBFORUM", 8, 143283},
	{"CONTENTTYPE", 11, 143284},
	{"SUBREGULATION", 13, 143285},
	{"TAKEI", 5, 143286},
	{"SUBSECTORS", 10, 143287},
	{"WITCHERY", 8, 143288},
	{"WINGLESS", 8, 143289},
	{"PREDILECTION", 12, 143290},
	{"MWP", 3, 143291},
	{"WEBFOCUS", 8, 143292},
	{"GIBBOUS", 7, 143293},
	{"TABAK", 5, 143294},
	{"DATEIEN", 7, 143295},
	{"KOTTONMOUTH", 11, 143296},
	{"HAMELIN", 7, 143297},
	{"FERR", 4, 143298},
	{"WFORMAT", 7, 143299},
	{"EBERRON", 7, 143300},
	{"METROSTARS", 10, 143301},
	{"PARTICULARY", 11, 143302},
	{"ARAKAWA", 7, 143303},
	{"HOVEY", 5, 143304},
	{"MAYERS", 6, 143305},
	{"WAVERED", 7, 143306},
	{"UPLU", 4, 143307},
	{"TMRA", 4, 143308},
	{"TIPF", 4, 143309},
	{"RCDE", 4, 143310},
	{"PTYF", 4, 143311},
	{"MJES", 4, 143312},
	{"LCTH", 4, 143313},
	{"IDGW", 4, 143314},
	{"GYIM", 4, 143315},
	{"GRUI", 4, 143316},
	{"GGCO", 4, 143317},
	{"FDRS", 4, 143318},
	{"DLEK", 4, 143319},
	{"DAUX", 4, 143320},
	{"CUG", 3, 143321},
	{"COAKLEY", 7, 143322},
	{"FLOODLIGHTS", 11, 143323},
	{"EDUCATIVE", 9, 143324},
	{"CLIMES", 6, 143325},
	{"LAPAROTOMY", 10, 143326},
	{"RIESGO", 6, 143327},
	{"PAGANI", 6, 143328},
	{"CANTONAL", 8, 143329},
	{"BICHE", 5, 143330},
	{"PRINTSTACKTRACE", 15, 143331},
	{"LADDA", 5, 143332},
	{"TALAGA", 6, 143333},
	{"ALBI", 4, 143334},
	{"CARTHY", 6, 143335},
	{"PURUS", 5, 143336},
	{"XCAMS", 5, 143337},
	{"SUBMACHINE", 10, 143338},
	{"COMBUSTOR", 9, 143339},
	{"ADDLED", 6, 143340},
	{"KGAA", 4, 143341},
	{"FIRELIGHT", 9, 143342},
	{"DREAMLIKE", 9, 143343},
	{"CONTRIVANCE", 11, 143344},
	{"PISTOLA", 7, 143345},
	{"ANOINT", 6, 143346},
	{"ANESTHETIST", 11, 143347},
	{"ABCNEWS", 7, 143348},
	{"RABINDRANATH", 12, 143349},
	{"BIGFIX", 6, 143350},
	{"HAYSEED", 7, 143351},
	{"BUSHIES", 7, 143352},
	{"UNOBSERVABLE", 12, 143353},
	{"TORRICELLI", 10, 143354},
	{"LOCALIZER", 9, 143355},
	{"ENDOTRACHEAL", 12, 143356},
	{"PRIVATFOTOS", 11, 143357},
	{"UNCLASSIFIABLE", 14, 143358},
	{"SCATTERS", 8, 143359},
	{"FENIMORE", 8, 143360},
	{"ZHER", 4, 143361},
	{"YROV", 4, 143362},
	{"UOBE", 4, 143363},
	{"TKAB", 4, 143364},
	{"SKMM", 4, 143365},
	{"RAEG", 4, 143366},
	{"OWZE", 4, 143367},
	{"OFGN", 4, 143368},
	{"FIXH", 4, 143369},
	{"FBIP", 4, 143370},
	{"TECNIK", 6, 143371},
	{"ANYCAST", 7, 143372},
	{"BERJAYA", 7, 143373},
	{"SWEDENBORG", 10, 143374},
	{"ESCAPISM", 8, 143375},
	{"GLANVILLE", 9, 143376},
	{"WEBBROWSER", 10, 143377},
	{"ICONO", 5, 143378},
	{"OVERHAULS", 9, 143379},
	{"CREARE", 6, 143380},
	{"WALLOWING", 9, 143381},
	{"PASLODE", 7, 143382},
	{"IONISATION", 10, 143383},
	{"MEXX", 4, 143384},
	{"SALISH", 6, 143385},
	{"CONFI", 5, 143386},
	{"AAPG", 4, 143387},
	{"AKKU", 4, 143388},
	{"SHULL", 5, 143389},
	{"SANDBAGS", 8, 143390},
	{"FORECOURT", 9, 143391},
	{"HINDRANCES", 10, 143392},
	{"BRAVER", 6, 143393},
	{"ERYTHROID", 9, 143394},
	{"GROHOL", 6, 143395},
	{"VIRDEN", 6, 143396},
	{"MALLY", 5, 143397},
	{"REPARTEE", 8, 143398},
	{"PHARMACIE", 9, 143399},
	{"SKUS", 4, 143400},
	{"LYTTELTON", 9, 143401},
	{"BARSKA", 6, 143402},
	{"COMIDA", 6, 143403},
	{"CIATED", 6, 143404},
	{"CHOUDHURY", 9, 143405},
	{"ACTRICE", 7, 143406},
	{"COLORE", 6, 143407},
	{"BYALA", 5, 143408},
	{"ULLJ", 4, 143409},
	{"OEBR", 4, 143410},
	{"NMVP", 4, 143411},
	{"MULB", 4, 143412},
	{"IRUR", 4, 143413},
	{"HYOG", 4, 143414},
	{"GAYH", 4, 143415},
	{"FASR", 4, 143416},
	{"CWED", 4, 143417},
	{"CBIN", 4, 143418},
	{"BSEL", 4, 143419},
	{"APHU", 4, 143420},
	{"NOCK", 4, 143421},
	{"HACKBERRY", 9, 143422},
	{"PIACENZA", 8, 143423},
	{"DISCRETIZED", 11, 143424},
	{"VIGNA", 5, 143425},
	{"BOGGY", 5, 143426},
	{"VRAGEN", 6, 143427},
	{"AZRAEL", 6, 143428},
	{"CROSSWAY", 8, 143429},
	{"NEUSTAR", 7, 143430},
	{"GAYCAMS", 7, 143431},
	{"COLEGIALAS", 10, 143432},
	{"GERTIE", 6, 143433},
	{"ELUTING", 7, 143434},
	{"REVEALER", 8, 143435},
	{"BALLONS", 7, 143436},
	{"WIESNER", 7, 143437},
	{"LOGANVILLE", 10, 143438},
	{"TERMES", 6, 143439},
	{"CHIMING", 7, 143440},
	{"DISSONANT", 9, 143441},
	{"GAYATRI", 7, 143442},
	{"VIPASSANA", 9, 143443},
	{"INFOPAK", 7, 143444},
	{"KAART", 5, 143445},
	{"SACLAY", 6, 143446},
	{"BEEB", 4, 143447},
	{"SAYYID", 6, 143448},
	{"ELINA", 5, 143449},
	{"NORTHERNERS", 11, 143450},
	{"BETIS", 5, 143451},
	{"JARAMILLO", 9, 143452},
	{"FORMENTERA", 10, 143453},
	{"CAMFUN", 6, 143454},
	{"ESSIAC", 6, 143455},
	{"PHARMACOGENOMICS", 16, 143456},
	{"MODULATIONS", 11, 143457},
	{"ZABI", 4, 143458},
	{"YCEB", 4, 143459},
	{"XSLA", 4, 143460},
	{"XLIF", 4, 143461},
	{"WELW", 4, 143462},
	{"SKIV", 4, 143463},
	{"PWED", 4, 143464},
	{"PCFO", 4, 143465},
	{"MLOT", 4, 143466},
	{"MCWI", 4, 143467},
	{"IZEK", 4, 143468},
	{"ICTK", 4, 143469},
	{"GTZE", 4, 143470},
	{"FHUL", 4, 143471},
	{"ERRP", 4, 143472},
	{"DMYK", 4, 143473},
	{"DMRR", 4, 143474},
	{"DJIB", 4, 143475},
	{"DIVY", 4, 143476},
	{"DDCH", 4, 143477},
	{"ABPO", 4, 143478},
	{"SYNTHESISED", 11, 143479},
	{"PHILANTHROPISTS", 15, 143480},
	{"URTEIL", 6, 143481},
	{"BAYNES", 6, 143482},
	{"PYKDE", 5, 143483},
	{"MICELLES", 8, 143484},
	{"CUERO", 5, 143485},
	{"DURET", 5, 143486},
	{"EATONTOWN", 9, 143487},
	{"HORWOOD", 7, 143488},
	{"SOLOMAN", 7, 143489},
	{"BEDHEAD", 7, 143490},
	{"STARTREK", 8, 143491},
	{"HEXUS", 5, 143492},
	{"UPREGULATION", 12, 143493},
	{"FITZGERALDS", 11, 143494},
	{"RETALIATED", 10, 143495},
	{"FOUNDS", 6, 143496},
	{"ACDBBLOCKBEGIN", 14, 143497},
	{"SCHISTOSOMA", 11, 143498},
	{"POPLARS", 7, 143499},
	{"IBLE", 4, 143500},
	{"CDRWS", 5, 143501},
	{"DEFLECTIONS", 11, 143502},
	{"CARRIGAN", 8, 143503},
	{"TUNAS", 5, 143504},
	{"COMISSION", 9, 143505},
	{"XZW", 3, 143506},
	{"WPQ", 3, 143507},
	{"WJY", 3, 143508},
	{"JGY", 3, 143509},
	{"GLQ", 3, 143510},
	{"DIARIAS", 7, 143511},
	{"CARRO", 5, 143512},
	{"USDOE", 5, 143513},
	{"BLECH", 5, 143514},
	{"KNIGHTLY", 8, 143515},
	{"AROSA", 5, 143516},
	{"TUFFY", 5, 143517},
	{"WGTD", 4, 143518},
	{"DEBATER", 7, 143519},
	{"AOMORI", 6, 143520},
	{"POLIT", 5, 143521},
	{"HELLACOPTERS", 12, 143522},
	{"EMCO", 4, 143523},
	{"CONGDON", 7, 143524},
	{"VSPA", 4, 143525},
	{"UGOL", 4, 143526},
	{"RNTD", 4, 143527},
	{"RKOH", 4, 143528},
	{"OYGO", 4, 143529},
	{"NMCH", 4, 143530},
	{"NDKG", 4, 143531},
	{"MUDW", 4, 143532},
	{"LNCE", 4, 143533},
	{"LIFB", 4, 143534},
	{"JAMP", 4, 143535},
	{"IJAB", 4, 143536},
	{"HSDR", 4, 143537},
	{"GZER", 4, 143538},
	{"DTVC", 4, 143539},
	{"COMPUTERWOCHE", 13, 143540},
	{"STATISTICA", 10, 143541},
	{"GOODHUE", 7, 143542},
	{"SLORC", 5, 143543},
	{"TARDE", 5, 143544},
	{"MILLINERY", 9, 143545},
	{"SKYVIEW", 7, 143546},
	{"CHAMBORD", 8, 143547},
	{"LITTELL", 7, 143548},
	{"NOWITZKI", 8, 143549},
	{"LETTERBOXED", 11, 143550},
	{"APPIAN", 6, 143551},
	{"BALLYS", 6, 143552},
	{"IRRESISTIBLY", 12, 143553},
	{"ENDEAVORING", 11, 143554},
	{"SUBSUBSECTION", 13, 143555},
	{"COLLI", 5, 143556},
	{"BEGLEITAGENTUR", 14, 143557},
	{"RAYNOX", 6, 143558},
	{"PARTBONDED", 10, 143559},
	{"DEJAVU", 6, 143560},
	{"ETHICIST", 8, 143561},
	{"GRATISCAMS", 10, 143562},
	{"COMICALLY", 9, 143563},
	{"SUBSTRATUM", 10, 143564},
	{"GILBOA", 6, 143565},
	{"UCHE", 4, 143566},
	{"HOYHOY", 6, 143567},
	{"PORPOISES", 9, 143568},
	{"GOOCHLAND", 9, 143569},
	{"PERLIS", 6, 143570},
	{"CCHA", 4, 143571},
	{"LIFEJACKETS", 11, 143572},
	{"RESPONCE", 8, 143573},
	{"VINER", 5, 143574},
	{"YMRB", 4, 143575},
	{"ULUC", 4, 143576},
	{"SKOD", 4, 143577},
	{"LMYP", 4, 143578},
	{"LKFE", 4, 143579},
	{"KYOJ", 4, 143580},
	{"IKUT", 4, 143581},
	{"GHUB", 4, 143582},
	{"EWTV", 4, 143583},
	{"DMOW", 4, 143584},
	{"DEBOER", 6, 143585},
	{"GUILLAIN", 8, 143586},
	{"LICHTENBERG", 11, 143587},
	{"BLOCKY", 6, 143588},
	{"ORANGUTANS", 10, 143589},
	{"MARTEX", 6, 143590},
	{"MARRIOTTS", 9, 143591},
	{"MACDUFF", 7, 143592},
	{"LIFESIZE", 8, 143593},
	{"SEKIMORI", 8, 143594},
	{"RUNBOARD", 8, 143595},
	{"MOUSSES", 7, 143596},
	{"DAGER", 5, 143597},
	{"PERSUADES", 9, 143598},
	{"RETROSHEET", 10, 143599},
	{"SACDS", 5, 143600},
	{"FINICKY", 7, 143601},
	{"DITIONAL", 8, 143602},
	{"LIPPS", 5, 143603},
	{"SANDGATE", 8, 143604},
	{"DARPARU", 7, 143605},
	{"OUSTING", 7, 143606},
	{"REPENS", 6, 143607},
	{"GATECRASHER", 11, 143608},
	{"LIFER", 5, 143609},
	{"RAPIDO", 6, 143610},
	{"BOUZOUKI", 8, 143611},
	{"CROSSHAIR", 9, 143612},
	{"DOOHAN", 6, 143613},
	{"CRESTRON", 8, 143614},
	{"SHOCKEY", 7, 143615},
	{"LOGNORMAL", 9, 143616},
	{"RAPPORTS", 8, 143617},
	{"FORESHADOWED", 12, 143618},
	{"NIBBLERS", 8, 143619},
	{"YLLM", 4, 143620},
	{"XUSA", 4, 143621},
	{"UMIW", 4, 143622},
	{"UFAR", 4, 143623},
	{"THMF", 4, 143624},
	{"SBAM", 4, 143625},
	{"LNDE", 4, 143626},
	{"HEXX", 4, 143627},
	{"GRHY", 4, 143628},
	{"GNUO", 4, 143629},
	{"EVPA", 4, 143630},
	{"EFDR", 4, 143631},
	{"EDDH", 4, 143632},
	{"DOIW", 4, 143633},
	{"CYNA", 4, 143634},
	{"MEEKNESS", 8, 143635},
	{"INTRANSITIVE", 12, 143636},
	{"ERECTUS", 7, 143637},
	{"HOUSECLEANING", 13, 143638},
	{"GUP", 3, 143639},
	{"SABAN", 5, 143640},
	{"BODYWORKERS", 11, 143641},
	{"AUDIBLY", 7, 143642},
	{"TIMKEN", 6, 143643},
	{"SKILLMAN", 8, 143644},
	{"INVINCIBILITY", 13, 143645},
	{"WOOKIE", 6, 143646},
	{"GOGLEE", 6, 143647},
	{"VIVOS", 5, 143648},
	{"MIRCETTE", 8, 143649},
	{"MCAVOY", 6, 143650},
	{"PINOCHLE", 8, 143651},
	{"NEEDEDFORBUILD", 14, 143652},
	{"DEWY", 4, 143653},
	{"RAPPROCHEMENT", 13, 143654},
	{"MENINO", 6, 143655},
	{"POLONAISE", 9, 143656},
	{"SALVAGING", 9, 143657},
	{"KOSRAE", 6, 143658},
	{"ACDBBLOCKEND", 12, 143659},
	{"RENNAISSANCE", 12, 143660},
	{"PERLMUTTER", 10, 143661},
	{"CNMI", 4, 143662},
	{"RRRR", 4, 143663},
	{"LSID", 4, 143664},
	{"ZAME", 4, 143665},
	{"YSSY", 4, 143666},
	{"XAGA", 4, 143667},
	{"UPHR", 4, 143668},
	{"TMRP", 4, 143669},
	{"PMHE", 4, 143670},
	{"OTGL", 4, 143671},
	{"KLAI", 4, 143672},
	{"KKOR", 4, 143673},
	{"GILW", 4, 143674},
	{"EMTU", 4, 143675},
	{"DNUD", 4, 143676},
	{"COWF", 4, 143677},
	{"BYUM", 4, 143678},
	{"BPAT", 4, 143679},
	{"ABME", 4, 143680},
	{"EVENTARGS", 9, 143681},
	{"TRADESKILL", 10, 143682},
	{"AVCA", 4, 143683},
	{"OBLIQUELY", 9, 143684},
	{"PRATAP", 6, 143685},
	{"UNEASILY", 8, 143686},
	{"TRUEX", 5, 143687},
	{"METED", 5, 143688},
	{"HUMM", 4, 143689},
	{"GATESVILLE", 10, 143690},
	{"SHULA", 5, 143691},
	{"LAMELLAR", 8, 143692},
	{"KALAMA", 6, 143693},
	{"LIVETH", 6, 143694},
	{"LLLL", 4, 143695},
	{"DISCHARGERS", 11, 143696},
	{"MAMORU", 6, 143697},
	{"FLTK", 4, 143698},
	{"TORRENTE", 8, 143699},
	{"OUTRE", 5, 143700},
	{"OUNTY", 5, 143701},
	{"AMAZONE", 7, 143702},
	{"GIRLSHOUSE", 10, 143703},
	{"FALKE", 5, 143704},
	{"PHOENICIA", 9, 143705},
	{"BIFURCATIONS", 12, 143706},
	{"CCAA", 4, 143707},
	{"HBCU", 4, 143708},
	{"MAKAWAO", 7, 143709},
	{"WRESTLES", 8, 143710},
	{"ADNODDAU", 8, 143711},
	{"VILSACK", 7, 143712},
	{"RADNORSHIRE", 11, 143713},
	{"BIOTINYLATED", 12, 143714},
	{"VARUN", 5, 143715},
	{"PEIF", 4, 143716},
	{"OVSC", 4, 143717},
	{"NGUC", 4, 143718},
	{"MROG", 4, 143719},
	{"LOPU", 4, 143720},
	{"LNPA", 4, 143721},
	{"KSPH", 4, 143722},
	{"KIAB", 4, 143723},
	{"KCRU", 4, 143724},
	{"GIFW", 4, 143725},
	{"BAGN", 4, 143726},
	{"CIATION", 7, 143727},
	{"DISSIPATES", 10, 143728},
	{"MUCIN", 5, 143729},
	{"TZADIK", 6, 143730},
	{"FATF", 4, 143731},
	{"HISPEED", 7, 143732},
	{"MONEDAS", 7, 143733},
	{"LEBEL", 5, 143734},
	{"BIOLINE", 7, 143735},
	{"STOPPAGES", 9, 143736},
	{"SOFFIT", 6, 143737},
	{"PEEPCAM", 7, 143738},
	{"CLIMAXES", 8, 143739},
	{"MASAO", 5, 143740},
	{"BOVEN", 5, 143741},
	{"SALTIRE", 7, 143742},
	{"BOSANSKI", 8, 143743},
	{"SABIO", 5, 143744},
	{"FORESPAR", 8, 143745},
	{"YOUNGSVILLE", 11, 143746},
	{"MEGARAID", 8, 143747},
	{"JAUNTY", 6, 143748},
	{"MOLESWORTH", 10, 143749},
	{"STARCHY", 7, 143750},
	{"BALTHAZAR", 9, 143751},
	{"SQUEAMISH", 9, 143752},
	{"ARBORICULTURE", 13, 143753},
	{"GHCI", 4, 143754},
	{"TOBOGGAN", 8, 143755},
	{"ZOOLOGIST", 9, 143756},
	{"TALIESIN", 8, 143757},
	{"FORST", 5, 143758},
	{"AVEDON", 6, 143759},
	{"PARVOVIRUS", 10, 143760},
	{"FINALISATION", 12, 143761},
	{"DOLLOP", 6, 143762},
	{"VENKAT", 6, 143763},
	{"OSWALT", 6, 143764},
	{"FEEDFORWARD", 11, 143765},
	{"FROTA", 5, 143766},
	{"YOJA", 4, 143767},
	{"XWON", 4, 143768},
	{"WKSL", 4, 143769},
	{"TGEL", 4, 143770},
	{"RVAG", 4, 143771},
	{"RGHR", 4, 143772},
	{"OELW", 4, 143773},
	{"NZEC", 4, 143774},
	{"MOEB", 4, 143775},
	{"LHIC", 4, 143776},
	{"KROT", 4, 143777},
	{"KIAF", 4, 143778},
	{"IRYM", 4, 143779},
	{"FREJ", 4, 143780},
	{"EDSJ", 4, 143781},
	{"CVIR", 4, 143782},
	{"AGPR", 4, 143783},
	{"PAIHIA", 6, 143784},
	{"SCREWY", 6, 143785},
	{"PARMI", 5, 143786},
	{"BRONCHI", 7, 143787},
	{"ECCENTRICITIES", 14, 143788},
	{"ITRON", 5, 143789},
	{"LIBPQ", 5, 143790},
	{"DRAINAGES", 9, 143791},
	{"BERTUZZI", 8, 143792},
	{"KARLSTAD", 8, 143793},
	{"KAHALA", 6, 143794},
	{"HCMC", 4, 143795},
	{"DEFLECTING", 10, 143796},
	{"DMITRIY", 7, 143797},
	{"PACKWOOD", 8, 143798},
	{"NENAGH", 6, 143799},
	{"BALDRY", 6, 143800},
	{"BLEEDER", 7, 143801},
	{"RMG", 3, 143802},
	{"HKFLIX", 6, 143803},
	{"BRYLANEHOME", 11, 143804},
	{"MIDDLEBROOK", 11, 143805},
	{"CASPASES", 8, 143806},
	{"PLAYGEAR", 8, 143807},
	{"DVICO", 5, 143808},
	{"SYLW", 4, 143809},
	{"TELEFONI", 8, 143810},
	{"COCKLE", 6, 143811},
	{"PASAR", 5, 143812},
	{"NYSTATIN", 8, 143813},
	{"BAGGIES", 7, 143814},
	{"ARGU", 4, 143815},
	{"GEHEUGEN", 8, 143816},
	{"POTENTIALITIES", 14, 143817},
	{"VIDZ", 4, 143818},
	{"DUNSMUIR", 8, 143819},
	{"NICHIREN", 8, 143820},
	{"FILEXT", 6, 143821},
	{"ANTHEA", 6, 143822},
	{"YUIS", 4, 143823},
	{"XTYY", 4, 143824},
	{"XBAT", 4, 143825},
	{"SCPR", 4, 143826},
	{"RUSV", 4, 143827},
	{"PEID", 4, 143828},
	{"OLCK", 4, 143829},
	{"NMOY", 4, 143830},
	{"LIJU", 4, 143831},
	{"KCAB", 4, 143832},
	{"HYUS", 4, 143833},
	{"HYCE", 4, 143834},
	{"GYNA", 4, 143835},
	{"FWEK", 4, 143836},
	{"EPJA", 4, 143837},
	{"EMEJ", 4, 143838},
	{"CKRS", 4, 143839},
	{"BWEH", 4, 143840},
	{"BNPA", 4, 143841},
	{"BEXA", 4, 143842},
	{"ASVU", 4, 143843},
	{"ANLL", 4, 143844},
	{"WAISTED", 7, 143845},
	{"CIRCO", 5, 143846},
	{"AEROTECH", 8, 143847},
	{"LETZTEN", 7, 143848},
	{"EXACERBATIONS", 13, 143849},
	{"BRONFMAN", 8, 143850},
	{"LITIGATOR", 9, 143851},
	{"STEPCHILD", 9, 143852},
	{"AIRSHIPS", 8, 143853},
	{"SHOELACES", 9, 143854},
	{"PRESUPPOSE", 10, 143855},
	{"KARLSEN", 7, 143856},
	{"STORYPRINT", 10, 143857},
	{"CUSSING", 7, 143858},
	{"HETTY", 5, 143859},
	{"EASYCALL", 8, 143860},
	{"PYCNOGENOL", 10, 143861},
	{"MYSQLI", 6, 143862},
	{"AFFECTATION", 11, 143863},
	{"NALLE", 5, 143864},
	{"FREIBERG", 8, 143865},
	{"VGCHEATE", 8, 143866},
	{"SOLARUM", 7, 143867},
	{"DPB", 3, 143868},
	{"GROHL", 5, 143869},
	{"REENTRANT", 9, 143870},
	{"FLICKERS", 8, 143871},
	{"BTEX", 4, 143872},
	{"CHANUTE", 7, 143873},
	{"STINNETT", 8, 143874},
	{"DUITSLAND", 9, 143875},
	{"BIGUNS", 6, 143876},
	{"BEKA", 4, 143877},
	{"SKAMANIA", 8, 143878},
	{"NONCASH", 7, 143879},
	{"OXYGENASE", 9, 143880},
	{"MERRI", 5, 143881},
	{"ANTICONVULSANT", 14, 143882},
	{"RADDISON", 8, 143883},
	{"PEEPBOX", 7, 143884},
	{"HSIANG", 6, 143885},
	{"KACHINA", 7, 143886},
	{"CRAYFORD", 8, 143887},
	{"CAMPBELLTON", 11, 143888},
	{"ABDICATE", 8, 143889},
	{"CREAK", 5, 143890},
	{"APEAR", 5, 143891},
	{"YEEM", 4, 143892},
	{"VEEG", 4, 143893},
	{"RILV", 4, 143894},
	{"OXMI", 4, 143895},
	{"NUKI", 4, 143896},
	{"MNCA", 4, 143897},
	{"MCOI", 4, 143898},
	{"LMOH", 4, 143899},
	{"LFVI", 4, 143900},
	{"GLAX", 4, 143901},
	{"GKEV", 4, 143902},
	{"EELJ", 4, 143903},
	{"BICP", 4, 143904},
	{"OFFICINA", 8, 143905},
	{"BENNI", 5, 143906},
	{"REFRAMING", 9, 143907},
	{"ZACHERY", 7, 143908},
	{"SWITCHBACK", 10, 143909},
	{"LOANER", 6, 143910},
	{"MAYRHOFEN", 9, 143911},
	{"ARCHDEACON", 10, 143912},
	{"POPA", 4, 143913},
	{"REIDEL", 6, 143914},
	{"HAZRAT", 6, 143915},
	{"BEGLEITAGENTUREN", 16, 143916},
	{"MONOFONE", 8, 143917},
	{"ORIGINALE", 9, 143918},
	{"POOLER", 6, 143919},
	{"MINYAN", 6, 143920},
	{"BANVILLE", 8, 143921},
	{"ROBER", 5, 143922},
	{"GILBERTSON", 10, 143923},
	{"TUSCON", 6, 143924},
	{"FERMIONIC", 9, 143925},
	{"VALK", 4, 143926},
	{"NOFLYSONUS", 10, 143927},
	{"MISSIONAL", 9, 143928},
	{"SUPERCHARGERS", 13, 143929},
	{"WIGGLING", 8, 143930},
	{"OGALLALA", 8, 143931},
	{"ODDI", 4, 143932},
	{"LINDBLAD", 8, 143933},
	{"TOREADOR", 8, 143934},
	{"SPREADSHEETPLUGIN", 17, 143935},
	{"ERATH", 5, 143936},
	{"SHIRI", 5, 143937},
	{"GIRLSCAM", 8, 143938},
	{"TAKEO", 5, 143939},
	{"CHICHEN", 7, 143940},
	{"HACIENDO", 8, 143941},
	{"GRRRL", 5, 143942},
	{"ORNITHOLOGISTS", 14, 143943},
	{"THEORA", 6, 143944},
	{"WEBCOPYRIGHT", 12, 143945},
	{"POPPE", 5, 143946},
	{"HAYLING", 7, 143947},
	{"SPLAY", 5, 143948},
	{"TEACHABLE", 9, 143949},
	{"YAWR", 4, 143950},
	{"UCEJ", 4, 143951},
	{"TLOF", 4, 143952},
	{"STKU", 4, 143953},
	{"PMCH", 4, 143954},
	{"OKUB", 4, 143955},
	{"ODOK", 4, 143956},
	{"MAPM", 4, 143957},
	{"MABB", 4, 143958},
	{"LPIF", 4, 143959},
	{"KTAB", 4, 143960},
	{"KHOD", 4, 143961},
	{"KEYQ", 4, 143962},
	{"IRDK", 4, 143963},
	{"IPHU", 4, 143964},
	{"HYPU", 4, 143965},
	{"FSTB", 4, 143966},
	{"ENYR", 4, 143967},
	{"BPOL", 4, 143968},
	{"AFCH", 4, 143969},
	{"SPURRIER", 8, 143970},
	{"ALFABET", 7, 143971},
	{"ELASTICIZED", 11, 143972},
	{"GOUCHER", 7, 143973},
	{"PRETENSION", 10, 143974},
	{"REALPOLITIK", 11, 143975},
	{"FOXNEWS", 7, 143976},
	{"MASSACHUSSETTS", 14, 143977},
	{"ANUNCIOS", 8, 143978},
	{"SABOTAGING", 10, 143979},
	{"DESCENTS", 8, 143980},
	{"VICISSITUDES", 12, 143981},
	{"JIVA", 4, 143982},
	{"MSDP", 4, 143983},
	{"DUPES", 5, 143984},
	{"VAUD", 4, 143985},
	{"MONTT", 5, 143986},
	{"LARKS", 5, 143987},
	{"TREADWAY", 8, 143988},
	{"WABCAMS", 7, 143989},
	{"VOLES", 5, 143990},
	{"PROHEALTH", 9, 143991},
	{"ENCRE", 5, 143992},
	{"YOSHIKAWA", 9, 143993},
	{"TORMENTOR", 9, 143994},
	{"NEWID", 5, 143995},
	{"LONGUEUIL", 9, 143996},
	{"ITZHAK", 6, 143997},
	{"STUMPF", 6, 143998},
	{"ACCOUSTIC", 9, 143999},
	{"ZORK", 4, 144000},
	{"KRC", 3, 144001},
	{"EUPHRAT", 7, 144002},
	{"BALLSBRIDGE", 11, 144003},
	{"MALUS", 5, 144004},
	{"REDDIT", 6, 144005},
	{"TAGEN", 5, 144006},
	{"CASTLEWOOD", 10, 144007},
	{"MICROGRAPHS", 11, 144008},
	{"KERNAL", 6, 144009},
	{"WEIDENFELD", 10, 144010},
	{"SUNNYCAM", 8, 144011},
	{"LABUAN", 6, 144012},
	{"PRODUKTION", 10, 144013},
	{"GWIAZDY", 7, 144014},
	{"POSTILION", 9, 144015},
	{"EXPUNGE", 7, 144016},
	{"THROMBOXANE", 11, 144017},
	{"BHIKKHU", 7, 144018},
	{"EXTERNS", 7, 144019},
	{"YSYR", 4, 144020},
	{"WDHA", 4, 144021},
	{"OXDO", 4, 144022},
	{"MEIB", 4, 144023},
	{"MALJ", 4, 144024},
	{"LPHL", 4, 144025},
	{"GGUS", 4, 144026},
	{"EGIZ", 4, 144027},
	{"EBDP", 4, 144028},
	{"DCAE", 4, 144029},
	{"CLAF", 4, 144030},
	{"BYCB", 4, 144031},
	{"AUZE", 4, 144032},
	{"PASSERSBY", 9, 144033},
	{"DISSIMILARITY", 13, 144034},
	{"ISOSORBIDE", 10, 144035},
	{"HYRULE", 6, 144036},
	{"NEUTRALIZER", 11, 144037},
	{"ORGI", 4, 144038},
	{"CINTA", 5, 144039},
	{"MOONO", 5, 144040},
	{"GFTP", 4, 144041},
	{"CITYMAP", 7, 144042},
	{"WEAL", 4, 144043},
	{"TRUSTNET", 8, 144044},
	{"UNIDAS", 6, 144045},
	{"PARTIDOS", 8, 144046},
	{"ELKRIDGE", 8, 144047},
	{"POSTTEST", 8, 144048},
	{"PHOTOSALES", 10, 144049},
	{"DECOHERENCE", 11, 144050},
	{"WAIHEKE", 7, 144051},
	{"UNSEAT", 6, 144052},
	{"BURKHOLDER", 10, 144053},
	{"PALPATION", 9, 144054},
	{"CAMROOM", 7, 144055},
	{"HARMONIX", 8, 144056},
	{"PLOVERS", 7, 144057},
	{"SUPERBIKES", 10, 144058},
	{"CADENA", 6, 144059},
	{"WDDX", 4, 144060},
	{"KASCHA", 6, 144061},
	{"FOWEY", 5, 144062},
	{"LYSOSOMES", 9, 144063},
	{"EVOLUTIONIST", 12, 144064},
	{"HOFFA", 5, 144065},
	{"GRUDGES", 7, 144066},
	{"WANKERS", 7, 144067},
	{"MYOCARDITIS", 11, 144068},
	{"PERVERSITY", 10, 144069},
	{"NEMAHA", 6, 144070},
	{"EBRO", 4, 144071},
	{"CONVULSIVE", 10, 144072},
	{"TATOUAGES", 9, 144073},
	{"ZAHU", 4, 144074},
	{"ZABR", 4, 144075},
	{"YNBE", 4, 144076},
	{"YFAK", 4, 144077},
	{"XESU", 4, 144078},
	{"XDUR", 4, 144079},
	{"WOOB", 4, 144080},
	{"UYNA", 4, 144081},
	{"RDEZ", 4, 144082},
	{"POTG", 4, 144083},
	{"PGEA", 4, 144084},
	{"OVRI", 4, 144085},
	{"MZER", 4, 144086},
	{"LAHF", 4, 144087},
	{"IAUL", 4, 144088},
	{"HUEL", 4, 144089},
	{"FYST", 4, 144090},
	{"FTCI", 4, 144091},
	{"FLAO", 4, 144092},
	{"EZMO", 4, 144093},
	{"DWIZ", 4, 144094},
	{"APRI", 4, 144095},
	{"KIRKCUDBRIGHTSHIRE", 18, 144096},
	{"INFLAME", 7, 144097},
	{"RATHBUN", 7, 144098},
	{"ACESSORIES", 10, 144099},
	{"LIBGUILE", 8, 144100},
	{"HAPHAZARDLY", 11, 144101},
	{"ORVIETO", 7, 144102},
	{"INCITS", 6, 144103},
	{"LUNDQVIST", 9, 144104},
	{"ENDERBY", 7, 144105},
	{"WATERLOOVILLE", 13, 144106},
	{"BESCHIKBAAR", 11, 144107},
	{"VALEURS", 7, 144108},
	{"DALKEITH", 8, 144109},
	{"NUMERATORS", 10, 144110},
	{"REGISTRAZIONE", 13, 144111},
	{"CONSIGLI", 8, 144112},
	{"HBSWK", 5, 144113},
	{"BLIZZARDS", 9, 144114},
	{"VERZEKERING", 11, 144115},
	{"TIGHTSPLEASE", 12, 144116},
	{"FREIGHTERS", 10, 144117},
	{"SCHWEPPES", 9, 144118},
	{"DGM", 3, 144119},
	{"POLYSERVE", 9, 144120},
	{"BUNKHOUSE", 9, 144121},
	{"ANIMANIACS", 10, 144122},
	{"GUTTMAN", 7, 144123},
	{"ECLAT", 5, 144124},
	{"PERRYMAN", 8, 144125},
	{"COPERNIC", 8, 144126},
	{"DORIC", 5, 144127},
	{"ROMULAN", 7, 144128},
	{"BELHAVEN", 8, 144129},
	{"PATHETICALLY", 12, 144130},
	{"SHEETROCK", 9, 144131},
	{"CARMIKE", 7, 144132},
	{"BLUSTER", 7, 144133},
	{"ENDOSPERM", 9, 144134},
	{"NEWBIN", 6, 144135},
	{"ZUSA", 4, 144136},
	{"ZAFR", 4, 144137},
	{"XMAG", 4, 144138},
	{"WVOI", 4, 144139},
	{"UYOF", 4, 144140},
	{"ULTK", 4, 144141},
	{"TOFX", 4, 144142},
	{"ODSV", 4, 144143},
	{"MPAH", 4, 144144},
	{"MBYL", 4, 144145},
	{"KLAV", 4, 144146},
	{"ILTG", 4, 144147},
	{"EZAB", 4, 144148},
	{"EUNJ", 4, 144149},
	{"DBIP", 4, 144150},
	{"DAMV", 4, 144151},
	{"COAB", 4, 144152},
	{"BBOS", 4, 144153},
	{"AFTV", 4, 144154},
	{"BONET", 5, 144155},
	{"VFAT", 4, 144156},
	{"TANGER", 6, 144157},
	{"SOTHINK", 7, 144158},
	{"CRAPO", 5, 144159},
	{"SNOBBERY", 8, 144160},
	{"NYPL", 4, 144161},
	{"RAINCOVER", 9, 144162},
	{"FREESPACE", 9, 144163},
	{"BOARDROOMS", 10, 144164},
	{"LEVERT", 6, 144165},
	{"WHATSUP", 7, 144166},
	{"MOVS", 4, 144167},
	{"BLASTOCYST", 10, 144168},
	{"REMEDYING", 9, 144169},
	{"ONDINE", 6, 144170},
	{"LEUKEMIC", 8, 144171},
	{"ERECTORS", 8, 144172},
	{"PERILLO", 7, 144173},
	{"WITCHING", 8, 144174},
	{"VEIW", 4, 144175},
	{"RIBAS", 5, 144176},
	{"ALDON", 5, 144177},
	{"DEPRECIATE", 10, 144178},
	{"TRANSHUMANISM", 13, 144179},
	{"ROHRER", 6, 144180},
	{"BELLUM", 6, 144181},
	{"EPISCOPALIANS", 13, 144182},
	{"PTYPE", 5, 144183},
	{"SOLARIUMKAMERA", 14, 144184},
	{"TOEWS", 5, 144185},
	{"ALGUIEN", 7, 144186},
	{"HUONG", 5, 144187},
	{"UTIMACO", 7, 144188},
	{"MANGINI", 7, 144189},
	{"GENDARME", 8, 144190},
	{"HWNDLG", 6, 144191},
	{"DIONYSIUS", 9, 144192},
	{"YUSD", 4, 144193},
	{"XINP", 4, 144194},
	{"XBEA", 4, 144195},
	{"UEMV", 4, 144196},
	{"OWDL", 4, 144197},
	{"LTIW", 4, 144198},
	{"LMSN", 4, 144199},
	{"LDWY", 4, 144200},
	{"GIMN", 4, 144201},
	{"FTJA", 4, 144202},
	{"FHUD", 4, 144203},
	{"CCFO", 4, 144204},
	{"BOWP", 4, 144205},
	{"IFANC", 5, 144206},
	{"ILLUSIONIST", 11, 144207},
	{"RESURRECTING", 12, 144208},
	{"CIAC", 4, 144209},
	{"ARMOND", 6, 144210},
	{"EISTEDDFOD", 10, 144211},
	{"ASTERIXX", 8, 144212},
	{"IMPERCEPTIBLE", 13, 144213},
	{"NODENAME", 8, 144214},
	{"LINKUP", 6, 144215},
	{"FAISON", 6, 144216},
	{"TOMAH", 5, 144217},
	{"LYRICISM", 8, 144218},
	{"BENTYL", 6, 144219},
	{"MATERA", 6, 144220},
	{"PRIL", 4, 144221},
	{"FATTEST", 7, 144222},
	{"DIGNISSIM", 9, 144223},
	{"ASIATICA", 8, 144224},
	{"EYEZ", 4, 144225},
	{"YAMPA", 5, 144226},
	{"DUBEY", 5, 144227},
	{"ARCANGELI", 9, 144228},
	{"TOPOLOGICALLY", 13, 144229},
	{"ATOLLS", 6, 144230},
	{"ABILIFY", 7, 144231},
	{"CGIWRAP", 7, 144232},
	{"COMMEMORATIVES", 14, 144233},
	{"YDL", 3, 144234},
	{"PARLEY", 6, 144235},
	{"STOCKYARDS", 10, 144236},
	{"YPME", 4, 144237},
	{"WWEK", 4, 144238},
	{"UYBR", 4, 144239},
	{"UKAB", 4, 144240},
	{"TLUS", 4, 144241},
	{"SOLW", 4, 144242},
	{"RVOS", 4, 144243},
	{"RPPR", 4, 144244},
	{"RBSF", 4, 144245},
	{"PTPU", 4, 144246},
	{"MRPI", 4, 144247},
	{"MRGE", 4, 144248},
	{"MPBY", 4, 144249},
	{"LIVN", 4, 144250},
	{"KIFR", 4, 144251},
	{"HMCG", 4, 144252},
	{"GTVS", 4, 144253},
	{"EYDG", 4, 144254},
	{"DOXO", 4, 144255},
	{"CPAY", 4, 144256},
	{"LEBIAN", 6, 144257},
	{"BLAG", 4, 144258},
	{"ULAANBAATAR", 11, 144259},
	{"GENNARO", 7, 144260},
	{"ADVERTIZING", 11, 144261},
	{"JESSAMINE", 9, 144262},
	{"PALATIAL", 8, 144263},
	{"MUTTS", 5, 144264},
	{"FLIR", 4, 144265},
	{"CABARETE", 8, 144266},
	{"REDA", 4, 144267},
	{"AKTUELLES", 9, 144268},
	{"FITTS", 5, 144269},
	{"CIPE", 4, 144270},
	{"CHINMOY", 7, 144271},
	{"ESTROGENIC", 10, 144272},
	{"GFCI", 4, 144273},
	{"NONCUSTODIAL", 12, 144274},
	{"CLIFFE", 6, 144275},
	{"PRELATE", 7, 144276},
	{"STALINISM", 9, 144277},
	{"SECHELT", 7, 144278},
	{"FLIPPANT", 8, 144279},
	{"CONTRAVENED", 11, 144280},
	{"SUNBED", 6, 144281},
	{"ZODIACAL", 8, 144282},
	{"NIGHTWING", 9, 144283},
	{"BANKHEAD", 8, 144284},
	{"LIBATIONS", 9, 144285},
	{"UNITEC", 6, 144286},
	{"REVERSIBILITY", 13, 144287},
	{"GHYLL", 5, 144288},
	{"UMAN", 4, 144289},
	{"CARC", 4, 144290},
	{"PARPORT", 7, 144291},
	{"XHAR", 4, 144292},
	{"VARL", 4, 144293},
	{"UPOW", 4, 144294},
	{"OSLY", 4, 144295},
	{"NRAU", 4, 144296},
	{"NGYS", 4, 144297},
	{"MNAG", 4, 144298},
	{"MBEW", 4, 144299},
	{"LOTJ", 4, 144300},
	{"KBYG", 4, 144301},
	{"IXIR", 4, 144302},
	{"GANX", 4, 144303},
	{"FFNI", 4, 144304},
	{"CYUS", 4, 144305},
	{"CYMU", 4, 144306},
	{"BAYG", 4, 144307},
	{"CONVIVIAL", 9, 144308},
	{"STOSSEL", 7, 144309},
	{"STORMTROOPERS", 13, 144310},
	{"UNIMPRESSIVE", 12, 144311},
	{"SPIDERED", 8, 144312},
	{"PRIVATMODELLE", 13, 144313},
	{"XDOCS", 5, 144314},
	{"IFROGGY", 7, 144315},
	{"ADORNS", 6, 144316},
	{"CANTUS", 6, 144317},
	{"KAZEHAKASE", 10, 144318},
	{"FRECH", 5, 144319},
	{"BACTRIM", 7, 144320},
	{"RNID", 4, 144321},
	{"MARYBETH", 8, 144322},
	{"KAMER", 5, 144323},
	{"PLASTID", 7, 144324},
	{"LOGKIT", 6, 144325},
	{"CSPS", 4, 144326},
	{"RETNA", 5, 144327},
	{"HAMBLIN", 7, 144328},
	{"ALTIX", 5, 144329},
	{"GRUBBING", 8, 144330},
	{"PREFORM", 7, 144331},
	{"COMMONERS", 9, 144332},
	{"SPOOLED", 7, 144333},
	{"VASCA", 5, 144334},
	{"CRUNCHER", 8, 144335},
	{"CITIFINANCIAL", 13, 144336},
	{"MALATA", 6, 144337},
	{"OWSLEY", 6, 144338},
	{"UNTERKUNFT", 10, 144339},
	{"CULTIVATES", 10, 144340},
	{"THANKFULNESS", 12, 144341},
	{"EASTERBROOK", 11, 144342},
	{"SRIRAM", 6, 144343},
	{"VALUEMAGS", 9, 144344},
	{"VASOCONSTRICTION", 16, 144345},
	{"INFORMALITY", 11, 144346},
	{"ZUDEM", 5, 144347},
	{"MEESE", 5, 144348},
	{"FREECAMCHAT", 11, 144349},
	{"UNTURNED", 8, 144350},
	{"FUZION", 6, 144351},
	{"PHOSPHATIDYLCHOLINE", 19, 144352},
	{"GOLFDICKE", 9, 144353},
	{"XREM", 4, 144354},
	{"WODU", 4, 144355},
	{"RTEU", 4, 144356},
	{"PYPL", 4, 144357},
	{"OMSQ", 4, 144358},
	{"ODYY", 4, 144359},
	{"NUTW", 4, 144360},
	{"MBOP", 4, 144361},
	{"MBOG", 4, 144362},
	{"LFOP", 4, 144363},
	{"HDUM", 4, 144364},
	{"FJAL", 4, 144365},
	{"EEFP", 4, 144366},
	{"NDAD", 4, 144367},
	{"IRKED", 5, 144368},
	{"WORKROOM", 8, 144369},
	{"GROSSMONT", 9, 144370},
	{"ENSOR", 5, 144371},
	{"SATHYA", 6, 144372},
	{"SOLARIU", 7, 144373},
	{"WACHTER", 7, 144374},
	{"UROGENITAL", 10, 144375},
	{"WOTTON", 6, 144376},
	{"BIOCIDE", 7, 144377},
	{"MUDGUARDS", 9, 144378},
	{"RIEHL", 5, 144379},
	{"RULZ", 4, 144380},
	{"ZUKUNFT", 7, 144381},
	{"PHOEBUS", 7, 144382},
	{"MURTAUGH", 8, 144383},
	{"PETZOLD", 7, 144384},
	{"CRAC", 4, 144385},
	{"ZDENKA", 6, 144386},
	{"RADICA", 6, 144387},
	{"LASKER", 6, 144388},
	{"DISKSPACE", 9, 144389},
	{"OUTGOINGS", 9, 144390},
	{"NICHOLASVILLE", 13, 144391},
	{"FERRERS", 7, 144392},
	{"OFFA", 4, 144393},
	{"WORKFORCES", 10, 144394},
	{"CILLIAN", 7, 144395},
	{"UNDERCUTTING", 12, 144396},
	{"WENGEN", 6, 144397},
	{"POPSTAR", 7, 144398},
	{"PRESUPPOSITION", 14, 144399},
	{"CENSURED", 8, 144400},
	{"UMESH", 5, 144401},
	{"GIARDINELLI", 11, 144402},
	{"GENKI", 5, 144403},
	{"ARSCHFICK", 9, 144404},
	{"OFFERTA", 7, 144405},
	{"CDER", 4, 144406},
	{"ACADEMICIAN", 11, 144407},
	{"GFORCE", 6, 144408},
	{"UOYO", 4, 144409},
	{"UOAL", 4, 144410},
	{"UETC", 4, 144411},
	{"PGRU", 4, 144412},
	{"NKCE", 4, 144413},
	{"LPCU", 4, 144414},
	{"KYOD", 4, 144415},
	{"JOWA", 4, 144416},
	{"JOSL", 4, 144417},
	{"HDWI", 4, 144418},
	{"EICY", 4, 144419},
	{"DCYP", 4, 144420},
	{"CTKA", 4, 144421},
	{"BBCH", 4, 144422},
	{"AWKC", 4, 144423},
	{"MONOS", 5, 144424},
	{"ANGIOGRAPHIC", 12, 144425},
	{"SACHE", 5, 144426},
	{"HAYFIELD", 8, 144427},
	{"CONTROLER", 9, 144428},
	{"RELISHED", 8, 144429},
	{"SULFAMETHOXAZOLE", 16, 144430},
	{"DAYNE", 5, 144431},
	{"MEMBERED", 8, 144432},
	{"INACCURATELY", 12, 144433},
	{"JEOPARDISE", 10, 144434},
	{"GBYTES", 6, 144435},
	{"BOERS", 5, 144436},
	{"PLURALIST", 9, 144437},
	{"LUJAN", 5, 144438},
	{"CRIP", 4, 144439},
	{"AVAIABLE", 8, 144440},
	{"SONNENBANK", 10, 144441},
	{"GIRS", 4, 144442},
	{"GRATISCAM", 9, 144443},
	{"FEUDING", 7, 144444},
	{"MOUTHWATERING", 13, 144445},
	{"WOODWAY", 7, 144446},
	{"PEJMANESQUE", 11, 144447},
	{"VIRIDIS", 7, 144448},
	{"SAVIORS", 7, 144449},
	{"WIZZ", 4, 144450},
	{"PAULIN", 6, 144451},
	{"KIMCHI", 6, 144452},
	{"WHEELWRIGHT", 11, 144453},
	{"KASTEN", 6, 144454},
	{"JEJU", 4, 144455},
	{"BLOEM", 5, 144456},
	{"TABATHA", 7, 144457},
	{"CINC", 4, 144458},
	{"ZZTO", 4, 144459},
	{"XBAN", 4, 144460},
	{"UYLA", 4, 144461},
	{"UHAL", 4, 144462},
	{"TKOL", 4, 144463},
	{"TDCA", 4, 144464},
	{"RWAC", 4, 144465},
	{"PYIT", 4, 144466},
	{"OFDV", 4, 144467},
	{"NAML", 4, 144468},
	{"LYAO", 4, 144469},
	{"LGRU", 4, 144470},
	{"LCOB", 4, 144471},
	{"EPEX", 4, 144472},
	{"DBOH", 4, 144473},
	{"CGIR", 4, 144474},
	{"AGSU", 4, 144475},
	{"SKRIV", 5, 144476},
	{"HEINER", 6, 144477},
	{"BOETTCHER", 9, 144478},
	{"DREWS", 5, 144479},
	{"PAGEEMAIL", 9, 144480},
	{"CONVERTABLE", 11, 144481},
	{"ACYLTRANSFERASE", 15, 144482},
	{"NARBERTH", 8, 144483},
	{"ANALVIDEO", 9, 144484},
	{"CHIRO", 5, 144485},
	{"GEHMAN", 6, 144486},
	{"PUCE", 4, 144487},
	{"CHALLANGE", 9, 144488},
	{"XRATED", 6, 144489},
	{"LINWORTH", 8, 144490},
	{"ANODIZING", 9, 144491},
	{"TOILS", 5, 144492},
	{"COMMISSAR", 9, 144493},
	{"VONDA", 5, 144494},
	{"WHITEBOX", 8, 144495},
	{"HANDPIECE", 9, 144496},
	{"CHESNUTT", 8, 144497},
	{"NOTINUSE", 8, 144498},
	{"SALLES", 6, 144499},
	{"MARGINALHACKS", 13, 144500},
	{"PREPKIT", 7, 144501},
	{"JELLYBEAN", 9, 144502},
	{"ADELANTO", 8, 144503},
	{"ENORME", 6, 144504},
	{"MINKE", 5, 144505},
	{"GINZBURG", 8, 144506},
	{"NAMORADO", 8, 144507},
	{"SCHWARTZMAN", 11, 144508},
	{"PIGMENTOSA", 10, 144509},
	{"WIKIPEDIANS", 11, 144510},
	{"SPANDAU", 7, 144511},
	{"TPKE", 4, 144512},
	{"SUPRAMOLECULAR", 14, 144513},
	{"CHICANA", 7, 144514},
	{"INSTIGATION", 11, 144515},
	{"VEUVE", 5, 144516},
	{"MOHSEN", 6, 144517},
	{"MINERALIZED", 11, 144518},
	{"TICES", 5, 144519},
	{"YKRE", 4, 144520},
	{"YEXO", 4, 144521},
	{"UEHL", 4, 144522},
	{"RSVS", 4, 144523},
	{"REVV", 4, 144524},
	{"REUM", 4, 144525},
	{"OYOD", 4, 144526},
	{"OPCE", 4, 144527},
	{"OELK", 4, 144528},
	{"OABC", 4, 144529},
	{"NZOD", 4, 144530},
	{"LILW", 4, 144531},
	{"HOUJ", 4, 144532},
	{"DRLI", 4, 144533},
	{"CYIM", 4, 144534},
	{"FRIEDBERG", 9, 144535},
	{"SUIZA", 5, 144536},
	{"DISORGANIZATION", 15, 144537},
	{"BUBBLER", 7, 144538},
	{"ENCANA", 6, 144539},
	{"EFAULT", 6, 144540},
	{"MUMMER", 6, 144541},
	{"INDEFATIGABLE", 13, 144542},
	{"DATABINDING", 11, 144543},
	{"OVERTHROWING", 12, 144544},
	{"LENARD", 6, 144545},
	{"SEAHORSES", 9, 144546},
	{"SADIQ", 5, 144547},
	{"BEILSTEIN", 9, 144548},
	{"SCRATCHPAD", 10, 144549},
	{"MAUDLIN", 7, 144550},
	{"DISKLABS", 8, 144551},
	{"ABBOTTS", 7, 144552},
	{"MKISOFS", 7, 144553},
	{"PLAYSMART", 9, 144554},
	{"REQUESTERS", 10, 144555},
	{"GILLHAM", 7, 144556},
	{"DISCOHALL", 9, 144557},
	{"RIGOLETTO", 9, 144558},
	{"LITITZ", 6, 144559},
	{"EXCUSABLE", 9, 144560},
	{"SCABS", 5, 144561},
	{"DURKHEIM", 8, 144562},
	{"CRAGGY", 6, 144563},
	{"HIZBULLAH", 9, 144564},
	{"GUSHED", 6, 144565},
	{"ZEMAN", 5, 144566},
	{"RODRIQUEZ", 9, 144567},
	{"RANGEFINDERS", 12, 144568},
	{"ROSAT", 5, 144569},
	{"GOGLEDD", 7, 144570},
	{"SIMPLI", 6, 144571},
	{"BERTOLUCCI", 10, 144572},
	{"BBDB", 4, 144573},
	{"EXTRICATE", 9, 144574},
	{"DISPLACES", 9, 144575},
	{"SICURO", 6, 144576},
	{"BALDURS", 7, 144577},
	{"STATIS", 6, 144578},
	{"PROVOCATIONS", 12, 144579},
	{"LEMBERG", 7, 144580},
	{"ALEMAN", 6, 144581},
	{"KAYAKERS", 8, 144582},
	{"YLCO", 4, 144583},
	{"SEKU", 4, 144584},
	{"REVT", 4, 144585},
	{"PTCR", 4, 144586},
	{"PEGM", 4, 144587},
	{"PAZI", 4, 144588},
	{"OKUW", 4, 144589},
	{"NDUW", 4, 144590},
	{"NCTV", 4, 144591},
	{"MRWO", 4, 144592},
	{"MMFI", 4, 144593},
	{"LLJR", 4, 144594},
	{"KOKS", 4, 144595},
	{"HUNU", 4, 144596},
	{"GYAM", 4, 144597},
	{"GMYN", 4, 144598},
	{"DLOI", 4, 144599},
	{"CGOT", 4, 144600},
	{"AURB", 4, 144601},
	{"SYSTEMIMAGER", 12, 144602},
	{"SOUNDSTATION", 12, 144603},
	{"THORBURN", 8, 144604},
	{"DISTILLERIES", 12, 144605},
	{"CGU", 3, 144606},
	{"MISSTEPS", 8, 144607},
	{"LANDMAN", 7, 144608},
	{"GEOF", 4, 144609},
	{"LOVEY", 5, 144610},
	{"DAYA", 4, 144611},
	{"POSTBUS", 7, 144612},
	{"LOWBROW", 7, 144613},
	{"REVOLUTIONISE", 13, 144614},
	{"ACTG", 4, 144615},
	{"NONINTEREST", 11, 144616},
	{"DOUBTERS", 8, 144617},
	{"DEPLORE", 7, 144618},
	{"BIEBER", 6, 144619},
	{"YYYYMMDD", 8, 144620},
	{"AUTOSTAR", 8, 144621},
	{"AUSTRALIAS", 10, 144622},
	{"SWIZZLE", 7, 144623},
	{"DEFRAUDED", 9, 144624},
	{"MULTICOMPONENT", 14, 144625},
	{"TWEAKER", 7, 144626},
	{"SUNSTUDIO", 9, 144627},
	{"PHAEDRUS", 8, 144628},
	{"FUHRER", 6, 144629},
	{"MENSAGEM", 8, 144630},
	{"DOWNLOADERS", 11, 144631},
	{"HARTING", 7, 144632},
	{"LHCB", 4, 144633},
	{"FREESOLARIUM", 12, 144634},
	{"SAUNACAM", 8, 144635},
	{"AKKERMAN", 8, 144636},
	{"LAUT", 4, 144637},
	{"BBALL", 5, 144638},
	{"WKSM", 4, 144639},
	{"VAJR", 4, 144640},
	{"SZIP", 4, 144641},
	{"RYNM", 4, 144642},
	{"RTZC", 4, 144643},
	{"RODF", 4, 144644},
	{"REOD", 4, 144645},
	{"LTSK", 4, 144646},
	{"GMMI", 4, 144647},
	{"EVJO", 4, 144648},
	{"EPMM", 4, 144649},
	{"AWVA", 4, 144650},
	{"AGFL", 4, 144651},
	{"CIENCE", 6, 144652},
	{"APLOMB", 6, 144653},
	{"WHMIS", 5, 144654},
	{"WAHINE", 6, 144655},
	{"CENTUM", 6, 144656},
	{"HIEROGLYPHS", 11, 144657},
	{"SUNTERRA", 8, 144658},
	{"ARTIKLER", 8, 144659},
	{"BRASWELL", 8, 144660},
	{"AVREVIEW", 8, 144661},
	{"MOODIE", 6, 144662},
	{"BEPPIN", 6, 144663},
	{"HEMOLYSIS", 9, 144664},
	{"MAXIMUSCLE", 10, 144665},
	{"GARRIDO", 7, 144666},
	{"IGER", 4, 144667},
	{"CABBAGES", 8, 144668},
	{"LITERACIES", 10, 144669},
	{"TRAINWRECK", 10, 144670},
	{"JOYPAD", 6, 144671},
	{"SPEIGHT", 7, 144672},
	{"APCS", 4, 144673},
	{"SABOTEUR", 8, 144674},
	{"AEROBED", 7, 144675},
	{"VILLIANS", 8, 144676},
	{"PMOS", 4, 144677},
	{"MUGSHOT", 7, 144678},
	{"TRUISM", 6, 144679},
	{"PATCHS", 6, 144680},
	{"OESOPHAGUS", 10, 144681},
	{"COGGINS", 7, 144682},
	{"SOLAIUM", 7, 144683},
	{"ROBOHELP", 8, 144684},
	{"YLAZ", 4, 144685},
	{"XCLI", 4, 144686},
	{"WGOA", 4, 144687},
	{"UKIE", 4, 144688},
	{"UIPA", 4, 144689},
	{"OXLO", 4, 144690},
	{"MRFI", 4, 144691},
	{"LAKR", 4, 144692},
	{"DKUM", 4, 144693},
	{"ARLV", 4, 144694},
	{"BOLEY", 5, 144695},
	{"LOTZ", 4, 144696},
	{"PUTRAJAYA", 9, 144697},
	{"MINOURA", 7, 144698},
	{"INDIRIZZO", 9, 144699},
	{"MACADAM", 7, 144700},
	{"PREMA", 5, 144701},
	{"RECCOMMEND", 10, 144702},
	{"NEWLIB", 6, 144703},
	{"SEMIBOLD", 8, 144704},
	{"EMPLOYE", 7, 144705},
	{"NHLPA", 5, 144706},
	{"FERVOUR", 7, 144707},
	{"ROCHEFORT", 9, 144708},
	{"BABYLONIANS", 11, 144709},
	{"LADIE", 5, 144710},
	{"FABIUS", 6, 144711},
	{"AGGLUTINATION", 13, 144712},
	{"RADIOSITY", 9, 144713},
	{"TICKLER", 7, 144714},
	{"BRONCHOSCOPY", 12, 144715},
	{"DIPROLENE", 9, 144716},
	{"WINDSTORM", 9, 144717},
	{"DVDFAB", 6, 144718},
	{"CORRECTABLE", 11, 144719},
	{"BRICKHOUSE", 10, 144720},
	{"LABLE", 5, 144721},
	{"SOLARCAM", 8, 144722},
	{"STARWEB", 7, 144723},
	{"PLOWMAN", 7, 144724},
	{"SYSCONFDIR", 10, 144725},
	{"REKHA", 5, 144726},
	{"DWC", 3, 144727},
	{"WILKENS", 7, 144728},
	{"YVOW", 4, 144729},
	{"YCEH", 4, 144730},
	{"UZZB", 4, 144731},
	{"TYSJ", 4, 144732},
	{"TOYB", 4, 144733},
	{"MPTC", 4, 144734},
	{"JAUR", 4, 144735},
	{"FFOP", 4, 144736},
	{"ERRF", 4, 144737},
	{"EMCF", 4, 144738},
	{"INFOLINK", 8, 144739},
	{"OPENMCL", 7, 144740},
	{"VIAGGIATORI", 11, 144741},
	{"TWINX", 5, 144742},
	{"SUBLUXATION", 11, 144743},
	{"SWITCHPORT", 10, 144744},
	{"LOZIER", 6, 144745},
	{"NORGES", 6, 144746},
	{"DESPONDENT", 10, 144747},
	{"WREAKING", 8, 144748},
	{"DOWNTURNS", 9, 144749},
	{"NEUBERGER", 9, 144750},
	{"BESAR", 5, 144751},
	{"ALEXANDRU", 9, 144752},
	{"BACKTALK", 8, 144753},
	{"ADBUSTERS", 9, 144754},
	{"PULSA", 5, 144755},
	{"GLENMORE", 8, 144756},
	{"PESARO", 6, 144757},
	{"ORIENTALIS", 10, 144758},
	{"ABLED", 5, 144759},
	{"LBB", 3, 144760},
	{"EELAM", 5, 144761},
	{"MATERIALISE", 11, 144762},
	{"COMETARY", 8, 144763},
	{"ZYOU", 4, 144764},
	{"ZFEL", 4, 144765},
	{"VYRO", 4, 144766},
	{"UWAY", 4, 144767},
	{"UROK", 4, 144768},
	{"ULUL", 4, 144769},
	{"PMLO", 4, 144770},
	{"KSUF", 4, 144771},
	{"FNOL", 4, 144772},
	{"FCAF", 4, 144773},
	{"ARQA", 4, 144774},
	{"ARCG", 4, 144775},
	{"AGMO", 4, 144776},
	{"CUNNINGLY", 9, 144777},
	{"CDJ", 3, 144778},
	{"RALLS", 5, 144779},
	{"INDYMAC", 7, 144780},
	{"TOPJOBS", 7, 144781},
	{"PUTING", 6, 144782},
	{"REFERE", 6, 144783},
	{"DCMTK", 5, 144784},
	{"REALTREE", 8, 144785},
	{"LINGUINE", 8, 144786},
	{"JAVAHELP", 8, 144787},
	{"COMMUTATOR", 10, 144788},
	{"KURTOSIS", 8, 144789},
	{"RAMAGE", 6, 144790},
	{"WATERJET", 8, 144791},
	{"COUNTRYBOOKSHOP", 15, 144792},
	{"FISMA", 5, 144793},
	{"BATHERS", 7, 144794},
	{"CSAP", 4, 144795},
	{"STOMA", 5, 144796},
	{"NONUNIFORM", 10, 144797},
	{"WEEHAWKEN", 9, 144798},
	{"OCEANOGR", 8, 144799},
	{"TALMADGE", 8, 144800},
	{"BACHER", 6, 144801},
	{"REHABIL", 7, 144802},
	{"ARGYLLSHIRE", 11, 144803},
	{"EXEUNT", 6, 144804},
	{"TELFER", 6, 144805},
	{"HEINTZ", 6, 144806},
	{"RACIN", 5, 144807},
	{"TURBID", 6, 144808},
	{"KIDA", 4, 144809},
	{"GLENNIE", 7, 144810},
	{"SERVIDORES", 10, 144811},
	{"KOLOA", 5, 144812},
	{"DOMAI", 5, 144813},
	{"STOYS", 5, 144814},
	{"CUOI", 4, 144815},
	{"CHAPBOOK", 8, 144816},
	{"DEFACTO", 7, 144817},
	{"BUILDABLE", 9, 144818},
	{"YKUB", 4, 144819},
	{"YDUD", 4, 144820},
	{"XBLO", 4, 144821},
	{"UEHU", 4, 144822},
	{"TVWE", 4, 144823},
	{"SJID", 4, 144824},
	{"OLOY", 4, 144825},
	{"LAUA", 4, 144826},
	{"IRYH", 4, 144827},
	{"HLOB", 4, 144828},
	{"ENMD", 4, 144829},
	{"DZIC", 4, 144830},
	{"STARNES", 7, 144831},
	{"LMFAO", 5, 144832},
	{"STERNA", 6, 144833},
	{"ISKCON", 6, 144834},
	{"SCEPTICS", 8, 144835},
	{"TOURE", 5, 144836},
	{"ERRORCODE", 9, 144837},
	{"POLLYANNA", 9, 144838},
	{"MINNESOTANS", 11, 144839},
	{"SAYVILLE", 8, 144840},
	{"HURENTEST", 9, 144841},
	{"AMYL", 4, 144842},
	{"PREMPRO", 7, 144843},
	{"ERATOR", 6, 144844},
	{"STRICK", 6, 144845},
	{"ATELY", 5, 144846},
	{"YORAM", 5, 144847},
	{"CRUSIER", 7, 144848},
	{"FRIEDMANN", 9, 144849},
	{"COMPONENTONE", 12, 144850},
	{"FREEMANS", 8, 144851},
	{"MAGNETOSPHERIC", 14, 144852},
	{"FGC", 3, 144853},
	{"NEUBAUER", 8, 144854},
	{"RONNI", 5, 144855},
	{"LOADOUT", 7, 144856},
	{"RGBCOLOR", 8, 144857},
	{"OUTPACED", 8, 144858},
	{"INSTITUTET", 10, 144859},
	{"DLIVE", 5, 144860},
	{"WUSS", 4, 144861},
	{"LINUXTHREADS", 12, 144862},
	{"PDATA", 5, 144863},
	{"PBWIKI", 6, 144864},
	{"NHPR", 4, 144865},
	{"HEMATOLOGISTS", 13, 144866},
	{"CATRON", 6, 144867},
	{"SPANNERCAM", 10, 144868},
	{"SPANNERBILDER", 13, 144869},
	{"STARMINE", 8, 144870},
	{"BORT", 4, 144871},
	{"PERHAM", 6, 144872},
	{"DRENNAN", 7, 144873},
	{"IMPLORED", 8, 144874},
	{"HOSTESSENSERVICE", 16, 144875},
	{"MERCIAL", 7, 144876},
	{"CAISO", 5, 144877},
	{"DEJONG", 6, 144878},
	{"EARTHING", 8, 144879},
	{"YPOM", 4, 144880},
	{"WDIM", 4, 144881},
	{"UCKV", 4, 144882},
	{"SJUG", 4, 144883},
	{"MNIW", 4, 144884},
	{"GKIM", 4, 144885},
	{"EKUB", 4, 144886},
	{"CTJE", 4, 144887},
	{"AXBY", 4, 144888},
	{"AFFU", 4, 144889},
	{"DOOKIE", 6, 144890},
	{"DIGRAPH", 7, 144891},
	{"GILLEY", 6, 144892},
	{"RIGHTY", 6, 144893},
	{"SCHERMO", 7, 144894},
	{"MALTHUS", 7, 144895},
	{"TRENTHAM", 8, 144896},
	{"CLUMPING", 8, 144897},
	{"MERCE", 5, 144898},
	{"TERATOGENIC", 11, 144899},
	{"MRSID", 5, 144900},
	{"CONSTITUTIONALISM", 17, 144901},
	{"SUGERENCIAS", 11, 144902},
	{"LUTTERWORTH", 11, 144903},
	{"JOFFE", 5, 144904},
	{"DECON", 5, 144905},
	{"COMPRESSIBILITY", 15, 144906},
	{"PHILPOT", 7, 144907},
	{"ACUFF", 5, 144908},
	{"MATRIMONIO", 10, 144909},
	{"ARIANNE", 7, 144910},
	{"TIMEVAL", 7, 144911},
	{"SCHACHT", 7, 144912},
	{"DEFERS", 6, 144913},
	{"RIVISTA", 7, 144914},
	{"RECALCULATION", 13, 144915},
	{"SOMES", 5, 144916},
	{"INTROVERT", 9, 144917},
	{"PRIVATEERS", 10, 144918},
	{"LEVEY", 5, 144919},
	{"SUBPAR", 6, 144920},
	{"JARON", 5, 144921},
	{"SPRINGBROOK", 11, 144922},
	{"PICTUER", 7, 144923},
	{"KNOWE", 5, 144924},
	{"PREOCCUPATIONS", 14, 144925},
	{"LUDOVICO", 8, 144926},
	{"EMAG", 4, 144927},
	{"BERMUDAN", 8, 144928},
	{"XSAV", 4, 144929},
	{"VEZW", 4, 144930},
	{"SKGO", 4, 144931},
	{"NZIB", 4, 144932},
	{"MNEC", 4, 144933},
	{"LYGH", 4, 144934},
	{"GUTW", 4, 144935},
	{"GNEP", 4, 144936},
	{"EKSY", 4, 144937},
	{"EKOW", 4, 144938},
	{"CJUD", 4, 144939},
	{"BECW", 4, 144940},
	{"REICHEL", 7, 144941},
	{"ORHAN", 5, 144942},
	{"UNALIGNED", 9, 144943},
	{"BESONDERS", 9, 144944},
	{"NIAMH", 5, 144945},
	{"POVIDED", 7, 144946},
	{"EROTIKCAMS", 10, 144947},
	{"QUACKERY", 8, 144948},
	{"VILLAINY", 8, 144949},
	{"VARVATOS", 8, 144950},
	{"JAMDAT", 6, 144951},
	{"LINTIAN", 7, 144952},
	{"BUFFED", 6, 144953},
	{"LOADSMORESTUFF", 14, 144954},
	{"LEGROOM", 7, 144955},
	{"NISHIDA", 7, 144956},
	{"TROMSO", 6, 144957},
	{"CALDO", 5, 144958},
	{"NATSUME", 7, 144959},
	{"SELLAFIELD", 10, 144960},
	{"GUUS", 4, 144961},
	{"GERRI", 5, 144962},
	{"SULL", 4, 144963},
	{"OUTPUTBIN", 9, 144964},
	{"MASHING", 7, 144965},
	{"MUIRHEAD", 8, 144966},
	{"JETSET", 6, 144967},
	{"FEUILLES", 8, 144968},
	{"YLDE", 4, 144969},
	{"YIDL", 4, 144970},
	{"WDRY", 4, 144971},
	{"TGDP", 4, 144972},
	{"TFAK", 4, 144973},
	{"NDVL", 4, 144974},
	{"NDUZ", 4, 144975},
	{"NDBN", 4, 144976},
	{"NCDI", 4, 144977},
	{"MADP", 4, 144978},
	{"LUGF", 4, 144979},
	{"KAML", 4, 144980},
	{"HAZR", 4, 144981},
	{"FVIA", 4, 144982},
	{"EDCM", 4, 144983},
	{"CAYL", 4, 144984},
	{"BCEA", 4, 144985},
	{"AKPU", 4, 144986},
	{"DIVERSES", 8, 144987},
	{"MTNL", 4, 144988},
	{"EBONITE", 7, 144989},
	{"SHUNTING", 8, 144990},
	{"RAPPEL", 6, 144991},
	{"KURANDA", 7, 144992},
	{"SIDEBURNS", 9, 144993},
	{"ATRINITI", 8, 144994},
	{"DEVELOPPEMENT", 13, 144995},
	{"WINGO", 5, 144996},
	{"MALADIE", 7, 144997},
	{"TERMINOLOGIES", 13, 144998},
	{"MANGERS", 7, 144999},
	{"FRAGONARD", 9, 145000},
	{"KPPP", 4, 145001},
	{"SYSTEMICALLY", 12, 145002},
	{"ENGLUND", 7, 145003},
	{"HURTLING", 8, 145004},
	{"HABITUATION", 11, 145005},
	{"PUCCA", 5, 145006},
	{"OSTEOTOMY", 9, 145007},
	{"BORUSSIA", 8, 145008},
	{"PILI", 4, 145009},
	{"SQUABBLE", 8, 145010},
	{"STRIPTV", 7, 145011},
	{"INORG", 5, 145012},
	{"PORTMAP", 7, 145013},
	{"MUAH", 4, 145014},
	{"RAVIN", 5, 145015},
	{"PONOKA", 6, 145016},
	{"SVAR", 4, 145017},
	{"COMMERCIALIZING", 15, 145018},
	{"MOOKIE", 6, 145019},
	{"MIGLIN", 6, 145020},
	{"UINY", 4, 145021},
	{"SPWA", 4, 145022},
	{"RFUC", 4, 145023},
	{"PJOS", 4, 145024},
	{"MTOQ", 4, 145025},
	{"LRYG", 4, 145026},
	{"IACW", 4, 145027},
	{"HIDR", 4, 145028},
	{"HEFJ", 4, 145029},
	{"GSUL", 4, 145030},
	{"GSUE", 4, 145031},
	{"FTJU", 4, 145032},
	{"EDXI", 4, 145033},
	{"CTVC", 4, 145034},
	{"AXTR", 4, 145035},
	{"CHECKBOOKS", 10, 145036},
	{"MACHINERIES", 11, 145037},
	{"LAMINAE", 7, 145038},
	{"DOODLEBUG", 9, 145039},
	{"DIMEBAG", 7, 145040},
	{"MIZUHO", 6, 145041},
	{"SUPERSLAM", 9, 145042},
	{"PINPOINTED", 10, 145043},
	{"VACCINIUM", 9, 145044},
	{"RICHTON", 7, 145045},
	{"RLBA", 4, 145046},
	{"STOUFFER", 8, 145047},
	{"POSITIVA", 8, 145048},
	{"PERFECTIONISM", 13, 145049},
	{"JADEN", 5, 145050},
	{"OMNES", 5, 145051},
	{"METHODISM", 9, 145052},
	{"CERIUM", 6, 145053},
	{"BIBLIOGRAPHIE", 13, 145054},
	{"GARROS", 6, 145055},
	{"ANYTOWN", 7, 145056},
	{"BIFURCATED", 10, 145057},
	{"FETISCHCAM", 10, 145058},
	{"KAWAGUCHI", 9, 145059},
	{"MENTE", 5, 145060},
	{"LIQUORAMA", 9, 145061},
	{"EXPRESSWAYS", 11, 145062},
	{"MOHAA", 5, 145063},
	{"BWARSAW", 7, 145064},
	{"TOWBAR", 6, 145065},
	{"LUEGO", 5, 145066},
	{"MOUTAIN", 7, 145067},
	{"CURLER", 6, 145068},
	{"OVERTAKES", 9, 145069},
	{"VITTER", 6, 145070},
	{"MARKEN", 6, 145071},
	{"BOUTROS", 7, 145072},
	{"OBFUSCATE", 9, 145073},
	{"CANDYSTAND", 10, 145074},
	{"TRANSLITERATED", 14, 145075},
	{"MWM", 3, 145076},
	{"FIBEROPTIC", 10, 145077},
	{"AMUN", 4, 145078},
	{"PREDOMINATES", 12, 145079},
	{"COPAN", 5, 145080},
	{"CROONER", 7, 145081},
	{"ZIOC", 4, 145082},
	{"XDEV", 4, 145083},
	{"VIWH", 4, 145084},
	{"SMCI", 4, 145085},
	{"SKWO", 4, 145086},
	{"SCHG", 4, 145087},
	{"RKKO", 4, 145088},
	{"RDAE", 4, 145089},
	{"RBAA", 4, 145090},
	{"PRUL", 4, 145091},
	{"NORQ", 4, 145092},
	{"MNCO", 4, 145093},
	{"FZON", 4, 145094},
	{"EDBB", 4, 145095},
	{"DUDD", 4, 145096},
	{"DOOC", 4, 145097},
	{"CJUN", 4, 145098},
	{"CANZ", 4, 145099},
	{"BOPT", 4, 145100},
	{"BBEI", 4, 145101},
	{"PHILLIS", 7, 145102},
	{"CHRY", 4, 145103},
	{"TEMOVATE", 8, 145104},
	{"SUBSTANTIA", 10, 145105},
	{"TEALEAF", 7, 145106},
	{"STRICHWEB", 9, 145107},
	{"TYPEDEFS", 8, 145108},
	{"STANDARDIZES", 12, 145109},
	{"PREPARATIVE", 11, 145110},
	{"VIEWERSHIP", 10, 145111},
	{"REDOING", 7, 145112},
	{"INTERLINE", 9, 145113},
	{"STARTLINGLY", 11, 145114},
	{"MATSUSHIMA", 10, 145115},
	{"GYROLOCK", 8, 145116},
	{"CAMDB", 5, 145117},
	{"VANDY", 5, 145118},
	{"LAUGHTON", 8, 145119},
	{"MACANUDO", 8, 145120},
	{"LEBEAU", 6, 145121},
	{"FREECHATCAM", 11, 145122},
	{"FUNNELED", 8, 145123},
	{"EARTHSEA", 8, 145124},
	{"RAWTENSTALL", 11, 145125},
	{"ALEUT", 5, 145126},
	{"COUPLET", 7, 145127},
	{"SUBCLASSING", 11, 145128},
	{"ALLITERATION", 12, 145129},
	{"PKZIP", 5, 145130},
	{"HACKETTSTOWN", 12, 145131},
	{"BARTHES", 7, 145132},
	{"EROSIVE", 7, 145133},
	{"GUTTERMAN", 9, 145134},
	{"NONLINEARITIES", 14, 145135},
	{"HAITHAM", 7, 145136},
	{"FALTA", 5, 145137},
	{"UNREFINED", 9, 145138},
	{"INIMICAL", 8, 145139},
	{"THYROIDITIS", 11, 145140},
	{"TEXOMA", 6, 145141},
	{"RMAC", 4, 145142},
	{"PLV", 3, 145143},
	{"WONV", 4, 145144},
	{"UGBA", 4, 145145},
	{"UDAK", 4, 145146},
	{"THPM", 4, 145147},
	{"TCPI", 4, 145148},
	{"SECD", 4, 145149},
	{"RPTF", 4, 145150},
	{"MEHY", 4, 145151},
	{"LYIB", 4, 145152},
	{"KRAA", 4, 145153},
	{"KOZL", 4, 145154},
	{"KOCA", 4, 145155},
	{"KBYE", 4, 145156},
	{"JIBR", 4, 145157},
	{"HMSF", 4, 145158},
	{"AKUF", 4, 145159},
	{"ARIC", 4, 145160},
	{"MEZUZAH", 7, 145161},
	{"CHRISTIN", 8, 145162},
	{"GEOMORPHIC", 10, 145163},
	{"ALBACETE", 8, 145164},
	{"IMPERIOUS", 9, 145165},
	{"ADJUDICATIVE", 12, 145166},
	{"WEBQUESTS", 9, 145167},
	{"KDV", 3, 145168},
	{"APUS", 4, 145169},
	{"MATHILDA", 8, 145170},
	{"FIREWALLING", 11, 145171},
	{"RAZAVI", 6, 145172},
	{"JUKES", 5, 145173},
	{"WIKIUSERSTOPIC", 14, 145174},
	{"LEYS", 4, 145175},
	{"BUNCHING", 8, 145176},
	{"BEDBUGS", 7, 145177},
	{"RAPAPORT", 8, 145178},
	{"HOSMER", 6, 145179},
	{"LORENE", 6, 145180},
	{"LOFAR", 5, 145181},
	{"DILLMAN", 7, 145182},
	{"SQUAWK", 6, 145183},
	{"DINUCLEOTIDE", 12, 145184},
	{"SUPERFOODS", 10, 145185},
	{"COSTE", 5, 145186},
	{"COALINGA", 8, 145187},
	{"VAGINOSIS", 9, 145188},
	{"TOWNSMEN", 8, 145189},
	{"FILESET", 7, 145190},
	{"GOOSEN", 6, 145191},
	{"SONDERN", 7, 145192},
	{"EMPH", 4, 145193},
	{"ACCREDIT", 8, 145194},
	{"WHITEBEAR", 9, 145195},
	{"LIMING", 6, 145196},
	{"SOLARIUMTV", 10, 145197},
	{"IRMO", 4, 145198},
	{"LOGROTATE", 9, 145199},
	{"ETHICALITY", 10, 145200},
	{"REVOIR", 6, 145201},
	{"YEVGENY", 7, 145202},
	{"PASKO", 5, 145203},
	{"MOLDAVIAN", 9, 145204},
	{"YLKI", 4, 145205},
	{"XBET", 4, 145206},
	{"XALI", 4, 145207},
	{"WENL", 4, 145208},
	{"UADV", 4, 145209},
	{"TADW", 4, 145210},
	{"SJUV", 4, 145211},
	{"PADB", 4, 145212},
	{"NUMR", 4, 145213},
	{"NBCB", 4, 145214},
	{"LNOC", 4, 145215},
	{"ECSW", 4, 145216},
	{"DFRY", 4, 145217},
	{"DALZ", 4, 145218},
	{"XACML", 5, 145219},
	{"REMARKETING", 11, 145220},
	{"ENTITLING", 9, 145221},
	{"AGUASCALIENTES", 14, 145222},
	{"POLYAMORY", 9, 145223},
	{"TENAFLY", 7, 145224},
	{"SKYLINES", 8, 145225},
	{"EDITBOXHEIGHT", 13, 145226},
	{"EGOCENTRIC", 10, 145227},
	{"RUBINO", 6, 145228},
	{"QUAKENET", 8, 145229},
	{"RYKODISC", 8, 145230},
	{"ARPEGGIOS", 9, 145231},
	{"UMF", 3, 145232},
	{"REINSTATING", 11, 145233},
	{"MCNAUGHT", 8, 145234},
	{"UNPAIRED", 8, 145235},
	{"BIRDSALL", 8, 145236},
	{"HANDFULS", 8, 145237},
	{"CORNUS", 6, 145238},
	{"ASIANNET", 8, 145239},
	{"WOODIES", 7, 145240},
	{"BRANDEE", 7, 145241},
	{"LOANING", 7, 145242},
	{"MONETIZATION", 12, 145243},
	{"NANDROLONE", 10, 145244},
	{"MUTATIS", 7, 145245},
	{"NORANDA", 7, 145246},
	{"XTEL", 4, 145247},
	{"SCHEFFLER", 9, 145248},
	{"ASPHYXIA", 8, 145249},
	{"HEBRIDEAN", 9, 145250},
	{"OVERSUBSCRIBED", 14, 145251},
	{"UTADA", 5, 145252},
	{"RAYTOWN", 7, 145253},
	{"GRATIA", 6, 145254},
	{"TRYS", 4, 145255},
	{"SYROS", 5, 145256},
	{"COLLOCATED", 10, 145257},
	{"COFACTORS", 9, 145258},
	{"RELACIONADOS", 12, 145259},
	{"CATECHOLAMINE", 13, 145260},
	{"FORMANT", 7, 145261},
	{"PORTNOY", 7, 145262},
	{"PICYURES", 8, 145263},
	{"COPYSTAR", 8, 145264},
	{"MABE", 4, 145265},
	{"SERVERWORKS", 11, 145266},
	{"VENTSHADE", 9, 145267},
	{"YAMC", 4, 145268},
	{"UCIC", 4, 145269},
	{"TOXX", 4, 145270},
	{"SOMR", 4, 145271},
	{"RYIA", 4, 145272},
	{"PIAM", 4, 145273},
	{"OMMM", 4, 145274},
	{"OFVL", 4, 145275},
	{"NGMM", 4, 145276},
	{"LIVR", 4, 145277},
	{"LAFG", 4, 145278},
	{"KANR", 4, 145279},
	{"HEKK", 4, 145280},
	{"EBLV", 4, 145281},
	{"CSJU", 4, 145282},
	{"CHYH", 4, 145283},
	{"BBEG", 4, 145284},
	{"ALFJ", 4, 145285},
	{"GONGS", 5, 145286},
	{"BASHERS", 7, 145287},
	{"OUTBID", 6, 145288},
	{"STRUCTURALISM", 13, 145289},
	{"KATZI", 5, 145290},
	{"MADAWASKA", 9, 145291},
	{"GLOBALISED", 10, 145292},
	{"SMELTERS", 8, 145293},
	{"HIPTOP", 6, 145294},
	{"LAGASSE", 7, 145295},
	{"SEALAND", 7, 145296},
	{"CANONGATE", 9, 145297},
	{"MOMSANALADVENTURE", 17, 145298},
	{"RAMANA", 6, 145299},
	{"KASTRUP", 7, 145300},
	{"EIGENEN", 7, 145301},
	{"BUSCO", 5, 145302},
	{"LARGA", 5, 145303},
	{"GISHUR", 6, 145304},
	{"PENTATEUCH", 10, 145305},
	{"MARGA", 5, 145306},
	{"BROXBOURNE", 10, 145307},
	{"OVERSOLD", 8, 145308},
	{"LSOCKET", 7, 145309},
	{"DORCEY", 6, 145310},
	{"DEMODULATOR", 11, 145311},
	{"FIGUREHEAD", 10, 145312},
	{"PASSTHROUGH", 11, 145313},
	{"INFOZONE", 8, 145314},
	{"IMMOBILITY", 10, 145315},
	{"LACQUERS", 8, 145316},
	{"FURANS", 6, 145317},
	{"TURTURRO", 8, 145318},
	{"STROTHER", 8, 145319},
	{"LUTTRELL", 8, 145320},
	{"KRISTOPHER", 10, 145321},
	{"KADIMA", 6, 145322},
	{"CHIEFTEC", 8, 145323},
	{"LADISLAV", 8, 145324},
	{"WIPPIT", 6, 145325},
	{"OPENSCENEGRAPH", 14, 145326},
	{"YOBS", 4, 145327},
	{"OBSESSING", 9, 145328},
	{"RESTAURATEUR", 12, 145329},
	{"SUMDEX", 6, 145330},
	{"BLOGGS", 6, 145331},
	{"PURIFIES", 8, 145332},
	{"BASEDIR", 7, 145333},
	{"ATATURK", 7, 145334},
	{"BOOLEANS", 8, 145335},
	{"STUNTING", 8, 145336},
	{"SPARKLED", 8, 145337},
	{"PARO", 4, 145338},
	{"MULA", 4, 145339},
	{"SCRIMSHAW", 9, 145340},
	{"RIFFING", 7, 145341},
	{"SUBMICRON", 9, 145342},
	{"YAROSLAV", 8, 145343},
	{"CCDP", 4, 145344},
	{"POTENZA", 7, 145345},
	{"NONEXEMPT", 9, 145346},
	{"SCRIPTURLPATH", 13, 145347},
	{"ELLIJAY", 7, 145348},
	{"SANUK", 5, 145349},
	{"SOLICAM", 7, 145350},
	{"VEGREVILLE", 10, 145351},
	{"YSEY", 4, 145352},
	{"TOLG", 4, 145353},
	{"RYIH", 4, 145354},
	{"RKOA", 4, 145355},
	{"REXL", 4, 145356},
	{"RCAE", 4, 145357},
	{"LOWZ", 4, 145358},
	{"HEVM", 4, 145359},
	{"CPIL", 4, 145360},
	{"STOCKSCOUTER", 12, 145361},
	{"INTERCHANGED", 12, 145362},
	{"BAFANA", 6, 145363},
	{"YGX", 3, 145364},
	{"WZJ", 3, 145365},
	{"VVZ", 3, 145366},
	{"UJG", 3, 145367},
	{"RJQ", 3, 145368},
	{"QXF", 3, 145369},
	{"QWM", 3, 145370},
	{"QVW", 3, 145371},
	{"PQG", 3, 145372},
	{"PGQ", 3, 145373},
	{"KQQ", 3, 145374},
	{"KQP", 3, 145375},
	{"JVK", 3, 145376},
	{"ANONIMO", 7, 145377},
	{"EXTRATERRITORIAL", 16, 145378},
	{"UNRAVELLING", 11, 145379},
	{"ECKEL", 5, 145380},
	{"AMARE", 5, 145381},
	{"YLD", 3, 145382},
	{"FFD", 3, 145383},
	{"DIBS", 4, 145384},
	{"INTERNETCAMERASDIRECT", 21, 145385},
	{"DYNAMODE", 8, 145386},
	{"CATLETT", 7, 145387},
	{"CANONSBURG", 10, 145388},
	{"CAUS", 4, 145389},
	{"GOOGE", 5, 145390},
	{"SOUNDWAVE", 9, 145391},
	{"TALCOTT", 7, 145392},
	{"MAKEMAKER", 9, 145393},
	{"PFL", 3, 145394},
	{"STEVO", 5, 145395},
	{"MAXIMISED", 9, 145396},
	{"TREMPEALEAU", 11, 145397},
	{"SHORETEL", 8, 145398},
	{"BORGMAN", 7, 145399},
	{"ARACHNID", 8, 145400},
	{"WHOOPEE", 7, 145401},
	{"EQUALING", 8, 145402},
	{"DENTATE", 7, 145403},
	{"DRBD", 4, 145404},
	{"HANSSEN", 7, 145405},
	{"TETSUYA", 7, 145406},
	{"DELT", 4, 145407},
	{"PRANAYAMA", 9, 145408},
	{"YEPR", 4, 145409},
	{"UBNA", 4, 145410},
	{"TKUN", 4, 145411},
	{"RNYS", 4, 145412},
	{"RMJO", 4, 145413},
	{"RCUN", 4, 145414},
	{"OFUB", 4, 145415},
	{"LOBT", 4, 145416},
	{"LAKU", 4, 145417},
	{"IMVA", 4, 145418},
	{"IGPH", 4, 145419},
	{"EKSV", 4, 145420},
	{"DGUM", 4, 145421},
	{"CTIR", 4, 145422},
	{"BJUN", 4, 145423},
	{"ETHERLINK", 9, 145424},
	{"MCKENNITT", 9, 145425},
	{"LULLED", 6, 145426},
	{"FANTOMAS", 8, 145427},
	{"INSTANTIATIONS", 14, 145428},
	{"DISREPUTE", 9, 145429},
	{"EIGENFUNCTIONS", 14, 145430},
	{"PINTURA", 7, 145431},
	{"SKYTRAIN", 8, 145432},
	{"RECHTEN", 7, 145433},
	{"IMPLACABLE", 10, 145434},
	{"ROTHBARD", 8, 145435},
	{"MBTI", 4, 145436},
	{"DIALLO", 6, 145437},
	{"UNINSPIRING", 11, 145438},
	{"DEWHURST", 8, 145439},
	{"QUIBBLES", 8, 145440},
	{"EMPLOYMENTS", 11, 145441},
	{"SACHSE", 6, 145442},
	{"GENL", 4, 145443},
	{"CARINTHIA", 9, 145444},
	{"THROMB", 6, 145445},
	{"ATTIRED", 7, 145446},
	{"HERRERO", 7, 145447},
	{"CHRONOSWISS", 11, 145448},
	{"MACCABI", 7, 145449},
	{"CLUNY", 5, 145450},
	{"HORNELL", 7, 145451},
	{"ZAHIR", 5, 145452},
	{"UNCALLED", 8, 145453},
	{"DEGRADABLE", 10, 145454},
	{"WINDOWTEXT", 10, 145455},
	{"STRATIX", 7, 145456},
	{"MASQ", 4, 145457},
	{"HALITOSIS", 9, 145458},
	{"HOTFIXES", 8, 145459},
	{"SLATON", 6, 145460},
	{"INIZIO", 6, 145461},
	{"CYBERCAFE", 9, 145462},
	{"HOMESCHOOLED", 12, 145463},
	{"YUCC", 4, 145464},
	{"VCLA", 4, 145465},
	{"SAWV", 4, 145466},
	{"ROXE", 4, 145467},
	{"OMIP", 4, 145468},
	{"NLID", 4, 145469},
	{"KYDA", 4, 145470},
	{"KIDL", 4, 145471},
	{"HLCA", 4, 145472},
	{"BHEW", 4, 145473},
	{"BAGD", 4, 145474},
	{"AXYO", 4, 145475},
	{"REPELS", 6, 145476},
	{"LOKAL", 5, 145477},
	{"INGUSHETIA", 10, 145478},
	{"ELECTROACOUSTIC", 15, 145479},
	{"CULLY", 5, 145480},
	{"AHANIX", 6, 145481},
	{"ROLLIE", 6, 145482},
	{"EMBEDDABLE", 10, 145483},
	{"SOLARIUMCAMS", 12, 145484},
	{"PMAX", 4, 145485},
	{"EMAILADDRESS", 12, 145486},
	{"NSPR", 4, 145487},
	{"LWW", 3, 145488},
	{"KALKASKA", 8, 145489},
	{"TEALIGHTS", 9, 145490},
	{"SEAFOAM", 7, 145491},
	{"LBIAN", 5, 145492},
	{"DATAGLYPHICS", 12, 145493},
	{"PASCHA", 6, 145494},
	{"HILMAR", 6, 145495},
	{"MEMETICS", 8, 145496},
	{"ATLETICO", 8, 145497},
	{"ARTSBARS", 8, 145498},
	{"PRANKSTER", 9, 145499},
	{"FISUBSILVER", 11, 145500},
	{"POSTNET", 7, 145501},
	{"WRUNG", 5, 145502},
	{"CROSSLINKED", 11, 145503},
	{"DEFRAUDING", 10, 145504},
	{"INTELLISENSE", 12, 145505},
	{"LWIP", 4, 145506},
	{"PLIANT", 6, 145507},
	{"ALMERE", 6, 145508},
	{"BENICIO", 7, 145509},
	{"METALLIZED", 10, 145510},
	{"OMLINE", 6, 145511},
	{"EMUS", 4, 145512},
	{"YOUTUBE", 7, 145513},
	{"FAGEN", 5, 145514},
	{"LANZHOU", 7, 145515},
	{"SUBPLOTS", 8, 145516},
	{"LANCHESTER", 10, 145517},
	{"REAPPEARANCE", 12, 145518},
	{"PYJAMA", 6, 145519},
	{"YOLS", 4, 145520},
	{"YLAA", 4, 145521},
	{"WCOD", 4, 145522},
	{"URUW", 4, 145523},
	{"TPEG", 4, 145524},
	{"TPAW", 4, 145525},
	{"SDCO", 4, 145526},
	{"RJIL", 4, 145527},
	{"PIWH", 4, 145528},
	{"MPHB", 4, 145529},
	{"FTUC", 4, 145530},
	{"FAXM", 4, 145531},
	{"DAOV", 4, 145532},
	{"CTPM", 4, 145533},
	{"AKHM", 4, 145534},
	{"BACKBEAT", 8, 145535},
	{"NSCAA", 5, 145536},
	{"BROOKLIN", 8, 145537},
	{"SARINA", 6, 145538},
	{"WAVENUMBER", 10, 145539},
	{"SIPURA", 6, 145540},
	{"URBAIN", 6, 145541},
	{"ALLUVIUM", 8, 145542},
	{"CCSD", 4, 145543},
	{"KOPLOW", 6, 145544},
	{"STARGAZE", 8, 145545},
	{"NROFF", 5, 145546},
	{"MICAELA", 7, 145547},
	{"CATABOLIC", 9, 145548},
	{"AVOCAT", 6, 145549},
	{"NETBOOK", 7, 145550},
	{"EMACIATED", 9, 145551},
	{"RIEKER", 6, 145552},
	{"DENVILLE", 8, 145553},
	{"MACEY", 5, 145554},
	{"IMIDAZOLE", 9, 145555},
	{"GERN", 4, 145556},
	{"MULTIVISION", 11, 145557},
	{"BRADMAN", 7, 145558},
	{"FLASHGET", 8, 145559},
	{"REDRAWING", 9, 145560},
	{"VASSAL", 6, 145561},
	{"WWJD", 4, 145562},
	{"ULTRALAST", 9, 145563},
	{"JACINTA", 7, 145564},
	{"SOMMERVILLE", 11, 145565},
	{"ASOTIN", 6, 145566},
	{"GVG", 3, 145567},
	{"HAMTRAMCK", 9, 145568},
	{"SHARPLES", 8, 145569},
	{"MICROSTRUCTURAL", 15, 145570},
	{"ZGRO", 4, 145571},
	{"YUSF", 4, 145572},
	{"YTUL", 4, 145573},
	{"YPTB", 4, 145574},
	{"UNKG", 4, 145575},
	{"UCEK", 4, 145576},
	{"OFHM", 4, 145577},
	{"GISY", 4, 145578},
	{"EBFR", 4, 145579},
	{"CKAA", 4, 145580},
	{"ALMIRA", 6, 145581},
	{"ILECS", 5, 145582},
	{"REMA", 4, 145583},
	{"MILLIMETRE", 10, 145584},
	{"LEFKOWITZ", 9, 145585},
	{"NEURAMINIDASE", 13, 145586},
	{"BORJA", 5, 145587},
	{"PLATAFORMA", 10, 145588},
	{"SWAMINATHAN", 11, 145589},
	{"WIKIHOMEURL", 11, 145590},
	{"THERMOSET", 9, 145591},
	{"PLATTED", 7, 145592},
	{"HARDCORD", 8, 145593},
	{"MUNICATIONS", 11, 145594},
	{"CANTOS", 6, 145595},
	{"REFINANCES", 10, 145596},
	{"PARAMETRIZED", 12, 145597},
	{"OSTRICHES", 9, 145598},
	{"MARSUPIAL", 9, 145599},
	{"MANSE", 5, 145600},
	{"PICADOR", 7, 145601},
	{"HORIZONTIC", 10, 145602},
	{"LAMONTAGNE", 10, 145603},
	{"CARMA", 5, 145604},
	{"POLYWELL", 8, 145605},
	{"SUBBUTEO", 8, 145606},
	{"PINING", 6, 145607},
	{"BRONZER", 7, 145608},
	{"CHASSISROLLANGLE", 16, 145609},
	{"INTRATHECAL", 11, 145610},
	{"CATECHESIS", 10, 145611},
	{"SMARTCARDS", 10, 145612},
	{"BURREN", 6, 145613},
	{"WESTS", 5, 145614},
	{"OPEX", 4, 145615},
	{"INTERNO", 7, 145616},
	{"ENTAILMENT", 10, 145617},
	{"SOCCERNATION", 12, 145618},
	{"PLASTERBOARD", 12, 145619},
	{"SEYFERT", 7, 145620},
	{"YABH", 4, 145621},
	{"XTLO", 4, 145622},
	{"WLYH", 4, 145623},
	{"UYHO", 4, 145624},
	{"UEPH", 4, 145625},
	{"TLLO", 4, 145626},
	{"OPVE", 4, 145627},
	{"NZAK", 4, 145628},
	{"NZAD", 4, 145629},
	{"KFEN", 4, 145630},
	{"IUCH", 4, 145631},
	{"FCOH", 4, 145632},
	{"COCL", 4, 145633},
	{"BOSK", 4, 145634},
	{"BNEY", 4, 145635},
	{"BAFE", 4, 145636},
	{"ASMD", 4, 145637},
	{"ALARMIST", 8, 145638},
	{"PENNSYLVANIAN", 13, 145639},
	{"HIGHSMITH", 9, 145640},
	{"VRM", 3, 145641},
	{"UMKLEIDEKABINE", 14, 145642},
	{"ASNER", 5, 145643},
	{"JAZZANOVA", 9, 145644},
	{"MBUF", 4, 145645},
	{"PERIMENOPAUSE", 13, 145646},
	{"HARDBODIED", 10, 145647},
	{"HARDAWAY", 8, 145648},
	{"WARRANTEE", 9, 145649},
	{"TURBOPROP", 9, 145650},
	{"IMPLICATING", 11, 145651},
	{"LABIAL", 6, 145652},
	{"PROMETRIC", 9, 145653},
	{"QUINIDINE", 9, 145654},
	{"VOLUN", 5, 145655},
	{"UNALLOWABLE", 11, 145656},
	{"SIMARD", 6, 145657},
	{"SQUEAKS", 7, 145658},
	{"UNKNOWING", 9, 145659},
	{"MILLILITERS", 11, 145660},
	{"NECHES", 6, 145661},
	{"BLITHELY", 8, 145662},
	{"AUTOCLAVES", 10, 145663},
	{"FRAMESHIFT", 10, 145664},
	{"DEALLOCATE", 10, 145665},
	{"FLEXTRONICS", 11, 145666},
	{"MODERNS", 7, 145667},
	{"CHANGSHA", 8, 145668},
	{"AMORTIZE", 8, 145669},
	{"SCHULZRINNE", 11, 145670},
	{"PAWSON", 6, 145671},
	{"KAKA", 4, 145672},
	{"ZZAC", 4, 145673},
	{"ZIEC", 4, 145674},
	{"YROF", 4, 145675},
	{"UMIE", 4, 145676},
	{"RBWA", 4, 145677},
	{"PMHA", 4, 145678},
	{"OVLE", 4, 145679},
	{"OKMH", 4, 145680},
	{"MBNE", 4, 145681},
	{"KIDP", 4, 145682},
	{"KBYJ", 4, 145683},
	{"IPVO", 4, 145684},
	{"EKPH", 4, 145685},
	{"DVDV", 4, 145686},
	{"DOXP", 4, 145687},
	{"ATWY", 4, 145688},
	{"ALYL", 4, 145689},
	{"HOLLOMAN", 8, 145690},
	{"CESIFO", 6, 145691},
	{"FASHIONABLY", 11, 145692},
	{"COELIAC", 7, 145693},
	{"CBJ", 3, 145694},
	{"STIPPLE", 7, 145695},
	{"WELBORN", 7, 145696},
	{"ZUNDEL", 6, 145697},
	{"VASCULATURE", 11, 145698},
	{"REXROTH", 7, 145699},
	{"POSEABLE", 8, 145700},
	{"BUNDCHEN", 8, 145701},
	{"VMTN", 4, 145702},
	{"BLACKALICIOUS", 13, 145703},
	{"VIRGINAL", 8, 145704},
	{"PHENOMENALLY", 12, 145705},
	{"IPFILTER", 8, 145706},
	{"GRATUI", 6, 145707},
	{"PESCADERO", 9, 145708},
	{"AUGUR", 5, 145709},
	{"LABORA", 6, 145710},
	{"RUNLEVEL", 8, 145711},
	{"COLONIZING", 10, 145712},
	{"RELL", 4, 145713},
	{"HYSSOP", 6, 145714},
	{"CONTEMPO", 8, 145715},
	{"KITING", 6, 145716},
	{"YANCY", 5, 145717},
	{"WCR", 3, 145718},
	{"MACEWAN", 7, 145719},
	{"MICKI", 5, 145720},
	{"SMURFIT", 7, 145721},
	{"VISTEK", 6, 145722},
	{"REPUTEDLY", 9, 145723},
	{"MODAFINIL", 9, 145724},
	{"HALFMOON", 8, 145725},
	{"SHANACHIE", 9, 145726},
	{"SCHLOCK", 7, 145727},
	{"MOONBASE", 8, 145728},
	{"SYMPTOMATOLOGY", 14, 145729},
	{"AITCHISON", 9, 145730},
	{"PARAKEETS", 9, 145731},
	{"ALEXANDROS", 10, 145732},
	{"BODLEIAN", 8, 145733},
	{"MIDAZOLAM", 9, 145734},
	{"TALLYING", 8, 145735},
	{"NARRATORS", 9, 145736},
	{"BODYGLOVE", 9, 145737},
	{"HOMEBUILDER", 11, 145738},
	{"LIGATURES", 9, 145739},
	{"COALESCING", 10, 145740},
	{"BILLFISH", 8, 145741},
	{"PARP", 4, 145742},
	{"HANSASTRASSE", 12, 145743},
	{"BICAMERAL", 9, 145744},
	{"YEGL", 4, 145745},
	{"YBBC", 4, 145746},
	{"WBUY", 4, 145747},
	{"TEXM", 4, 145748},
	{"RLEP", 4, 145749},
	{"NTDM", 4, 145750},
	{"IBAY", 4, 145751},
	{"EPUF", 4, 145752},
	{"EKJO", 4, 145753},
	{"DKRU", 4, 145754},
	{"CHAPEAU", 7, 145755},
	{"ETHERIC", 7, 145756},
	{"YURT", 4, 145757},
	{"CAWS", 4, 145758},
	{"GUYTON", 6, 145759},
	{"HRRZ", 4, 145760},
	{"HAKUBA", 6, 145761},
	{"KICKAPOO", 8, 145762},
	{"PARTIED", 7, 145763},
	{"PDSN", 4, 145764},
	{"TRAVELIN", 8, 145765},
	{"SIMPITS", 7, 145766},
	{"ALLSPORTS", 9, 145767},
	{"GOME", 4, 145768},
	{"DRAMATIZED", 10, 145769},
	{"COLEG", 5, 145770},
	{"OBNOXIOUSLY", 11, 145771},
	{"MOTES", 5, 145772},
	{"MICRONIZED", 10, 145773},
	{"BACKLOGS", 8, 145774},
	{"FIELDSTONE", 10, 145775},
	{"HELENSBURGH", 11, 145776},
	{"IDYLL", 5, 145777},
	{"BRINGETH", 8, 145778},
	{"OTTAWAY", 7, 145779},
	{"GIFTSTODRINK", 12, 145780},
	{"NANOCRYSTALS", 12, 145781},
	{"RAPOPORT", 8, 145782},
	{"PAQUET", 6, 145783},
	{"GRAP", 4, 145784},
	{"BTUS", 4, 145785},
	{"ASSURANT", 8, 145786},
	{"DATALOGGER", 10, 145787},
	{"ANESTH", 6, 145788},
	{"FARNAM", 6, 145789},
	{"REGLE", 5, 145790},
	{"BROOMSTICK", 10, 145791},
	{"THUY", 4, 145792},
	{"RABUN", 5, 145793},
	{"SUFFOCATED", 10, 145794},
	{"KOLO", 4, 145795},
	{"TOGP", 4, 145796},
	{"RPIZ", 4, 145797},
	{"RBWH", 4, 145798},
	{"PEZT", 4, 145799},
	{"OGEM", 4, 145800},
	{"FUTO", 4, 145801},
	{"FGEA", 4, 145802},
	{"EVIW", 4, 145803},
	{"EEXX", 4, 145804},
	{"DRNA", 4, 145805},
	{"MOTORCADE", 9, 145806},
	{"FEEDCOUNT", 9, 145807},
	{"BELUISTEREN", 11, 145808},
	{"LOBOTOMY", 8, 145809},
	{"BEFRIENDING", 11, 145810},
	{"XYZZY", 5, 145811},
	{"ANDRESS", 7, 145812},
	{"VRRP", 4, 145813},
	{"REMINDME", 8, 145814},
	{"VOULEZ", 6, 145815},
	{"SCOSCHE", 7, 145816},
	{"CONTIGS", 7, 145817},
	{"RCX", 3, 145818},
	{"SITESEARCH", 10, 145819},
	{"CTAGS", 5, 145820},
	{"FOLKMANIS", 9, 145821},
	{"OBTENER", 7, 145822},
	{"DORNIER", 7, 145823},
	{"DSPAM", 5, 145824},
	{"PROFESSIONNEL", 13, 145825},
	{"MARAUDING", 9, 145826},
	{"ECHNOLOGY", 9, 145827},
	{"CYNICALLY", 9, 145828},
	{"BIRKS", 5, 145829},
	{"ASSUAGE", 7, 145830},
	{"GEORGIOS", 8, 145831},
	{"ESTRANGEMENT", 12, 145832},
	{"MEDIAWORKS", 10, 145833},
	{"VERSICHERUNG", 12, 145834},
	{"RWX", 3, 145835},
	{"DENSETSU", 8, 145836},
	{"GESSNER", 7, 145837},
	{"RESTAURATION", 12, 145838},
	{"HANDCRAFT", 9, 145839},
	{"ASMARA", 6, 145840},
	{"LIMPED", 6, 145841},
	{"BERL", 4, 145842},
	{"KHARKIV", 7, 145843},
	{"PERIGNON", 8, 145844},
	{"NUMBERIC", 8, 145845},
	{"YEARNED", 7, 145846},
	{"AGATA", 5, 145847},
	{"FEEDLAST", 8, 145848},
	{"FONDEST", 7, 145849},
	{"VERKAUF", 7, 145850},
	{"PWLIB", 5, 145851},
	{"JOCURI", 6, 145852},
	{"BIZARRELY", 9, 145853},
	{"BIOASSAYS", 9, 145854},
	{"WYLI", 4, 145855},
	{"UKLU", 4, 145856},
	{"SKMY", 4, 145857},
	{"RRAE", 4, 145858},
	{"PZON", 4, 145859},
	{"OZLO", 4, 145860},
	{"OYDL", 4, 145861},
	{"OFHR", 4, 145862},
	{"MPAM", 4, 145863},
	{"LMCK", 4, 145864},
	{"IPCU", 4, 145865},
	{"HYAY", 4, 145866},
	{"HLYQ", 4, 145867},
	{"ALMN", 4, 145868},
	{"IRONDALE", 8, 145869},
	{"HESSTON", 7, 145870},
	{"WISCASSET", 9, 145871},
	{"PARCE", 5, 145872},
	{"LULING", 6, 145873},
	{"FRIGHTENS", 9, 145874},
	{"INCONTINENT", 11, 145875},
	{"AMANTE", 6, 145876},
	{"PERPETRATE", 10, 145877},
	{"UPCHURCH", 8, 145878},
	{"NORDICTRACK", 11, 145879},
	{"CHARMANE", 8, 145880},
	{"CHISAGO", 7, 145881},
	{"PARADA", 6, 145882},
	{"TALKEETNA", 9, 145883},
	{"BEHREND", 7, 145884},
	{"JEFFRYV", 7, 145885},
	{"TELOMERES", 9, 145886},
	{"JANNEY", 6, 145887},
	{"TRARALGON", 9, 145888},
	{"MASCHINE", 8, 145889},
	{"FRITS", 5, 145890},
	{"ESTILO", 6, 145891},
	{"VALVOLINE", 9, 145892},
	{"DASD", 4, 145893},
	{"NONCREDIT", 9, 145894},
	{"PETRE", 5, 145895},
	{"MOLESEY", 7, 145896},
	{"BIRMAN", 6, 145897},
	{"ARCHANGELS", 10, 145898},
	{"LAHIRI", 6, 145899},
	{"NOMBRES", 7, 145900},
	{"SERENDIPITOUS", 13, 145901},
	{"MIENTRAS", 8, 145902},
	{"FRANCESE", 8, 145903},
	{"STREETCARS", 10, 145904},
	{"IMEEM", 5, 145905},
	{"INMYHEART", 9, 145906},
	{"ANGABEN", 7, 145907},
	{"FIERCEST", 8, 145908},
	{"DEALCLICK", 9, 145909},
	{"COINING", 7, 145910},
	{"MACHINIMA", 9, 145911},
	{"ALTIMETRY", 9, 145912},
	{"CUENTAS", 7, 145913},
	{"KERNER", 6, 145914},
	{"BIOCHIMICA", 10, 145915},
	{"SUMMERFEST", 10, 145916},
	{"OFFUTT", 6, 145917},
	{"COMEBACKS", 9, 145918},
	{"OKINAWAN", 8, 145919},
	{"ZDIS", 4, 145920},
	{"UGOP", 4, 145921},
	{"SMGR", 4, 145922},
	{"PBON", 4, 145923},
	{"MPSN", 4, 145924},
	{"GNCE", 4, 145925},
	{"FIAW", 4, 145926},
	{"ACWE", 4, 145927},
	{"INVECTIVE", 9, 145928},
	{"CARTAS", 6, 145929},
	{"ERAGE", 5, 145930},
	{"SURJECTIVE", 10, 145931},
	{"MERISTEM", 8, 145932},
	{"INTERURBAN", 10, 145933},
	{"SEVIGNY", 7, 145934},
	{"TAILBACK", 8, 145935},
	{"PAYTV", 5, 145936},
	{"CLAUDICAM", 9, 145937},
	{"SULCUS", 6, 145938},
	{"LIBGLIB", 7, 145939},
	{"MEGAGAMES", 9, 145940},
	{"RILED", 5, 145941},
	{"ZANAX", 5, 145942},
	{"PINKHAM", 7, 145943},
	{"LITURGIES", 9, 145944},
	{"COMREG", 6, 145945},
	{"LIPSON", 6, 145946},
	{"CRESCAT", 7, 145947},
	{"MCCLOY", 6, 145948},
	{"ICHIKAWA", 8, 145949},
	{"DEMIAN", 6, 145950},
	{"FERTIL", 6, 145951},
	{"TOURO", 5, 145952},
	{"CABELAS", 7, 145953},
	{"COMPUTABILITY", 13, 145954},
	{"SUEUR", 5, 145955},
	{"ZVAH", 4, 145956},
	{"ZOOC", 4, 145957},
	{"WIMO", 4, 145958},
	{"WHUR", 4, 145959},
	{"UMRU", 4, 145960},
	{"TYIW", 4, 145961},
	{"SSMR", 4, 145962},
	{"SOUC", 4, 145963},
	{"PYAL", 4, 145964},
	{"POCE", 4, 145965},
	{"NNYU", 4, 145966},
	{"NLWE", 4, 145967},
	{"NFEU", 4, 145968},
	{"LGUR", 4, 145969},
	{"KUTC", 4, 145970},
	{"IVEX", 4, 145971},
	{"IVAK", 4, 145972},
	{"ESYU", 4, 145973},
	{"DOQU", 4, 145974},
	{"CCWI", 4, 145975},
	{"AUVO", 4, 145976},
	{"ABFA", 4, 145977},
	{"SATTERFIELD", 11, 145978},
	{"ASHCRAFT", 8, 145979},
	{"FENTRESS", 8, 145980},
	{"PHILIPINES", 10, 145981},
	{"IBBOTSON", 8, 145982},
	{"FLEXES", 6, 145983},
	{"ENCAP", 5, 145984},
	{"DEPOSE", 6, 145985},
	{"PACIFY", 6, 145986},
	{"WEATHERALL", 10, 145987},
	{"WINSTEAD", 8, 145988},
	{"CAROTENOID", 10, 145989},
	{"PROLIFERATED", 12, 145990},
	{"THATCHAM", 8, 145991},
	{"FAVORIS", 7, 145992},
	{"TAGOUT", 6, 145993},
	{"SUNDER", 6, 145994},
	{"CORPOR", 6, 145995},
	{"SEMIDEFINITE", 12, 145996},
	{"BALLESTEROS", 11, 145997},
	{"DENYTOPICCHANGE", 15, 145998},
	{"SELLIN", 6, 145999},
	{"AYCAN", 5, 146000},
	{"RESCO", 5, 146001},
	{"TATTERSALL", 10, 146002},
	{"EXCOMMUNICATION", 15, 146003},
	{"SUNKIST", 7, 146004},
	{"POTTAWATOMIE", 12, 146005},
	{"REPUBLISHING", 12, 146006},
	{"CRISTIANOS", 10, 146007},
	{"YIFP", 4, 146008},
	{"USIW", 4, 146009},
	{"UMOW", 4, 146010},
	{"UKOW", 4, 146011},
	{"LPHD", 4, 146012},
	{"LCOG", 4, 146013},
	{"KEOC", 4, 146014},
	{"HALQ", 4, 146015},
	{"GGUR", 4, 146016},
	{"FBYM", 4, 146017},
	{"DSEF", 4, 146018},
	{"BDAV", 4, 146019},
	{"JAYNES", 6, 146020},
	{"SCONS", 5, 146021},
	{"LOWMAN", 6, 146022},
	{"MUSHCLIENT", 10, 146023},
	{"GRIZZLED", 8, 146024},
	{"KHUYEN", 6, 146025},
	{"INANCIAL", 8, 146026},
	{"MONOSPACED", 10, 146027},
	{"NORTHWIND", 9, 146028},
	{"WOODLINE", 8, 146029},
	{"LADE", 4, 146030},
	{"RECARO", 6, 146031},
	{"MODPERL", 7, 146032},
	{"EDITIO", 6, 146033},
	{"BUBU", 4, 146034},
	{"BUFSIZE", 7, 146035},
	{"SOBOL", 5, 146036},
	{"PACEY", 5, 146037},
	{"UTAMA", 5, 146038},
	{"CABALLO", 7, 146039},
	{"VODKAS", 6, 146040},
	{"GLITTERATI", 10, 146041},
	{"LOATHED", 7, 146042},
	{"BRZEZINSKI", 10, 146043},
	{"FLORID", 6, 146044},
	{"FATALISM", 8, 146045},
	{"AVIC", 4, 146046},
	{"STOPWATCHES", 11, 146047},
	{"MYERSCOUGH", 10, 146048},
	{"SHEPPERTON", 10, 146049},
	{"DAGESTAN", 8, 146050},
	{"SAAVEDRA", 8, 146051},
	{"MATTEI", 6, 146052},
	{"COMMENTOR", 9, 146053},
	{"BETWEENS", 8, 146054},
	{"SOUDER", 6, 146055},
	{"GAZILLION", 9, 146056},
	{"WEIRDOS", 7, 146057},
	{"GRANULOCYTES", 12, 146058},
	{"TRUITT", 6, 146059},
	{"TOXOID", 6, 146060},
	{"PHOTOGRAPHICAL", 14, 146061},
	{"MINKUS", 6, 146062},
	{"YOUNT", 5, 146063},
	{"VSYNC", 5, 146064},
	{"DESPISES", 8, 146065},
	{"ESTEVEZ", 7, 146066},
	{"EXTINGUISHMENT", 14, 146067},
	{"AVENEL", 6, 146068},
	{"TCOM", 4, 146069},
	{"YGEE", 4, 146070},
	{"YDNA", 4, 146071},
	{"UDRU", 4, 146072},
	{"PUBC", 4, 146073},
	{"OUXA", 4, 146074},
	{"OFBN", 4, 146075},
	{"OBGA", 4, 146076},
	{"HLUT", 4, 146077},
	{"GOPM", 4, 146078},
	{"EPKE", 4, 146079},
	{"CYSS", 4, 146080},
	{"CIOD", 4, 146081},
	{"BWAL", 4, 146082},
	{"ABSM", 4, 146083},
	{"HANDBASE", 8, 146084},
	{"DECONGESTANTS", 13, 146085},
	{"ESQUIVEL", 8, 146086},
	{"MAGADAN", 7, 146087},
	{"JOUSTING", 8, 146088},
	{"CHANTER", 7, 146089},
	{"MAHALO", 6, 146090},
	{"SECURECODE", 10, 146091},
	{"QUACKS", 6, 146092},
	{"ROQUEFORT", 9, 146093},
	{"POLYSILICON", 11, 146094},
	{"PINPOINTS", 9, 146095},
	{"KYRIE", 5, 146096},
	{"ARME", 4, 146097},
	{"LEBRUN", 6, 146098},
	{"BERTONE", 7, 146099},
	{"HPRD", 4, 146100},
	{"FERRULES", 8, 146101},
	{"GERMANO", 7, 146102},
	{"MACDONALDS", 10, 146103},
	{"BLEECKER", 8, 146104},
	{"WEND", 4, 146105},
	{"NONUNION", 8, 146106},
	{"STARBASE", 8, 146107},
	{"HILLARD", 7, 146108},
	{"FLEXTRA", 7, 146109},
	{"BELDING", 7, 146110},
	{"TUKEY", 5, 146111},
	{"CHLORDANE", 9, 146112},
	{"GLUCOSIDASE", 11, 146113},
	{"CHEBYSHEV", 9, 146114},
	{"SMALLBIZ", 8, 146115},
	{"HANKE", 5, 146116},
	{"STERIC", 6, 146117},
	{"DIRECTIONALITY", 14, 146118},
	{"BLACKEST", 8, 146119},
	{"REIHE", 5, 146120},
	{"FUHRMAN", 7, 146121},
	{"DURABOLIN", 9, 146122},
	{"PAGELIST", 8, 146123},
	{"VNODE", 5, 146124},
	{"SHEPTON", 7, 146125},
	{"SECURID", 7, 146126},
	{"ROUBLES", 7, 146127},
	{"ULUH", 4, 146128},
	{"TDEU", 4, 146129},
	{"RYAY", 4, 146130},
	{"PUBT", 4, 146131},
	{"PBAD", 4, 146132},
	{"OBAU", 4, 146133},
	{"NLAZ", 4, 146134},
	{"KYGO", 4, 146135},
	{"HEJM", 4, 146136},
	{"GRUR", 4, 146137},
	{"FSGT", 4, 146138},
	{"EPMF", 4, 146139},
	{"EJMA", 4, 146140},
	{"CATHODES", 8, 146141},
	{"RELENTED", 8, 146142},
	{"MEINUNG", 7, 146143},
	{"SABOR", 5, 146144},
	{"CAVERSHAM", 9, 146145},
	{"RIDGELY", 7, 146146},
	{"MAHAR", 5, 146147},
	{"LINKTITLE", 9, 146148},
	{"GAMESS", 6, 146149},
	{"PRICEWATCH", 10, 146150},
	{"SOCCERWAY", 9, 146151},
	{"BRUNDAGE", 8, 146152},
	{"ARCHY", 5, 146153},
	{"DOMESDAY", 8, 146154},
	{"CHRISTMAN", 9, 146155},
	{"HEARTLANDS", 10, 146156},
	{"BLUPLUSPLUS", 11, 146157},
	{"TREKKERS", 8, 146158},
	{"MUDSTONE", 8, 146159},
	{"JMR", 3, 146160},
	{"BUDDAH", 6, 146161},
	{"UNBLOCKED", 9, 146162},
	{"FRANTISEK", 9, 146163},
	{"KIMMIE", 6, 146164},
	{"FONTSLANT", 9, 146165},
	{"MCGLYNN", 7, 146166},
	{"SOLDERS", 7, 146167},
	{"BINKY", 5, 146168},
	{"VEERS", 5, 146169},
	{"INVALIDATES", 11, 146170},
	{"CATENA", 6, 146171},
	{"NETTLETON", 9, 146172},
	{"ROBBE", 5, 146173},
	{"MAHENDRA", 8, 146174},
	{"VABO", 4, 146175},
	{"SMYJ", 4, 146176},
	{"ORCC", 4, 146177},
	{"NUBU", 4, 146178},
	{"MRFE", 4, 146179},
	{"MMCD", 4, 146180},
	{"LKDE", 4, 146181},
	{"FAZI", 4, 146182},
	{"APOG", 4, 146183},
	{"PERIODO", 7, 146184},
	{"COLLEGEHUMOR", 12, 146185},
	{"PRECARIOUSLY", 12, 146186},
	{"KAZIMIERZ", 9, 146187},
	{"USHIO", 5, 146188},
	{"SORELL", 6, 146189},
	{"NURNBERG", 8, 146190},
	{"FORCAST", 7, 146191},
	{"DAKOTAS", 7, 146192},
	{"HUBCAP", 6, 146193},
	{"SCHIZOID", 8, 146194},
	{"TARRED", 6, 146195},
	{"MORDRED", 7, 146196},
	{"EJNL", 4, 146197},
	{"DAPAT", 5, 146198},
	{"MADELYN", 7, 146199},
	{"LAWFULNESS", 10, 146200},
	{"DDK", 3, 146201},
	{"MAJOSKA", 7, 146202},
	{"TINCIDUNT", 9, 146203},
	{"THERMOFORMING", 13, 146204},
	{"JURLIQUE", 8, 146205},
	{"BEGET", 5, 146206},
	{"RECTILINEAR", 11, 146207},
	{"CICLO", 5, 146208},
	{"MUTAGEN", 7, 146209},
	{"BANDEAU", 7, 146210},
	{"TOLLESON", 8, 146211},
	{"BATANGAS", 8, 146212},
	{"LACTAM", 6, 146213},
	{"JOLEE", 5, 146214},
	{"TINACAM", 7, 146215},
	{"WEINMAN", 7, 146216},
	{"PHYSICALITY", 11, 146217},
	{"YAKOVLEV", 8, 146218},
	{"COMBINATIONAL", 13, 146219},
	{"VERSI", 5, 146220},
	{"YUVAL", 5, 146221},
	{"SMIME", 5, 146222},
	{"HURENFORUM", 10, 146223},
	{"GIJOE", 5, 146224},
	{"WEBLOGGER", 9, 146225},
	{"ONITSUKA", 8, 146226},
	{"MUSSELBURGH", 11, 146227},
	{"CSTR", 4, 146228},
	{"WEYA", 4, 146229},
	{"SOXG", 4, 146230},
	{"RZAM", 4, 146231},
	{"ROUW", 4, 146232},
	{"ONFC", 4, 146233},
	{"OEMF", 4, 146234},
	{"MYSR", 4, 146235},
	{"IKAY", 4, 146236},
	{"IDYT", 4, 146237},
	{"GFAB", 4, 146238},
	{"FALY", 4, 146239},
	{"EPKI", 4, 146240},
	{"KOONS", 5, 146241},
	{"SOLUZIONI", 9, 146242},
	{"ANTIPLATELET", 12, 146243},
	{"STENOGRAPHER", 12, 146244},
	{"NACHTLEBEN", 10, 146245},
	{"BIORHYTHM", 9, 146246},
	{"RENTERIA", 8, 146247},
	{"NIPPED", 6, 146248},
	{"DISGUISING", 10, 146249},
	{"INVULNERABLE", 12, 146250},
	{"GOODGER", 7, 146251},
	{"ARCHEOLOGIST", 12, 146252},
	{"REFINISHED", 10, 146253},
	{"FLICKERED", 9, 146254},
	{"CYNWYD", 6, 146255},
	{"DEHAI", 5, 146256},
	{"VSAM", 4, 146257},
	{"BIGTITTS", 8, 146258},
	{"PLAGIARIZED", 11, 146259},
	{"WOUTERS", 7, 146260},
	{"NEOFORMANS", 10, 146261},
	{"ISSUERINFO", 10, 146262},
	{"BABYSIT", 7, 146263},
	{"SEBACEOUS", 9, 146264},
	{"MORS", 4, 146265},
	{"DENSON", 6, 146266},
	{"DIWAN", 5, 146267},
	{"SHADOWLANDS", 11, 146268},
	{"VASODILATION", 12, 146269},
	{"MUTATING", 8, 146270},
	{"BREDESEN", 8, 146271},
	{"PHILIDOR", 8, 146272},
	{"MAAK", 4, 146273},
	{"LUCISTNIK", 9, 146274},
	{"FARINGDON", 9, 146275},
	{"FEMINA", 6, 146276},
	{"HYPERSPECTRAL", 13, 146277},
	{"SIROCCO", 7, 146278},
	{"QUIERE", 6, 146279},
	{"ANTENNACABLEPLUG", 16, 146280},
	{"GEOCENTRIC", 10, 146281},
	{"ANKERBERG", 9, 146282},
	{"YNBC", 4, 146283},
	{"YAZI", 4, 146284},
	{"UYNO", 4, 146285},
	{"ULOM", 4, 146286},
	{"PBYW", 4, 146287},
	{"NMIM", 4, 146288},
	{"LEMK", 4, 146289},
	{"KWET", 4, 146290},
	{"IYAP", 4, 146291},
	{"FTYN", 4, 146292},
	{"FLTO", 4, 146293},
	{"CYTI", 4, 146294},
	{"CHKU", 4, 146295},
	{"AWBL", 4, 146296},
	{"KUMMER", 6, 146297},
	{"RESTAURANTES", 12, 146298},
	{"SYLLABUSES", 10, 146299},
	{"OPCW", 4, 146300},
	{"BOOKWORMS", 9, 146301},
	{"IVANOVA", 7, 146302},
	{"ABSORBABLE", 10, 146303},
	{"SHOWGROUND", 10, 146304},
	{"LEBEDEV", 7, 146305},
	{"ANIMATRIX", 9, 146306},
	{"WARRANTING", 10, 146307},
	{"RRM", 3, 146308},
	{"HITLIST", 7, 146309},
	{"SUBSTRINGS", 10, 146310},
	{"DANIDA", 6, 146311},
	{"HARDCODE", 8, 146312},
	{"DODI", 4, 146313},
	{"GOOOGLE", 7, 146314},
	{"THREADER", 8, 146315},
	{"NAQADA", 6, 146316},
	{"GLOVEBOX", 8, 146317},
	{"RHEUMATOL", 9, 146318},
	{"EOWYN", 5, 146319},
	{"SURIN", 5, 146320},
	{"GWENOLE", 7, 146321},
	{"MULTAN", 6, 146322},
	{"WEBSTATS", 8, 146323},
	{"SPECIALISATIONS", 15, 146324},
	{"TEACUPS", 7, 146325},
	{"EUERIE", 6, 146326},
	{"KUMBLE", 6, 146327},
	{"STREAMSIDE", 10, 146328},
	{"UNDERNET", 8, 146329},
	{"ECSC", 4, 146330},
	{"SHYAMALAN", 9, 146331},
	{"HIDEOUSLY", 9, 146332},
	{"KERFUFFLE", 9, 146333},
	{"MYCOBACTERIAL", 13, 146334},
	{"HALFLING", 8, 146335},
	{"RECIEPT", 7, 146336},
	{"CROKE", 5, 146337},
	{"NAOKI", 5, 146338},
	{"YEHU", 4, 146339},
	{"UACI", 4, 146340},
	{"TDUL", 4, 146341},
	{"SMDU", 4, 146342},
	{"SIMW", 4, 146343},
	{"ROBW", 4, 146344},
	{"RJUV", 4, 146345},
	{"LECB", 4, 146346},
	{"IGEC", 4, 146347},
	{"GLUS", 4, 146348},
	{"GKRA", 4, 146349},
	{"FUPO", 4, 146350},
	{"EFUP", 4, 146351},
	{"DGOG", 4, 146352},
	{"DOERR", 5, 146353},
	{"WITTMAN", 7, 146354},
	{"SPORTZWEAR", 10, 146355},
	{"BERKE", 5, 146356},
	{"BRAVERMAN", 9, 146357},
	{"ISOTHERM", 8, 146358},
	{"MOTHERLY", 8, 146359},
	{"SOLVEIG", 7, 146360},
	{"INSPIRAL", 8, 146361},
	{"BULWER", 6, 146362},
	{"VERBOTENER", 10, 146363},
	{"MODELE", 6, 146364},
	{"KIDDICARE", 9, 146365},
	{"ELUM", 4, 146366},
	{"RETICULAR", 9, 146367},
	{"RODAN", 5, 146368},
	{"CRUZE", 5, 146369},
	{"BENY", 4, 146370},
	{"BIGROCKMEDIA", 12, 146371},
	{"MEFI", 4, 146372},
	{"PAGEREGION", 10, 146373},
	{"KRU", 3, 146374},
	{"SAVANNAS", 8, 146375},
	{"NUDGING", 7, 146376},
	{"BLINDER", 7, 146377},
	{"PINETOP", 7, 146378},
	{"WISPY", 5, 146379},
	{"CUPHOLDERS", 10, 146380},
	{"BORDERLAND", 10, 146381},
	{"WEBSOLARIUM", 11, 146382},
	{"SUBTITULOS", 10, 146383},
	{"FELICIANA", 9, 146384},
	{"CHUMASH", 7, 146385},
	{"KLIC", 4, 146386},
	{"GNARLY", 6, 146387},
	{"BOONDOCK", 8, 146388},
	{"PROPOXYPHENE", 12, 146389},
	{"BILLOWING", 9, 146390},
	{"MATHE", 5, 146391},
	{"VEXATIOUS", 9, 146392},
	{"RECAPITALIZATION", 16, 146393},
	{"INCHEON", 7, 146394},
	{"COACHMEN", 8, 146395},
	{"ALMO", 4, 146396},
	{"GIRLISH", 7, 146397},
	{"TORG", 4, 146398},
	{"VEXP", 4, 146399},
	{"UYUA", 4, 146400},
	{"PODW", 4, 146401},
	{"OXBA", 4, 146402},
	{"NULE", 4, 146403},
	{"LEBB", 4, 146404},
	{"HOLG", 4, 146405},
	{"HEPV", 4, 146406},
	{"FDYI", 4, 146407},
	{"EZLA", 4, 146408},
	{"DXBO", 4, 146409},
	{"DGIO", 4, 146410},
	{"CNNM", 4, 146411},
	{"BIPE", 4, 146412},
	{"MILLEFIORI", 10, 146413},
	{"MASUOKA", 7, 146414},
	{"WORSTALL", 8, 146415},
	{"INURE", 5, 146416},
	{"KORUNY", 6, 146417},
	{"SWALLOWERS", 10, 146418},
	{"NGUY", 4, 146419},
	{"HEUVEL", 6, 146420},
	{"WOOLWORTH", 9, 146421},
	{"SHIVELY", 7, 146422},
	{"ADEQ", 4, 146423},
	{"LATTES", 6, 146424},
	{"NICOLAE", 7, 146425},
	{"DATACOMM", 8, 146426},
	{"ATOMIZER", 8, 146427},
	{"REDDENING", 9, 146428},
	{"DEVOLO", 6, 146429},
	{"PACHISLO", 8, 146430},
	{"ENCORES", 7, 146431},
	{"AVANZATA", 8, 146432},
	{"SOCIOBIOLOGY", 12, 146433},
	{"SARC", 4, 146434},
	{"SUNDAR", 6, 146435},
	{"ATTENTIVENESS", 13, 146436},
	{"MANSONI", 7, 146437},
	{"FOREMEN", 7, 146438},
	{"GIDP", 4, 146439},
	{"RIDEOUT", 7, 146440},
	{"AGNIESZKA", 9, 146441},
	{"RHETORICALLY", 12, 146442},
	{"NEUROPSYCHIATRY", 15, 146443},
	{"SOLARIUMBILDER", 14, 146444},
	{"NRMA", 4, 146445},
	{"NNUAL", 5, 146446},
	{"TATSUYA", 7, 146447},
	{"KANAMYCIN", 9, 146448},
	{"PREMIX", 6, 146449},
	{"VASOACTIVE", 10, 146450},
	{"ITWEB", 5, 146451},
	{"CESR", 4, 146452},
	{"NEWSLETTERSNEWSLETTERS", 22, 146453},
	{"OSCON", 5, 146454},
	{"VINCENTE", 8, 146455},
	{"BOTRYTIS", 8, 146456},
	{"BENITA", 6, 146457},
	{"RANCHOS", 7, 146458},
	{"KARRIMOR", 8, 146459},
	{"CATALIN", 7, 146460},
	{"DAINESE", 7, 146461},
	{"PREGNENT", 8, 146462},
	{"WUSH", 4, 146463},
	{"VYFR", 4, 146464},
	{"URUH", 4, 146465},
	{"ORBN", 4, 146466},
	{"OFSD", 4, 146467},
	{"NJEL", 4, 146468},
	{"NEUL", 4, 146469},
	{"JEWA", 4, 146470},
	{"FURE", 4, 146471},
	{"FMEW", 4, 146472},
	{"DDRJ", 4, 146473},
	{"CUNC", 4, 146474},
	{"BREB", 4, 146475},
	{"BIMB", 4, 146476},
	{"AXOB", 4, 146477},
	{"UPSTANDING", 10, 146478},
	{"LILIUM", 6, 146479},
	{"RHUS", 4, 146480},
	{"RAMCOMPONENTS", 13, 146481},
	{"IMMI", 4, 146482},
	{"KASHAN", 6, 146483},
	{"YEARLINGS", 9, 146484},
	{"TRIFOLIUM", 9, 146485},
	{"GOLDENPALACE", 12, 146486},
	{"BONEHEAD", 8, 146487},
	{"ASSIGNEES", 9, 146488},
	{"KRAV", 4, 146489},
	{"SHAMEFULLY", 10, 146490},
	{"MONOPODS", 8, 146491},
	{"MAISY", 5, 146492},
	{"MCCREADY", 8, 146493},
	{"HERCULEAN", 9, 146494},
	{"DRYAD", 5, 146495},
	{"LEGISLATIVELY", 13, 146496},
	{"TORMENTING", 10, 146497},
	{"LUL", 3, 146498},
	{"KRULL", 5, 146499},
	{"COBIT", 5, 146500},
	{"GROKLAW", 7, 146501},
	{"PHOTOSETS", 9, 146502},
	{"LINKE", 5, 146503},
	{"ALLOWTOPICRENAME", 16, 146504},
	{"ATERM", 5, 146505},
	{"KESSINGER", 9, 146506},
	{"CARTYOUR", 8, 146507},
	{"CORPORATI", 9, 146508},
	{"DISINTEREST", 11, 146509},
	{"OFFSIDES", 8, 146510},
	{"UNEXAMINED", 10, 146511},
	{"SMDS", 4, 146512},
	{"OLIGOMERIC", 10, 146513},
	{"NEWSTEXT", 8, 146514},
	{"BAYLE", 5, 146515},
	{"PERFILS", 7, 146516},
	{"CONCESSIONAIRE", 14, 146517},
	{"VDSE", 4, 146518},
	{"TUSJ", 4, 146519},
	{"TUEP", 4, 146520},
	{"RLWO", 4, 146521},
	{"OECU", 4, 146522},
	{"MFLU", 4, 146523},
	{"LRYH", 4, 146524},
	{"GULY", 4, 146525},
	{"FFVA", 4, 146526},
	{"EPOG", 4, 146527},
	{"EGEJ", 4, 146528},
	{"EDDV", 4, 146529},
	{"EAFM", 4, 146530},
	{"CSDR", 4, 146531},
	{"ACFL", 4, 146532},
	{"SUBFORM", 7, 146533},
	{"SCHLESSINGER", 12, 146534},
	{"PLEURA", 6, 146535},
	{"DEFOLIATION", 11, 146536},
	{"BRAGGED", 7, 146537},
	{"RUBIDIUM", 8, 146538},
	{"PESTER", 6, 146539},
	{"BORDSTEINSCHWALBEN", 18, 146540},
	{"THROMBOLYSIS", 12, 146541},
	{"SHISHA", 6, 146542},
	{"LWD", 3, 146543},
	{"DEPUTATION", 10, 146544},
	{"PRETORIUS", 9, 146545},
	{"FMM", 3, 146546},
	{"GWEITHREDU", 10, 146547},
	{"BYR", 3, 146548},
	{"GNULIB", 6, 146549},
	{"OPPRESSING", 10, 146550},
	{"GETLINE", 7, 146551},
	{"BIRON", 5, 146552},
	{"UNCW", 4, 146553},
	{"MARFAN", 6, 146554},
	{"PROMOZIONE", 10, 146555},
	{"BELFORT", 7, 146556},
	{"MILLWARD", 8, 146557},
	{"NUCLEOLUS", 9, 146558},
	{"TIMELYWEB", 9, 146559},
	{"SOLVATION", 9, 146560},
	{"CLX", 3, 146561},
	{"KDDI", 4, 146562},
	{"DAPS", 4, 146563},
	{"SAGARIN", 7, 146564},
	{"YNIL", 4, 146565},
	{"WLSP", 4, 146566},
	{"VRIC", 4, 146567},
	{"TZWE", 4, 146568},
	{"SUWO", 4, 146569},
	{"RGHM", 4, 146570},
	{"RETJ", 4, 146571},
	{"QIAR", 4, 146572},
	{"PADC", 4, 146573},
	{"OXME", 4, 146574},
	{"OFSF", 4, 146575},
	{"KYOH", 4, 146576},
	{"GIPH", 4, 146577},
	{"GDIM", 4, 146578},
	{"EVWI", 4, 146579},
	{"EDPY", 4, 146580},
	{"CYSM", 4, 146581},
	{"WISHY", 5, 146582},
	{"BERARDI", 7, 146583},
	{"ROSEBANK", 8, 146584},
	{"TIMBALAND", 9, 146585},
	{"SNUGGLY", 7, 146586},
	{"FENCER", 6, 146587},
	{"DETRICK", 7, 146588},
	{"JAYALLEN", 8, 146589},
	{"TRIUNE", 6, 146590},
	{"SLACKLINING", 11, 146591},
	{"ANTERIORES", 10, 146592},
	{"HAIRDO", 6, 146593},
	{"UNDRESSES", 9, 146594},
	{"DOMINEERING", 11, 146595},
	{"CHINES", 6, 146596},
	{"MINERALISATION", 14, 146597},
	{"TRADUZIONE", 10, 146598},
	{"ONELOOK", 7, 146599},
	{"NEPHILIM", 8, 146600},
	{"CABLECARD", 9, 146601},
	{"METEOSAT", 8, 146602},
	{"ESCRITORIO", 10, 146603},
	{"TERMI", 5, 146604},
	{"SHUNTS", 6, 146605},
	{"DUGGER", 6, 146606},
	{"CANSECO", 7, 146607},
	{"HAWICK", 6, 146608},
	{"VIEDO", 5, 146609},
	{"OSSIG", 5, 146610},
	{"CLASSWORK", 9, 146611},
	{"ELFTOWN", 7, 146612},
	{"ATTENDER", 8, 146613},
	{"LYSATOR", 7, 146614},
	{"ALBER", 5, 146615},
	{"PROFFESIONAL", 12, 146616},
	{"FRUTTI", 6, 146617},
	{"ALCHOHOL", 8, 146618},
	{"TEENFICK", 8, 146619},
	{"FROBENIUS", 9, 146620},
	{"NEKKID", 6, 146621},
	{"BRIEL", 5, 146622},
	{"RIDDLER", 7, 146623},
	{"UNIVERSITAIRES", 14, 146624},
	{"MECA", 4, 146625},
	{"ZARW", 4, 146626},
	{"YSMS", 4, 146627},
	{"YAJI", 4, 146628},
	{"WEIC", 4, 146629},
	{"UUMO", 4, 146630},
	{"USHJ", 4, 146631},
	{"UMBW", 4, 146632},
	{"SOGY", 4, 146633},
	{"OAKG", 4, 146634},
	{"LOUM", 4, 146635},
	{"LGIO", 4, 146636},
	{"LCUI", 4, 146637},
	{"KDOR", 4, 146638},
	{"JAYP", 4, 146639},
	{"IVAG", 4, 146640},
	{"IFTV", 4, 146641},
	{"IBAW", 4, 146642},
	{"GICV", 4, 146643},
	{"GGAB", 4, 146644},
	{"ERIX", 4, 146645},
	{"EEWW", 4, 146646},
	{"DMVP", 4, 146647},
	{"ADZO", 4, 146648},
	{"ABITIBI", 7, 146649},
	{"TRACKABLE", 9, 146650},
	{"INDUCT", 6, 146651},
	{"FACCIALE", 8, 146652},
	{"CONNECTIVES", 11, 146653},
	{"EOSINOPHILIC", 12, 146654},
	{"BUSENFICK", 9, 146655},
	{"STAAL", 5, 146656},
	{"BINK", 4, 146657},
	{"SAWYERS", 7, 146658},
	{"CHIRALITY", 9, 146659},
	{"MARLAND", 7, 146660},
	{"CANNELL", 7, 146661},
	{"KUMA", 4, 146662},
	{"OBTRUSIVE", 9, 146663},
	{"XSCAPE", 6, 146664},
	{"PARADIGMATIC", 12, 146665},
	{"JROTC", 5, 146666},
	{"NCQA", 4, 146667},
	{"MACGILLIVRAY", 12, 146668},
	{"UNCONTAMINATED", 14, 146669},
	{"FGETC", 5, 146670},
	{"HALFPIPE", 8, 146671},
	{"ROADWIRED", 9, 146672},
	{"WAYMAN", 6, 146673},
	{"MOKENA", 6, 146674},
	{"BURD", 4, 146675},
	{"BELCHERTOWN", 11, 146676},
	{"PROTEOGLYCANS", 13, 146677},
	{"FREESOLARIUMCAM", 15, 146678},
	{"DISTIN", 6, 146679},
	{"PONTA", 5, 146680},
	{"TRULLI", 6, 146681},
	{"WRINKLING", 9, 146682},
	{"BLOOMIN", 7, 146683},
	{"WIJNEN", 6, 146684},
	{"WIRY", 4, 146685},
	{"NIGMS", 5, 146686},
	{"HARRIES", 7, 146687},
	{"GRANITES", 8, 146688},
	{"ZERU", 4, 146689},
	{"YNRE", 4, 146690},
	{"XNAR", 4, 146691},
	{"XIEL", 4, 146692},
	{"VREL", 4, 146693},
	{"VPIN", 4, 146694},
	{"TCIG", 4, 146695},
	{"STUG", 4, 146696},
	{"SJRA", 4, 146697},
	{"OXAC", 4, 146698},
	{"OGUC", 4, 146699},
	{"LONV", 4, 146700},
	{"JAWD", 4, 146701},
	{"HKLI", 4, 146702},
	{"FSUT", 4, 146703},
	{"FONW", 4, 146704},
	{"EJPM", 4, 146705},
	{"DIFD", 4, 146706},
	{"APHP", 4, 146707},
	{"AELU", 4, 146708},
	{"TILLIS", 6, 146709},
	{"QUIMPER", 7, 146710},
	{"ARMBANDS", 8, 146711},
	{"WESTLOCK", 8, 146712},
	{"TOKUSHIMA", 9, 146713},
	{"TARANTELLA", 10, 146714},
	{"LABYRINTHS", 10, 146715},
	{"OCCU", 4, 146716},
	{"RAUF", 4, 146717},
	{"LIDER", 5, 146718},
	{"DAYLIGHTS", 9, 146719},
	{"TBOX", 4, 146720},
	{"NCIX", 4, 146721},
	{"MENIERE", 7, 146722},
	{"GONDII", 6, 146723},
	{"ELOUNDA", 7, 146724},
	{"CONVO", 5, 146725},
	{"VOLARE", 6, 146726},
	{"SKIDDING", 8, 146727},
	{"KONTRABAND", 10, 146728},
	{"CHERRYWOOD", 10, 146729},
	{"KARIBA", 6, 146730},
	{"MARQUETRY", 9, 146731},
	{"JEALOUSLY", 9, 146732},
	{"GILI", 4, 146733},
	{"CGTALK", 6, 146734},
	{"LEFLORE", 7, 146735},
	{"GETOBJECT", 9, 146736},
	{"DATALOGIC", 9, 146737},
	{"PODGEAR", 7, 146738},
	{"HAHNEL", 6, 146739},
	{"FRENCHY", 7, 146740},
	{"HEMORRHOID", 10, 146741},
	{"BEARE", 5, 146742},
	{"WELCHES", 7, 146743},
	{"TENCE", 5, 146744},
	{"SEDIMENTOLOGY", 13, 146745},
	{"ARDF", 4, 146746},
	{"USEAGE", 6, 146747},
	{"BORENSTEIN", 10, 146748},
	{"FOOTMAN", 7, 146749},
	{"STYLISED", 8, 146750},
	{"GRANTA", 6, 146751},
	{"GURANTEED", 9, 146752},
	{"LORY", 4, 146753},
	{"DOMU", 4, 146754},
	{"TAILERS", 7, 146755},
	{"CAMERE", 6, 146756},
	{"JUNIUS", 6, 146757},
	{"FRAKES", 6, 146758},
	{"SADDLER", 7, 146759},
	{"PENSE", 5, 146760},
	{"OPTIONED", 8, 146761},
	{"DYNEIN", 6, 146762},
	{"AQUAT", 5, 146763},
	{"ZZAF", 4, 146764},
	{"XTHY", 4, 146765},
	{"XELE", 4, 146766},
	{"RAUX", 4, 146767},
	{"PUNL", 4, 146768},
	{"PTBR", 4, 146769},
	{"PLAD", 4, 146770},
	{"OOFK", 4, 146771},
	{"OCIF", 4, 146772},
	{"NUSY", 4, 146773},
	{"NKUB", 4, 146774},
	{"LPMY", 4, 146775},
	{"KIMK", 4, 146776},
	{"IFPU", 4, 146777},
	{"HDUA", 4, 146778},
	{"EIDG", 4, 146779},
	{"EDMT", 4, 146780},
	{"BJON", 4, 146781},
	{"AXER", 4, 146782},
	{"DALIBOR", 7, 146783},
	{"SOLLARIUM", 9, 146784},
	{"PREPPED", 7, 146785},
	{"CHAFE", 5, 146786},
	{"BOVE", 4, 146787},
	{"ALLOVER", 7, 146788},
	{"MANTEO", 6, 146789},
	{"MANGT", 5, 146790},
	{"SELINSGROVE", 11, 146791},
	{"WUSA", 4, 146792},
	{"PRESIDIUM", 9, 146793},
	{"TAPIS", 5, 146794},
	{"DOBKIN", 6, 146795},
	{"SCHOOLBOYS", 10, 146796},
	{"SPEACH", 6, 146797},
	{"ALEXANDRIAN", 11, 146798},
	{"LAFONT", 6, 146799},
	{"SINLESS", 7, 146800},
	{"BML", 3, 146801},
	{"DEARY", 5, 146802},
	{"MANCHE", 6, 146803},
	{"ILIAS", 5, 146804},
	{"KOHLS", 5, 146805},
	{"CONTENUTO", 9, 146806},
	{"NOBLY", 5, 146807},
	{"DEKA", 4, 146808},
	{"POPESCU", 7, 146809},
	{"MOULDER", 7, 146810},
	{"VACATURES", 9, 146811},
	{"ABSOLUTISM", 10, 146812},
	{"GUEPARD", 7, 146813},
	{"MIELKE", 6, 146814},
	{"MCCRARY", 7, 146815},
	{"UNIVERSALIS", 11, 146816},
	{"COMMUNAUTAIRE", 13, 146817},
	{"METAJY", 6, 146818},
	{"FUC", 3, 146819},
	{"ORAGE", 5, 146820},
	{"BRACTS", 6, 146821},
	{"YNAC", 4, 146822},
	{"WKEE", 4, 146823},
	{"WIIM", 4, 146824},
	{"UADP", 4, 146825},
	{"PMBU", 4, 146826},
	{"OWDD", 4, 146827},
	{"LLUJ", 4, 146828},
	{"LKEI", 4, 146829},
	{"LCUE", 4, 146830},
	{"ILMJ", 4, 146831},
	{"IAUR", 4, 146832},
	{"FVAM", 4, 146833},
	{"FDUP", 4, 146834},
	{"EOPU", 4, 146835},
	{"CPUL", 4, 146836},
	{"AZWA", 4, 146837},
	{"AFOG", 4, 146838},
	{"SCHWARZSCHILD", 13, 146839},
	{"DEVER", 5, 146840},
	{"ASTROMETRY", 10, 146841},
	{"PDNS", 4, 146842},
	{"APOYO", 5, 146843},
	{"ANAPHYLACTIC", 12, 146844},
	{"APPARATUSES", 11, 146845},
	{"BUNKO", 5, 146846},
	{"KOMA", 4, 146847},
	{"JIABAO", 6, 146848},
	{"HINXTON", 7, 146849},
	{"SHLOMI", 6, 146850},
	{"BALLROOMS", 9, 146851},
	{"TURTLENECKS", 11, 146852},
	{"MACARENA", 8, 146853},
	{"FLIRTATIOUS", 11, 146854},
	{"PARATHION", 9, 146855},
	{"ANNABELLA", 9, 146856},
	{"ELLENDALE", 9, 146857},
	{"ACOUST", 6, 146858},
	{"GAVI", 4, 146859},
	{"BDG", 3, 146860},
	{"LEONHARD", 8, 146861},
	{"EUROBASKET", 10, 146862},
	{"HAUSE", 5, 146863},
	{"VIDEOCAMERA", 11, 146864},
	{"TURA", 4, 146865},
	{"NRCAN", 5, 146866},
	{"MARFA", 5, 146867},
	{"STONELEIGH", 10, 146868},
	{"NOTEUP", 6, 146869},
	{"ULTRAMOBILE", 11, 146870},
	{"ANTIARRHYTHMIC", 14, 146871},
	{"YFIA", 4, 146872},
	{"WNOM", 4, 146873},
	{"SCHY", 4, 146874},
	{"RKUM", 4, 146875},
	{"JAWH", 4, 146876},
	{"IACY", 4, 146877},
	{"CMOO", 4, 146878},
	{"BTAR", 4, 146879},
	{"BCOI", 4, 146880},
	{"APDR", 4, 146881},
	{"POLYPOSIS", 9, 146882},
	{"ARCHITEKTUR", 11, 146883},
	{"GETATTRIBUTE", 12, 146884},
	{"FURORE", 6, 146885},
	{"CARMI", 5, 146886},
	{"DELIMIT", 7, 146887},
	{"LAVERGNE", 8, 146888},
	{"AUTOGEN", 7, 146889},
	{"FREEWHEELING", 12, 146890},
	{"GROSSER", 7, 146891},
	{"TERMPAPERS", 10, 146892},
	{"GUDRUN", 6, 146893},
	{"LAURO", 5, 146894},
	{"KHYPERMEDIA", 11, 146895},
	{"ADDTIONAL", 9, 146896},
	{"KEYENCE", 7, 146897},
	{"CRYBABY", 7, 146898},
	{"FIXIT", 5, 146899},
	{"CIVITAS", 7, 146900},
	{"BOLINAS", 7, 146901},
	{"MASCAGNI", 8, 146902},
	{"MEETINGPLACE", 12, 146903},
	{"SHARER", 6, 146904},
	{"MORTALITIES", 11, 146905},
	{"ZDRIVE", 6, 146906},
	{"AMASSING", 8, 146907},
	{"PERIHELION", 10, 146908},
	{"BIRK", 4, 146909},
	{"WILTING", 7, 146910},
	{"TOSFEATURES", 11, 146911},
	{"SUZANNA", 7, 146912},
	{"CAUDA", 5, 146913},
	{"ZUTANO", 6, 146914},
	{"THUNDERBALL", 11, 146915},
	{"ISNULL", 6, 146916},
	{"SYSPRO", 6, 146917},
	{"CONFIDENCES", 11, 146918},
	{"WAKEFULNESS", 11, 146919},
	{"DAMIR", 5, 146920},
	{"HAYAO", 5, 146921},
	{"ONIZUKA", 7, 146922},
	{"MILITARIZATION", 14, 146923},
	{"MONOPOLIZE", 10, 146924},
	{"DELVED", 6, 146925},
	{"ZASC", 4, 146926},
	{"YFIB", 4, 146927},
	{"URKU", 4, 146928},
	{"UIRO", 4, 146929},
	{"UHUR", 4, 146930},
	{"RHIZ", 4, 146931},
	{"RAGB", 4, 146932},
	{"NDIY", 4, 146933},
	{"NAPB", 4, 146934},
	{"IURA", 4, 146935},
	{"IFKE", 4, 146936},
	{"GOOC", 4, 146937},
	{"EEFB", 4, 146938},
	{"DJEE", 4, 146939},
	{"AZYR", 4, 146940},
	{"ADGL", 4, 146941},
	{"SKINT", 5, 146942},
	{"HOWARDFORUMS", 12, 146943},
	{"NANOCOMPOSITES", 14, 146944},
	{"LUSTGROTTE", 10, 146945},
	{"MCWHORTER", 9, 146946},
	{"JAMECO", 6, 146947},
	{"SHELBOURNE", 10, 146948},
	{"ITALERI", 7, 146949},
	{"GEHEN", 5, 146950},
	{"NEUROPEPTIDES", 13, 146951},
	{"LUTEAL", 6, 146952},
	{"BACKBACK", 8, 146953},
	{"PARAGUAYAN", 10, 146954},
	{"SABOTAGED", 9, 146955},
	{"TUMORIGENESIS", 13, 146956},
	{"SUBSE", 5, 146957},
	{"VENOMS", 6, 146958},
	{"HARRISONVILLE", 13, 146959},
	{"BKLYN", 5, 146960},
	{"AUDITABLE", 9, 146961},
	{"NIGHTY", 6, 146962},
	{"HYVES", 5, 146963},
	{"PICMG", 5, 146964},
	{"CLASSICALS", 10, 146965},
	{"BIJECTION", 9, 146966},
	{"AFRL", 4, 146967},
	{"LORAS", 5, 146968},
	{"PIRA", 4, 146969},
	{"NADJA", 5, 146970},
	{"CONSOLED", 8, 146971},
	{"TIENTS", 6, 146972},
	{"SUBLEASES", 9, 146973},
	{"DESPARATE", 9, 146974},
	{"EVERDAY", 7, 146975},
	{"SIBM", 4, 146976},
	{"OMOY", 4, 146977},
	{"MISY", 4, 146978},
	{"MDHA", 4, 146979},
	{"LOOZ", 4, 146980},
	{"KYAC", 4, 146981},
	{"DAYQ", 4, 146982},
	{"COAM", 4, 146983},
	{"AHLU", 4, 146984},
	{"RAJYA", 5, 146985},
	{"DUMBED", 6, 146986},
	{"HECHE", 5, 146987},
	{"TICKETCENTER", 12, 146988},
	{"SKYLAR", 6, 146989},
	{"BUDO", 4, 146990},
	{"MAYORES", 7, 146991},
	{"KSTARS", 6, 146992},
	{"BLOGSPHERE", 10, 146993},
	{"KHABAROVSK", 10, 146994},
	{"GRIFFEN", 7, 146995},
	{"RESIDENCIAL", 11, 146996},
	{"SATURATING", 10, 146997},
	{"BLB", 3, 146998},
	{"CONTRITION", 10, 146999},
	{"COSTRUZIONE", 11, 147000},
	{"SPERMATOGENESIS", 15, 147001},
	{"LIVEWORLD", 9, 147002},
	{"SZYMANSKI", 9, 147003},
	{"FRENCHIE", 8, 147004},
	{"ABCAM", 5, 147005},
	{"EVID", 4, 147006},
	{"FAMERS", 6, 147007},
	{"DELIVERABILITY", 14, 147008},
	{"VITUS", 5, 147009},
	{"JINDAL", 6, 147010},
	{"MALLEY", 6, 147011},
	{"GUIDLINES", 9, 147012},
	{"SNAPDATA", 8, 147013},
	{"DIENER", 6, 147014},
	{"BIOMEDICS", 9, 147015},
	{"GLUONS", 6, 147016},
	{"BUSHWACKER", 10, 147017},
	{"NAVIGATIONS", 11, 147018},
	{"CLASES", 6, 147019},
	{"BALANCERS", 9, 147020},
	{"BENFORD", 7, 147021},
	{"OURPRICE", 8, 147022},
	{"RESOUND", 7, 147023},
	{"PPING", 5, 147024},
	{"SNAKESKIN", 9, 147025},
	{"UNSUSPECTED", 11, 147026},
	{"TWINSBURG", 9, 147027},
	{"LATTIMORE", 9, 147028},
	{"LECTER", 6, 147029},
	{"EGGLETON", 8, 147030},
	{"BALDOR", 6, 147031},
	{"PYAR", 4, 147032},
	{"ARCHBISHOPS", 11, 147033},
	{"YNNM", 4, 147034},
	{"XTOD", 4, 147035},
	{"TZBU", 4, 147036},
	{"RSND", 4, 147037},
	{"PPSE", 4, 147038},
	{"NDFC", 4, 147039},
	{"MKIS", 4, 147040},
	{"GSTP", 4, 147041},
	{"GRUG", 4, 147042},
	{"FMCD", 4, 147043},
	{"DDGO", 4, 147044},
	{"DCWA", 4, 147045},
	{"BEDK", 4, 147046},
	{"APFA", 4, 147047},
	{"AMCG", 4, 147048},
	{"KOSTENLOSECAMS", 14, 147049},
	{"BRANCA", 6, 147050},
	{"KEYSHIA", 7, 147051},
	{"BYER", 4, 147052},
	{"TARPAULIN", 9, 147053},
	{"PHARMACOPOEIA", 13, 147054},
	{"GOONG", 5, 147055},
	{"SCOUTNEWS", 9, 147056},
	{"ENCOUR", 6, 147057},
	{"WCCO", 4, 147058},
	{"GRUNER", 6, 147059},
	{"ABAJO", 5, 147060},
	{"STOPED", 6, 147061},
	{"MUSTAPHA", 8, 147062},
	{"LANSA", 5, 147063},
	{"BROOKTROUT", 10, 147064},
	{"TOZER", 5, 147065},
	{"XPOS", 4, 147066},
	{"GOVER", 5, 147067},
	{"MISYS", 5, 147068},
	{"STRATEGIZE", 10, 147069},
	{"SCHAAL", 6, 147070},
	{"TIWARI", 6, 147071},
	{"POLYM", 5, 147072},
	{"MERKLE", 6, 147073},
	{"DOHENY", 6, 147074},
	{"PALMAX", 6, 147075},
	{"QUIKLOK", 7, 147076},
	{"NOBBY", 5, 147077},
	{"CASTAIC", 7, 147078},
	{"ONDERWERP", 9, 147079},
	{"LITTERATUR", 10, 147080},
	{"REARWARD", 8, 147081},
	{"XOFF", 4, 147082},
	{"COLLEGIALITY", 12, 147083},
	{"DKOS", 4, 147084},
	{"JASPERS", 7, 147085},
	{"CHEROKEES", 9, 147086},
	{"CYBERCASH", 9, 147087},
	{"CAPRICCIO", 9, 147088},
	{"MIGA", 4, 147089},
	{"PEACEABLY", 9, 147090},
	{"REAGEER", 7, 147091},
	{"BYRAM", 5, 147092},
	{"ZOEL", 4, 147093},
	{"WUPC", 4, 147094},
	{"RPDR", 4, 147095},
	{"RFCO", 4, 147096},
	{"RAXE", 4, 147097},
	{"OFCF", 4, 147098},
	{"NGDP", 4, 147099},
	{"MAUM", 4, 147100},
	{"LOMS", 4, 147101},
	{"HPUP", 4, 147102},
	{"HLAF", 4, 147103},
	{"FOFU", 4, 147104},
	{"FAEU", 4, 147105},
	{"ECUY", 4, 147106},
	{"CUEN", 4, 147107},
	{"BEEG", 4, 147108},
	{"ARRP", 4, 147109},
	{"CURVETO", 7, 147110},
	{"BOOLE", 5, 147111},
	{"EXACTED", 7, 147112},
	{"ODDEST", 6, 147113},
	{"BAYLIS", 6, 147114},
	{"TRIATHLETES", 11, 147115},
	{"YPG", 3, 147116},
	{"TOYNBEE", 7, 147117},
	{"KAUN", 4, 147118},
	{"DISCH", 5, 147119},
	{"CONSOLI", 7, 147120},
	{"KILMORE", 7, 147121},
	{"LIHEAP", 6, 147122},
	{"DOUGHBOY", 8, 147123},
	{"AAMC", 4, 147124},
	{"PURPOSED", 8, 147125},
	{"EVINCE", 6, 147126},
	{"PUYO", 4, 147127},
	{"ALLOWWEBCHANGE", 14, 147128},
	{"BOUDICCA", 8, 147129},
	{"PERIYAR", 7, 147130},
	{"FRATERS", 7, 147131},
	{"VERIMED", 7, 147132},
	{"HYENAS", 6, 147133},
	{"HORNPIPE", 8, 147134},
	{"PINANG", 6, 147135},
	{"GOALKEEPING", 11, 147136},
	{"BLDGS", 5, 147137},
	{"NHRP", 4, 147138},
	{"SUGARBUSH", 9, 147139},
	{"APYCOM", 6, 147140},
	{"OBERT", 5, 147141},
	{"CHANGEMAN", 9, 147142},
	{"TEMPLATED", 9, 147143},
	{"WHITSON", 7, 147144},
	{"BAYCOL", 6, 147145},
	{"MANYARA", 7, 147146},
	{"THESAURUSLEGEND", 15, 147147},
	{"CINEREA", 7, 147148},
	{"SPANKS", 6, 147149},
	{"YCNN", 4, 147150},
	{"TEDX", 4, 147151},
	{"SPSP", 4, 147152},
	{"PAMT", 4, 147153},
	{"NZOM", 4, 147154},
	{"NMUG", 4, 147155},
	{"LKSN", 4, 147156},
	{"FFGI", 4, 147157},
	{"ECWO", 4, 147158},
	{"DACD", 4, 147159},
	{"CKYJ", 4, 147160},
	{"ATKL", 4, 147161},
	{"FREEDOMCROWSNEST", 16, 147162},
	{"LUSSIER", 7, 147163},
	{"MILROY", 6, 147164},
	{"DEEPA", 5, 147165},
	{"UMKLEIDERAUM", 12, 147166},
	{"RACEBOOK", 8, 147167},
	{"COMPETATIVE", 11, 147168},
	{"SIGIL", 5, 147169},
	{"CONSIS", 6, 147170},
	{"ANSAWDD", 7, 147171},
	{"INNOVATED", 9, 147172},
	{"CANDLEWICK", 10, 147173},
	{"CAITLYN", 7, 147174},
	{"TUCKAHOE", 8, 147175},
	{"HISTOR", 6, 147176},
	{"KOLCRAFT", 8, 147177},
	{"VISITBRITAIN", 12, 147178},
	{"MISSISSIPPIAN", 13, 147179},
	{"OOGLE", 5, 147180},
	{"MASTERCRAFT", 11, 147181},
	{"FACC", 4, 147182},
	{"BECERRA", 7, 147183},
	{"DARLINGHURST", 12, 147184},
	{"SCHOOLMATES", 11, 147185},
	{"DEFVAL", 6, 147186},
	{"REGIST", 6, 147187},
	{"ASSORTABILITY", 13, 147188},
	{"AVANQUEST", 9, 147189},
	{"MCKINLEYVILLE", 13, 147190},
	{"LUOGO", 5, 147191},
	{"BPW", 3, 147192},
	{"BALKO", 5, 147193},
	{"BULLA", 5, 147194},
	{"BOATYARD", 8, 147195},
	{"ALLCONSUMING", 12, 147196},
	{"YMRA", 4, 147197},
	{"YKLE", 4, 147198},
	{"YINZ", 4, 147199},
	{"WTID", 4, 147200},
	{"UAFO", 4, 147201},
	{"OXYF", 4, 147202},
	{"OLUO", 4, 147203},
	{"MOBJ", 4, 147204},
	{"IYAB", 4, 147205},
	{"GYAB", 4, 147206},
	{"DULS", 4, 147207},
	{"AYAJ", 4, 147208},
	{"AXYT", 4, 147209},
	{"AEGY", 4, 147210},
	{"DEWI", 4, 147211},
	{"CRUFT", 5, 147212},
	{"LECONTE", 7, 147213},
	{"REDSTATE", 8, 147214},
	{"ACAP", 4, 147215},
	{"COMPARABLES", 11, 147216},
	{"WIGGINTON", 9, 147217},
	{"BERTHING", 8, 147218},
	{"TIMESPAN", 8, 147219},
	{"USNEWS", 6, 147220},
	{"POLYPROTEIN", 11, 147221},
	{"GLASSBORO", 9, 147222},
	{"AVISTA", 6, 147223},
	{"MEUR", 4, 147224},
	{"BREATHLESSLY", 12, 147225},
	{"MOISTURIZES", 11, 147226},
	{"KAWASHIMA", 9, 147227},
	{"ONTONAGON", 9, 147228},
	{"CHILIS", 6, 147229},
	{"METEORA", 7, 147230},
	{"OWOSSO", 6, 147231},
	{"LATERALS", 8, 147232},
	{"LIEW", 4, 147233},
	{"TOLMAN", 6, 147234},
	{"SMETANA", 7, 147235},
	{"ZVJ", 3, 147236},
	{"ZDK", 3, 147237},
	{"WQK", 3, 147238},
	{"WQD", 3, 147239},
	{"VPZ", 3, 147240},
	{"UUQ", 3, 147241},
	{"UQF", 3, 147242},
	{"QWW", 3, 147243},
	{"QLY", 3, 147244},
	{"PZG", 3, 147245},
	{"JZC", 3, 147246},
	{"JGZ", 3, 147247},
	{"TESSIER", 7, 147248},
	{"SEESAW", 6, 147249},
	{"STALYBRIDGE", 11, 147250},
	{"CRASHER", 7, 147251},
	{"BROD", 4, 147252},
	{"HARLEYS", 7, 147253},
	{"HARPE", 5, 147254},
	{"LOCALLIFE", 9, 147255},
	{"GREGARIUS", 9, 147256},
	{"DIMENSIONED", 11, 147257},
	{"GRANTVILLE", 10, 147258},
	{"EMMAELIZ", 8, 147259},
	{"HOSING", 6, 147260},
	{"CARVEL", 6, 147261},
	{"HOARDED", 7, 147262},
	{"MORPHO", 6, 147263},
	{"SPARSITY", 8, 147264},
	{"FORSIDEN", 8, 147265},
	{"TREVELYAN", 9, 147266},
	{"VSUP", 4, 147267},
	{"ULUW", 4, 147268},
	{"UDYU", 4, 147269},
	{"SOXD", 4, 147270},
	{"OLMM", 4, 147271},
	{"OFDS", 4, 147272},
	{"MRNO", 4, 147273},
	{"HYAK", 4, 147274},
	{"GUMO", 4, 147275},
	{"ERCT", 4, 147276},
	{"EPYL", 4, 147277},
	{"EDBS", 4, 147278},
	{"AKPL", 4, 147279},
	{"AJBU", 4, 147280},
	{"ACNIELSEN", 9, 147281},
	{"FRCP", 4, 147282},
	{"ELLION", 6, 147283},
	{"DENYWEBCHANGE", 13, 147284},
	{"TSAWWASSEN", 10, 147285},
	{"NATURALNESS", 11, 147286},
	{"RIEU", 4, 147287},
	{"PYOTR", 5, 147288},
	{"SWINGARM", 8, 147289},
	{"PHOTOBLOGGERS", 13, 147290},
	{"GVWR", 4, 147291},
	{"FLINGS", 6, 147292},
	{"FLAS", 4, 147293},
	{"ENTERITIS", 9, 147294},
	{"RANTOUL", 7, 147295},
	{"IMMUNOSTAINING", 14, 147296},
	{"YUR", 3, 147297},
	{"QUITA", 5, 147298},
	{"VALEDICTORIAN", 13, 147299},
	{"RAMIN", 5, 147300},
	{"HOLGA", 5, 147301},
	{"GADE", 4, 147302},
	{"CELTIA", 6, 147303},
	{"LAKEFIELD", 9, 147304},
	{"STROH", 5, 147305},
	{"MONOSPACE", 9, 147306},
	{"REFRIED", 7, 147307},
	{"AGRICUL", 7, 147308},
	{"HAFLINGER", 9, 147309},
	{"NYCWIRELESS", 11, 147310},
	{"MILEY", 5, 147311},
	{"QANDO", 5, 147312},
	{"GORSKI", 6, 147313},
	{"ZEUN", 4, 147314},
	{"YVIV", 4, 147315},
	{"XELL", 4, 147316},
	{"LBFT", 4, 147317},
	{"HGAY", 4, 147318},
	{"GMYG", 4, 147319},
	{"GGWI", 4, 147320},
	{"EMPC", 4, 147321},
	{"TIPPY", 5, 147322},
	{"KLEINMAN", 8, 147323},
	{"KEMBLE", 6, 147324},
	{"IRRITABLY", 9, 147325},
	{"UFFIZI", 6, 147326},
	{"MONTENEGRIN", 11, 147327},
	{"JETSTAR", 7, 147328},
	{"CARDOZA", 7, 147329},
	{"ARNOT", 5, 147330},
	{"SCHEIDE", 7, 147331},
	{"PEEKABOO", 8, 147332},
	{"GORGEOUSLY", 10, 147333},
	{"CHROMATOGRAPH", 13, 147334},
	{"UNSATISFYING", 12, 147335},
	{"TASSIE", 6, 147336},
	{"SETTIMEOUT", 10, 147337},
	{"MONTGOMERIE", 11, 147338},
	{"NEXTLINK", 8, 147339},
	{"PSYCHIATR", 9, 147340},
	{"CUEING", 6, 147341},
	{"NOONDAY", 7, 147342},
	{"GETMESSAGE", 10, 147343},
	{"KASSIN", 6, 147344},
	{"KANDEL", 6, 147345},
	{"COURTEOUSLY", 11, 147346},
	{"PROBLEMI", 8, 147347},
	{"LIMEHOUSE", 9, 147348},
	{"KENNERLEY", 9, 147349},
	{"BICKLEY", 7, 147350},
	{"SARITA", 6, 147351},
	{"TYPEINFO", 8, 147352},
	{"INCYTE", 6, 147353},
	{"MTEXT", 5, 147354},
	{"MONTS", 5, 147355},
	{"LINDEX", 6, 147356},
	{"EFAVIRENZ", 9, 147357},
	{"SOPOT", 5, 147358},
	{"SOUNDBITE", 9, 147359},
	{"MEBANE", 6, 147360},
	{"DIFFING", 7, 147361},
	{"SINUOUS", 7, 147362},
	{"KRUSTY", 6, 147363},
	{"ABBADOX", 7, 147364},
	{"ETTRICK", 7, 147365},
	{"YNRA", 4, 147366},
	{"YKOL", 4, 147367},
	{"OBIU", 4, 147368},
	{"HOUB", 4, 147369},
	{"EIPU", 4, 147370},
	{"EGYE", 4, 147371},
	{"AMIJ", 4, 147372},
	{"CONNALLY", 8, 147373},
	{"AVAILING", 8, 147374},
	{"PEROXISOMAL", 11, 147375},
	{"TRICHLOROETHANE", 15, 147376},
	{"OPERAT", 6, 147377},
	{"TAILRANK", 8, 147378},
	{"MANEUVERED", 10, 147379},
	{"LINUXDOC", 8, 147380},
	{"CLUDES", 6, 147381},
	{"COLEUS", 6, 147382},
	{"CSABA", 5, 147383},
	{"MEEKLY", 6, 147384},
	{"ZIELINSKI", 9, 147385},
	{"ANTHROPOMETRIC", 14, 147386},
	{"ACCORDIONS", 10, 147387},
	{"ROMANIANS", 9, 147388},
	{"CLARIFIER", 9, 147389},
	{"DISENCHANTMENT", 14, 147390},
	{"TRANSPOSABLE", 12, 147391},
	{"SACCHARIN", 9, 147392},
	{"WILDERS", 7, 147393},
	{"BULMER", 6, 147394},
	{"AUSTECHWRITER", 13, 147395},
	{"BRIEFER", 7, 147396},
	{"EPPERSON", 8, 147397},
	{"OVERTONE", 8, 147398},
	{"MARGIELA", 8, 147399},
	{"KITZBUHEL", 9, 147400},
	{"INDUSTRIELLE", 12, 147401},
	{"TELEVISON", 9, 147402},
	{"MTRR", 4, 147403},
	{"OWEGO", 5, 147404},
	{"DEACETYLASE", 11, 147405},
	{"ALLINA", 6, 147406},
	{"VEDIO", 5, 147407},
	{"SOBRANTE", 8, 147408},
	{"PROFICIENCIES", 13, 147409},
	{"GOLGOTHA", 8, 147410},
	{"SERFS", 5, 147411},
	{"SPANTREE", 8, 147412},
	{"WLR", 3, 147413},
	{"VIVES", 5, 147414},
	{"YVIG", 4, 147415},
	{"YSKO", 4, 147416},
	{"YSIK", 4, 147417},
	{"YOLE", 4, 147418},
	{"YLOF", 4, 147419},
	{"YHOF", 4, 147420},
	{"RPEI", 4, 147421},
	{"RIGW", 4, 147422},
	{"OPPH", 4, 147423},
	{"MLIA", 4, 147424},
	{"LTFL", 4, 147425},
	{"LGHO", 4, 147426},
	{"JETC", 4, 147427},
	{"HMEW", 4, 147428},
	{"FFAA", 4, 147429},
	{"ERMK", 4, 147430},
	{"EDUV", 4, 147431},
	{"DXAV", 4, 147432},
	{"CUAS", 4, 147433},
	{"CSSY", 4, 147434},
	{"EFFENDI", 7, 147435},
	{"CANELA", 6, 147436},
	{"INSUBSTANTIAL", 13, 147437},
	{"NIGHTCRAWLER", 12, 147438},
	{"DCPI", 4, 147439},
	{"VANTAA", 6, 147440},
	{"CATEGORIZES", 11, 147441},
	{"GOLDCOAST", 9, 147442},
	{"FANSHAWE", 8, 147443},
	{"TUBERCULOUS", 11, 147444},
	{"HOMBURG", 7, 147445},
	{"MORICHES", 8, 147446},
	{"JAMMY", 5, 147447},
	{"ISUP", 4, 147448},
	{"WAILED", 6, 147449},
	{"STUPA", 5, 147450},
	{"BASEDIALOG", 10, 147451},
	{"REVOKES", 7, 147452},
	{"HANDSHAKING", 11, 147453},
	{"IPPOLITO", 8, 147454},
	{"TAGBOX", 6, 147455},
	{"KNAW", 4, 147456},
	{"PDEV", 4, 147457},
	{"FRAZZLED", 8, 147458},
	{"NATORI", 6, 147459},
	{"REPURCHASES", 11, 147460},
	{"LUDMILA", 7, 147461},
	{"MOONDANCE", 9, 147462},
	{"STEINBRENNER", 12, 147463},
	{"SENDTO", 6, 147464},
	{"NEWTECH", 7, 147465},
	{"STUDIOWORKS", 11, 147466},
	{"EIGENSTATES", 11, 147467},
	{"DIFFERENCING", 12, 147468},
	{"NAKASHIMA", 9, 147469},
	{"THUNDERBOLTS", 12, 147470},
	{"CHAUDHRY", 8, 147471},
	{"AHWATUKEE", 9, 147472},
	{"GRUELLING", 9, 147473},
	{"TULE", 4, 147474},
	{"NGUOI", 5, 147475},
	{"HUSTLING", 8, 147476},
	{"WRASSE", 6, 147477},
	{"BIEDERLACK", 10, 147478},
	{"YBOE", 4, 147479},
	{"TLUI", 4, 147480},
	{"TEUC", 4, 147481},
	{"REVP", 4, 147482},
	{"RCCH", 4, 147483},
	{"NJUV", 4, 147484},
	{"MMWH", 4, 147485},
	{"KHEF", 4, 147486},
	{"FTMY", 4, 147487},
	{"ETCD", 4, 147488},
	{"EDNF", 4, 147489},
	{"DMRO", 4, 147490},
	{"KLEMM", 5, 147491},
	{"CADAVERS", 8, 147492},
	{"RAICH", 5, 147493},
	{"USEF", 4, 147494},
	{"POLLINATORS", 11, 147495},
	{"TAILPIECE", 9, 147496},
	{"GLIA", 4, 147497},
	{"SHAMROCKS", 9, 147498},
	{"MIDRAND", 7, 147499},
	{"SHOALHAVEN", 10, 147500},
	{"CHAMPAGNES", 10, 147501},
	{"ADJOINS", 7, 147502},
	{"RIKI", 4, 147503},
	{"ASCD", 4, 147504},
	{"SEROUS", 6, 147505},
	{"GRAVIMETRIC", 11, 147506},
	{"MILANESE", 8, 147507},
	{"GALVANIZE", 9, 147508},
	{"DKOSOPEDIA", 10, 147509},
	{"USCF", 4, 147510},
	{"LOWESTONWEB", 11, 147511},
	{"GHAZALS", 7, 147512},
	{"GEOMAG", 6, 147513},
	{"RECIPEBOX", 9, 147514},
	{"ACCESSORS", 9, 147515},
	{"DEMENT", 6, 147516},
	{"HACKY", 5, 147517},
	{"TSUNG", 5, 147518},
	{"ORDERLINE", 9, 147519},
	{"BRF", 3, 147520},
	{"PALIO", 5, 147521},
	{"ELLENTON", 8, 147522},
	{"TEMES", 5, 147523},
	{"ALACRITECH", 10, 147524},
	{"STRAIGHTFORWARDLY", 17, 147525},
	{"CRUSADING", 9, 147526},
	{"ZITAT", 5, 147527},
	{"MARRON", 6, 147528},
	{"FORAN", 5, 147529},
	{"MASOOD", 6, 147530},
	{"INFLUENCERS", 11, 147531},
	{"GREENSPACE", 10, 147532},
	{"SLATTED", 7, 147533},
	{"BLOOMED", 7, 147534},
	{"UMNR", 4, 147535},
	{"TLLA", 4, 147536},
	{"SUTC", 4, 147537},
	{"RLNE", 4, 147538},
	{"OBFI", 4, 147539},
	{"NOPF", 4, 147540},
	{"NIMD", 4, 147541},
	{"NDTM", 4, 147542},
	{"GYMC", 4, 147543},
	{"GALQ", 4, 147544},
	{"FUTR", 4, 147545},
	{"EVIJ", 4, 147546},
	{"DDBU", 4, 147547},
	{"AMRIT", 5, 147548},
	{"HONIG", 5, 147549},
	{"GIGGING", 7, 147550},
	{"CRINGELY", 8, 147551},
	{"RHOMBUS", 7, 147552},
	{"CORVAIR", 7, 147553},
	{"READJUST", 8, 147554},
	{"PERSONE", 7, 147555},
	{"AFFICHES", 8, 147556},
	{"HORTENSE", 8, 147557},
	{"LOWDEN", 6, 147558},
	{"BAADER", 6, 147559},
	{"BIOFLAVONOIDS", 13, 147560},
	{"CYNLLUNIO", 9, 147561},
	{"LLEIDA", 6, 147562},
	{"FIRMED", 6, 147563},
	{"SPORTSBETTING", 13, 147564},
	{"CHYMOTRYPSIN", 12, 147565},
	{"HMMS", 4, 147566},
	{"ASTALAVISTA", 11, 147567},
	{"MWAH", 4, 147568},
	{"FRAMETABLE", 10, 147569},
	{"APOSTOLATE", 10, 147570},
	{"SETTABLE", 8, 147571},
	{"LAWRANCE", 8, 147572},
	{"TESTABILITY", 11, 147573},
	{"ANDRESEN", 8, 147574},
	{"GARDENCLEANING", 14, 147575},
	{"BIGTIME", 7, 147576},
	{"ALMODOVAR", 9, 147577},
	{"SCRAWL", 6, 147578},
	{"PCAP", 4, 147579},
	{"AMBIENTAL", 9, 147580},
	{"KATAYAMA", 8, 147581},
	{"BONNAROO", 8, 147582},
	{"SEAFARER", 8, 147583},
	{"PETOK", 5, 147584},
	{"NONACADEMIC", 11, 147585},
	{"REPELLER", 8, 147586},
	{"XLAS", 4, 147587},
	{"NGNF", 4, 147588},
	{"NCMI", 4, 147589},
	{"LRHY", 4, 147590},
	{"LPAF", 4, 147591},
	{"JONP", 4, 147592},
	{"JAYI", 4, 147593},
	{"ERBG", 4, 147594},
	{"DWIK", 4, 147595},
	{"CSAU", 4, 147596},
	{"BUPR", 4, 147597},
	{"BDAR", 4, 147598},
	{"ABCL", 4, 147599},
	{"DOCKETED", 8, 147600},
	{"EDELNUTTEN", 10, 147601},
	{"GOMEL", 5, 147602},
	{"CAUDIUM", 7, 147603},
	{"RANJAN", 6, 147604},
	{"GUC", 3, 147605},
	{"DOWNLAD", 7, 147606},
	{"MANANA", 6, 147607},
	{"MARKDOWNS", 9, 147608},
	{"YOUSUF", 6, 147609},
	{"INTELIHEALTH", 12, 147610},
	{"VERWENDET", 9, 147611},
	{"SPRECHEN", 8, 147612},
	{"RODOS", 5, 147613},
	{"FORBEAR", 7, 147614},
	{"PATRIZIA", 8, 147615},
	{"STANSTEAD", 9, 147616},
	{"SANITAIRE", 9, 147617},
	{"FOAMED", 6, 147618},
	{"TOLAND", 6, 147619},
	{"KLEIDERMARKT", 12, 147620},
	{"WAIANAE", 7, 147621},
	{"REFECTORY", 9, 147622},
	{"GIESE", 5, 147623},
	{"DIDAX", 5, 147624},
	{"SALDANHA", 8, 147625},
	{"ALFARO", 6, 147626},
	{"BAIRNSDALE", 10, 147627},
	{"UFF", 3, 147628},
	{"BIOIDENTICAL", 12, 147629},
	{"LOSTOCK", 7, 147630},
	{"SKULLCANDY", 10, 147631},
	{"SENTER", 6, 147632},
	{"FILT", 4, 147633},
	{"BUTCHERING", 10, 147634},
	{"BASELWORLD", 10, 147635},
	{"KARUNA", 6, 147636},
	{"REBALANCE", 9, 147637},
	{"VICI", 4, 147638},
	{"YEARNS", 6, 147639},
	{"OPPURTUNITY", 11, 147640},
	{"TARAWA", 6, 147641},
	{"UNACCUSTOMED", 12, 147642},
	{"SIFRY", 5, 147643},
	{"NOVATEL", 7, 147644},
	{"PWP", 3, 147645},
	{"ZIEB", 4, 147646},
	{"XITR", 4, 147647},
	{"WTOV", 4, 147648},
	{"SJOC", 4, 147649},
	{"SGEL", 4, 147650},
	{"SFUC", 4, 147651},
	{"ORLS", 4, 147652},
	{"LKGR", 4, 147653},
	{"IRYL", 4, 147654},
	{"IFCU", 4, 147655},
	{"GRUT", 4, 147656},
	{"GNGA", 4, 147657},
	{"GKAM", 4, 147658},
	{"EVAK", 4, 147659},
	{"EAZU", 4, 147660},
	{"DRWE", 4, 147661},
	{"DRMC", 4, 147662},
	{"DRGA", 4, 147663},
	{"DNIM", 4, 147664},
	{"BYEP", 4, 147665},
	{"AMKH", 4, 147666},
	{"PLATOONS", 8, 147667},
	{"FLORAPOST", 9, 147668},
	{"HAMSTRINGS", 10, 147669},
	{"UNDERS", 6, 147670},
	{"PERLDOC", 7, 147671},
	{"UNBELIEVING", 11, 147672},
	{"PSOTD", 5, 147673},
	{"ELEUTHERA", 9, 147674},
	{"LUMINARY", 8, 147675},
	{"DORCEL", 6, 147676},
	{"CONGRESSIONALLY", 15, 147677},
	{"QUITTER", 7, 147678},
	{"PURSER", 6, 147679},
	{"PRATIQUES", 9, 147680},
	{"IGNITOR", 7, 147681},
	{"PARAPLEGIC", 10, 147682},
	{"NUALA", 5, 147683},
	{"RAVEONETTES", 11, 147684},
	{"FURTIVE", 7, 147685},
	{"MUTUALITY", 9, 147686},
	{"PLUMTREE", 8, 147687},
	{"FRAGRANCEDIRECT", 15, 147688},
	{"GWU", 3, 147689},
	{"GRUNDLAGEN", 10, 147690},
	{"SAURABH", 7, 147691},
	{"RENOUNCING", 10, 147692},
	{"FUGLY", 5, 147693},
	{"COSTER", 6, 147694},
	{"SPECHT", 6, 147695},
	{"MAJUMDAR", 8, 147696},
	{"ATHEARN", 7, 147697},
	{"ACCOSTED", 8, 147698},
	{"CONNING", 7, 147699},
	{"CRAFTON", 7, 147700},
	{"TIEMPOS", 7, 147701},
	{"KWORD", 5, 147702},
	{"DIPPERS", 7, 147703},
	{"WOMYN", 5, 147704},
	{"INCANTATIONS", 12, 147705},
	{"LEATHERNECKS", 12, 147706},
	{"DURIAN", 6, 147707},
	{"BOULEZ", 6, 147708},
	{"PUTZ", 4, 147709},
	{"PACIFICPOKER", 12, 147710},
	{"YSKU", 4, 147711},
	{"VASK", 4, 147712},
	{"STWW", 4, 147713},
	{"RZAR", 4, 147714},
	{"OOMJ", 4, 147715},
	{"ONLL", 4, 147716},
	{"MRHI", 4, 147717},
	{"KOUF", 4, 147718},
	{"KBAK", 4, 147719},
	{"IXCL", 4, 147720},
	{"IPJU", 4, 147721},
	{"EYCY", 4, 147722},
	{"ERFD", 4, 147723},
	{"ERBN", 4, 147724},
	{"EDRP", 4, 147725},
	{"DDSL", 4, 147726},
	{"DDPR", 4, 147727},
	{"WASEDA", 6, 147728},
	{"VIMEO", 5, 147729},
	{"TEKNOLOGI", 9, 147730},
	{"LITIGATORS", 10, 147731},
	{"CIWMB", 5, 147732},
	{"PREMENOPAUSAL", 13, 147733},
	{"MOSTYN", 6, 147734},
	{"MIZZOU", 6, 147735},
	{"CRASHDAY", 8, 147736},
	{"BERNAMA", 7, 147737},
	{"ENCHANTRESS", 11, 147738},
	{"RIESENSCHWANZ", 13, 147739},
	{"BRUNELL", 7, 147740},
	{"VODAPHONE", 9, 147741},
	{"UMPIRING", 8, 147742},
	{"PARALLELOGRAM", 13, 147743},
	{"KARAM", 5, 147744},
	{"HIRANO", 6, 147745},
	{"TWIKITEMPLATES", 14, 147746},
	{"FEIL", 4, 147747},
	{"VEITCH", 6, 147748},
	{"ZABEL", 5, 147749},
	{"VIROLOGIC", 9, 147750},
	{"FICTIONALLEY", 12, 147751},
	{"AGRIBUS", 7, 147752},
	{"QUMANA", 6, 147753},
	{"KAORI", 5, 147754},
	{"BLEETH", 6, 147755},
	{"GNOCCHI", 7, 147756},
	{"IGNITER", 7, 147757},
	{"PRURITUS", 8, 147758},
	{"URSELF", 6, 147759},
	{"PCNA", 4, 147760},
	{"WRYS", 4, 147761},
	{"VYSO", 4, 147762},
	{"UEKE", 4, 147763},
	{"SMRH", 4, 147764},
	{"RKUK", 4, 147765},
	{"RBSB", 4, 147766},
	{"RAKP", 4, 147767},
	{"PSIR", 4, 147768},
	{"KYPI", 4, 147769},
	{"GFUS", 4, 147770},
	{"FEEG", 4, 147771},
	{"EZLO", 4, 147772},
	{"EGMS", 4, 147773},
	{"CYIF", 4, 147774},
	{"BYIF", 4, 147775},
	{"BOBU", 4, 147776},
	{"AWIG", 4, 147777},
	{"TRABAJADORES", 12, 147778},
	{"WORKAMPING", 10, 147779},
	{"WONDERMENT", 10, 147780},
	{"LINDEMANN", 9, 147781},
	{"PROSUMER", 8, 147782},
	{"GOOGOL", 6, 147783},
	{"STONEMAN", 8, 147784},
	{"MANCO", 5, 147785},
	{"VERGENNES", 9, 147786},
	{"PASADO", 6, 147787},
	{"GROPED", 6, 147788},
	{"DEMERSAL", 8, 147789},
	{"ELIHU", 5, 147790},
	{"BPDU", 4, 147791},
	{"MORGAGES", 8, 147792},
	{"KUNE", 4, 147793},
	{"HEROSCAPE", 9, 147794},
	{"CEDARBURG", 9, 147795},
	{"WARDER", 6, 147796},
	{"PREAMPLIFIERS", 13, 147797},
	{"ARTREPUBLIC", 11, 147798},
	{"SIALIC", 6, 147799},
	{"STAGECRAFT", 10, 147800},
	{"MORBIDLY", 8, 147801},
	{"IDGNET", 6, 147802},
	{"MIFFLI", 6, 147803},
	{"TRUSSVILLE", 10, 147804},
	{"FUTURISTS", 9, 147805},
	{"PALFREY", 7, 147806},
	{"ADARE", 5, 147807},
	{"ACDBBLOCKREFERENCE", 18, 147808},
	{"FIORUCCI", 8, 147809},
	{"NODESHELL", 9, 147810},
	{"STRENGHT", 8, 147811},
	{"MARIBEL", 7, 147812},
	{"LDX", 3, 147813},
	{"WOBBLER", 7, 147814},
	{"TURPIS", 6, 147815},
	{"LANSBURY", 8, 147816},
	{"YBIZ", 4, 147817},
	{"RYOA", 4, 147818},
	{"RNVO", 4, 147819},
	{"RMGI", 4, 147820},
	{"REBC", 4, 147821},
	{"LEPM", 4, 147822},
	{"LAVK", 4, 147823},
	{"HLWA", 4, 147824},
	{"GUIG", 4, 147825},
	{"GRYH", 4, 147826},
	{"FCUN", 4, 147827},
	{"DNEM", 4, 147828},
	{"REVIEWPOST", 10, 147829},
	{"SLINGBOX", 8, 147830},
	{"CRYPTANALYSIS", 13, 147831},
	{"HILLTON", 7, 147832},
	{"JAQUI", 5, 147833},
	{"BIOPHARMACEUTICALS", 18, 147834},
	{"AUSSTATS", 8, 147835},
	{"HUMBOLT", 7, 147836},
	{"TARSKI", 6, 147837},
	{"ROXBORO", 7, 147838},
	{"FIBRINOLYTIC", 12, 147839},
	{"SPOL", 4, 147840},
	{"UNSU", 4, 147841},
	{"IMPLEMENTOR", 11, 147842},
	{"OCTAVIAN", 8, 147843},
	{"FOSDEM", 6, 147844},
	{"MUDHONEY", 8, 147845},
	{"INCLUDEDIR", 10, 147846},
	{"DENSITOMETRY", 12, 147847},
	{"WEBSVN", 6, 147848},
	{"KENYATTA", 8, 147849},
	{"MUSCOGEE", 8, 147850},
	{"REXFORD", 7, 147851},
	{"CERIDIAN", 8, 147852},
	{"TAUREN", 6, 147853},
	{"CADWELL", 7, 147854},
	{"EZONICS", 7, 147855},
	{"ALLAHU", 6, 147856},
	{"YCBCR", 5, 147857},
	{"PERSECUTING", 11, 147858},
	{"FNATIC", 6, 147859},
	{"BONZO", 5, 147860},
	{"LVC", 3, 147861},
	{"WYNNEWOOD", 9, 147862},
	{"FINDIT", 6, 147863},
	{"INFANTRYMAN", 11, 147864},
	{"JAWBONE", 7, 147865},
	{"KATMAI", 6, 147866},
	{"HINESVILLE", 10, 147867},
	{"JEJUNUM", 7, 147868},
	{"CORROBORATING", 13, 147869},
	{"XORE", 4, 147870},
	{"URBW", 4, 147871},
	{"UBTM", 4, 147872},
	{"UBEK", 4, 147873},
	{"TSYC", 4, 147874},
	{"TLOM", 4, 147875},
	{"TCEC", 4, 147876},
	{"TAXY", 4, 147877},
	{"RFMA", 4, 147878},
	{"REVC", 4, 147879},
	{"OFKG", 4, 147880},
	{"OBKE", 4, 147881},
	{"GGTO", 4, 147882},
	{"EJEU", 4, 147883},
	{"ANXM", 4, 147884},
	{"AKCR", 4, 147885},
	{"BINKLEY", 7, 147886},
	{"MICROCIRCULATION", 16, 147887},
	{"LARGAN", 6, 147888},
	{"DOWNLOADZ", 9, 147889},
	{"FEIGN", 5, 147890},
	{"MEALY", 5, 147891},
	{"REFTYPE", 7, 147892},
	{"MWEB", 4, 147893},
	{"UKEXPERT", 8, 147894},
	{"ISSFORUM", 8, 147895},
	{"BFR", 3, 147896},
	{"KIDCO", 5, 147897},
	{"RMSD", 4, 147898},
	{"BELLINGER", 9, 147899},
	{"SWOOPING", 8, 147900},
	{"FLEXUSB", 7, 147901},
	{"RANGA", 5, 147902},
	{"LERT", 4, 147903},
	{"BOULE", 5, 147904},
	{"APPID", 5, 147905},
	{"BLUELINE", 8, 147906},
	{"ZILCH", 5, 147907},
	{"MCKELVEY", 8, 147908},
	{"LATITUDINAL", 11, 147909},
	{"PASSMORE", 8, 147910},
	{"ARCIMS", 6, 147911},
	{"GOINS", 5, 147912},
	{"JCF", 3, 147913},
	{"NORTHGLENN", 10, 147914},
	{"BLACKCURRANT", 12, 147915},
	{"WICHERT", 7, 147916},
	{"IGDA", 4, 147917},
	{"JACKALS", 7, 147918},
	{"NICETIES", 8, 147919},
	{"RUMPUS", 6, 147920},
	{"WEBCHATS", 8, 147921},
	{"SABINO", 6, 147922},
	{"LEPTOSPIROSIS", 13, 147923},
	{"OUTLIVE", 7, 147924},
	{"HARDHOUSE", 9, 147925},
	{"DERELICTION", 11, 147926},
	{"GBL", 3, 147927},
	{"INTERFERONS", 11, 147928},
	{"TRABALHO", 8, 147929},
	{"BOLLARD", 7, 147930},
	{"XROU", 4, 147931},
	{"UMBP", 4, 147932},
	{"ULZE", 4, 147933},
	{"TYUR", 4, 147934},
	{"RGHL", 4, 147935},
	{"QAWI", 4, 147936},
	{"OEPR", 4, 147937},
	{"NOVM", 4, 147938},
	{"LWOE", 4, 147939},
	{"KTAP", 4, 147940},
	{"FOFY", 4, 147941},
	{"FDOD", 4, 147942},
	{"CSKE", 4, 147943},
	{"BOFN", 4, 147944},
	{"BIEK", 4, 147945},
	{"BRAKED", 6, 147946},
	{"ADONAI", 6, 147947},
	{"PUPAE", 5, 147948},
	{"PUSSIE", 6, 147949},
	{"BOOKSEARCH", 10, 147950},
	{"VIDEOETA", 8, 147951},
	{"ERATO", 5, 147952},
	{"DISFIGUREMENT", 13, 147953},
	{"VAPORIZERS", 10, 147954},
	{"RYDBERG", 7, 147955},
	{"ELHOVO", 6, 147956},
	{"AIRFREIGHT", 10, 147957},
	{"HAPKIDO", 7, 147958},
	{"SUNBEDS", 7, 147959},
	{"SINCLAR", 7, 147960},
	{"CLUBMAN", 7, 147961},
	{"CROSSETT", 8, 147962},
	{"JEANNEAU", 8, 147963},
	{"JAPANESS", 8, 147964},
	{"EBAUM", 5, 147965},
	{"LIBFFI", 6, 147966},
	{"SIGNALER", 8, 147967},
	{"HANDYMEN", 8, 147968},
	{"SYNTHESIZES", 11, 147969},
	{"DEBURRING", 9, 147970},
	{"HFCS", 4, 147971},
	{"VARIG", 5, 147972},
	{"QUERETARO", 9, 147973},
	{"PALMPILOT", 9, 147974},
	{"EXACTNESS", 9, 147975},
	{"BESSE", 5, 147976},
	{"WOTC", 4, 147977},
	{"HYPNOTISTS", 10, 147978},
	{"BAKSHI", 6, 147979},
	{"LAMOILLE", 8, 147980},
	{"AUTOCROSS", 9, 147981},
	{"SHERBORN", 8, 147982},
	{"HOFMAN", 6, 147983},
	{"BARBAROSSA", 10, 147984},
	{"WEDD", 4, 147985},
	{"OLINDA", 6, 147986},
	{"PUREVISION", 10, 147987},
	{"DIVERTOR", 8, 147988},
	{"KROME", 5, 147989},
	{"DRAY", 4, 147990},
	{"DRAC", 4, 147991},
	{"STUTZ", 5, 147992},
	{"GRIERSON", 8, 147993},
	{"WORLDWATCH", 10, 147994},
	{"XEPI", 4, 147995},
	{"SUAG", 4, 147996},
	{"SKNU", 4, 147997},
	{"RUDH", 4, 147998},
	{"PEGT", 4, 147999},
	{"OMRB", 4, 148000},
	{"LRIA", 4, 148001},
	{"GKUR", 4, 148002},
	{"CIWO", 4, 148003},
	{"BOXN", 4, 148004},
	{"AKUW", 4, 148005},
	{"AIFU", 4, 148006},
	{"AAMB", 4, 148007},
	{"WESTSHORE", 9, 148008},
	{"DPMS", 4, 148009},
	{"SHEVARDNADZE", 12, 148010},
	{"STATIONARITY", 12, 148011},
	{"HOMEPLUG", 8, 148012},
	{"FEWN", 4, 148013},
	{"PAPERCLIP", 9, 148014},
	{"MONOTHEISTIC", 12, 148015},
	{"DIVERSIONARY", 12, 148016},
	{"SILURIAN", 8, 148017},
	{"BOKS", 4, 148018},
	{"YOSHIHIRO", 9, 148019},
	{"AUTOSITE", 8, 148020},
	{"NETWORKERS", 10, 148021},
	{"MALBEC", 6, 148022},
	{"CORIN", 5, 148023},
	{"DETACHING", 9, 148024},
	{"EVACUEE", 7, 148025},
	{"MORPHOMETRIC", 12, 148026},
	{"LEECHER", 7, 148027},
	{"SUNBURNED", 9, 148028},
	{"KLF", 3, 148029},
	{"QUACKENBUSH", 11, 148030},
	{"PUOI", 4, 148031},
	{"DANELECTRO", 10, 148032},
	{"LOYA", 4, 148033},
	{"OVERVOLTAGE", 11, 148034},
	{"LIBSIGC", 7, 148035},
	{"STEELCASE", 9, 148036},
	{"SPASMODIC", 9, 148037},
	{"POQUOSON", 8, 148038},
	{"MJB", 3, 148039},
	{"VSPACE", 6, 148040},
	{"INTERLACING", 11, 148041},
	{"SHARIAH", 7, 148042},
	{"CHEMTREENO", 10, 148043},
	{"RADKE", 5, 148044},
	{"BELMORE", 7, 148045},
	{"WOJA", 4, 148046},
	{"VAMI", 4, 148047},
	{"UBCR", 4, 148048},
	{"TCOG", 4, 148049},
	{"POMM", 4, 148050},
	{"KKAS", 4, 148051},
	{"IBAG", 4, 148052},
	{"GEGY", 4, 148053},
	{"BSBI", 4, 148054},
	{"BFIR", 4, 148055},
	{"AVAZ", 4, 148056},
	{"ELEGANTE", 8, 148057},
	{"CORNE", 5, 148058},
	{"SCOPATE", 7, 148059},
	{"RESETCHANNEL", 12, 148060},
	{"SUMMERVACATION", 14, 148061},
	{"ISOLD", 5, 148062},
	{"CONCRETES", 9, 148063},
	{"NUDO", 4, 148064},
	{"BASESRC", 7, 148065},
	{"ROTK", 4, 148066},
	{"AUGMENTATIVE", 12, 148067},
	{"VLAAMS", 6, 148068},
	{"SAYONARA", 8, 148069},
	{"QUIETUDE", 8, 148070},
	{"GAMME", 5, 148071},
	{"SEABREEZE", 9, 148072},
	{"ZYLISS", 6, 148073},
	{"ORGIEN", 6, 148074},
	{"ROUNDLY", 7, 148075},
	{"PLANETMIRROR", 12, 148076},
	{"GRIVEL", 6, 148077},
	{"MONARCHIES", 10, 148078},
	{"RESPAWN", 7, 148079},
	{"RODDENBERRY", 11, 148080},
	{"JILLY", 5, 148081},
	{"GEARHART", 8, 148082},
	{"CASSAVETES", 10, 148083},
	{"VIDOR", 5, 148084},
	{"SIMFEROPOL", 10, 148085},
	{"PETANQUE", 8, 148086},
	{"REFRIG", 6, 148087},
	{"SHELFMARK", 9, 148088},
	{"MISCALCULATION", 14, 148089},
	{"AUTOTOOLS", 9, 148090},
	{"TOPFIELD", 8, 148091},
	{"ADJUDICATORS", 12, 148092},
	{"CUBECART", 8, 148093},
	{"TROST", 5, 148094},
	{"INTERPROFESSIONAL", 17, 148095},
	{"NARRABRI", 8, 148096},
	{"DERMABRASION", 12, 148097},
	{"CAMEMBERT", 9, 148098},
	{"SLONE", 5, 148099},
	{"READFILE", 8, 148100},
	{"ATRIOVENTRICULAR", 16, 148101},
	{"CAMANO", 6, 148102},
	{"KINOSHITA", 9, 148103},
	{"YMIM", 4, 148104},
	{"YLRE", 4, 148105},
	{"XTEX", 4, 148106},
	{"VINV", 4, 148107},
	{"VALY", 4, 148108},
	{"UCUL", 4, 148109},
	{"ORDQ", 4, 148110},
	{"NVAM", 4, 148111},
	{"MIGL", 4, 148112},
	{"MAKK", 4, 148113},
	{"LPIG", 4, 148114},
	{"IQBA", 4, 148115},
	{"EVDE", 4, 148116},
	{"BWHA", 4, 148117},
	{"APGO", 4, 148118},
	{"EFERENCES", 9, 148119},
	{"QPOPPER", 7, 148120},
	{"WINLESS", 7, 148121},
	{"UPHAM", 5, 148122},
	{"MOLLUSK", 7, 148123},
	{"WILDFOWL", 8, 148124},
	{"CONSTIPATED", 11, 148125},
	{"BUNDESTAG", 9, 148126},
	{"SYNTAXES", 8, 148127},
	{"HEARTENED", 9, 148128},
	{"SCOTIABANK", 10, 148129},
	{"WINCHENDON", 10, 148130},
	{"PLANVIEW", 8, 148131},
	{"ULTRAPORTABLE", 13, 148132},
	{"FOTOGRAFIAS", 11, 148133},
	{"OPERATINGSYSTEM", 15, 148134},
	{"KONSTANTINOS", 12, 148135},
	{"RHODODENDRONS", 13, 148136},
	{"WYNDAM", 6, 148137},
	{"PRONGHORN", 9, 148138},
	{"NEEDLENOSE", 10, 148139},
	{"MORBI", 5, 148140},
	{"EMWIN", 5, 148141},
	{"FLIRTED", 7, 148142},
	{"HOTTY", 5, 148143},
	{"UNILATERALISM", 13, 148144},
	{"LEOPOLDO", 8, 148145},
	{"SHUCK", 5, 148146},
	{"EUROTEL", 7, 148147},
	{"REFCOUNT", 8, 148148},
	{"ACOLYTES", 8, 148149},
	{"VRAIMENT", 8, 148150},
	{"HAWLFRAINT", 10, 148151},
	{"FRETLESS", 8, 148152},
	{"ROYALIST", 8, 148153},
	{"UNTROUBLED", 10, 148154},
	{"REMSEN", 6, 148155},
	{"DIVERTIMENTO", 12, 148156},
	{"ORDENADOR", 9, 148157},
	{"NEJM", 4, 148158},
	{"WUNDERGROUND", 12, 148159},
	{"JAMIS", 5, 148160},
	{"LEMOS", 5, 148161},
	{"UNASSEMBLED", 11, 148162},
	{"THIGPEN", 7, 148163},
	{"TELLABS", 7, 148164},
	{"ASPIRANTS", 9, 148165},
	{"CRYPTOCOCCUS", 12, 148166},
	{"XBUS", 4, 148167},
	{"UEZF", 4, 148168},
	{"SYBY", 4, 148169},
	{"SAYV", 4, 148170},
	{"RREX", 4, 148171},
	{"PGAV", 4, 148172},
	{"PESV", 4, 148173},
	{"LUWH", 4, 148174},
	{"KSJE", 4, 148175},
	{"IIBR", 4, 148176},
	{"HPEP", 4, 148177},
	{"GPIR", 4, 148178},
	{"FUTH", 4, 148179},
	{"DMAV", 4, 148180},
	{"DHOY", 4, 148181},
	{"CIFT", 4, 148182},
	{"BOLW", 4, 148183},
	{"ABIF", 4, 148184},
	{"BIONDO", 6, 148185},
	{"SANDHU", 6, 148186},
	{"ORGANISME", 9, 148187},
	{"SHEEPISHLY", 10, 148188},
	{"DENK", 4, 148189},
	{"MACHEK", 6, 148190},
	{"WABASHA", 7, 148191},
	{"NUCLEOSOME", 10, 148192},
	{"HIERARCH", 8, 148193},
	{"MOTELES", 7, 148194},
	{"SKLEP", 5, 148195},
	{"SHIKOKU", 7, 148196},
	{"EIGHTBALL", 9, 148197},
	{"AIDSLINE", 8, 148198},
	{"PARISIENNE", 10, 148199},
	{"SHUFFLER", 8, 148200},
	{"PSYCHOPHYSICAL", 14, 148201},
	{"SCIGN", 5, 148202},
	{"TOGGLED", 7, 148203},
	{"SHOPPINGCLOTHING", 16, 148204},
	{"ROSACEAE", 8, 148205},
	{"PDFFACTORY", 10, 148206},
	{"NEVERS", 6, 148207},
	{"BARTHS", 6, 148208},
	{"KHELPCENTER", 11, 148209},
	{"NIZHNY", 6, 148210},
	{"GESTIONE", 8, 148211},
	{"SADIST", 6, 148212},
	{"PHARYNGITIS", 11, 148213},
	{"WHITEFACE", 9, 148214},
	{"KASTNER", 7, 148215},
	{"ZLEB", 4, 148216},
	{"YYOR", 4, 148217},
	{"UMNM", 4, 148218},
	{"ULPS", 4, 148219},
	{"TOWC", 4, 148220},
	{"TJAB", 4, 148221},
	{"TAMK", 4, 148222},
	{"PIEM", 4, 148223},
	{"NCHQ", 4, 148224},
	{"MBFR", 4, 148225},
	{"LPGR", 4, 148226},
	{"KUOM", 4, 148227},
	{"KMHW", 4, 148228},
	{"INLL", 4, 148229},
	{"HPEL", 4, 148230},
	{"GUSN", 4, 148231},
	{"GOAK", 4, 148232},
	{"EXNU", 4, 148233},
	{"ECZA", 4, 148234},
	{"CEEU", 4, 148235},
	{"MOURNE", 6, 148236},
	{"CASTLEMAINE", 11, 148237},
	{"SYNCHING", 8, 148238},
	{"IMPLEMENTER", 11, 148239},
	{"FXR", 3, 148240},
	{"RUSSIE", 6, 148241},
	{"CAMAC", 5, 148242},
	{"JABLONSKI", 9, 148243},
	{"SCHWANN", 7, 148244},
	{"DONOTDELETE", 11, 148245},
	{"MACROINVERTEBRATE", 17, 148246},
	{"CANTONMENT", 10, 148247},
	{"WARILY", 6, 148248},
	{"UDOCS", 5, 148249},
	{"PISANO", 6, 148250},
	{"CADMUS", 6, 148251},
	{"MEDIALAB", 8, 148252},
	{"NOMAIL", 6, 148253},
	{"TELLE", 5, 148254},
	{"RIKA", 4, 148255},
	{"MICROFLUIDIC", 12, 148256},
	{"MCCARRON", 8, 148257},
	{"GECUBE", 6, 148258},
	{"SKIPN", 5, 148259},
	{"SUNDBERG", 8, 148260},
	{"SPAD", 4, 148261},
	{"ISANTI", 6, 148262},
	{"FLASHDANCE", 10, 148263},
	{"PONTYPOOL", 9, 148264},
	{"BOLEYN", 6, 148265},
	{"LILYDALE", 8, 148266},
	{"ATHENATECH", 10, 148267},
	{"NCSC", 4, 148268},
	{"FREESOUND", 9, 148269},
	{"RMOVETO", 7, 148270},
	{"XSIZE", 5, 148271},
	{"TRAFICANT", 9, 148272},
	{"EQUIPEMENT", 10, 148273},
	{"AFLAME", 6, 148274},
	{"INZAMAM", 7, 148275},
	{"BBCLONE", 7, 148276},
	{"SCHALL", 6, 148277},
	{"YMOH", 4, 148278},
	{"PYDR", 4, 148279},
	{"NZOB", 4, 148280},
	{"LTTW", 4, 148281},
	{"LKYL", 4, 148282},
	{"KJIM", 4, 148283},
	{"ITLU", 4, 148284},
	{"HYMC", 4, 148285},
	{"GHWR", 4, 148286},
	{"EDJS", 4, 148287},
	{"DLOL", 4, 148288},
	{"AJAJ", 4, 148289},
	{"PHONETICALLY", 12, 148290},
	{"ARIGHT", 6, 148291},
	{"MOSINEE", 7, 148292},
	{"STANNARD", 8, 148293},
	{"NORTHWAY", 8, 148294},
	{"CMRS", 4, 148295},
	{"ECHOCARDIOGRAM", 14, 148296},
	{"DSMZ", 4, 148297},
	{"NEWSBRIEF", 9, 148298},
	{"SERVICESFINANCING", 17, 148299},
	{"BALROG", 6, 148300},
	{"NOMINATOR", 9, 148301},
	{"TRIPLING", 8, 148302},
	{"KYRGYSTAN", 9, 148303},
	{"KANTIAN", 7, 148304},
	{"ESMOND", 6, 148305},
	{"GOTLAND", 7, 148306},
	{"CARBOXYPEPTIDASE", 16, 148307},
	{"DEBEN", 5, 148308},
	{"GOOGLY", 6, 148309},
	{"SCUFFED", 7, 148310},
	{"VOLVED", 6, 148311},
	{"SPORTRAK", 8, 148312},
	{"SIMPKINS", 8, 148313},
	{"RESECTED", 8, 148314},
	{"WINDLASS", 8, 148315},
	{"BESTOP", 6, 148316},
	{"ICAR", 4, 148317},
	{"EBERLY", 6, 148318},
	{"CRUSIE", 6, 148319},
	{"VANPOOL", 7, 148320},
	{"STUDIOUS", 8, 148321},
	{"ABSOLUTIST", 10, 148322},
	{"SHIFLETT", 8, 148323},
	{"EYCK", 4, 148324},
	{"MEYERSON", 8, 148325},
	{"USBD", 4, 148326},
	{"TZIP", 4, 148327},
	{"TZDE", 4, 148328},
	{"TGUM", 4, 148329},
	{"TEUG", 4, 148330},
	{"PTYR", 4, 148331},
	{"OMCY", 4, 148332},
	{"OFUA", 4, 148333},
	{"NJAD", 4, 148334},
	{"LPPO", 4, 148335},
	{"KHOG", 4, 148336},
	{"GBIB", 4, 148337},
	{"DNYA", 4, 148338},
	{"CFOC", 4, 148339},
	{"ASGM", 4, 148340},
	{"ARXA", 4, 148341},
	{"ALOX", 4, 148342},
	{"KEMPE", 5, 148343},
	{"OLOMOUC", 7, 148344},
	{"WEEKNIGHT", 9, 148345},
	{"KUZNETSOV", 9, 148346},
	{"PATELLAR", 8, 148347},
	{"INFERS", 6, 148348},
	{"NILSON", 6, 148349},
	{"DPML", 4, 148350},
	{"HINRICH", 7, 148351},
	{"FINENESS", 8, 148352},
	{"DUBNA", 5, 148353},
	{"GEMMELL", 7, 148354},
	{"SALICYLATES", 11, 148355},
	{"RENVILLE", 8, 148356},
	{"COLLECTIVISM", 12, 148357},
	{"GARAND", 6, 148358},
	{"DEWEESE", 7, 148359},
	{"KOOGA", 5, 148360},
	{"ALVEOLI", 7, 148361},
	{"YOUGER", 6, 148362},
	{"KEYSTORE", 8, 148363},
	{"BYERLY", 6, 148364},
	{"SUGIMOTO", 8, 148365},
	{"CISTI", 5, 148366},
	{"HKSAR", 5, 148367},
	{"REFCO", 5, 148368},
	{"CRIPPS", 6, 148369},
	{"FLUORINATED", 11, 148370},
	{"MAMMUT", 6, 148371},
	{"WARRENTY", 8, 148372},
	{"NEWGROUNDS", 10, 148373},
	{"TRANSDERM", 9, 148374},
	{"ORAZ", 4, 148375},
	{"DOSENT", 6, 148376},
	{"SETZEN", 6, 148377},
	{"ILLIAD", 6, 148378},
	{"IMMUNOCYTOCHEMISTRY", 19, 148379},
	{"PHARISEE", 8, 148380},
	{"QUESADILLAS", 11, 148381},
	{"EMACHINE", 8, 148382},
	{"SCHADENFREUDE", 13, 148383},
	{"XNOW", 4, 148384},
	{"WFER", 4, 148385},
	{"UFEA", 4, 148386},
	{"SUBN", 4, 148387},
	{"RPHD", 4, 148388},
	{"RKLU", 4, 148389},
	{"PBYL", 4, 148390},
	{"OULK", 4, 148391},
	{"MEZS", 4, 148392},
	{"LATJ", 4, 148393},
	{"JAVU", 4, 148394},
	{"FMOZ", 4, 148395},
	{"ECYO", 4, 148396},
	{"ONEGAI", 6, 148397},
	{"ISVALID", 7, 148398},
	{"WELLIES", 7, 148399},
	{"BECCARY", 7, 148400},
	{"DEVENIR", 7, 148401},
	{"NORTRIPTYLINE", 13, 148402},
	{"CERCLE", 6, 148403},
	{"JEFFRY", 6, 148404},
	{"BATCHELDER", 10, 148405},
	{"URANIA", 6, 148406},
	{"ODUM", 4, 148407},
	{"PRARIE", 6, 148408},
	{"MUSSORGSKY", 10, 148409},
	{"EARLVILLE", 9, 148410},
	{"THREDBO", 7, 148411},
	{"DIELDRIN", 8, 148412},
	{"GIAC", 4, 148413},
	{"ENDOPEPTIDASE", 13, 148414},
	{"UVW", 3, 148415},
	{"APOLIPOPROTEINS", 15, 148416},
	{"OPTIONEN", 8, 148417},
	{"AMICABLY", 8, 148418},
	{"PMAP", 4, 148419},
	{"PORPHYRIN", 9, 148420},
	{"PVAL", 4, 148421},
	{"KNITTY", 6, 148422},
	{"TUREEN", 6, 148423},
	{"TRANSI", 6, 148424},
	{"VANDANA", 7, 148425},
	{"UPROOT", 6, 148426},
	{"ECOLOGIC", 8, 148427},
	{"RHEEM", 5, 148428},
	{"AMETEK", 6, 148429},
	{"PINCHAS", 7, 148430},
	{"AIRMAGNET", 9, 148431},
	{"MOBILEPLANET", 12, 148432},
	{"MINDBRANCH", 10, 148433},
	{"FRONTIERES", 10, 148434},
	{"PROCEDURALLY", 12, 148435},
	{"PHOTOGRAMMETRIC", 15, 148436},
	{"YGES", 4, 148437},
	{"XHIG", 4, 148438},
	{"OFLT", 4, 148439},
	{"NSUZ", 4, 148440},
	{"MLYD", 4, 148441},
	{"GNLO", 4, 148442},
	{"DVOY", 4, 148443},
	{"SANREMO", 7, 148444},
	{"MCGOUGH", 7, 148445},
	{"SPORTSCARDS", 11, 148446},
	{"NUPTIALS", 8, 148447},
	{"CYBERTRONPC", 11, 148448},
	{"MUNCHERS", 8, 148449},
	{"GREIF", 5, 148450},
	{"TECHBARGAINS", 12, 148451},
	{"NAPILI", 6, 148452},
	{"FLINTS", 6, 148453},
	{"SATIRIST", 8, 148454},
	{"YOAV", 4, 148455},
	{"DECONSTRUCTED", 13, 148456},
	{"BANANI", 6, 148457},
	{"ROOKER", 6, 148458},
	{"POORS", 5, 148459},
	{"INTECH", 6, 148460},
	{"OLIVERA", 7, 148461},
	{"CABLETRON", 9, 148462},
	{"TARIFAS", 7, 148463},
	{"VITEX", 5, 148464},
	{"SKATEBOARDERS", 13, 148465},
	{"AWESOMENESS", 11, 148466},
	{"JARREAU", 7, 148467},
	{"FOUST", 5, 148468},
	{"VISITER", 7, 148469},
	{"METHUSELAH", 10, 148470},
	{"AMCC", 4, 148471},
	{"IPCOP", 5, 148472},
	{"SANKAR", 6, 148473},
	{"DOWNHOLE", 8, 148474},
	{"SOFTSHELL", 9, 148475},
	{"RELLIHAN", 8, 148476},
	{"GIRISH", 6, 148477},
	{"YHAOO", 5, 148478},
	{"RUCL", 4, 148479},
	{"RTZT", 4, 148480},
	{"PYGO", 4, 148481},
	{"NUOL", 4, 148482},
	{"LLJI", 4, 148483},
	{"CUEV", 4, 148484},
	{"CDAI", 4, 148485},
	{"AWFE", 4, 148486},
	{"KOTLER", 6, 148487},
	{"GRAFICO", 7, 148488},
	{"MAFIC", 5, 148489},
	{"ASTROLOGIE", 10, 148490},
	{"DONOHOE", 7, 148491},
	{"DIZZEE", 6, 148492},
	{"LOGJAM", 6, 148493},
	{"CAMILLO", 7, 148494},
	{"PUSSSY", 6, 148495},
	{"ULB", 3, 148496},
	{"RCIA", 4, 148497},
	{"HAEMOPHILIA", 11, 148498},
	{"OUTLINER", 8, 148499},
	{"CLUMBER", 7, 148500},
	{"NIHILISTIC", 10, 148501},
	{"DEVALUE", 7, 148502},
	{"EXTORT", 6, 148503},
	{"SCHR", 4, 148504},
	{"STAATEN", 7, 148505},
	{"RENNAISANCE", 11, 148506},
	{"ESTIMA", 6, 148507},
	{"LAWYERING", 9, 148508},
	{"QUINTO", 6, 148509},
	{"GLEEFUL", 7, 148510},
	{"SHAKEY", 6, 148511},
	{"RICCIONE", 8, 148512},
	{"CHECKPOINTING", 13, 148513},
	{"VIGNETTING", 10, 148514},
	{"SPRIGHTLY", 9, 148515},
	{"CARVES", 6, 148516},
	{"MANNS", 5, 148517},
	{"ELECTRONICSTALK", 15, 148518},
	{"SPINKS", 6, 148519},
	{"GRINDSTONE", 10, 148520},
	{"SPEAKETH", 8, 148521},
	{"JORY", 4, 148522},
	{"TADEUSZ", 7, 148523},
	{"HYDROQUINONE", 12, 148524},
	{"FASTWEB", 7, 148525},
	{"SINGLEMODE", 10, 148526},
	{"NUENDO", 6, 148527},
	{"WORKCENTER", 10, 148528},
	{"ZZEN", 4, 148529},
	{"YEBU", 4, 148530},
	{"VAWO", 4, 148531},
	{"UCIR", 4, 148532},
	{"TMRH", 4, 148533},
	{"SVLA", 4, 148534},
	{"SEMD", 4, 148535},
	{"RZAA", 4, 148536},
	{"OGFA", 4, 148537},
	{"NTKU", 4, 148538},
	{"NDHM", 4, 148539},
	{"KPED", 4, 148540},
	{"INXM", 4, 148541},
	{"ILOQ", 4, 148542},
	{"HOXY", 4, 148543},
	{"FEOP", 4, 148544},
	{"EYDP", 4, 148545},
	{"DMRD", 4, 148546},
	{"AYEC", 4, 148547},
	{"NEVSKY", 6, 148548},
	{"REGISTRABLE", 11, 148549},
	{"KEWANEE", 7, 148550},
	{"GETINSTANCE", 11, 148551},
	{"ADASTRA", 7, 148552},
	{"SPIVAK", 6, 148553},
	{"ALLSTAYS", 8, 148554},
	{"SHEREE", 6, 148555},
	{"ROOFER", 6, 148556},
	{"VOLTRON", 7, 148557},
	{"VANNA", 5, 148558},
	{"REPLAYING", 9, 148559},
	{"DEALMAC", 7, 148560},
	{"COBBLES", 7, 148561},
	{"QUINONE", 7, 148562},
	{"TOVAR", 5, 148563},
	{"HILIGAYNON", 10, 148564},
	{"SACREDNESS", 10, 148565},
	{"MENTON", 6, 148566},
	{"EFORCE", 6, 148567},
	{"MONTEVALLO", 10, 148568},
	{"HEADINGTON", 10, 148569},
	{"PUNCHSTOCK", 10, 148570},
	{"RAINCOATS", 9, 148571},
	{"PETTICOATS", 10, 148572},
	{"NJDEP", 5, 148573},
	{"WOBBLING", 8, 148574},
	{"AIRAID", 6, 148575},
	{"NHANES", 6, 148576},
	{"IOWAHAWK", 8, 148577},
	{"INTERMARRIAGE", 13, 148578},
	{"ENGINEERI", 9, 148579},
	{"BACHE", 5, 148580},
	{"DEMODULATION", 12, 148581},
	{"CHRONIQUES", 10, 148582},
	{"HORSEHEADS", 10, 148583},
	{"PROFFER", 7, 148584},
	{"RACEFACE", 8, 148585},
	{"NSCC", 4, 148586},
	{"LIPOPOLYSACCHARIDES", 19, 148587},
	{"TNRCC", 5, 148588},
	{"THORNLEY", 8, 148589},
	{"HAPLY", 5, 148590},
	{"CHONDROCYTES", 12, 148591},
	{"SHOPING", 7, 148592},
	{"PRONOUNCES", 10, 148593},
	{"FUSSING", 7, 148594},
	{"MARILU", 6, 148595},
	{"SOLZHENITSYN", 12, 148596},
	{"PALINDROME", 10, 148597},
	{"POOPED", 6, 148598},
	{"FREEPICTURES", 12, 148599},
	{"BISOU", 5, 148600},
	{"ZSPE", 4, 148601},
	{"YLTO", 4, 148602},
	{"YBUZ", 4, 148603},
	{"UEWR", 4, 148604},
	{"RGFI", 4, 148605},
	{"RCUF", 4, 148606},
	{"PTVI", 4, 148607},
	{"OVIV", 4, 148608},
	{"OSUZ", 4, 148609},
	{"ORPN", 4, 148610},
	{"NDNM", 4, 148611},
	{"MAML", 4, 148612},
	{"LKDI", 4, 148613},
	{"IZRA", 4, 148614},
	{"IRKR", 4, 148615},
	{"IBSW", 4, 148616},
	{"HYSL", 4, 148617},
	{"HKRA", 4, 148618},
	{"GOMY", 4, 148619},
	{"GCAG", 4, 148620},
	{"FOWE", 4, 148621},
	{"AXRO", 4, 148622},
	{"HARVIE", 6, 148623},
	{"ALLENBY", 7, 148624},
	{"AANNDD", 6, 148625},
	{"EDUCATIO", 8, 148626},
	{"SPEEDBOOSTER", 12, 148627},
	{"KAVU", 4, 148628},
	{"BRABANTIA", 9, 148629},
	{"PAUILLAC", 8, 148630},
	{"MOTORCARS", 9, 148631},
	{"EXPENSING", 9, 148632},
	{"STRAGGLERS", 10, 148633},
	{"SCOWL", 5, 148634},
	{"GEOX", 4, 148635},
	{"TINDER", 6, 148636},
	{"PRIORITIZES", 11, 148637},
	{"NEUROMA", 7, 148638},
	{"BACKFIELD", 9, 148639},
	{"AGGIORNAMENTO", 13, 148640},
	{"GADGETRY", 8, 148641},
	{"MKP", 3, 148642},
	{"OMNISCIENCE", 11, 148643},
	{"SWSUSP", 6, 148644},
	{"TEAHOUSE", 8, 148645},
	{"SHAKILY", 7, 148646},
	{"CHATTERLIGHT", 12, 148647},
	{"DUNLEAVY", 8, 148648},
	{"POPULARES", 9, 148649},
	{"STOCKHAUSEN", 11, 148650},
	{"UTHSCSA", 7, 148651},
	{"LEICS", 5, 148652},
	{"ANALDEHNUNG", 11, 148653},
	{"CUELLAR", 7, 148654},
	{"FORLANI", 7, 148655},
	{"DEUEL", 5, 148656},
	{"JARMUSCH", 8, 148657},
	{"SCRIPTION", 9, 148658},
	{"DRESSMAKERS", 11, 148659},
	{"WIGLEY", 6, 148660},
	{"ANTANANARIVO", 12, 148661},
	{"SOULD", 5, 148662},
	{"ALBANO", 6, 148663},
	{"BETTERPHOTO", 11, 148664},
	{"WELCOM", 6, 148665},
	{"NEKED", 5, 148666},
	{"OOSTENDE", 8, 148667},
	{"SHOPPERSCHOICE", 14, 148668},
	{"FRANKLINCOVEY", 13, 148669},
	{"SOFTWEAR", 8, 148670},
	{"CONNACHT", 8, 148671},
	{"ALLEGIANCES", 11, 148672},
	{"ZFAI", 4, 148673},
	{"ZANZ", 4, 148674},
	{"XPIS", 4, 148675},
	{"UYVE", 4, 148676},
	{"UMOC", 4, 148677},
	{"UJUN", 4, 148678},
	{"SYCL", 4, 148679},
	{"SWAX", 4, 148680},
	{"RMFL", 4, 148681},
	{"RFOI", 4, 148682},
	{"NYLS", 4, 148683},
	{"LPAK", 4, 148684},
	{"LIZH", 4, 148685},
	{"KSIC", 4, 148686},
	{"IZAD", 4, 148687},
	{"CYET", 4, 148688},
	{"CKYU", 4, 148689},
	{"CHTB", 4, 148690},
	{"AUFR", 4, 148691},
	{"STATSGURU", 9, 148692},
	{"DOMAINES", 8, 148693},
	{"TESSCO", 6, 148694},
	{"LEADEN", 6, 148695},
	{"PIZZICATO", 9, 148696},
	{"MATTHEY", 7, 148697},
	{"BISONS", 6, 148698},
	{"DEFRAGMENTATION", 15, 148699},
	{"ADVANTAGEOUSLY", 14, 148700},
	{"DAYPOEMS", 8, 148701},
	{"SAPIEN", 6, 148702},
	{"DRIGGS", 6, 148703},
	{"RUANE", 5, 148704},
	{"ERFORMANCE", 10, 148705},
	{"MASOCHISTIC", 11, 148706},
	{"ONLINR", 6, 148707},
	{"SENTOSA", 7, 148708},
	{"GIORGI", 6, 148709},
	{"SUESS", 5, 148710},
	{"ASIAGO", 6, 148711},
	{"VANDE", 5, 148712},
	{"BEGALA", 6, 148713},
	{"SECRETO", 7, 148714},
	{"KINDEREN", 8, 148715},
	{"PROLYL", 6, 148716},
	{"MESKILL", 7, 148717},
	{"POUNCED", 7, 148718},
	{"MONNET", 6, 148719},
	{"NEUROBIOL", 9, 148720},
	{"FAMINES", 7, 148721},
	{"WOLLTE", 6, 148722},
	{"JOLSON", 6, 148723},
	{"CARPETBAGGER", 12, 148724},
	{"BAYEUX", 6, 148725},
	{"DRUK", 4, 148726},
	{"XGRE", 4, 148727},
	{"WTAB", 4, 148728},
	{"UCAI", 4, 148729},
	{"RCAH", 4, 148730},
	{"NGLL", 4, 148731},
	{"NEZR", 4, 148732},
	{"NCAY", 4, 148733},
	{"NBLV", 4, 148734},
	{"MSYR", 4, 148735},
	{"MCMO", 4, 148736},
	{"LFSW", 4, 148737},
	{"IGYO", 4, 148738},
	{"GPIS", 4, 148739},
	{"FUMN", 4, 148740},
	{"EVDA", 4, 148741},
	{"FANTAGRAPHICS", 13, 148742},
	{"CARRIZO", 7, 148743},
	{"SONGTEKST", 9, 148744},
	{"TEIGNMOUTH", 10, 148745},
	{"XANTHINE", 8, 148746},
	{"COMUNITY", 8, 148747},
	{"SUCKIN", 6, 148748},
	{"BREVIS", 6, 148749},
	{"IGLU", 4, 148750},
	{"LIPOSOME", 8, 148751},
	{"CIENA", 5, 148752},
	{"VIDEOSEVEN", 10, 148753},
	{"HALBERT", 7, 148754},
	{"DETLEF", 6, 148755},
	{"QURANIC", 7, 148756},
	{"TERTULLIAN", 10, 148757},
	{"MERITAGE", 8, 148758},
	{"RENMIMBI", 8, 148759},
	{"BAGO", 4, 148760},
	{"CHAUVINISM", 10, 148761},
	{"DEVANEY", 7, 148762},
	{"ARTFORM", 7, 148763},
	{"ERING", 5, 148764},
	{"BASEPLATE", 9, 148765},
	{"PEMA", 4, 148766},
	{"ELPIDA", 6, 148767},
	{"TUBI", 4, 148768},
	{"SNAPFISH", 8, 148769},
	{"POMPE", 5, 148770},
	{"OLIKA", 5, 148771},
	{"FASTIDIOUS", 10, 148772},
	{"TEXLIVE", 7, 148773},
	{"COXSACKIE", 9, 148774},
	{"BELCH", 5, 148775},
	{"OXIDIZE", 7, 148776},
	{"JAMMA", 5, 148777},
	{"COATBRIDGE", 10, 148778},
	{"COKING", 6, 148779},
	{"WIKISYNTAX", 10, 148780},
	{"ENSCONCED", 9, 148781},
	{"GENNADY", 7, 148782},
	{"TUDY", 4, 148783},
	{"ASSINIBOINE", 11, 148784},
	{"ILOCOS", 6, 148785},
	{"CYPRIAN", 7, 148786},
	{"FELS", 4, 148787},
	{"YURV", 4, 148788},
	{"XESG", 4, 148789},
	{"WOKN", 4, 148790},
	{"VARK", 4, 148791},
	{"UDSS", 4, 148792},
	{"ROWJ", 4, 148793},
	{"ROEP", 4, 148794},
	{"RLCR", 4, 148795},
	{"OYUS", 4, 148796},
	{"OUHU", 4, 148797},
	{"OLSQ", 4, 148798},
	{"NUMH", 4, 148799},
	{"NAYU", 4, 148800},
	{"MIEP", 4, 148801},
	{"LABF", 4, 148802},
	{"FZOO", 4, 148803},
	{"FTOJ", 4, 148804},
	{"ALPY", 4, 148805},
	{"ABFR", 4, 148806},
	{"LYCORIS", 7, 148807},
	{"UWSP", 4, 148808},
	{"MICROBITE", 9, 148809},
	{"RESPONSABILITY", 14, 148810},
	{"FLABBERGASTED", 13, 148811},
	{"TRUCKLOADS", 10, 148812},
	{"AYLWARD", 7, 148813},
	{"POLICED", 7, 148814},
	{"SPECTROMETRIC", 13, 148815},
	{"KARPOV", 6, 148816},
	{"EXONUCLEASE", 11, 148817},
	{"TASCHENBUCH", 11, 148818},
	{"LIZENZ", 6, 148819},
	{"SPADER", 6, 148820},
	{"CHABON", 6, 148821},
	{"SAGACITY", 8, 148822},
	{"KOCK", 4, 148823},
	{"LIMEY", 5, 148824},
	{"JOBSGUIDE", 9, 148825},
	{"TONSILLITIS", 11, 148826},
	{"KISSIN", 6, 148827},
	{"WEDDERBURN", 10, 148828},
	{"NIPPING", 7, 148829},
	{"TRITICALE", 9, 148830},
	{"TATAMI", 6, 148831},
	{"SITECOM", 7, 148832},
	{"RGDS", 4, 148833},
	{"FILLABLE", 8, 148834},
	{"AVOCATS", 7, 148835},
	{"HLMP", 4, 148836},
	{"OAKLAWN", 7, 148837},
	{"ULTRASTAR", 9, 148838},
	{"VULNS", 5, 148839},
	{"HWANGE", 6, 148840},
	{"WCCP", 4, 148841},
	{"UKSCRAPPERS", 11, 148842},
	{"FOGS", 4, 148843},
	{"BARYONS", 7, 148844},
	{"LOVINS", 6, 148845},
	{"UDOO", 4, 148846},
	{"TGLU", 4, 148847},
	{"SNUD", 4, 148848},
	{"REVY", 4, 148849},
	{"RAGP", 4, 148850},
	{"NKKI", 4, 148851},
	{"KSMY", 4, 148852},
	{"KOZU", 4, 148853},
	{"FOGI", 4, 148854},
	{"FIPH", 4, 148855},
	{"EFFN", 4, 148856},
	{"BYIG", 4, 148857},
	{"APTW", 4, 148858},
	{"HEALT", 5, 148859},
	{"RUTHIN", 6, 148860},
	{"CUTESY", 6, 148861},
	{"POLYCHROME", 10, 148862},
	{"DOLIONES", 8, 148863},
	{"LUTH", 4, 148864},
	{"KENER", 5, 148865},
	{"FOWLES", 6, 148866},
	{"GRAPHED", 7, 148867},
	{"RFL", 3, 148868},
	{"NANOSECONDS", 11, 148869},
	{"TRIFOLD", 7, 148870},
	{"BOSTIC", 6, 148871},
	{"ROYO", 4, 148872},
	{"DVBE", 4, 148873},
	{"DANFOSS", 7, 148874},
	{"SESSILE", 7, 148875},
	{"LIGER", 5, 148876},
	{"RESPUESTA", 9, 148877},
	{"PICCOLI", 7, 148878},
	{"ADEC", 4, 148879},
	{"AUSBILDUNG", 10, 148880},
	{"ORIGIONAL", 9, 148881},
	{"YOSHIO", 6, 148882},
	{"HERECLICK", 9, 148883},
	{"RESV", 4, 148884},
	{"IQPC", 4, 148885},
	{"SUBDISTRICT", 11, 148886},
	{"BANNERMAN", 9, 148887},
	{"PINELANDS", 9, 148888},
	{"MISPERCEPTIONS", 14, 148889},
	{"CONTACTABOUT", 12, 148890},
	{"GUNGRAVE", 8, 148891},
	{"BOXLIGHT", 8, 148892},
	{"GAUGHAN", 7, 148893},
	{"BOYSTUFF", 8, 148894},
	{"ZZOR", 4, 148895},
	{"XMAD", 4, 148896},
	{"URUF", 4, 148897},
	{"UKIR", 4, 148898},
	{"SWIZ", 4, 148899},
	{"RMOE", 4, 148900},
	{"LMLO", 4, 148901},
	{"LFJO", 4, 148902},
	{"LBIB", 4, 148903},
	{"KAED", 4, 148904},
	{"JELI", 4, 148905},
	{"IGVE", 4, 148906},
	{"HPAV", 4, 148907},
	{"HBYG", 4, 148908},
	{"GRYL", 4, 148909},
	{"GKIR", 4, 148910},
	{"FTSY", 4, 148911},
	{"FLDE", 4, 148912},
	{"FKEI", 4, 148913},
	{"FGIG", 4, 148914},
	{"ERPD", 4, 148915},
	{"CTOK", 4, 148916},
	{"CAEU", 4, 148917},
	{"ARPG", 4, 148918},
	{"MDPRO", 5, 148919},
	{"DEFINI", 6, 148920},
	{"CWRU", 4, 148921},
	{"PROTESTATIONS", 13, 148922},
	{"ENGELBERG", 9, 148923},
	{"XGL", 3, 148924},
	{"AGITPROP", 8, 148925},
	{"PHPGEDVIEW", 10, 148926},
	{"BLOGWARE", 8, 148927},
	{"FILEENCODING", 12, 148928},
	{"BRUSCHETTA", 10, 148929},
	{"AXKIT", 5, 148930},
	{"TRICKLED", 8, 148931},
	{"MCMULLAN", 8, 148932},
	{"RHCE", 4, 148933},
	{"CANYONING", 9, 148934},
	{"REEDLEY", 7, 148935},
	{"EAGLETON", 8, 148936},
	{"FLIPSYDE", 8, 148937},
	{"BALAZS", 6, 148938},
	{"LUGLIO", 6, 148939},
	{"TORII", 5, 148940},
	{"HANSFORD", 8, 148941},
	{"NIGHTER", 7, 148942},
	{"WHOLES", 6, 148943},
	{"REDISPLAY", 9, 148944},
	{"MALLIKA", 7, 148945},
	{"WINCO", 5, 148946},
	{"BARNESANDNOBLE", 14, 148947},
	{"PENNOCK", 7, 148948},
	{"AYLA", 4, 148949},
	{"WEIPA", 5, 148950},
	{"LUNGO", 5, 148951},
	{"ZSIM", 4, 148952},
	{"UVEF", 4, 148953},
	{"ULKW", 4, 148954},
	{"UAYI", 4, 148955},
	{"SCBR", 4, 148956},
	{"RDKR", 4, 148957},
	{"PURH", 4, 148958},
	{"OURZ", 4, 148959},
	{"MMLO", 4, 148960},
	{"MLEB", 4, 148961},
	{"MBPR", 4, 148962},
	{"JANL", 4, 148963},
	{"IPJA", 4, 148964},
	{"ERPY", 4, 148965},
	{"AKUK", 4, 148966},
	{"AARB", 4, 148967},
	{"MATTO", 5, 148968},
	{"KMALLOC", 7, 148969},
	{"ERDE", 4, 148970},
	{"ANALPHILOSOPHER", 15, 148971},
	{"SEEMA", 5, 148972},
	{"IFPRI", 5, 148973},
	{"CYTOPATHOLOGY", 13, 148974},
	{"BOLOETSE", 8, 148975},
	{"MIRCEA", 6, 148976},
	{"SAVY", 4, 148977},
	{"KORDA", 5, 148978},
	{"CATALOGER", 9, 148979},
	{"FONDLED", 7, 148980},
	{"TREKLENS", 8, 148981},
	{"POIDS", 5, 148982},
	{"WISTFULLY", 9, 148983},
	{"SSHRC", 5, 148984},
	{"ABOUNDED", 8, 148985},
	{"UITGEVER", 8, 148986},
	{"EVANGELIZE", 10, 148987},
	{"ROSENSTEIN", 10, 148988},
	{"HEUREUX", 7, 148989},
	{"FACULTEIT", 9, 148990},
	{"DISLOYAL", 8, 148991},
	{"PARALYZING", 10, 148992},
	{"SIDHE", 5, 148993},
	{"GOODSPEED", 9, 148994},
	{"VANSTONE", 8, 148995},
	{"PLEVEN", 6, 148996},
	{"WATERVLIET", 10, 148997},
	{"FREELANCEDESIGNERS", 18, 148998},
	{"NISUS", 5, 148999},
	{"COUNTERINSURGENCY", 17, 149000},
	{"FLATRON", 7, 149001},
	{"PHRED", 5, 149002},
	{"PLONK", 5, 149003},
	{"HOSKING", 7, 149004},
	{"STAGGERS", 8, 149005},
	{"DRAYTEK", 7, 149006},
	{"ZRET", 4, 149007},
	{"YGMA", 4, 149008},
	{"SUOM", 4, 149009},
	{"PPHE", 4, 149010},
	{"MADF", 4, 149011},
	{"IXBL", 4, 149012},
	{"HOYL", 4, 149013},
	{"GGUL", 4, 149014},
	{"GETQ", 4, 149015},
	{"FBOG", 4, 149016},
	{"ELMD", 4, 149017},
	{"DTVP", 4, 149018},
	{"DKOH", 4, 149019},
	{"BNAB", 4, 149020},
	{"CONTORTED", 9, 149021},
	{"PREPAC", 6, 149022},
	{"RAMBAM", 6, 149023},
	{"ODDJACK", 7, 149024},
	{"POLEMICAL", 9, 149025},
	{"WALTHERS", 8, 149026},
	{"IFIED", 5, 149027},
	{"TINGLEY", 7, 149028},
	{"SPERMATOPHYTA", 13, 149029},
	{"JAYNA", 5, 149030},
	{"MATSUO", 6, 149031},
	{"CHERRYPY", 8, 149032},
	{"ISPYNOW", 7, 149033},
	{"NEIGHBORLY", 10, 149034},
	{"KANNEL", 6, 149035},
	{"VISWANATHAN", 11, 149036},
	{"SPORRAN", 7, 149037},
	{"HERWIG", 6, 149038},
	{"MEISNER", 7, 149039},
	{"OVERLAWYERED", 12, 149040},
	{"ADONLINE", 8, 149041},
	{"CHARLET", 7, 149042},
	{"NOUMEA", 6, 149043},
	{"CULEBRA", 7, 149044},
	{"DEFECTOR", 8, 149045},
	{"PHOTOIMPACT", 11, 149046},
	{"SIEMON", 6, 149047},
	{"NARANJO", 7, 149048},
	{"TROILUS", 7, 149049},
	{"KERWIN", 6, 149050},
	{"SUPERCHARGE", 11, 149051},
	{"MONTLAKE", 8, 149052},
	{"ABELSON", 7, 149053},
	{"JEWELLRY", 8, 149054},
	{"FEIRA", 5, 149055},
	{"OHMIC", 5, 149056},
	{"CTAG", 4, 149057},
	{"HEALTHOLOGY", 11, 149058},
	{"HARAN", 5, 149059},
	{"WRINKLY", 7, 149060},
	{"STUNTMAN", 8, 149061},
	{"YEOMANS", 7, 149062},
	{"PARSNIP", 7, 149063},
	{"PLMN", 4, 149064},
	{"UMEU", 4, 149065},
	{"TVLI", 4, 149066},
	{"SGUZ", 4, 149067},
	{"QDID", 4, 149068},
	{"OVKA", 4, 149069},
	{"LGLE", 4, 149070},
	{"JMAH", 4, 149071},
	{"IHUR", 4, 149072},
	{"HGAB", 4, 149073},
	{"GNAK", 4, 149074},
	{"GKAL", 4, 149075},
	{"FSPU", 4, 149076},
	{"COGG", 4, 149077},
	{"CFAB", 4, 149078},
	{"CEIB", 4, 149079},
	{"BPOI", 4, 149080},
	{"ZILLIONS", 8, 149081},
	{"INFOIMAGING", 11, 149082},
	{"CREWMEN", 7, 149083},
	{"LIVEABOARDS", 11, 149084},
	{"ALIYEV", 6, 149085},
	{"VOLUTPAT", 8, 149086},
	{"OROLOGI", 7, 149087},
	{"ANNATOPIA", 9, 149088},
	{"TOUGHEN", 7, 149089},
	{"YISROEL", 7, 149090},
	{"LIPOXYGENASE", 12, 149091},
	{"LONGLEAF", 8, 149092},
	{"DONZI", 5, 149093},
	{"INTRAEPITHELIAL", 15, 149094},
	{"EINHORN", 7, 149095},
	{"ELIYAHU", 7, 149096},
	{"RADIOTELEPHONE", 14, 149097},
	{"SHIZZLE", 7, 149098},
	{"PAGINATED", 9, 149099},
	{"SOYLENT", 7, 149100},
	{"INGLATERRA", 10, 149101},
	{"SUPERBOY", 8, 149102},
	{"LANSOPRAZOLE", 12, 149103},
	{"ATTUNEMENT", 10, 149104},
	{"ENCED", 5, 149105},
	{"BEATE", 5, 149106},
	{"OGOPLEX", 7, 149107},
	{"LASHER", 6, 149108},
	{"HELSINGBORG", 11, 149109},
	{"RVSM", 4, 149110},
	{"WRACKED", 7, 149111},
	{"GIRBAUD", 7, 149112},
	{"ZBOARD", 6, 149113},
	{"WINDLEY", 7, 149114},
	{"KOWA", 4, 149115},
	{"DABBLED", 7, 149116},
	{"YNNF", 4, 149117},
	{"XOLO", 4, 149118},
	{"WHUS", 4, 149119},
	{"UWEI", 4, 149120},
	{"RKUL", 4, 149121},
	{"RBEQ", 4, 149122},
	{"PEOV", 4, 149123},
	{"MPMF", 4, 149124},
	{"MABD", 4, 149125},
	{"IKYO", 4, 149126},
	{"GDUB", 4, 149127},
	{"DEAQ", 4, 149128},
	{"CDPH", 4, 149129},
	{"BCAB", 4, 149130},
	{"AKOD", 4, 149131},
	{"ADOY", 4, 149132},
	{"SOLOW", 5, 149133},
	{"VILLES", 6, 149134},
	{"GETURL", 6, 149135},
	{"HONEYBEES", 9, 149136},
	{"ZXG", 3, 149137},
	{"ZWZ", 3, 149138},
	{"YRQ", 3, 149139},
	{"WVX", 3, 149140},
	{"QFB", 3, 149141},
	{"MWQ", 3, 149142},
	{"JZB", 3, 149143},
	{"GXK", 3, 149144},
	{"GXJ", 3, 149145},
	{"BXU", 3, 149146},
	{"QUICKLOOK", 9, 149147},
	{"FACTFINDER", 10, 149148},
	{"CONTRIBUTER", 11, 149149},
	{"GLAUCA", 6, 149150},
	{"PADAWAN", 7, 149151},
	{"LANNER", 6, 149152},
	{"CONSULTEES", 10, 149153},
	{"LCLHEP", 6, 149154},
	{"KORRES", 6, 149155},
	{"GALVAN", 6, 149156},
	{"PROGRAMMINGTALK", 15, 149157},
	{"BIDDULPH", 8, 149158},
	{"IRIDOLOGY", 9, 149159},
	{"CONNELLSVILLE", 13, 149160},
	{"CHOON", 5, 149161},
	{"MANYELETI", 9, 149162},
	{"DICES", 5, 149163},
	{"EVAPORATORS", 11, 149164},
	{"BILDE", 5, 149165},
	{"BOUGUEREAU", 10, 149166},
	{"HEMODYNAMICS", 12, 149167},
	{"ACOUSTIMASS", 11, 149168},
	{"UNRECOGNISED", 12, 149169},
	{"COLSTON", 7, 149170},
	{"PITEOUS", 7, 149171},
	{"CREDANT", 7, 149172},
	{"OCSP", 4, 149173},
	{"ROBINA", 6, 149174},
	{"NBYTES", 6, 149175},
	{"HAIRSTYLING", 11, 149176},
	{"PERFUNCTORY", 11, 149177},
	{"JABBAR", 6, 149178},
	{"BURRARD", 7, 149179},
	{"PERVADED", 8, 149180},
	{"PITTA", 5, 149181},
	{"KRUPPS", 6, 149182},
	{"PERFORMATIVE", 12, 149183},
	{"LAVOISIER", 9, 149184},
	{"COMPRADORES", 11, 149185},
	{"HARTSHORNE", 10, 149186},
	{"DOORSTEPS", 9, 149187},
	{"ZDES", 4, 149188},
	{"YPSU", 4, 149189},
	{"WWEF", 4, 149190},
	{"WOWR", 4, 149191},
	{"UDIL", 4, 149192},
	{"UDFR", 4, 149193},
	{"OYEM", 4, 149194},
	{"OKJA", 4, 149195},
	{"OBMI", 4, 149196},
	{"NGBP", 4, 149197},
	{"MHYP", 4, 149198},
	{"MDUC", 4, 149199},
	{"KSIZ", 4, 149200},
	{"KHMA", 4, 149201},
	{"JIUJ", 4, 149202},
	{"HIBR", 4, 149203},
	{"FPAM", 4, 149204},
	{"EYUL", 4, 149205},
	{"BBIM", 4, 149206},
	{"ATDB", 4, 149207},
	{"BAIER", 5, 149208},
	{"FALSETTO", 8, 149209},
	{"INTRANASAL", 10, 149210},
	{"GILERA", 6, 149211},
	{"MISSTRESS", 9, 149212},
	{"SKIDOO", 6, 149213},
	{"TIMERANG", 8, 149214},
	{"GREENBRIAR", 10, 149215},
	{"BERRIE", 6, 149216},
	{"AUTOCONFIGURATION", 17, 149217},
	{"INCHING", 7, 149218},
	{"FOXHOUND", 8, 149219},
	{"EXTRATERRESTRIALS", 17, 149220},
	{"BULLFIGHTING", 12, 149221},
	{"HUEVOS", 6, 149222},
	{"TATTERS", 7, 149223},
	{"SUBSTITUENTS", 12, 149224},
	{"PARDUE", 6, 149225},
	{"PUISSANCE", 9, 149226},
	{"COALBED", 7, 149227},
	{"TUNICS", 6, 149228},
	{"MUESLI", 6, 149229},
	{"PROTRUSIONS", 11, 149230},
	{"NUTRASPORT", 10, 149231},
	{"ARDENNE", 7, 149232},
	{"LIBARY", 6, 149233},
	{"ICAC", 4, 149234},
	{"BYTESTOR", 8, 149235},
	{"NEXGEN", 6, 149236},
	{"RAIHAN", 6, 149237},
	{"OSMIUM", 6, 149238},
	{"LEPERS", 6, 149239},
	{"VIVASTREET", 10, 149240},
	{"PERCEPT", 7, 149241},
	{"GLOATING", 8, 149242},
	{"CRIMINALIZATION", 15, 149243},
	{"DISMEMBERED", 11, 149244},
	{"PORTH", 5, 149245},
	{"TIMESTEP", 8, 149246},
	{"NESCAC", 6, 149247},
	{"STRATEGYPAGE", 12, 149248},
	{"ICELANDAIR", 10, 149249},
	{"BRUS", 4, 149250},
	{"XQES", 4, 149251},
	{"EIRP", 4, 149252},
	{"HIERRO", 6, 149253},
	{"CONTRAPTIONS", 12, 149254},
	{"CAGR", 4, 149255},
	{"PERFIDY", 7, 149256},
	{"YOMK", 4, 149257},
	{"YDUL", 4, 149258},
	{"WDOO", 4, 149259},
	{"UYWE", 4, 149260},
	{"UEPM", 4, 149261},
	{"OPIF", 4, 149262},
	{"OGBI", 4, 149263},
	{"OELG", 4, 149264},
	{"OCAW", 4, 149265},
	{"NUWI", 4, 149266},
	{"NDGT", 4, 149267},
	{"HEGF", 4, 149268},
	{"GWIG", 4, 149269},
	{"GMAU", 4, 149270},
	{"DEXU", 4, 149271},
	{"BTWE", 4, 149272},
	{"BOUI", 4, 149273},
	{"MINNE", 5, 149274},
	{"DENATURING", 10, 149275},
	{"CCEA", 4, 149276},
	{"LAMPERT", 7, 149277},
	{"DEADBOLT", 8, 149278},
	{"SOCKLOG", 7, 149279},
	{"CENTRALISATION", 14, 149280},
	{"SHIVE", 5, 149281},
	{"MEANER", 6, 149282},
	{"JBUTTON", 7, 149283},
	{"LOMI", 4, 149284},
	{"PSALTER", 7, 149285},
	{"HOSTAP", 6, 149286},
	{"ULIKE", 5, 149287},
	{"REGULARIZED", 11, 149288},
	{"IRLANDA", 7, 149289},
	{"THERMA", 6, 149290},
	{"LONOKE", 6, 149291},
	{"ASIANGIRLS", 10, 149292},
	{"PROPOUNDED", 10, 149293},
	{"VECT", 4, 149294},
	{"ISOZYME", 7, 149295},
	{"GORDIE", 6, 149296},
	{"VALOIS", 6, 149297},
	{"MRR", 3, 149298},
	{"LENAWEE", 7, 149299},
	{"LINARES", 7, 149300},
	{"BOWNE", 5, 149301},
	{"RAGHU", 5, 149302},
	{"ZIMA", 4, 149303},
	{"CHAYNES", 7, 149304},
	{"SAGUENAY", 8, 149305},
	{"VFL", 3, 149306},
	{"REARPROJECTIONTELEVISION", 24, 149307},
	{"SPIKEY", 6, 149308},
	{"ASPNET", 6, 149309},
	{"ROAMER", 6, 149310},
	{"EMBEDDINGS", 10, 149311},
	{"FLORESCENT", 10, 149312},
	{"MCCAW", 5, 149313},
	{"MYRINET", 7, 149314},
	{"COMSAT", 6, 149315},
	{"INSUBORDINATION", 15, 149316},
	{"TEEPEE", 6, 149317},
	{"FETICHISME", 10, 149318},
	{"ALLOWWEBRENAME", 14, 149319},
	{"CHCH", 4, 149320},
	{"MAQUETTE", 8, 149321},
	{"APGAR", 5, 149322},
	{"BAYT", 4, 149323},
	{"YHIC", 4, 149324},
	{"UYUS", 4, 149325},
	{"OCTC", 4, 149326},
	{"OCTB", 4, 149327},
	{"NGWY", 4, 149328},
	{"HBIB", 4, 149329},
	{"FYOG", 4, 149330},
	{"FCEM", 4, 149331},
	{"ECBI", 4, 149332},
	{"CROV", 4, 149333},
	{"BVIS", 4, 149334},
	{"BOMO", 4, 149335},
	{"HAGLER", 6, 149336},
	{"DIABOLO", 7, 149337},
	{"SETAUKET", 8, 149338},
	{"REIMBURSING", 11, 149339},
	{"FNMA", 4, 149340},
	{"DRES", 4, 149341},
	{"IMPIOUS", 7, 149342},
	{"ABSOLVED", 8, 149343},
	{"ILOUNGE", 7, 149344},
	{"SEVERSON", 8, 149345},
	{"INTERCOMPARISON", 15, 149346},
	{"LEVENSON", 8, 149347},
	{"DISHONORED", 10, 149348},
	{"PENRYN", 6, 149349},
	{"VIVIR", 5, 149350},
	{"LEADBETTER", 10, 149351},
	{"MULFORD", 7, 149352},
	{"WAGSTAFF", 8, 149353},
	{"FUJISAWA", 8, 149354},
	{"HYDROGEL", 8, 149355},
	{"BEBO", 4, 149356},
	{"GALANTE", 7, 149357},
	{"NORTHEN", 7, 149358},
	{"BATHSHEBA", 9, 149359},
	{"ROBUSTA", 7, 149360},
	{"MAGICALIA", 9, 149361},
	{"DEEJAYS", 7, 149362},
	{"MAKAI", 5, 149363},
	{"KLARA", 5, 149364},
	{"CARINE", 6, 149365},
	{"PARAGONSPORTS", 13, 149366},
	{"PLAQUEMINES", 11, 149367},
	{"SNAPPERS", 8, 149368},
	{"WASHBASIN", 9, 149369},
	{"TRUNC", 5, 149370},
	{"STILTED", 7, 149371},
	{"RADIA", 5, 149372},
	{"MATHIESON", 9, 149373},
	{"PILIPINO", 8, 149374},
	{"FESTSCHRIFT", 11, 149375},
	{"DILAUDID", 8, 149376},
	{"AUXERRE", 7, 149377},
	{"ZRAN", 4, 149378},
	{"ZCZE", 4, 149379},
	{"WIME", 4, 149380},
	{"TYUK", 4, 149381},
	{"RGGR", 4, 149382},
	{"RCYM", 4, 149383},
	{"OKGE", 4, 149384},
	{"OBVE", 4, 149385},
	{"NMAB", 4, 149386},
	{"MILR", 4, 149387},
	{"MABH", 4, 149388},
	{"LURO", 4, 149389},
	{"LPIO", 4, 149390},
	{"LHIK", 4, 149391},
	{"IVAP", 4, 149392},
	{"HEBW", 4, 149393},
	{"FRSQ", 4, 149394},
	{"FGOE", 4, 149395},
	{"ELWY", 4, 149396},
	{"CDIG", 4, 149397},
	{"BYIB", 4, 149398},
	{"AZYG", 4, 149399},
	{"FREEBORDERS", 11, 149400},
	{"MUZICA", 6, 149401},
	{"HASTENING", 9, 149402},
	{"APERITIF", 8, 149403},
	{"DINES", 5, 149404},
	{"COEXTENSIVE", 11, 149405},
	{"WHIZZ", 5, 149406},
	{"TLINGIT", 7, 149407},
	{"PHENYLPROPANOLAMINE", 19, 149408},
	{"LABATT", 6, 149409},
	{"CLICHED", 7, 149410},
	{"BIOSIS", 6, 149411},
	{"BIGATTI", 7, 149412},
	{"MICROSEMI", 9, 149413},
	{"CURRENTPOINT", 12, 149414},
	{"TWIKIVARIABLESNTOZ", 18, 149415},
	{"CHELLE", 6, 149416},
	{"NCIC", 4, 149417},
	{"HOSSEINI", 8, 149418},
	{"ELEFANT", 7, 149419},
	{"TOMIE", 5, 149420},
	{"PRESTATYN", 9, 149421},
	{"DOWNPATRICK", 11, 149422},
	{"OUTPERFORMING", 13, 149423},
	{"INTERNAZIONALI", 14, 149424},
	{"DVMRP", 5, 149425},
	{"PATANOL", 7, 149426},
	{"FUSILIERS", 9, 149427},
	{"ROTISERIE", 9, 149428},
	{"MEGAFITNESS", 11, 149429},
	{"GYR", 3, 149430},
	{"MPSC", 4, 149431},
	{"GUNTERSVILLE", 12, 149432},
	{"LENIHAN", 7, 149433},
	{"VFC", 3, 149434},
	{"MYKISS", 6, 149435},
	{"WEATHERGIRL", 11, 149436},
	{"CAPON", 5, 149437},
	{"UNREALISED", 10, 149438},
	{"INTERSESSION", 12, 149439},
	{"LOVELANDIA", 10, 149440},
	{"WEAKLEY", 7, 149441},
	{"MONETIZE", 8, 149442},
	{"DIOSKE", 6, 149443},
	{"WEBSEITEN", 9, 149444},
	{"SYNECHOCYSTIS", 13, 149445},
	{"TIBBETTS", 8, 149446},
	{"ZHAK", 4, 149447},
	{"ZELM", 4, 149448},
	{"UXFA", 4, 149449},
	{"UDFL", 4, 149450},
	{"PSIB", 4, 149451},
	{"OKIK", 4, 149452},
	{"NAPD", 4, 149453},
	{"LIEZ", 4, 149454},
	{"KWEM", 4, 149455},
	{"KTIG", 4, 149456},
	{"HUAP", 4, 149457},
	{"GYAH", 4, 149458},
	{"GOKI", 4, 149459},
	{"EZAF", 4, 149460},
	{"DKAA", 4, 149461},
	{"DAIW", 4, 149462},
	{"CDOF", 4, 149463},
	{"AYKR", 4, 149464},
	{"AGWO", 4, 149465},
	{"ORDS", 4, 149466},
	{"STIFFLY", 7, 149467},
	{"SUNRPC", 6, 149468},
	{"MERMAN", 6, 149469},
	{"CHRONOLOGIES", 12, 149470},
	{"MORIMOTO", 8, 149471},
	{"FAJITA", 6, 149472},
	{"DENYWEBRENAME", 13, 149473},
	{"UPRIMA", 6, 149474},
	{"PUNXSUTAWNEY", 12, 149475},
	{"NEXPAK", 6, 149476},
	{"BITZ", 4, 149477},
	{"CIOJURY", 7, 149478},
	{"CXOEXTRA", 8, 149479},
	{"HARTVILLE", 9, 149480},
	{"WHANAU", 6, 149481},
	{"ONLINEPOKER", 11, 149482},
	{"FOLGENDEN", 9, 149483},
	{"DIAMANTI", 8, 149484},
	{"CACHER", 6, 149485},
	{"GRAMPA", 6, 149486},
	{"BMWS", 4, 149487},
	{"MICROLIGHT", 10, 149488},
	{"NASTINESS", 9, 149489},
	{"LANGARA", 7, 149490},
	{"THERAVADA", 9, 149491},
	{"SLUMBERLAND", 11, 149492},
	{"MAGGS", 5, 149493},
	{"FESTIVITY", 9, 149494},
	{"TONGASS", 7, 149495},
	{"COLLECTABL", 10, 149496},
	{"RESEARCHMIDTAB", 14, 149497},
	{"GRK", 3, 149498},
	{"MOFOS", 5, 149499},
	{"BLADING", 7, 149500},
	{"AWANA", 5, 149501},
	{"GEMARA", 6, 149502},
	{"IBACKUP", 7, 149503},
	{"TAKUMI", 6, 149504},
	{"UNYE", 4, 149505},
	{"RKEO", 4, 149506},
	{"PSGU", 4, 149507},
	{"OPMJ", 4, 149508},
	{"ONWV", 4, 149509},
	{"OKUL", 4, 149510},
	{"OFMG", 4, 149511},
	{"NIXD", 4, 149512},
	{"MUZA", 4, 149513},
	{"MTVE", 4, 149514},
	{"METK", 4, 149515},
	{"LKOT", 4, 149516},
	{"LIOV", 4, 149517},
	{"HYIC", 4, 149518},
	{"FBUG", 4, 149519},
	{"EUSY", 4, 149520},
	{"BIME", 4, 149521},
	{"AHWR", 4, 149522},
	{"NGVD", 4, 149523},
	{"SLATWALL", 8, 149524},
	{"MUSSO", 5, 149525},
	{"KARADZIC", 8, 149526},
	{"ANAYA", 5, 149527},
	{"DROGA", 5, 149528},
	{"BECR", 4, 149529},
	{"THESSALY", 8, 149530},
	{"WASL", 4, 149531},
	{"METALLICS", 9, 149532},
	{"TAKU", 4, 149533},
	{"ISCHAEMIA", 9, 149534},
	{"MISSAL", 6, 149535},
	{"CALPAIN", 7, 149536},
	{"CAHNERS", 7, 149537},
	{"EICHLER", 7, 149538},
	{"SETSERIAL", 9, 149539},
	{"QIPO", 4, 149540},
	{"PROCESSIONAL", 12, 149541},
	{"LYNGSAT", 7, 149542},
	{"CATHRYN", 7, 149543},
	{"MATSUOKA", 8, 149544},
	{"MAKEDEV", 7, 149545},
	{"FOLGENDE", 8, 149546},
	{"NVQS", 4, 149547},
	{"YONAH", 5, 149548},
	{"SLAYTON", 7, 149549},
	{"HAVOK", 5, 149550},
	{"ENERGIZES", 9, 149551},
	{"JARKKO", 6, 149552},
	{"NONOPERATING", 12, 149553},
	{"AYRE", 4, 149554},
	{"LACRIMAL", 8, 149555},
	{"COMMEDIA", 8, 149556},
	{"AUTOPILOTS", 10, 149557},
	{"FOOTLOCKER", 10, 149558},
	{"KEYPORT", 7, 149559},
	{"UPPERCUT", 8, 149560},
	{"ABOUTS", 6, 149561},
	{"BROWNVILLE", 10, 149562},
	{"MELHOR", 6, 149563},
	{"RECHERCHEZ", 10, 149564},
	{"SINGLEPLAYER", 12, 149565},
	{"GEKKO", 5, 149566},
	{"ASCOM", 5, 149567},
	{"KATONAH", 7, 149568},
	{"HYDRANGEAS", 10, 149569},
	{"AUTOBODY", 8, 149570},
	{"AFIRE", 5, 149571},
	{"SOWED", 5, 149572},
	{"COOKTOWN", 8, 149573},
	{"CHATMAN", 7, 149574},
	{"PROPRIO", 7, 149575},
	{"MARKETINGVOX", 12, 149576},
	{"EXAMINEES", 9, 149577},
	{"ZZOT", 4, 149578},
	{"YCEP", 4, 149579},
	{"WTUN", 4, 149580},
	{"SJAB", 4, 149581},
	{"PYGM", 4, 149582},
	{"PTGR", 4, 149583},
	{"NTZW", 4, 149584},
	{"NNPL", 4, 149585},
	{"NDGP", 4, 149586},
	{"MMIF", 4, 149587},
	{"KWOL", 4, 149588},
	{"KKEV", 4, 149589},
	{"KJUL", 4, 149590},
	{"KINZ", 4, 149591},
	{"IKLI", 4, 149592},
	{"FYWA", 4, 149593},
	{"FTYH", 4, 149594},
	{"FPNE", 4, 149595},
	{"DDRR", 4, 149596},
	{"DDEH", 4, 149597},
	{"CSJO", 4, 149598},
	{"RETURNVALUE", 11, 149599},
	{"MUNA", 4, 149600},
	{"LPNS", 4, 149601},
	{"HIMES", 5, 149602},
	{"LOUVER", 6, 149603},
	{"SEAFRESH", 8, 149604},
	{"SCHIEFFER", 9, 149605},
	{"SCHOLLS", 7, 149606},
	{"OAKLANDS", 8, 149607},
	{"ROLLY", 5, 149608},
	{"REALWORLD", 9, 149609},
	{"LINKSHARE", 9, 149610},
	{"BACKFIRES", 9, 149611},
	{"WEBSHITES", 9, 149612},
	{"SYNDICATIONS", 12, 149613},
	{"GALAGA", 6, 149614},
	{"CRISCO", 6, 149615},
	{"MARIKO", 6, 149616},
	{"ELMBRIDGE", 9, 149617},
	{"ATPASES", 7, 149618},
	{"MADWIFI", 7, 149619},
	{"PARSI", 5, 149620},
	{"HITPOINTS", 9, 149621},
	{"BROYLES", 7, 149622},
	{"BERKHAMSTED", 11, 149623},
	{"LASTKNOWNFILETYPE", 17, 149624},
	{"TUMS", 4, 149625},
	{"JAFAR", 5, 149626},
	{"SANCTI", 6, 149627},
	{"WRENN", 5, 149628},
	{"TICKLERS", 8, 149629},
	{"WOLTER", 6, 149630},
	{"GOLOMB", 6, 149631},
	{"ARAR", 4, 149632},
	{"SVENDSEN", 8, 149633},
	{"BRAHMINS", 8, 149634},
	{"NITED", 5, 149635},
	{"METHOS", 6, 149636},
	{"LATELINE", 8, 149637},
	{"YUMN", 4, 149638},
	{"YMEO", 4, 149639},
	{"XTEM", 4, 149640},
	{"UYEV", 4, 149641},
	{"TIRW", 4, 149642},
	{"QWHO", 4, 149643},
	{"NCTG", 4, 149644},
	{"LWIZ", 4, 149645},
	{"KOLS", 4, 149646},
	{"IRTV", 4, 149647},
	{"IDYI", 4, 149648},
	{"IBMC", 4, 149649},
	{"HJUR", 4, 149650},
	{"DRNO", 4, 149651},
	{"BDEA", 4, 149652},
	{"AYZE", 4, 149653},
	{"SPINOR", 6, 149654},
	{"CLOWES", 6, 149655},
	{"CMPSIZE", 7, 149656},
	{"DANSVILLE", 9, 149657},
	{"SABERTOOTH", 10, 149658},
	{"HEADINGLEY", 10, 149659},
	{"MTUNE", 5, 149660},
	{"IESAF", 5, 149661},
	{"WERDER", 6, 149662},
	{"MUMBA", 5, 149663},
	{"BORDENTOWN", 10, 149664},
	{"BACKMAN", 7, 149665},
	{"KIYOSAKI", 8, 149666},
	{"GROUNDSWELL", 11, 149667},
	{"MUTANDIS", 8, 149668},
	{"OVERNIGHTS", 10, 149669},
	{"PHYSORG", 7, 149670},
	{"RUTAN", 5, 149671},
	{"BCU", 3, 149672},
	{"CHORDIE", 7, 149673},
	{"GLOAT", 5, 149674},
	{"ENTANGLEMENTS", 13, 149675},
	{"DECSS", 5, 149676},
	{"GROSSET", 7, 149677},
	{"CLAWING", 7, 149678},
	{"AUTOMOTIVEDEALERS", 17, 149679},
	{"LUTHIER", 7, 149680},
	{"KROGH", 5, 149681},
	{"CONDENSATES", 11, 149682},
	{"LUER", 4, 149683},
	{"SKINNABLE", 9, 149684},
	{"WRANGLE", 7, 149685},
	{"SINFEST", 7, 149686},
	{"ZISP", 4, 149687},
	{"VASM", 4, 149688},
	{"UXMA", 4, 149689},
	{"STKR", 4, 149690},
	{"PPEC", 4, 149691},
	{"NMLS", 4, 149692},
	{"MHAU", 4, 149693},
	{"IDHY", 4, 149694},
	{"HMEY", 4, 149695},
	{"HKYL", 4, 149696},
	{"FYAC", 4, 149697},
	{"BEYR", 4, 149698},
	{"AUTOUR", 6, 149699},
	{"PSYCHOLINGUISTICS", 17, 149700},
	{"COPYFIGHT", 9, 149701},
	{"IMMENSITY", 9, 149702},
	{"NEWSREELS", 9, 149703},
	{"SQUABBLING", 10, 149704},
	{"SCAPA", 5, 149705},
	{"DAEGU", 5, 149706},
	{"CARSTAIRS", 9, 149707},
	{"HALACHA", 7, 149708},
	{"POSADAS", 7, 149709},
	{"GAROU", 5, 149710},
	{"MEDROXYPROGESTERONE", 19, 149711},
	{"WILMORE", 7, 149712},
	{"SETLENGTH", 9, 149713},
	{"VIVEKANANDA", 11, 149714},
	{"HOYTS", 5, 149715},
	{"ACQUIESCED", 10, 149716},
	{"BACKES", 6, 149717},
	{"ROSAMUND", 8, 149718},
	{"MEGASTAR", 8, 149719},
	{"COWDEN", 6, 149720},
	{"GALERA", 6, 149721},
	{"FASCINATES", 10, 149722},
	{"HOOLE", 5, 149723},
	{"DEINEN", 6, 149724},
	{"FITZGIBBON", 10, 149725},
	{"BUTYRATE", 8, 149726},
	{"ORGANOPHOSPHATE", 15, 149727},
	{"KARGIL", 6, 149728},
	{"CRLS", 4, 149729},
	{"ANTIQBOOK", 9, 149730},
	{"MORPHEME", 8, 149731},
	{"YVAN", 4, 149732},
	{"DESALES", 7, 149733},
	{"SDDS", 4, 149734},
	{"PRODUZIONE", 10, 149735},
	{"HASLER", 6, 149736},
	{"XDIV", 4, 149737},
	{"UKPA", 4, 149738},
	{"UBOV", 4, 149739},
	{"OXYO", 4, 149740},
	{"OMCM", 4, 149741},
	{"KIFW", 4, 149742},
	{"KHUD", 4, 149743},
	{"HMCA", 4, 149744},
	{"GYIE", 4, 149745},
	{"ETVR", 4, 149746},
	{"EKIK", 4, 149747},
	{"CYDA", 4, 149748},
	{"CEYT", 4, 149749},
	{"CEAK", 4, 149750},
	{"CBYA", 4, 149751},
	{"UNCHARACTERISTICALLY", 20, 149752},
	{"LMODERN", 7, 149753},
	{"CONCORDANCES", 12, 149754},
	{"PPLICATION", 10, 149755},
	{"LIBERALIZE", 10, 149756},
	{"HOGWASH", 7, 149757},
	{"REGENCE", 7, 149758},
	{"CONSECRATE", 10, 149759},
	{"ACREAGES", 8, 149760},
	{"LOGG", 4, 149761},
	{"BARCELLONA", 10, 149762},
	{"LIGHTSABERS", 11, 149763},
	{"INCOM", 5, 149764},
	{"SUBSIDIZATION", 13, 149765},
	{"NEWSBYTES", 9, 149766},
	{"PURSUERS", 8, 149767},
	{"PHEOCHROMOCYTOMA", 16, 149768},
	{"WYLER", 5, 149769},
	{"FROLICKING", 10, 149770},
	{"BERTL", 5, 149771},
	{"MUTAGENS", 8, 149772},
	{"BUTTERCREAM", 11, 149773},
	{"TROPICO", 7, 149774},
	{"REACTOME", 8, 149775},
	{"AMPHETADESK", 11, 149776},
	{"LESSDISKS", 9, 149777},
	{"HIDEAWAYS", 9, 149778},
	{"WESCOTT", 7, 149779},
	{"CANAD", 5, 149780},
	{"BROTHERTON", 10, 149781},
	{"FAUSTFICK", 9, 149782},
	{"HEATHCLIFF", 10, 149783},
	{"MARKOVIAN", 9, 149784},
	{"PREDESTINED", 11, 149785},
	{"EDULIS", 6, 149786},
	{"LOWEY", 5, 149787},
	{"GNEISS", 6, 149788},
	{"FELECIA", 7, 149789},
	{"BRUCK", 5, 149790},
	{"CREAMWARE", 9, 149791},
	{"SKILLSET", 8, 149792},
	{"SHIRKY", 6, 149793},
	{"BOOKCROSSERS", 12, 149794},
	{"USDB", 4, 149795},
	{"UERP", 4, 149796},
	{"UAYW", 4, 149797},
	{"SHYW", 4, 149798},
	{"NUTF", 4, 149799},
	{"NTDY", 4, 149800},
	{"NRYN", 4, 149801},
	{"MAEM", 4, 149802},
	{"LYAA", 4, 149803},
	{"JINW", 4, 149804},
	{"IDKU", 4, 149805},
	{"HMEB", 4, 149806},
	{"GYHI", 4, 149807},
	{"GCIG", 4, 149808},
	{"FFYC", 4, 149809},
	{"ELGL", 4, 149810},
	{"DSTG", 4, 149811},
	{"AVUR", 4, 149812},
	{"AIBR", 4, 149813},
	{"UNROLL", 6, 149814},
	{"JAPANESSE", 9, 149815},
	{"ZAID", 4, 149816},
	{"JALOPNIK", 8, 149817},
	{"GEVONDEN", 8, 149818},
	{"HELLBLAZER", 10, 149819},
	{"WATERHOLE", 9, 149820},
	{"ALMAY", 5, 149821},
	{"HEPPNER", 7, 149822},
	{"EPHILOSOPHER", 12, 149823},
	{"ESTAMOS", 7, 149824},
	{"JUGGALOS", 8, 149825},
	{"CHARTERHOUSE", 12, 149826},
	{"SAVARD", 6, 149827},
	{"MCIVER", 6, 149828},
	{"MUMU", 4, 149829},
	{"LEKCJE", 6, 149830},
	{"DISOBEYED", 9, 149831},
	{"JOONDALUP", 9, 149832},
	{"JENTEAL", 7, 149833},
	{"GUNDERSEN", 9, 149834},
	{"BLUECROSS", 9, 149835},
	{"CSULB", 5, 149836},
	{"BIOPHYSICA", 10, 149837},
	{"RENEGOTIATED", 12, 149838},
	{"FIRME", 5, 149839},
	{"EMAX", 4, 149840},
	{"DILEEP", 6, 149841},
	{"PRSPS", 5, 149842},
	{"ZILLAPEDIA", 10, 149843},
	{"SESAM", 5, 149844},
	{"AFFARI", 6, 149845},
	{"HIPPARCOS", 9, 149846},
	{"CHARACTERISING", 14, 149847},
	{"ANANSI", 6, 149848},
	{"PEPER", 5, 149849},
	{"DISHONOUR", 9, 149850},
	{"SHOUNEN", 7, 149851},
	{"DEVANAGARI", 10, 149852},
	{"PHAGES", 6, 149853},
	{"HESITANTLY", 10, 149854},
	{"SEMINARIANS", 11, 149855},
	{"LINUXTAG", 8, 149856},
	{"PIEPER", 6, 149857},
	{"INTERRELIGIOUS", 14, 149858},
	{"SATURNIA", 8, 149859},
	{"ZBRO", 4, 149860},
	{"YPYT", 4, 149861},
	{"XBOO", 4, 149862},
	{"UPEC", 4, 149863},
	{"TYRR", 4, 149864},
	{"THKM", 4, 149865},
	{"SECB", 4, 149866},
	{"PEAW", 4, 149867},
	{"OYDD", 4, 149868},
	{"MUAL", 4, 149869},
	{"MIFS", 4, 149870},
	{"LAPJ", 4, 149871},
	{"KJUM", 4, 149872},
	{"GITY", 4, 149873},
	{"EXDA", 4, 149874},
	{"EFOV", 4, 149875},
	{"DZIP", 4, 149876},
	{"CBOY", 4, 149877},
	{"CBID", 4, 149878},
	{"BBCB", 4, 149879},
	{"LAVISHED", 8, 149880},
	{"DIALD", 5, 149881},
	{"COURTESAN", 9, 149882},
	{"PRESCOD", 7, 149883},
	{"KRUM", 4, 149884},
	{"UNKEMPT", 7, 149885},
	{"HEALINGS", 8, 149886},
	{"BASSIN", 6, 149887},
	{"MALLINCKRODT", 12, 149888},
	{"EVALUA", 6, 149889},
	{"ADJUDICATORY", 12, 149890},
	{"UNAPPEALING", 11, 149891},
	{"JORAM", 5, 149892},
	{"THUJA", 5, 149893},
	{"NALYSIS", 7, 149894},
	{"HEARTACHES", 10, 149895},
	{"ESRF", 4, 149896},
	{"DEFACING", 8, 149897},
	{"TARTE", 5, 149898},
	{"PHPTAL", 6, 149899},
	{"ZEICHEN", 7, 149900},
	{"TAMES", 5, 149901},
	{"OLIGARCHS", 9, 149902},
	{"CASTED", 6, 149903},
	{"WESTMOUNT", 9, 149904},
	{"ENCY", 4, 149905},
	{"HAUNTINGLY", 10, 149906},
	{"DCFS", 4, 149907},
	{"FRENKEL", 7, 149908},
	{"JOENSUU", 7, 149909},
	{"JEDER", 5, 149910},
	{"YMRM", 4, 149911},
	{"XMED", 4, 149912},
	{"TRIW", 4, 149913},
	{"TAVU", 4, 149914},
	{"REPG", 4, 149915},
	{"RCFO", 4, 149916},
	{"OYDP", 4, 149917},
	{"OXPO", 4, 149918},
	{"OLDZ", 4, 149919},
	{"NKYW", 4, 149920},
	{"MPHN", 4, 149921},
	{"MJOR", 4, 149922},
	{"LJOY", 4, 149923},
	{"LABN", 4, 149924},
	{"FODE", 4, 149925},
	{"DNIP", 4, 149926},
	{"ALKG", 4, 149927},
	{"INTERJECTED", 11, 149928},
	{"SUNSITE", 7, 149929},
	{"NOVENA", 6, 149930},
	{"HUMOROUSLY", 10, 149931},
	{"SMBUS", 5, 149932},
	{"ADJUDICATIONS", 13, 149933},
	{"VICTORIOUSLY", 12, 149934},
	{"LEGITIMATION", 12, 149935},
	{"TIENER", 6, 149936},
	{"CATCHPHRASE", 11, 149937},
	{"BONDURANT", 9, 149938},
	{"MIGS", 4, 149939},
	{"TRANSLINK", 9, 149940},
	{"JOTTING", 7, 149941},
	{"IVERMECTIN", 10, 149942},
	{"STALWARTS", 9, 149943},
	{"VORTEC", 6, 149944},
	{"LUBECK", 6, 149945},
	{"STUARTS", 7, 149946},
	{"DOCHERTY", 8, 149947},
	{"RYKA", 4, 149948},
	{"HANGOUTS", 8, 149949},
	{"TROYER", 6, 149950},
	{"JALAPENOS", 9, 149951},
	{"ASCENTS", 7, 149952},
	{"BIGTIT", 6, 149953},
	{"STERILIZING", 11, 149954},
	{"CLOQUET", 7, 149955},
	{"DATACARD", 8, 149956},
	{"ANGL", 4, 149957},
	{"OVERSTUFFED", 11, 149958},
	{"TECHNICALS", 10, 149959},
	{"METHODSFOR", 10, 149960},
	{"HINGEGEN", 8, 149961},
	{"GLOBALE", 7, 149962},
	{"RECLASSIFY", 10, 149963},
	{"TRIOXIDE", 8, 149964},
	{"TROPES", 6, 149965},
	{"INDUSTR", 7, 149966},
	{"AUBRY", 5, 149967},
	{"SINGHAL", 7, 149968},
	{"ACCEPTABLY", 10, 149969},
	{"MEERKAT", 7, 149970},
	{"KENZER", 6, 149971},
	{"PASSAGEMAKER", 12, 149972},
	{"ZZOF", 4, 149973},
	{"YDIT", 4, 149974},
	{"XAMT", 4, 149975},
	{"XABO", 4, 149976},
	{"UZZT", 4, 149977},
	{"TKRE", 4, 149978},
	{"TAMJ", 4, 149979},
	{"REZZ", 4, 149980},
	{"RAFB", 4, 149981},
	{"PODD", 4, 149982},
	{"NDQA", 4, 149983},
	{"MCUB", 4, 149984},
	{"HLUK", 4, 149985},
	{"BLOR", 4, 149986},
	{"AIYU", 4, 149987},
	{"PUTRA", 5, 149988},
	{"EBAYERS", 7, 149989},
	{"SCAL", 4, 149990},
	{"PIAZZOLLA", 9, 149991},
	{"NOBUO", 5, 149992},
	{"SOLV", 4, 149993},
	{"PARAME", 6, 149994},
	{"TATOOINE", 8, 149995},
	{"SHAREUP", 7, 149996},
	{"RETARDING", 9, 149997},
	{"DECKARD", 7, 149998},
	{"INDISCRETION", 12, 149999},
	{"UNDERTONE", 9, 150000},
	{"EINTRAGEN", 9, 150001},
	{"DIFERENT", 8, 150002},
	{"MICROCRYSTALLINE", 16, 150003},
	{"DUELL", 5, 150004},
	{"POLYESTERS", 10, 150005},
	{"HERMENEUTIC", 11, 150006},
	{"BURKITT", 7, 150007},
	{"SABBAT", 6, 150008},
	{"HURSTVILLE", 10, 150009},
	{"ENGENDERS", 9, 150010},
	{"SHEKHAR", 7, 150011},
	{"MATTHAU", 7, 150012},
	{"TRADERONLINE", 12, 150013},
	{"SQUIB", 5, 150014},
	{"SHUMWAY", 7, 150015},
	{"TOPOS", 5, 150016},
	{"PELS", 4, 150017},
	{"NEUROPROTECTIVE", 15, 150018},
	{"PACA", 4, 150019},
	{"KYPROY", 6, 150020},
	{"GUETTA", 6, 150021},
	{"DOLIBARR", 8, 150022},
	{"GOWAN", 5, 150023},
	{"ENBRIDGE", 8, 150024},
	{"CANNABINOIDS", 12, 150025},
	{"PATERNALISTIC", 13, 150026},
	{"THERMOPHILUS", 12, 150027},
	{"NIMDA", 5, 150028},
	{"WAGU", 4, 150029},
	{"VDAV", 4, 150030},
	{"SUPY", 4, 150031},
	{"SFOG", 4, 150032},
	{"NKEC", 4, 150033},
	{"NDHD", 4, 150034},
	{"MCOF", 4, 150035},
	{"LPBY", 4, 150036},
	{"KKHA", 4, 150037},
	{"KEMS", 4, 150038},
	{"HFRY", 4, 150039},
	{"GALY", 4, 150040},
	{"EVWR", 4, 150041},
	{"EKIP", 4, 150042},
	{"CBCT", 4, 150043},
	{"CAFL", 4, 150044},
	{"AALC", 4, 150045},
	{"VENTRILOQUIST", 13, 150046},
	{"BUSHMASTER", 10, 150047},
	{"UNDERNOURISHED", 14, 150048},
	{"PORCINI", 7, 150049},
	{"DRUMLINE", 8, 150050},
	{"SANTOKU", 7, 150051},
	{"KOGYO", 5, 150052},
	{"ROTHESAY", 8, 150053},
	{"PROMOTOR", 8, 150054},
	{"IATROGENIC", 10, 150055},
	{"BRONICA", 7, 150056},
	{"KAKI", 4, 150057},
	{"SCHAUER", 7, 150058},
	{"CORTESE", 7, 150059},
	{"SHENTON", 7, 150060},
	{"HALLOWS", 7, 150061},
	{"FAMILAR", 7, 150062},
	{"SURESTORE", 9, 150063},
	{"SLOVO", 5, 150064},
	{"DECEASE", 7, 150065},
	{"STIGMATIZED", 11, 150066},
	{"COOTS", 5, 150067},
	{"TACTFUL", 7, 150068},
	{"PRUNERS", 7, 150069},
	{"ACTINOPTERYGII", 14, 150070},
	{"ALLURA", 6, 150071},
	{"FRIABLE", 7, 150072},
	{"FLYWHEELS", 9, 150073},
	{"PERCEPTRON", 10, 150074},
	{"NUTTING", 7, 150075},
	{"NETWERK", 7, 150076},
	{"PITTER", 6, 150077},
	{"LEFEL", 5, 150078},
	{"DEION", 5, 150079},
	{"CYTOLOGICAL", 11, 150080},
	{"ARMISTEAD", 9, 150081},
	{"BRODHEAD", 8, 150082},
	{"ZIPLOCK", 7, 150083},
	{"AMANI", 5, 150084},
	{"LEEMING", 7, 150085},
	{"YMCI", 4, 150086},
	{"YCAI", 4, 150087},
	{"VSLA", 4, 150088},
	{"SUBZ", 4, 150089},
	{"SEDZ", 4, 150090},
	{"RYPP", 4, 150091},
	{"RSCY", 4, 150092},
	{"PPEI", 4, 150093},
	{"OCAG", 4, 150094},
	{"NUXW", 4, 150095},
	{"NOUP", 4, 150096},
	{"MCWH", 4, 150097},
	{"JAOF", 4, 150098},
	{"IPTP", 4, 150099},
	{"ILOX", 4, 150100},
	{"IBCO", 4, 150101},
	{"HVAU", 4, 150102},
	{"FMRB", 4, 150103},
	{"FAXS", 4, 150104},
	{"EIFG", 4, 150105},
	{"LSOF", 4, 150106},
	{"PALATINATE", 10, 150107},
	{"MOONDOG", 7, 150108},
	{"FINDUTILS", 9, 150109},
	{"KONVERTER", 9, 150110},
	{"INTERRACIALS", 12, 150111},
	{"RIZE", 4, 150112},
	{"FRUSCIANTE", 10, 150113},
	{"JUNKET", 6, 150114},
	{"DIRECTORSHIPS", 13, 150115},
	{"BURGIN", 6, 150116},
	{"ANTITRYPSIN", 11, 150117},
	{"DISCOGRAPHIE", 12, 150118},
	{"GUESTLIST", 9, 150119},
	{"MONADIC", 7, 150120},
	{"STEGANOGRAPHY", 13, 150121},
	{"REFERAL", 7, 150122},
	{"CLASSIFICA", 10, 150123},
	{"DALHART", 7, 150124},
	{"ABUL", 4, 150125},
	{"PRISHTINA", 9, 150126},
	{"HOBERMAN", 8, 150127},
	{"KONYA", 5, 150128},
	{"LIEGEN", 6, 150129},
	{"WYOMISSING", 10, 150130},
	{"WALKMEN", 7, 150131},
	{"BARRANQUILLA", 12, 150132},
	{"HAKU", 4, 150133},
	{"ENDOCRINOLOGIST", 15, 150134},
	{"SCOUTMASTER", 11, 150135},
	{"TEETHERS", 8, 150136},
	{"MERRIN", 6, 150137},
	{"IPSC", 4, 150138},
	{"GAND", 4, 150139},
	{"YANKING", 7, 150140},
	{"POSITIONERS", 11, 150141},
	{"LONGOS", 6, 150142},
	{"GREENHALGH", 10, 150143},
	{"JAYASURIYA", 10, 150144},
	{"KIDLINGTON", 10, 150145},
	{"OUAGADOUGOU", 11, 150146},
	{"MCMS", 4, 150147},
	{"FAWNING", 7, 150148},
	{"WESTWIND", 8, 150149},
	{"GIALLO", 6, 150150},
	{"HELIS", 5, 150151},
	{"YESJ", 4, 150152},
	{"WSFU", 4, 150153},
	{"WJUM", 4, 150154},
	{"UDAF", 4, 150155},
	{"RITJ", 4, 150156},
	{"NPYR", 4, 150157},
	{"MSJE", 4, 150158},
	{"MRUR", 4, 150159},
	{"MNSF", 4, 150160},
	{"MEGW", 4, 150161},
	{"LMBR", 4, 150162},
	{"LBRY", 4, 150163},
	{"KNOM", 4, 150164},
	{"HAMZ", 4, 150165},
	{"ENGF", 4, 150166},
	{"EFJE", 4, 150167},
	{"COID", 4, 150168},
	{"CEJI", 4, 150169},
	{"PRISSY", 6, 150170},
	{"WALSINGHAM", 10, 150171},
	{"FITR", 4, 150172},
	{"BHUTANESE", 9, 150173},
	{"HKUST", 5, 150174},
	{"ARCHINFORM", 10, 150175},
	{"GODEL", 5, 150176},
	{"ZOONOTIC", 8, 150177},
	{"RADHIKA", 7, 150178},
	{"HUGGERS", 7, 150179},
	{"SPILLANE", 8, 150180},
	{"JUNKO", 5, 150181},
	{"ERBYN", 5, 150182},
	{"HOPSON", 6, 150183},
	{"PSYCHOS", 7, 150184},
	{"ABOLISHES", 9, 150185},
	{"DIGWEED", 7, 150186},
	{"BASC", 4, 150187},
	{"LITTLER", 7, 150188},
	{"SOUNESS", 7, 150189},
	{"JOVENCITOS", 10, 150190},
	{"DATAPATH", 8, 150191},
	{"MONBIOT", 7, 150192},
	{"DIGIPOWER", 9, 150193},
	{"SOUTHEASTERLY", 13, 150194},
	{"FUNNILY", 7, 150195},
	{"DECOCTION", 9, 150196},
	{"RESENTS", 7, 150197},
	{"SATORU", 6, 150198},
	{"ORIENTALS", 9, 150199},
	{"SQUEAKING", 9, 150200},
	{"EUBANK", 6, 150201},
	{"HAZLEHURST", 10, 150202},
	{"PRING", 5, 150203},
	{"BUFFINGTON", 10, 150204},
	{"MKTEMP", 6, 150205},
	{"ARANYM", 6, 150206},
	{"SOKW", 4, 150207},
	{"PISK", 4, 150208},
	{"OUXC", 4, 150209},
	{"OMRM", 4, 150210},
	{"OCUC", 4, 150211},
	{"OAUL", 4, 150212},
	{"NULO", 4, 150213},
	{"MVPI", 4, 150214},
	{"KYTA", 4, 150215},
	{"KRIL", 4, 150216},
	{"ITGL", 4, 150217},
	{"HEJR", 4, 150218},
	{"EMRH", 4, 150219},
	{"EDVU", 4, 150220},
	{"CULB", 4, 150221},
	{"CMCI", 4, 150222},
	{"CGAH", 4, 150223},
	{"BSDR", 4, 150224},
	{"AUAR", 4, 150225},
	{"KVAERNER", 8, 150226},
	{"CCVS", 4, 150227},
	{"TINKLING", 8, 150228},
	{"ALKMAAR", 7, 150229},
	{"MOIVES", 6, 150230},
	{"WINARRANGER", 11, 150231},
	{"BARRINGER", 9, 150232},
	{"BERGSON", 7, 150233},
	{"DRIE", 4, 150234},
	{"NOSTRUM", 7, 150235},
	{"ESERVICES", 9, 150236},
	{"DALZIEL", 7, 150237},
	{"ALPIN", 5, 150238},
	{"MISCHKE", 7, 150239},
	{"MASTERLY", 8, 150240},
	{"KABOBS", 6, 150241},
	{"REBOL", 5, 150242},
	{"HANDWOVEN", 9, 150243},
	{"DUNCE", 5, 150244},
	{"FLINTRIDGE", 10, 150245},
	{"CONNY", 5, 150246},
	{"CLAYSTONE", 9, 150247},
	{"FERA", 4, 150248},
	{"BUTCHERY", 8, 150249},
	{"BARTCOP", 7, 150250},
	{"ATLANTEAN", 9, 150251},
	{"WRESTING", 8, 150252},
	{"HOLIDAYHAVENS", 13, 150253},
	{"CHOICESUK", 9, 150254},
	{"BLUESHIELD", 10, 150255},
	{"DIGIFOCUS", 9, 150256},
	{"BURNE", 5, 150257},
	{"ENTRAINED", 9, 150258},
	{"TRESPASSERS", 11, 150259},
	{"EPITOMIZES", 10, 150260},
	{"LEIBOWITZ", 9, 150261},
	{"GOKHALE", 7, 150262},
	{"TORQUES", 7, 150263},
	{"WHIC", 4, 150264},
	{"PICOSEARCH", 10, 150265},
	{"YNIX", 4, 150266},
	{"UOPO", 4, 150267},
	{"UOLE", 4, 150268},
	{"RCNN", 4, 150269},
	{"PGOE", 4, 150270},
	{"OFUD", 4, 150271},
	{"MITV", 4, 150272},
	{"LSTB", 4, 150273},
	{"JEKY", 4, 150274},
	{"ERCZ", 4, 150275},
	{"DKOM", 4, 150276},
	{"DDRD", 4, 150277},
	{"CHCY", 4, 150278},
	{"CBUD", 4, 150279},
	{"AYIB", 4, 150280},
	{"REASEARCH", 9, 150281},
	{"LIESEGANG", 9, 150282},
	{"TREACLE", 7, 150283},
	{"NIANTIC", 7, 150284},
	{"FREEBIRD", 8, 150285},
	{"PASSIN", 6, 150286},
	{"MITZVOT", 7, 150287},
	{"HERBE", 5, 150288},
	{"BLINKY", 6, 150289},
	{"VERDON", 6, 150290},
	{"VARIABLY", 8, 150291},
	{"SHOPAHOLIC", 10, 150292},
	{"INFRANT", 7, 150293},
	{"SUBTRACTIVE", 11, 150294},
	{"PASSAU", 6, 150295},
	{"HAPPENSTANCE", 12, 150296},
	{"JESSIKA", 7, 150297},
	{"PETWEAR", 7, 150298},
	{"FRANKRIJK", 9, 150299},
	{"REINVIGORATE", 12, 150300},
	{"MCGUIGAN", 8, 150301},
	{"TOPLOADER", 9, 150302},
	{"HERALDING", 9, 150303},
	{"UNCOLLECTIBLE", 13, 150304},
	{"PILON", 5, 150305},
	{"NAMEBASE", 8, 150306},
	{"CLAFLIN", 7, 150307},
	{"MOBYSTORE", 9, 150308},
	{"VICINO", 6, 150309},
	{"STOEL", 5, 150310},
	{"PREREGISTRATION", 15, 150311},
	{"MISCONFIGURATION", 16, 150312},
	{"CORRODE", 7, 150313},
	{"BLOOPER", 7, 150314},
	{"CASOS", 5, 150315},
	{"KINKI", 5, 150316},
	{"FREDERICKTOWN", 13, 150317},
	{"LLYFRGELL", 9, 150318},
	{"AMPHORA", 7, 150319},
	{"HOUBIGANT", 9, 150320},
	{"DIEING", 6, 150321},
	{"MATCHESSTORE", 12, 150322},
	{"GTLDS", 5, 150323},
	{"PARASYMPATHETIC", 15, 150324},
	{"MYSON", 5, 150325},
	{"BOURSES", 7, 150326},
	{"MENHIR", 6, 150327},
	{"ADVE", 4, 150328},
	{"SOCIALISATION", 13, 150329},
	{"YAYA", 4, 150330},
	{"LDG", 3, 150331},
	{"PRINZE", 6, 150332},
	{"DEADWEIGHT", 10, 150333},
	{"UNCONSTITUTIONALLY", 18, 150334},
	{"MEGATOKYO", 9, 150335},
	{"YUCH", 4, 150336},
	{"YANV", 4, 150337},
	{"WNKA", 4, 150338},
	{"SPWI", 4, 150339},
	{"SCMI", 4, 150340},
	{"RWWI", 4, 150341},
	{"RLRI", 4, 150342},
	{"RHUA", 4, 150343},
	{"PHRY", 4, 150344},
	{"ORKQ", 4, 150345},
	{"NGDV", 4, 150346},
	{"NFOF", 4, 150347},
	{"IXEV", 4, 150348},
	{"ILKU", 4, 150349},
	{"GLYK", 4, 150350},
	{"ERHP", 4, 150351},
	{"EMRT", 4, 150352},
	{"EIMJ", 4, 150353},
	{"ADIX", 4, 150354},
	{"MACRAME", 7, 150355},
	{"DAUGTHER", 8, 150356},
	{"THELEN", 6, 150357},
	{"FOOLHARDY", 9, 150358},
	{"SPRINTERS", 9, 150359},
	{"REVIT", 5, 150360},
	{"STRATHSPEY", 10, 150361},
	{"DROOLS", 6, 150362},
	{"FANNIES", 7, 150363},
	{"DIAPHRAGMATIC", 13, 150364},
	{"UNFLATTERING", 12, 150365},
	{"BRISTLING", 9, 150366},
	{"TACONIC", 7, 150367},
	{"ZLOTYS", 6, 150368},
	{"FILBERT", 7, 150369},
	{"CASSIN", 6, 150370},
	{"BOREAS", 6, 150371},
	{"BLACKHEADS", 10, 150372},
	{"SEAWOLVES", 9, 150373},
	{"XMLBEANS", 8, 150374},
	{"DISORD", 6, 150375},
	{"STOPING", 7, 150376},
	{"CEDUNA", 6, 150377},
	{"CHERUBIM", 8, 150378},
	{"LAGAN", 5, 150379},
	{"ADENAUER", 8, 150380},
	{"TORRENCE", 8, 150381},
	{"BANSTEAD", 8, 150382},
	{"THOROUGHBREDS", 13, 150383},
	{"BRONSTEIN", 9, 150384},
	{"MYODBC", 6, 150385},
	{"GASTRIN", 7, 150386},
	{"ACEC", 4, 150387},
	{"NIGHTCAP", 8, 150388},
	{"MASSCHIP", 8, 150389},
	{"CHISLEHURST", 11, 150390},
	{"BUAT", 4, 150391},
	{"MASSY", 5, 150392},
	{"CONSOLING", 9, 150393},
	{"ANTIDOTES", 9, 150394},
	{"CHARACTERISES", 13, 150395},
	{"SENSATIONALISM", 14, 150396},
	{"KICKBALL", 8, 150397},
	{"ANTIOCHUS", 9, 150398},
	{"HUBLEY", 6, 150399},
	{"DEFINETELY", 10, 150400},
	{"CUTLETS", 7, 150401},
	{"XWD", 3, 150402},
	{"MOVEIS", 6, 150403},
	{"HTTPSERVLETREQUEST", 18, 150404},
	{"CONDORS", 7, 150405},
	{"DIANTHUS", 8, 150406},
	{"UNCONFINED", 10, 150407},
	{"HOOFS", 5, 150408},
	{"RHEOLI", 6, 150409},
	{"JAPANISCHE", 10, 150410},
	{"DREAMCOAT", 9, 150411},
	{"YMOW", 4, 150412},
	{"XONV", 4, 150413},
	{"TYPM", 4, 150414},
	{"PYFR", 4, 150415},
	{"PFLY", 4, 150416},
	{"OYOG", 4, 150417},
	{"OYMU", 4, 150418},
	{"OHUL", 4, 150419},
	{"OFMD", 4, 150420},
	{"NGKL", 4, 150421},
	{"MFIF", 4, 150422},
	{"LFBI", 4, 150423},
	{"LAYQ", 4, 150424},
	{"JAMW", 4, 150425},
	{"IIDU", 4, 150426},
	{"GYUA", 4, 150427},
	{"EBMO", 4, 150428},
	{"DTUI", 4, 150429},
	{"CFUT", 4, 150430},
	{"AWGS", 4, 150431},
	{"ALTG", 4, 150432},
	{"FRAGILIS", 8, 150433},
	{"MACFIXIT", 8, 150434},
	{"INTEG", 5, 150435},
	{"ACCLIMATED", 10, 150436},
	{"YMMV", 4, 150437},
	{"KOVACH", 6, 150438},
	{"THEDRINKSHOP", 12, 150439},
	{"BOTETOURT", 9, 150440},
	{"DRAWL", 5, 150441},
	{"VEUX", 4, 150442},
	{"HAMMONTON", 9, 150443},
	{"WINROUTE", 8, 150444},
	{"EZURIO", 6, 150445},
	{"MEDICOM", 7, 150446},
	{"BLANTYRE", 8, 150447},
	{"UNMASKING", 9, 150448},
	{"JARDINES", 8, 150449},
	{"CONSTRICTOR", 11, 150450},
	{"LEAGUER", 7, 150451},
	{"OLLEGE", 6, 150452},
	{"SAMSTAG", 7, 150453},
	{"GRANULOMATOUS", 13, 150454},
	{"SCHIST", 6, 150455},
	{"EQUATIONAL", 10, 150456},
	{"FRIEDEL", 7, 150457},
	{"CLEARINGHOUSES", 14, 150458},
	{"JULE", 4, 150459},
	{"SEIGE", 5, 150460},
	{"MANOEUVRING", 11, 150461},
	{"COUNSELL", 8, 150462},
	{"NINGXIA", 7, 150463},
	{"BARTO", 5, 150464},
	{"LANCES", 6, 150465},
	{"HELFEN", 6, 150466},
	{"WXWIDGETS", 9, 150467},
	{"RASTAFARI", 9, 150468},
	{"SCANDIA", 7, 150469},
	{"LILLI", 5, 150470},
	{"AUTOINSTALL", 11, 150471},
	{"HEMIPTERA", 9, 150472},
	{"DEMYSTIFY", 9, 150473},
	{"MACULA", 6, 150474},
	{"AAUW", 4, 150475},
	{"WELTE", 5, 150476},
	{"EMRE", 4, 150477},
	{"PICANTE", 7, 150478},
	{"MELCHIZEDEK", 11, 150479},
	{"TOGGLING", 8, 150480},
	{"FEXCXC", 6, 150481},
	{"ZBOR", 4, 150482},
	{"YTLE", 4, 150483},
	{"WETB", 4, 150484},
	{"UTTB", 4, 150485},
	{"PCWI", 4, 150486},
	{"NDFM", 4, 150487},
	{"MGUY", 4, 150488},
	{"MCUP", 4, 150489},
	{"MBOV", 4, 150490},
	{"LOEF", 4, 150491},
	{"LNEB", 4, 150492},
	{"IGIC", 4, 150493},
	{"ICIW", 4, 150494},
	{"EEXU", 4, 150495},
	{"AKUD", 4, 150496},
	{"MEDICAP", 7, 150497},
	{"MEXRI", 5, 150498},
	{"CARRON", 6, 150499},
	{"HISTONET", 8, 150500},
	{"MOWRY", 5, 150501},
	{"FAVORIT", 7, 150502},
	{"SPARCS", 6, 150503},
	{"ROBEY", 5, 150504},
	{"RIVIER", 6, 150505},
	{"BURSTY", 6, 150506},
	{"DACRON", 6, 150507},
	{"PSYCINFO", 8, 150508},
	{"CLICKONCE", 9, 150509},
	{"VERJAARDAG", 10, 150510},
	{"NAUSEUM", 7, 150511},
	{"ENDSLEIGH", 9, 150512},
	{"EBOX", 4, 150513},
	{"PROJECTA", 8, 150514},
	{"WRR", 3, 150515},
	{"COLLYER", 7, 150516},
	{"KILLE", 5, 150517},
	{"IMOGENE", 7, 150518},
	{"YUKAWA", 6, 150519},
	{"ALTAMIRA", 8, 150520},
	{"IMPUTE", 6, 150521},
	{"BRENNEMAN", 9, 150522},
	{"ANALOGICAL", 10, 150523},
	{"POLYGLOT", 8, 150524},
	{"MAULED", 6, 150525},
	{"RPSL", 4, 150526},
	{"ROSLIN", 6, 150527},
	{"PLUMBED", 7, 150528},
	{"HOLISTICSHOP", 12, 150529},
	{"DRAINER", 7, 150530},
	{"AHUJA", 5, 150531},
	{"SPYWAREBLASTER", 14, 150532},
	{"BERENGUER", 9, 150533},
	{"AVERETT", 7, 150534},
	{"OSSIPEE", 7, 150535},
	{"MOBILEDIA", 9, 150536},
	{"OESTERREICH", 11, 150537},
	{"CHIVE", 5, 150538},
	{"MAYFLIES", 8, 150539},
	{"STEELERSLIVE", 12, 150540},
	{"DAINTIES", 8, 150541},
	{"ICTR", 4, 150542},
	{"YOXF", 4, 150543},
	{"TDWH", 4, 150544},
	{"SYDU", 4, 150545},
	{"ROUI", 4, 150546},
	{"IRTM", 4, 150547},
	{"FMRM", 4, 150548},
	{"FERZ", 4, 150549},
	{"ENYB", 4, 150550},
	{"DIAY", 4, 150551},
	{"DABN", 4, 150552},
	{"BHIR", 4, 150553},
	{"ATYM", 4, 150554},
	{"ACHZ", 4, 150555},
	{"SOFTTABS", 8, 150556},
	{"SHOPPBS", 7, 150557},
	{"BLIMPS", 6, 150558},
	{"THERMOLIFE", 10, 150559},
	{"PEPSIN", 6, 150560},
	{"TOTESPORT", 9, 150561},
	{"VADEM", 5, 150562},
	{"LINUXSA", 7, 150563},
	{"LEGHORN", 7, 150564},
	{"PAYORS", 6, 150565},
	{"SHAYNA", 6, 150566},
	{"BUDDYLIST", 9, 150567},
	{"LONLEY", 6, 150568},
	{"KOOLHAAS", 8, 150569},
	{"HAHAHAH", 7, 150570},
	{"BYTECC", 6, 150571},
	{"ARAVA", 5, 150572},
	{"EXTR", 4, 150573},
	{"SKETCHBOOKS", 11, 150574},
	{"YOONOO", 6, 150575},
	{"PORKER", 6, 150576},
	{"STOCKROOM", 9, 150577},
	{"DIRECTNESS", 10, 150578},
	{"CAMERAPHONE", 11, 150579},
	{"GLUTTON", 7, 150580},
	{"LAQUELLE", 8, 150581},
	{"CHESNUT", 7, 150582},
	{"NEUROTOXIC", 10, 150583},
	{"GORELICK", 8, 150584},
	{"CEDEGA", 6, 150585},
	{"EXEDY", 5, 150586},
	{"SLOCCOUNT", 9, 150587},
	{"PADMANABHAN", 11, 150588},
	{"JRL", 3, 150589},
	{"MEDIACOM", 8, 150590},
	{"TRUZZI", 6, 150591},
	{"ADAMSTOWN", 9, 150592},
	{"ICONCEPTS", 9, 150593},
	{"DEVELOOPER", 10, 150594},
	{"BLUEBOOK", 8, 150595},
	{"BUFLEN", 6, 150596},
	{"UNNATURALLY", 11, 150597},
	{"SHOULDN", 7, 150598},
	{"FURRIES", 7, 150599},
	{"HEFLEY", 6, 150600},
	{"ELEMENTALS", 10, 150601},
	{"WLTI", 4, 150602},
	{"SCAW", 4, 150603},
	{"PPOM", 4, 150604},
	{"NUSV", 4, 150605},
	{"NTUK", 4, 150606},
	{"MKIR", 4, 150607},
	{"LLPM", 4, 150608},
	{"KYSM", 4, 150609},
	{"IMPW", 4, 150610},
	{"FSMU", 4, 150611},
	{"DYUK", 4, 150612},
	{"DDVA", 4, 150613},
	{"CDUF", 4, 150614},
	{"BMAI", 4, 150615},
	{"ATZW", 4, 150616},
	{"TURNEY", 6, 150617},
	{"LUCHTHAVEN", 10, 150618},
	{"DISQUIET", 8, 150619},
	{"EDITON", 6, 150620},
	{"GETPARENT", 9, 150621},
	{"HEERO", 5, 150622},
	{"BFGOODRICH", 10, 150623},
	{"TUMEFACIENS", 11, 150624},
	{"PORTRUSH", 8, 150625},
	{"FINING", 6, 150626},
	{"HOUSEPLANS", 10, 150627},
	{"VORNADO", 7, 150628},
	{"UNSANITARY", 10, 150629},
	{"PREGNET", 7, 150630},
	{"MAKELAARS", 9, 150631},
	{"CONTRATTO", 9, 150632},
	{"DISSOCIATE", 10, 150633},
	{"GRAYING", 7, 150634},
	{"DEERSKIN", 8, 150635},
	{"INFOTEL", 7, 150636},
	{"DATAMIRROR", 10, 150637},
	{"IMLAY", 5, 150638},
	{"ADVER", 5, 150639},
	{"MIDBRAIN", 8, 150640},
	{"SSLEAY", 6, 150641},
	{"MEEST", 5, 150642},
	{"SUFFICED", 8, 150643},
	{"ZAFAR", 5, 150644},
	{"BERITA", 6, 150645},
	{"SPOTLIGHTING", 12, 150646},
	{"CORSAGES", 8, 150647},
	{"HIERONYMUS", 10, 150648},
	{"METHANOCOCCUS", 13, 150649},
	{"LOOMPA", 6, 150650},
	{"DISALLOWING", 11, 150651},
	{"NESPRESSO", 9, 150652},
	{"EXTOLLING", 9, 150653},
	{"DUSCHE", 6, 150654},
	{"VALPROATE", 9, 150655},
	{"POMPEI", 6, 150656},
	{"VICT", 4, 150657},
	{"BASLER", 6, 150658},
	{"WEARIED", 7, 150659},
	{"CORDA", 5, 150660},
	{"KROPP", 5, 150661},
	{"SYLVANIAN", 9, 150662},
	{"LIBCLIPS", 8, 150663},
	{"ORENSTEIN", 9, 150664},
	{"BIGSHOT", 7, 150665},
	{"BARBE", 5, 150666},
	{"YCUN", 4, 150667},
	{"WSYM", 4, 150668},
	{"UXWI", 4, 150669},
	{"UFTI", 4, 150670},
	{"UDZI", 4, 150671},
	{"RPCT", 4, 150672},
	{"PTAY", 4, 150673},
	{"PSVO", 4, 150674},
	{"OUGF", 4, 150675},
	{"NGUD", 4, 150676},
	{"NDWU", 4, 150677},
	{"MRUT", 4, 150678},
	{"LMYM", 4, 150679},
	{"LFOW", 4, 150680},
	{"LAHD", 4, 150681},
	{"HUPH", 4, 150682},
	{"HLEX", 4, 150683},
	{"GCAD", 4, 150684},
	{"ETZW", 4, 150685},
	{"DUDI", 4, 150686},
	{"KODAMA", 6, 150687},
	{"DIMERIC", 7, 150688},
	{"TERRAZA", 7, 150689},
	{"REBUTTED", 8, 150690},
	{"PHILDATE", 8, 150691},
	{"BRAIDWOOD", 9, 150692},
	{"DURSLEY", 7, 150693},
	{"MAGOG", 5, 150694},
	{"WASTELANDS", 10, 150695},
	{"PITIED", 6, 150696},
	{"PRYMENAV", 8, 150697},
	{"MISSENSE", 8, 150698},
	{"CAROUSELS", 9, 150699},
	{"CABINE", 6, 150700},
	{"USENEXT", 7, 150701},
	{"POLYRESIN", 9, 150702},
	{"SIBYL", 5, 150703},
	{"JUSTPHONES", 10, 150704},
	{"ANONYMIZER", 10, 150705},
	{"SESQUICENTENNIAL", 16, 150706},
	{"LIGNES", 6, 150707},
	{"DIANABOL", 8, 150708},
	{"TRENDWATCH", 10, 150709},
	{"SEARCHENGINEWORLD", 17, 150710},
	{"LEGALE", 6, 150711},
	{"AUTONOLEGGIO", 12, 150712},
	{"BARBEE", 6, 150713},
	{"UNSWORTH", 8, 150714},
	{"SPIAGGIA", 8, 150715},
	{"MACHA", 5, 150716},
	{"EOPLE", 5, 150717},
	{"BASSANO", 7, 150718},
	{"VICTOIRE", 8, 150719},
	{"XPRINT", 6, 150720},
	{"DERI", 4, 150721},
	{"BOSCOVS", 7, 150722},
	{"EMELINE", 7, 150723},
	{"CALEY", 5, 150724},
	{"YNWI", 4, 150725},
	{"XSUR", 4, 150726},
	{"XIMP", 4, 150727},
	{"WLAY", 4, 150728},
	{"VGAM", 4, 150729},
	{"UUSU", 4, 150730},
	{"TPMR", 4, 150731},
	{"TGMA", 4, 150732},
	{"OULG", 4, 150733},
	{"MYSN", 4, 150734},
	{"MOKL", 4, 150735},
	{"LOOC", 4, 150736},
	{"LMFI", 4, 150737},
	{"ERLB", 4, 150738},
	{"EMPW", 4, 150739},
	{"DPIK", 4, 150740},
	{"EULERIAN", 8, 150741},
	{"PERVASIVENESS", 13, 150742},
	{"ERRING", 6, 150743},
	{"GESCHIEDENIS", 12, 150744},
	{"VALVERDE", 8, 150745},
	{"PICKINGS", 8, 150746},
	{"ACCLAMATION", 11, 150747},
	{"EXEGETICAL", 10, 150748},
	{"YPRES", 5, 150749},
	{"SYSTEMC", 7, 150750},
	{"DUCHARME", 8, 150751},
	{"MITOMYCIN", 9, 150752},
	{"BACKORDERS", 10, 150753},
	{"CONDOLEEZA", 10, 150754},
	{"MILITUM", 7, 150755},
	{"MOUSEMATS", 9, 150756},
	{"FINNTROLL", 9, 150757},
	{"HEATHKIT", 8, 150758},
	{"GIGANTE", 7, 150759},
	{"NUCLIDES", 8, 150760},
	{"LOGOART", 7, 150761},
	{"KPFA", 4, 150762},
	{"RHABDOMYOLYSIS", 14, 150763},
	{"UNEXPOSED", 9, 150764},
	{"SOLAMENTE", 9, 150765},
	{"BERENICE", 8, 150766},
	{"SUGARMAN", 8, 150767},
	{"ENDOSULFAN", 10, 150768},
	{"COMBINA", 7, 150769},
	{"UMPHREY", 7, 150770},
	{"PREDOCTORAL", 11, 150771},
	{"PIXLEY", 6, 150772},
	{"BAZARUTO", 8, 150773},
	{"CISTERNS", 8, 150774},
	{"CANDIE", 6, 150775},
	{"HUDSPETH", 8, 150776},
	{"INVICTUS", 8, 150777},
	{"FLOORSPACE", 10, 150778},
	{"NAKANISHI", 9, 150779},
	{"DUCTUS", 6, 150780},
	{"HEADWATER", 9, 150781},
	{"SOCIOPOLITICAL", 14, 150782},
	{"YIWE", 4, 150783},
	{"VEYL", 4, 150784},
	{"USZE", 4, 150785},
	{"RIZT", 4, 150786},
	{"LYDW", 4, 150787},
	{"LRAG", 4, 150788},
	{"LKSG", 4, 150789},
	{"LAJE", 4, 150790},
	{"KEMM", 4, 150791},
	{"IXFA", 4, 150792},
	{"HLRE", 4, 150793},
	{"EPMU", 4, 150794},
	{"CNEU", 4, 150795},
	{"AUJO", 4, 150796},
	{"PANOPLY", 7, 150797},
	{"MAILLOT", 7, 150798},
	{"CREDULITY", 9, 150799},
	{"MICROLINE", 9, 150800},
	{"BRIGHTSTAR", 10, 150801},
	{"GENIOUS", 7, 150802},
	{"STANEK", 6, 150803},
	{"FANBASE", 7, 150804},
	{"RHOWCH", 6, 150805},
	{"IMMOBILIZER", 11, 150806},
	{"NITRITES", 8, 150807},
	{"HUMVEES", 7, 150808},
	{"ANIBAL", 6, 150809},
	{"SCIENTIFIQUES", 13, 150810},
	{"POWERHOUSES", 11, 150811},
	{"BREL", 4, 150812},
	{"MODDER", 6, 150813},
	{"IMAGEDATA", 9, 150814},
	{"INSIPIDUS", 9, 150815},
	{"DANZE", 5, 150816},
	{"BAGGS", 5, 150817},
	{"ASTOUND", 7, 150818},
	{"ESCOM", 5, 150819},
	{"OVERSUPPLY", 10, 150820},
	{"COILING", 7, 150821},
	{"CAPUCHIN", 8, 150822},
	{"KABHI", 5, 150823},
	{"OSTROM", 6, 150824},
	{"EHRMAN", 6, 150825},
	{"AIRD", 4, 150826},
	{"MEGAWATI", 8, 150827},
	{"PENROD", 6, 150828},
	{"CHERRYVILLE", 11, 150829},
	{"VOTZE", 5, 150830},
	{"JOWETT", 6, 150831},
	{"KAMAN", 5, 150832},
	{"IABC", 4, 150833},
	{"LONGITUDES", 10, 150834},
	{"YHOD", 4, 150835},
	{"XPLU", 4, 150836},
	{"WADR", 4, 150837},
	{"VISK", 4, 150838},
	{"UETF", 4, 150839},
	{"PEZH", 4, 150840},
	{"OPMD", 4, 150841},
	{"MEMD", 4, 150842},
	{"LMYH", 4, 150843},
	{"LEJR", 4, 150844},
	{"IABD", 4, 150845},
	{"FELU", 4, 150846},
	{"DQVI", 4, 150847},
	{"ATPP", 4, 150848},
	{"HEYWARD", 7, 150849},
	{"IJCAI", 5, 150850},
	{"PANIK", 5, 150851},
	{"PLATTFORM", 9, 150852},
	{"BREADMAKER", 10, 150853},
	{"PORTATION", 9, 150854},
	{"CALAHONDA", 9, 150855},
	{"COPPIE", 6, 150856},
	{"WIRELES", 7, 150857},
	{"ENGELMANN", 9, 150858},
	{"FREENODE", 8, 150859},
	{"XONG", 4, 150860},
	{"PLAIDS", 6, 150861},
	{"VOCA", 4, 150862},
	{"IVERSEN", 7, 150863},
	{"FONTENOT", 8, 150864},
	{"FRICTIONS", 9, 150865},
	{"GLASSFISH", 9, 150866},
	{"CITYBEAT", 8, 150867},
	{"ARGLIST", 7, 150868},
	{"PRECANCEROUS", 12, 150869},
	{"KAMINS", 6, 150870},
	{"FAMIGLIA", 8, 150871},
	{"BARENBOIM", 9, 150872},
	{"MONOCULTURE", 11, 150873},
	{"GMES", 4, 150874},
	{"PARVA", 5, 150875},
	{"ISEARCH", 7, 150876},
	{"NATURALE", 8, 150877},
	{"MAIOR", 5, 150878},
	{"BEWERTUNGEN", 11, 150879},
	{"BAGBY", 5, 150880},
	{"POTUS", 5, 150881},
	{"MCFALL", 6, 150882},
	{"SHIPING", 7, 150883},
	{"FIGUEIREDO", 10, 150884},
	{"VERKEHR", 7, 150885},
	{"MIKKELSEN", 9, 150886},
	{"ESCRIPTION", 10, 150887},
	{"KEYCITE", 7, 150888},
	{"CHARL", 5, 150889},
	{"WITHA", 5, 150890},
	{"WATERBIRDS", 10, 150891},
	{"RECLASSIFICATIONS", 17, 150892},
	{"HIEBERT", 7, 150893},
	{"BRACEBRIDGE", 11, 150894},
	{"MANIP", 5, 150895},
	{"UZIS", 4, 150896},
	{"SPAB", 4, 150897},
	{"SMYV", 4, 150898},
	{"RMKI", 4, 150899},
	{"RAEW", 4, 150900},
	{"ORFM", 4, 150901},
	{"OMCN", 4, 150902},
	{"OAUR", 4, 150903},
	{"MBDE", 4, 150904},
	{"LSMY", 4, 150905},
	{"LDMR", 4, 150906},
	{"IRSV", 4, 150907},
	{"HUKS", 4, 150908},
	{"GYMU", 4, 150909},
	{"BUNY", 4, 150910},
	{"BAPO", 4, 150911},
	{"AKEX", 4, 150912},
	{"PULTE", 5, 150913},
	{"EBERHART", 8, 150914},
	{"DIRITTO", 7, 150915},
	{"BIOVETC", 7, 150916},
	{"HEMATURIA", 9, 150917},
	{"KALK", 4, 150918},
	{"SMOLT", 5, 150919},
	{"RADIOCOMMUNICATIONS", 19, 150920},
	{"MAPHACK", 7, 150921},
	{"LUANA", 5, 150922},
	{"SOUPED", 6, 150923},
	{"NETVISION", 9, 150924},
	{"MINUSES", 7, 150925},
	{"COSMONAUTS", 10, 150926},
	{"HIGHRISE", 8, 150927},
	{"ERICCSON", 8, 150928},
	{"INCOHERENCE", 11, 150929},
	{"STUFFINGS", 9, 150930},
	{"PLZEN", 5, 150931},
	{"UMW", 3, 150932},
	{"TINYMCE", 7, 150933},
	{"OILFIELDS", 9, 150934},
	{"DROUIN", 6, 150935},
	{"AKROTIRI", 8, 150936},
	{"KISSY", 5, 150937},
	{"SULTANAHMET", 11, 150938},
	{"NARWHAL", 7, 150939},
	{"MATCHESRATING", 13, 150940},
	{"ARPEL", 5, 150941},
	{"GERMINATING", 11, 150942},
	{"QUIKDROP", 8, 150943},
	{"BLAD", 4, 150944},
	{"CALAMUS", 7, 150945},
	{"MBK", 3, 150946},
	{"SYMPATHISE", 10, 150947},
	{"VIDEOCARD", 9, 150948},
	{"USCS", 4, 150949},
	{"MARGINALISATION", 15, 150950},
	{"CWND", 4, 150951},
	{"SEMIGROUPS", 10, 150952},
	{"PRESUPUESTO", 11, 150953},
	{"WYONG", 5, 150954},
	{"HEADEND", 7, 150955},
	{"TENNESEE", 8, 150956},
	{"CASAR", 5, 150957},
	{"USAOPOLY", 8, 150958},
	{"LILLOOET", 8, 150959},
	{"DAWS", 4, 150960},
	{"RAWR", 4, 150961},
	{"HICKAM", 6, 150962},
	{"NONESSENTIAL", 12, 150963},
	{"RMSE", 4, 150964},
	{"ZENV", 4, 150965},
	{"YLUX", 4, 150966},
	{"UMHY", 4, 150967},
	{"UDIV", 4, 150968},
	{"TTDU", 4, 150969},
	{"PBYE", 4, 150970},
	{"NEZP", 4, 150971},
	{"MVPH", 4, 150972},
	{"LPWE", 4, 150973},
	{"KCOD", 4, 150974},
	{"DYUG", 4, 150975},
	{"DGAO", 4, 150976},
	{"CELM", 4, 150977},
	{"AARK", 4, 150978},
	{"UNWORN", 6, 150979},
	{"HDCD", 4, 150980},
	{"RIGHTNESS", 9, 150981},
	{"HOWLEY", 6, 150982},
	{"REBER", 5, 150983},
	{"MALKMUS", 7, 150984},
	{"PIETRA", 6, 150985},
	{"BZIP", 4, 150986},
	{"WHINERS", 7, 150987},
	{"NOIRS", 5, 150988},
	{"TRIANON", 7, 150989},
	{"KGF", 3, 150990},
	{"RESTUARANT", 10, 150991},
	{"PITYING", 7, 150992},
	{"WARTY", 5, 150993},
	{"EASYART", 7, 150994},
	{"GIRA", 4, 150995},
	{"CAMBLER", 7, 150996},
	{"ASTLE", 5, 150997},
	{"PSYCOPG", 7, 150998},
	{"JOSLYN", 6, 150999},
	{"BCBS", 4, 151000},
	{"SAALBACH", 8, 151001},
	{"FANFORCE", 8, 151002},
	{"KEUKEN", 6, 151003},
	{"TWITCHED", 8, 151004},
	{"GIORGOS", 7, 151005},
	{"MEDICINALS", 10, 151006},
	{"CLEFS", 5, 151007},
	{"DEMME", 5, 151008},
	{"HATTRICK", 8, 151009},
	{"LAVALIER", 8, 151010},
	{"RETICULE", 8, 151011},
	{"MUCKY", 5, 151012},
	{"PERVIOUS", 8, 151013},
	{"OPENSC", 6, 151014},
	{"RIJNDAEL", 8, 151015},
	{"BARNACLES", 9, 151016},
	{"SEANIX", 6, 151017},
	{"AXIL", 4, 151018},
	{"DARYN", 5, 151019},
	{"CATSTER", 7, 151020},
	{"PUNCTUATE", 9, 151021},
	{"EGGDROP", 7, 151022},
	{"SNOWGLOBE", 9, 151023},
	{"ICONALT", 7, 151024},
	{"ACTUEL", 6, 151025},
	{"PEERON", 6, 151026},
	{"EASTING", 7, 151027},
	{"MOSK", 4, 151028},
	{"LDIF", 4, 151029},
	{"ZYSA", 4, 151030},
	{"WSVA", 4, 151031},
	{"VYOU", 4, 151032},
	{"UEMY", 4, 151033},
	{"UECK", 4, 151034},
	{"TKMH", 4, 151035},
	{"TKAC", 4, 151036},
	{"SYFA", 4, 151037},
	{"SJOL", 4, 151038},
	{"RVAA", 4, 151039},
	{"RFFI", 4, 151040},
	{"RBDE", 4, 151041},
	{"NUSK", 4, 151042},
	{"MKIP", 4, 151043},
	{"MINQ", 4, 151044},
	{"KBUY", 4, 151045},
	{"EZIR", 4, 151046},
	{"EKYR", 4, 151047},
	{"EDBC", 4, 151048},
	{"CKIB", 4, 151049},
	{"CAEX", 4, 151050},
	{"AMBW", 4, 151051},
	{"VLDL", 4, 151052},
	{"POPSTARS", 8, 151053},
	{"PANTED", 6, 151054},
	{"MIDSHIPMAN", 10, 151055},
	{"HURTADO", 7, 151056},
	{"ACCUPRIL", 8, 151057},
	{"TETLEY", 6, 151058},
	{"PHALLE", 6, 151059},
	{"ESTUDOS", 7, 151060},
	{"ROSECRANS", 9, 151061},
	{"LONGHAIR", 8, 151062},
	{"EXOTHERMIC", 10, 151063},
	{"ISOLATIONISM", 12, 151064},
	{"JUDA", 4, 151065},
	{"CONFERENCIA", 11, 151066},
	{"REMOTECONTROL", 13, 151067},
	{"MANCUNIANS", 10, 151068},
	{"NASHBAR", 7, 151069},
	{"REISTERSTOWN", 12, 151070},
	{"OVERMAN", 7, 151071},
	{"INNISFAIL", 9, 151072},
	{"GONDOLAS", 8, 151073},
	{"BENBROOK", 8, 151074},
	{"SWIFTNESS", 9, 151075},
	{"LILLARD", 7, 151076},
	{"SPENDERS", 8, 151077},
	{"PLAYFORD", 8, 151078},
	{"DIPLOMATICALLY", 14, 151079},
	{"SAMIZDAT", 8, 151080},
	{"NECESSARIES", 11, 151081},
	{"CINCY", 5, 151082},
	{"ALMEDA", 6, 151083},
	{"ENSTORE", 7, 151084},
	{"ZORBA", 5, 151085},
	{"QUINTESSENTIALLY", 16, 151086},
	{"NESMITH", 7, 151087},
	{"ANDROGYNOUS", 11, 151088},
	{"WINDSPEED", 9, 151089},
	{"ADVENTNET", 9, 151090},
	{"ISBELL", 6, 151091},
	{"WESTERNMOST", 11, 151092},
	{"GOVERNO", 7, 151093},
	{"NULLITY", 7, 151094},
	{"DISCRIMINATIVE", 14, 151095},
	{"CROTTY", 6, 151096},
	{"SCHAAF", 6, 151097},
	{"VERMOX", 6, 151098},
	{"BUSINESSS", 9, 151099},
	{"ZEMY", 4, 151100},
	{"XAIR", 4, 151101},
	{"NCIU", 4, 151102},
	{"LCEO", 4, 151103},
	{"LAXS", 4, 151104},
	{"KLAG", 4, 151105},
	{"HYKI", 4, 151106},
	{"HWRA", 4, 151107},
	{"GUEK", 4, 151108},
	{"FNAU", 4, 151109},
	{"FITJ", 4, 151110},
	{"BUMV", 4, 151111},
	{"BEGT", 4, 151112},
	{"BERNINI", 7, 151113},
	{"SANGH", 5, 151114},
	{"ROLSTON", 7, 151115},
	{"BELEK", 5, 151116},
	{"FTAPE", 5, 151117},
	{"GOMERA", 6, 151118},
	{"DCFORUM", 7, 151119},
	{"ZEEMAN", 6, 151120},
	{"NDISWRAPPER", 11, 151121},
	{"TULI", 4, 151122},
	{"MENINGIOMA", 10, 151123},
	{"YARBOROUGH", 10, 151124},
	{"SANDYS", 6, 151125},
	{"BLUESPOON", 9, 151126},
	{"CCIS", 4, 151127},
	{"SHEMESH", 7, 151128},
	{"JOTTINGS", 8, 151129},
	{"RORTY", 5, 151130},
	{"MELDRUM", 7, 151131},
	{"FRSIRT", 6, 151132},
	{"BERMUDEZ", 8, 151133},
	{"LYK", 3, 151134},
	{"DAWA", 4, 151135},
	{"MISCONSTRUED", 12, 151136},
	{"GLFLOAT", 7, 151137},
	{"AGENTUR", 7, 151138},
	{"MACEO", 5, 151139},
	{"PETCARE", 7, 151140},
	{"TACKETT", 7, 151141},
	{"TENEMOS", 7, 151142},
	{"RELISHING", 9, 151143},
	{"SUPERCEDES", 10, 151144},
	{"CROMBIE", 7, 151145},
	{"TABB", 4, 151146},
	{"RENDERERS", 9, 151147},
	{"CGB", 3, 151148},
	{"UNSUITED", 8, 151149},
	{"INSPITE", 7, 151150},
	{"HINDEMITH", 9, 151151},
	{"SMASHBOX", 8, 151152},
	{"ZEBRAHEAD", 9, 151153},
	{"SPECTACULARS", 12, 151154},
	{"SINGLETONS", 10, 151155},
	{"BEAUDRY", 7, 151156},
	{"HAWKERS", 7, 151157},
	{"TRIPPI", 6, 151158},
	{"AERIO", 5, 151159},
	{"GLOBAT", 6, 151160},
	{"ISHERWOOD", 9, 151161},
	{"DELTOID", 7, 151162},
	{"GLUTAMYL", 8, 151163},
	{"SWEARINGEN", 10, 151164},
	{"ADRENOCEPTOR", 12, 151165},
	{"BRIANS", 6, 151166},
	{"YTUS", 4, 151167},
	{"SUSK", 4, 151168},
	{"RYKR", 4, 151169},
	{"PEZE", 4, 151170},
	{"MOBV", 4, 151171},
	{"MLYW", 4, 151172},
	{"FTIF", 4, 151173},
	{"EMSQ", 4, 151174},
	{"EAKJ", 4, 151175},
	{"DWEU", 4, 151176},
	{"DMRT", 4, 151177},
	{"DICG", 4, 151178},
	{"ARSZ", 4, 151179},
	{"APSJ", 4, 151180},
	{"BEGGINING", 9, 151181},
	{"HYDROXYLATION", 13, 151182},
	{"GURGLING", 8, 151183},
	{"COOMBES", 7, 151184},
	{"SHOREVIEW", 9, 151185},
	{"INCLUIR", 7, 151186},
	{"IMAGININGS", 10, 151187},
	{"AGEFI", 5, 151188},
	{"CELCIUS", 7, 151189},
	{"KRASNODAR", 9, 151190},
	{"COMSCORE", 8, 151191},
	{"TAMBORINE", 9, 151192},
	{"CINTAS", 6, 151193},
	{"CAMB", 4, 151194},
	{"LACHANCE", 8, 151195},
	{"SUBDIVIDER", 10, 151196},
	{"CELEBRANTS", 10, 151197},
	{"WHITEVILLE", 10, 151198},
	{"DAMAGESPEED", 11, 151199},
	{"EDENTON", 7, 151200},
	{"KUGLER", 6, 151201},
	{"WYCHAVON", 8, 151202},
	{"SPYTECH", 7, 151203},
	{"RESIDENCIA", 10, 151204},
	{"ZWK", 3, 151205},
	{"ZWF", 3, 151206},
	{"ZKK", 3, 151207},
	{"XUQ", 3, 151208},
	{"XJJ", 3, 151209},
	{"WXV", 3, 151210},
	{"WXJ", 3, 151211},
	{"WVQ", 3, 151212},
	{"QYP", 3, 151213},
	{"QXB", 3, 151214},
	{"PZV", 3, 151215},
	{"PVJ", 3, 151216},
	{"MQG", 3, 151217},
	{"MFQ", 3, 151218},
	{"KMQ", 3, 151219},
	{"KJQ", 3, 151220},
	{"DQY", 3, 151221},
	{"OHCHR", 5, 151222},
	{"TAMORA", 6, 151223},
	{"PEDER", 5, 151224},
	{"MICON", 5, 151225},
	{"FRINK", 5, 151226},
	{"WALLEY", 6, 151227},
	{"CHOLESTASIS", 11, 151228},
	{"DEXIA", 5, 151229},
	{"COMPAGNIA", 9, 151230},
	{"WARATAH", 7, 151231},
	{"BOATSWAIN", 9, 151232},
	{"BREADWINNER", 11, 151233},
	{"VINOS", 5, 151234},
	{"GRIFFIS", 7, 151235},
	{"HEARTHSTONE", 11, 151236},
	{"CWRS", 4, 151237},
	{"BBFC", 4, 151238},
	{"TINPLATE", 8, 151239},
	{"STANDARDISE", 11, 151240},
	{"FONDLE", 6, 151241},
	{"CUDDLED", 7, 151242},
	{"AGIAN", 5, 151243},
	{"YNOG", 4, 151244},
	{"XEGE", 4, 151245},
	{"UAVA", 4, 151246},
	{"THYY", 4, 151247},
	{"TAXG", 4, 151248},
	{"PEGB", 4, 151249},
	{"OBOV", 4, 151250},
	{"LUBV", 4, 151251},
	{"LRAZ", 4, 151252},
	{"IFBL", 4, 151253},
	{"ICJI", 4, 151254},
	{"HRUR", 4, 151255},
	{"FEBV", 4, 151256},
	{"ERMJ", 4, 151257},
	{"DTAF", 4, 151258},
	{"DOEM", 4, 151259},
	{"DFFI", 4, 151260},
	{"BTUR", 4, 151261},
	{"ARFT", 4, 151262},
	{"ALYG", 4, 151263},
	{"AJUI", 4, 151264},
	{"CRYSTALLIZE", 11, 151265},
	{"SPOGG", 5, 151266},
	{"LEIBER", 6, 151267},
	{"VIDING", 6, 151268},
	{"GEOLOGICALLY", 12, 151269},
	{"WESTMINISTER", 12, 151270},
	{"IUNIVERSE", 9, 151271},
	{"BULBUL", 6, 151272},
	{"ROCO", 4, 151273},
	{"GUSSETED", 8, 151274},
	{"SUPERINTENDENCE", 15, 151275},
	{"HYPERTECH", 9, 151276},
	{"PEPCID", 6, 151277},
	{"NOMINET", 7, 151278},
	{"POHNPEI", 7, 151279},
	{"LUMINES", 7, 151280},
	{"PORKSTER", 8, 151281},
	{"EROTYKA", 7, 151282},
	{"AUSTERLITZ", 10, 151283},
	{"UMLAUT", 6, 151284},
	{"FENDING", 7, 151285},
	{"NAPISY", 6, 151286},
	{"BWPLUGPROTOCOL", 14, 151287},
	{"NEMATIC", 7, 151288},
	{"CITYS", 5, 151289},
	{"GRANMA", 6, 151290},
	{"ADOLC", 5, 151291},
	{"CHAPPEL", 7, 151292},
	{"RESYNC", 6, 151293},
	{"HEAVIES", 7, 151294},
	{"LANDSBERG", 9, 151295},
	{"SELAMAT", 7, 151296},
	{"YNEK", 4, 151297},
	{"PUGI", 4, 151298},
	{"PDOL", 4, 151299},
	{"IXHU", 4, 151300},
	{"HUAB", 4, 151301},
	{"GOIM", 4, 151302},
	{"GEIV", 4, 151303},
	{"EKCU", 4, 151304},
	{"DLYJ", 4, 151305},
	{"ARCP", 4, 151306},
	{"HOLYFIELD", 9, 151307},
	{"REGELN", 6, 151308},
	{"CARMELLA", 8, 151309},
	{"PODGE", 5, 151310},
	{"LOCKA", 5, 151311},
	{"WINTERVILLE", 11, 151312},
	{"EXTRUDING", 9, 151313},
	{"POPPLER", 7, 151314},
	{"LINFORD", 7, 151315},
	{"LEONOR", 6, 151316},
	{"BETSIE", 6, 151317},
	{"KIRSHENBAUM", 11, 151318},
	{"BZERO", 5, 151319},
	{"WWYAHOO", 7, 151320},
	{"BETTERS", 7, 151321},
	{"MKNOD", 5, 151322},
	{"CWIS", 4, 151323},
	{"TRUDI", 5, 151324},
	{"ISOLATIONIST", 12, 151325},
	{"BUSSEY", 6, 151326},
	{"IMPERIALS", 9, 151327},
	{"ANTISYMMETRIC", 13, 151328},
	{"SUSTAINER", 9, 151329},
	{"CUNLIFFE", 8, 151330},
	{"JOAB", 4, 151331},
	{"HATSHEPSUT", 10, 151332},
	{"OKURA", 5, 151333},
	{"WWL", 3, 151334},
	{"CORRUPTIONS", 11, 151335},
	{"REISMAN", 7, 151336},
	{"GALARY", 6, 151337},
	{"PERSEVERING", 11, 151338},
	{"HASSETT", 7, 151339},
	{"HARDCASE", 8, 151340},
	{"ULKT", 4, 151341},
	{"SRUH", 4, 151342},
	{"RMCU", 4, 151343},
	{"RGFL", 4, 151344},
	{"MPMU", 4, 151345},
	{"MHUD", 4, 151346},
	{"LSKU", 4, 151347},
	{"LPOK", 4, 151348},
	{"LIPV", 4, 151349},
	{"HYDU", 4, 151350},
	{"HGAU", 4, 151351},
	{"HEWK", 4, 151352},
	{"GIAK", 4, 151353},
	{"EUPK", 4, 151354},
	{"DVDE", 4, 151355},
	{"DOXB", 4, 151356},
	{"CODU", 4, 151357},
	{"CAOW", 4, 151358},
	{"AWEM", 4, 151359},
	{"SILVERLAKE", 10, 151360},
	{"TWYFORD", 7, 151361},
	{"TRANSVERSELY", 12, 151362},
	{"SPERBER", 7, 151363},
	{"ADDRESSEES", 10, 151364},
	{"REMARRY", 7, 151365},
	{"GALASHIELS", 10, 151366},
	{"ANTARA", 6, 151367},
	{"NITRIFICATION", 13, 151368},
	{"ABELARD", 7, 151369},
	{"NOBILE", 6, 151370},
	{"UNPERTURBED", 11, 151371},
	{"SILANE", 6, 151372},
	{"INAUGURATES", 11, 151373},
	{"KOJO", 4, 151374},
	{"DEGREASING", 10, 151375},
	{"AKAD", 4, 151376},
	{"RYDELL", 6, 151377},
	{"FEATURELESS", 11, 151378},
	{"AUTHENTIFICATION", 16, 151379},
	{"ESCUELAS", 8, 151380},
	{"IFCCARTESIANPOINT", 17, 151381},
	{"ARROZ", 5, 151382},
	{"MICHAELSON", 10, 151383},
	{"KDEEDU", 6, 151384},
	{"PESETAS", 7, 151385},
	{"GUARENTEE", 9, 151386},
	{"THUNDERDOME", 11, 151387},
	{"PASTEURIZATION", 14, 151388},
	{"IDYLLWILD", 9, 151389},
	{"BEANZ", 5, 151390},
	{"SLAVED", 6, 151391},
	{"WORTHAM", 7, 151392},
	{"PLICATIONS", 10, 151393},
	{"BABALU", 6, 151394},
	{"ANKUR", 5, 151395},
	{"WIKKA", 5, 151396},
	{"ZONET", 5, 151397},
	{"KRAKAUER", 8, 151398},
	{"ZSOLT", 5, 151399},
	{"DAWSONS", 7, 151400},
	{"RANBAXY", 7, 151401},
	{"ANTIMALARIAL", 12, 151402},
	{"PERMITTIVITY", 12, 151403},
	{"SUMMERHOUSE", 11, 151404},
	{"TRADUCI", 7, 151405},
	{"UMNP", 4, 151406},
	{"UKAU", 4, 151407},
	{"SVOR", 4, 151408},
	{"SBCH", 4, 151409},
	{"PDUT", 4, 151410},
	{"NWAX", 4, 151411},
	{"NLUZ", 4, 151412},
	{"MHAY", 4, 151413},
	{"LWEM", 4, 151414},
	{"LSKO", 4, 151415},
	{"KVID", 4, 151416},
	{"HMSW", 4, 151417},
	{"FYAP", 4, 151418},
	{"EICR", 4, 151419},
	{"EGYD", 4, 151420},
	{"DAIR", 4, 151421},
	{"NETCONNECT", 10, 151422},
	{"PORTERHOUSE", 11, 151423},
	{"ILLUSIVE", 8, 151424},
	{"TSTMS", 5, 151425},
	{"OCTAVIUS", 8, 151426},
	{"MEDITATIE", 9, 151427},
	{"CHUCKING", 8, 151428},
	{"MISSIN", 6, 151429},
	{"DELICATES", 9, 151430},
	{"PICARDIE", 8, 151431},
	{"AQUATICA", 8, 151432},
	{"WARMONGER", 9, 151433},
	{"DALGAARD", 8, 151434},
	{"UIDS", 4, 151435},
	{"SUBIC", 5, 151436},
	{"RESCALING", 9, 151437},
	{"LRQH", 4, 151438},
	{"PETIOLE", 7, 151439},
	{"DISQUIETING", 11, 151440},
	{"ERTIES", 6, 151441},
	{"ENFAMIL", 7, 151442},
	{"CONJUGATING", 11, 151443},
	{"CHANDA", 6, 151444},
	{"NICLAS", 6, 151445},
	{"MOIRE", 5, 151446},
	{"TUFTE", 5, 151447},
	{"CONTRACTILITY", 13, 151448},
	{"KOSICE", 6, 151449},
	{"ECONOM", 6, 151450},
	{"KUYKENDALL", 10, 151451},
	{"AMERINDIAN", 10, 151452},
	{"YOGALATES", 9, 151453},
	{"ILLUMINA", 8, 151454},
	{"BOMP", 4, 151455},
	{"CANTY", 5, 151456},
	{"RSTR", 4, 151457},
	{"JENKINTOWN", 10, 151458},
	{"NEELEY", 6, 151459},
	{"BALDWINSVILLE", 13, 151460},
	{"LEGALZOOM", 9, 151461},
	{"RIPENESS", 8, 151462},
	{"FRENCHTOWN", 10, 151463},
	{"WYES", 4, 151464},
	{"WUNL", 4, 151465},
	{"WOAW", 4, 151466},
	{"WFAV", 4, 151467},
	{"UNZE", 4, 151468},
	{"UDDG", 4, 151469},
	{"TTYJ", 4, 151470},
	{"RDIB", 4, 151471},
	{"KIBR", 4, 151472},
	{"IFYL", 4, 151473},
	{"GIWH", 4, 151474},
	{"GGYT", 4, 151475},
	{"EXMU", 4, 151476},
	{"DRZE", 4, 151477},
	{"DJEO", 4, 151478},
	{"CNNP", 4, 151479},
	{"CGAV", 4, 151480},
	{"BNEX", 4, 151481},
	{"BCET", 4, 151482},
	{"PHILP", 5, 151483},
	{"VEERING", 7, 151484},
	{"RADISYS", 7, 151485},
	{"MOLESKINES", 10, 151486},
	{"AEDATING", 8, 151487},
	{"ADVERTIZE", 9, 151488},
	{"ALGUNA", 6, 151489},
	{"TABBING", 7, 151490},
	{"SINKHOLE", 8, 151491},
	{"TIERE", 5, 151492},
	{"MEDCOMPARE", 10, 151493},
	{"STREAKY", 7, 151494},
	{"HARUKA", 6, 151495},
	{"RUTTING", 7, 151496},
	{"CATFORD", 7, 151497},
	{"BOURDON", 7, 151498},
	{"JUNKER", 6, 151499},
	{"COMMODIFICATION", 15, 151500},
	{"SMITHTON", 8, 151501},
	{"NEUROPHYSIOLOGICAL", 18, 151502},
	{"GWG", 3, 151503},
	{"ICHABOD", 7, 151504},
	{"VAPID", 5, 151505},
	{"DEBATERS", 8, 151506},
	{"ALDWYCH", 7, 151507},
	{"NICAL", 5, 151508},
	{"SHUGART", 7, 151509},
	{"TSETSE", 6, 151510},
	{"APPEARENCE", 10, 151511},
	{"ADULTERATION", 12, 151512},
	{"CINAHL", 6, 151513},
	{"ANGRA", 5, 151514},
	{"KMWORLD", 7, 151515},
	{"CLOUDVEIL", 9, 151516},
	{"PAKET", 5, 151517},
	{"REACTOS", 7, 151518},
	{"PIEDS", 5, 151519},
	{"DEBRIDEMENT", 11, 151520},
	{"MENDIP", 6, 151521},
	{"IKARUS", 6, 151522},
	{"UNREMITTING", 11, 151523},
	{"OKOTOKS", 7, 151524},
	{"RECHNUNG", 8, 151525},
	{"SEMITE", 6, 151526},
	{"HAIRBALL", 8, 151527},
	{"YERKES", 6, 151528},
	{"ZYWH", 4, 151529},
	{"XXAN", 4, 151530},
	{"VASD", 4, 151531},
	{"SIBY", 4, 151532},
	{"PHCH", 4, 151533},
	{"OUFU", 4, 151534},
	{"OFNM", 4, 151535},
	{"NKLU", 4, 151536},
	{"NDMH", 4, 151537},
	{"LGUL", 4, 151538},
	{"KOVY", 4, 151539},
	{"HODM", 4, 151540},
	{"FBOE", 4, 151541},
	{"EUNQ", 4, 151542},
	{"EDDT", 4, 151543},
	{"DUIA", 4, 151544},
	{"CISJ", 4, 151545},
	{"AEFR", 4, 151546},
	{"CWDM", 4, 151547},
	{"EAGLEVILLE", 10, 151548},
	{"ORRICO", 6, 151549},
	{"CARDZ", 5, 151550},
	{"CLENCHING", 9, 151551},
	{"ARAC", 4, 151552},
	{"ARQUIVO", 7, 151553},
	{"PRIMULA", 7, 151554},
	{"HAMBY", 5, 151555},
	{"INTEROFFICE", 11, 151556},
	{"GLOVERSVILLE", 12, 151557},
	{"PETCH", 5, 151558},
	{"BESTAR", 6, 151559},
	{"INTERNATIONAUX", 14, 151560},
	{"CORDIALS", 8, 151561},
	{"AFRC", 4, 151562},
	{"BANDAGED", 8, 151563},
	{"EVANESCENT", 10, 151564},
	{"UDG", 3, 151565},
	{"AUSSTELLUNG", 11, 151566},
	{"MEDORA", 6, 151567},
	{"PICTUREQUEST", 12, 151568},
	{"FORTUNATO", 9, 151569},
	{"OVERSHOES", 9, 151570},
	{"LIBGTKMM", 8, 151571},
	{"ATAVISTIC", 9, 151572},
	{"PRADHAN", 7, 151573},
	{"BREMSSTRAHLUNG", 14, 151574},
	{"FEVERED", 7, 151575},
	{"ROADSIDETHOUGHT", 15, 151576},
	{"INDIGNITY", 9, 151577},
	{"MEDILL", 6, 151578},
	{"GULEZ", 5, 151579},
	{"PINCHES", 7, 151580},
	{"ELLING", 6, 151581},
	{"MULTIPAGE", 9, 151582},
	{"SEMIAUTOMATIC", 13, 151583},
	{"CLAUSS", 6, 151584},
	{"POLTI", 5, 151585},
	{"GENERALISTS", 11, 151586},
	{"COPEPODS", 8, 151587},
	{"TTAGETMEMORY", 12, 151588},
	{"CHIPPERS", 8, 151589},
	{"ZYAB", 4, 151590},
	{"XDRO", 4, 151591},
	{"UFFN", 4, 151592},
	{"THJR", 4, 151593},
	{"THCD", 4, 151594},
	{"RGDO", 4, 151595},
	{"RAQD", 4, 151596},
	{"OMWW", 4, 151597},
	{"OKUK", 4, 151598},
	{"NUXC", 4, 151599},
	{"NJUK", 4, 151600},
	{"KOVT", 4, 151601},
	{"KOPR", 4, 151602},
	{"KMYF", 4, 151603},
	{"KFAT", 4, 151604},
	{"HLDE", 4, 151605},
	{"ELZO", 4, 151606},
	{"DAAV", 4, 151607},
	{"BOXV", 4, 151608},
	{"CUHK", 4, 151609},
	{"ASPINALL", 8, 151610},
	{"AFRIDI", 6, 151611},
	{"VMP", 3, 151612},
	{"NEUSE", 5, 151613},
	{"BUTA", 4, 151614},
	{"ZOROASTRIANISM", 14, 151615},
	{"AGLOW", 5, 151616},
	{"METOCLOPRAMIDE", 14, 151617},
	{"GREENBANK", 9, 151618},
	{"NETLABELS", 9, 151619},
	{"AKAROA", 6, 151620},
	{"CHIDAMBARAM", 11, 151621},
	{"MACASKILL", 9, 151622},
	{"CLAREOS", 7, 151623},
	{"ESCHATOLOGICAL", 14, 151624},
	{"MONONGALIA", 10, 151625},
	{"WANAMAKER", 9, 151626},
	{"SHINICHI", 8, 151627},
	{"PESCE", 5, 151628},
	{"NICOTINAMIDE", 12, 151629},
	{"AQMD", 4, 151630},
	{"FIDELIO", 7, 151631},
	{"IRREGULARS", 10, 151632},
	{"HUTTER", 6, 151633},
	{"SLIMMERS", 8, 151634},
	{"JEWELSWAREHOUSE", 15, 151635},
	{"INVESTIGA", 9, 151636},
	{"DINGER", 6, 151637},
	{"LILES", 5, 151638},
	{"JUDG", 4, 151639},
	{"KARYOTYPE", 9, 151640},
	{"MIDDEN", 6, 151641},
	{"DACHSHUNDS", 10, 151642},
	{"YONGKANG", 8, 151643},
	{"ELECTROLUMINESCENT", 18, 151644},
	{"BIOCRAWLER", 10, 151645},
	{"ASCOLI", 6, 151646},
	{"HGTVPRO", 7, 151647},
	{"ZOROASTRIAN", 11, 151648},
	{"ERRATICALLY", 11, 151649},
	{"RAFSANJANI", 10, 151650},
	{"NOTAMMENT", 9, 151651},
	{"UNAPOLOGETIC", 12, 151652},
	{"BOLIVARIAN", 10, 151653},
	{"EUROPOL", 7, 151654},
	{"BULLOCKS", 8, 151655},
	{"WLIC", 4, 151656},
	{"VAWE", 4, 151657},
	{"UMBH", 4, 151658},
	{"UMBD", 4, 151659},
	{"UFEN", 4, 151660},
	{"TOBP", 4, 151661},
	{"OUXF", 4, 151662},
	{"NGNY", 4, 151663},
	{"MKAM", 4, 151664},
	{"LNAG", 4, 151665},
	{"KAFL", 4, 151666},
	{"JOSD", 4, 151667},
	{"IGOM", 4, 151668},
	{"HLLO", 4, 151669},
	{"FOSY", 4, 151670},
	{"EEZZ", 4, 151671},
	{"AUPI", 4, 151672},
	{"AUDP", 4, 151673},
	{"AKUH", 4, 151674},
	{"ACHROMATIC", 10, 151675},
	{"INEBRIATED", 10, 151676},
	{"ZEMECKIS", 8, 151677},
	{"PEINTURE", 8, 151678},
	{"GLBA", 4, 151679},
	{"CHATTE", 6, 151680},
	{"RANDO", 5, 151681},
	{"RENAISANCE", 10, 151682},
	{"LOJA", 4, 151683},
	{"KONGO", 5, 151684},
	{"CRISPADS", 8, 151685},
	{"MFW", 3, 151686},
	{"ARCOM", 5, 151687},
	{"PTCA", 4, 151688},
	{"CONSERVA", 8, 151689},
	{"UNIVERSITARIO", 13, 151690},
	{"TELEOLOGICAL", 12, 151691},
	{"NOCTURNES", 9, 151692},
	{"MOYENNE", 7, 151693},
	{"ELIZABETHTON", 12, 151694},
	{"VALERIUS", 8, 151695},
	{"CERTI", 5, 151696},
	{"ISLAN", 5, 151697},
	{"PORM", 4, 151698},
	{"VILIFIED", 8, 151699},
	{"TELEFILM", 8, 151700},
	{"HOUSWIVES", 9, 151701},
	{"CHUCKED", 7, 151702},
	{"MEISSEN", 7, 151703},
	{"NUBIRA", 6, 151704},
	{"RANSACKED", 9, 151705},
	{"MOMMAS", 6, 151706},
	{"COURREGES", 9, 151707},
	{"CAROLING", 8, 151708},
	{"FROESE", 6, 151709},
	{"HISTORIE", 8, 151710},
	{"BUGBEAR", 7, 151711},
	{"WREAKED", 7, 151712},
	{"USETRADEMARKSCOPYRIGHT", 22, 151713},
	{"HYNDMAN", 7, 151714},
	{"SURFRIDER", 9, 151715},
	{"YODI", 4, 151716},
	{"YIPR", 4, 151717},
	{"XYIN", 4, 151718},
	{"UEZR", 4, 151719},
	{"SDPA", 4, 151720},
	{"SCIB", 4, 151721},
	{"LFRY", 4, 151722},
	{"JINC", 4, 151723},
	{"HADZ", 4, 151724},
	{"GUNV", 4, 151725},
	{"GOMB", 4, 151726},
	{"EWKS", 4, 151727},
	{"EGPO", 4, 151728},
	{"EDLB", 4, 151729},
	{"DHIJ", 4, 151730},
	{"DFEI", 4, 151731},
	{"BDIR", 4, 151732},
	{"AYIK", 4, 151733},
	{"DYMOCKS", 7, 151734},
	{"HOGSHEAD", 8, 151735},
	{"FCIP", 4, 151736},
	{"MASQUES", 7, 151737},
	{"ROBEEZ", 6, 151738},
	{"SPECTRO", 7, 151739},
	{"RISORSE", 7, 151740},
	{"RADARSAT", 8, 151741},
	{"STANSBURY", 9, 151742},
	{"POCS", 4, 151743},
	{"BREEDEN", 7, 151744},
	{"EUSKERA", 7, 151745},
	{"GRAVELS", 7, 151746},
	{"HALFPENNY", 9, 151747},
	{"GRATUITAS", 9, 151748},
	{"CCV", 3, 151749},
	{"FORMULAIRE", 10, 151750},
	{"DEREGULATING", 12, 151751},
	{"FETES", 5, 151752},
	{"CUTI", 4, 151753},
	{"QUARTERDECK", 11, 151754},
	{"LANCEOLATE", 10, 151755},
	{"NANTAHALA", 9, 151756},
	{"KNEELS", 6, 151757},
	{"SEPALS", 6, 151758},
	{"PINGED", 6, 151759},
	{"LEVOFLOXACIN", 12, 151760},
	{"MESMER", 6, 151761},
	{"STEREOCHEMISTRY", 15, 151762},
	{"KLIKK", 5, 151763},
	{"AMPL", 4, 151764},
	{"RETICENCE", 9, 151765},
	{"PASSIVES", 8, 151766},
	{"IAMBIC", 6, 151767},
	{"MISHKA", 6, 151768},
	{"PERSONALES", 10, 151769},
	{"NIEUWSBRIEF", 11, 151770},
	{"PROVABLY", 8, 151771},
	{"BICKER", 6, 151772},
	{"LIERAC", 6, 151773},
	{"CAPRON", 6, 151774},
	{"FALLER", 6, 151775},
	{"UMRAH", 5, 151776},
	{"RONDEAU", 7, 151777},
	{"POSTPRODUCTION", 14, 151778},
	{"CAMSHAFTS", 9, 151779},
	{"YPAM", 4, 151780},
	{"YMEW", 4, 151781},
	{"WBYS", 4, 151782},
	{"UOLI", 4, 151783},
	{"RZAK", 4, 151784},
	{"ORCN", 4, 151785},
	{"OPYB", 4, 151786},
	{"LMYB", 4, 151787},
	{"LMME", 4, 151788},
	{"GUTH", 4, 151789},
	{"TREETOP", 7, 151790},
	{"NPOV", 4, 151791},
	{"LISBETH", 7, 151792},
	{"CONDONING", 9, 151793},
	{"KAHLIL", 6, 151794},
	{"LUVS", 4, 151795},
	{"WARKWORTH", 9, 151796},
	{"MAREMMA", 7, 151797},
	{"SERWER", 6, 151798},
	{"QOUTES", 6, 151799},
	{"PROSELYTIZING", 13, 151800},
	{"URD", 3, 151801},
	{"NERV", 4, 151802},
	{"HASSEL", 6, 151803},
	{"GBIF", 4, 151804},
	{"INEDIBLE", 8, 151805},
	{"LOCKFILE", 8, 151806},
	{"HACC", 4, 151807},
	{"GOULDHOME", 9, 151808},
	{"FALSEWORK", 9, 151809},
	{"TETHERS", 7, 151810},
	{"OSORIO", 6, 151811},
	{"MCCLAREN", 8, 151812},
	{"DEPLORED", 8, 151813},
	{"SUBALPINE", 9, 151814},
	{"ANABAPTIST", 10, 151815},
	{"ICKE", 4, 151816},
	{"EZELL", 5, 151817},
	{"HAIRBRUSH", 9, 151818},
	{"UNTANGLING", 10, 151819},
	{"ANHYDRASE", 9, 151820},
	{"OROSCOPO", 8, 151821},
	{"TUNNELED", 8, 151822},
	{"IDEATIVE", 8, 151823},
	{"POPEX", 5, 151824},
	{"CASAMENTO", 9, 151825},
	{"PLAYSITE", 8, 151826},
	{"VILIFICATION", 12, 151827},
	{"GOBJECT", 7, 151828},
	{"NIGROVIRIDIS", 12, 151829},
	{"ZRES", 4, 151830},
	{"YNNB", 4, 151831},
	{"XINV", 4, 151832},
	{"UTMM", 4, 151833},
	{"TRIR", 4, 151834},
	{"SZAK", 4, 151835},
	{"SMRG", 4, 151836},
	{"REGJ", 4, 151837},
	{"NDXB", 4, 151838},
	{"MSAK", 4, 151839},
	{"LPHF", 4, 151840},
	{"LDUA", 4, 151841},
	{"LAGN", 4, 151842},
	{"KARH", 4, 151843},
	{"IOCY", 4, 151844},
	{"IGVI", 4, 151845},
	{"ERDG", 4, 151846},
	{"DIOJ", 4, 151847},
	{"BZER", 4, 151848},
	{"AULY", 4, 151849},
	{"KAUSHIK", 7, 151850},
	{"BRINDLEY", 8, 151851},
	{"UNFASHIONABLE", 13, 151852},
	{"PARANA", 6, 151853},
	{"GOODSTYLE", 9, 151854},
	{"SPIROS", 6, 151855},
	{"BODYBOARD", 9, 151856},
	{"PHRVA", 5, 151857},
	{"DRF", 3, 151858},
	{"ZOLLVEREIN", 10, 151859},
	{"GORDONS", 7, 151860},
	{"LLYN", 4, 151861},
	{"LAVINA", 6, 151862},
	{"DHAHRAN", 7, 151863},
	{"BIGGLES", 7, 151864},
	{"PRINGLES", 8, 151865},
	{"JACOBEAN", 8, 151866},
	{"HYSTER", 6, 151867},
	{"METABOLIZING", 12, 151868},
	{"EMULATEUR", 9, 151869},
	{"SCHRAM", 6, 151870},
	{"LOVETH", 6, 151871},
	{"PREPCOM", 7, 151872},
	{"CIPD", 4, 151873},
	{"SCEPTIC", 7, 151874},
	{"RAJASTHANI", 10, 151875},
	{"REDETERMINATION", 15, 151876},
	{"MARDER", 6, 151877},
	{"SOFTWALK", 8, 151878},
	{"UNTRANSFORMED", 13, 151879},
	{"PLOYEES", 7, 151880},
	{"REALIGNED", 9, 151881},
	{"WYSS", 4, 151882},
	{"NONCURRENT", 10, 151883},
	{"MILLILITER", 10, 151884},
	{"EDIMAX", 6, 151885},
	{"GORGON", 6, 151886},
	{"ATTRIBUTETYPE", 13, 151887},
	{"OPENJADE", 8, 151888},
	{"YNGO", 4, 151889},
	{"VPAL", 4, 151890},
	{"SPYC", 4, 151891},
	{"RYOI", 4, 151892},
	{"RMVE", 4, 151893},
	{"RIFB", 4, 151894},
	{"LVIG", 4, 151895},
	{"JIWH", 4, 151896},
	{"HYVI", 4, 151897},
	{"FONJ", 4, 151898},
	{"FFEO", 4, 151899},
	{"EGGF", 4, 151900},
	{"DEIW", 4, 151901},
	{"ANZL", 4, 151902},
	{"UNITEDHEALTH", 12, 151903},
	{"SUBSUMPTION", 11, 151904},
	{"FIBRILS", 7, 151905},
	{"LAPLANTE", 8, 151906},
	{"CRUELLA", 7, 151907},
	{"FREEH", 5, 151908},
	{"VELODROME", 9, 151909},
	{"VOCIFEROUS", 10, 151910},
	{"OUTBUILDING", 11, 151911},
	{"KFREEBSD", 8, 151912},
	{"OTTERBOX", 8, 151913},
	{"APLUS", 5, 151914},
	{"FERNLEY", 7, 151915},
	{"AALIB", 5, 151916},
	{"VERENIGING", 10, 151917},
	{"CHRISTMASTIME", 13, 151918},
	{"TRAPDOOR", 8, 151919},
	{"KNODE", 5, 151920},
	{"CBEEBIES", 8, 151921},
	{"RIEGEL", 6, 151922},
	{"SEVICES", 7, 151923},
	{"BACKLIST", 8, 151924},
	{"HEADFIRST", 9, 151925},
	{"WEGMAN", 6, 151926},
	{"COMED", 5, 151927},
	{"CLIFFSNOTES", 11, 151928},
	{"WAGERED", 7, 151929},
	{"SKEEN", 5, 151930},
	{"BACKGAMON", 9, 151931},
	{"USTINOV", 7, 151932},
	{"OBSERVABILITY", 13, 151933},
	{"BEAUSOLEIL", 10, 151934},
	{"VYAS", 4, 151935},
	{"SALZ", 4, 151936},
	{"KVMS", 4, 151937},
	{"KRANZ", 5, 151938},
	{"BETTMANN", 8, 151939},
	{"AZZA", 4, 151940},
	{"CHILDE", 6, 151941},
	{"COBLESKILL", 10, 151942},
	{"COLLEG", 6, 151943},
	{"MEDESKI", 7, 151944},
	{"WALLIES", 7, 151945},
	{"WETM", 4, 151946},
	{"VYFA", 4, 151947},
	{"UELK", 4, 151948},
	{"TLIU", 4, 151949},
	{"SIBR", 4, 151950},
	{"RLHO", 4, 151951},
	{"RFWH", 4, 151952},
	{"PIGT", 4, 151953},
	{"OXUN", 4, 151954},
	{"NOXW", 4, 151955},
	{"NNCL", 4, 151956},
	{"NIDB", 4, 151957},
	{"MYSB", 4, 151958},
	{"MSYD", 4, 151959},
	{"LKOS", 4, 151960},
	{"LFGU", 4, 151961},
	{"LEOX", 4, 151962},
	{"KYVI", 4, 151963},
	{"BYPS", 4, 151964},
	{"PXM", 3, 151965},
	{"KAYLANI", 7, 151966},
	{"GURDJIEFF", 9, 151967},
	{"LANGUISHED", 10, 151968},
	{"SNEERING", 8, 151969},
	{"RADIOPHARMACEUTICALS", 20, 151970},
	{"MGRS", 4, 151971},
	{"VISBY", 5, 151972},
	{"THEIST", 6, 151973},
	{"LLUVIA", 6, 151974},
	{"MASTERCLASSES", 13, 151975},
	{"MACAM", 5, 151976},
	{"LYTTLE", 6, 151977},
	{"TELFAIR", 7, 151978},
	{"GORI", 4, 151979},
	{"TOTALCHOICE", 11, 151980},
	{"SPIRITUALIST", 12, 151981},
	{"SARMA", 5, 151982},
	{"TEESDALE", 8, 151983},
	{"BILITIES", 8, 151984},
	{"WORKREST", 8, 151985},
	{"SKIPE", 5, 151986},
	{"COITUS", 6, 151987},
	{"CHURCHMAN", 9, 151988},
	{"WHAKATANE", 9, 151989},
	{"POSANDO", 7, 151990},
	{"SUBQUERY", 8, 151991},
	{"ONOFRIO", 7, 151992},
	{"SCRAPPERS", 9, 151993},
	{"VMEBUS", 6, 151994},
	{"ORIGINATIONS", 12, 151995},
	{"CONTENIDOS", 10, 151996},
	{"CHAMILLIONAIRE", 14, 151997},
	{"AMSTRON", 7, 151998},
	{"LISETTE", 7, 151999},
	{"NETMAGAZINES", 12, 152000},
	{"KELLE", 5, 152001},
	{"COCOONS", 7, 152002},
	{"LIBGTK", 6, 152003},
	{"HUGGABLE", 8, 152004},
	{"DESERTERS", 9, 152005},
	{"SHAMING", 7, 152006},
	{"PEICES", 6, 152007},
	{"MAGID", 5, 152008},
	{"SEPARABILITY", 12, 152009},
	{"NEURITIS", 8, 152010},
	{"ENTROPIA", 8, 152011},
	{"LIBVORBIS", 9, 152012},
	{"YLYR", 4, 152013},
	{"UOLA", 4, 152014},
	{"TKUS", 4, 152015},
	{"SMSD", 4, 152016},
	{"RPEY", 4, 152017},
	{"RODL", 4, 152018},
	{"PPSP", 4, 152019},
	{"OVBO", 4, 152020},
	{"KEKU", 4, 152021},
	{"ISJR", 4, 152022},
	{"GRYR", 4, 152023},
	{"DFFO", 4, 152024},
	{"CAOP", 4, 152025},
	{"ACSB", 4, 152026},
	{"SHEMA", 5, 152027},
	{"PROBL", 5, 152028},
	{"OFFIC", 5, 152029},
	{"MURINAE", 7, 152030},
	{"DRUMSET", 7, 152031},
	{"AINDA", 5, 152032},
	{"DELTRON", 7, 152033},
	{"SMBFS", 5, 152034},
	{"PHARMACEUTICS", 13, 152035},
	{"VERRE", 5, 152036},
	{"WESTEND", 7, 152037},
	{"JORMA", 5, 152038},
	{"SEROGROUP", 9, 152039},
	{"OPUNTIA", 7, 152040},
	{"DOUPLOAD", 8, 152041},
	{"DMUSIC", 6, 152042},
	{"MITCHELLS", 9, 152043},
	{"EMMIS", 5, 152044},
	{"FRONTRANGE", 10, 152045},
	{"NONSTOCK", 8, 152046},
	{"KAQWS", 5, 152047},
	{"WOODHAM", 7, 152048},
	{"DENTITION", 9, 152049},
	{"ECEVIT", 6, 152050},
	{"IOANNINA", 8, 152051},
	{"UNDERSTAFFED", 12, 152052},
	{"SWAMY", 5, 152053},
	{"SMALLNESS", 9, 152054},
	{"NHGRI", 5, 152055},
	{"FLUOROCARBON", 12, 152056},
	{"SINTON", 6, 152057},
	{"EMPFEHLUNGEN", 12, 152058},
	{"ELIMINATORS", 11, 152059},
	{"PLUMER", 6, 152060},
	{"EXTERNA", 7, 152061},
	{"PARADISUS", 9, 152062},
	{"HENRICH", 7, 152063},
	{"ACQUISTO", 8, 152064},
	{"SPRUE", 5, 152065},
	{"CUTBACK", 7, 152066},
	{"PERINEAL", 8, 152067},
	{"BENUTZERNAME", 12, 152068},
	{"COFFEEMAKERS", 12, 152069},
	{"XMAK", 4, 152070},
	{"UDAG", 4, 152071},
	{"TMAZ", 4, 152072},
	{"RYLB", 4, 152073},
	{"PUTJ", 4, 152074},
	{"PGUA", 4, 152075},
	{"NGNG", 4, 152076},
	{"NGNC", 4, 152077},
	{"LVUL", 4, 152078},
	{"KSSM", 4, 152079},
	{"IMOM", 4, 152080},
	{"IGEF", 4, 152081},
	{"HULH", 4, 152082},
	{"GYBL", 4, 152083},
	{"GOSR", 4, 152084},
	{"GFAU", 4, 152085},
	{"FLPR", 4, 152086},
	{"EPEY", 4, 152087},
	{"EKTW", 4, 152088},
	{"DJOD", 4, 152089},
	{"REMOTEST", 8, 152090},
	{"RETORTS", 7, 152091},
	{"TRNC", 4, 152092},
	{"RAVERS", 6, 152093},
	{"GAVAGE", 6, 152094},
	{"HOUSEKEEPERS", 12, 152095},
	{"CATNO", 5, 152096},
	{"SHENMUE", 7, 152097},
	{"SOCIALISE", 9, 152098},
	{"FAREWELLS", 9, 152099},
	{"UNFORESEEABLE", 13, 152100},
	{"CONSCRIPT", 9, 152101},
	{"TINGA", 5, 152102},
	{"PARSHA", 6, 152103},
	{"BATALI", 6, 152104},
	{"COUNTEROFFER", 12, 152105},
	{"BABYZ", 5, 152106},
	{"REDDER", 6, 152107},
	{"WINDOWSILL", 10, 152108},
	{"AEROPOSTALE", 11, 152109},
	{"DEGC", 4, 152110},
	{"SPEECHGUARD", 11, 152111},
	{"SENSITIZING", 11, 152112},
	{"CLOE", 4, 152113},
	{"NMAKE", 5, 152114},
	{"LAMOUR", 6, 152115},
	{"MYSPELL", 7, 152116},
	{"MOORLANDS", 9, 152117},
	{"ALEK", 4, 152118},
	{"GEETA", 5, 152119},
	{"BRANDES", 7, 152120},
	{"UNCOMPLETED", 11, 152121},
	{"MAPPERS", 7, 152122},
	{"COSATU", 6, 152123},
	{"CRIA", 4, 152124},
	{"WORKTOP", 7, 152125},
	{"TOPCO", 5, 152126},
	{"TROPE", 5, 152127},
	{"OUTUBRO", 7, 152128},
	{"HILF", 4, 152129},
	{"MAGEN", 5, 152130},
	{"JANGO", 5, 152131},
	{"TROUPES", 7, 152132},
	{"GOLDER", 6, 152133},
	{"TIPTOE", 6, 152134},
	{"YSYL", 4, 152135},
	{"XDEL", 4, 152136},
	{"TPML", 4, 152137},
	{"RCWH", 4, 152138},
	{"PBAI", 4, 152139},
	{"LYJI", 4, 152140},
	{"LOYC", 4, 152141},
	{"LEUL", 4, 152142},
	{"IBIK", 4, 152143},
	{"HMYN", 4, 152144},
	{"AKYC", 4, 152145},
	{"TROWD", 5, 152146},
	{"WEKA", 4, 152147},
	{"BEATBOX", 7, 152148},
	{"YPOS", 4, 152149},
	{"GAMAL", 5, 152150},
	{"POEMA", 5, 152151},
	{"GOSNELL", 7, 152152},
	{"USERGUIDE", 9, 152153},
	{"SOCIABILITY", 11, 152154},
	{"IDEALISTS", 9, 152155},
	{"UWF", 3, 152156},
	{"DISSENTED", 9, 152157},
	{"XLV", 3, 152158},
	{"VOLCANOLOGY", 11, 152159},
	{"KONTACT", 7, 152160},
	{"COWGILL", 7, 152161},
	{"MAVALA", 6, 152162},
	{"RVP", 3, 152163},
	{"BUNGLED", 7, 152164},
	{"CCGS", 4, 152165},
	{"CROWING", 7, 152166},
	{"KAYNE", 5, 152167},
	{"MOVIECLIP", 9, 152168},
	{"FETTUCCINE", 10, 152169},
	{"LEWANDOWSKI", 11, 152170},
	{"HIJINKS", 7, 152171},
	{"HARBORVIEW", 10, 152172},
	{"JAXP", 4, 152173},
	{"FIXATIVE", 8, 152174},
	{"TRAXDATA", 8, 152175},
	{"INTIAL", 6, 152176},
	{"AIMMS", 5, 152177},
	{"MIGO", 4, 152178},
	{"SKYFI", 5, 152179},
	{"CELLES", 6, 152180},
	{"SAFENET", 7, 152181},
	{"THANKLESS", 9, 152182},
	{"CRUXSHADOWS", 11, 152183},
	{"HALLIGAN", 8, 152184},
	{"EXFOLIATE", 9, 152185},
	{"CANOVA", 6, 152186},
	{"TIONSHIP", 8, 152187},
	{"ROSEWATER", 9, 152188},
	{"PARAQUAT", 8, 152189},
	{"LAZARD", 6, 152190},
	{"JANTZEN", 7, 152191},
	{"AVERS", 5, 152192},
	{"ANTHY", 5, 152193},
	{"TEXTPHONE", 9, 152194},
	{"ULTIMATES", 9, 152195},
	{"TRIMEDICA", 9, 152196},
	{"HOCHZEIT", 8, 152197},
	{"SUBMENUS", 8, 152198},
	{"WISHAW", 6, 152199},
	{"GUYMON", 6, 152200},
	{"ZZST", 4, 152201},
	{"XIEC", 4, 152202},
	{"WWWU", 4, 152203},
	{"UTZO", 4, 152204},
	{"URTK", 4, 152205},
	{"UROY", 4, 152206},
	{"UBOS", 4, 152207},
	{"PIDH", 4, 152208},
	{"NUTD", 4, 152209},
	{"LLMD", 4, 152210},
	{"LIXW", 4, 152211},
	{"KYCR", 4, 152212},
	{"KOSF", 4, 152213},
	{"IXAD", 4, 152214},
	{"IMAZ", 4, 152215},
	{"HMSB", 4, 152216},
	{"GPEE", 4, 152217},
	{"FUPF", 4, 152218},
	{"ANCP", 4, 152219},
	{"RHINOTEK", 8, 152220},
	{"BINMODE", 7, 152221},
	{"GROKS", 5, 152222},
	{"NORBERG", 7, 152223},
	{"PUDGE", 5, 152224},
	{"BAKSH", 5, 152225},
	{"PRINCIPI", 8, 152226},
	{"MCPA", 4, 152227},
	{"AMBLYOPIA", 9, 152228},
	{"NESTON", 6, 152229},
	{"SHIPOWNERS", 10, 152230},
	{"BEELER", 6, 152231},
	{"STRINGENCY", 10, 152232},
	{"CONTROLED", 9, 152233},
	{"DOWNHAM", 7, 152234},
	{"NEUIGKEITEN", 11, 152235},
	{"LIVABILITY", 10, 152236},
	{"SCHULD", 6, 152237},
	{"QUALE", 5, 152238},
	{"ROMANTICA", 9, 152239},
	{"FRATER", 6, 152240},
	{"CDQ", 3, 152241},
	{"LUONGO", 6, 152242},
	{"BLACKWELLS", 10, 152243},
	{"SUBLIMITY", 9, 152244},
	{"JACKIN", 6, 152245},
	{"RIMOUSKI", 8, 152246},
	{"MISBEHAVE", 9, 152247},
	{"BIRCHES", 7, 152248},
	{"HANSOL", 6, 152249},
	{"DOSTOYEVSKY", 11, 152250},
	{"DYANNA", 6, 152251},
	{"IGSREPORT", 9, 152252},
	{"CHINOS", 6, 152253},
	{"CRUNCHED", 8, 152254},
	{"RATIFICATIONS", 13, 152255},
	{"OFFICEHOLDERS", 13, 152256},
	{"ZOBE", 4, 152257},
	{"UOCH", 4, 152258},
	{"TPMH", 4, 152259},
	{"SEGP", 4, 152260},
	{"RUON", 4, 152261},
	{"RNAJ", 4, 152262},
	{"RBIP", 4, 152263},
	{"PIGF", 4, 152264},
	{"NBAX", 4, 152265},
	{"MIOW", 4, 152266},
	{"MIDU", 4, 152267},
	{"ILUC", 4, 152268},
	{"HUKE", 4, 152269},
	{"GALK", 4, 152270},
	{"DNIL", 4, 152271},
	{"BUWA", 4, 152272},
	{"BUED", 4, 152273},
	{"ASYX", 4, 152274},
	{"ARFW", 4, 152275},
	{"AJOC", 4, 152276},
	{"DESCHAMPS", 9, 152277},
	{"NECESITA", 8, 152278},
	{"SASKACHEWAN", 11, 152279},
	{"DEVILBISS", 9, 152280},
	{"NETCONCEPTS", 11, 152281},
	{"GATCHAMAN", 9, 152282},
	{"MASSOUD", 7, 152283},
	{"METRORAIL", 9, 152284},
	{"MCCRORY", 7, 152285},
	{"XMLTV", 5, 152286},
	{"PAMA", 4, 152287},
	{"NAVEGADOR", 9, 152288},
	{"CODEWORDS", 9, 152289},
	{"QUIDU", 5, 152290},
	{"RINGLEADER", 10, 152291},
	{"THUNDERED", 9, 152292},
	{"OFFLOADING", 10, 152293},
	{"ENTERTAINMEN", 12, 152294},
	{"PUNTARENAS", 10, 152295},
	{"MARPLES", 7, 152296},
	{"GMTFROM", 7, 152297},
	{"FUMED", 5, 152298},
	{"SUBTRACTS", 9, 152299},
	{"GENERALES", 9, 152300},
	{"NULLSOFT", 8, 152301},
	{"CONSERVATOIRE", 13, 152302},
	{"RETURNER", 8, 152303},
	{"FPV", 3, 152304},
	{"BURNELL", 7, 152305},
	{"PATENCY", 7, 152306},
	{"FILP", 4, 152307},
	{"RIKON", 5, 152308},
	{"BODDY", 5, 152309},
	{"TURKI", 5, 152310},
	{"IRWINDALE", 9, 152311},
	{"GROUNDNUT", 9, 152312},
	{"CYBERCAST", 9, 152313},
	{"FESTE", 5, 152314},
	{"THEREUNTO", 9, 152315},
	{"ZVEZDA", 6, 152316},
	{"DEMARINI", 8, 152317},
	{"ABLESTOCK", 9, 152318},
	{"BRONCHODILATOR", 14, 152319},
	{"GROM", 4, 152320},
	{"SCLEROTHERAPY", 13, 152321},
	{"HUTCHERSON", 10, 152322},
	{"KITIMAT", 7, 152323},
	{"GROSJEAN", 8, 152324},
	{"KNIGHTDALE", 10, 152325},
	{"INBOXES", 7, 152326},
	{"KILIMS", 6, 152327},
	{"ROSARITO", 8, 152328},
	{"PERFRINGENS", 11, 152329},
	{"ACTIPET", 7, 152330},
	{"BILDES", 6, 152331},
	{"COMPATRIOT", 10, 152332},
	{"RAEKWON", 7, 152333},
	{"DISCONTENTED", 12, 152334},
	{"YNNR", 4, 152335},
	{"WLIE", 4, 152336},
	{"UTKR", 4, 152337},
	{"UPSQ", 4, 152338},
	{"NFIJ", 4, 152339},
	{"MFOS", 4, 152340},
	{"JALO", 4, 152341},
	{"ISMJ", 4, 152342},
	{"FTSG", 4, 152343},
	{"FIKN", 4, 152344},
	{"EUTZ", 4, 152345},
	{"EIDU", 4, 152346},
	{"DSSK", 4, 152347},
	{"BCSM", 4, 152348},
	{"BWW", 3, 152349},
	{"JADO", 4, 152350},
	{"FRAGRANCEX", 10, 152351},
	{"AUTOMOUNT", 9, 152352},
	{"REFLEXIVITY", 11, 152353},
	{"INSTITUE", 8, 152354},
	{"NYSERDA", 7, 152355},
	{"CSEQ", 4, 152356},
	{"CDTV", 4, 152357},
	{"FERIEN", 6, 152358},
	{"DRONING", 7, 152359},
	{"FLYWAY", 6, 152360},
	{"EILEAN", 6, 152361},
	{"CSKA", 4, 152362},
	{"REDUCTIONISM", 12, 152363},
	{"DECARLO", 7, 152364},
	{"TOOLEY", 6, 152365},
	{"MILLCREEK", 9, 152366},
	{"HABERMAN", 8, 152367},
	{"AUCOIN", 6, 152368},
	{"POWERLINES", 10, 152369},
	{"YAWNED", 6, 152370},
	{"FORUMZ", 6, 152371},
	{"GADU", 4, 152372},
	{"WBEL", 4, 152373},
	{"SCUTTLED", 8, 152374},
	{"CDUNIVERSE", 10, 152375},
	{"NONSURGICAL", 11, 152376},
	{"REMANUFACTURING", 15, 152377},
	{"VIJAYA", 6, 152378},
	{"DISCOLOR", 8, 152379},
	{"BLACKSTOCK", 10, 152380},
	{"MARLER", 6, 152381},
	{"HOLISTICALLY", 12, 152382},
	{"HAMBLEN", 7, 152383},
	{"HARRODSBURG", 11, 152384},
	{"WOODMERE", 8, 152385},
	{"DICTONARY", 9, 152386},
	{"RGM", 3, 152387},
	{"YIFM", 4, 152388},
	{"UKRI", 4, 152389},
	{"UGIO", 4, 152390},
	{"TZAP", 4, 152391},
	{"TOWP", 4, 152392},
	{"THGM", 4, 152393},
	{"SZEK", 4, 152394},
	{"SMSL", 4, 152395},
	{"RBSM", 4, 152396},
	{"QUEJ", 4, 152397},
	{"OTYL", 4, 152398},
	{"LCES", 4, 152399},
	{"HUTW", 4, 152400},
	{"GZOO", 4, 152401},
	{"DOXM", 4, 152402},
	{"DMRW", 4, 152403},
	{"BUGF", 4, 152404},
	{"BIDL", 4, 152405},
	{"AQAR", 4, 152406},
	{"COMPR", 5, 152407},
	{"WOCHEN", 6, 152408},
	{"GALLAHER", 8, 152409},
	{"CHANDRIKA", 9, 152410},
	{"RUTTEN", 6, 152411},
	{"GOVERNMENTVAR", 13, 152412},
	{"DEHUMIDIFICATION", 16, 152413},
	{"INOFFENSIVE", 11, 152414},
	{"CLINTONVILLE", 12, 152415},
	{"ERUDITION", 9, 152416},
	{"REWIRE", 6, 152417},
	{"FELDMANN", 8, 152418},
	{"SHOCKWAVES", 10, 152419},
	{"FFTW", 4, 152420},
	{"WRIGHTSTOWN", 11, 152421},
	{"PORCO", 5, 152422},
	{"DOWNBLOUSE", 10, 152423},
	{"GAHAN", 5, 152424},
	{"MASONITE", 8, 152425},
	{"VIDEOLOGIC", 10, 152426},
	{"POLTAVA", 7, 152427},
	{"BHAGAT", 6, 152428},
	{"VALAR", 5, 152429},
	{"POSTIVE", 7, 152430},
	{"BEDSTEADS", 9, 152431},
	{"PISTA", 5, 152432},
	{"CORINTO", 7, 152433},
	{"RICHLANDS", 9, 152434},
	{"PACKETEER", 9, 152435},
	{"OFAC", 4, 152436},
	{"FACTIONAL", 9, 152437},
	{"IMPRIMATUR", 10, 152438},
	{"RAPD", 4, 152439},
	{"HAMPTONINNS", 11, 152440},
	{"ACHERON", 7, 152441},
	{"NANOG", 5, 152442},
	{"MINISTERO", 9, 152443},
	{"CREATIVEMATCH", 13, 152444},
	{"REVALIDATION", 12, 152445},
	{"GORT", 4, 152446},
	{"TRUS", 4, 152447},
	{"TARPAULINS", 10, 152448},
	{"JUNKERS", 7, 152449},
	{"KLOOF", 5, 152450},
	{"REBRANDED", 9, 152451},
	{"WALTERBORO", 10, 152452},
	{"CYBERLAW", 8, 152453},
	{"HDSP", 4, 152454},
	{"MAKAN", 5, 152455},
	{"PERITONEUM", 10, 152456},
	{"TITTENKETTEN", 12, 152457},
	{"XPIT", 4, 152458},
	{"VIAK", 4, 152459},
	{"UMYE", 4, 152460},
	{"TZCH", 4, 152461},
	{"TTBL", 4, 152462},
	{"SMRR", 4, 152463},
	{"SDAF", 4, 152464},
	{"RFFO", 4, 152465},
	{"PPOF", 4, 152466},
	{"OXRI", 4, 152467},
	{"MRVA", 4, 152468},
	{"MMYV", 4, 152469},
	{"LLUX", 4, 152470},
	{"KCEM", 4, 152471},
	{"HEJP", 4, 152472},
	{"GWRA", 4, 152473},
	{"FADY", 4, 152474},
	{"ECEG", 4, 152475},
	{"CKKO", 4, 152476},
	{"BEYC", 4, 152477},
	{"ABOC", 4, 152478},
	{"GENOTOXIC", 9, 152479},
	{"IMPRESA", 7, 152480},
	{"EMBASSYSUITES", 13, 152481},
	{"EVILDOERS", 9, 152482},
	{"KIRGHIZ", 7, 152483},
	{"CONWELL", 7, 152484},
	{"KVR", 3, 152485},
	{"ACIP", 4, 152486},
	{"DIVOIRE", 7, 152487},
	{"CYCLOHEXIMIDE", 13, 152488},
	{"TURPITUDE", 9, 152489},
	{"FALTOYANO", 9, 152490},
	{"INIGO", 5, 152491},
	{"ESIGN", 5, 152492},
	{"AMERSFOORT", 10, 152493},
	{"TCHR", 4, 152494},
	{"ANTHER", 6, 152495},
	{"PAPERCUT", 8, 152496},
	{"MEAGHAN", 7, 152497},
	{"ARDELL", 6, 152498},
	{"KLETS", 5, 152499},
	{"LIBLTDL", 7, 152500},
	{"PERROT", 6, 152501},
	{"STRICTNESS", 10, 152502},
	{"LINNEAN", 7, 152503},
	{"GARDNERS", 8, 152504},
	{"ALLINTERNAL", 11, 152505},
	{"AMILORIDE", 9, 152506},
	{"GANDOLFINI", 10, 152507},
	{"YORKIES", 7, 152508},
	{"MULTIPACK", 9, 152509},
	{"DOKI", 4, 152510},
	{"FRIBIDI", 7, 152511},
	{"STOMPS", 6, 152512},
	{"BBJ", 3, 152513},
	{"ETIOLOGIC", 9, 152514},
	{"WELKE", 5, 152515},
	{"EGALITARIANISM", 14, 152516},
	{"ROVANIEMI", 9, 152517},
	{"RETROPERITONEAL", 15, 152518},
	{"DBACCESS", 8, 152519},
	{"HUMANITARIANISM", 15, 152520},
	{"SPECTROPHOTOMETRIC", 18, 152521},
	{"DUCHENNE", 8, 152522},
	{"ASPERGILLOSIS", 13, 152523},
	{"VIKI", 4, 152524},
	{"SUBGRAPHS", 9, 152525},
	{"XYFO", 4, 152526},
	{"XTPI", 4, 152527},
	{"UXUS", 4, 152528},
	{"UOMS", 4, 152529},
	{"UMAV", 4, 152530},
	{"UKIK", 4, 152531},
	{"TVOY", 4, 152532},
	{"STWY", 4, 152533},
	{"SALQ", 4, 152534},
	{"RYLH", 4, 152535},
	{"ISDW", 4, 152536},
	{"CAYN", 4, 152537},
	{"VBZ", 3, 152538},
	{"JBP", 3, 152539},
	{"HOMEANNEX", 9, 152540},
	{"PHPDOC", 6, 152541},
	{"DELO", 4, 152542},
	{"LEELEE", 6, 152543},
	{"CHARCOT", 7, 152544},
	{"RWQCB", 5, 152545},
	{"ENTRETIEN", 9, 152546},
	{"CASKEY", 6, 152547},
	{"RAMMER", 6, 152548},
	{"BIVALVES", 8, 152549},
	{"NIEBUHR", 7, 152550},
	{"MMSE", 4, 152551},
	{"MEDIENKRITIK", 12, 152552},
	{"ACRA", 4, 152553},
	{"ENTROPIC", 8, 152554},
	{"NIEVE", 5, 152555},
	{"TRAUB", 5, 152556},
	{"FRIVOLITY", 9, 152557},
	{"GULPED", 6, 152558},
	{"THERMISTORS", 11, 152559},
	{"ASETEK", 6, 152560},
	{"ZACARIAS", 8, 152561},
	{"CAPODIMONTE", 11, 152562},
	{"PGV", 3, 152563},
	{"POWERONE", 8, 152564},
	{"SUBTLER", 7, 152565},
	{"DEVILED", 7, 152566},
	{"PERFIL", 6, 152567},
	{"ALLAFRICA", 9, 152568},
	{"MATSUYAMA", 9, 152569},
	{"WELLYLUG", 8, 152570},
	{"BELLEAIR", 8, 152571},
	{"INITTAB", 7, 152572},
	{"WELLPOINT", 9, 152573},
	{"CUPIDS", 6, 152574},
	{"AGIRLSWORLD", 11, 152575},
	{"HIPPI", 5, 152576},
	{"VESTIDOS", 8, 152577},
	{"KEESHOND", 8, 152578},
	{"CANC", 4, 152579},
	{"YCEU", 4, 152580},
	{"YAMN", 4, 152581},
	{"YALK", 4, 152582},
	{"XEAR", 4, 152583},
	{"WDUS", 4, 152584},
	{"UEZB", 4, 152585},
	{"RMRU", 4, 152586},
	{"RDUG", 4, 152587},
	{"PUPB", 4, 152588},
	{"NKYF", 4, 152589},
	{"MGIN", 4, 152590},
	{"LMEV", 4, 152591},
	{"IMBW", 4, 152592},
	{"HGOW", 4, 152593},
	{"GNFA", 4, 152594},
	{"EKLU", 4, 152595},
	{"ECHJ", 4, 152596},
	{"DPIX", 4, 152597},
	{"DMRK", 4, 152598},
	{"DIJA", 4, 152599},
	{"CTEF", 4, 152600},
	{"AZUN", 4, 152601},
	{"ATMB", 4, 152602},
	{"ATBC", 4, 152603},
	{"TRUNCATING", 10, 152604},
	{"HPANA", 5, 152605},
	{"MATHES", 6, 152606},
	{"DUNGAREES", 9, 152607},
	{"RVC", 3, 152608},
	{"SEGNO", 5, 152609},
	{"LEPIED", 6, 152610},
	{"YASIN", 5, 152611},
	{"WARMBLOOD", 9, 152612},
	{"BABIN", 5, 152613},
	{"SKINZ", 5, 152614},
	{"INVIOLABLE", 10, 152615},
	{"MURASAKI", 8, 152616},
	{"HERNIATION", 10, 152617},
	{"IMMUNOBLOT", 10, 152618},
	{"DOFASCO", 7, 152619},
	{"ARTECH", 6, 152620},
	{"WASHY", 5, 152621},
	{"BERES", 5, 152622},
	{"THUMPS", 6, 152623},
	{"BUNDOORA", 8, 152624},
	{"YASUKUNI", 8, 152625},
	{"THINKTANK", 9, 152626},
	{"PARLUX", 6, 152627},
	{"OUTSMART", 8, 152628},
	{"AMGUEDDFA", 9, 152629},
	{"STARLA", 6, 152630},
	{"NAUSEATING", 10, 152631},
	{"FOUTS", 5, 152632},
	{"NECTED", 6, 152633},
	{"MITIGATES", 9, 152634},
	{"NYBOT", 5, 152635},
	{"CYBERMEDIA", 10, 152636},
	{"EPHEMERIDES", 11, 152637},
	{"MOHANTY", 7, 152638},
	{"TICKCO", 6, 152639},
	{"THYMINE", 7, 152640},
	{"THANOS", 6, 152641},
	{"LIBERALISED", 11, 152642},
	{"DHAR", 4, 152643},
	{"WATSONS", 7, 152644},
	{"UNRAVELED", 9, 152645},
	{"AUGERS", 6, 152646},
	{"SENORITA", 8, 152647},
	{"RIFLEMEN", 8, 152648},
	{"INSUFFERABLE", 12, 152649},
	{"KAKO", 4, 152650},
	{"TALKTIME", 8, 152651},
	{"CLASPING", 8, 152652},
	{"BLINDERS", 8, 152653},
	{"LANDEN", 6, 152654},
	{"SEAMOUNT", 8, 152655},
	{"PREDATE", 7, 152656},
	{"KELMAN", 6, 152657},
	{"MIRON", 5, 152658},
	{"YGEL", 4, 152659},
	{"WENM", 4, 152660},
	{"UKWE", 4, 152661},
	{"UENW", 4, 152662},
	{"SUSJ", 4, 152663},
	{"RPMW", 4, 152664},
	{"OVJA", 4, 152665},
	{"OLMD", 4, 152666},
	{"OKDU", 4, 152667},
	{"OFSG", 4, 152668},
	{"OFNG", 4, 152669},
	{"NGVU", 4, 152670},
	{"MOCE", 4, 152671},
	{"LMCI", 4, 152672},
	{"HDUS", 4, 152673},
	{"ESGM", 4, 152674},
	{"EILF", 4, 152675},
	{"BBUR", 4, 152676},
	{"AIGP", 4, 152677},
	{"INTERJECTIONS", 13, 152678},
	{"MACMAHON", 8, 152679},
	{"THORNES", 7, 152680},
	{"POJO", 4, 152681},
	{"MULLETS", 7, 152682},
	{"LUSTING", 7, 152683},
	{"TOMOKO", 6, 152684},
	{"WIGSTON", 7, 152685},
	{"WASHOUGAL", 9, 152686},
	{"DARLINA", 7, 152687},
	{"TOGOLAND", 8, 152688},
	{"CYBERSOURCE", 11, 152689},
	{"WELLY", 5, 152690},
	{"USURPATION", 10, 152691},
	{"PETROGLYPH", 10, 152692},
	{"BRIMMED", 7, 152693},
	{"TOMOROW", 7, 152694},
	{"BEEM", 4, 152695},
	{"EASWARAN", 8, 152696},
	{"SUBJUGATED", 10, 152697},
	{"ELISABETTA", 10, 152698},
	{"FRISELL", 7, 152699},
	{"SONOR", 5, 152700},
	{"PACH", 4, 152701},
	{"DREAMBOX", 8, 152702},
	{"UNLEARNED", 9, 152703},
	{"SPOTSWOOD", 9, 152704},
	{"CHARTIER", 8, 152705},
	{"ERRO", 4, 152706},
	{"LYCHEE", 6, 152707},
	{"THRIFTS", 7, 152708},
	{"MSONORMAL", 9, 152709},
	{"ESULTS", 6, 152710},
	{"UNSTATED", 8, 152711},
	{"NUKESENTINEL", 12, 152712},
	{"CHADD", 5, 152713},
	{"CLOVELLY", 8, 152714},
	{"INTERNEURONS", 12, 152715},
	{"PROSTRATED", 10, 152716},
	{"GERMICIDAL", 10, 152717},
	{"GOOK", 4, 152718},
	{"SCAIFE", 6, 152719},
	{"TSUJI", 5, 152720},
	{"BEAUMARIS", 9, 152721},
	{"OCCLUSAL", 8, 152722},
	{"KAFFEE", 6, 152723},
	{"DESANTIS", 8, 152724},
	{"EXCUSING", 8, 152725},
	{"RATIONALISE", 11, 152726},
	{"EMTEC", 5, 152727},
	{"DATAPORTS", 9, 152728},
	{"VSMO", 4, 152729},
	{"LSSK", 4, 152730},
	{"KVEH", 4, 152731},
	{"INRW", 4, 152732},
	{"GGRU", 4, 152733},
	{"GGHO", 4, 152734},
	{"FROP", 4, 152735},
	{"DBCO", 4, 152736},
	{"COOC", 4, 152737},
	{"BEDJ", 4, 152738},
	{"STRUVE", 6, 152739},
	{"REPORTDEBT", 10, 152740},
	{"REJOINING", 9, 152741},
	{"KADER", 5, 152742},
	{"CHROMATOGR", 10, 152743},
	{"ANAPLASTIC", 10, 152744},
	{"RYUICHI", 7, 152745},
	{"MUHARRAM", 8, 152746},
	{"TRANSFORMANTS", 13, 152747},
	{"BELMONTE", 8, 152748},
	{"CANDLELIT", 9, 152749},
	{"TENSIONERS", 10, 152750},
	{"SUBIR", 5, 152751},
	{"METROWERKS", 10, 152752},
	{"EFREN", 5, 152753},
	{"MICROFLORA", 10, 152754},
	{"AFTENPOSTEN", 11, 152755},
	{"NEOCONSERVATIVES", 16, 152756},
	{"KUBIAK", 6, 152757},
	{"METAREVIEW", 10, 152758},
	{"HOLLYDAY", 8, 152759},
	{"HESKETH", 7, 152760},
	{"CAREMARK", 8, 152761},
	{"BOUYGUES", 8, 152762},
	{"AMIDES", 6, 152763},
	{"SPLA", 4, 152764},
	{"DIHYDROXY", 9, 152765},
	{"TARDIVE", 7, 152766},
	{"PAPERPORT", 9, 152767},
	{"ETIAM", 5, 152768},
	{"GROUPNAME", 9, 152769},
	{"CISTRON", 7, 152770},
	{"CAMPANELLA", 10, 152771},
	{"UPLANDER", 8, 152772},
	{"JORN", 4, 152773},
	{"FORSKOLIN", 9, 152774},
	{"GUNMA", 5, 152775},
	{"AUTOMORPHISMS", 13, 152776},
	{"PASSIVATION", 11, 152777},
	{"SLANTING", 8, 152778},
	{"HECATE", 6, 152779},
	{"BALANCHINE", 10, 152780},
	{"MULGRAVE", 8, 152781},
	{"LYRICA", 6, 152782},
	{"MONTARA", 7, 152783},
	{"NORBIZNESS", 10, 152784},
	{"KULL", 4, 152785},
	{"FEATHERING", 10, 152786},
	{"TITTENGUIDE", 11, 152787},
	{"ZHENGZHOU", 9, 152788},
	{"WINDTUNNEL", 10, 152789},
	{"CAMPERVANS", 10, 152790},
	{"YUDH", 4, 152791},
	{"TGEM", 4, 152792},
	{"SIFG", 4, 152793},
	{"REVB", 4, 152794},
	{"RBSP", 4, 152795},
	{"PTJO", 4, 152796},
	{"PHMO", 4, 152797},
	{"OBYJ", 4, 152798},
	{"MRUB", 4, 152799},
	{"MPJU", 4, 152800},
	{"MKRI", 4, 152801},
	{"MBSP", 4, 152802},
	{"LADP", 4, 152803},
	{"IXCE", 4, 152804},
	{"IVWH", 4, 152805},
	{"HOKL", 4, 152806},
	{"HAYB", 4, 152807},
	{"GZEB", 4, 152808},
	{"GHAJ", 4, 152809},
	{"ENPP", 4, 152810},
	{"EAPY", 4, 152811},
	{"DMYV", 4, 152812},
	{"BFOL", 4, 152813},
	{"AKOC", 4, 152814},
	{"PEDIDO", 6, 152815},
	{"PODIUMS", 7, 152816},
	{"DYNEX", 5, 152817},
	{"PHONONS", 7, 152818},
	{"NHUNG", 5, 152819},
	{"WINFS", 5, 152820},
	{"MAISIE", 6, 152821},
	{"WATERLOGGED", 11, 152822},
	{"SALTING", 7, 152823},
	{"BIBLIOTHECA", 11, 152824},
	{"PENFOLDS", 8, 152825},
	{"MOFAZ", 5, 152826},
	{"BIBLIOTECAS", 11, 152827},
	{"STAUNCHLY", 9, 152828},
	{"WUM", 3, 152829},
	{"SLASHERS", 8, 152830},
	{"DETESTED", 8, 152831},
	{"AURICULAR", 9, 152832},
	{"OVEREXPRESSING", 14, 152833},
	{"LAQUINTAINN", 11, 152834},
	{"WDP", 3, 152835},
	{"HIZB", 4, 152836},
	{"SCRAWNY", 7, 152837},
	{"MAZZY", 5, 152838},
	{"PEPPERY", 7, 152839},
	{"VIVISECTION", 11, 152840},
	{"PORIRUA", 7, 152841},
	{"OVERAL", 6, 152842},
	{"MESTO", 5, 152843},
	{"MATHURA", 7, 152844},
	{"SPLODGE", 7, 152845},
	{"PHOSPHOTRANSFERASE", 18, 152846},
	{"DAUNTLESS", 9, 152847},
	{"UNPLUGGING", 10, 152848},
	{"MORAG", 5, 152849},
	{"SYNTHPOP", 8, 152850},
	{"PULSATIONS", 10, 152851},
	{"IMMUNIZE", 8, 152852},
	{"EOSINOPHIL", 10, 152853},
	{"DOCTORING", 9, 152854},
	{"PERLITE", 7, 152855},
	{"ECPI", 4, 152856},
	{"BRUIJN", 6, 152857},
	{"SCUTTLEBUTT", 11, 152858},
	{"FRUGALITY", 9, 152859},
	{"NYMPHET", 7, 152860},
	{"COLORBLENDS", 11, 152861},
	{"CALTON", 6, 152862},
	{"SHOUTOUTS", 9, 152863},
	{"VERON", 5, 152864},
	{"YAHM", 4, 152865},
	{"VIEU", 4, 152866},
	{"TIDU", 4, 152867},
	{"RGBR", 4, 152868},
	{"PIKI", 4, 152869},
	{"OVCA", 4, 152870},
	{"OJUG", 4, 152871},
	{"HRDE", 4, 152872},
	{"GSTC", 4, 152873},
	{"EZFR", 4, 152874},
	{"ENZW", 4, 152875},
	{"EECY", 4, 152876},
	{"AYEP", 4, 152877},
	{"AJAU", 4, 152878},
	{"UNSURPRISING", 12, 152879},
	{"FREEDOS", 7, 152880},
	{"APPRENTICED", 11, 152881},
	{"STECKER", 7, 152882},
	{"HERNIAS", 7, 152883},
	{"REFLEXION", 9, 152884},
	{"PASQUINI", 8, 152885},
	{"CARNFORTH", 9, 152886},
	{"VOMITED", 7, 152887},
	{"TOSHIYUKI", 9, 152888},
	{"ROTORCRAFT", 10, 152889},
	{"KROL", 4, 152890},
	{"MISINTERPRET", 12, 152891},
	{"KURUPT", 6, 152892},
	{"UNDISCIPLINED", 13, 152893},
	{"JFM", 3, 152894},
	{"WELLNES", 7, 152895},
	{"BONEYARD", 8, 152896},
	{"ADVOCATEN", 9, 152897},
	{"ANIKA", 5, 152898},
	{"HANDCRAFTS", 10, 152899},
	{"KOLLEKTIV", 9, 152900},
	{"VOETSCH", 7, 152901},
	{"SIGNALIZED", 10, 152902},
	{"MURTAGH", 7, 152903},
	{"LANGAN", 6, 152904},
	{"LUNGED", 6, 152905},
	{"AUTON", 5, 152906},
	{"HOLOFOIL", 8, 152907},
	{"PROFIEL", 7, 152908},
	{"USAJOBS", 7, 152909},
	{"MULLALLY", 8, 152910},
	{"XENOTRANSPLANTATION", 19, 152911},
	{"CPDL", 4, 152912},
	{"BYFORD", 6, 152913},
	{"VERGIL", 6, 152914},
	{"STRICTURE", 9, 152915},
	{"DUMBELL", 7, 152916},
	{"IDEMPOTENT", 10, 152917},
	{"ZERK", 4, 152918},
	{"ZELB", 4, 152919},
	{"YIPA", 4, 152920},
	{"YEFI", 4, 152921},
	{"YAKH", 4, 152922},
	{"XYTO", 4, 152923},
	{"XECO", 4, 152924},
	{"UZEN", 4, 152925},
	{"UYTE", 4, 152926},
	{"URAZ", 4, 152927},
	{"ULPM", 4, 152928},
	{"UEDV", 4, 152929},
	{"UDFA", 4, 152930},
	{"SUDH", 4, 152931},
	{"SOMD", 4, 152932},
	{"SHKU", 4, 152933},
	{"RUBU", 4, 152934},
	{"ROOB", 4, 152935},
	{"RIGB", 4, 152936},
	{"RDYH", 4, 152937},
	{"PYRR", 4, 152938},
	{"NIXR", 4, 152939},
	{"NILY", 4, 152940},
	{"LRUD", 4, 152941},
	{"LPEV", 4, 152942},
	{"LMPO", 4, 152943},
	{"GDOS", 4, 152944},
	{"FZIO", 4, 152945},
	{"FNOU", 4, 152946},
	{"EZHU", 4, 152947},
	{"DDDI", 4, 152948},
	{"DAIB", 4, 152949},
	{"BWEW", 4, 152950},
	{"BBCD", 4, 152951},
	{"NOVICK", 6, 152952},
	{"BENNO", 5, 152953},
	{"RUSSKIJ", 7, 152954},
	{"BIOTRANSFORMATION", 17, 152955},
	{"GVW", 3, 152956},
	{"FURNAS", 6, 152957},
	{"DISINVESTMENT", 13, 152958},
	{"DEFRAGMENTER", 12, 152959},
	{"DISAPPOINTINGLY", 15, 152960},
	{"ALLEYWAYS", 9, 152961},
	{"FMG", 3, 152962},
	{"AVNER", 5, 152963},
	{"KICKOFFS", 8, 152964},
	{"WIENS", 5, 152965},
	{"DUNKING", 7, 152966},
	{"DENOTATION", 10, 152967},
	{"PRECERTIFICATION", 16, 152968},
	{"RVD", 3, 152969},
	{"PITCURES", 8, 152970},
	{"ZESTRIL", 7, 152971},
	{"VERTS", 5, 152972},
	{"DAIQUIRI", 8, 152973},
	{"EMBARASSMENT", 12, 152974},
	{"OPERE", 5, 152975},
	{"IMAGEMAP", 8, 152976},
	{"POUTING", 7, 152977},
	{"LUCIER", 6, 152978},
	{"LDW", 3, 152979},
	{"WATLING", 7, 152980},
	{"HADDINGTON", 10, 152981},
	{"DIMENSIONALLY", 13, 152982},
	{"SYNDICATOR", 10, 152983},
	{"DAHER", 5, 152984},
	{"JUMANJI", 7, 152985},
	{"EISLER", 6, 152986},
	{"SAMAEL", 6, 152987},
	{"ARBITRATED", 10, 152988},
	{"DALZELL", 7, 152989},
	{"CHRISTIANBITS", 13, 152990},
	{"VRIJ", 4, 152991},
	{"GIELGUD", 7, 152992},
	{"CREER", 5, 152993},
	{"HAMMON", 6, 152994},
	{"MARTINUS", 8, 152995},
	{"STRAINTS", 8, 152996},
	{"SQUALENE", 8, 152997},
	{"CRANNY", 6, 152998},
	{"SPRINGY", 7, 152999},
	{"KNOWLE", 6, 153000},
	{"NINFETA", 7, 153001},
	{"PERPLEX", 7, 153002},
	{"MAUBOUSSIN", 10, 153003},
	{"ESBJERG", 7, 153004},
	{"AAMCO", 5, 153005},
	{"NTCIP", 5, 153006},
	{"LAMENTABLE", 10, 153007},
	{"JLC", 3, 153008},
	{"ARCHITECTEN", 11, 153009},
	{"YSIZE", 5, 153010},
	{"VEEY", 4, 153011},
	{"UYDE", 4, 153012},
	{"UDFI", 4, 153013},
	{"MUCU", 4, 153014},
	{"MMUA", 4, 153015},
	{"LMRS", 4, 153016},
	{"LLCW", 4, 153017},
	{"LLAQ", 4, 153018},
	{"LIZO", 4, 153019},
	{"KSYM", 4, 153020},
	{"KKOT", 4, 153021},
	{"GELN", 4, 153022},
	{"ETVB", 4, 153023},
	{"DUCD", 4, 153024},
	{"AWPI", 4, 153025},
	{"PAULL", 5, 153026},
	{"MCDST", 5, 153027},
	{"ROSSLAND", 8, 153028},
	{"READOUTS", 8, 153029},
	{"AKADEMI", 7, 153030},
	{"SIGNES", 6, 153031},
	{"LAHAT", 5, 153032},
	{"INFLUENCER", 10, 153033},
	{"UNCOUNTABLE", 11, 153034},
	{"TECHNIKA", 8, 153035},
	{"LIFEFORM", 8, 153036},
	{"CHANTICLEER", 11, 153037},
	{"BESUCHEN", 8, 153038},
	{"OUSTERHOUT", 10, 153039},
	{"COUNTERSUNK", 11, 153040},
	{"TENURES", 7, 153041},
	{"MLW", 3, 153042},
	{"FLOCKFINDER", 11, 153043},
	{"APELDOORN", 9, 153044},
	{"NOWRAP", 6, 153045},
	{"VOELKER", 7, 153046},
	{"SONGLIST", 8, 153047},
	{"AICC", 4, 153048},
	{"REBELLING", 9, 153049},
	{"ADBLOCK", 7, 153050},
	{"MICROFILMS", 10, 153051},
	{"GOOBER", 6, 153052},
	{"DESTITUTION", 11, 153053},
	{"RUMMAGING", 9, 153054},
	{"MESOLITHIC", 10, 153055},
	{"MACCHINE", 8, 153056},
	{"REINSURER", 9, 153057},
	{"JUNCO", 5, 153058},
	{"RECCA", 5, 153059},
	{"ZDF", 3, 153060},
	{"AMMETER", 7, 153061},
	{"FUNIMATION", 10, 153062},
	{"NETOP", 5, 153063},
	{"MAGIE", 5, 153064},
	{"GLADIOLUS", 9, 153065},
	{"UNOL", 4, 153066},
	{"PSCI", 4, 153067},
	{"CTTW", 4, 153068},
	{"REDESIGNS", 9, 153069},
	{"NEURODEVELOPMENTAL", 18, 153070},
	{"UNCOUPLING", 10, 153071},
	{"UNITAS", 6, 153072},
	{"YENW", 4, 153073},
	{"YCYN", 4, 153074},
	{"WIGI", 4, 153075},
	{"SIKK", 4, 153076},
	{"ROLK", 4, 153077},
	{"RLEU", 4, 153078},
	{"OXCL", 4, 153079},
	{"NJAF", 4, 153080},
	{"MMOH", 4, 153081},
	{"MEOM", 4, 153082},
	{"LTUM", 4, 153083},
	{"HUKW", 4, 153084},
	{"EMPP", 4, 153085},
	{"BORNHOLM", 8, 153086},
	{"PIANA", 5, 153087},
	{"RHAGLEN", 7, 153088},
	{"CARBONATION", 11, 153089},
	{"BROWSEALOUD", 11, 153090},
	{"LOBORTIS", 8, 153091},
	{"DOREN", 5, 153092},
	{"LIJIANG", 7, 153093},
	{"LINDEMAN", 8, 153094},
	{"RUBINETTO", 9, 153095},
	{"AMERIMARK", 9, 153096},
	{"MARNIER", 7, 153097},
	{"BROACHED", 8, 153098},
	{"HELIOCENTRIC", 12, 153099},
	{"KESTENBAUM", 10, 153100},
	{"LIAW", 4, 153101},
	{"ALVITA", 6, 153102},
	{"LLAWN", 5, 153103},
	{"JVP", 3, 153104},
	{"WAVERS", 6, 153105},
	{"ICMA", 4, 153106},
	{"RECONFIRM", 9, 153107},
	{"SERVICESERVICE", 14, 153108},
	{"PUCKERED", 8, 153109},
	{"SQUALID", 7, 153110},
	{"DENYTOPICRENAME", 15, 153111},
	{"STIGLER", 7, 153112},
	{"HIPPEST", 7, 153113},
	{"RECEPT", 6, 153114},
	{"TAYLORVILLE", 11, 153115},
	{"KEUKENS", 7, 153116},
	{"GEMA", 4, 153117},
	{"READMITTED", 10, 153118},
	{"EFFING", 6, 153119},
	{"FRANCHISORS", 11, 153120},
	{"PROGN", 5, 153121},
	{"XSLI", 4, 153122},
	{"XLOO", 4, 153123},
	{"WUPE", 4, 153124},
	{"WLYN", 4, 153125},
	{"UTOJ", 4, 153126},
	{"UPTD", 4, 153127},
	{"UGWE", 4, 153128},
	{"TPUE", 4, 153129},
	{"SHYG", 4, 153130},
	{"PSUG", 4, 153131},
	{"PRYA", 4, 153132},
	{"ODRS", 4, 153133},
	{"OBIM", 4, 153134},
	{"NOVR", 4, 153135},
	{"LOYH", 4, 153136},
	{"IXBI", 4, 153137},
	{"FSEW", 4, 153138},
	{"DRWH", 4, 153139},
	{"COTF", 4, 153140},
	{"ALND", 4, 153141},
	{"BREADMAN", 8, 153142},
	{"SHUNNING", 8, 153143},
	{"HORIUCHI", 8, 153144},
	{"WESTBORO", 8, 153145},
	{"EVENTLOG", 8, 153146},
	{"DAVITA", 6, 153147},
	{"ALLADIN", 7, 153148},
	{"WATERPIK", 8, 153149},
	{"PASSBAND", 8, 153150},
	{"ONECARE", 7, 153151},
	{"ARTICLEID", 9, 153152},
	{"BOTTINEAU", 9, 153153},
	{"ERHALTEN", 8, 153154},
	{"BONDO", 5, 153155},
	{"CINDERS", 7, 153156},
	{"BOGOR", 5, 153157},
	{"AGENTE", 6, 153158},
	{"CARDIZEM", 8, 153159},
	{"CYTOKINESIS", 11, 153160},
	{"SMUDGES", 7, 153161},
	{"QWIK", 4, 153162},
	{"INTERROGATORY", 13, 153163},
	{"PAYLINE", 7, 153164},
	{"TURNTABLISTS", 12, 153165},
	{"NILPOTENT", 9, 153166},
	{"BOWDON", 6, 153167},
	{"NEPHRECTOMY", 11, 153168},
	{"MERCYFUL", 8, 153169},
	{"SYNDIC", 6, 153170},
	{"CLEAVING", 8, 153171},
	{"YELLOWDOG", 9, 153172},
	{"TANKCSAPDA", 10, 153173},
	{"HOLDUP", 6, 153174},
	{"KUHIO", 5, 153175},
	{"AUTOBUS", 7, 153176},
	{"SEMICIRCULAR", 12, 153177},
	{"PHONETOOLS", 10, 153178},
	{"CONDOMI", 7, 153179},
	{"BARTOLOMEO", 10, 153180},
	{"MONTANT", 7, 153181},
	{"ALLOSTERIC", 10, 153182},
	{"LISTINO", 7, 153183},
	{"TROW", 4, 153184},
	{"METROKANE", 9, 153185},
	{"WSOB", 4, 153186},
	{"WMYF", 4, 153187},
	{"TYEP", 4, 153188},
	{"SCOK", 4, 153189},
	{"RSMS", 4, 153190},
	{"NKYE", 4, 153191},
	{"NADF", 4, 153192},
	{"MKAI", 4, 153193},
	{"KOBU", 4, 153194},
	{"IPIM", 4, 153195},
	{"DMRL", 4, 153196},
	{"DLYY", 4, 153197},
	{"CYGE", 4, 153198},
	{"BICR", 4, 153199},
	{"AMNG", 4, 153200},
	{"NENAD", 5, 153201},
	{"BOUL", 4, 153202},
	{"VOCALIZATIONS", 13, 153203},
	{"USANDO", 6, 153204},
	{"PREACHY", 7, 153205},
	{"TOOMBS", 6, 153206},
	{"TIGERLILY", 9, 153207},
	{"OVERWORK", 8, 153208},
	{"ALOMAR", 6, 153209},
	{"PUBDATE", 7, 153210},
	{"JOVANOVIC", 9, 153211},
	{"BELCHING", 8, 153212},
	{"KIRCHE", 6, 153213},
	{"PILINGS", 7, 153214},
	{"MATABELELAND", 12, 153215},
	{"MEINL", 5, 153216},
	{"ESTADIO", 7, 153217},
	{"MXR", 3, 153218},
	{"SIMATIC", 7, 153219},
	{"NEWAYGO", 7, 153220},
	{"BLITZED", 7, 153221},
	{"FARBEN", 6, 153222},
	{"COMPARA", 7, 153223},
	{"GEOSTL", 6, 153224},
	{"PHOTOEMISSION", 13, 153225},
	{"MCCALLISTER", 11, 153226},
	{"ROCHES", 6, 153227},
	{"ICCA", 4, 153228},
	{"COSENZA", 7, 153229},
	{"GUYVER", 6, 153230},
	{"RAYMONDVILLE", 12, 153231},
	{"CATTY", 5, 153232},
	{"HYPERCALCEMIA", 13, 153233},
	{"ISHIHARA", 8, 153234},
	{"MENSAGENS", 9, 153235},
	{"HAULIERS", 8, 153236},
	{"DELLOSA", 7, 153237},
	{"STRINGFELLOW", 12, 153238},
	{"MASOCHIST", 9, 153239},
	{"DIVORCENET", 10, 153240},
	{"MUTANS", 6, 153241},
	{"WISHERS", 7, 153242},
	{"NRFB", 4, 153243},
	{"BDRMS", 5, 153244},
	{"MANNINGTON", 10, 153245},
	{"DRAMATIZATION", 13, 153246},
	{"OFFICINALE", 10, 153247},
	{"WADH", 4, 153248},
	{"UYME", 4, 153249},
	{"UXON", 4, 153250},
	{"UBHU", 4, 153251},
	{"RIKT", 4, 153252},
	{"PPUC", 4, 153253},
	{"MURG", 4, 153254},
	{"FTQU", 4, 153255},
	{"FTAV", 4, 153256},
	{"FOXL", 4, 153257},
	{"EVSP", 4, 153258},
	{"CYSY", 4, 153259},
	{"BSIG", 4, 153260},
	{"ELECTROSPRAY", 12, 153261},
	{"RANDSTAD", 8, 153262},
	{"DYLID", 5, 153263},
	{"MOBIEL", 6, 153264},
	{"POMMEL", 6, 153265},
	{"BASQUIAT", 8, 153266},
	{"UNTERSUCHUNGEN", 14, 153267},
	{"PLAYLAND", 8, 153268},
	{"INDENTATIONS", 12, 153269},
	{"ATTENUATES", 10, 153270},
	{"KENTFIELD", 9, 153271},
	{"DRIJFZAND", 9, 153272},
	{"SIGUE", 5, 153273},
	{"DENR", 4, 153274},
	{"INTERVI", 7, 153275},
	{"NEWSALERTS", 10, 153276},
	{"AMARO", 5, 153277},
	{"BIGGLESWADE", 11, 153278},
	{"CRAKE", 5, 153279},
	{"STORETHE", 8, 153280},
	{"SISSIES", 7, 153281},
	{"HUNNY", 5, 153282},
	{"BOOMERANGS", 10, 153283},
	{"BERMUDAGRASS", 12, 153284},
	{"HRADEC", 6, 153285},
	{"THURAYA", 7, 153286},
	{"MACKIN", 6, 153287},
	{"CATALOGUS", 9, 153288},
	{"ABACAVIR", 8, 153289},
	{"GUTTING", 7, 153290},
	{"THRISSUR", 8, 153291},
	{"MYNEDIAD", 8, 153292},
	{"INTERMIXED", 10, 153293},
	{"EMIGRATING", 10, 153294},
	{"AQUARIST", 8, 153295},
	{"EMENT", 5, 153296},
	{"BLF", 3, 153297},
	{"XMAME", 5, 153298},
	{"MDV", 3, 153299},
	{"GAININFORMATIONCONTAINER", 24, 153300},
	{"LOGIK", 5, 153301},
	{"RERUM", 5, 153302},
	{"ZIDERGIRL", 9, 153303},
	{"THUMBPRINT", 10, 153304},
	{"ARQUITECTURA", 12, 153305},
	{"SHANDON", 7, 153306},
	{"GILLNET", 7, 153307},
	{"POLANYI", 7, 153308},
	{"FREEMEN", 7, 153309},
	{"XKLA", 4, 153310},
	{"ULIH", 4, 153311},
	{"SMEU", 4, 153312},
	{"SKJO", 4, 153313},
	{"SDEX", 4, 153314},
	{"PEPU", 4, 153315},
	{"PCVE", 4, 153316},
	{"OTYR", 4, 153317},
	{"MLEO", 4, 153318},
	{"FWYO", 4, 153319},
	{"FTYG", 4, 153320},
	{"FFOD", 4, 153321},
	{"ERXA", 4, 153322},
	{"ERSX", 4, 153323},
	{"EMVO", 4, 153324},
	{"DHRY", 4, 153325},
	{"BIJO", 4, 153326},
	{"AYAQ", 4, 153327},
	{"ZVD", 3, 153328},
	{"ZKG", 3, 153329},
	{"ZFB", 3, 153330},
	{"XWL", 3, 153331},
	{"XCJ", 3, 153332},
	{"WQP", 3, 153333},
	{"VGJ", 3, 153334},
	{"QKL", 3, 153335},
	{"MVQ", 3, 153336},
	{"JZR", 3, 153337},
	{"JQC", 3, 153338},
	{"GRQ", 3, 153339},
	{"ENGENDERING", 11, 153340},
	{"BIRDFEEDERS", 11, 153341},
	{"PREFUSE", 7, 153342},
	{"MORABITO", 8, 153343},
	{"MELLAN", 6, 153344},
	{"PILEUP", 6, 153345},
	{"PEGPWRLW", 8, 153346},
	{"OPPORTUNI", 9, 153347},
	{"DUOPOLY", 7, 153348},
	{"PRESEN", 6, 153349},
	{"CHAUHAN", 7, 153350},
	{"SPECIF", 6, 153351},
	{"BUSQUEDA", 8, 153352},
	{"INFOANARCHY", 11, 153353},
	{"RAYEARTH", 8, 153354},
	{"DYNOMITE", 8, 153355},
	{"STABILISERS", 11, 153356},
	{"LINNET", 6, 153357},
	{"HULETT", 6, 153358},
	{"EDMS", 4, 153359},
	{"BMB", 3, 153360},
	{"ULTRAHIGH", 9, 153361},
	{"DICING", 6, 153362},
	{"HEIGHTENING", 11, 153363},
	{"GERSTNER", 8, 153364},
	{"VERZEKERINGEN", 13, 153365},
	{"WILKEN", 6, 153366},
	{"GOEDE", 5, 153367},
	{"CALAVISTA", 9, 153368},
	{"VALL", 4, 153369},
	{"GAITER", 6, 153370},
	{"MAITREYA", 8, 153371},
	{"MTWR", 4, 153372},
	{"LADDIE", 6, 153373},
	{"CHAUMET", 7, 153374},
	{"CHIMAERA", 8, 153375},
	{"OBJDUMP", 7, 153376},
	{"TALLIT", 6, 153377},
	{"BELLOWED", 8, 153378},
	{"KILLAM", 6, 153379},
	{"FEROCIOUSLY", 11, 153380},
	{"HIVEMIND", 8, 153381},
	{"WADLEY", 6, 153382},
	{"SCHOCK", 6, 153383},
	{"AMBOSELI", 8, 153384},
	{"MOIETIES", 8, 153385},
	{"ABSPRITZEN", 10, 153386},
	{"NEDLANDS", 8, 153387},
	{"CUSTOMIZER", 10, 153388},
	{"KINDERHOOK", 10, 153389},
	{"CMON", 4, 153390},
	{"ZEOV", 4, 153391},
	{"XUSI", 4, 153392},
	{"WGUA", 4, 153393},
	{"UKTA", 4, 153394},
	{"ROWK", 4, 153395},
	{"ROJU", 4, 153396},
	{"RLID", 4, 153397},
	{"PSYE", 4, 153398},
	{"OVDA", 4, 153399},
	{"OUGC", 4, 153400},
	{"NDRF", 4, 153401},
	{"MPTM", 4, 153402},
	{"LOHM", 4, 153403},
	{"LCAH", 4, 153404},
	{"ISPW", 4, 153405},
	{"GGAZ", 4, 153406},
	{"FWAD", 4, 153407},
	{"EYIG", 4, 153408},
	{"ECAJ", 4, 153409},
	{"AEBU", 4, 153410},
	{"RESTRIKE", 8, 153411},
	{"ETHIDIUM", 8, 153412},
	{"KIANNA", 6, 153413},
	{"BUTANOL", 7, 153414},
	{"UNBEARABLY", 10, 153415},
	{"PWNED", 5, 153416},
	{"VYOTECH", 7, 153417},
	{"EBOST", 5, 153418},
	{"MONITORES", 9, 153419},
	{"GUNFIGHTER", 10, 153420},
	{"BERTHOUD", 8, 153421},
	{"HERMITE", 7, 153422},
	{"TONIGHTS", 8, 153423},
	{"BASEMAP", 7, 153424},
	{"DEVERAUX", 8, 153425},
	{"STRETCHABLE", 11, 153426},
	{"TIONALLY", 8, 153427},
	{"DAHMER", 6, 153428},
	{"SHILLER", 7, 153429},
	{"DMK", 3, 153430},
	{"TIMESLOTS", 9, 153431},
	{"WILLO", 5, 153432},
	{"UPROOTING", 9, 153433},
	{"ANCHORAGES", 10, 153434},
	{"DEVAS", 5, 153435},
	{"WEASIE", 6, 153436},
	{"VIRTUOZZO", 9, 153437},
	{"CITYLINK", 8, 153438},
	{"HOSTMASTER", 10, 153439},
	{"GTLD", 4, 153440},
	{"TENCHU", 6, 153441},
	{"WEINSTOCK", 9, 153442},
	{"ORIENTALES", 10, 153443},
	{"LETTIE", 6, 153444},
	{"POLYPHON", 8, 153445},
	{"SEWALL", 6, 153446},
	{"ARTERIALS", 9, 153447},
	{"PROSOFT", 7, 153448},
	{"NETID", 5, 153449},
	{"OLESEN", 6, 153450},
	{"STENGEL", 7, 153451},
	{"BARRIERE", 8, 153452},
	{"WEAB", 4, 153453},
	{"UISK", 4, 153454},
	{"SPYG", 4, 153455},
	{"SOLC", 4, 153456},
	{"SBOC", 4, 153457},
	{"ROXK", 4, 153458},
	{"ROGM", 4, 153459},
	{"NAYR", 4, 153460},
	{"LITK", 4, 153461},
	{"LGAA", 4, 153462},
	{"LFIA", 4, 153463},
	{"KBOL", 4, 153464},
	{"JUTL", 4, 153465},
	{"IWAM", 4, 153466},
	{"IKAF", 4, 153467},
	{"IHUL", 4, 153468},
	{"HUPR", 4, 153469},
	{"GCAK", 4, 153470},
	{"EUXA", 4, 153471},
	{"EFCL", 4, 153472},
	{"ECKV", 4, 153473},
	{"CLAG", 4, 153474},
	{"ATCF", 4, 153475},
	{"SKIMP", 5, 153476},
	{"RESISTERS", 9, 153477},
	{"ZUSAMMENFASSUNG", 15, 153478},
	{"OXYGENE", 7, 153479},
	{"REZEPTE", 7, 153480},
	{"PANCHAYATS", 10, 153481},
	{"COLFER", 6, 153482},
	{"MCCOWN", 6, 153483},
	{"MEZLAN", 6, 153484},
	{"DEVITT", 6, 153485},
	{"SULFHYDRYL", 10, 153486},
	{"TIEBREAKER", 10, 153487},
	{"ANSTEY", 6, 153488},
	{"GREENBUILDING", 13, 153489},
	{"RELOCATES", 9, 153490},
	{"SCCC", 4, 153491},
	{"HORNSEY", 7, 153492},
	{"SKYLARKING", 10, 153493},
	{"AVEIRO", 6, 153494},
	{"GOTU", 4, 153495},
	{"INVERURIE", 9, 153496},
	{"MATIZ", 5, 153497},
	{"LARYNGITIS", 10, 153498},
	{"PCK", 3, 153499},
	{"EXTRICATION", 11, 153500},
	{"FREESBIE", 8, 153501},
	{"BLAB", 4, 153502},
	{"VLD", 3, 153503},
	{"PROFIGOLD", 9, 153504},
	{"ENDOGENEITY", 11, 153505},
	{"DIGRAPHS", 8, 153506},
	{"RAFIK", 5, 153507},
	{"SELASSIE", 8, 153508},
	{"MALEY", 5, 153509},
	{"MACLEAY", 7, 153510},
	{"BEAMAN", 6, 153511},
	{"KWC", 3, 153512},
	{"INTERRELATIONS", 14, 153513},
	{"QUESTI", 6, 153514},
	{"SHINAGAWA", 9, 153515},
	{"GERRITSEN", 9, 153516},
	{"CASHLESS", 8, 153517},
	{"AUDIOGALAXY", 11, 153518},
	{"FESSENDEN", 9, 153519},
	{"ENTIER", 6, 153520},
	{"QUESTIONMARK", 12, 153521},
	{"ANIMATI", 7, 153522},
	{"MULLINGAR", 9, 153523},
	{"NICHELLE", 8, 153524},
	{"VERDUGO", 7, 153525},
	{"TIMBERED", 8, 153526},
	{"KOKESHI", 7, 153527},
	{"WWFA", 4, 153528},
	{"UNNU", 4, 153529},
	{"UIAR", 4, 153530},
	{"RAQP", 4, 153531},
	{"PMME", 4, 153532},
	{"OJOY", 4, 153533},
	{"MOWB", 4, 153534},
	{"LPOC", 4, 153535},
	{"LAJI", 4, 153536},
	{"ICKQ", 4, 153537},
	{"ESMP", 4, 153538},
	{"AEDW", 4, 153539},
	{"GOBBLING", 8, 153540},
	{"YAHOOS", 6, 153541},
	{"ANALOGIC", 8, 153542},
	{"PAVLIK", 6, 153543},
	{"ONTENTS", 7, 153544},
	{"CLARESHOLM", 10, 153545},
	{"DICKMAN", 7, 153546},
	{"IMPLANTING", 10, 153547},
	{"INTERTWINING", 12, 153548},
	{"RUBRUM", 6, 153549},
	{"STOOGE", 6, 153550},
	{"TRABECULAR", 10, 153551},
	{"ELDEN", 5, 153552},
	{"KATHE", 5, 153553},
	{"MOULDERS", 8, 153554},
	{"KATMANDU", 8, 153555},
	{"HORNIK", 6, 153556},
	{"CONSERVATORSHIP", 15, 153557},
	{"DELFIN", 6, 153558},
	{"CANED", 5, 153559},
	{"ARIK", 4, 153560},
	{"BYFIELD", 7, 153561},
	{"ELDORA", 6, 153562},
	{"SIGMOIDOSCOPY", 13, 153563},
	{"SPHERION", 8, 153564},
	{"POWERSPEC", 9, 153565},
	{"UNRIGHTEOUSNESS", 15, 153566},
	{"BELLEZA", 7, 153567},
	{"WOOLOVERS", 9, 153568},
	{"SHRILLY", 7, 153569},
	{"THUNDERHEAD", 11, 153570},
	{"SUCESSFULLY", 11, 153571},
	{"CATULLUS", 8, 153572},
	{"AGINCOURT", 9, 153573},
	{"MANOHAR", 7, 153574},
	{"INTELLISTRAND", 13, 153575},
	{"DUNNIGAN", 8, 153576},
	{"TOMEK", 5, 153577},
	{"SUBREGIONS", 10, 153578},
	{"SENDFILE", 8, 153579},
	{"KEYID", 5, 153580},
	{"MALAK", 5, 153581},
	{"WRITELINE", 9, 153582},
	{"BEFUDDLED", 9, 153583},
	{"WNESTED", 7, 153584},
	{"ZYHO", 4, 153585},
	{"ZWAL", 4, 153586},
	{"WESF", 4, 153587},
	{"OFBM", 4, 153588},
	{"NJUT", 4, 153589},
	{"NCEX", 4, 153590},
	{"MLYP", 4, 153591},
	{"LDOJ", 4, 153592},
	{"KFIT", 4, 153593},
	{"GTAY", 4, 153594},
	{"GAPF", 4, 153595},
	{"CYSW", 4, 153596},
	{"BOSM", 4, 153597},
	{"BMIC", 4, 153598},
	{"AQUN", 4, 153599},
	{"AIFR", 4, 153600},
	{"MYSTIKAL", 8, 153601},
	{"OPTIMISER", 9, 153602},
	{"CBER", 4, 153603},
	{"DULLED", 6, 153604},
	{"HOLIDAYINN", 10, 153605},
	{"NUESTRAS", 8, 153606},
	{"BARTOLO", 7, 153607},
	{"DENNEHY", 7, 153608},
	{"TRANCHES", 8, 153609},
	{"MAWRTH", 6, 153610},
	{"SAYYAF", 6, 153611},
	{"KAMMA", 5, 153612},
	{"BUCHMAN", 7, 153613},
	{"VALETING", 8, 153614},
	{"SKETCHPAD", 9, 153615},
	{"HAYAKAWA", 8, 153616},
	{"PRAHRAN", 7, 153617},
	{"BANANASHOES", 11, 153618},
	{"NONINFRINGEMENT", 15, 153619},
	{"INTERWEAVE", 10, 153620},
	{"INTERLOCUTOR", 12, 153621},
	{"MCNETT", 6, 153622},
	{"ANCILLARIES", 11, 153623},
	{"SHOPFERRET", 10, 153624},
	{"CIBOLA", 6, 153625},
	{"DBFORUMS", 8, 153626},
	{"FLATLINE", 8, 153627},
	{"EVERYTHINGS", 11, 153628},
	{"SHADYSIDE", 9, 153629},
	{"SPEEDIER", 8, 153630},
	{"DMACHINEMON", 11, 153631},
	{"NAMBOUR", 7, 153632},
	{"STRADDLED", 9, 153633},
	{"AERIE", 5, 153634},
	{"PARALOGS", 8, 153635},
	{"COOLDOWN", 8, 153636},
	{"PANSONIC", 8, 153637},
	{"INTERROSE", 9, 153638},
	{"BASILAR", 7, 153639},
	{"AMITAI", 6, 153640},
	{"UNIVERSITAS", 11, 153641},
	{"INSECTICIDAL", 12, 153642},
	{"YNEJ", 4, 153643},
	{"YMYW", 4, 153644},
	{"YIAL", 4, 153645},
	{"YAWF", 4, 153646},
	{"XELI", 4, 153647},
	{"WIIF", 4, 153648},
	{"VABU", 4, 153649},
	{"UJOU", 4, 153650},
	{"RIXE", 4, 153651},
	{"PEMY", 4, 153652},
	{"OLNF", 4, 153653},
	{"OAMW", 4, 153654},
	{"MCHL", 4, 153655},
	{"LTSV", 4, 153656},
	{"KMSQ", 4, 153657},
	{"JOCA", 4, 153658},
	{"GHEK", 4, 153659},
	{"EFVI", 4, 153660},
	{"DULH", 4, 153661},
	{"DKEM", 4, 153662},
	{"DDWO", 4, 153663},
	{"DCOK", 4, 153664},
	{"CDWA", 4, 153665},
	{"BCSU", 4, 153666},
	{"AYKU", 4, 153667},
	{"AUGL", 4, 153668},
	{"ALFK", 4, 153669},
	{"FARI", 4, 153670},
	{"CARETAKING", 10, 153671},
	{"BAYCOM", 6, 153672},
	{"MCBEE", 5, 153673},
	{"LOWREY", 6, 153674},
	{"ARBA", 4, 153675},
	{"NOSSOS", 6, 153676},
	{"HARPY", 5, 153677},
	{"ORIENTALIA", 10, 153678},
	{"TEGEL", 5, 153679},
	{"AGRONOMIST", 10, 153680},
	{"BRIDGEHEAD", 10, 153681},
	{"SAINTHOOD", 9, 153682},
	{"PDFADOBE", 8, 153683},
	{"LACERATION", 10, 153684},
	{"HEPATOMA", 8, 153685},
	{"WPB", 3, 153686},
	{"KINGLY", 6, 153687},
	{"CHIDED", 6, 153688},
	{"WRP", 3, 153689},
	{"DRINKWATER", 10, 153690},
	{"KEOWN", 5, 153691},
	{"TIKKUN", 6, 153692},
	{"GRAMSCI", 7, 153693},
	{"WXMAP", 5, 153694},
	{"SALBUTAMOL", 10, 153695},
	{"DBSNP", 5, 153696},
	{"TURBANS", 7, 153697},
	{"MENDHAM", 7, 153698},
	{"DTSCH", 5, 153699},
	{"ACQUIT", 6, 153700},
	{"COMPROMISO", 10, 153701},
	{"VOCODER", 7, 153702},
	{"MCGEORGE", 8, 153703},
	{"CONVERGYS", 9, 153704},
	{"NUMERI", 6, 153705},
	{"BONAR", 5, 153706},
	{"CARMAKERS", 9, 153707},
	{"WEBADVISOR", 10, 153708},
	{"SLICKERS", 8, 153709},
	{"SCHEFFER", 8, 153710},
	{"NEUROLEPTIC", 11, 153711},
	{"CHELA", 5, 153712},
	{"CONTRACTURE", 11, 153713},
	{"CHILDRENSWEAR", 13, 153714},
	{"XLOC", 4, 153715},
	{"UORY", 4, 153716},
	{"RMRC", 4, 153717},
	{"MYOS", 4, 153718},
	{"MEAQ", 4, 153719},
	{"MAOP", 4, 153720},
	{"KRUB", 4, 153721},
	{"KOMS", 4, 153722},
	{"INBB", 4, 153723},
	{"GTHG", 4, 153724},
	{"EUKD", 4, 153725},
	{"CRUG", 4, 153726},
	{"BURH", 4, 153727},
	{"CULINAIRE", 9, 153728},
	{"COUSE", 5, 153729},
	{"ESPORTS", 7, 153730},
	{"SUSPECTDJ", 9, 153731},
	{"ELECTROCUTED", 12, 153732},
	{"CHOISIR", 7, 153733},
	{"PROPOGANDA", 10, 153734},
	{"SVETI", 5, 153735},
	{"SMOOCH", 6, 153736},
	{"PERTINENCE", 10, 153737},
	{"WALLEN", 6, 153738},
	{"HVOR", 4, 153739},
	{"ALLOWAY", 7, 153740},
	{"MOGLIE", 6, 153741},
	{"HAVAS", 5, 153742},
	{"SINGE", 5, 153743},
	{"CHRISTENINGS", 12, 153744},
	{"STUNDEN", 7, 153745},
	{"AUTORS", 6, 153746},
	{"CRAGG", 5, 153747},
	{"MCCORKLE", 8, 153748},
	{"OPTIONEE", 8, 153749},
	{"CLASSYPERFUMES", 14, 153750},
	{"UNDERPERFORM", 12, 153751},
	{"EGOLD", 5, 153752},
	{"BASIA", 5, 153753},
	{"HATBORO", 7, 153754},
	{"HARPING", 7, 153755},
	{"POLANCO", 7, 153756},
	{"LWC", 3, 153757},
	{"UROS", 4, 153758},
	{"PANDE", 5, 153759},
	{"ELLIOTTE", 8, 153760},
	{"PLUNK", 5, 153761},
	{"ALVARION", 8, 153762},
	{"UICC", 4, 153763},
	{"AUDIOQUEST", 10, 153764},
	{"CENG", 4, 153765},
	{"INFLEXIBILITY", 13, 153766},
	{"GAMEMASTER", 10, 153767},
	{"LIOUVILLE", 9, 153768},
	{"KERO", 4, 153769},
	{"GOODWRENCH", 10, 153770},
	{"TRIZ", 4, 153771},
	{"YXME", 4, 153772},
	{"YDEU", 4, 153773},
	{"WLHA", 4, 153774},
	{"TDYI", 4, 153775},
	{"REUC", 4, 153776},
	{"QBMA", 4, 153777},
	{"OFDD", 4, 153778},
	{"NTUD", 4, 153779},
	{"NBAJ", 4, 153780},
	{"LOYP", 4, 153781},
	{"KYOM", 4, 153782},
	{"KRAW", 4, 153783},
	{"HOMG", 4, 153784},
	{"HIKK", 4, 153785},
	{"EXEG", 4, 153786},
	{"DREZ", 4, 153787},
	{"DKOW", 4, 153788},
	{"DJSA", 4, 153789},
	{"CMOL", 4, 153790},
	{"CHKR", 4, 153791},
	{"BYEF", 4, 153792},
	{"AYEQ", 4, 153793},
	{"HIAASEN", 7, 153794},
	{"EXTREMEPIE", 10, 153795},
	{"SUZUKA", 6, 153796},
	{"CHANDRASEKHAR", 13, 153797},
	{"TRIATHLONS", 10, 153798},
	{"OAKEY", 5, 153799},
	{"ROXYBOT", 7, 153800},
	{"HEATHLAND", 9, 153801},
	{"PBF", 3, 153802},
	{"VACHON", 6, 153803},
	{"MOBLOGGING", 10, 153804},
	{"MRES", 4, 153805},
	{"SARNO", 5, 153806},
	{"KDEUTILS", 8, 153807},
	{"RETICULATED", 11, 153808},
	{"AKIMBO", 6, 153809},
	{"AZAHAR", 6, 153810},
	{"BEECHES", 7, 153811},
	{"REVELATORY", 10, 153812},
	{"LANGASEK", 8, 153813},
	{"THWAITES", 8, 153814},
	{"OBGIN", 5, 153815},
	{"MOBOS", 5, 153816},
	{"GARDNERVILLE", 12, 153817},
	{"DAMACY", 6, 153818},
	{"ECKHARDT", 8, 153819},
	{"PRICESCAN", 9, 153820},
	{"LARNED", 6, 153821},
	{"BERTINI", 7, 153822},
	{"OTTERY", 6, 153823},
	{"PERMALINKREPLY", 14, 153824},
	{"ARCHITEC", 8, 153825},
	{"RIETI", 5, 153826},
	{"BECA", 4, 153827},
	{"RYKO", 4, 153828},
	{"VEENA", 5, 153829},
	{"SEULE", 5, 153830},
	{"DONEE", 5, 153831},
	{"CHUNKING", 8, 153832},
	{"VELUX", 5, 153833},
	{"GAUCHER", 7, 153834},
	{"TOPOL", 5, 153835},
	{"ULTRATHIN", 9, 153836},
	{"PEMBA", 5, 153837},
	{"ABRAHAMSON", 10, 153838},
	{"AUGMENTER", 9, 153839},
	{"YEOR", 4, 153840},
	{"WSMY", 4, 153841},
	{"UMND", 4, 153842},
	{"TBIZ", 4, 153843},
	{"RPBE", 4, 153844},
	{"PTDA", 4, 153845},
	{"PSAK", 4, 153846},
	{"NYLT", 4, 153847},
	{"LSAK", 4, 153848},
	{"IPTD", 4, 153849},
	{"GSJA", 4, 153850},
	{"EVIM", 4, 153851},
	{"EGCH", 4, 153852},
	{"DPMW", 4, 153853},
	{"CLYI", 4, 153854},
	{"BYKH", 4, 153855},
	{"BSAV", 4, 153856},
	{"AIGD", 4, 153857},
	{"ABMO", 4, 153858},
	{"ENERGYFILES", 11, 153859},
	{"PARTICULARITIES", 15, 153860},
	{"SIVAN", 5, 153861},
	{"HIEROGLYPHIC", 12, 153862},
	{"EBERHARDT", 9, 153863},
	{"ARYANS", 6, 153864},
	{"PROGRAMMABILITY", 15, 153865},
	{"CRYOSURGERY", 11, 153866},
	{"TUBEY", 5, 153867},
	{"ROMPL", 5, 153868},
	{"INFOZINE", 8, 153869},
	{"INGTON", 6, 153870},
	{"YOURSELFERS", 11, 153871},
	{"BABI", 4, 153872},
	{"EWWW", 4, 153873},
	{"MCLEISH", 7, 153874},
	{"SEABURY", 7, 153875},
	{"HPGL", 4, 153876},
	{"WCMC", 4, 153877},
	{"SEMITES", 7, 153878},
	{"BANISHING", 9, 153879},
	{"USCC", 4, 153880},
	{"CONSIDINE", 9, 153881},
	{"VLP", 3, 153882},
	{"GIGAHERTZ", 9, 153883},
	{"TENSELY", 7, 153884},
	{"MOTILE", 6, 153885},
	{"LABRADORITE", 11, 153886},
	{"FGREP", 5, 153887},
	{"WAREWASHING", 11, 153888},
	{"UNICAMERAL", 10, 153889},
	{"NAUDIA", 6, 153890},
	{"DEUTERON", 8, 153891},
	{"SENSIS", 6, 153892},
	{"MARSHLAND", 9, 153893},
	{"GYRE", 4, 153894},
	{"LAUDA", 5, 153895},
	{"RECTUS", 6, 153896},
	{"SAUZE", 5, 153897},
	{"DUNFORD", 7, 153898},
	{"PRUNER", 6, 153899},
	{"HAABAA", 6, 153900},
	{"LONGCHAMP", 9, 153901},
	{"JOSEFINA", 8, 153902},
	{"ESCHENBACH", 10, 153903},
	{"SLAPPA", 6, 153904},
	{"MYHOLLYWOOD", 11, 153905},
	{"NAKURU", 6, 153906},
	{"DATSUNS", 7, 153907},
	{"LIFEFORMS", 9, 153908},
	{"PHILISHAVE", 10, 153909},
	{"NORMBLOG", 8, 153910},
	{"CLAMOUR", 7, 153911},
	{"ZBEG", 4, 153912},
	{"YUTO", 4, 153913},
	{"YUBI", 4, 153914},
	{"YGOM", 4, 153915},
	{"WGUN", 4, 153916},
	{"VREN", 4, 153917},
	{"RKNU", 4, 153918},
	{"PFIT", 4, 153919},
	{"OYCR", 4, 153920},
	{"OPYM", 4, 153921},
	{"OAUB", 4, 153922},
	{"HUTM", 4, 153923},
	{"GYNI", 4, 153924},
	{"EXEX", 4, 153925},
	{"BNPP", 4, 153926},
	{"BHIL", 4, 153927},
	{"AXBO", 4, 153928},
	{"DSDP", 4, 153929},
	{"PEDEN", 5, 153930},
	{"MUTCH", 5, 153931},
	{"TUSSAUDS", 8, 153932},
	{"REVITALISE", 10, 153933},
	{"KURU", 4, 153934},
	{"SHAHRUKH", 8, 153935},
	{"SMALTO", 6, 153936},
	{"DVDREMAKE", 9, 153937},
	{"BIGFORK", 7, 153938},
	{"MESSA", 5, 153939},
	{"MURCIELAGO", 10, 153940},
	{"BEEMER", 6, 153941},
	{"CARTOONISH", 10, 153942},
	{"PLAGIARIZE", 10, 153943},
	{"GORDAN", 6, 153944},
	{"FLECKS", 6, 153945},
	{"FELTEN", 6, 153946},
	{"EXPORTABLE", 10, 153947},
	{"CPUE", 4, 153948},
	{"TITTENSUCHE", 11, 153949},
	{"CARRUTH", 7, 153950},
	{"BAAR", 4, 153951},
	{"SOPRA", 5, 153952},
	{"ALVAR", 5, 153953},
	{"RMM", 3, 153954},
	{"SLIVERS", 7, 153955},
	{"SEITECH", 7, 153956},
	{"SYSTRAY", 7, 153957},
	{"STOCKGROUP", 10, 153958},
	{"KUTV", 4, 153959},
	{"UNED", 4, 153960},
	{"PUNKT", 5, 153961},
	{"MOUNTAINBIKING", 14, 153962},
	{"DUNKEL", 6, 153963},
	{"CYM", 3, 153964},
	{"MAISONNEUVE", 11, 153965},
	{"HASEK", 5, 153966},
	{"CHESTY", 6, 153967},
	{"SNAPDRAGONS", 11, 153968},
	{"WEBSTAR", 7, 153969},
	{"UNRAVELS", 8, 153970},
	{"CHATER", 6, 153971},
	{"ELECTRET", 8, 153972},
	{"CLAMPDOWN", 9, 153973},
	{"BASKERVILLES", 12, 153974},
	{"ERLE", 4, 153975},
	{"LIGHTNER", 8, 153976},
	{"QUANTEX", 7, 153977},
	{"DOERING", 7, 153978},
	{"DISCUSSIONSS", 12, 153979},
	{"BARRETTES", 9, 153980},
	{"MERAK", 5, 153981},
	{"CONCOCTIONS", 11, 153982},
	{"COMPAROMETER", 12, 153983},
	{"MONETTE", 7, 153984},
	{"BERLE", 5, 153985},
	{"FLOSSING", 8, 153986},
	{"XTCE", 4, 153987},
	{"VSWA", 4, 153988},
	{"UYWO", 4, 153989},
	{"SAGY", 4, 153990},
	{"PMWA", 4, 153991},
	{"OMFY", 4, 153992},
	{"OGBY", 4, 153993},
	{"MUMV", 4, 153994},
	{"KIYE", 4, 153995},
	{"IJIR", 4, 153996},
	{"HUIL", 4, 153997},
	{"GCEO", 4, 153998},
	{"FFOG", 4, 153999},
	{"DHMS", 4, 154000},
	{"DFIO", 4, 154001},
	{"AUXT", 4, 154002},
	{"KOLAR", 5, 154003},
	{"SOFTBANK", 8, 154004},
	{"VACUOLES", 8, 154005},
	{"FRAGRANCEBAY", 12, 154006},
	{"GHOULISH", 8, 154007},
	{"BIVENS", 6, 154008},
	{"UNADORNED", 9, 154009},
	{"SNOWBLOWER", 10, 154010},
	{"HYDROGEOLOGIC", 13, 154011},
	{"LINGUE", 6, 154012},
	{"WANANGA", 7, 154013},
	{"PELLING", 7, 154014},
	{"RUNTIMES", 8, 154015},
	{"SOLDEU", 6, 154016},
	{"FLATOUT", 7, 154017},
	{"CAYUSE", 6, 154018},
	{"ENGSTROM", 8, 154019},
	{"PREFACED", 8, 154020},
	{"SHPG", 4, 154021},
	{"AIMSMILEYS", 10, 154022},
	{"XINCLUDE", 8, 154023},
	{"ARBITRARINESS", 13, 154024},
	{"CACL", 4, 154025},
	{"CMAIL", 5, 154026},
	{"WIJN", 4, 154027},
	{"SAMOANS", 7, 154028},
	{"EPSDT", 5, 154029},
	{"ANNOUCEMENT", 11, 154030},
	{"LUNGES", 6, 154031},
	{"NSCD", 4, 154032},
	{"MASINI", 6, 154033},
	{"GUINT", 5, 154034},
	{"GLEICHEN", 8, 154035},
	{"PARAMEDICAL", 11, 154036},
	{"EYNDE", 5, 154037},
	{"SPRL", 4, 154038},
	{"COPYRIGHTABLE", 13, 154039},
	{"ABUTS", 5, 154040},
	{"SCAC", 4, 154041},
	{"PHOTOLUMINESCENCE", 17, 154042},
	{"JACKHAMMER", 10, 154043},
	{"ATBATT", 6, 154044},
	{"IDBI", 4, 154045},
	{"VERBAND", 7, 154046},
	{"EDMUNDSTON", 10, 154047},
	{"RAGAZZI", 7, 154048},
	{"COMF", 4, 154049},
	{"LNAME", 5, 154050},
	{"HUDA", 4, 154051},
	{"MICROSURGERY", 12, 154052},
	{"SEEALSO", 7, 154053},
	{"STRATO", 6, 154054},
	{"HEMANT", 6, 154055},
	{"JSMITH", 6, 154056},
	{"GRAT", 4, 154057},
	{"ZFOU", 4, 154058},
	{"WZER", 4, 154059},
	{"VRAD", 4, 154060},
	{"UORB", 4, 154061},
	{"UCYW", 4, 154062},
	{"SSUV", 4, 154063},
	{"SOLF", 4, 154064},
	{"RCPR", 4, 154065},
	{"RAEB", 4, 154066},
	{"OKUD", 4, 154067},
	{"MBWE", 4, 154068},
	{"LUXK", 4, 154069},
	{"IJOU", 4, 154070},
	{"HCOB", 4, 154071},
	{"HCLY", 4, 154072},
	{"GGOS", 4, 154073},
	{"EDTC", 4, 154074},
	{"CTTY", 4, 154075},
	{"BYRH", 4, 154076},
	{"RUBI", 4, 154077},
	{"WAMPLER", 7, 154078},
	{"YELLOWED", 8, 154079},
	{"FRIT", 4, 154080},
	{"DOBRICH", 7, 154081},
	{"JLB", 3, 154082},
	{"CHADDS", 6, 154083},
	{"KEOUGH", 6, 154084},
	{"MAJESTIES", 9, 154085},
	{"WEIDMAN", 7, 154086},
	{"SARPY", 5, 154087},
	{"RETRACTOR", 9, 154088},
	{"BESTWESTERN", 11, 154089},
	{"VITAMINDER", 10, 154090},
	{"LYNDE", 5, 154091},
	{"ENDEARMENT", 10, 154092},
	{"PETZ", 4, 154093},
	{"MALC", 4, 154094},
	{"BUNGE", 5, 154095},
	{"DUCASSE", 7, 154096},
	{"FEALTY", 6, 154097},
	{"DISPUTATION", 11, 154098},
	{"REBUTTALS", 9, 154099},
	{"DENDRITE", 8, 154100},
	{"TRICUSPID", 9, 154101},
	{"WENNER", 6, 154102},
	{"OSBURN", 6, 154103},
	{"EJWTERIKWN", 10, 154104},
	{"REVIVA", 6, 154105},
	{"BREATHALYZER", 12, 154106},
	{"NEOVASCULARIZATION", 18, 154107},
	{"MEAP", 4, 154108},
	{"AFFICHAGE", 9, 154109},
	{"LIGHTROOM", 9, 154110},
	{"RUAOK", 5, 154111},
	{"CFMX", 4, 154112},
	{"SPONSER", 7, 154113},
	{"LIGON", 5, 154114},
	{"BACKDRAFT", 9, 154115},
	{"KLASERIE", 8, 154116},
	{"RABB", 4, 154117},
	{"COLORSPACE", 10, 154118},
	{"EFRAIN", 6, 154119},
	{"BIGGIN", 6, 154120},
	{"WPLU", 4, 154121},
	{"UKOF", 4, 154122},
	{"SZOM", 4, 154123},
	{"RYZI", 4, 154124},
	{"RIXH", 4, 154125},
	{"OYSY", 4, 154126},
	{"OBUE", 4, 154127},
	{"MPEX", 4, 154128},
	{"LPHN", 4, 154129},
	{"LIJO", 4, 154130},
	{"LBIE", 4, 154131},
	{"KWEG", 4, 154132},
	{"KMEW", 4, 154133},
	{"IRYD", 4, 154134},
	{"HEJL", 4, 154135},
	{"GRYD", 4, 154136},
	{"EZIG", 4, 154137},
	{"EYSJ", 4, 154138},
	{"EBCR", 4, 154139},
	{"DZEL", 4, 154140},
	{"DUON", 4, 154141},
	{"DTVI", 4, 154142},
	{"CNEC", 4, 154143},
	{"MOORHOUSE", 9, 154144},
	{"DOYLES", 6, 154145},
	{"OPCIONES", 8, 154146},
	{"COMPUTERACT", 11, 154147},
	{"NISHIKAWA", 9, 154148},
	{"LEICHT", 6, 154149},
	{"HILLERT", 7, 154150},
	{"WHOSO", 5, 154151},
	{"THRACIAN", 8, 154152},
	{"SOURCEFILE", 10, 154153},
	{"HOOSICK", 7, 154154},
	{"SANITIZERS", 10, 154155},
	{"FASHIONISTAS", 12, 154156},
	{"PARTINGTON", 10, 154157},
	{"WESTBY", 6, 154158},
	{"ECONTENT", 8, 154159},
	{"EGENERA", 7, 154160},
	{"VENDEE", 6, 154161},
	{"BADAWI", 6, 154162},
	{"PERRET", 6, 154163},
	{"GPNOTEBOOK", 10, 154164},
	{"CARTAN", 6, 154165},
	{"SCHLEY", 6, 154166},
	{"LEJABY", 6, 154167},
	{"ARYEH", 5, 154168},
	{"SOOTHER", 7, 154169},
	{"OPINIONES", 9, 154170},
	{"SAFAR", 5, 154171},
	{"FORERUNNERS", 11, 154172},
	{"EXHALATION", 10, 154173},
	{"EMTAC", 5, 154174},
	{"BOERI", 5, 154175},
	{"MAYUMI", 6, 154176},
	{"DATAQUEST", 9, 154177},
	{"CIOL", 4, 154178},
	{"HUMORLINKS", 10, 154179},
	{"JAGDISH", 7, 154180},
	{"VALENS", 6, 154181},
	{"SAFONAU", 7, 154182},
	{"WKLY", 4, 154183},
	{"CIPFA", 5, 154184},
	{"PAGEVIEW", 8, 154185},
	{"NNDB", 4, 154186},
	{"RADIALS", 7, 154187},
	{"ZEGE", 4, 154188},
	{"YPHR", 4, 154189},
	{"WDAM", 4, 154190},
	{"RLCH", 4, 154191},
	{"REKP", 4, 154192},
	{"PEZD", 4, 154193},
	{"NLOF", 4, 154194},
	{"EVLE", 4, 154195},
	{"CUEG", 4, 154196},
	{"CBYP", 4, 154197},
	{"BAIC", 4, 154198},
	{"CHELYABINSK", 11, 154199},
	{"CALLUSES", 8, 154200},
	{"SUNSTONE", 8, 154201},
	{"PHANGAN", 7, 154202},
	{"INSTALLATIE", 11, 154203},
	{"LEAFED", 6, 154204},
	{"CARINII", 7, 154205},
	{"KINGSOLVER", 10, 154206},
	{"TAMBOR", 6, 154207},
	{"SEALINE", 7, 154208},
	{"SOUTHER", 7, 154209},
	{"LINCO", 5, 154210},
	{"IQNET", 5, 154211},
	{"IZAK", 4, 154212},
	{"INVESTITURE", 11, 154213},
	{"KITTANNING", 10, 154214},
	{"FOTOPAGES", 9, 154215},
	{"WIECK", 5, 154216},
	{"PALEONTOLOGIST", 14, 154217},
	{"MICROPROBE", 10, 154218},
	{"FRANNY", 6, 154219},
	{"BAVA", 4, 154220},
	{"BDNF", 4, 154221},
	{"METAMAIL", 8, 154222},
	{"DOKUMENTE", 9, 154223},
	{"THEORETISCHE", 12, 154224},
	{"COLORIST", 8, 154225},
	{"INDERAL", 7, 154226},
	{"GNURADIO", 8, 154227},
	{"HOTWIFE", 7, 154228},
	{"TOPICINFO", 9, 154229},
	{"ELASTICA", 8, 154230},
	{"RAMZI", 5, 154231},
	{"PBUFFER", 7, 154232},
	{"BEATITUDES", 10, 154233},
	{"VVVV", 4, 154234},
	{"ANIMATES", 8, 154235},
	{"XRED", 4, 154236},
	{"WOSQ", 4, 154237},
	{"UIKO", 4, 154238},
	{"TAPC", 4, 154239},
	{"SMUH", 4, 154240},
	{"SDUF", 4, 154241},
	{"RYLW", 4, 154242},
	{"RNSJ", 4, 154243},
	{"OZUN", 4, 154244},
	{"NFOD", 4, 154245},
	{"LJAS", 4, 154246},
	{"KREJ", 4, 154247},
	{"IMYA", 4, 154248},
	{"HLWI", 4, 154249},
	{"HDRY", 4, 154250},
	{"FJUA", 4, 154251},
	{"EKRY", 4, 154252},
	{"BYOM", 4, 154253},
	{"AZEF", 4, 154254},
	{"APYD", 4, 154255},
	{"RUFFIAN", 7, 154256},
	{"BOOKLISTS", 9, 154257},
	{"UNDETERRED", 10, 154258},
	{"TURKESTAN", 9, 154259},
	{"DARESBURY", 9, 154260},
	{"CHRO", 4, 154261},
	{"BALTHASAR", 9, 154262},
	{"LEFTWING", 8, 154263},
	{"PSSST", 5, 154264},
	{"NEWSMAN", 7, 154265},
	{"ARTIKELEN", 9, 154266},
	{"BOROSILICATE", 12, 154267},
	{"SAUNDRA", 7, 154268},
	{"AFFIXING", 8, 154269},
	{"DAYZ", 4, 154270},
	{"OURSELF", 7, 154271},
	{"AERATORS", 8, 154272},
	{"NEWW", 4, 154273},
	{"COLLEGAMENTI", 12, 154274},
	{"SBIG", 4, 154275},
	{"BALUN", 5, 154276},
	{"ERNAKULAM", 9, 154277},
	{"EFFERENT", 8, 154278},
	{"DOVONEX", 7, 154279},
	{"RTTL", 4, 154280},
	{"ORCHESTRATIONS", 14, 154281},
	{"BGD", 3, 154282},
	{"KLAX", 4, 154283},
	{"CORRATEC", 8, 154284},
	{"JEMISON", 7, 154285},
	{"INVARIABLE", 10, 154286},
	{"CLUBBER", 7, 154287},
	{"DELANCEY", 8, 154288},
	{"ECONOLODGES", 11, 154289},
	{"INCLINES", 8, 154290},
	{"ESPANYOL", 8, 154291},
	{"BBP", 3, 154292},
	{"MARQUESAS", 9, 154293},
	{"REALIZAR", 8, 154294},
	{"BEEFS", 5, 154295},
	{"SPEYER", 6, 154296},
	{"SARMIENTO", 9, 154297},
	{"FESTIVUS", 8, 154298},
	{"SENDAK", 6, 154299},
	{"SOUTHEY", 7, 154300},
	{"CACHONDOS", 9, 154301},
	{"PATRONISING", 11, 154302},
	{"AHEARN", 6, 154303},
	{"VYUN", 4, 154304},
	{"UYAG", 4, 154305},
	{"UPUI", 4, 154306},
	{"UNOZ", 4, 154307},
	{"UBZE", 4, 154308},
	{"TYIC", 4, 154309},
	{"SZEL", 4, 154310},
	{"SMLO", 4, 154311},
	{"SKSG", 4, 154312},
	{"RREK", 4, 154313},
	{"RCLY", 4, 154314},
	{"QIRE", 4, 154315},
	{"OFSV", 4, 154316},
	{"MBDO", 4, 154317},
	{"MAOU", 4, 154318},
	{"KYGA", 4, 154319},
	{"KUSC", 4, 154320},
	{"KSSW", 4, 154321},
	{"KEIB", 4, 154322},
	{"JAKU", 4, 154323},
	{"IPPH", 4, 154324},
	{"IFYU", 4, 154325},
	{"GUWA", 4, 154326},
	{"GDAW", 4, 154327},
	{"FIMN", 4, 154328},
	{"FDEI", 4, 154329},
	{"COXC", 4, 154330},
	{"BACY", 4, 154331},
	{"AUTZ", 4, 154332},
	{"APHL", 4, 154333},
	{"MICROBLAZE", 10, 154334},
	{"GOREN", 5, 154335},
	{"SLIEMA", 6, 154336},
	{"MARYKNOLL", 9, 154337},
	{"EUROBAROMETER", 13, 154338},
	{"TRIIODOTHYRONINE", 16, 154339},
	{"IMPR", 4, 154340},
	{"INFOBASE", 8, 154341},
	{"PLAYE", 5, 154342},
	{"ARGP", 4, 154343},
	{"TENGGARA", 8, 154344},
	{"NLAISCRIPT", 10, 154345},
	{"GEEL", 4, 154346},
	{"COWPEA", 6, 154347},
	{"PCAT", 4, 154348},
	{"PARTITA", 7, 154349},
	{"VOICESTREAM", 11, 154350},
	{"SIMONSAYS", 9, 154351},
	{"RAIBLE", 6, 154352},
	{"PMDD", 4, 154353},
	{"ASPIRATE", 8, 154354},
	{"LDU", 3, 154355},
	{"CHOWDERS", 8, 154356},
	{"COHOES", 6, 154357},
	{"VARMINT", 7, 154358},
	{"DARRINGTON", 10, 154359},
	{"STACE", 5, 154360},
	{"CILIATE", 7, 154361},
	{"BIKEWAY", 7, 154362},
	{"TIMESLIPS", 9, 154363},
	{"BALLED", 6, 154364},
	{"PICOT", 5, 154365},
	{"FGCU", 4, 154366},
	{"MISHANDLED", 10, 154367},
	{"MORRISONS", 9, 154368},
	{"DARRAGH", 7, 154369},
	{"DATAFILES", 9, 154370},
	{"SQUEEGEES", 9, 154371},
	{"HYPATIA", 7, 154372},
	{"MIKKEL", 6, 154373},
	{"DECIPHERED", 10, 154374},
	{"ICER", 4, 154375},
	{"ZYAS", 4, 154376},
	{"XWOO", 4, 154377},
	{"XWAL", 4, 154378},
	{"WSUF", 4, 154379},
	{"WJAP", 4, 154380},
	{"WHYK", 4, 154381},
	{"TCYN", 4, 154382},
	{"RAVU", 4, 154383},
	{"OXPI", 4, 154384},
	{"OLBS", 4, 154385},
	{"MAMN", 4, 154386},
	{"LYMD", 4, 154387},
	{"FYHO", 4, 154388},
	{"ERSTELLT", 8, 154389},
	{"SHUDDERS", 8, 154390},
	{"REFE", 4, 154391},
	{"QUESADILLA", 10, 154392},
	{"ASIATICO", 8, 154393},
	{"RISHIKESH", 9, 154394},
	{"ALEXANDR", 8, 154395},
	{"GERNE", 5, 154396},
	{"KUTTA", 5, 154397},
	{"DEANGELO", 8, 154398},
	{"AKING", 5, 154399},
	{"ARDENTLY", 8, 154400},
	{"USEING", 6, 154401},
	{"ONEWAY", 6, 154402},
	{"CROISSANCE", 10, 154403},
	{"FAOM", 4, 154404},
	{"KERBY", 5, 154405},
	{"HOSTINGTECH", 11, 154406},
	{"BUBONIC", 7, 154407},
	{"NOACK", 5, 154408},
	{"MONEYDANCE", 10, 154409},
	{"KLINGONS", 8, 154410},
	{"FRYS", 4, 154411},
	{"SEEPED", 6, 154412},
	{"TURNSTILES", 10, 154413},
	{"MODELLO", 7, 154414},
	{"KAYAKO", 6, 154415},
	{"CRUMBLY", 7, 154416},
	{"WEEDON", 6, 154417},
	{"STEPCHILDREN", 12, 154418},
	{"GRANITIC", 8, 154419},
	{"RATTLESNAKES", 12, 154420},
	{"UNTRIED", 7, 154421},
	{"GREETZ", 6, 154422},
	{"LUISE", 5, 154423},
	{"FRANCOPHONIE", 12, 154424},
	{"MJM", 3, 154425},
	{"BEGONIAS", 8, 154426},
	{"CLOUDING", 8, 154427},
	{"MULVEY", 6, 154428},
	{"DPRG", 4, 154429},
	{"NARADA", 6, 154430},
	{"CORUNNA", 7, 154431},
	{"PAYNTER", 7, 154432},
	{"COPIAGUE", 8, 154433},
	{"HERLIHY", 7, 154434},
	{"TETONAS", 7, 154435},
	{"VERDEN", 6, 154436},
	{"RUGGEDNESS", 10, 154437},
	{"ENTEROCOCCI", 11, 154438},
	{"GUIDEPOSTS", 10, 154439},
	{"SPAYING", 7, 154440},
	{"LYNDSEY", 7, 154441},
	{"KEXP", 4, 154442},
	{"BRONCHUS", 8, 154443},
	{"GRACIELA", 8, 154444},
	{"YEAL", 4, 154445},
	{"VYEN", 4, 154446},
	{"UNPI", 4, 154447},
	{"TOWY", 4, 154448},
	{"TLID", 4, 154449},
	{"SOMP", 4, 154450},
	{"RCYP", 4, 154451},
	{"RAQM", 4, 154452},
	{"ONGX", 4, 154453},
	{"NZOW", 4, 154454},
	{"MRIF", 4, 154455},
	{"MDRY", 4, 154456},
	{"LBUZ", 4, 154457},
	{"KUPV", 4, 154458},
	{"HYLU", 4, 154459},
	{"HQUO", 4, 154460},
	{"FJUP", 4, 154461},
	{"DDBO", 4, 154462},
	{"CAPG", 4, 154463},
	{"BYZO", 4, 154464},
	{"MOBILEDIT", 9, 154465},
	{"JTABLE", 6, 154466},
	{"RGBA", 4, 154467},
	{"FORES", 5, 154468},
	{"INTRUDED", 8, 154469},
	{"KOMMENTARER", 11, 154470},
	{"CHRISTEL", 8, 154471},
	{"CEONEX", 6, 154472},
	{"ODFW", 4, 154473},
	{"SCRYING", 7, 154474},
	{"BORINGS", 7, 154475},
	{"TERMINOLOGICAL", 14, 154476},
	{"NEWLYN", 6, 154477},
	{"MARMADUKE", 9, 154478},
	{"JOBSON", 6, 154479},
	{"LOEWIS", 6, 154480},
	{"FUTUREQUEST", 11, 154481},
	{"DESTRUCTORS", 11, 154482},
	{"BETON", 5, 154483},
	{"CYCLER", 6, 154484},
	{"RULEMAKINGS", 11, 154485},
	{"TORRINI", 7, 154486},
	{"INUVIK", 6, 154487},
	{"HANDSHAKES", 10, 154488},
	{"WINSTONE", 8, 154489},
	{"AQHNA", 5, 154490},
	{"AIRCARD", 7, 154491},
	{"OFLOXACIN", 9, 154492},
	{"APPLEBAUM", 9, 154493},
	{"ADULTO", 6, 154494},
	{"TAMSIN", 6, 154495},
	{"KYPRIAKO", 8, 154496},
	{"VZW", 3, 154497},
	{"DIZIONARIO", 10, 154498},
	{"UNICARE", 7, 154499},
	{"LUANN", 5, 154500},
	{"GRAYSVILLE", 10, 154501},
	{"ROSSMAN", 7, 154502},
	{"BEACHY", 6, 154503},
	{"DJMAZE", 6, 154504},
	{"ASPHYXIATION", 12, 154505},
	{"SUNRESCUE", 9, 154506},
	{"SHACKLEFORD", 11, 154507},
	{"FERENCES", 8, 154508},
	{"COPPICE", 7, 154509},
	{"VYGOTSKY", 8, 154510},
	{"HYUNG", 5, 154511},
	{"UMVO", 4, 154512},
	{"TZWO", 4, 154513},
	{"RXBO", 4, 154514},
	{"RSYH", 4, 154515},
	{"PYWE", 4, 154516},
	{"PGAL", 4, 154517},
	{"MMMI", 4, 154518},
	{"JILI", 4, 154519},
	{"ITMR", 4, 154520},
	{"HUJA", 4, 154521},
	{"HDOD", 4, 154522},
	{"GJAR", 4, 154523},
	{"GDUA", 4, 154524},
	{"FAAL", 4, 154525},
	{"BTYO", 4, 154526},
	{"OLVER", 5, 154527},
	{"DRUMCODE", 8, 154528},
	{"SILVERWOOD", 10, 154529},
	{"TRUEMAN", 7, 154530},
	{"CESME", 5, 154531},
	{"LAVONNE", 7, 154532},
	{"KDKA", 4, 154533},
	{"QUANAH", 6, 154534},
	{"LANDDICKE", 9, 154535},
	{"ZUNIGA", 6, 154536},
	{"AUTOCRACY", 9, 154537},
	{"YAOUNDE", 7, 154538},
	{"NESTLES", 7, 154539},
	{"SEPHARDI", 8, 154540},
	{"SONIDO", 6, 154541},
	{"BACKWARDNESS", 12, 154542},
	{"FIRSTPAGE", 9, 154543},
	{"INDIVIDUEL", 10, 154544},
	{"BLIZZCON", 8, 154545},
	{"JAMMIES", 7, 154546},
	{"BOOKBINDERS", 11, 154547},
	{"LRR", 3, 154548},
	{"UNDIMINISHED", 12, 154549},
	{"KAUKAUNA", 8, 154550},
	{"BLAISDELL", 9, 154551},
	{"GUAPO", 5, 154552},
	{"RHESTR", 6, 154553},
	{"MAZEL", 5, 154554},
	{"CAPUT", 5, 154555},
	{"UNFORCED", 8, 154556},
	{"DISAPPROVES", 11, 154557},
	{"TOWCESTER", 9, 154558},
	{"FONTES", 6, 154559},
	{"CESSFUL", 7, 154560},
	{"GALIL", 5, 154561},
	{"CONNAISSANCE", 12, 154562},
	{"ATTLEBOROUGH", 12, 154563},
	{"BOPPERS", 7, 154564},
	{"DISCOMFORTS", 11, 154565},
	{"GAGARIN", 7, 154566},
	{"GREYED", 6, 154567},
	{"JANJAWEED", 9, 154568},
	{"MANIK", 5, 154569},
	{"PUTENV", 6, 154570},
	{"FLWYDDYN", 8, 154571},
	{"SHRESTHA", 8, 154572},
	{"GUNDY", 5, 154573},
	{"XANTHAN", 7, 154574},
	{"GWERINIAETH", 11, 154575},
	{"SLEEPWALKING", 12, 154576},
	{"MACHIAVELLIAN", 13, 154577},
	{"CLAMMY", 6, 154578},
	{"ZIPL", 4, 154579},
	{"YPIX", 4, 154580},
	{"VVYA", 4, 154581},
	{"TEXW", 4, 154582},
	{"SGTM", 4, 154583},
	{"OKJO", 4, 154584},
	{"LEZT", 4, 154585},
	{"LERQ", 4, 154586},
	{"KOSB", 4, 154587},
	{"HUCO", 4, 154588},
	{"GNOG", 4, 154589},
	{"GDPR", 4, 154590},
	{"EGPU", 4, 154591},
	{"DYUA", 4, 154592},
	{"DURD", 4, 154593},
	{"DEZR", 4, 154594},
	{"CYPU", 4, 154595},
	{"AFWI", 4, 154596},
	{"DISCUSSANTS", 11, 154597},
	{"CHARNEY", 7, 154598},
	{"GOOGLW", 6, 154599},
	{"LALOR", 5, 154600},
	{"FINNIE", 6, 154601},
	{"TACOM", 5, 154602},
	{"IMARI", 5, 154603},
	{"CMAJ", 4, 154604},
	{"MULTIFORME", 10, 154605},
	{"HOMINIDS", 8, 154606},
	{"CORNINGWARE", 11, 154607},
	{"MISDIRECTION", 12, 154608},
	{"AQUISITION", 10, 154609},
	{"JAVASPACES", 10, 154610},
	{"CHOLECYSTITIS", 13, 154611},
	{"EPYDOC", 6, 154612},
	{"WOCHENEND", 9, 154613},
	{"MONTECATINI", 11, 154614},
	{"FOOTBAL", 7, 154615},
	{"VELIT", 5, 154616},
	{"TRIVEDI", 7, 154617},
	{"PPRULE", 6, 154618},
	{"NAHANT", 6, 154619},
	{"SLAYINGS", 8, 154620},
	{"PEAVY", 5, 154621},
	{"EFECTOS", 7, 154622},
	{"SOUTHWOLD", 9, 154623},
	{"BISPHENOL", 9, 154624},
	{"ROUTH", 5, 154625},
	{"NOVATOR", 7, 154626},
	{"REFERENCIA", 10, 154627},
	{"GOOFING", 7, 154628},
	{"ENCUESTA", 8, 154629},
	{"PHASEOLUS", 9, 154630},
	{"GRUNWALD", 8, 154631},
	{"ADUL", 4, 154632},
	{"CAPTAINED", 9, 154633},
	{"NAMBE", 5, 154634},
	{"KANU", 4, 154635},
	{"REIFICATION", 11, 154636},
	{"INDISPUTABLY", 12, 154637},
	{"XTYT", 4, 154638},
	{"WNOC", 4, 154639},
	{"VILJ", 4, 154640},
	{"UMNL", 4, 154641},
	{"TVDI", 4, 154642},
	{"TJAG", 4, 154643},
	{"RLGU", 4, 154644},
	{"PRCO", 4, 154645},
	{"PIAG", 4, 154646},
	{"MRFA", 4, 154647},
	{"LKUR", 4, 154648},
	{"KKAK", 4, 154649},
	{"ILWR", 4, 154650},
	{"GNCL", 4, 154651},
	{"GCOB", 4, 154652},
	{"FZEL", 4, 154653},
	{"EJOG", 4, 154654},
	{"DKIP", 4, 154655},
	{"CURC", 4, 154656},
	{"BORV", 4, 154657},
	{"AUDM", 4, 154658},
	{"DHCLIENT", 8, 154659},
	{"WIKISOURCE", 10, 154660},
	{"FLUOROSCOPY", 11, 154661},
	{"FILSON", 6, 154662},
	{"EBER", 4, 154663},
	{"ECHOCARDIOGRAPHIC", 17, 154664},
	{"COMPLETAMENTE", 13, 154665},
	{"RIFLED", 6, 154666},
	{"INNOVISION", 10, 154667},
	{"HEADZ", 5, 154668},
	{"AMUNDSON", 8, 154669},
	{"WITHHOLDS", 9, 154670},
	{"WESTPOINT", 9, 154671},
	{"CANCELABLE", 10, 154672},
	{"HOUSEPLANT", 10, 154673},
	{"MAASS", 5, 154674},
	{"BAKI", 4, 154675},
	{"MEGLIO", 6, 154676},
	{"DESICCATION", 11, 154677},
	{"STICKLEY", 8, 154678},
	{"DEFUSING", 8, 154679},
	{"FRESCA", 6, 154680},
	{"HELVETIA", 8, 154681},
	{"LAMOND", 6, 154682},
	{"ACERBIC", 7, 154683},
	{"BITARTRATE", 10, 154684},
	{"TOEVOEGEN", 9, 154685},
	{"THURROTT", 8, 154686},
	{"ENTRANSIT", 9, 154687},
	{"DOPEXVII", 8, 154688},
	{"GENERALISATIONS", 15, 154689},
	{"KAZUHIRO", 8, 154690},
	{"BLACKBEARD", 10, 154691},
	{"NAVIGON", 7, 154692},
	{"KITAB", 5, 154693},
	{"BEECHCRAFT", 10, 154694},
	{"BONNERS", 7, 154695},
	{"MALAYAN", 7, 154696},
	{"DEISM", 5, 154697},
	{"RFIO", 4, 154698},
	{"OVERCHARGES", 11, 154699},
	{"ALONGWITH", 9, 154700},
	{"BROWED", 6, 154701},
	{"SUBENTRY", 8, 154702},
	{"ONCP", 4, 154703},
	{"NRPG", 4, 154704},
	{"NODY", 4, 154705},
	{"MMOK", 4, 154706},
	{"LEDX", 4, 154707},
	{"KAMR", 4, 154708},
	{"JYOT", 4, 154709},
	{"GKRI", 4, 154710},
	{"FOBL", 4, 154711},
	{"EKEW", 4, 154712},
	{"DYAU", 4, 154713},
	{"CHTF", 4, 154714},
	{"CECD", 4, 154715},
	{"SURVIVABLE", 10, 154716},
	{"POMERANIA", 9, 154717},
	{"DALER", 5, 154718},
	{"PHENOLOGY", 9, 154719},
	{"WITHING", 7, 154720},
	{"PRAGMATIST", 10, 154721},
	{"GAITED", 6, 154722},
	{"BOGEYS", 6, 154723},
	{"CSCO", 4, 154724},
	{"SIDDHARTH", 9, 154725},
	{"SKITOWN", 7, 154726},
	{"LARKINS", 7, 154727},
	{"BRIANNE", 7, 154728},
	{"PERREAULT", 9, 154729},
	{"LATTERLY", 8, 154730},
	{"BIBLER", 6, 154731},
	{"MILLISEC", 8, 154732},
	{"GBICS", 5, 154733},
	{"SAUCEPANS", 9, 154734},
	{"DRIZZLED", 8, 154735},
	{"ECOUTE", 6, 154736},
	{"BTRC", 4, 154737},
	{"FAIRCLOUGH", 10, 154738},
	{"GOETTINGEN", 10, 154739},
	{"FLOGGED", 7, 154740},
	{"DISADVANTAGEOUS", 15, 154741},
	{"BANDGAP", 7, 154742},
	{"OUTFALLS", 8, 154743},
	{"CRAIGS", 6, 154744},
	{"DRABBLE", 7, 154745},
	{"FESTS", 5, 154746},
	{"SENDMESSAGE", 11, 154747},
	{"HOPPIN", 6, 154748},
	{"DISPELS", 7, 154749},
	{"BOOKKEEPERS", 11, 154750},
	{"BENCHLEY", 8, 154751},
	{"ARKIVET", 7, 154752},
	{"KNACKS", 6, 154753},
	{"ALIFE", 5, 154754},
	{"MCCLINTON", 9, 154755},
	{"SUBSCALE", 8, 154756},
	{"EVENTDATE", 9, 154757},
	{"FLAGELLA", 8, 154758},
	{"VFB", 3, 154759},
	{"PLAYMATS", 8, 154760},
	{"COHAN", 5, 154761},
	{"YABY", 4, 154762},
	{"XYMO", 4, 154763},
	{"UXKL", 4, 154764},
	{"UGHZ", 4, 154765},
	{"RAKB", 4, 154766},
	{"NKKE", 4, 154767},
	{"MAXL", 4, 154768},
	{"LUKO", 4, 154769},
	{"LHOG", 4, 154770},
	{"KYSS", 4, 154771},
	{"KUSW", 4, 154772},
	{"KUPN", 4, 154773},
	{"GHUE", 4, 154774},
	{"EPTK", 4, 154775},
	{"EILR", 4, 154776},
	{"DDFR", 4, 154777},
	{"AKSG", 4, 154778},
	{"MDAC", 4, 154779},
	{"UFCW", 4, 154780},
	{"SUBITEM", 7, 154781},
	{"DIETAS", 6, 154782},
	{"PREFERING", 9, 154783},
	{"QUILLEN", 7, 154784},
	{"HEMANGIOMA", 10, 154785},
	{"LOEFFLER", 8, 154786},
	{"CWF", 3, 154787},
	{"PAYNESVILLE", 11, 154788},
	{"SCHERTZ", 7, 154789},
	{"PHILOLOGICAL", 12, 154790},
	{"LIBERTEL", 8, 154791},
	{"UPB", 3, 154792},
	{"EPISHS", 6, 154793},
	{"CCNMATTHEWS", 11, 154794},
	{"WAGTAIL", 7, 154795},
	{"CHINAS", 6, 154796},
	{"CASITAS", 7, 154797},
	{"NEWSTALK", 8, 154798},
	{"IMMOKALEE", 9, 154799},
	{"BUELLTON", 8, 154800},
	{"STYLO", 5, 154801},
	{"JSPWIKI", 7, 154802},
	{"SAMIRA", 6, 154803},
	{"RUMINATE", 8, 154804},
	{"BALCHIK", 7, 154805},
	{"ENAMOURED", 9, 154806},
	{"UNPALATABLE", 11, 154807},
	{"BRINSON", 7, 154808},
	{"MJR", 3, 154809},
	{"KAYTEE", 6, 154810},
	{"JAMELIA", 7, 154811},
	{"MONEYSAVING", 11, 154812},
	{"SHRUGGING", 9, 154813},
	{"EUROTRIP", 8, 154814},
	{"SOMEWAY", 7, 154815},
	{"OVERNET", 7, 154816},
	{"SIGCOMM", 7, 154817},
	{"DISSE", 5, 154818},
	{"NEUTRALIZES", 11, 154819},
	{"PERSISTENCY", 11, 154820},
	{"MAINMENU", 8, 154821},
	{"BIRACIAL", 8, 154822},
	{"SARKOZY", 7, 154823},
	{"CONSCRIPTS", 10, 154824},
	{"DAYSINN", 7, 154825},
	{"HAIRSTYLIST", 11, 154826},
	{"PROPAGANDIST", 12, 154827},
	{"SHYLA", 5, 154828},
	{"LEATHERWORKING", 14, 154829},
	{"TTYK", 4, 154830},
	{"TKMW", 4, 154831},
	{"OFFQ", 4, 154832},
	{"MOSR", 4, 154833},
	{"MEUT", 4, 154834},
	{"LSGL", 4, 154835},
	{"KAGG", 4, 154836},
	{"HREJ", 4, 154837},
	{"HMEF", 4, 154838},
	{"ERCF", 4, 154839},
	{"DUGT", 4, 154840},
	{"ANXB", 4, 154841},
	{"AHLW", 4, 154842},
	{"MARRINER", 8, 154843},
	{"RESTRNT", 7, 154844},
	{"PARTICK", 7, 154845},
	{"SCHMIEG", 7, 154846},
	{"BLOODLUST", 9, 154847},
	{"TOPLOAD", 7, 154848},
	{"BORGESS", 7, 154849},
	{"GUILDERLAND", 11, 154850},
	{"BRUNEAU", 7, 154851},
	{"YASUHIRO", 8, 154852},
	{"DANGERDAVE", 10, 154853},
	{"CHIMERAS", 8, 154854},
	{"SUNSPECS", 8, 154855},
	{"MULGREW", 7, 154856},
	{"LOMANI", 6, 154857},
	{"DICHLOROBENZENE", 15, 154858},
	{"MALAN", 5, 154859},
	{"CATTAIL", 7, 154860},
	{"TAHUN", 5, 154861},
	{"HUMIDIFICATION", 14, 154862},
	{"YITZCHAK", 8, 154863},
	{"REPUBLIKY", 9, 154864},
	{"ANTEPRIME", 9, 154865},
	{"FLUTIST", 7, 154866},
	{"DUALISTIC", 9, 154867},
	{"BEFITS", 6, 154868},
	{"YOGIS", 5, 154869},
	{"MANDALAS", 8, 154870},
	{"WHOPPERS", 8, 154871},
	{"INSTANTS", 8, 154872},
	{"STRATED", 7, 154873},
	{"DIVYA", 5, 154874},
	{"DENUNCIATIONS", 13, 154875},
	{"DECREMENTS", 10, 154876},
	{"HORTONS", 7, 154877},
	{"RASPY", 5, 154878},
	{"PERVADE", 7, 154879},
	{"LUAN", 4, 154880},
	{"STYLEVENUE", 10, 154881},
	{"BLEDEL", 6, 154882},
	{"GALERKIN", 8, 154883},
	{"CONTEXTUALLY", 12, 154884},
	{"YORICK", 6, 154885},
	{"XRP", 3, 154886},
	{"SUBCUTANEOUSLY", 14, 154887},
	{"KYAW", 4, 154888},
	{"SCALERS", 7, 154889},
	{"TIMAGE", 6, 154890},
	{"OVOID", 5, 154891},
	{"ENDARTERECTOMY", 14, 154892},
	{"IMBUE", 5, 154893},
	{"REDISTRIBUTABLE", 15, 154894},
	{"ENTRAPPED", 9, 154895},
	{"VERSICOLOR", 10, 154896},
	{"SHOPTALK", 8, 154897},
	{"LAMAN", 5, 154898},
	{"YDRM", 4, 154899},
	{"ULIW", 4, 154900},
	{"RKGL", 4, 154901},
	{"RCZA", 4, 154902},
	{"MIAG", 4, 154903},
	{"MAIF", 4, 154904},
	{"JIDA", 4, 154905},
	{"IFCE", 4, 154906},
	{"GHUT", 4, 154907},
	{"ESPF", 4, 154908},
	{"EOKU", 4, 154909},
	{"EKGE", 4, 154910},
	{"EDBP", 4, 154911},
	{"DZOR", 4, 154912},
	{"DFAY", 4, 154913},
	{"CAGI", 4, 154914},
	{"AMBC", 4, 154915},
	{"COLLOQUE", 8, 154916},
	{"SUERTE", 6, 154917},
	{"AUTOREN", 7, 154918},
	{"GIRAUD", 6, 154919},
	{"PERESTROIKA", 11, 154920},
	{"BERNDES", 7, 154921},
	{"APACHES", 7, 154922},
	{"FWEND", 5, 154923},
	{"ANAPHASE", 8, 154924},
	{"APERIODIC", 9, 154925},
	{"PROXIED", 7, 154926},
	{"TSUBO", 5, 154927},
	{"DEVELOPPED", 10, 154928},
	{"RESIDENSE", 9, 154929},
	{"GETPROPERTY", 11, 154930},
	{"ARCHDUKE", 8, 154931},
	{"REDISTRIBUTIVE", 14, 154932},
	{"COWTOWN", 7, 154933},
	{"CAMPERDOWN", 10, 154934},
	{"POTEMKIN", 8, 154935},
	{"MIPT", 4, 154936},
	{"COMISKEY", 8, 154937},
	{"EUREF", 5, 154938},
	{"BENGE", 5, 154939},
	{"SLAGS", 5, 154940},
	{"MARKLIN", 7, 154941},
	{"MYRIADS", 7, 154942},
	{"AMPALIAN", 8, 154943},
	{"PHYSIOLOGISTS", 13, 154944},
	{"SURFEN", 6, 154945},
	{"ROCHON", 6, 154946},
	{"FARMWORKER", 10, 154947},
	{"CUPAR", 5, 154948},
	{"KUEHN", 5, 154949},
	{"GAJIM", 5, 154950},
	{"BETTERCARING", 12, 154951},
	{"WENDERS", 7, 154952},
	{"CHEB", 4, 154953},
	{"PHYTOESTROGENS", 14, 154954},
	{"TROMBONIST", 10, 154955},
	{"CYTOMETRIC", 10, 154956},
	{"BRONCHIOLITIS", 13, 154957},
	{"PARKOUR", 7, 154958},
	{"DIARIST", 7, 154959},
	{"EGOTISM", 7, 154960},
	{"SPANO", 5, 154961},
	{"ZIAR", 4, 154962},
	{"YRSO", 4, 154963},
	{"YRRE", 4, 154964},
	{"YMPL", 4, 154965},
	{"YEDQ", 4, 154966},
	{"SIDB", 4, 154967},
	{"RIPN", 4, 154968},
	{"OBSK", 4, 154969},
	{"NDPF", 4, 154970},
	{"NBCD", 4, 154971},
	{"MPOC", 4, 154972},
	{"KSLU", 4, 154973},
	{"IYAJ", 4, 154974},
	{"HBOG", 4, 154975},
	{"FOWA", 4, 154976},
	{"DDME", 4, 154977},
	{"DCWI", 4, 154978},
	{"COBT", 4, 154979},
	{"ALPHEN", 6, 154980},
	{"YUNUS", 5, 154981},
	{"YUME", 4, 154982},
	{"WAPPING", 7, 154983},
	{"GRUPPI", 6, 154984},
	{"BOLLER", 6, 154985},
	{"HATCHLINGS", 10, 154986},
	{"NONCONFORMITY", 13, 154987},
	{"FAUSTFICKEN", 11, 154988},
	{"PRONOUNCIATION", 14, 154989},
	{"MACNEILL", 8, 154990},
	{"SERVICERS", 9, 154991},
	{"LLUN", 4, 154992},
	{"RUSTICA", 7, 154993},
	{"MOTHERLESS", 10, 154994},
	{"MAGTEK", 6, 154995},
	{"WESTRIDGE", 9, 154996},
	{"INTERCONNECTIVITY", 17, 154997},
	{"DUKANE", 6, 154998},
	{"SUPERFLUID", 10, 154999},
	{"PLACINGS", 8, 155000},
	{"MARGARITAVILLE", 14, 155001},
	{"FOGHORN", 7, 155002},
	{"GENIO", 5, 155003},
	{"IFSP", 4, 155004},
	{"CMFPLONE", 8, 155005},
	{"QSAR", 4, 155006},
	{"TRANSFERASES", 12, 155007},
	{"KERATITIS", 9, 155008},
	{"BARWON", 6, 155009},
	{"RUMMEL", 6, 155010},
	{"SVELTE", 6, 155011},
	{"AFFIXES", 7, 155012},
	{"BRAINPOWER", 10, 155013},
	{"SHELLCODE", 9, 155014},
	{"WHEEZE", 6, 155015},
	{"INVISALIGN", 10, 155016},
	{"EDERSEE", 7, 155017},
	{"BOOTYLICIOUS", 12, 155018},
	{"NEWZEALAND", 10, 155019},
	{"FILEY", 5, 155020},
	{"ROSETOWN", 8, 155021},
	{"OGRES", 5, 155022},
	{"SMASHER", 7, 155023},
	{"WALLOPS", 7, 155024},
	{"NVIRONMENTAL", 12, 155025},
	{"TRIGEM", 6, 155026},
	{"TIBERIAS", 8, 155027},
	{"LONGISH", 7, 155028},
	{"HORDEUM", 7, 155029},
	{"FOCACCIA", 8, 155030},
	{"YAKK", 4, 155031},
	{"TZDI", 4, 155032},
	{"SJIL", 4, 155033},
	{"PJON", 4, 155034},
	{"OLWR", 4, 155035},
	{"NEZC", 4, 155036},
	{"NDDN", 4, 155037},
	{"NCBE", 4, 155038},
	{"LAMG", 4, 155039},
	{"KOOF", 4, 155040},
	{"JRAS", 4, 155041},
	{"FTTW", 4, 155042},
	{"EBWO", 4, 155043},
	{"DRCI", 4, 155044},
	{"COLJ", 4, 155045},
	{"CLYM", 4, 155046},
	{"CAEV", 4, 155047},
	{"BCHR", 4, 155048},
	{"AFUC", 4, 155049},
	{"SOMALIS", 7, 155050},
	{"POLLITT", 7, 155051},
	{"KFAR", 4, 155052},
	{"ANGIOGRAM", 9, 155053},
	{"COUNTYBLOCKMAP", 14, 155054},
	{"MAUNGANUI", 9, 155055},
	{"YARDER", 6, 155056},
	{"DLCTIONARY", 10, 155057},
	{"ELARA", 5, 155058},
	{"LAKEWAY", 7, 155059},
	{"STROUP", 6, 155060},
	{"ARNALDO", 7, 155061},
	{"GOLDBLATT", 9, 155062},
	{"FLATWOODS", 9, 155063},
	{"VARICES", 7, 155064},
	{"GATLING", 7, 155065},
	{"CHALDEAN", 8, 155066},
	{"AUCK", 4, 155067},
	{"THYRISTOR", 9, 155068},
	{"EPROCUREMENT", 12, 155069},
	{"DANCY", 5, 155070},
	{"EUROCOPTER", 10, 155071},
	{"AVIDLY", 6, 155072},
	{"XTSETARG", 8, 155073},
	{"GOLDRING", 8, 155074},
	{"COMEDIE", 7, 155075},
	{"GEOVISION", 9, 155076},
	{"HEADMISTRESS", 12, 155077},
	{"SHOWPIECE", 9, 155078},
	{"PRAIZE", 6, 155079},
	{"TITTENBILDER", 12, 155080},
	{"CONFECTIONER", 12, 155081},
	{"STARTIN", 7, 155082},
	{"FASTCLICK", 9, 155083},
	{"BIONDI", 6, 155084},
	{"KRACKER", 7, 155085},
	{"MLG", 3, 155086},
	{"LOUDMOUTH", 9, 155087},
	{"MOHICAN", 7, 155088},
	{"DELCAM", 6, 155089},
	{"WFU", 3, 155090},
	{"RECIPROCATED", 12, 155091},
	{"KATATONIA", 9, 155092},
	{"SWEATBAND", 9, 155093},
	{"BRABUS", 6, 155094},
	{"SQUABBLES", 9, 155095},
	{"EOSINOPHILIA", 12, 155096},
	{"AILSA", 5, 155097},
	{"DEUSX", 5, 155098},
	{"HEFEI", 5, 155099},
	{"VACT", 4, 155100},
	{"SZAB", 4, 155101},
	{"NPCO", 4, 155102},
	{"NDGS", 4, 155103},
	{"IUSZ", 4, 155104},
	{"IFHU", 4, 155105},
	{"GEMD", 4, 155106},
	{"EGSL", 4, 155107},
	{"DHIW", 4, 155108},
	{"JOURNALERS", 10, 155109},
	{"MATERIALIZES", 12, 155110},
	{"BUFFOON", 7, 155111},
	{"ICONOTEC", 8, 155112},
	{"ALLENAYRES", 10, 155113},
	{"RECOUPMENT", 10, 155114},
	{"ACHY", 4, 155115},
	{"CHRISTIANSTED", 13, 155116},
	{"TILLED", 6, 155117},
	{"SEDUCTIVELY", 11, 155118},
	{"SCHLOSSDICKE", 12, 155119},
	{"LURGAN", 6, 155120},
	{"SKULLE", 6, 155121},
	{"POETICA", 7, 155122},
	{"NETSCALER", 9, 155123},
	{"NABU", 4, 155124},
	{"CERTIFI", 7, 155125},
	{"REPRESENTABLE", 13, 155126},
	{"GETHITS", 7, 155127},
	{"ANTIQUING", 9, 155128},
	{"RUMBLED", 7, 155129},
	{"TOCHIGI", 7, 155130},
	{"CARVEY", 6, 155131},
	{"MISTERY", 7, 155132},
	{"MITTEL", 6, 155133},
	{"UNALIENABLE", 11, 155134},
	{"BOWRAL", 6, 155135},
	{"AMBOS", 5, 155136},
	{"UWP", 3, 155137},
	{"MUQTADA", 7, 155138},
	{"GOOGAL", 6, 155139},
	{"WEEDED", 6, 155140},
	{"GRANADOS", 8, 155141},
	{"DISOBEYING", 10, 155142},
	{"CTIVE", 5, 155143},
	{"BISSET", 6, 155144},
	{"IBATIS", 6, 155145},
	{"KRUSKAL", 7, 155146},
	{"PSYCHOPHYSICS", 13, 155147},
	{"GALLU", 5, 155148},
	{"HEARTSTRINGS", 12, 155149},
	{"SQLSTATE", 8, 155150},
	{"GIGGS", 5, 155151},
	{"BSTR", 4, 155152},
	{"OJIBWE", 6, 155153},
	{"LZW", 3, 155154},
	{"ARUM", 4, 155155},
	{"ABFD", 4, 155156},
	{"DRUSILLA", 8, 155157},
	{"SIDON", 5, 155158},
	{"LANGLADE", 8, 155159},
	{"ZYFO", 4, 155160},
	{"UMIB", 4, 155161},
	{"SECM", 4, 155162},
	{"SBNW", 4, 155163},
	{"RVIB", 4, 155164},
	{"NUWH", 4, 155165},
	{"LLCT", 4, 155166},
	{"KHEG", 4, 155167},
	{"JEVA", 4, 155168},
	{"EPBI", 4, 155169},
	{"EDZU", 4, 155170},
	{"DJPM", 4, 155171},
	{"DAWF", 4, 155172},
	{"BOFK", 4, 155173},
	{"AJDA", 4, 155174},
	{"ADZA", 4, 155175},
	{"EXHIB", 5, 155176},
	{"BHANDARI", 8, 155177},
	{"HONEYPOTS", 9, 155178},
	{"BACKOFF", 7, 155179},
	{"OUTSOURCERS", 11, 155180},
	{"ACRID", 5, 155181},
	{"MYVILLARENTERS", 14, 155182},
	{"DIJO", 4, 155183},
	{"MAINSTAGE", 9, 155184},
	{"UNINHABITABLE", 13, 155185},
	{"NONSTRUCTURAL", 13, 155186},
	{"MONTSOURIS", 10, 155187},
	{"WJLA", 4, 155188},
	{"REBREATHER", 10, 155189},
	{"EGALLERY", 8, 155190},
	{"IMPRIMANTE", 10, 155191},
	{"FORCLOSURE", 10, 155192},
	{"SAILNET", 7, 155193},
	{"CHARI", 5, 155194},
	{"KACZYNSKI", 9, 155195},
	{"BRASSY", 6, 155196},
	{"TRESPASSES", 10, 155197},
	{"ITEXT", 5, 155198},
	{"MATEY", 5, 155199},
	{"HELPU", 5, 155200},
	{"QUARTILES", 9, 155201},
	{"CONVERSED", 9, 155202},
	{"XINDICE", 7, 155203},
	{"LEATHERFACE", 11, 155204},
	{"UNDERSTATE", 10, 155205},
	{"ALPHECCA", 8, 155206},
	{"GRAVATT", 7, 155207},
	{"RELICENSING", 11, 155208},
	{"INGENIOUSLY", 11, 155209},
	{"HOGY", 4, 155210},
	{"FLORIBUNDA", 10, 155211},
	{"PREUSS", 6, 155212},
	{"COWART", 6, 155213},
	{"BONIFACIO", 9, 155214},
	{"ROOTSTOCK", 9, 155215},
	{"PENNDOT", 7, 155216},
	{"IMPRECISION", 11, 155217},
	{"BACKSCAT", 8, 155218},
	{"POLYOMAVIRUS", 12, 155219},
	{"SNARF", 5, 155220},
	{"HOSTALES", 8, 155221},
	{"TEORIA", 6, 155222},
	{"BALCK", 5, 155223},
	{"REENABLE", 8, 155224},
	{"ISOSPIN", 7, 155225},
	{"BAGRAM", 6, 155226},
	{"SIMONTON", 8, 155227},
	{"ZISL", 4, 155228},
	{"YJRA", 4, 155229},
	{"XTAK", 4, 155230},
	{"TUCA", 4, 155231},
	{"RVYN", 4, 155232},
	{"RKOO", 4, 155233},
	{"REXW", 4, 155234},
	{"NYYA", 4, 155235},
	{"MNGO", 4, 155236},
	{"JAVO", 4, 155237},
	{"GGSD", 4, 155238},
	{"FMBA", 4, 155239},
	{"ERKP", 4, 155240},
	{"DOLH", 4, 155241},
	{"DABH", 4, 155242},
	{"BWAR", 4, 155243},
	{"ABDO", 4, 155244},
	{"FOCUSER", 7, 155245},
	{"ATTACHURLPATH", 13, 155246},
	{"KAHLE", 5, 155247},
	{"SPROUSE", 7, 155248},
	{"HOWITT", 6, 155249},
	{"CONCHITA", 8, 155250},
	{"REPU", 4, 155251},
	{"SANFRANCISCO", 12, 155252},
	{"EMSWORTH", 8, 155253},
	{"OSTEOBLASTS", 11, 155254},
	{"COMMUNITARIAN", 13, 155255},
	{"SEGYE", 5, 155256},
	{"LOTHROP", 7, 155257},
	{"COUNTERBALANCED", 15, 155258},
	{"MAKENA", 6, 155259},
	{"RIFLESCOPE", 10, 155260},
	{"SISCO", 5, 155261},
	{"CALNE", 5, 155262},
	{"UNDERTAKERS", 11, 155263},
	{"TANGERINES", 10, 155264},
	{"LEEP", 4, 155265},
	{"OFFSUIT", 7, 155266},
	{"IGNATIEFF", 9, 155267},
	{"ROYA", 4, 155268},
	{"SCANDINAVICA", 12, 155269},
	{"PRICKED", 7, 155270},
	{"DHMOKRATIAS", 11, 155271},
	{"MORELLA", 7, 155272},
	{"PLOG", 4, 155273},
	{"NORTHING", 8, 155274},
	{"MOMSONFILM", 10, 155275},
	{"DCIST", 5, 155276},
	{"COPPERS", 7, 155277},
	{"CLUS", 4, 155278},
	{"DEADSPIN", 8, 155279},
	{"DUNTON", 6, 155280},
	{"BREMERHAVEN", 11, 155281},
	{"DISCOUNTER", 10, 155282},
	{"TITTENRESERVIERUNG", 18, 155283},
	{"EARTHWATCH", 10, 155284},
	{"FAECALIS", 8, 155285},
	{"OTORHINOLARYNGOLOGY", 19, 155286},
	{"PROCREATE", 9, 155287},
	{"DERAILS", 7, 155288},
	{"SMOLTS", 6, 155289},
	{"ARVATO", 6, 155290},
	{"OSREINSTALL", 11, 155291},
	{"DPU", 3, 155292},
	{"ZOBR", 4, 155293},
	{"XBLA", 4, 155294},
	{"ULOL", 4, 155295},
	{"TZAD", 4, 155296},
	{"TMRR", 4, 155297},
	{"TKLA", 4, 155298},
	{"QUAA", 4, 155299},
	{"PMOF", 4, 155300},
	{"NUTL", 4, 155301},
	{"MUDC", 4, 155302},
	{"LPSG", 4, 155303},
	{"ERQI", 4, 155304},
	{"DIMD", 4, 155305},
	{"BCSR", 4, 155306},
	{"HARDENER", 8, 155307},
	{"MYZ", 3, 155308},
	{"COOKSEY", 7, 155309},
	{"PATERNALISM", 11, 155310},
	{"ALIANT", 6, 155311},
	{"REDDENED", 8, 155312},
	{"MADINA", 6, 155313},
	{"UDINESE", 7, 155314},
	{"AIRWISE", 7, 155315},
	{"SURREALISTIC", 12, 155316},
	{"UBBTHREADS", 10, 155317},
	{"SUPERCLASSES", 12, 155318},
	{"MEASURABLY", 10, 155319},
	{"HYPERLINKING", 12, 155320},
	{"GLASSWERK", 9, 155321},
	{"EXHORTATIONS", 12, 155322},
	{"STRNCASECMP", 11, 155323},
	{"SUBBAND", 7, 155324},
	{"HAWKISH", 7, 155325},
	{"CASTELLS", 8, 155326},
	{"OBSTRUCTS", 9, 155327},
	{"BOWERMAN", 8, 155328},
	{"TONGE", 5, 155329},
	{"HINRICHS", 8, 155330},
	{"WHEREEVER", 9, 155331},
	{"CNOTES", 6, 155332},
	{"DULUG", 5, 155333},
	{"METALLOTHIONEIN", 15, 155334},
	{"RUAN", 4, 155335},
	{"FAVORITEN", 9, 155336},
	{"LARCALORIMETER", 14, 155337},
	{"BLINKERS", 8, 155338},
	{"FEXOFENADINE", 12, 155339},
	{"LEUK", 4, 155340},
	{"MAKA", 4, 155341},
	{"BIAGGI", 6, 155342},
	{"ALPSWEEK", 8, 155343},
	{"LOLLIES", 7, 155344},
	{"UPREGULATED", 11, 155345},
	{"WOHNUNG", 7, 155346},
	{"AGAINE", 6, 155347},
	{"FUREY", 5, 155348},
	{"AMADOU", 6, 155349},
	{"LEGIONNAIRE", 11, 155350},
	{"HIJOS", 5, 155351},
	{"GRANULOSA", 9, 155352},
	{"COSMICGIRL", 10, 155353},
	{"PLUMMETS", 8, 155354},
	{"ENCAUSTIC", 9, 155355},
	{"TDCI", 4, 155356},
	{"HOLDOVER", 8, 155357},
	{"HOWEY", 5, 155358},
	{"SWANSTON", 8, 155359},
	{"HEFFNER", 7, 155360},
	{"SLIKE", 5, 155361},
	{"HEALTHSCOUT", 11, 155362},
	{"XSPR", 4, 155363},
	{"VPCA", 4, 155364},
	{"VECD", 4, 155365},
	{"UIGN", 4, 155366},
	{"UCYD", 4, 155367},
	{"UAPO", 4, 155368},
	{"SLYJ", 4, 155369},
	{"RMLB", 4, 155370},
	{"RBIH", 4, 155371},
	{"PHME", 4, 155372},
	{"OMRY", 4, 155373},
	{"OCBS", 4, 155374},
	{"NGDN", 4, 155375},
	{"LDAE", 4, 155376},
	{"KOIV", 4, 155377},
	{"IAUP", 4, 155378},
	{"GUTF", 4, 155379},
	{"CAGN", 4, 155380},
	{"ABYK", 4, 155381},
	{"HONDAS", 6, 155382},
	{"BATRA", 5, 155383},
	{"SARCOPLASMIC", 12, 155384},
	{"ROTHBURY", 8, 155385},
	{"MICROANALYSIS", 13, 155386},
	{"ENERGISE", 8, 155387},
	{"RADEOX", 6, 155388},
	{"ONLONE", 6, 155389},
	{"COADY", 5, 155390},
	{"RENZI", 5, 155391},
	{"SUNWAY", 6, 155392},
	{"PRESSLER", 8, 155393},
	{"MACROINVERTEBRATES", 18, 155394},
	{"POULET", 6, 155395},
	{"ALMEN", 5, 155396},
	{"TITTENFINDER", 12, 155397},
	{"DECKERS", 7, 155398},
	{"BUTONZ", 6, 155399},
	{"OROLOGIO", 8, 155400},
	{"THATTHE", 7, 155401},
	{"ACTIONEVENT", 11, 155402},
	{"COLUMB", 6, 155403},
	{"CSCL", 4, 155404},
	{"BEBITS", 6, 155405},
	{"BANKSIDE", 8, 155406},
	{"KAVI", 4, 155407},
	{"EAKINS", 6, 155408},
	{"GEBRAUCHTE", 10, 155409},
	{"LIBXI", 5, 155410},
	{"REBUILDER", 9, 155411},
	{"LYDA", 4, 155412},
	{"DEGENERATES", 11, 155413},
	{"RUTILE", 6, 155414},
	{"HEMISPHERICAL", 13, 155415},
	{"DEMEANOUR", 9, 155416},
	{"KEMI", 4, 155417},
	{"HEIMER", 6, 155418},
	{"VOYETRA", 7, 155419},
	{"REQUIRMENTS", 11, 155420},
	{"JAYDE", 5, 155421},
	{"WOID", 4, 155422},
	{"VELZ", 4, 155423},
	{"VDEC", 4, 155424},
	{"UKSO", 4, 155425},
	{"TPUZ", 4, 155426},
	{"ONBJ", 4, 155427},
	{"OECR", 4, 155428},
	{"NHLW", 4, 155429},
	{"LPID", 4, 155430},
	{"GYEV", 4, 155431},
	{"EPDU", 4, 155432},
	{"ENRC", 4, 155433},
	{"EICU", 4, 155434},
	{"EGBY", 4, 155435},
	{"ABEP", 4, 155436},
	{"PAPYRI", 6, 155437},
	{"PRIFYSGOL", 9, 155438},
	{"FASTR", 5, 155439},
	{"MILAGRO", 7, 155440},
	{"BROADSIDES", 10, 155441},
	{"MISOGYNY", 8, 155442},
	{"ARTICULATORY", 12, 155443},
	{"LIPP", 4, 155444},
	{"INITIA", 6, 155445},
	{"CLOSETED", 8, 155446},
	{"PARENS", 6, 155447},
	{"KRENTZ", 6, 155448},
	{"FIBULA", 6, 155449},
	{"BOVEY", 5, 155450},
	{"PROGRAME", 8, 155451},
	{"DEFENSA", 7, 155452},
	{"CATEDRAL", 8, 155453},
	{"IDEALO", 6, 155454},
	{"EZGAS", 5, 155455},
	{"NOTCHING", 8, 155456},
	{"MEGAMI", 6, 155457},
	{"SULFONIC", 8, 155458},
	{"MITTEILUNGEN", 12, 155459},
	{"EXCRUCIATINGLY", 14, 155460},
	{"INDOCTRINATED", 13, 155461},
	{"SCHELLING", 9, 155462},
	{"JAROMIR", 7, 155463},
	{"TYPEERROR", 9, 155464},
	{"PEJA", 4, 155465},
	{"LUCAYA", 6, 155466},
	{"UNCEREMONIOUSLY", 15, 155467},
	{"EUPHEMISMS", 10, 155468},
	{"NADEEM", 6, 155469},
	{"LEMAR", 5, 155470},
	{"MAGLI", 5, 155471},
	{"MESSAGESLOGIN", 13, 155472},
	{"MEHROTRA", 8, 155473},
	{"DRAGONHEART", 11, 155474},
	{"HARTZELL", 8, 155475},
	{"SUNUNU", 6, 155476},
	{"MULTIPLICATIONS", 15, 155477},
	{"ARRY", 4, 155478},
	{"JINR", 4, 155479},
	{"HALVORSON", 9, 155480},
	{"GENUINENESS", 11, 155481},
	{"FREESERVE", 9, 155482},
	{"IMPOTENCY", 9, 155483},
	{"LEURA", 5, 155484},
	{"SCRIPTWRITING", 13, 155485},
	{"BUNGAY", 6, 155486},
	{"BILA", 4, 155487},
	{"ZIZA", 4, 155488},
	{"ZIDI", 4, 155489},
	{"YRIB", 4, 155490},
	{"XSUC", 4, 155491},
	{"XSPA", 4, 155492},
	{"WKIT", 4, 155493},
	{"VDES", 4, 155494},
	{"SKCH", 4, 155495},
	{"MSSY", 4, 155496},
	{"LVDA", 4, 155497},
	{"LSTD", 4, 155498},
	{"LPGU", 4, 155499},
	{"KKOS", 4, 155500},
	{"ECPO", 4, 155501},
	{"BBSF", 4, 155502},
	{"JAGO", 4, 155503},
	{"PPML", 4, 155504},
	{"ULY", 3, 155505},
	{"HIMSS", 5, 155506},
	{"PSEUDOCODE", 10, 155507},
	{"MANUVA", 6, 155508},
	{"GETCHA", 6, 155509},
	{"MONOMIAL", 8, 155510},
	{"MARQUAND", 8, 155511},
	{"KOZLOV", 6, 155512},
	{"POISSONS", 8, 155513},
	{"OEKAKI", 6, 155514},
	{"VESTIBULUM", 10, 155515},
	{"PAMPANGA", 8, 155516},
	{"MIDHURST", 8, 155517},
	{"VOLTE", 5, 155518},
	{"GLYCOLS", 7, 155519},
	{"VALDIVIA", 8, 155520},
	{"ATRIX", 5, 155521},
	{"GENECHIP", 8, 155522},
	{"PEEBLESSHIRE", 12, 155523},
	{"WINSHIP", 7, 155524},
	{"ZVV", 3, 155525},
	{"XVJ", 3, 155526},
	{"VXU", 3, 155527},
	{"QYD", 3, 155528},
	{"QWU", 3, 155529},
	{"QVP", 3, 155530},
	{"QLZ", 3, 155531},
	{"KVZ", 3, 155532},
	{"JQK", 3, 155533},
	{"JDQ", 3, 155534},
	{"DEMITASSE", 9, 155535},
	{"JIHADIST", 8, 155536},
	{"PALENCIA", 8, 155537},
	{"CNTL", 4, 155538},
	{"ZEROPAID", 8, 155539},
	{"BORONIA", 7, 155540},
	{"BALABAN", 7, 155541},
	{"WIRKLICH", 8, 155542},
	{"XTENSION", 8, 155543},
	{"SUSPIRIA", 8, 155544},
	{"PARSHALL", 8, 155545},
	{"COMAS", 5, 155546},
	{"NIACE", 5, 155547},
	{"CERMAK", 6, 155548},
	{"WHEATIES", 8, 155549},
	{"MUZAFFARABAD", 12, 155550},
	{"MARKOS", 6, 155551},
	{"FRICTIONLESS", 12, 155552},
	{"TURNOUTS", 8, 155553},
	{"HOSTAS", 6, 155554},
	{"BROUHAHA", 8, 155555},
	{"LEARNIN", 7, 155556},
	{"YFUM", 4, 155557},
	{"WUPM", 4, 155558},
	{"WDBE", 4, 155559},
	{"RLEL", 4, 155560},
	{"QHAV", 4, 155561},
	{"PDEE", 4, 155562},
	{"OYAK", 4, 155563},
	{"ODHY", 4, 155564},
	{"NJIR", 4, 155565},
	{"LHAJ", 4, 155566},
	{"LABM", 4, 155567},
	{"JWHO", 4, 155568},
	{"HIDU", 4, 155569},
	{"GPAO", 4, 155570},
	{"GOSY", 4, 155571},
	{"EEBB", 4, 155572},
	{"AYTY", 4, 155573},
	{"CRANNIES", 8, 155574},
	{"BLACKSPOT", 9, 155575},
	{"HOLON", 5, 155576},
	{"IMPACTOR", 8, 155577},
	{"VBOOKIE", 7, 155578},
	{"NAGLER", 6, 155579},
	{"SWITCHPLATES", 12, 155580},
	{"PKF", 3, 155581},
	{"BOORMAN", 7, 155582},
	{"LILUG", 5, 155583},
	{"COMENTS", 7, 155584},
	{"TENNENT", 7, 155585},
	{"TANKARDS", 8, 155586},
	{"PROSPERING", 10, 155587},
	{"OLCOTT", 6, 155588},
	{"REGALIS", 7, 155589},
	{"JOBUNIVERSE", 11, 155590},
	{"RITUXIMAB", 9, 155591},
	{"IMPULSIVITY", 11, 155592},
	{"DEARER", 6, 155593},
	{"MILLAY", 6, 155594},
	{"JBOD", 4, 155595},
	{"INCHED", 6, 155596},
	{"CHIAVE", 6, 155597},
	{"CIMS", 4, 155598},
	{"SAQUINAVIR", 10, 155599},
	{"RISQUES", 7, 155600},
	{"AGENCIAS", 8, 155601},
	{"AMORPHIS", 8, 155602},
	{"IMPLEMENTABLE", 13, 155603},
	{"FORESMAN", 8, 155604},
	{"ANTIFERROMAGNETIC", 17, 155605},
	{"KITAGAWA", 8, 155606},
	{"TONGRO", 6, 155607},
	{"UUUU", 4, 155608},
	{"CYBERIA", 7, 155609},
	{"FAMILLES", 8, 155610},
	{"HCRAES", 6, 155611},
	{"ABRSM", 5, 155612},
	{"SACC", 4, 155613},
	{"ASTURIAN", 8, 155614},
	{"MCCOMAS", 7, 155615},
	{"CAVO", 4, 155616},
	{"USEAST", 6, 155617},
	{"MARJA", 5, 155618},
	{"COAHUILA", 8, 155619},
	{"VAGAL", 5, 155620},
	{"FINEPRINT", 9, 155621},
	{"INSPIRATORY", 11, 155622},
	{"MINUTELY", 8, 155623},
	{"MOBYSCORE", 9, 155624},
	{"NINERS", 6, 155625},
	{"CRISTA", 6, 155626},
	{"FSTOP", 5, 155627},
	{"HEBERGEMENT", 11, 155628},
	{"SUPERSTRING", 11, 155629},
	{"FERAUD", 6, 155630},
	{"XDEBUG", 6, 155631},
	{"AMETUER", 7, 155632},
	{"SFONDI", 6, 155633},
	{"WIZCOM", 6, 155634},
	{"TEAMTRACK", 9, 155635},
	{"MINITOWER", 9, 155636},
	{"YTVA", 4, 155637},
	{"YKOT", 4, 155638},
	{"URSJ", 4, 155639},
	{"UOFP", 4, 155640},
	{"UOBV", 4, 155641},
	{"UKCA", 4, 155642},
	{"UBGO", 4, 155643},
	{"PVEN", 4, 155644},
	{"PSVA", 4, 155645},
	{"NHCR", 4, 155646},
	{"IHUM", 4, 155647},
	{"HMCL", 4, 155648},
	{"FZAM", 4, 155649},
	{"FYUN", 4, 155650},
	{"FRIF", 4, 155651},
	{"FHYB", 4, 155652},
	{"DOUM", 4, 155653},
	{"DKLI", 4, 155654},
	{"DAEG", 4, 155655},
	{"AYEU", 4, 155656},
	{"SEDITIOUS", 9, 155657},
	{"CHIFLEY", 7, 155658},
	{"EAUZONE", 7, 155659},
	{"SCHERERVILLE", 12, 155660},
	{"BAZA", 4, 155661},
	{"TIMBRES", 7, 155662},
	{"DELAMINATION", 12, 155663},
	{"WALKAROUND", 10, 155664},
	{"APPEXCHANGE", 11, 155665},
	{"TROTZ", 5, 155666},
	{"CHOUTEAU", 8, 155667},
	{"INARTICULATE", 12, 155668},
	{"FIBRO", 5, 155669},
	{"TURBA", 5, 155670},
	{"VERTAR", 6, 155671},
	{"HAFEZ", 5, 155672},
	{"YIWU", 4, 155673},
	{"POEME", 5, 155674},
	{"STRUDEL", 7, 155675},
	{"EMPTED", 6, 155676},
	{"HERZBERG", 8, 155677},
	{"BRUST", 5, 155678},
	{"GOOGLLE", 7, 155679},
	{"PUBLISHABLE", 11, 155680},
	{"DISASSEMBLER", 12, 155681},
	{"PROINFLAMMATORY", 15, 155682},
	{"APNOEA", 6, 155683},
	{"CORALIA", 7, 155684},
	{"GOODIN", 6, 155685},
	{"RAMEAU", 6, 155686},
	{"NAIPAUL", 7, 155687},
	{"BELTOON", 7, 155688},
	{"MILADY", 6, 155689},
	{"SILVERED", 8, 155690},
	{"PONTOONS", 8, 155691},
	{"PLING", 5, 155692},
	{"ELECTRONIX", 10, 155693},
	{"SCHLAFZIMMER", 12, 155694},
	{"ALARCON", 7, 155695},
	{"BINED", 5, 155696},
	{"CRISTY", 6, 155697},
	{"UNIGRAPHICS", 11, 155698},
	{"INKER", 5, 155699},
	{"HYPERVENTILATION", 16, 155700},
	{"SUBGENUS", 8, 155701},
	{"LABYRINTHINE", 12, 155702},
	{"DAIRYING", 8, 155703},
	{"CORUSCANT", 9, 155704},
	{"SUBTASKS", 8, 155705},
	{"YOUSE", 5, 155706},
	{"TOXICOLOGIST", 12, 155707},
	{"TIERNAN", 7, 155708},
	{"JOLTS", 5, 155709},
	{"PINHEIRO", 8, 155710},
	{"CARPIO", 6, 155711},
	{"VARIE", 5, 155712},
	{"LAGUIOLE", 8, 155713},
	{"BOOKPOOL", 8, 155714},
	{"ABRI", 4, 155715},
	{"CONTEMPORAIN", 12, 155716},
	{"GRASSED", 7, 155717},
	{"UODO", 4, 155718},
	{"SICQ", 4, 155719},
	{"REXM", 4, 155720},
	{"POXI", 4, 155721},
	{"ONKC", 4, 155722},
	{"OEGR", 4, 155723},
	{"NYXM", 4, 155724},
	{"LSTL", 4, 155725},
	{"GNBR", 4, 155726},
	{"EDMB", 4, 155727},
	{"EBDA", 4, 155728},
	{"CYFL", 4, 155729},
	{"BULM", 4, 155730},
	{"BAYVILLE", 8, 155731},
	{"CARNINCI", 8, 155732},
	{"POCHE", 5, 155733},
	{"PANDUIT", 7, 155734},
	{"NEUEM", 5, 155735},
	{"TWIKIHISTORY", 12, 155736},
	{"ERBIUM", 6, 155737},
	{"HINDUTVA", 8, 155738},
	{"PANTRIES", 8, 155739},
	{"WERKS", 5, 155740},
	{"ECCLESIAL", 9, 155741},
	{"CASCAIS", 7, 155742},
	{"ALBERTUS", 8, 155743},
	{"KORD", 4, 155744},
	{"FRANCISCA", 9, 155745},
	{"VIANA", 5, 155746},
	{"NESCO", 5, 155747},
	{"LEARJET", 7, 155748},
	{"DUGONG", 6, 155749},
	{"FROMAGE", 7, 155750},
	{"NORDEA", 6, 155751},
	{"WEAVED", 6, 155752},
	{"GUNBOAT", 7, 155753},
	{"SCRUTINISE", 10, 155754},
	{"CASTLETOWN", 10, 155755},
	{"BLACKDOG", 8, 155756},
	{"POURRI", 6, 155757},
	{"WINKSITE", 8, 155758},
	{"ENCYCLOPAEDIAS", 14, 155759},
	{"BBOX", 4, 155760},
	{"NEUROPHARMACOLOGY", 17, 155761},
	{"STOJAKOVIC", 10, 155762},
	{"NETTOYAGE", 9, 155763},
	{"LIGURE", 6, 155764},
	{"FORBS", 5, 155765},
	{"KALLIS", 6, 155766},
	{"SADDENS", 7, 155767},
	{"REEXAMINED", 10, 155768},
	{"THEORIZE", 8, 155769},
	{"ENTERTAIMENT", 12, 155770},
	{"TRIANGULATED", 12, 155771},
	{"DRIPPINGS", 9, 155772},
	{"SATNAV", 6, 155773},
	{"TELEPOPMUSIK", 12, 155774},
	{"CONFRONTA", 9, 155775},
	{"AUTOBUILD", 9, 155776},
	{"GOPED", 5, 155777},
	{"DIGIUM", 6, 155778},
	{"XITU", 4, 155779},
	{"VAKD", 4, 155780},
	{"UKUM", 4, 155781},
	{"OSWR", 4, 155782},
	{"MNIK", 4, 155783},
	{"LTZO", 4, 155784},
	{"KSIR", 4, 155785},
	{"KHMO", 4, 155786},
	{"HULD", 4, 155787},
	{"HMSP", 4, 155788},
	{"GAEV", 4, 155789},
	{"FSYW", 4, 155790},
	{"FENJ", 4, 155791},
	{"CTOY", 4, 155792},
	{"COXT", 4, 155793},
	{"BBIL", 4, 155794},
	{"ASPW", 4, 155795},
	{"SCAPEGOATS", 10, 155796},
	{"SHEPHERDSTOWN", 13, 155797},
	{"LANDAUER", 8, 155798},
	{"MONTRACHET", 10, 155799},
	{"ALARIS", 6, 155800},
	{"QASIM", 5, 155801},
	{"AZEROTH", 7, 155802},
	{"ADIUM", 5, 155803},
	{"FARALLON", 8, 155804},
	{"VORTECH", 7, 155805},
	{"BALLENGER", 9, 155806},
	{"PSUEDO", 6, 155807},
	{"VLOGS", 5, 155808},
	{"BALTO", 5, 155809},
	{"NISTELROOY", 10, 155810},
	{"WELLNESDICKE", 12, 155811},
	{"MANYLION", 8, 155812},
	{"RENDERMAN", 9, 155813},
	{"NORTHCUTT", 9, 155814},
	{"GABROVO", 7, 155815},
	{"CARM", 4, 155816},
	{"SOCHI", 5, 155817},
	{"LEGISLA", 7, 155818},
	{"MIIKE", 5, 155819},
	{"MACO", 4, 155820},
	{"ERUPTIVE", 8, 155821},
	{"GOODLUCK", 8, 155822},
	{"GENERALISE", 10, 155823},
	{"BRABHAM", 7, 155824},
	{"AZTECH", 6, 155825},
	{"GIFTWRAPPING", 12, 155826},
	{"VOICI", 5, 155827},
	{"STYRIA", 6, 155828},
	{"POLITICIZATION", 14, 155829},
	{"SANATORIUM", 10, 155830},
	{"WEHRMACHT", 9, 155831},
	{"HAZWOPER", 8, 155832},
	{"CHANNELVIEW", 11, 155833},
	{"RPGOBJECTS", 10, 155834},
	{"SENDA", 5, 155835},
	{"DOLLARSMASH", 11, 155836},
	{"USERFRIENDLY", 12, 155837},
	{"CHOLECYSTOKININ", 15, 155838},
	{"ALIDA", 5, 155839},
	{"WSZYSTKIE", 9, 155840},
	{"FULLERENE", 9, 155841},
	{"WEATHERTECH", 11, 155842},
	{"TRYMEDIA", 8, 155843},
	{"SAERCH", 6, 155844},
	{"MESSAGER", 8, 155845},
	{"HOXIE", 5, 155846},
	{"ZALD", 4, 155847},
	{"YHOG", 4, 155848},
	{"TZAM", 4, 155849},
	{"TMEJ", 4, 155850},
	{"RVEJ", 4, 155851},
	{"RTRH", 4, 155852},
	{"RGSF", 4, 155853},
	{"RGHD", 4, 155854},
	{"NPHU", 4, 155855},
	{"MLAI", 4, 155856},
	{"KCOF", 4, 155857},
	{"IEKR", 4, 155858},
	{"GUAF", 4, 155859},
	{"EPYS", 4, 155860},
	{"CDUC", 4, 155861},
	{"MAHOPAC", 7, 155862},
	{"KENCO", 5, 155863},
	{"ASCETICISM", 10, 155864},
	{"SKELMERSDALE", 12, 155865},
	{"SLOTTING", 8, 155866},
	{"DRYSUIT", 7, 155867},
	{"RECONCILES", 10, 155868},
	{"DISENTANGLE", 11, 155869},
	{"AUTORI", 6, 155870},
	{"ONESTEP", 7, 155871},
	{"HARTIGAN", 8, 155872},
	{"FOLKSONOMIES", 12, 155873},
	{"INFLATES", 8, 155874},
	{"HELLOS", 6, 155875},
	{"GAKUEN", 6, 155876},
	{"KLOSS", 5, 155877},
	{"BLFS", 4, 155878},
	{"BESTOWING", 9, 155879},
	{"DAHLBERG", 8, 155880},
	{"ADMINISTRATING", 14, 155881},
	{"SIMULTANEITY", 12, 155882},
	{"KDEADDONS", 9, 155883},
	{"BELIE", 5, 155884},
	{"OSTEND", 6, 155885},
	{"BPB", 3, 155886},
	{"BRR", 3, 155887},
	{"DIVINING", 8, 155888},
	{"CONCENSUS", 9, 155889},
	{"MUSCLECAR", 9, 155890},
	{"LCK", 3, 155891},
	{"HUNGOVER", 8, 155892},
	{"CASAROSAFLORISTS", 16, 155893},
	{"GAELTACHT", 9, 155894},
	{"DACA", 4, 155895},
	{"ORBIX", 5, 155896},
	{"AMOUNG", 6, 155897},
	{"FACULTATIVE", 11, 155898},
	{"HIJJAH", 6, 155899},
	{"MESSIN", 6, 155900},
	{"BALUSTRADE", 10, 155901},
	{"BIODYNAMIC", 10, 155902},
	{"FORTIETH", 8, 155903},
	{"ADULTEROUS", 10, 155904},
	{"SLYLY", 5, 155905},
	{"WINSFORD", 8, 155906},
	{"MURATEC", 7, 155907},
	{"XSIG", 4, 155908},
	{"WLOT", 4, 155909},
	{"UXPA", 4, 155910},
	{"ULUR", 4, 155911},
	{"UKEK", 4, 155912},
	{"SRUF", 4, 155913},
	{"RIIR", 4, 155914},
	{"PMUL", 4, 155915},
	{"PDOM", 4, 155916},
	{"NUTG", 4, 155917},
	{"NDQV", 4, 155918},
	{"NCOY", 4, 155919},
	{"LYUG", 4, 155920},
	{"LCHL", 4, 155921},
	{"IVPR", 4, 155922},
	{"IGIF", 4, 155923},
	{"HSJU", 4, 155924},
	{"GNEY", 4, 155925},
	{"ELTJ", 4, 155926},
	{"EJRA", 4, 155927},
	{"DELJ", 4, 155928},
	{"BCLE", 4, 155929},
	{"SPANGLE", 7, 155930},
	{"RAJKUMAR", 8, 155931},
	{"DISPOSITIONAL", 13, 155932},
	{"RINGWALD", 8, 155933},
	{"SUPERADS", 8, 155934},
	{"DEMARCATED", 10, 155935},
	{"PMW", 3, 155936},
	{"CANDO", 5, 155937},
	{"BROCKENHURST", 12, 155938},
	{"DOWNEAST", 8, 155939},
	{"UNFAZED", 7, 155940},
	{"PREMIXED", 8, 155941},
	{"ISIXSIGMA", 9, 155942},
	{"WASAGA", 6, 155943},
	{"SCALPERS", 8, 155944},
	{"OSTEOGENESIS", 12, 155945},
	{"FUJAIRAH", 8, 155946},
	{"ALED", 4, 155947},
	{"JOERN", 5, 155948},
	{"TRUSTEDBSD", 10, 155949},
	{"SHIED", 5, 155950},
	{"MALTING", 7, 155951},
	{"CRIPPEN", 7, 155952},
	{"SLAUGHTERHOUSES", 15, 155953},
	{"DERIV", 5, 155954},
	{"OPINE", 5, 155955},
	{"ALMONTE", 7, 155956},
	{"PPPN", 4, 155957},
	{"TRICO", 5, 155958},
	{"HABERDASHERY", 12, 155959},
	{"DRIVEWERKS", 10, 155960},
	{"SHODOWN", 7, 155961},
	{"COMMITING", 9, 155962},
	{"WOODSY", 6, 155963},
	{"FANSUB", 6, 155964},
	{"GRIPHON", 7, 155965},
	{"LYONNAIS", 8, 155966},
	{"SIGUIENTES", 10, 155967},
	{"SCOPOLAMINE", 11, 155968},
	{"MARIOS", 6, 155969},
	{"HINTERN", 7, 155970},
	{"CAMPANULA", 9, 155971},
	{"PLANTAINS", 9, 155972},
	{"EVELINE", 7, 155973},
	{"CLARINGTON", 10, 155974},
	{"NORMED", 6, 155975},
	{"MERONYMS", 8, 155976},
	{"FIGURATION", 10, 155977},
	{"HURLBURT", 8, 155978},
	{"WORH", 4, 155979},
	{"TLLH", 4, 155980},
	{"OFDJ", 4, 155981},
	{"NYLC", 4, 155982},
	{"MVIT", 4, 155983},
	{"LTZT", 4, 155984},
	{"LIFC", 4, 155985},
	{"ILYQ", 4, 155986},
	{"FLSU", 4, 155987},
	{"FARQ", 4, 155988},
	{"EVSU", 4, 155989},
	{"DCUC", 4, 155990},
	{"CBSH", 4, 155991},
	{"PETWORTH", 8, 155992},
	{"AIRBOAT", 7, 155993},
	{"HYPHAE", 6, 155994},
	{"CAYS", 4, 155995},
	{"PREREQS", 7, 155996},
	{"SILVAN", 6, 155997},
	{"ALEGENT", 7, 155998},
	{"PHLOEM", 6, 155999},
	{"MOLESKIN", 8, 156000},
	{"DEFERENTIAL", 11, 156001},
	{"CHEC", 4, 156002},
	{"ICRP", 4, 156003},
	{"LCV", 3, 156004},
	{"IKEGAMI", 7, 156005},
	{"STOMATAL", 8, 156006},
	{"TARTER", 6, 156007},
	{"SHRINER", 7, 156008},
	{"SANDINISTA", 10, 156009},
	{"ENLIVENED", 9, 156010},
	{"LUTES", 5, 156011},
	{"MSTR", 4, 156012},
	{"AZUMI", 5, 156013},
	{"REPOVIEW", 8, 156014},
	{"BROWNER", 7, 156015},
	{"UNBALANCE", 9, 156016},
	{"MANISHA", 7, 156017},
	{"TRATIVE", 7, 156018},
	{"PACKMAN", 7, 156019},
	{"CALIBRA", 7, 156020},
	{"HOLDALLS", 8, 156021},
	{"SANDEE", 6, 156022},
	{"BOAL", 4, 156023},
	{"SVEND", 5, 156024},
	{"HOFSTADTER", 10, 156025},
	{"PUFFINS", 7, 156026},
	{"COTERIE", 7, 156027},
	{"PDIP", 4, 156028},
	{"TILLSONBURG", 11, 156029},
	{"CUFT", 4, 156030},
	{"WAHIAWA", 7, 156031},
	{"ROHRABACHER", 11, 156032},
	{"LADLES", 6, 156033},
	{"STANGER", 7, 156034},
	{"DIENSTLEISTUNGEN", 16, 156035},
	{"WINTERBOTTOM", 12, 156036},
	{"MCDIARMID", 9, 156037},
	{"STREE", 5, 156038},
	{"PPMV", 4, 156039},
	{"AMBUSHES", 8, 156040},
	{"SHOWSTOPPER", 11, 156041},
	{"MALAS", 5, 156042},
	{"HOLONYMS", 8, 156043},
	{"CARBURETTOR", 11, 156044},
	{"ACTUATING", 9, 156045},
	{"JAILING", 7, 156046},
	{"CAUDATE", 7, 156047},
	{"CABARETS", 8, 156048},
	{"ZECI", 4, 156049},
	{"VAVA", 4, 156050},
	{"SOMF", 4, 156051},
	{"REUK", 4, 156052},
	{"PPOU", 4, 156053},
	{"PBYI", 4, 156054},
	{"LRHE", 4, 156055},
	{"FPUM", 4, 156056},
	{"FFYB", 4, 156057},
	{"ESMV", 4, 156058},
	{"DYID", 4, 156059},
	{"DVEE", 4, 156060},
	{"DBIZ", 4, 156061},
	{"BTAK", 4, 156062},
	{"AFWO", 4, 156063},
	{"CERAM", 5, 156064},
	{"AZIANI", 6, 156065},
	{"BRUNA", 5, 156066},
	{"ELECTROPORATION", 15, 156067},
	{"EXCEP", 5, 156068},
	{"OZOMATLI", 8, 156069},
	{"FREEMASON", 9, 156070},
	{"CAEDMON", 7, 156071},
	{"MAGNANIMOUS", 11, 156072},
	{"SUHALI", 6, 156073},
	{"VSNL", 4, 156074},
	{"GANADO", 6, 156075},
	{"TWIGGS", 6, 156076},
	{"ELMAN", 5, 156077},
	{"RUBIS", 5, 156078},
	{"SOUNDZ", 6, 156079},
	{"CLAIRMONT", 9, 156080},
	{"SCHUTZHUND", 10, 156081},
	{"SATANIST", 8, 156082},
	{"KLAES", 5, 156083},
	{"WWD", 3, 156084},
	{"PLAIT", 5, 156085},
	{"NATURINO", 8, 156086},
	{"HSUEH", 5, 156087},
	{"CEFTRIAXONE", 11, 156088},
	{"GUTTURAL", 8, 156089},
	{"DYAD", 4, 156090},
	{"PHOTOGRAPHIE", 12, 156091},
	{"NALINI", 6, 156092},
	{"LEVELERS", 8, 156093},
	{"LIBOGG", 6, 156094},
	{"ALEVE", 5, 156095},
	{"ANAESTHETISTS", 13, 156096},
	{"CARTING", 7, 156097},
	{"VINITA", 6, 156098},
	{"HANDBELL", 8, 156099},
	{"ETHYLHEXYL", 10, 156100},
	{"CARAMELS", 8, 156101},
	{"CALCIFIED", 9, 156102},
	{"PRIDED", 6, 156103},
	{"CRANS", 5, 156104},
	{"ELECTROSTATICS", 14, 156105},
	{"PBLUESCRIPT", 11, 156106},
	{"RJTECH", 6, 156107},
	{"INVERSES", 8, 156108},
	{"BUONO", 5, 156109},
	{"ZYWA", 4, 156110},
	{"WWAI", 4, 156111},
	{"UCOV", 4, 156112},
	{"TVDR", 4, 156113},
	{"TPMU", 4, 156114},
	{"TMRK", 4, 156115},
	{"SRDI", 4, 156116},
	{"RYNH", 4, 156117},
	{"RABG", 4, 156118},
	{"NZED", 4, 156119},
	{"NFAZ", 4, 156120},
	{"FFFU", 4, 156121},
	{"ABUH", 4, 156122},
	{"SHEAHAN", 7, 156123},
	{"CHLAMYDOMONAS", 13, 156124},
	{"SIZZLA", 6, 156125},
	{"HEEHEE", 6, 156126},
	{"JANNASCHII", 10, 156127},
	{"MINEFIELDS", 10, 156128},
	{"FLAVOURING", 10, 156129},
	{"ENUMS", 5, 156130},
	{"RFERL", 5, 156131},
	{"PUIMUN", 6, 156132},
	{"KOHLI", 5, 156133},
	{"CALIFORNIAUSA", 13, 156134},
	{"ALAPPUZHA", 9, 156135},
	{"REWIRING", 8, 156136},
	{"HAPPENIN", 8, 156137},
	{"BRAINTEASERS", 12, 156138},
	{"NIGHTSPOTS", 10, 156139},
	{"HEDMAN", 6, 156140},
	{"ALTEON", 6, 156141},
	{"ANCIENS", 7, 156142},
	{"FEDSTATS", 8, 156143},
	{"GARAM", 5, 156144},
	{"JIGDO", 5, 156145},
	{"SCIUROGNATHI", 12, 156146},
	{"ENDODONTIC", 10, 156147},
	{"INCHARGE", 8, 156148},
	{"SPRINGBREAK", 11, 156149},
	{"SERCO", 5, 156150},
	{"MALTED", 6, 156151},
	{"KOLD", 4, 156152},
	{"ENCLUME", 7, 156153},
	{"ELECTROPLANKTON", 15, 156154},
	{"CITYBREAKAWAYS", 14, 156155},
	{"GUERNEVILLE", 11, 156156},
	{"DURNING", 7, 156157},
	{"CANADAS", 7, 156158},
	{"BARRELED", 8, 156159},
	{"UNCHARACTERISTIC", 16, 156160},
	{"LOUISBOURG", 10, 156161},
	{"LOGIE", 5, 156162},
	{"CHATEAUNEUF", 11, 156163},
	{"NAMER", 5, 156164},
	{"SHABBIR", 7, 156165},
	{"LUTIL", 5, 156166},
	{"PRINTLN", 7, 156167},
	{"BROODSTOCK", 10, 156168},
	{"WONY", 4, 156169},
	{"VUSA", 4, 156170},
	{"VDFO", 4, 156171},
	{"TSCY", 4, 156172},
	{"SPMO", 4, 156173},
	{"RLOL", 4, 156174},
	{"RKVO", 4, 156175},
	{"RKIW", 4, 156176},
	{"RKGU", 4, 156177},
	{"NWRT", 4, 156178},
	{"LKMI", 4, 156179},
	{"KUOK", 4, 156180},
	{"JELE", 4, 156181},
	{"INMP", 4, 156182},
	{"IMFS", 4, 156183},
	{"IFFG", 4, 156184},
	{"GEYM", 4, 156185},
	{"EGDO", 4, 156186},
	{"DIMJ", 4, 156187},
	{"DHWA", 4, 156188},
	{"CYND", 4, 156189},
	{"BYKY", 4, 156190},
	{"BISG", 4, 156191},
	{"GAMERA", 6, 156192},
	{"COOPERATIONS", 12, 156193},
	{"CLADES", 6, 156194},
	{"LYSED", 5, 156195},
	{"WORMBASE", 8, 156196},
	{"CSHARP", 6, 156197},
	{"CAPSIZED", 8, 156198},
	{"SHEARMAN", 8, 156199},
	{"ISANG", 5, 156200},
	{"APPTALK", 7, 156201},
	{"RHABDOMYOSARCOMA", 16, 156202},
	{"KILOBYTE", 8, 156203},
	{"UNSAT", 5, 156204},
	{"VADOSE", 6, 156205},
	{"EJECTA", 6, 156206},
	{"BRESLAU", 7, 156207},
	{"CENTRICA", 8, 156208},
	{"TOPLISTS", 8, 156209},
	{"OBLIGATES", 9, 156210},
	{"BLANKETED", 9, 156211},
	{"TRIAXIAL", 8, 156212},
	{"AMBERS", 6, 156213},
	{"PROXYING", 8, 156214},
	{"KELME", 5, 156215},
	{"MUNITIES", 8, 156216},
	{"GELLIR", 6, 156217},
	{"IGOURMET", 8, 156218},
	{"STREICHELN", 10, 156219},
	{"UNREALITY", 9, 156220},
	{"CHRISTOPHERS", 12, 156221},
	{"BUCKHANNON", 10, 156222},
	{"EJECTING", 8, 156223},
	{"NOTICESPUBLIC", 13, 156224},
	{"METAPHONE", 9, 156225},
	{"GUIDELOCAL", 10, 156226},
	{"TYPOLOGIES", 10, 156227},
	{"NGATI", 5, 156228},
	{"PINSTRIPES", 10, 156229},
	{"WEITEREN", 8, 156230},
	{"EXTRUDERS", 9, 156231},
	{"WAUCONDA", 8, 156232},
	{"ZZHA", 4, 156233},
	{"YMYG", 4, 156234},
	{"WIMF", 4, 156235},
	{"VATP", 4, 156236},
	{"VAFT", 4, 156237},
	{"UMPG", 4, 156238},
	{"ULIG", 4, 156239},
	{"UILO", 4, 156240},
	{"SKOY", 4, 156241},
	{"RFHA", 4, 156242},
	{"OYEU", 4, 156243},
	{"ODUA", 4, 156244},
	{"NZIL", 4, 156245},
	{"NWAW", 4, 156246},
	{"NGCS", 4, 156247},
	{"NDCZ", 4, 156248},
	{"MKRA", 4, 156249},
	{"LLKR", 4, 156250},
	{"LISQ", 4, 156251},
	{"LBUG", 4, 156252},
	{"LBSI", 4, 156253},
	{"KKRA", 4, 156254},
	{"IRBH", 4, 156255},
	{"IOJU", 4, 156256},
	{"IGIP", 4, 156257},
	{"GGSR", 4, 156258},
	{"DYPH", 4, 156259},
	{"CURM", 4, 156260},
	{"BORMAN", 6, 156261},
	{"MORUYA", 6, 156262},
	{"WAKAYAMA", 8, 156263},
	{"ANTITHROMBIN", 12, 156264},
	{"LORENZEN", 8, 156265},
	{"REGET", 5, 156266},
	{"MACSPEECH", 9, 156267},
	{"FISHEL", 6, 156268},
	{"PETSAFE", 7, 156269},
	{"SITETOURIST", 11, 156270},
	{"PODNAPISI", 9, 156271},
	{"WEDDLE", 6, 156272},
	{"MATINEES", 8, 156273},
	{"HOMENEWSMEN", 11, 156274},
	{"INCYTEPD", 8, 156275},
	{"MURS", 4, 156276},
	{"LUTSCHEN", 8, 156277},
	{"AAFC", 4, 156278},
	{"TUBELESS", 8, 156279},
	{"SOLED", 5, 156280},
	{"ZOUCH", 5, 156281},
	{"HOTBOX", 6, 156282},
	{"SMARTCHOICE", 11, 156283},
	{"RYL", 3, 156284},
	{"PORTAUDIO", 9, 156285},
	{"GLANTZ", 6, 156286},
	{"WFM", 3, 156287},
	{"TELLICO", 7, 156288},
	{"HENNINGER", 9, 156289},
	{"BARTLET", 7, 156290},
	{"ENCAMPMENTS", 11, 156291},
	{"NOWIDCTLPAR", 11, 156292},
	{"ONLIEN", 6, 156293},
	{"BILKENT", 7, 156294},
	{"ILEAL", 5, 156295},
	{"TRANSA", 6, 156296},
	{"STAEDTLER", 9, 156297},
	{"PELCO", 5, 156298},
	{"MALAD", 5, 156299},
	{"GEOID", 5, 156300},
	{"VSFTPD", 6, 156301},
	{"HINDENBURG", 10, 156302},
	{"KIMMO", 5, 156303},
	{"BUKHARA", 7, 156304},
	{"WHITEN", 6, 156305},
	{"DERNIERS", 8, 156306},
	{"PROGNAME", 8, 156307},
	{"YAMAUCHI", 8, 156308},
	{"ENTENDRE", 8, 156309},
	{"CPCU", 4, 156310},
	{"AVAILABLILITY", 13, 156311},
	{"HAEMORRHAGIC", 12, 156312},
	{"CUIDADO", 7, 156313},
	{"BENZINE", 7, 156314},
	{"MASTURBIEREN", 12, 156315},
	{"MACKE", 5, 156316},
	{"ZISB", 4, 156317},
	{"XJUS", 4, 156318},
	{"WEXH", 4, 156319},
	{"WANJ", 4, 156320},
	{"VASL", 4, 156321},
	{"UKOU", 4, 156322},
	{"UKDE", 4, 156323},
	{"PYVA", 4, 156324},
	{"NTVL", 4, 156325},
	{"LCDT", 4, 156326},
	{"KAYC", 4, 156327},
	{"IZUN", 4, 156328},
	{"IGVO", 4, 156329},
	{"HURK", 4, 156330},
	{"GKIS", 4, 156331},
	{"GGYC", 4, 156332},
	{"EXOV", 4, 156333},
	{"ETMW", 4, 156334},
	{"DLOM", 4, 156335},
	{"CIOM", 4, 156336},
	{"CORRIDA", 7, 156337},
	{"KATHRIN", 7, 156338},
	{"RHODAMINE", 9, 156339},
	{"SPRIGGS", 7, 156340},
	{"POPULATES", 9, 156341},
	{"MOGGED", 6, 156342},
	{"CHEWIE", 6, 156343},
	{"ACOMA", 5, 156344},
	{"POWERTOYS", 9, 156345},
	{"HAILSTORM", 9, 156346},
	{"SETATTRIBUTE", 12, 156347},
	{"PIMMEL", 6, 156348},
	{"REYNARD", 7, 156349},
	{"REMARQUE", 8, 156350},
	{"LYMPHADENOPATHY", 15, 156351},
	{"KATRINE", 7, 156352},
	{"MONKFISH", 8, 156353},
	{"PERUSED", 7, 156354},
	{"CARNOUSTIE", 10, 156355},
	{"OBJECTTYPE", 10, 156356},
	{"PHTHALATES", 10, 156357},
	{"RAPPELLING", 10, 156358},
	{"CATAL", 5, 156359},
	{"KARPINSKI", 9, 156360},
	{"REFRAINS", 8, 156361},
	{"KIRTON", 6, 156362},
	{"ACTIVIN", 7, 156363},
	{"NEWSON", 6, 156364},
	{"DIMITROV", 8, 156365},
	{"FURROWED", 8, 156366},
	{"REPLICATIVE", 11, 156367},
	{"HEDONIST", 8, 156368},
	{"METAPHORIC", 10, 156369},
	{"CCFLAGS", 7, 156370},
	{"RABCK", 5, 156371},
	{"MANURES", 7, 156372},
	{"INCLUSIONARY", 12, 156373},
	{"EPITOMIZED", 10, 156374},
	{"HOGMANAY", 8, 156375},
	{"UKG", 3, 156376},
	{"CYCLODEXTRIN", 12, 156377},
	{"NEUROMANCER", 11, 156378},
	{"SMARTSOUND", 10, 156379},
	{"MSMQ", 4, 156380},
	{"LOTUSSCRIPT", 11, 156381},
	{"TABERNACLES", 11, 156382},
	{"CANDLEMASS", 10, 156383},
	{"MURE", 4, 156384},
	{"VIRILE", 6, 156385},
	{"HMMER", 5, 156386},
	{"MESSAGEONE", 10, 156387},
	{"CASARES", 7, 156388},
	{"RENAE", 5, 156389},
	{"KEYMAPS", 7, 156390},
	{"YVIK", 4, 156391},
	{"PGER", 4, 156392},
	{"ONLD", 4, 156393},
	{"NKWR", 4, 156394},
	{"KBYN", 4, 156395},
	{"HFID", 4, 156396},
	{"BOSQ", 4, 156397},
	{"AMIC", 4, 156398},
	{"POITIER", 7, 156399},
	{"WASHBOARD", 9, 156400},
	{"FFB", 3, 156401},
	{"MOLOKO", 6, 156402},
	{"LUVANA", 6, 156403},
	{"WYNETTE", 7, 156404},
	{"POIGNANCY", 9, 156405},
	{"SAVILLS", 7, 156406},
	{"SHRIFT", 6, 156407},
	{"PERCODAN", 8, 156408},
	{"VISIBILITIES", 12, 156409},
	{"UNIAXIAL", 8, 156410},
	{"PACHINKO", 8, 156411},
	{"LEHRSTUHL", 9, 156412},
	{"SIZZLER", 7, 156413},
	{"MACHINEGUN", 10, 156414},
	{"OPING", 5, 156415},
	{"LAMPORT", 7, 156416},
	{"JOINDER", 7, 156417},
	{"POLARITIES", 10, 156418},
	{"EKNATH", 6, 156419},
	{"WEBLOGGERS", 10, 156420},
	{"SOLIDIFIES", 10, 156421},
	{"KODACHROME", 10, 156422},
	{"SOLOMONIA", 9, 156423},
	{"ETHYLBENZENE", 12, 156424},
	{"WEBLISTS", 8, 156425},
	{"LINGALA", 7, 156426},
	{"DETESTABLE", 10, 156427},
	{"POUCE", 5, 156428},
	{"ESTUDO", 6, 156429},
	{"PIRATING", 8, 156430},
	{"BAGSBUY", 7, 156431},
	{"ADLIB", 5, 156432},
	{"ROZELLE", 7, 156433},
	{"OCALAN", 6, 156434},
	{"MOONEE", 6, 156435},
	{"SWAYBACK", 8, 156436},
	{"POPL", 4, 156437},
	{"PAPADIMITRIOU", 13, 156438},
	{"DANSON", 6, 156439},
	{"TERROIR", 7, 156440},
	{"NONNATIVE", 9, 156441},
	{"PARISHIONER", 11, 156442},
	{"MODDERS", 7, 156443},
	{"POMME", 5, 156444},
	{"IGFBP", 5, 156445},
	{"MARGULIES", 9, 156446},
	{"HUCKNALL", 8, 156447},
	{"INKFROG", 7, 156448},
	{"STINKER", 7, 156449},
	{"CERTAINES", 9, 156450},
	{"SOMBRA", 6, 156451},
	{"IMAGEZOO", 8, 156452},
	{"YOSHINORI", 9, 156453},
	{"TEXEL", 5, 156454},
	{"MYSTIFYING", 10, 156455},
	{"YPTF", 4, 156456},
	{"YBCA", 4, 156457},
	{"VYPA", 4, 156458},
	{"VHAV", 4, 156459},
	{"TLLT", 4, 156460},
	{"SMCR", 4, 156461},
	{"SILU", 4, 156462},
	{"RNUK", 4, 156463},
	{"RCZE", 4, 156464},
	{"PDAL", 4, 156465},
	{"MAYQ", 4, 156466},
	{"LOTK", 4, 156467},
	{"KHIC", 4, 156468},
	{"JATR", 4, 156469},
	{"IGFU", 4, 156470},
	{"GFAK", 4, 156471},
	{"EVAF", 4, 156472},
	{"EUGN", 4, 156473},
	{"EKFL", 4, 156474},
	{"EDLT", 4, 156475},
	{"DPNE", 4, 156476},
	{"DMIU", 4, 156477},
	{"DEKK", 4, 156478},
	{"DAIF", 4, 156479},
	{"BGAR", 4, 156480},
	{"ATUD", 4, 156481},
	{"ABSL", 4, 156482},
	{"CVAR", 4, 156483},
	{"ARBUTHNOT", 9, 156484},
	{"SWYDDI", 6, 156485},
	{"TAKSIM", 6, 156486},
	{"SATANISTS", 9, 156487},
	{"TURDS", 5, 156488},
	{"PLAUT", 5, 156489},
	{"ANDERLECHT", 10, 156490},
	{"HOARSENESS", 10, 156491},
	{"GENELEC", 7, 156492},
	{"NARBONNE", 8, 156493},
	{"MERITOCRACY", 11, 156494},
	{"ZEHNDER", 7, 156495},
	{"VOISIN", 6, 156496},
	{"SHAREABLE", 9, 156497},
	{"JILTED", 6, 156498},
	{"NIKOLAEV", 8, 156499},
	{"LEDEEN", 6, 156500},
	{"MRB", 3, 156501},
	{"MACHISMO", 8, 156502},
	{"IBER", 4, 156503},
	{"PARABEN", 7, 156504},
	{"HONORARIA", 9, 156505},
	{"CENTURIONS", 10, 156506},
	{"FOLL", 4, 156507},
	{"REDBONE", 7, 156508},
	{"PORING", 6, 156509},
	{"CATLOW", 6, 156510},
	{"ENCANTO", 7, 156511},
	{"FRCPC", 5, 156512},
	{"WHITED", 6, 156513},
	{"SWFDISPLAYITEM", 14, 156514},
	{"STRONACH", 8, 156515},
	{"UHER", 4, 156516},
	{"SCLEROTIC", 9, 156517},
	{"BLACKMAGIC", 10, 156518},
	{"UNIROYAL", 8, 156519},
	{"QUIVERS", 7, 156520},
	{"DOCKER", 6, 156521},
	{"INTERLAND", 9, 156522},
	{"ALMONT", 6, 156523},
	{"PARKINSONISM", 12, 156524},
	{"MESAJ", 5, 156525},
	{"FREEVERSE", 9, 156526},
	{"ESDP", 4, 156527},
	{"NETVAULT", 8, 156528},
	{"COSTINGS", 8, 156529},
	{"PYROCOCCUS", 10, 156530},
	{"FLAUNTING", 9, 156531},
	{"LOVEBIRDS", 9, 156532},
	{"MULCHES", 7, 156533},
	{"TEAGAN", 6, 156534},
	{"FRAYING", 7, 156535},
	{"EDUCTION", 8, 156536},
	{"CORBET", 6, 156537},
	{"PORCA", 5, 156538},
	{"PASQUOTANK", 10, 156539},
	{"RAMIPRIL", 8, 156540},
	{"PEEPED", 6, 156541},
	{"DOUSED", 6, 156542},
	{"GETDATE", 7, 156543},
	{"FUZE", 4, 156544},
	{"WWDC", 4, 156545},
	{"GIORNALE", 8, 156546},
	{"CRUIKSHANK", 10, 156547},
	{"ZYIS", 4, 156548},
	{"ZPAR", 4, 156549},
	{"YJUA", 4, 156550},
	{"XICW", 4, 156551},
	{"WOKA", 4, 156552},
	{"VSLO", 4, 156553},
	{"VOWH", 4, 156554},
	{"RPMM", 4, 156555},
	{"QUBC", 4, 156556},
	{"PCRU", 4, 156557},
	{"ORCM", 4, 156558},
	{"NYLR", 4, 156559},
	{"NGCP", 4, 156560},
	{"LKAI", 4, 156561},
	{"KOTR", 4, 156562},
	{"GYVE", 4, 156563},
	{"GUPU", 4, 156564},
	{"ELBS", 4, 156565},
	{"EGYL", 4, 156566},
	{"CCAV", 4, 156567},
	{"ABYU", 4, 156568},
	{"ZOOEY", 5, 156569},
	{"ALKYLATION", 10, 156570},
	{"PRALLEN", 7, 156571},
	{"WALZER", 6, 156572},
	{"LETHA", 5, 156573},
	{"BARACODA", 8, 156574},
	{"PREVEN", 6, 156575},
	{"THUMBING", 8, 156576},
	{"COMPUTA", 7, 156577},
	{"ELLAS", 5, 156578},
	{"MAXUM", 5, 156579},
	{"GEOSCIENTISTS", 13, 156580},
	{"HEXAVALENT", 10, 156581},
	{"METUS", 5, 156582},
	{"SYNXIS", 6, 156583},
	{"ELEY", 4, 156584},
	{"ROMANIZATION", 12, 156585},
	{"HERSHBERGER", 11, 156586},
	{"MAGHERAFELT", 11, 156587},
	{"MESSAGEBOX", 10, 156588},
	{"FLOSSMOOR", 9, 156589},
	{"QUER", 4, 156590},
	{"CARRIBBEAN", 10, 156591},
	{"HOBBYLINC", 9, 156592},
	{"DISASSEMBLING", 13, 156593},
	{"WAILS", 5, 156594},
	{"NORME", 5, 156595},
	{"GILD", 4, 156596},
	{"TALIS", 5, 156597},
	{"COCKLES", 7, 156598},
	{"BERENGER", 8, 156599},
	{"NAUR", 4, 156600},
	{"SHIMMERS", 8, 156601},
	{"STANDIN", 7, 156602},
	{"TYNGSBORO", 9, 156603},
	{"TRIODE", 6, 156604},
	{"DEBONAIR", 8, 156605},
	{"CRIEFF", 6, 156606},
	{"SURBER", 6, 156607},
	{"TRANSPORTATIONS", 15, 156608},
	{"NEUROBIOLOGICAL", 15, 156609},
	{"DUXFORD", 7, 156610},
	{"RETINOID", 8, 156611},
	{"INDIGNANTLY", 11, 156612},
	{"FAZED", 5, 156613},
	{"SHEERNESS", 9, 156614},
	{"CLEWISTON", 9, 156615},
	{"CARLINI", 7, 156616},
	{"INVIGORATED", 11, 156617},
	{"AWESOMELY", 9, 156618},
	{"YLME", 4, 156619},
	{"XVIC", 4, 156620},
	{"WANZ", 4, 156621},
	{"VICU", 4, 156622},
	{"VAFI", 4, 156623},
	{"UOSK", 4, 156624},
	{"TKAU", 4, 156625},
	{"SWAZ", 4, 156626},
	{"RIXB", 4, 156627},
	{"PHYU", 4, 156628},
	{"OYSK", 4, 156629},
	{"LRAW", 4, 156630},
	{"LMRI", 4, 156631},
	{"KTIL", 4, 156632},
	{"FTSK", 4, 156633},
	{"FLIO", 4, 156634},
	{"BEUL", 4, 156635},
	{"AORK", 4, 156636},
	{"OBJECTID", 8, 156637},
	{"MCKUSICK", 8, 156638},
	{"WATERVIEW", 9, 156639},
	{"NEURODEGENERATION", 17, 156640},
	{"VERNET", 6, 156641},
	{"BUCOLIC", 7, 156642},
	{"BAHNHOF", 7, 156643},
	{"PENTOBARBITAL", 13, 156644},
	{"MONITEUR", 8, 156645},
	{"DISAFFECTION", 12, 156646},
	{"BOSSE", 5, 156647},
	{"OPENPOWER", 9, 156648},
	{"EMBASY", 6, 156649},
	{"LGD", 3, 156650},
	{"AMBALA", 6, 156651},
	{"GRAPPLED", 8, 156652},
	{"MENTEES", 7, 156653},
	{"EXECUTIONERS", 12, 156654},
	{"CYSYLLTU", 8, 156655},
	{"ZARINA", 6, 156656},
	{"BRUFORD", 7, 156657},
	{"FLOCCULATION", 12, 156658},
	{"DUNSBOROUGH", 11, 156659},
	{"NOSTROMO", 8, 156660},
	{"CANAANITE", 9, 156661},
	{"BROADUS", 7, 156662},
	{"INFUSES", 7, 156663},
	{"MORPHOLOGIES", 12, 156664},
	{"DAGBLAD", 7, 156665},
	{"CAHIER", 6, 156666},
	{"BELIAL", 6, 156667},
	{"BRAMWELL", 8, 156668},
	{"FINALIZES", 9, 156669},
	{"TURNTABLISM", 11, 156670},
	{"INFODIR", 7, 156671},
	{"MIDFIELDERS", 11, 156672},
	{"HOTLISTS", 8, 156673},
	{"GRANDY", 6, 156674},
	{"GATTACA", 7, 156675},
	{"WHELDON", 7, 156676},
	{"UNADDRESSED", 11, 156677},
	{"THASSOS", 7, 156678},
	{"ECOREGIONS", 10, 156679},
	{"NORMALMENTE", 11, 156680},
	{"LOWPASS", 7, 156681},
	{"DURAMINE", 8, 156682},
	{"BELFIELD", 8, 156683},
	{"MMIV", 4, 156684},
	{"HARDE", 5, 156685},
	{"WALSHAM", 7, 156686},
	{"PROCLARITY", 10, 156687},
	{"SECCION", 7, 156688},
	{"XFL", 3, 156689},
	{"LUCCI", 5, 156690},
	{"IMPALER", 7, 156691},
	{"USYN", 4, 156692},
	{"PPNE", 4, 156693},
	{"NDKS", 4, 156694},
	{"KUJI", 4, 156695},
	{"KBYO", 4, 156696},
	{"JERV", 4, 156697},
	{"IBYL", 4, 156698},
	{"HDDE", 4, 156699},
	{"GYEM", 4, 156700},
	{"GMEB", 4, 156701},
	{"ETZG", 4, 156702},
	{"EDVS", 4, 156703},
	{"DFOI", 4, 156704},
	{"CEPP", 4, 156705},
	{"BROH", 4, 156706},
	{"BOLC", 4, 156707},
	{"AMCM", 4, 156708},
	{"ACIZ", 4, 156709},
	{"SONOGRAM", 8, 156710},
	{"AEOLUS", 6, 156711},
	{"BENALLA", 7, 156712},
	{"FARHAD", 6, 156713},
	{"POSTOFFICE", 10, 156714},
	{"OKEMO", 5, 156715},
	{"DECOUPLE", 8, 156716},
	{"CLICKGAMER", 10, 156717},
	{"SWYDDFA", 7, 156718},
	{"BLESSEDNESS", 11, 156719},
	{"UNADILLA", 8, 156720},
	{"RIDEGEAR", 8, 156721},
	{"DECRIES", 7, 156722},
	{"COURTESIES", 10, 156723},
	{"QUIZZING", 8, 156724},
	{"FAGIN", 5, 156725},
	{"OCGA", 4, 156726},
	{"BOOING", 6, 156727},
	{"MISERICORDIA", 12, 156728},
	{"APOTHEOSIS", 10, 156729},
	{"PHYTOPATHOLOGY", 14, 156730},
	{"IMBROGLIO", 9, 156731},
	{"ABSORBENCY", 10, 156732},
	{"TETHYS", 6, 156733},
	{"GORRIE", 6, 156734},
	{"MICROCLIMATE", 12, 156735},
	{"GRUYERE", 7, 156736},
	{"JETTE", 5, 156737},
	{"INTERDENOMINATIONAL", 19, 156738},
	{"LIBRIUM", 7, 156739},
	{"NEUROGENESIS", 12, 156740},
	{"CPLD", 4, 156741},
	{"CHIPMAKER", 9, 156742},
	{"SEARCG", 6, 156743},
	{"OVATIONS", 8, 156744},
	{"NEWSPHOTOS", 10, 156745},
	{"ZEVA", 4, 156746},
	{"YMYA", 4, 156747},
	{"WPHY", 4, 156748},
	{"WKAT", 4, 156749},
	{"WELM", 4, 156750},
	{"RMOG", 4, 156751},
	{"ORDZ", 4, 156752},
	{"NEUX", 4, 156753},
	{"LFKN", 4, 156754},
	{"KHRA", 4, 156755},
	{"KBUL", 4, 156756},
	{"HILR", 4, 156757},
	{"GYGO", 4, 156758},
	{"EXYS", 4, 156759},
	{"EMRD", 4, 156760},
	{"DAQI", 4, 156761},
	{"CAIF", 4, 156762},
	{"BBCM", 4, 156763},
	{"AMNU", 4, 156764},
	{"HYPNOTICS", 9, 156765},
	{"GROSSESSE", 9, 156766},
	{"GLAVINE", 7, 156767},
	{"BETTERING", 9, 156768},
	{"TIGRESS", 7, 156769},
	{"MINAR", 5, 156770},
	{"RANTBURG", 8, 156771},
	{"GIRLIES", 7, 156772},
	{"LISTAS", 6, 156773},
	{"GEWORDEN", 8, 156774},
	{"ILLIQUID", 8, 156775},
	{"GILLAM", 6, 156776},
	{"JOHNSSON", 8, 156777},
	{"OCCHI", 5, 156778},
	{"CHANTE", 6, 156779},
	{"BLEATING", 8, 156780},
	{"WESLO", 5, 156781},
	{"STRATAGEM", 9, 156782},
	{"CHAKRABARTI", 11, 156783},
	{"RANSOME", 7, 156784},
	{"JUSS", 4, 156785},
	{"JOUW", 4, 156786},
	{"JEMMA", 5, 156787},
	{"CRANKSETS", 9, 156788},
	{"ZAPTHINK", 8, 156789},
	{"PUNI", 4, 156790},
	{"ALYN", 4, 156791},
	{"TUSHAR", 6, 156792},
	{"WALLENBERG", 10, 156793},
	{"SQUATTED", 8, 156794},
	{"COASTSIDE", 9, 156795},
	{"TREVOSE", 7, 156796},
	{"SIDDIQI", 7, 156797},
	{"DAGON", 5, 156798},
	{"HUGUES", 6, 156799},
	{"HIJRI", 5, 156800},
	{"BOOKPORT", 8, 156801},
	{"BAMBER", 6, 156802},
	{"LYNGBY", 6, 156803},
	{"HUMMELS", 7, 156804},
	{"UNLABELLED", 10, 156805},
	{"SPYAXE", 6, 156806},
	{"COUNTRYS", 8, 156807},
	{"TURCOTTE", 8, 156808},
	{"SUBSTITUENT", 11, 156809},
	{"WENTZVILLE", 10, 156810},
	{"NATASCHA", 8, 156811},
	{"UNDEREMPLOYMENT", 15, 156812},
	{"LOTTI", 5, 156813},
	{"VENCE", 5, 156814},
	{"ATALANTA", 8, 156815},
	{"PLAYDIA", 7, 156816},
	{"PREPOSITIONAL", 13, 156817},
	{"MUNCHAUSEN", 10, 156818},
	{"HYDROXYZINE", 11, 156819},
	{"LEMMY", 5, 156820},
	{"BLANE", 5, 156821},
	{"MOONWALK", 8, 156822},
	{"DOLCI", 5, 156823},
	{"AUDIOLINK", 9, 156824},
	{"PARTAGE", 7, 156825},
	{"TENORMIN", 8, 156826},
	{"LEVAR", 5, 156827},
	{"YRDW", 4, 156828},
	{"RNUL", 4, 156829},
	{"NDKW", 4, 156830},
	{"MOXF", 4, 156831},
	{"LUBK", 4, 156832},
	{"LEOK", 4, 156833},
	{"KMHI", 4, 156834},
	{"GJAI", 4, 156835},
	{"FBAU", 4, 156836},
	{"ERFB", 4, 156837},
	{"CNAR", 4, 156838},
	{"REASSERT", 8, 156839},
	{"LANCETS", 7, 156840},
	{"IBELGAUFTS", 10, 156841},
	{"INTRACEREBRAL", 13, 156842},
	{"SCELTA", 6, 156843},
	{"CONNIVING", 9, 156844},
	{"LEVONORGESTREL", 14, 156845},
	{"TRIBOLOGY", 9, 156846},
	{"BLASI", 5, 156847},
	{"SCANPROSITE", 11, 156848},
	{"HERCULE", 7, 156849},
	{"SUBPHYLUM", 9, 156850},
	{"SAFTY", 5, 156851},
	{"MICROFLEECE", 11, 156852},
	{"UDLD", 4, 156853},
	{"CACC", 4, 156854},
	{"CHLORHEXIDINE", 13, 156855},
	{"AUTHORITATIVELY", 15, 156856},
	{"VNUNET", 6, 156857},
	{"VITRA", 5, 156858},
	{"RUFFED", 6, 156859},
	{"CHARAN", 6, 156860},
	{"WOLFENSOHN", 10, 156861},
	{"STEGANOS", 8, 156862},
	{"ATASCOSA", 8, 156863},
	{"PRESELECTED", 11, 156864},
	{"AWACS", 5, 156865},
	{"ZUCCA", 5, 156866},
	{"UIDE", 4, 156867},
	{"ARLINE", 6, 156868},
	{"PENALITIES", 10, 156869},
	{"KONUS", 5, 156870},
	{"GREENBRAE", 9, 156871},
	{"SCHIPPERKE", 10, 156872},
	{"CARDER", 6, 156873},
	{"THIBODEAU", 9, 156874},
	{"COMBER", 6, 156875},
	{"EPPENDORF", 9, 156876},
	{"BEHAN", 5, 156877},
	{"MUZZLELOADER", 12, 156878},
	{"THURINGIA", 9, 156879},
	{"UNPLEASANTNESS", 14, 156880},
	{"DELMONT", 7, 156881},
	{"BIZCARTA", 8, 156882},
	{"KUMARI", 6, 156883},
	{"THERMALROCK", 11, 156884},
	{"PIXLAND", 7, 156885},
	{"SANDE", 5, 156886},
	{"BETTERED", 8, 156887},
	{"MARKETEAM", 9, 156888},
	{"AZOM", 4, 156889},
	{"YUWA", 4, 156890},
	{"WIGE", 4, 156891},
	{"REPK", 4, 156892},
	{"RDEY", 4, 156893},
	{"OZIM", 4, 156894},
	{"OXKM", 4, 156895},
	{"LALN", 4, 156896},
	{"HWEG", 4, 156897},
	{"HJAK", 4, 156898},
	{"GAPM", 4, 156899},
	{"FLUW", 4, 156900},
	{"FJOA", 4, 156901},
	{"ETMD", 4, 156902},
	{"EBCC", 4, 156903},
	{"DAPC", 4, 156904},
	{"AQOR", 4, 156905},
	{"IRAC", 4, 156906},
	{"RIVERWOOD", 9, 156907},
	{"INTERNATS", 9, 156908},
	{"IMBECILE", 8, 156909},
	{"GRAVEST", 7, 156910},
	{"DIRECTORYITERATOR", 17, 156911},
	{"ZOMBA", 5, 156912},
	{"CONTAC", 6, 156913},
	{"DEFILEMENT", 10, 156914},
	{"ALLOYING", 8, 156915},
	{"BUTTING", 7, 156916},
	{"CLOB", 4, 156917},
	{"PISTOIA", 7, 156918},
	{"GOBBLED", 7, 156919},
	{"FRIEDL", 6, 156920},
	{"JIRGA", 5, 156921},
	{"PICKEREL", 8, 156922},
	{"KRAJ", 4, 156923},
	{"MRIS", 4, 156924},
	{"PLETH", 5, 156925},
	{"MINARET", 7, 156926},
	{"MALUKU", 6, 156927},
	{"POSTPRANDIAL", 12, 156928},
	{"WARDLAW", 7, 156929},
	{"TITTIE", 6, 156930},
	{"SARGASSO", 8, 156931},
	{"OMBUDSPERSON", 12, 156932},
	{"NAMELIST", 8, 156933},
	{"DICKHEAD", 8, 156934},
	{"PROBLY", 6, 156935},
	{"SYNDICATING", 11, 156936},
	{"RESVERATROL", 11, 156937},
	{"HISPANIOLA", 10, 156938},
	{"ZAPATERO", 8, 156939},
	{"GRANTON", 7, 156940},
	{"VELOX", 5, 156941},
	{"ORGASIM", 7, 156942},
	{"CATAHOULA", 9, 156943},
	{"WYBOD", 5, 156944},
	{"BRIDGTON", 8, 156945},
	{"PRODUCTFINDER", 13, 156946},
	{"DANAE", 5, 156947},
	{"XPILOT", 6, 156948},
	{"IRRIGATORS", 10, 156949},
	{"GVHD", 4, 156950},
	{"XRAN", 4, 156951},
	{"UMSK", 4, 156952},
	{"THCC", 4, 156953},
	{"RKYW", 4, 156954},
	{"PHEF", 4, 156955},
	{"PCIO", 4, 156956},
	{"OLNL", 4, 156957},
	{"ODKE", 4, 156958},
	{"KYOC", 4, 156959},
	{"IFDR", 4, 156960},
	{"HRUW", 4, 156961},
	{"HPMA", 4, 156962},
	{"HMAM", 4, 156963},
	{"GYMF", 4, 156964},
	{"GWAD", 4, 156965},
	{"GILH", 4, 156966},
	{"GDIO", 4, 156967},
	{"FAZA", 4, 156968},
	{"EDLL", 4, 156969},
	{"DZEA", 4, 156970},
	{"DSOK", 4, 156971},
	{"DDLA", 4, 156972},
	{"CSUI", 4, 156973},
	{"BYSD", 4, 156974},
	{"ANML", 4, 156975},
	{"GOTHIKA", 7, 156976},
	{"MODLOGAN", 8, 156977},
	{"LAROUSSE", 8, 156978},
	{"MASARU", 6, 156979},
	{"CONCEIVES", 9, 156980},
	{"CLEANINGS", 9, 156981},
	{"NESARA", 6, 156982},
	{"CONDADO", 7, 156983},
	{"ROSATI", 6, 156984},
	{"TOWNSFOLK", 9, 156985},
	{"ECUSA", 5, 156986},
	{"CNNTEXT", 7, 156987},
	{"ADULTES", 7, 156988},
	{"EATHER", 6, 156989},
	{"HOLMEN", 6, 156990},
	{"XERO", 4, 156991},
	{"ESQUIMALT", 9, 156992},
	{"DENARIUS", 8, 156993},
	{"AFFLICTS", 8, 156994},
	{"RBP", 3, 156995},
	{"ABUZZ", 5, 156996},
	{"SHUR", 4, 156997},
	{"THINNESS", 8, 156998},
	{"ONASSIS", 7, 156999},
	{"AYAHUASCA", 9, 157000},
	{"CUPOLAS", 7, 157001},
	{"FELCO", 5, 157002},
	{"SKEWING", 7, 157003},
	{"DICHLOROETHANE", 14, 157004},
	{"UPLOADERS", 9, 157005},
	{"COUNTERACTING", 13, 157006},
	{"MARILLA", 7, 157007},
	{"SESOTHO", 7, 157008},
	{"DEMILITARIZATION", 16, 157009},
	{"KDECORE", 7, 157010},
	{"DISCHORD", 8, 157011},
	{"SUTTLE", 6, 157012},
	{"MUSIL", 5, 157013},
	{"KFZ", 3, 157014},
	{"GOLDY", 5, 157015},
	{"RAMSHACKLE", 10, 157016},
	{"ALKYD", 5, 157017},
	{"ULLAPOOL", 8, 157018},
	{"OUELLET", 7, 157019},
	{"DULLNESS", 8, 157020},
	{"OXIMETRY", 8, 157021},
	{"SYLLOGISM", 9, 157022},
	{"SCRUSHY", 7, 157023},
	{"CALERA", 6, 157024},
	{"DENITION", 8, 157025},
	{"WRENCHED", 8, 157026},
	{"WERTZ", 5, 157027},
	{"GIOVANE", 7, 157028},
	{"WINTHER", 7, 157029},
	{"ZECH", 4, 157030},
	{"DOMEXCEPTION", 12, 157031},
	{"USURPING", 8, 157032},
	{"DERMABLEND", 10, 157033},
	{"UTMP", 4, 157034},
	{"VENTUS", 6, 157035},
	{"JMETER", 6, 157036},
	{"CCPA", 4, 157037},
	{"AROUSES", 7, 157038},
	{"AUGUSTINIAN", 11, 157039},
	{"SUBASSEMBLIES", 13, 157040},
	{"SPUDS", 5, 157041},
	{"LINGUISTIQUE", 12, 157042},
	{"GDV", 3, 157043},
	{"ZBAC", 4, 157044},
	{"UOIW", 4, 157045},
	{"ULKU", 4, 157046},
	{"UGTA", 4, 157047},
	{"TLTD", 4, 157048},
	{"RIXP", 4, 157049},
	{"OCDS", 4, 157050},
	{"MUPG", 4, 157051},
	{"LFWR", 4, 157052},
	{"DMAF", 4, 157053},
	{"AURG", 4, 157054},
	{"AROJ", 4, 157055},
	{"FOXHOLES", 8, 157056},
	{"FOCUSSES", 8, 157057},
	{"SCALD", 5, 157058},
	{"COREG", 5, 157059},
	{"REMOTEEXCEPTION", 15, 157060},
	{"FESTO", 5, 157061},
	{"MESYLATE", 8, 157062},
	{"PUMPIN", 6, 157063},
	{"KURLAND", 7, 157064},
	{"USANA", 5, 157065},
	{"TILAK", 5, 157066},
	{"RODOLPHE", 8, 157067},
	{"FOLIATION", 9, 157068},
	{"BURNESS", 7, 157069},
	{"STEINAR", 7, 157070},
	{"TYERS", 5, 157071},
	{"BICK", 4, 157072},
	{"SLRN", 4, 157073},
	{"REVELERS", 8, 157074},
	{"HELIOTROPE", 10, 157075},
	{"LOONG", 5, 157076},
	{"TAGAMET", 7, 157077},
	{"HALIM", 5, 157078},
	{"GULLEY", 6, 157079},
	{"AQUILINE", 8, 157080},
	{"MMDS", 4, 157081},
	{"SUPRISING", 9, 157082},
	{"FIDDLED", 7, 157083},
	{"KUNSTLER", 8, 157084},
	{"BUTZ", 4, 157085},
	{"HYPERNIA", 8, 157086},
	{"CELSO", 5, 157087},
	{"ADERANT", 7, 157088},
	{"GIFY", 4, 157089},
	{"BSOD", 4, 157090},
	{"UNDECIDABLE", 11, 157091},
	{"IMAGINARIUM", 11, 157092},
	{"SATURATES", 9, 157093},
	{"GOLEMAN", 7, 157094},
	{"GAMBIAE", 7, 157095},
	{"BOOKSHARE", 9, 157096},
	{"HOTDOCS", 7, 157097},
	{"WIGTON", 6, 157098},
	{"GOTCHAS", 7, 157099},
	{"FOGLE", 5, 157100},
	{"HATCHLING", 9, 157101},
	{"SEAHAM", 6, 157102},
	{"YNPA", 4, 157103},
	{"WWCH", 4, 157104},
	{"WCEO", 4, 157105},
	{"TVPE", 4, 157106},
	{"SDAZ", 4, 157107},
	{"ONMM", 4, 157108},
	{"LBSW", 4, 157109},
	{"HWAC", 4, 157110},
	{"HEZC", 4, 157111},
	{"FSBY", 4, 157112},
	{"ESLD", 4, 157113},
	{"BBOA", 4, 157114},
	{"ANXR", 4, 157115},
	{"REAPERS", 7, 157116},
	{"SYMTOMS", 7, 157117},
	{"TIGERHAWK", 9, 157118},
	{"SYBERIA", 7, 157119},
	{"PARKFIELD", 9, 157120},
	{"COMRIE", 6, 157121},
	{"MILLBANK", 8, 157122},
	{"OFFICELOCATIONS", 15, 157123},
	{"LASKA", 5, 157124},
	{"BJJ", 3, 157125},
	{"APRENDER", 8, 157126},
	{"NAVASOTA", 8, 157127},
	{"PENNWELL", 8, 157128},
	{"AGRE", 4, 157129},
	{"WORDREFERENCE", 13, 157130},
	{"SBML", 4, 157131},
	{"TWOFTPD", 7, 157132},
	{"MOLDERS", 7, 157133},
	{"DIAGN", 5, 157134},
	{"UNCOUTH", 7, 157135},
	{"ALLEIN", 6, 157136},
	{"UCABLES", 7, 157137},
	{"SOKOBAN", 7, 157138},
	{"SERGER", 6, 157139},
	{"DIVESTER", 8, 157140},
	{"DAISAKU", 7, 157141},
	{"DAUBER", 6, 157142},
	{"AZUMANGA", 8, 157143},
	{"LADER", 5, 157144},
	{"MASSAC", 6, 157145},
	{"CAPTAINCY", 9, 157146},
	{"RELICT", 6, 157147},
	{"BUSINESSOBJECTS", 15, 157148},
	{"PAEDIATRICIAN", 13, 157149},
	{"OBERSTAR", 8, 157150},
	{"TRELLIAN", 8, 157151},
	{"GETIMAGESIZE", 12, 157152},
	{"AMDMB", 5, 157153},
	{"WHIMPERING", 10, 157154},
	{"RELOJ", 5, 157155},
	{"ENRL", 4, 157156},
	{"JDRF", 4, 157157},
	{"BRYMAN", 6, 157158},
	{"EUROSTOXX", 9, 157159},
	{"VIEWSTATE", 9, 157160},
	{"TIMOLOL", 7, 157161},
	{"LEHMER", 6, 157162},
	{"HUGGY", 5, 157163},
	{"SOURAV", 6, 157164},
	{"PHOTOGRAPHICA", 13, 157165},
	{"FRONTRUNNER", 11, 157166},
	{"BURBERRYS", 9, 157167},
	{"GEODESICS", 9, 157168},
	{"MEDIANTE", 8, 157169},
	{"YUKR", 4, 157170},
	{"XUNT", 4, 157171},
	{"XPUR", 4, 157172},
	{"UIFI", 4, 157173},
	{"UAGM", 4, 157174},
	{"RUJA", 4, 157175},
	{"OFXE", 4, 157176},
	{"MPOE", 4, 157177},
	{"MDAD", 4, 157178},
	{"KAAC", 4, 157179},
	{"IZCO", 4, 157180},
	{"HDVI", 4, 157181},
	{"GPOK", 4, 157182},
	{"GELV", 4, 157183},
	{"FFVO", 4, 157184},
	{"DPUD", 4, 157185},
	{"DFUC", 4, 157186},
	{"ANCZ", 4, 157187},
	{"HADLEIGH", 8, 157188},
	{"MICHALSKI", 9, 157189},
	{"SKINK", 5, 157190},
	{"VALDERRAMA", 10, 157191},
	{"PHILBRICK", 9, 157192},
	{"ELEAZAR", 7, 157193},
	{"CONSTANTA", 9, 157194},
	{"RELAXATIONS", 11, 157195},
	{"LUNS", 4, 157196},
	{"STENCILED", 9, 157197},
	{"BILAN", 5, 157198},
	{"RCSB", 4, 157199},
	{"HORNSEA", 7, 157200},
	{"RAMIE", 5, 157201},
	{"TROAN", 5, 157202},
	{"BELLONA", 7, 157203},
	{"WYLE", 4, 157204},
	{"GRIPPERS", 8, 157205},
	{"NIPOMO", 6, 157206},
	{"SAQIB", 5, 157207},
	{"INTENSIVES", 10, 157208},
	{"GLUTARALDEHYDE", 14, 157209},
	{"LYCOPERSICON", 12, 157210},
	{"CAMBIOS", 7, 157211},
	{"TURTLEDOVE", 10, 157212},
	{"PEOP", 4, 157213},
	{"SALMETEROL", 10, 157214},
	{"ETTINGER", 8, 157215},
	{"SONICSTAGE", 10, 157216},
	{"PORTENT", 7, 157217},
	{"SHORTHANDED", 11, 157218},
	{"UNIVERSO", 8, 157219},
	{"GWOT", 4, 157220},
	{"BHAGAVAN", 8, 157221},
	{"VDM", 3, 157222},
	{"LIBGD", 5, 157223},
	{"ENGINEE", 7, 157224},
	{"BOJANGLES", 9, 157225},
	{"TRIPATHI", 8, 157226},
	{"GUNNS", 5, 157227},
	{"EZIMERCHANT", 11, 157228},
	{"OPTIX", 5, 157229},
	{"FATTEN", 6, 157230},
	{"AFILLIATE", 9, 157231},
	{"LIBPERL", 7, 157232},
	{"AKTIV", 5, 157233},
	{"COVERDALE", 9, 157234},
	{"ARRA", 4, 157235},
	{"LOCKOUTS", 8, 157236},
	{"IFTRUE", 6, 157237},
	{"CROSSLY", 7, 157238},
	{"STAGNATED", 9, 157239},
	{"YITZ", 4, 157240},
	{"XTEP", 4, 157241},
	{"UYPE", 4, 157242},
	{"UBYO", 4, 157243},
	{"TOCF", 4, 157244},
	{"RYZO", 4, 157245},
	{"RNDT", 4, 157246},
	{"RDUF", 4, 157247},
	{"RCUE", 4, 157248},
	{"PYES", 4, 157249},
	{"PPSB", 4, 157250},
	{"ORVU", 4, 157251},
	{"MYMC", 4, 157252},
	{"MIXM", 4, 157253},
	{"MEZW", 4, 157254},
	{"FSAK", 4, 157255},
	{"FIVA", 4, 157256},
	{"FFPH", 4, 157257},
	{"EZPE", 4, 157258},
	{"EPMW", 4, 157259},
	{"DMCI", 4, 157260},
	{"BRUZ", 4, 157261},
	{"AZIW", 4, 157262},
	{"AWIW", 4, 157263},
	{"TUREK", 5, 157264},
	{"TODMORDEN", 9, 157265},
	{"BLABBER", 7, 157266},
	{"MONTANARO", 9, 157267},
	{"HADST", 5, 157268},
	{"DANIWEB", 7, 157269},
	{"BASHMAN", 7, 157270},
	{"FIER", 4, 157271},
	{"MIRRORMASK", 10, 157272},
	{"IMGS", 4, 157273},
	{"FFII", 4, 157274},
	{"PREFINISHED", 11, 157275},
	{"POLYTECHNICS", 12, 157276},
	{"GOWDA", 5, 157277},
	{"THERMUS", 7, 157278},
	{"SUPERSCALAR", 11, 157279},
	{"FINGERN", 7, 157280},
	{"ANTIPASTO", 9, 157281},
	{"WHOLISTIC", 9, 157282},
	{"BRENDEL", 7, 157283},
	{"WRISTLET", 8, 157284},
	{"SYTEMS", 6, 157285},
	{"BODACIOUS", 9, 157286},
	{"WESTMEAD", 8, 157287},
	{"GALIANO", 7, 157288},
	{"ADMONISH", 8, 157289},
	{"TAIZHOU", 7, 157290},
	{"MUSIX", 5, 157291},
	{"ELLISVILLE", 10, 157292},
	{"POWERVAULT", 10, 157293},
	{"COAUTHORED", 10, 157294},
	{"FUNCTIONALIZED", 14, 157295},
	{"HOMECHOICE", 10, 157296},
	{"SEROCONVERSION", 14, 157297},
	{"GADI", 4, 157298},
	{"VREF", 4, 157299},
	{"FAKEROOT", 8, 157300},
	{"RUNCO", 5, 157301},
	{"ROWEN", 5, 157302},
	{"APPC", 4, 157303},
	{"GRIBBLE", 7, 157304},
	{"RAMAH", 5, 157305},
	{"CHOUINARD", 9, 157306},
	{"ABERFELDY", 9, 157307},
	{"WHIPPANY", 8, 157308},
	{"IFRC", 4, 157309},
	{"TUJUNGA", 7, 157310},
	{"WIXEN", 5, 157311},
	{"CONNOTES", 8, 157312},
	{"XSOU", 4, 157313},
	{"UNIU", 4, 157314},
	{"UICA", 4, 157315},
	{"TOUF", 4, 157316},
	{"SCUC", 4, 157317},
	{"RZBU", 4, 157318},
	{"RCBU", 4, 157319},
	{"PHUK", 4, 157320},
	{"MRAV", 4, 157321},
	{"MPGO", 4, 157322},
	{"MOPI", 4, 157323},
	{"MHID", 4, 157324},
	{"LOGJ", 4, 157325},
	{"LKFA", 4, 157326},
	{"LIPN", 4, 157327},
	{"KAMS", 4, 157328},
	{"FSIK", 4, 157329},
	{"FGUS", 4, 157330},
	{"DDIQ", 4, 157331},
	{"CWRA", 4, 157332},
	{"AZZD", 4, 157333},
	{"PALEONTOLOGISTS", 15, 157334},
	{"BUCA", 4, 157335},
	{"MCKIBBEN", 8, 157336},
	{"TROPOPAUSE", 10, 157337},
	{"ESPOUSING", 9, 157338},
	{"CURVACEOUS", 10, 157339},
	{"BATTLEMENTS", 11, 157340},
	{"TRANSGRESS", 10, 157341},
	{"BUPIVACAINE", 11, 157342},
	{"LEANT", 5, 157343},
	{"DOMIN", 5, 157344},
	{"BOWN", 4, 157345},
	{"CYHOEDDUS", 9, 157346},
	{"EXPONENTIATION", 14, 157347},
	{"BLOWHARDS", 9, 157348},
	{"ZARLINK", 7, 157349},
	{"LANK", 4, 157350},
	{"GENATLAS", 8, 157351},
	{"CLAIREMONT", 10, 157352},
	{"OPENCA", 6, 157353},
	{"STEINHARDT", 10, 157354},
	{"TAILER", 6, 157355},
	{"RAMIS", 5, 157356},
	{"VAPORIZED", 9, 157357},
	{"GOVERNORSHIP", 12, 157358},
	{"QAZI", 4, 157359},
	{"SERVEURS", 8, 157360},
	{"KOEPI", 5, 157361},
	{"BLACKLINE", 9, 157362},
	{"TOLLED", 6, 157363},
	{"ERGOT", 5, 157364},
	{"NARESH", 6, 157365},
	{"FRAMA", 5, 157366},
	{"SPORRANS", 8, 157367},
	{"FORTIGATE", 9, 157368},
	{"AKEMI", 5, 157369},
	{"ALIGARH", 7, 157370},
	{"OPENFACTS", 9, 157371},
	{"SCHUMPETER", 10, 157372},
	{"MSGT", 4, 157373},
	{"BACOLOD", 7, 157374},
	{"NUVO", 4, 157375},
	{"BLACKFIN", 8, 157376},
	{"YELENA", 6, 157377},
	{"VLR", 3, 157378},
	{"REGRESSORS", 10, 157379},
	{"CASTLEBERRY", 11, 157380},
	{"BREIL", 5, 157381},
	{"YRAA", 4, 157382},
	{"UKOI", 4, 157383},
	{"TKLE", 4, 157384},
	{"SLEL", 4, 157385},
	{"PURF", 4, 157386},
	{"PGRI", 4, 157387},
	{"OVIM", 4, 157388},
	{"NTPM", 4, 157389},
	{"NCKA", 4, 157390},
	{"MBBL", 4, 157391},
	{"LSUW", 4, 157392},
	{"JIAB", 4, 157393},
	{"HTLU", 4, 157394},
	{"EZMU", 4, 157395},
	{"EIWR", 4, 157396},
	{"EBSW", 4, 157397},
	{"DJUG", 4, 157398},
	{"DDSD", 4, 157399},
	{"COYT", 4, 157400},
	{"AZAG", 4, 157401},
	{"BACULOVIRUS", 11, 157402},
	{"ZEALOUSLY", 9, 157403},
	{"MATTAFIX", 8, 157404},
	{"BAIKONUR", 8, 157405},
	{"REPATRIATE", 10, 157406},
	{"HARDS", 5, 157407},
	{"PNEUMONITIS", 11, 157408},
	{"JCD", 3, 157409},
	{"HIROKO", 6, 157410},
	{"MIDAIR", 6, 157411},
	{"EDOARDO", 7, 157412},
	{"DOWAGER", 7, 157413},
	{"RIBOZYME", 8, 157414},
	{"JAXA", 4, 157415},
	{"PUBLICHEALTH", 12, 157416},
	{"TSUCHIYA", 8, 157417},
	{"HARALSON", 8, 157418},
	{"GASTEIN", 7, 157419},
	{"ENVOYEZ", 7, 157420},
	{"SMUDGING", 8, 157421},
	{"EVAP", 4, 157422},
	{"WERKEN", 6, 157423},
	{"BUSKIRK", 7, 157424},
	{"SQUEALED", 8, 157425},
	{"ENCP", 4, 157426},
	{"USPQ", 4, 157427},
	{"ABADI", 5, 157428},
	{"THEMATICS", 9, 157429},
	{"NEUROSURGEONS", 13, 157430},
	{"SEROTONERGIC", 12, 157431},
	{"TOWNLAND", 8, 157432},
	{"CONVENTS", 8, 157433},
	{"ROMANE", 6, 157434},
	{"WNBC", 4, 157435},
	{"STOCKARD", 8, 157436},
	{"EULALIA", 7, 157437},
	{"EQUIPTMENT", 10, 157438},
	{"BOEKHANDEL", 10, 157439},
	{"PAGEPRO", 7, 157440},
	{"PHIFER", 6, 157441},
	{"XDG", 3, 157442},
	{"CINCINATTI", 10, 157443},
	{"DATASAFE", 8, 157444},
	{"NETIX", 5, 157445},
	{"VERTRAG", 7, 157446},
	{"THERMADOR", 9, 157447},
	{"ACHOS", 5, 157448},
	{"OMID", 4, 157449},
	{"UPNU", 4, 157450},
	{"TCOK", 4, 157451},
	{"ROVT", 4, 157452},
	{"PGOR", 4, 157453},
	{"NVOR", 4, 157454},
	{"MBCH", 4, 157455},
	{"LYOI", 4, 157456},
	{"KKIA", 4, 157457},
	{"KCYC", 4, 157458},
	{"IVOW", 4, 157459},
	{"HUBC", 4, 157460},
	{"HEZR", 4, 157461},
	{"EYOM", 4, 157462},
	{"EIRZ", 4, 157463},
	{"ECEV", 4, 157464},
	{"DOHU", 4, 157465},
	{"DDUF", 4, 157466},
	{"DAKU", 4, 157467},
	{"APIK", 4, 157468},
	{"APHM", 4, 157469},
	{"SHINEY", 6, 157470},
	{"BISECTION", 9, 157471},
	{"BENIFIT", 7, 157472},
	{"SISKIND", 7, 157473},
	{"MIGLIORE", 8, 157474},
	{"TRYPANOSOMIASIS", 15, 157475},
	{"WORKABILITY", 11, 157476},
	{"MOBILEOUTLET", 12, 157477},
	{"KALPANA", 7, 157478},
	{"BROOKVALE", 9, 157479},
	{"USURPER", 7, 157480},
	{"CESSNOCK", 8, 157481},
	{"PAPAIN", 6, 157482},
	{"FREEGEEK", 8, 157483},
	{"PROTPARAM", 9, 157484},
	{"FLATLEY", 7, 157485},
	{"PTFS", 4, 157486},
	{"TRIVALENT", 9, 157487},
	{"PHOSPHOGLYCERATE", 16, 157488},
	{"RECITATIONS", 11, 157489},
	{"BRENDEN", 7, 157490},
	{"INCULCATE", 9, 157491},
	{"OLLA", 4, 157492},
	{"WAMP", 4, 157493},
	{"EASTCHESTER", 11, 157494},
	{"MUNCY", 5, 157495},
	{"STIEGLITZ", 9, 157496},
	{"EGLISE", 6, 157497},
	{"LAJOIE", 6, 157498},
	{"TCLTK", 5, 157499},
	{"JAKOBSEN", 8, 157500},
	{"SENTIENCE", 9, 157501},
	{"GULBIS", 6, 157502},
	{"ADMINSTRATOR", 12, 157503},
	{"CALICE", 6, 157504},
	{"DIOXYGENASE", 11, 157505},
	{"IMPETIGO", 8, 157506},
	{"CASERTA", 7, 157507},
	{"CUVIER", 6, 157508},
	{"BLUT", 4, 157509},
	{"GRAHAMS", 7, 157510},
	{"IWATE", 5, 157511},
	{"MASSENET", 8, 157512},
	{"GOLFE", 5, 157513},
	{"TORTURERS", 9, 157514},
	{"GURKHA", 6, 157515},
	{"WYANDOT", 7, 157516},
	{"TARIK", 5, 157517},
	{"MONEYGRAM", 9, 157518},
	{"FUKIN", 5, 157519},
	{"SHUM", 4, 157520},
	{"DIATOMACEOUS", 12, 157521},
	{"DRACHMAS", 8, 157522},
	{"OHIOANS", 7, 157523},
	{"INDEMNIFYING", 12, 157524},
	{"HOMESTAYS", 9, 157525},
	{"CURREN", 6, 157526},
	{"MISCLASSIFICATION", 17, 157527},
	{"VINU", 4, 157528},
	{"TDBA", 4, 157529},
	{"RDIX", 4, 157530},
	{"NZEP", 4, 157531},
	{"LYIP", 4, 157532},
	{"LFHU", 4, 157533},
	{"IXOP", 4, 157534},
	{"HBAU", 4, 157535},
	{"EMRG", 4, 157536},
	{"DOZO", 4, 157537},
	{"DCOY", 4, 157538},
	{"DAQS", 4, 157539},
	{"CIDD", 4, 157540},
	{"CEYH", 4, 157541},
	{"ARRD", 4, 157542},
	{"AMKU", 4, 157543},
	{"HELOISE", 7, 157544},
	{"HASTIE", 6, 157545},
	{"NORWEST", 7, 157546},
	{"WIER", 4, 157547},
	{"PMDF", 4, 157548},
	{"ANALEROTIK", 10, 157549},
	{"BARGHOUTI", 9, 157550},
	{"ROSENDERG", 9, 157551},
	{"GLYBURIDE", 9, 157552},
	{"HEFFALUMP", 9, 157553},
	{"CONFORTABLE", 11, 157554},
	{"REIMBURSES", 10, 157555},
	{"FILLION", 7, 157556},
	{"AMBEDKAR", 8, 157557},
	{"RUMSON", 6, 157558},
	{"LIVIGNO", 7, 157559},
	{"ALIMENTARIUS", 12, 157560},
	{"SIVER", 5, 157561},
	{"BURCHELL", 8, 157562},
	{"YELLOWBRIX", 10, 157563},
	{"DECISIONAL", 10, 157564},
	{"TROIE", 5, 157565},
	{"ULTIMI", 6, 157566},
	{"OPPORTUNISTS", 12, 157567},
	{"PETULA", 6, 157568},
	{"NEUSPEED", 8, 157569},
	{"UNDESIGNATED", 12, 157570},
	{"PELI", 4, 157571},
	{"AANBIEDINGEN", 12, 157572},
	{"LASWELL", 7, 157573},
	{"PARIKH", 6, 157574},
	{"UNIMPAIRED", 10, 157575},
	{"VISTORS", 7, 157576},
	{"CRAZIER", 7, 157577},
	{"MARRICKVILLE", 12, 157578},
	{"FOTR", 4, 157579},
	{"HILLSVILLE", 10, 157580},
	{"GENEWEB", 7, 157581},
	{"QUESTIA", 7, 157582},
	{"GAMELOFT", 8, 157583},
	{"SEARCHBLOG", 10, 157584},
	{"BAPTIZING", 9, 157585},
	{"ANIMENFO", 8, 157586},
	{"MIDFOOT", 7, 157587},
	{"BALEARES", 8, 157588},
	{"BIGGRIN", 7, 157589},
	{"KERATOSIS", 9, 157590},
	{"CORPORATISM", 11, 157591},
	{"MCAL", 4, 157592},
	{"ACADEMON", 8, 157593},
	{"BINDWEED", 8, 157594},
	{"LIUE", 4, 157595},
	{"ARICEPT", 7, 157596},
	{"MADLIBS", 7, 157597},
	{"RESAMPLE", 8, 157598},
	{"FRSM", 4, 157599},
	{"TAMAYO", 6, 157600},
	{"ZASW", 4, 157601},
	{"XMIS", 4, 157602},
	{"VSYS", 4, 157603},
	{"UHOU", 4, 157604},
	{"TIKK", 4, 157605},
	{"SPPR", 4, 157606},
	{"SMOZ", 4, 157607},
	{"OMBG", 4, 157608},
	{"NVYO", 4, 157609},
	{"MPCR", 4, 157610},
	{"MMOI", 4, 157611},
	{"LIKW", 4, 157612},
	{"GMAF", 4, 157613},
	{"FBIW", 4, 157614},
	{"EKMU", 4, 157615},
	{"ECOZ", 4, 157616},
	{"BTPA", 4, 157617},
	{"YARM", 4, 157618},
	{"LINAS", 5, 157619},
	{"DCOP", 4, 157620},
	{"KHAMENEI", 8, 157621},
	{"HEEDLESS", 8, 157622},
	{"RANCOR", 6, 157623},
	{"RMV", 3, 157624},
	{"GPSCITY", 7, 157625},
	{"BUSIN", 5, 157626},
	{"TRANSCULTURAL", 13, 157627},
	{"KITON", 5, 157628},
	{"CERE", 4, 157629},
	{"ICWALES", 7, 157630},
	{"TRAVER", 6, 157631},
	{"GPGME", 5, 157632},
	{"TROTS", 5, 157633},
	{"PROVIDENTIAL", 12, 157634},
	{"WELLSTON", 8, 157635},
	{"GLADIUS", 7, 157636},
	{"RYEDALE", 7, 157637},
	{"BSDGAMES", 8, 157638},
	{"BOILERMAKER", 11, 157639},
	{"QXL", 3, 157640},
	{"EXTRAPOLATIONS", 14, 157641},
	{"WESTERBERG", 10, 157642},
	{"DEHYDROEPIANDROSTERONE", 22, 157643},
	{"OTHMAN", 6, 157644},
	{"IRELANDS", 8, 157645},
	{"HANDPHONE", 9, 157646},
	{"DIOP", 4, 157647},
	{"FREIHEIT", 8, 157648},
	{"ESTATEAPARTMENTS", 16, 157649},
	{"THURSBY", 7, 157650},
	{"KACKE", 5, 157651},
	{"PACCHETTI", 9, 157652},
	{"STABILA", 7, 157653},
	{"LOLLITA", 7, 157654},
	{"BAYLY", 5, 157655},
	{"WGC", 3, 157656},
	{"SIPPY", 5, 157657},
	{"CASC", 4, 157658},
	{"HEARTHSONG", 10, 157659},
	{"PROTSCALE", 9, 157660},
	{"TEXTFORMATTINGFAQ", 17, 157661},
	{"HOLLANDAISE", 11, 157662},
	{"NORTHVIEW", 9, 157663},
	{"MAZARRON", 8, 157664},
	{"ZKOW", 4, 157665},
	{"YBCT", 4, 157666},
	{"XHEL", 4, 157667},
	{"TBAM", 4, 157668},
	{"NIFD", 4, 157669},
	{"LYRH", 4, 157670},
	{"KYEL", 4, 157671},
	{"IKMO", 4, 157672},
	{"IFVO", 4, 157673},
	{"HGUR", 4, 157674},
	{"GKAS", 4, 157675},
	{"GALJ", 4, 157676},
	{"FKUN", 4, 157677},
	{"DKOU", 4, 157678},
	{"DIFU", 4, 157679},
	{"CULC", 4, 157680},
	{"CEZO", 4, 157681},
	{"AYEB", 4, 157682},
	{"AUMG", 4, 157683},
	{"IRINOTECAN", 10, 157684},
	{"JETAUDIO", 8, 157685},
	{"GCCADMIN", 8, 157686},
	{"DARESAY", 7, 157687},
	{"FOOTBAG", 7, 157688},
	{"MOIVE", 5, 157689},
	{"KAPITEL", 7, 157690},
	{"WYLDER", 6, 157691},
	{"MEGGINSON", 9, 157692},
	{"EASTERLING", 10, 157693},
	{"SUMMERSVILLE", 12, 157694},
	{"AVAHI", 5, 157695},
	{"CORIOLANUS", 10, 157696},
	{"EDITORES", 8, 157697},
	{"LIBERALITY", 10, 157698},
	{"RETR", 4, 157699},
	{"BALING", 6, 157700},
	{"BRITTANIA", 9, 157701},
	{"DOMEIN", 6, 157702},
	{"BRIARPATCH", 10, 157703},
	{"SABLOTRON", 9, 157704},
	{"FREETIME", 8, 157705},
	{"WINMODEM", 8, 157706},
	{"MCCLEAN", 7, 157707},
	{"RYNE", 4, 157708},
	{"DESIGNCOMMUNITY", 15, 157709},
	{"TURNBUCKLE", 10, 157710},
	{"DEOL", 4, 157711},
	{"ZCONFIG", 7, 157712},
	{"IRONHORSE", 9, 157713},
	{"DARKSTALKERS", 12, 157714},
	{"OHLONE", 6, 157715},
	{"KNURLED", 7, 157716},
	{"LABORE", 6, 157717},
	{"WORLDISROUND", 12, 157718},
	{"CHILDLINE", 9, 157719},
	{"PRINCIPES", 9, 157720},
	{"ARENDAL", 7, 157721},
	{"PASSIFLORA", 10, 157722},
	{"MALLRATS", 8, 157723},
	{"INSTATE", 7, 157724},
	{"YREX", 4, 157725},
	{"YKAP", 4, 157726},
	{"XWHA", 4, 157727},
	{"WETZ", 4, 157728},
	{"UAKI", 4, 157729},
	{"RUOF", 4, 157730},
	{"ROIK", 4, 157731},
	{"PUBO", 4, 157732},
	{"NYTV", 4, 157733},
	{"MUWA", 4, 157734},
	{"MRSN", 4, 157735},
	{"KITG", 4, 157736},
	{"GMIA", 4, 157737},
	{"GEMR", 4, 157738},
	{"FTKE", 4, 157739},
	{"FHOB", 4, 157740},
	{"BOBN", 4, 157741},
	{"ATVM", 4, 157742},
	{"PNEUMOPHILA", 11, 157743},
	{"INFM", 4, 157744},
	{"CUSHTIE", 7, 157745},
	{"TOOLSHED", 8, 157746},
	{"ACTUS", 5, 157747},
	{"UNIDATA", 7, 157748},
	{"LAFAVE", 6, 157749},
	{"GRAMA", 5, 157750},
	{"SEMAINES", 8, 157751},
	{"NEDBANK", 7, 157752},
	{"COLERAIN", 8, 157753},
	{"UPSHAW", 6, 157754},
	{"OSSIFICATION", 12, 157755},
	{"IMPERF", 6, 157756},
	{"AERSCHE", 7, 157757},
	{"STORT", 5, 157758},
	{"VASHTI", 6, 157759},
	{"KOMPRESSOR", 10, 157760},
	{"RHODIOLA", 8, 157761},
	{"INDULGES", 8, 157762},
	{"FEATHERBED", 10, 157763},
	{"BANDMATES", 9, 157764},
	{"PROSOURCE", 9, 157765},
	{"CLONEID", 7, 157766},
	{"UNTHINKING", 10, 157767},
	{"CRESOL", 6, 157768},
	{"YPC", 3, 157769},
	{"WRAGGSTER", 9, 157770},
	{"SALTMARSH", 9, 157771},
	{"CHESHIREKNICKERS", 16, 157772},
	{"TENOFOVIR", 9, 157773},
	{"WINDU", 5, 157774},
	{"LIOR", 4, 157775},
	{"CASHES", 6, 157776},
	{"INDEXERS", 8, 157777},
	{"CHERAW", 6, 157778},
	{"STANK", 5, 157779},
	{"DONTFORGETYOURCARD", 18, 157780},
	{"TUTTA", 5, 157781},
	{"MARCELLE", 8, 157782},
	{"NETPRO", 6, 157783},
	{"SEMAN", 5, 157784},
	{"CLEVENGER", 9, 157785},
	{"CUTHBERTSON", 11, 157786},
	{"DIMORPHISM", 10, 157787},
	{"AIRWALK", 7, 157788},
	{"BETTORS", 7, 157789},
	{"PEPTIDEMASS", 11, 157790},
	{"CHARMM", 6, 157791},
	{"YAAC", 4, 157792},
	{"VAGG", 4, 157793},
	{"UDII", 4, 157794},
	{"TYMP", 4, 157795},
	{"RERV", 4, 157796},
	{"PHSD", 4, 157797},
	{"ONUD", 4, 157798},
	{"OCCL", 4, 157799},
	{"NZEW", 4, 157800},
	{"NNCR", 4, 157801},
	{"NJRW", 4, 157802},
	{"NJOC", 4, 157803},
	{"MRKO", 4, 157804},
	{"LYYI", 4, 157805},
	{"LUPB", 4, 157806},
	{"IYAC", 4, 157807},
	{"ISYC", 4, 157808},
	{"FMOI", 4, 157809},
	{"DNOJ", 4, 157810},
	{"CSUG", 4, 157811},
	{"ALPT", 4, 157812},
	{"AICU", 4, 157813},
	{"BERNS", 5, 157814},
	{"VIOUS", 5, 157815},
	{"FLOSSIE", 7, 157816},
	{"FLASHMAN", 8, 157817},
	{"XYLOSE", 6, 157818},
	{"BATF", 4, 157819},
	{"IMODE", 5, 157820},
	{"EEUROPE", 7, 157821},
	{"BRANDE", 6, 157822},
	{"LEGALISATION", 12, 157823},
	{"PROTARAS", 8, 157824},
	{"PERGOLAS", 8, 157825},
	{"DEFAULTVALUE", 12, 157826},
	{"PORTLAOISE", 10, 157827},
	{"ANURAG", 6, 157828},
	{"BIOINFORMATIC", 13, 157829},
	{"INESTIMABLE", 11, 157830},
	{"HAEMATOL", 8, 157831},
	{"NOYCE", 5, 157832},
	{"NORTHPOINT", 10, 157833},
	{"MORTENSON", 9, 157834},
	{"AJMAN", 5, 157835},
	{"WHILES", 6, 157836},
	{"SAAKASHVILI", 11, 157837},
	{"NICKOLAS", 8, 157838},
	{"PAYEES", 6, 157839},
	{"BOOKHQ", 6, 157840},
	{"KEITA", 5, 157841},
	{"CONCATENATING", 13, 157842},
	{"PYRIDOXAL", 9, 157843},
	{"PIPEDREAMS", 10, 157844},
	{"JPB", 3, 157845},
	{"FISTERS", 7, 157846},
	{"INCONVENIENCED", 14, 157847},
	{"BYW", 3, 157848},
	{"SEACRH", 6, 157849},
	{"COMBES", 6, 157850},
	{"CHLAMYDIAL", 10, 157851},
	{"DUSTWRAPPER", 11, 157852},
	{"NEXCOM", 6, 157853},
	{"MICROSECOND", 11, 157854},
	{"HILLTRIBE", 9, 157855},
	{"CHARTBUSTER", 11, 157856},
	{"MUSKEGO", 7, 157857},
	{"DOTLET", 6, 157858},
	{"HANTAVIRUS", 10, 157859},
	{"NCCU", 4, 157860},
	{"HILLYARD", 8, 157861},
	{"PATRIMOINE", 10, 157862},
	{"MALINOIS", 8, 157863},
	{"TURNSTILE", 9, 157864},
	{"ULV", 3, 157865},
	{"RHIF", 4, 157866},
	{"INDUCTEE", 8, 157867},
	{"TOPROL", 6, 157868},
	{"SEPHIA", 6, 157869},
	{"DISTRUSTED", 10, 157870},
	{"QUADRENNIAL", 11, 157871},
	{"SUBTEST", 7, 157872},
	{"SCHOOLBOOK", 10, 157873},
	{"VIAVOICE", 8, 157874},
	{"REGROUPED", 9, 157875},
	{"ZKD", 3, 157876},
	{"ZJW", 3, 157877},
	{"XPQ", 3, 157878},
	{"XJF", 3, 157879},
	{"XCZ", 3, 157880},
	{"WFZ", 3, 157881},
	{"VZL", 3, 157882},
	{"VWK", 3, 157883},
	{"QFW", 3, 157884},
	{"QDQ", 3, 157885},
	{"LGQ", 3, 157886},
	{"KKQ", 3, 157887},
	{"KGQ", 3, 157888},
	{"KDQ", 3, 157889},
	{"KBZ", 3, 157890},
	{"JYB", 3, 157891},
	{"JXW", 3, 157892},
	{"ZINW", 4, 157893},
	{"YDUA", 4, 157894},
	{"XWEB", 4, 157895},
	{"WAPU", 4, 157896},
	{"RMHU", 4, 157897},
	{"RAYY", 4, 157898},
	{"PVOC", 4, 157899},
	{"PTHB", 4, 157900},
	{"NERZ", 4, 157901},
	{"MSEF", 4, 157902},
	{"MOOC", 4, 157903},
	{"LOKL", 4, 157904},
	{"LIYU", 4, 157905},
	{"LCTO", 4, 157906},
	{"LBUB", 4, 157907},
	{"KUYU", 4, 157908},
	{"IVYS", 4, 157909},
	{"IKMI", 4, 157910},
	{"DUCC", 4, 157911},
	{"CWOO", 4, 157912},
	{"BUPT", 4, 157913},
	{"AXSU", 4, 157914},
	{"SLIVEN", 6, 157915},
	{"PRIE", 4, 157916},
	{"FREEK", 5, 157917},
	{"STELIOS", 7, 157918},
	{"FOLKTALE", 8, 157919},
	{"DEERHOOF", 8, 157920},
	{"PYRMONT", 7, 157921},
	{"DICTIONAR", 9, 157922},
	{"SENGE", 5, 157923},
	{"TULLIUS", 7, 157924},
	{"THESPIAN", 8, 157925},
	{"BCIS", 4, 157926},
	{"KWIN", 4, 157927},
	{"TEKEN", 5, 157928},
	{"INTPTR", 6, 157929},
	{"GUTLESS", 7, 157930},
	{"ELECTRICSHOCK", 13, 157931},
	{"ACED", 4, 157932},
	{"PULPING", 7, 157933},
	{"COMMSDESIGN", 11, 157934},
	{"TORROX", 6, 157935},
	{"DESIPRAMINE", 11, 157936},
	{"HUDAK", 5, 157937},
	{"BRICKLAYERS", 11, 157938},
	{"SCRIPTORIUM", 11, 157939},
	{"POLYURETHANES", 13, 157940},
	{"USSG", 4, 157941},
	{"MARSTERS", 8, 157942},
	{"DROR", 4, 157943},
	{"CESKE", 5, 157944},
	{"NYISUTTER", 9, 157945},
	{"LAMIN", 5, 157946},
	{"ENBREL", 6, 157947},
	{"CAPULET", 7, 157948},
	{"AEGON", 5, 157949},
	{"ODORANT", 7, 157950},
	{"MOHAWKS", 7, 157951},
	{"CRUCIBLES", 9, 157952},
	{"IGNOBLE", 7, 157953},
	{"HOBGOBLIN", 9, 157954},
	{"GUMBEL", 6, 157955},
	{"TAZZ", 4, 157956},
	{"DEPMOD", 6, 157957},
	{"WITTIG", 6, 157958},
	{"SUBSTAN", 7, 157959},
	{"SOMERSWORTH", 11, 157960},
	{"HOMELITE", 8, 157961},
	{"CHELATED", 8, 157962},
	{"HEMATOL", 7, 157963},
	{"FRANKISH", 8, 157964},
	{"CARLSTADT", 9, 157965},
	{"YNCE", 4, 157966},
	{"XLEG", 4, 157967},
	{"VCRE", 4, 157968},
	{"UZTH", 4, 157969},
	{"TVAG", 4, 157970},
	{"SILP", 4, 157971},
	{"RRIH", 4, 157972},
	{"PPYJ", 4, 157973},
	{"NSCY", 4, 157974},
	{"NLCD", 4, 157975},
	{"LYAE", 4, 157976},
	{"HLID", 4, 157977},
	{"FGES", 4, 157978},
	{"FCTI", 4, 157979},
	{"DSMR", 4, 157980},
	{"DHEQ", 4, 157981},
	{"ANZB", 4, 157982},
	{"WIZDATA", 7, 157983},
	{"WBB", 3, 157984},
	{"FRANKLINTON", 11, 157985},
	{"TRLOG", 5, 157986},
	{"SBORRATA", 8, 157987},
	{"JEROBOAM", 8, 157988},
	{"SUBALGEBRA", 10, 157989},
	{"OULX", 4, 157990},
	{"DOPPELGANGER", 12, 157991},
	{"TIMIDLY", 7, 157992},
	{"RIGHTIST", 8, 157993},
	{"LANCETTI", 8, 157994},
	{"BRUSCHI", 7, 157995},
	{"SUPERBLOCK", 10, 157996},
	{"LURKED", 6, 157997},
	{"CALENDARSCRIPT", 14, 157998},
	{"UCLUELET", 8, 157999},
	{"GREYISH", 7, 158000},
	{"GEOIP", 5, 158001},
	{"CLEARCUT", 8, 158002},
	{"POULAN", 6, 158003},
	{"TOPTEN", 6, 158004},
	{"SPIRA", 5, 158005},
	{"SWIRE", 5, 158006},
	{"SALLAM", 6, 158007},
	{"RICETTE", 7, 158008},
	{"GOLDLINE", 8, 158009},
	{"WEATHERBOY", 10, 158010},
	{"IMITATIVE", 9, 158011},
	{"RDAS", 4, 158012},
	{"CIENTLY", 7, 158013},
	{"SHUPPA", 6, 158014},
	{"IGUAL", 5, 158015},
	{"POINSETTIAS", 11, 158016},
	{"CONCORDANT", 10, 158017},
	{"VISEGRAD", 8, 158018},
	{"RHODIA", 6, 158019},
	{"CAUTA", 5, 158020},
	{"MAZER", 5, 158021},
	{"MINKY", 5, 158022},
	{"INDULGELINGERIE", 15, 158023},
	{"FLIPCHART", 9, 158024},
	{"PEPTIDECUTTER", 13, 158025},
	{"GRIMMER", 7, 158026},
	{"REDUCTIONIST", 12, 158027},
	{"MASHER", 6, 158028},
	{"SCOTIAN", 7, 158029},
	{"THRUXTON", 8, 158030},
	{"TERRIGAL", 8, 158031},
	{"CONLIN", 6, 158032},
	{"LOOKERS", 7, 158033},
	{"PAGODAS", 7, 158034},
	{"NULLAM", 6, 158035},
	{"RACEPOINTS", 10, 158036},
	{"MAXIMISES", 9, 158037},
	{"GANZE", 5, 158038},
	{"HOBBLE", 6, 158039},
	{"REBECA", 6, 158040},
	{"ZIMU", 4, 158041},
	{"YDDA", 4, 158042},
	{"WCIV", 4, 158043},
	{"VEZH", 4, 158044},
	{"UYCH", 4, 158045},
	{"UKAP", 4, 158046},
	{"UGOH", 4, 158047},
	{"UGAF", 4, 158048},
	{"TCSU", 4, 158049},
	{"SIPG", 4, 158050},
	{"SILW", 4, 158051},
	{"SCOZ", 4, 158052},
	{"RSNY", 4, 158053},
	{"RNYN", 4, 158054},
	{"RCYI", 4, 158055},
	{"NMYJ", 4, 158056},
	{"NKIK", 4, 158057},
	{"MCAH", 4, 158058},
	{"LLUK", 4, 158059},
	{"KJAS", 4, 158060},
	{"IRUK", 4, 158061},
	{"INCV", 4, 158062},
	{"IGFL", 4, 158063},
	{"HOFQ", 4, 158064},
	{"FVAU", 4, 158065},
	{"FICQ", 4, 158066},
	{"EYIL", 4, 158067},
	{"EPEB", 4, 158068},
	{"EKUW", 4, 158069},
	{"EBVI", 4, 158070},
	{"DMAW", 4, 158071},
	{"COLH", 4, 158072},
	{"CBEE", 4, 158073},
	{"BSGA", 4, 158074},
	{"DEXIGNER", 8, 158075},
	{"BIOSC", 5, 158076},
	{"BURJ", 4, 158077},
	{"BIBLIOMANIA", 11, 158078},
	{"CDPARANOIA", 10, 158079},
	{"ROTEN", 5, 158080},
	{"KANNST", 6, 158081},
	{"STELLENANGEBOT", 14, 158082},
	{"RUNING", 6, 158083},
	{"MIRCOSOFT", 9, 158084},
	{"ESTHETICIAN", 11, 158085},
	{"DISTCHECK", 9, 158086},
	{"PLATER", 6, 158087},
	{"YASIR", 5, 158088},
	{"DESKTOPX", 8, 158089},
	{"TILLS", 5, 158090},
	{"RXPG", 4, 158091},
	{"GRAVITON", 8, 158092},
	{"NAZIM", 5, 158093},
	{"WWU", 3, 158094},
	{"KANGAS", 6, 158095},
	{"REPENTANT", 9, 158096},
	{"POVRAY", 6, 158097},
	{"CHOPSTICK", 9, 158098},
	{"REISHI", 6, 158099},
	{"ORALVERKEHR", 11, 158100},
	{"TRAWLS", 6, 158101},
	{"DISSECTIONS", 11, 158102},
	{"TELECOMMUTERS", 13, 158103},
	{"PWLLHELI", 8, 158104},
	{"COMITE", 6, 158105},
	{"BEAZER", 6, 158106},
	{"ICONOCLASTIC", 12, 158107},
	{"EGFP", 4, 158108},
	{"WEINHEIM", 8, 158109},
	{"AUTOM", 5, 158110},
	{"HOLMSTROM", 9, 158111},
	{"FAIRBURY", 8, 158112},
	{"DIABLOS", 7, 158113},
	{"GABRIOLA", 8, 158114},
	{"MOBIPACK", 8, 158115},
	{"GLENNON", 7, 158116},
	{"DURCHGEFICKT", 12, 158117},
	{"SHOUTOUT", 8, 158118},
	{"BACKISSUES", 10, 158119},
	{"WOODLOT", 7, 158120},
	{"MEANNESS", 8, 158121},
	{"PERFS", 5, 158122},
	{"SWANLEY", 7, 158123},
	{"SATIVUM", 7, 158124},
	{"HARMANKARDON", 12, 158125},
	{"GOOGLISMS", 9, 158126},
	{"ERDMANN", 7, 158127},
	{"BLACKALL", 8, 158128},
	{"SAESNEG", 7, 158129},
	{"WEGE", 4, 158130},
	{"ATHERSTONE", 10, 158131},
	{"ROUGHRIDERS", 11, 158132},
	{"IMPUESTO", 8, 158133},
	{"ARBOREAL", 8, 158134},
	{"FRANKL", 6, 158135},
	{"MIXON", 5, 158136},
	{"WILLIES", 7, 158137},
	{"YEEL", 4, 158138},
	{"XINB", 4, 158139},
	{"TUEL", 4, 158140},
	{"SKDI", 4, 158141},
	{"SGOG", 4, 158142},
	{"SCME", 4, 158143},
	{"PWAI", 4, 158144},
	{"OVFR", 4, 158145},
	{"OKGU", 4, 158146},
	{"NCYY", 4, 158147},
	{"MMHA", 4, 158148},
	{"MKEP", 4, 158149},
	{"LYMS", 4, 158150},
	{"LEWP", 4, 158151},
	{"IBWE", 4, 158152},
	{"FGUJ", 4, 158153},
	{"FEFL", 4, 158154},
	{"FBEV", 4, 158155},
	{"EMUK", 4, 158156},
	{"EKMC", 4, 158157},
	{"BYBC", 4, 158158},
	{"BIPR", 4, 158159},
	{"BAGM", 4, 158160},
	{"APYH", 4, 158161},
	{"ISOLE", 5, 158162},
	{"ULES", 4, 158163},
	{"SICKLES", 7, 158164},
	{"RIVERSDALE", 10, 158165},
	{"INHALANT", 8, 158166},
	{"CIPRIANI", 8, 158167},
	{"VALENCIAN", 9, 158168},
	{"CALLOC", 6, 158169},
	{"BIDING", 6, 158170},
	{"UNASSAILABLE", 12, 158171},
	{"SIDAN", 5, 158172},
	{"TECHGUIDES", 10, 158173},
	{"REPLYS", 6, 158174},
	{"LYKE", 4, 158175},
	{"BIOTECHS", 8, 158176},
	{"PANAFAX", 7, 158177},
	{"CLERKSHIPS", 10, 158178},
	{"CANADIENNES", 11, 158179},
	{"SPORTPHARMA", 11, 158180},
	{"PHPUNIT", 7, 158181},
	{"WSHADOW", 7, 158182},
	{"KLEBERG", 7, 158183},
	{"BRINGIN", 7, 158184},
	{"TAIPEITIMES", 11, 158185},
	{"DISHARMONY", 10, 158186},
	{"CDCL", 4, 158187},
	{"VIEWAUTH", 8, 158188},
	{"OVERSTATEMENT", 13, 158189},
	{"COERCING", 8, 158190},
	{"TILLE", 5, 158191},
	{"POLICEWOMAN", 11, 158192},
	{"RIFLESCOPES", 11, 158193},
	{"CARDINALE", 9, 158194},
	{"IMATINIB", 8, 158195},
	{"XMLREADER", 9, 158196},
	{"BAHTS", 5, 158197},
	{"KFOG", 4, 158198},
	{"OPSWARE", 7, 158199},
	{"DAWNLOAD", 8, 158200},
	{"USERRA", 6, 158201},
	{"MUTTERS", 7, 158202},
	{"CNNFN", 5, 158203},
	{"ACADIANA", 8, 158204},
	{"PRESENCES", 9, 158205},
	{"LISSE", 5, 158206},
	{"SINGHALESE", 10, 158207},
	{"FONTANINI", 9, 158208},
	{"YETV", 4, 158209},
	{"VSBE", 4, 158210},
	{"VEZM", 4, 158211},
	{"TDAG", 4, 158212},
	{"SJAD", 4, 158213},
	{"RUDR", 4, 158214},
	{"ROBD", 4, 158215},
	{"LMEO", 4, 158216},
	{"LKEM", 4, 158217},
	{"KYER", 4, 158218},
	{"KFUT", 4, 158219},
	{"HWAZ", 4, 158220},
	{"HMCK", 4, 158221},
	{"GHNC", 4, 158222},
	{"FYMA", 4, 158223},
	{"FSDI", 4, 158224},
	{"FOFJ", 4, 158225},
	{"FLOF", 4, 158226},
	{"ETML", 4, 158227},
	{"EPSK", 4, 158228},
	{"CTIG", 4, 158229},
	{"BIEP", 4, 158230},
	{"AWLB", 4, 158231},
	{"ADUG", 4, 158232},
	{"BRECHER", 7, 158233},
	{"AUSTRAILIA", 10, 158234},
	{"MANAGERTIME", 11, 158235},
	{"SWIFTECH", 8, 158236},
	{"KRONOLITH", 9, 158237},
	{"WATERDOWN", 9, 158238},
	{"ADENOMATOUS", 11, 158239},
	{"AIRLIFTED", 9, 158240},
	{"REIDY", 5, 158241},
	{"BACKPAGE", 8, 158242},
	{"BOLIVARS", 8, 158243},
	{"GRAFFITTI", 9, 158244},
	{"GBV", 3, 158245},
	{"JFRAME", 6, 158246},
	{"CULEX", 5, 158247},
	{"HARU", 4, 158248},
	{"AEBERSOLD", 9, 158249},
	{"ORTHOSTATIC", 11, 158250},
	{"VILLEPIN", 8, 158251},
	{"PINC", 4, 158252},
	{"KERNAN", 6, 158253},
	{"GORETEX", 7, 158254},
	{"GAMESPOTASIA", 12, 158255},
	{"SQUEALS", 7, 158256},
	{"MAMMON", 6, 158257},
	{"SHARA", 5, 158258},
	{"CAVOUR", 6, 158259},
	{"DISCOVERABLE", 12, 158260},
	{"LETTY", 5, 158261},
	{"ATROPHIC", 8, 158262},
	{"PARASUCO", 8, 158263},
	{"TOMBE", 5, 158264},
	{"SILVEIRA", 8, 158265},
	{"MEGAPATH", 8, 158266},
	{"SYSINTERNALS", 12, 158267},
	{"SCHWAENZE", 9, 158268},
	{"BELTANE", 7, 158269},
	{"KMP", 3, 158270},
	{"THOMS", 5, 158271},
	{"WHIR", 4, 158272},
	{"PARIJS", 6, 158273},
	{"CALCINEURIN", 11, 158274},
	{"PUGLIESE", 8, 158275},
	{"ALCOR", 5, 158276},
	{"EXCIPIENTS", 10, 158277},
	{"ESTEP", 5, 158278},
	{"CHRISTOPHERSON", 14, 158279},
	{"ESPIRITU", 8, 158280},
	{"DEVFSD", 6, 158281},
	{"LIGHTBULBS", 10, 158282},
	{"MEHNDI", 6, 158283},
	{"DYESS", 5, 158284},
	{"IDAUTOMATION", 12, 158285},
	{"UTTM", 4, 158286},
	{"THDJ", 4, 158287},
	{"SOKB", 4, 158288},
	{"RBIZ", 4, 158289},
	{"OEYD", 4, 158290},
	{"NCPU", 4, 158291},
	{"FZEN", 4, 158292},
	{"FMYK", 4, 158293},
	{"FINY", 4, 158294},
	{"EZAW", 4, 158295},
	{"COGH", 4, 158296},
	{"APYP", 4, 158297},
	{"PANHEAD", 7, 158298},
	{"MADHURI", 7, 158299},
	{"AGAINS", 6, 158300},
	{"UNTANGLE", 8, 158301},
	{"AFFLICTING", 10, 158302},
	{"ALIZE", 5, 158303},
	{"RONJA", 5, 158304},
	{"CHAUDHARY", 9, 158305},
	{"POSTO", 5, 158306},
	{"QUOTEWORLD", 10, 158307},
	{"BIOGRAPHERS", 11, 158308},
	{"VIOLACION", 9, 158309},
	{"SILVERPLATED", 12, 158310},
	{"LAUE", 4, 158311},
	{"NATIONSTATES", 12, 158312},
	{"COPI", 4, 158313},
	{"UNIES", 5, 158314},
	{"LICS", 4, 158315},
	{"ESCRITO", 7, 158316},
	{"MINDSPRING", 10, 158317},
	{"BOTTS", 5, 158318},
	{"OPSLAG", 6, 158319},
	{"FESSIONAL", 9, 158320},
	{"PCCC", 4, 158321},
	{"AUDIOCASSETTE", 13, 158322},
	{"ANALFICKEN", 10, 158323},
	{"WHEELHOUSE", 10, 158324},
	{"WALDNER", 7, 158325},
	{"ANGIOSPERMS", 11, 158326},
	{"THYMOCYTES", 10, 158327},
	{"OPINES", 6, 158328},
	{"BALIN", 5, 158329},
	{"WIZARDING", 9, 158330},
	{"SUBMODULE", 9, 158331},
	{"SCHALKE", 7, 158332},
	{"RECENCY", 7, 158333},
	{"MOXA", 4, 158334},
	{"ERGON", 5, 158335},
	{"AMCO", 4, 158336},
	{"KIDNAPPER", 9, 158337},
	{"KENNYS", 6, 158338},
	{"HYACINTHS", 9, 158339},
	{"MAINTAINENCE", 12, 158340},
	{"ORDONEZ", 7, 158341},
	{"MUSCHIBILDER", 12, 158342},
	{"CLOUDSCAPE", 10, 158343},
	{"TRUESPACE", 9, 158344},
	{"TECHENCYCLOPEDIA", 16, 158345},
	{"ROGELIO", 7, 158346},
	{"WICHSVORLAGEN", 13, 158347},
	{"CRACKLIB", 8, 158348},
	{"MANOMETRY", 9, 158349},
	{"DEMANDES", 8, 158350},
	{"HSCSD", 5, 158351},
	{"SWED", 4, 158352},
	{"BACKFILLING", 11, 158353},
	{"KIDWELL", 7, 158354},
	{"ZTRI", 4, 158355},
	{"ZLEG", 4, 158356},
	{"YFET", 4, 158357},
	{"XTSF", 4, 158358},
	{"SMUI", 4, 158359},
	{"RLSJ", 4, 158360},
	{"ORXA", 4, 158361},
	{"NDRJ", 4, 158362},
	{"IXYO", 4, 158363},
	{"EJAF", 4, 158364},
	{"CMWI", 4, 158365},
	{"AXIF", 4, 158366},
	{"ANLD", 4, 158367},
	{"SEMPRA", 6, 158368},
	{"SHAIK", 5, 158369},
	{"RALOXIFENE", 10, 158370},
	{"PFENNIG", 7, 158371},
	{"FLOVENT", 7, 158372},
	{"RUSTLER", 7, 158373},
	{"MAPHIST", 7, 158374},
	{"PRODISC", 7, 158375},
	{"DKR", 3, 158376},
	{"CLARIION", 8, 158377},
	{"JETTIES", 7, 158378},
	{"ANALBILDER", 10, 158379},
	{"KWUN", 4, 158380},
	{"OFLC", 4, 158381},
	{"MAGICGATE", 9, 158382},
	{"CYBERDUCK", 9, 158383},
	{"TUNITY", 6, 158384},
	{"ARVS", 4, 158385},
	{"GOSFORTH", 8, 158386},
	{"TIRUPATI", 8, 158387},
	{"MONCUR", 6, 158388},
	{"SPORTLINE", 9, 158389},
	{"NACHMAN", 7, 158390},
	{"UOFA", 4, 158391},
	{"FREEHOLDERS", 11, 158392},
	{"PIETERS", 7, 158393},
	{"VENTRE", 6, 158394},
	{"DYNAM", 5, 158395},
	{"FACETIOUS", 9, 158396},
	{"FISTBANG", 8, 158397},
	{"MCCLEARY", 8, 158398},
	{"GLENUM", 6, 158399},
	{"SECOR", 5, 158400},
	{"TINKLE", 6, 158401},
	{"DEVENTER", 8, 158402},
	{"FERRAN", 6, 158403},
	{"CARTVIEW", 8, 158404},
	{"WORMED", 6, 158405},
	{"LIGASES", 7, 158406},
	{"ZANOTTI", 7, 158407},
	{"DRESSMAKING", 11, 158408},
	{"KAVALA", 6, 158409},
	{"LACTOFERRIN", 11, 158410},
	{"BLITHERING", 10, 158411},
	{"GEOPHYSICISTS", 13, 158412},
	{"LAVATORIES", 10, 158413},
	{"SCOVILLE", 8, 158414},
	{"EREDIVISIE", 10, 158415},
	{"WVDIAL", 6, 158416},
	{"PREBUILT", 8, 158417},
	{"INTEGRASE", 9, 158418},
	{"HISTOIRES", 9, 158419},
	{"MACJAMS", 7, 158420},
	{"GOULDS", 6, 158421},
	{"PATLABOR", 8, 158422},
	{"WEIBER", 6, 158423},
	{"ZHIL", 4, 158424},
	{"YOPR", 4, 158425},
	{"XBUI", 4, 158426},
	{"WBIB", 4, 158427},
	{"UKAD", 4, 158428},
	{"TVSW", 4, 158429},
	{"RQIN", 4, 158430},
	{"PMAF", 4, 158431},
	{"NYIP", 4, 158432},
	{"LMGO", 4, 158433},
	{"HYOL", 4, 158434},
	{"HYHU", 4, 158435},
	{"HAWD", 4, 158436},
	{"GAHY", 4, 158437},
	{"FVLA", 4, 158438},
	{"EMUI", 4, 158439},
	{"EKIG", 4, 158440},
	{"EKBI", 4, 158441},
	{"DNGO", 4, 158442},
	{"BTCA", 4, 158443},
	{"BLYQ", 4, 158444},
	{"BITY", 4, 158445},
	{"BBCF", 4, 158446},
	{"TRICT", 5, 158447},
	{"SHROOMS", 7, 158448},
	{"PENICILLIUM", 11, 158449},
	{"ENGORGED", 8, 158450},
	{"SERIALVERSIONUID", 16, 158451},
	{"IDSF", 4, 158452},
	{"HITMEN", 6, 158453},
	{"MYKE", 4, 158454},
	{"NASDAQNM", 8, 158455},
	{"DIREITOS", 8, 158456},
	{"FUJIYAMA", 8, 158457},
	{"CALTRAIN", 8, 158458},
	{"CHARLA", 6, 158459},
	{"APPROCHE", 8, 158460},
	{"CIVILLY", 7, 158461},
	{"STARDICT", 8, 158462},
	{"INQUISITIVELY", 13, 158463},
	{"GABALDON", 8, 158464},
	{"ANADOLU", 7, 158465},
	{"GLENORCHY", 9, 158466},
	{"AVTOYBOX", 8, 158467},
	{"GGL", 3, 158468},
	{"POINCIANA", 9, 158469},
	{"UNHURT", 6, 158470},
	{"FORMMAIL", 8, 158471},
	{"CROSSRAIL", 9, 158472},
	{"TAUTOLOGY", 9, 158473},
	{"HAINAUT", 7, 158474},
	{"SSDNA", 5, 158475},
	{"OPTICA", 6, 158476},
	{"INCREDULITY", 11, 158477},
	{"FORRES", 6, 158478},
	{"CONCEP", 6, 158479},
	{"TOMERS", 6, 158480},
	{"MREM", 4, 158481},
	{"AGHAIDH", 7, 158482},
	{"PHARMACODYNAMIC", 15, 158483},
	{"CREDITON", 8, 158484},
	{"ACCOMACK", 8, 158485},
	{"POLYNUCLEOTIDE", 14, 158486},
	{"BURROS", 6, 158487},
	{"MOTIFSCAN", 9, 158488},
	{"FLANDRES", 8, 158489},
	{"AREATA", 6, 158490},
	{"QUANTI", 6, 158491},
	{"UNTAXED", 7, 158492},
	{"PINGREE", 7, 158493},
	{"CROSTON", 7, 158494},
	{"YAWNS", 5, 158495},
	{"MINIMUS", 7, 158496},
	{"ORGINALLY", 9, 158497},
	{"HELMUTH", 7, 158498},
	{"EPIDIDYMIS", 10, 158499},
	{"CATTOLICA", 9, 158500},
	{"CROKER", 6, 158501},
	{"CHANSERV", 8, 158502},
	{"NEWAGE", 6, 158503},
	{"VRMS", 4, 158504},
	{"MAURIS", 6, 158505},
	{"ASCHER", 6, 158506},
	{"WBL", 3, 158507},
	{"NODEID", 6, 158508},
	{"HEALTHYHERB", 11, 158509},
	{"INTERLAYER", 10, 158510},
	{"HIROSHIGE", 9, 158511},
	{"CELLULARPHONE", 13, 158512},
	{"ZGOT", 4, 158513},
	{"YBEQ", 4, 158514},
	{"UATC", 4, 158515},
	{"TTYV", 4, 158516},
	{"TFEV", 4, 158517},
	{"RKAA", 4, 158518},
	{"OVSP", 4, 158519},
	{"NILW", 4, 158520},
	{"NAPW", 4, 158521},
	{"MEGM", 4, 158522},
	{"FLLA", 4, 158523},
	{"FCHL", 4, 158524},
	{"EMKA", 4, 158525},
	{"BYUL", 4, 158526},
	{"BRUD", 4, 158527},
	{"MENSTRUATING", 12, 158528},
	{"PISTES", 6, 158529},
	{"COLORBLIND", 10, 158530},
	{"LIISA", 5, 158531},
	{"DARUL", 5, 158532},
	{"HILVERSUM", 9, 158533},
	{"OBLIGEE", 7, 158534},
	{"BRIARD", 6, 158535},
	{"ROYSTER", 7, 158536},
	{"INSTINCTUAL", 11, 158537},
	{"BRACEY", 6, 158538},
	{"MCCULLY", 7, 158539},
	{"CLIENTDATA", 10, 158540},
	{"PROSCRIPTION", 12, 158541},
	{"STOWMARKET", 10, 158542},
	{"STREAMTYPE", 10, 158543},
	{"PSILOC", 6, 158544},
	{"FORETELL", 8, 158545},
	{"SAFIR", 5, 158546},
	{"HOARDS", 6, 158547},
	{"SPELPUNT", 8, 158548},
	{"SHOREBIRD", 9, 158549},
	{"FEELEY", 6, 158550},
	{"GAMALIEL", 8, 158551},
	{"INACTIVETOPIC", 13, 158552},
	{"INTERNETTVSDIRECT", 17, 158553},
	{"GWELD", 5, 158554},
	{"BOCCACCIO", 9, 158555},
	{"VASHEM", 6, 158556},
	{"WHIMPERED", 9, 158557},
	{"NECC", 4, 158558},
	{"COMPUTADORA", 11, 158559},
	{"PHENTRAMIN", 10, 158560},
	{"LAKEHURST", 9, 158561},
	{"AMERCIAN", 8, 158562},
	{"COLORIZE", 8, 158563},
	{"TOUGHT", 6, 158564},
	{"CARDE", 5, 158565},
	{"KINTYRE", 7, 158566},
	{"KNACKIGE", 8, 158567},
	{"FOULKE", 6, 158568},
	{"CRUMLIN", 7, 158569},
	{"KHANH", 5, 158570},
	{"ALAURA", 6, 158571},
	{"SHILPA", 6, 158572},
	{"SISTENT", 7, 158573},
	{"CALCOMP", 7, 158574},
	{"RECEIPES", 8, 158575},
	{"INTERNETHIFISDIRECT", 19, 158576},
	{"CISSE", 5, 158577},
	{"BODYS", 5, 158578},
	{"ERBB", 4, 158579},
	{"WYMONDHAM", 9, 158580},
	{"EHRHARDT", 8, 158581},
	{"MOYO", 4, 158582},
	{"NBCC", 4, 158583},
	{"MANJIMUP", 8, 158584},
	{"YSIV", 4, 158585},
	{"XDEA", 4, 158586},
	{"WPUN", 4, 158587},
	{"UODB", 4, 158588},
	{"TIZW", 4, 158589},
	{"TFUC", 4, 158590},
	{"RGID", 4, 158591},
	{"NYSV", 4, 158592},
	{"MDUS", 4, 158593},
	{"EXML", 4, 158594},
	{"DOTB", 4, 158595},
	{"BUSINESSLIKE", 12, 158596},
	{"SUBSITE", 7, 158597},
	{"INTRAHEPATIC", 12, 158598},
	{"LECKTE", 6, 158599},
	{"MODAS", 5, 158600},
	{"MEGATON", 7, 158601},
	{"EGYPTE", 6, 158602},
	{"ATTACHABLE", 10, 158603},
	{"STRUCTED", 8, 158604},
	{"PAULIST", 7, 158605},
	{"JUBA", 4, 158606},
	{"FRILL", 5, 158607},
	{"ESTRELA", 7, 158608},
	{"INTERNETCAMCORDERSDIRECT", 24, 158609},
	{"CAGIVA", 6, 158610},
	{"UNITRON", 7, 158611},
	{"INTERNETDVDSDIRECT", 18, 158612},
	{"WURM", 4, 158613},
	{"VAMPS", 5, 158614},
	{"IPNG", 4, 158615},
	{"MUDSLIDES", 9, 158616},
	{"COLLINSON", 9, 158617},
	{"NETIZEN", 7, 158618},
	{"DIACRITICAL", 11, 158619},
	{"POLAROIDS", 9, 158620},
	{"RTRV", 4, 158621},
	{"MOBILIZES", 9, 158622},
	{"BREHM", 5, 158623},
	{"LANDWARD", 8, 158624},
	{"DCIS", 4, 158625},
	{"HIDEAKI", 7, 158626},
	{"SHINKANSEN", 10, 158627},
	{"HUBBS", 5, 158628},
	{"PERSTEL", 7, 158629},
	{"VEGSOURCE", 9, 158630},
	{"TRLEFT", 6, 158631},
	{"HEIDEN", 6, 158632},
	{"BETTMAN", 7, 158633},
	{"BROADDUS", 8, 158634},
	{"GUANYLATE", 9, 158635},
	{"NOTARIAL", 8, 158636},
	{"PHYSIOGRAPHIC", 13, 158637},
	{"CEILINGMOUNTING", 15, 158638},
	{"CRIPPLES", 8, 158639},
	{"MAJORTRAVEL", 11, 158640},
	{"DUBARRY", 7, 158641},
	{"CISTERCIAN", 10, 158642},
	{"AMUSINGLY", 9, 158643},
	{"VASILY", 6, 158644},
	{"HYACINTHE", 9, 158645},
	{"WORKPAD", 7, 158646},
	{"CORNICES", 8, 158647},
	{"DGP", 3, 158648},
	{"RAMMELN", 7, 158649},
	{"MEHL", 4, 158650},
	{"OSTENTATIOUS", 12, 158651},
	{"VRAI", 4, 158652},
	{"RENOUNCES", 9, 158653},
	{"SHAKLEE", 7, 158654},
	{"TRAVIESAS", 9, 158655},
	{"SPACIAL", 7, 158656},
	{"FOLDOC", 6, 158657},
	{"TMSU", 4, 158658},
	{"TEKU", 4, 158659},
	{"TCWA", 4, 158660},
	{"RPFA", 4, 158661},
	{"NUTJ", 4, 158662},
	{"NNYX", 4, 158663},
	{"NIDU", 4, 158664},
	{"MSTL", 4, 158665},
	{"KMYW", 4, 158666},
	{"EXAF", 4, 158667},
	{"DYKO", 4, 158668},
	{"DOXR", 4, 158669},
	{"DDIB", 4, 158670},
	{"KDX", 3, 158671},
	{"KWELLER", 7, 158672},
	{"AVIDA", 5, 158673},
	{"ALDERAC", 7, 158674},
	{"YOHIMBINE", 9, 158675},
	{"TEMPING", 7, 158676},
	{"IDATA", 5, 158677},
	{"DELIUS", 6, 158678},
	{"KELLETT", 7, 158679},
	{"TUFBOY", 6, 158680},
	{"SSRC", 4, 158681},
	{"TOUPEE", 6, 158682},
	{"JOBCENTER", 9, 158683},
	{"NORTHERNIRELAND", 15, 158684},
	{"KEMBER", 6, 158685},
	{"MOTORRAD", 8, 158686},
	{"POCKETING", 9, 158687},
	{"TANNIC", 6, 158688},
	{"PENCILED", 8, 158689},
	{"KIRSHNER", 8, 158690},
	{"DADEY", 5, 158691},
	{"TAKK", 4, 158692},
	{"PQR", 3, 158693},
	{"NETWOR", 6, 158694},
	{"MIDSECTION", 10, 158695},
	{"HAUSMANN", 8, 158696},
	{"VOLZ", 4, 158697},
	{"ULLSWATER", 9, 158698},
	{"RADMIND", 7, 158699},
	{"OUPUT", 5, 158700},
	{"WYLD", 4, 158701},
	{"OINGO", 5, 158702},
	{"IWPR", 4, 158703},
	{"ANTIPHON", 8, 158704},
	{"PETROVIC", 8, 158705},
	{"PARTIDA", 7, 158706},
	{"EBRAHIM", 7, 158707},
	{"THEATR", 6, 158708},
	{"TRANSPOSING", 11, 158709},
	{"RIFAMPICIN", 10, 158710},
	{"MULTICOLOURED", 13, 158711},
	{"BEREITS", 7, 158712},
	{"XSITE", 5, 158713},
	{"INGATESTONE", 11, 158714},
	{"WBIT", 4, 158715},
	{"VAFR", 4, 158716},
	{"UVSA", 4, 158717},
	{"UGSR", 4, 158718},
	{"TJUG", 4, 158719},
	{"TAGD", 4, 158720},
	{"SYDR", 4, 158721},
	{"SFYA", 4, 158722},
	{"RNWR", 4, 158723},
	{"PSYL", 4, 158724},
	{"PPAW", 4, 158725},
	{"PFUE", 4, 158726},
	{"NGMB", 4, 158727},
	{"LHEU", 4, 158728},
	{"IKPA", 4, 158729},
	{"IGTU", 4, 158730},
	{"HBUB", 4, 158731},
	{"GPEL", 4, 158732},
	{"EBDO", 4, 158733},
	{"REROUTED", 8, 158734},
	{"HAYLE", 5, 158735},
	{"PCCARD", 6, 158736},
	{"RETESTED", 8, 158737},
	{"MENUPAGES", 9, 158738},
	{"DIFFEREN", 8, 158739},
	{"MURRINA", 7, 158740},
	{"MERL", 4, 158741},
	{"RHODOLITE", 9, 158742},
	{"CROSSDRESSERS", 13, 158743},
	{"SHYLOCK", 7, 158744},
	{"PIPPEN", 6, 158745},
	{"SUBDURAL", 8, 158746},
	{"TABLETOPS", 9, 158747},
	{"FREESTUFF", 9, 158748},
	{"COOKNIK", 7, 158749},
	{"THOROLD", 7, 158750},
	{"GRANGEMOUTH", 11, 158751},
	{"DOWNSPOUTS", 10, 158752},
	{"DRAGONRIDERS", 12, 158753},
	{"RATIFIES", 8, 158754},
	{"PYGAME", 6, 158755},
	{"HOOVERS", 7, 158756},
	{"OCHSNER", 7, 158757},
	{"AMPTRON", 7, 158758},
	{"MACMINUTE", 9, 158759},
	{"PEAP", 4, 158760},
	{"REDIR", 5, 158761},
	{"WICHSVORLAGE", 12, 158762},
	{"SUSITNA", 7, 158763},
	{"HANDERS", 7, 158764},
	{"SACRUM", 6, 158765},
	{"BELFOUR", 7, 158766},
	{"XBM", 3, 158767},
	{"DELLINGER", 9, 158768},
	{"HEYY", 4, 158769},
	{"FOTZENSCHLEIM", 13, 158770},
	{"REME", 4, 158771},
	{"RTOG", 4, 158772},
	{"THEMING", 7, 158773},
	{"SCHIFFMAN", 9, 158774},
	{"DESEO", 5, 158775},
	{"APHERESIS", 9, 158776},
	{"NUTCASE", 7, 158777},
	{"CATFIGHTS", 9, 158778},
	{"CRARY", 5, 158779},
	{"SNEDDON", 7, 158780},
	{"NEUROTOXIN", 10, 158781},
	{"CROWBOROUGH", 11, 158782},
	{"WORLDE", 6, 158783},
	{"SWOFFORD", 8, 158784},
	{"GAMEBOOKERS", 11, 158785},
	{"AMULE", 5, 158786},
	{"SPHERICALLY", 11, 158787},
	{"INTELLISYNC", 11, 158788},
	{"WIPR", 4, 158789},
	{"WADU", 4, 158790},
	{"TYUG", 4, 158791},
	{"TMBE", 4, 158792},
	{"RPIM", 4, 158793},
	{"RNRH", 4, 158794},
	{"RCNE", 4, 158795},
	{"ORYQ", 4, 158796},
	{"ORSZ", 4, 158797},
	{"MRAJ", 4, 158798},
	{"LUPL", 4, 158799},
	{"LBAA", 4, 158800},
	{"HYEM", 4, 158801},
	{"GLIU", 4, 158802},
	{"FVON", 4, 158803},
	{"EXTK", 4, 158804},
	{"DZAD", 4, 158805},
	{"DPMM", 4, 158806},
	{"CTAX", 4, 158807},
	{"CKEB", 4, 158808},
	{"CIWH", 4, 158809},
	{"CBSF", 4, 158810},
	{"APRP", 4, 158811},
	{"ACGI", 4, 158812},
	{"ANDROSTENEDIONE", 15, 158813},
	{"SUBTESTS", 8, 158814},
	{"PAYMASTER", 9, 158815},
	{"DOOMS", 5, 158816},
	{"PLANEFUN", 8, 158817},
	{"KELTNER", 7, 158818},
	{"STRSQL", 6, 158819},
	{"NESHOBA", 7, 158820},
	{"EPILATOR", 8, 158821},
	{"KNACKARSCH", 10, 158822},
	{"BURS", 4, 158823},
	{"EPITHELIA", 9, 158824},
	{"UNDERLAYMENT", 12, 158825},
	{"DELROY", 6, 158826},
	{"WILLEMSTAD", 10, 158827},
	{"MAGNETRON", 9, 158828},
	{"ABID", 4, 158829},
	{"CANAANITES", 10, 158830},
	{"SPECIFIEDUNITED", 15, 158831},
	{"PTRACE", 6, 158832},
	{"WALVERINE", 9, 158833},
	{"RATEPAYER", 9, 158834},
	{"CHAIRLIFT", 9, 158835},
	{"RELEASER", 8, 158836},
	{"OPTIQUE", 7, 158837},
	{"HARDLINERS", 10, 158838},
	{"CARNAC", 6, 158839},
	{"HYDROXYUREA", 11, 158840},
	{"DHUL", 4, 158841},
	{"GAMBLIN", 7, 158842},
	{"SCHWANZLUTSCHER", 15, 158843},
	{"BUNDA", 5, 158844},
	{"SCHWANZLUTSCHEN", 15, 158845},
	{"SEMINARIO", 9, 158846},
	{"SCREENPRINT", 11, 158847},
	{"DERBYN", 6, 158848},
	{"WALKMANS", 8, 158849},
	{"TIMESERVICESCLASSES", 19, 158850},
	{"QUEENSFERRY", 11, 158851},
	{"INTERPROVINCIAL", 15, 158852},
	{"WATERPOLO", 9, 158853},
	{"GNARLED", 7, 158854},
	{"LIBALLEGRO", 10, 158855},
	{"GXP", 3, 158856},
	{"MUSSELMAN", 9, 158857},
	{"LEONARDI", 8, 158858},
	{"CHACE", 5, 158859},
	{"BRIDGEHAMPTON", 13, 158860},
	{"DOCE", 4, 158861},
	{"JOHANNE", 7, 158862},
	{"ZEEX", 4, 158863},
	{"YAIK", 4, 158864},
	{"XIER", 4, 158865},
	{"WUNE", 4, 158866},
	{"TJAL", 4, 158867},
	{"OVOU", 4, 158868},
	{"MOWO", 4, 158869},
	{"MMWA", 4, 158870},
	{"MAHW", 4, 158871},
	{"LEXJ", 4, 158872},
	{"KDOY", 4, 158873},
	{"IJUD", 4, 158874},
	{"HYMY", 4, 158875},
	{"FWWI", 4, 158876},
	{"EJUP", 4, 158877},
	{"DRLO", 4, 158878},
	{"DOTP", 4, 158879},
	{"DMOY", 4, 158880},
	{"DEZC", 4, 158881},
	{"DECY", 4, 158882},
	{"AXAM", 4, 158883},
	{"AKCL", 4, 158884},
	{"ABMW", 4, 158885},
	{"THACHER", 7, 158886},
	{"MULTIHOMING", 11, 158887},
	{"GNASHING", 8, 158888},
	{"SILVAS", 6, 158889},
	{"SAMTEC", 6, 158890},
	{"FONCTIONNEMENT", 14, 158891},
	{"GUK", 3, 158892},
	{"GOVTRACK", 8, 158893},
	{"CLASSTYPE", 9, 158894},
	{"WICHSTE", 7, 158895},
	{"TEEMU", 5, 158896},
	{"MHASH", 5, 158897},
	{"ICPD", 4, 158898},
	{"BOMBARDING", 10, 158899},
	{"FRREE", 5, 158900},
	{"MUENCH", 6, 158901},
	{"BIGLOO", 6, 158902},
	{"BUTI", 4, 158903},
	{"DOLFIN", 6, 158904},
	{"RISTORANTI", 10, 158905},
	{"USHORT", 6, 158906},
	{"SPLAYED", 7, 158907},
	{"HOBB", 4, 158908},
	{"MACKS", 5, 158909},
	{"CREEDMOOR", 9, 158910},
	{"PREUVE", 6, 158911},
	{"RETIRO", 6, 158912},
	{"JAMAAT", 6, 158913},
	{"ALWAYSON", 8, 158914},
	{"BARNEYS", 7, 158915},
	{"EARTHLING", 9, 158916},
	{"TRANSAC", 7, 158917},
	{"ISACA", 5, 158918},
	{"ISSUABLE", 8, 158919},
	{"CROHNS", 6, 158920},
	{"ANTHROPOLOGIE", 13, 158921},
	{"TELEMUNDO", 9, 158922},
	{"VTAM", 4, 158923},
	{"PLOD", 4, 158924},
	{"NAPANEE", 7, 158925},
	{"FLAMBOROUGH", 11, 158926},
	{"CONSIDERA", 9, 158927},
	{"VIELLEICHT", 10, 158928},
	{"DAMALS", 6, 158929},
	{"JMGARVIN", 8, 158930},
	{"TRANSPIRE", 9, 158931},
	{"GARN", 4, 158932},
	{"TENBURY", 7, 158933},
	{"NONTAXABLE", 10, 158934},
	{"ACCENTUATES", 11, 158935},
	{"FLUVOXAMINE", 11, 158936},
	{"COVETOUSNESS", 12, 158937},
	{"BOXART", 6, 158938},
	{"LIBNSS", 6, 158939},
	{"OCCUPA", 6, 158940},
	{"FVC", 3, 158941},
	{"VIDRO", 5, 158942},
	{"FRIEDRICHSHAFEN", 15, 158943},
	{"YDUF", 4, 158944},
	{"VARC", 4, 158945},
	{"TMSF", 4, 158946},
	{"TEMJ", 4, 158947},
	{"SYAF", 4, 158948},
	{"RERK", 4, 158949},
	{"MHZA", 4, 158950},
	{"LTUT", 4, 158951},
	{"JEMI", 4, 158952},
	{"IGJU", 4, 158953},
	{"HYBI", 4, 158954},
	{"HNBC", 4, 158955},
	{"FATV", 4, 158956},
	{"ELRS", 4, 158957},
	{"EDGB", 4, 158958},
	{"DYRS", 4, 158959},
	{"DAFP", 4, 158960},
	{"CVIN", 4, 158961},
	{"CPUA", 4, 158962},
	{"CGOD", 4, 158963},
	{"CAGU", 4, 158964},
	{"KARMANN", 7, 158965},
	{"FITZMAURICE", 11, 158966},
	{"RUDELBUMSEN", 11, 158967},
	{"MUSICKE", 7, 158968},
	{"DAMMED", 6, 158969},
	{"LANGUARD", 8, 158970},
	{"NUNG", 4, 158971},
	{"OFTWARE", 7, 158972},
	{"NUMI", 4, 158973},
	{"MAREA", 5, 158974},
	{"BARRACUDAS", 10, 158975},
	{"VELAS", 5, 158976},
	{"PGY", 3, 158977},
	{"FRIG", 4, 158978},
	{"ELECTRI", 7, 158979},
	{"PIEBALD", 7, 158980},
	{"UNAWARES", 8, 158981},
	{"SCORNFUL", 8, 158982},
	{"EXTENTIONS", 10, 158983},
	{"KLOK", 4, 158984},
	{"SKENE", 5, 158985},
	{"FDX", 3, 158986},
	{"VITRIOLIC", 9, 158987},
	{"OFFSCREEN", 9, 158988},
	{"KEEWATIN", 8, 158989},
	{"MICROSUEDE", 10, 158990},
	{"EARTHLINGS", 10, 158991},
	{"CONTAM", 6, 158992},
	{"BOURGES", 7, 158993},
	{"BWINDI", 6, 158994},
	{"OVERWINTERING", 13, 158995},
	{"NEWFANGLED", 10, 158996},
	{"ALTERNATIVA", 11, 158997},
	{"LAFRANCE", 8, 158998},
	{"CROSSWISE", 9, 158999},
	{"TUCKERMAN", 9, 159000},
	{"LELE", 4, 159001},
	{"COINFECTION", 11, 159002},
	{"HOOLEY", 6, 159003},
	{"NICATION", 8, 159004},
	{"BIEDERMAN", 9, 159005},
	{"TUNEFUL", 7, 159006},
	{"BIREFRINGENCE", 13, 159007},
	{"ROUTT", 5, 159008},
	{"VIOLINISTS", 10, 159009},
	{"EPORTFOLIO", 10, 159010},
	{"MOOREFIELD", 10, 159011},
	{"LEATHERBACK", 11, 159012},
	{"AUTOHEADER", 10, 159013},
	{"HYATTHOTEL", 10, 159014},
	{"YXAN", 4, 159015},
	{"YLOI", 4, 159016},
	{"VYOR", 4, 159017},
	{"VSFA", 4, 159018},
	{"TZUM", 4, 159019},
	{"TTWR", 4, 159020},
	{"TFUJ", 4, 159021},
	{"RFUG", 4, 159022},
	{"PROY", 4, 159023},
	{"NKIB", 4, 159024},
	{"NGIJ", 4, 159025},
	{"MVPT", 4, 159026},
	{"MOMP", 4, 159027},
	{"MCSW", 4, 159028},
	{"MAOV", 4, 159029},
	{"KAUG", 4, 159030},
	{"IJAR", 4, 159031},
	{"HWAK", 4, 159032},
	{"FIXB", 4, 159033},
	{"FBBC", 4, 159034},
	{"DHUC", 4, 159035},
	{"DDRC", 4, 159036},
	{"CSOW", 4, 159037},
	{"BSJO", 4, 159038},
	{"BBSP", 4, 159039},
	{"AUTC", 4, 159040},
	{"AKUY", 4, 159041},
	{"VANUNU", 6, 159042},
	{"LIDL", 4, 159043},
	{"INTERPRETABLE", 13, 159044},
	{"PULI", 4, 159045},
	{"ATOMICALLY", 10, 159046},
	{"ABLATIVE", 8, 159047},
	{"THORNDALE", 9, 159048},
	{"STEFFAN", 7, 159049},
	{"PLETELY", 7, 159050},
	{"WORKHAVEN", 9, 159051},
	{"NIACINAMIDE", 11, 159052},
	{"HACHE", 5, 159053},
	{"BODHRAN", 7, 159054},
	{"CICCONE", 7, 159055},
	{"CYCLICALLY", 10, 159056},
	{"SOCIOPATH", 9, 159057},
	{"WALLERSTEIN", 11, 159058},
	{"PANTA", 5, 159059},
	{"BICICLETTE", 10, 159060},
	{"SUMMITT", 7, 159061},
	{"USNR", 4, 159062},
	{"DIALIN", 6, 159063},
	{"IPOMOEA", 7, 159064},
	{"PAROLEES", 8, 159065},
	{"LECTERNS", 8, 159066},
	{"CARDONE", 7, 159067},
	{"UREMIC", 6, 159068},
	{"VIRIDIPLANTAE", 13, 159069},
	{"BENONI", 6, 159070},
	{"ROSELLA", 7, 159071},
	{"KFW", 3, 159072},
	{"NETWORLD", 8, 159073},
	{"GIROLAMO", 8, 159074},
	{"AGULHAS", 7, 159075},
	{"ATTRAZIONI", 10, 159076},
	{"ENKEPHALIN", 10, 159077},
	{"QUECHEE", 7, 159078},
	{"ELGG", 4, 159079},
	{"DARMO", 5, 159080},
	{"MESCALINE", 9, 159081},
	{"APCD", 4, 159082},
	{"GRISMAN", 7, 159083},
	{"QUIENES", 7, 159084},
	{"ELLAND", 6, 159085},
	{"MOJACAR", 7, 159086},
	{"BLEEKER", 7, 159087},
	{"RESOURCESHELF", 13, 159088},
	{"CLUETRAIN", 9, 159089},
	{"SAILPLANES", 10, 159090},
	{"GOLDENDALE", 10, 159091},
	{"BOPPY", 5, 159092},
	{"YLHA", 4, 159093},
	{"YDBA", 4, 159094},
	{"YALY", 4, 159095},
	{"TZBA", 4, 159096},
	{"SKOC", 4, 159097},
	{"RAFH", 4, 159098},
	{"PBYN", 4, 159099},
	{"LTOX", 4, 159100},
	{"LAMK", 4, 159101},
	{"GTOX", 4, 159102},
	{"FEFU", 4, 159103},
	{"EKMM", 4, 159104},
	{"EILK", 4, 159105},
	{"DDAK", 4, 159106},
	{"DBCA", 4, 159107},
	{"AKGA", 4, 159108},
	{"TIMBERLANDS", 11, 159109},
	{"BYTEORDER", 9, 159110},
	{"WHADDYA", 7, 159111},
	{"HUMDRUM", 7, 159112},
	{"TUSCULUM", 8, 159113},
	{"DISTENDED", 9, 159114},
	{"HAMPTONINN", 10, 159115},
	{"TELOMERIC", 9, 159116},
	{"SOLIDAGO", 8, 159117},
	{"BOTTLERS", 8, 159118},
	{"SIFU", 4, 159119},
	{"SHEPHERDING", 11, 159120},
	{"FREGATA", 7, 159121},
	{"FAUN", 4, 159122},
	{"PAPINEAU", 8, 159123},
	{"ZELCO", 5, 159124},
	{"SKORT", 5, 159125},
	{"MAILWASHER", 10, 159126},
	{"ATTRNAME", 8, 159127},
	{"COMMONWEAL", 10, 159128},
	{"MULLIS", 6, 159129},
	{"SENSUS", 6, 159130},
	{"MASSEUR", 7, 159131},
	{"SCHYLLING", 9, 159132},
	{"RIVALED", 7, 159133},
	{"MICROFILMING", 12, 159134},
	{"PREMI", 5, 159135},
	{"NORRIDGE", 8, 159136},
	{"POWERWINCH", 10, 159137},
	{"BYBEE", 5, 159138},
	{"INDISPENSIBLE", 13, 159139},
	{"AZLE", 4, 159140},
	{"VIDEOSTUDIO", 11, 159141},
	{"SIPHONED", 8, 159142},
	{"UNNTAK", 6, 159143},
	{"KORB", 4, 159144},
	{"PRINTMAKER", 10, 159145},
	{"VITASPRINGS", 11, 159146},
	{"HAMILTONS", 9, 159147},
	{"TIDIED", 6, 159148},
	{"TACIS", 5, 159149},
	{"PROGRAMMIERUNG", 14, 159150},
	{"BLOGGIE", 7, 159151},
	{"RIJKSMUSEUM", 11, 159152},
	{"DOMINANTLY", 10, 159153},
	{"STEELPAD", 8, 159154},
	{"JRM", 3, 159155},
	{"SILTSTONE", 9, 159156},
	{"STATIONHOMESFOOD", 16, 159157},
	{"BRAHIMI", 7, 159158},
	{"PARLER", 6, 159159},
	{"AWOKEN", 6, 159160},
	{"CODEPROJECT", 11, 159161},
	{"ADALAT", 6, 159162},
	{"ASIAWEEK", 8, 159163},
	{"VISUALAGE", 9, 159164},
	{"NEOCORTEX", 9, 159165},
	{"STARFIELD", 9, 159166},
	{"SYNECHOCOCCUS", 13, 159167},
	{"PENLAC", 6, 159168},
	{"HELMAN", 6, 159169},
	{"REFACTORED", 10, 159170},
	{"WORLDLII", 8, 159171},
	{"FOLGEN", 6, 159172},
	{"ZZOW", 4, 159173},
	{"YKST", 4, 159174},
	{"YKEM", 4, 159175},
	{"WEFU", 4, 159176},
	{"VYDI", 4, 159177},
	{"UOSY", 4, 159178},
	{"UKYI", 4, 159179},
	{"SCSW", 4, 159180},
	{"SBNC", 4, 159181},
	{"RDIK", 4, 159182},
	{"ORLL", 4, 159183},
	{"OBKI", 4, 159184},
	{"NWEJ", 4, 159185},
	{"NUZB", 4, 159186},
	{"NULM", 4, 159187},
	{"NEKU", 4, 159188},
	{"LVIB", 4, 159189},
	{"LMPE", 4, 159190},
	{"DMMA", 4, 159191},
	{"DLEJ", 4, 159192},
	{"DCST", 4, 159193},
	{"CSHU", 4, 159194},
	{"AUFA", 4, 159195},
	{"RENTABLE", 8, 159196},
	{"EGREETINGS", 10, 159197},
	{"CYANOCOBALAMIN", 14, 159198},
	{"ROYBAL", 6, 159199},
	{"PRESSURIZATION", 14, 159200},
	{"INSTRUCCIONES", 13, 159201},
	{"HYPOPLASIA", 10, 159202},
	{"SHINODA", 7, 159203},
	{"NEWBINS", 7, 159204},
	{"GROTHENDIECK", 12, 159205},
	{"GOODELL", 7, 159206},
	{"PERCUSSIONS", 11, 159207},
	{"FATNESS", 7, 159208},
	{"PIONE", 5, 159209},
	{"COALESCED", 9, 159210},
	{"WIZZARD", 7, 159211},
	{"NUTRACEUTICS", 12, 159212},
	{"SUMME", 5, 159213},
	{"HARLEYSVILLE", 12, 159214},
	{"ROSICRUCIAN", 11, 159215},
	{"KNOP", 4, 159216},
	{"KNIPEX", 6, 159217},
	{"VERKOOP", 7, 159218},
	{"SPORTINGBET", 11, 159219},
	{"GALARIES", 8, 159220},
	{"ZEITSCHRIFTEN", 13, 159221},
	{"WBEM", 4, 159222},
	{"SRILANKAN", 9, 159223},
	{"POZUJE", 6, 159224},
	{"JANSSENS", 8, 159225},
	{"LODITA", 6, 159226},
	{"ROCKLER", 7, 159227},
	{"SEPTEM", 6, 159228},
	{"BOOKBINDER", 10, 159229},
	{"BLOGEXPLOSION", 13, 159230},
	{"RAYCOM", 6, 159231},
	{"OLYMPIAKOS", 10, 159232},
	{"HILTONHOTELS", 12, 159233},
	{"MACRON", 6, 159234},
	{"OFFSTAGE", 8, 159235},
	{"PAINTWORK", 9, 159236},
	{"PHOTOJOURNALISTIC", 17, 159237},
	{"HOEVEN", 6, 159238},
	{"HARLIN", 6, 159239},
	{"LENTE", 5, 159240},
	{"DANCEABLE", 9, 159241},
	{"ZAPTEL", 6, 159242},
	{"DANGLED", 7, 159243},
	{"CASR", 4, 159244},
	{"PRESUMPTIVELY", 13, 159245},
	{"CHARRO", 6, 159246},
	{"ARSENIDE", 8, 159247},
	{"VIDEOHOUND", 10, 159248},
	{"MINDSETS", 8, 159249},
	{"BOURTON", 7, 159250},
	{"BROADHEAD", 9, 159251},
	{"CYANO", 5, 159252},
	{"FIXEDLY", 7, 159253},
	{"UYBO", 4, 159254},
	{"UMJO", 4, 159255},
	{"TOXY", 4, 159256},
	{"RJRA", 4, 159257},
	{"RAAW", 4, 159258},
	{"OMCG", 4, 159259},
	{"MIMU", 4, 159260},
	{"LAFS", 4, 159261},
	{"IGYA", 4, 159262},
	{"GAOZ", 4, 159263},
	{"EYYA", 4, 159264},
	{"EOQU", 4, 159265},
	{"CVIA", 4, 159266},
	{"CEKS", 4, 159267},
	{"AURL", 4, 159268},
	{"ATYF", 4, 159269},
	{"CALIDRIS", 8, 159270},
	{"FEEBLY", 6, 159271},
	{"CLAUDICATION", 12, 159272},
	{"HULLED", 6, 159273},
	{"BRANCHVILLE", 11, 159274},
	{"SADMIN", 6, 159275},
	{"PRURIENT", 8, 159276},
	{"MELANOMAS", 9, 159277},
	{"HAVARD", 6, 159278},
	{"INDEPUNDIT", 10, 159279},
	{"DYNABOOK", 8, 159280},
	{"COMMENTO", 8, 159281},
	{"DVW", 3, 159282},
	{"SPRITZ", 6, 159283},
	{"RYLE", 4, 159284},
	{"AVITAL", 6, 159285},
	{"DEMUXER", 7, 159286},
	{"RETHYMNON", 9, 159287},
	{"DEFINATE", 8, 159288},
	{"PANOPTICON", 10, 159289},
	{"MYOSITIS", 8, 159290},
	{"LIFFEY", 6, 159291},
	{"WORDTRACKER", 11, 159292},
	{"NAOKO", 5, 159293},
	{"POCKY", 5, 159294},
	{"PHARES", 6, 159295},
	{"FAKENHAM", 8, 159296},
	{"WEDDELL", 7, 159297},
	{"HOMEABOUT", 9, 159298},
	{"OBJEKT", 6, 159299},
	{"SUBFRAME", 8, 159300},
	{"YUU", 3, 159301},
	{"SOLINGEN", 8, 159302},
	{"SUBRULE", 7, 159303},
	{"LONGINT", 7, 159304},
	{"GAREY", 5, 159305},
	{"GETSTRING", 9, 159306},
	{"VEXATION", 8, 159307},
	{"REDESIGNATION", 13, 159308},
	{"LACH", 4, 159309},
	{"ROSLINDALE", 10, 159310},
	{"GALAN", 5, 159311},
	{"OXIMETER", 8, 159312},
	{"INDENTURES", 10, 159313},
	{"CMPL", 4, 159314},
	{"NIGHTSHIFT", 10, 159315},
	{"RYSZARD", 7, 159316},
	{"BASTIONS", 8, 159317},
	{"MELLING", 7, 159318},
	{"DEFECATION", 10, 159319},
	{"BAILLY", 6, 159320},
	{"THREADBARE", 10, 159321},
	{"OKAYS", 5, 159322},
	{"EMISSARIES", 10, 159323},
	{"EDENBRIDGE", 10, 159324},
	{"ANGLICANISM", 11, 159325},
	{"ANSWERPHONE", 11, 159326},
	{"FLYEUROPE", 9, 159327},
	{"VERTUE", 6, 159328},
	{"SPORTZ", 6, 159329},
	{"LIVRO", 5, 159330},
	{"CODD", 4, 159331},
	{"FLAKEY", 6, 159332},
	{"FINANCEFAMILY", 13, 159333},
	{"SAARI", 5, 159334},
	{"PALLONE", 7, 159335},
	{"SUBSIDING", 9, 159336},
	{"YLEX", 4, 159337},
	{"XCYL", 4, 159338},
	{"WGAS", 4, 159339},
	{"WEFL", 4, 159340},
	{"UTYN", 4, 159341},
	{"RRYZ", 4, 159342},
	{"PTQU", 4, 159343},
	{"PHBR", 4, 159344},
	{"OIPR", 4, 159345},
	{"MNEL", 4, 159346},
	{"LEGN", 4, 159347},
	{"KMEU", 4, 159348},
	{"IIBY", 4, 159349},
	{"GLIL", 4, 159350},
	{"GJOR", 4, 159351},
	{"DNHL", 4, 159352},
	{"BCSL", 4, 159353},
	{"CYFNOD", 6, 159354},
	{"ORDERABLE", 9, 159355},
	{"PURRED", 6, 159356},
	{"COALFIELD", 9, 159357},
	{"ENVELOPS", 8, 159358},
	{"JOBCV", 5, 159359},
	{"DOGVILLE", 8, 159360},
	{"MJPEG", 5, 159361},
	{"ASSOCIAZIONI", 12, 159362},
	{"LIEVE", 5, 159363},
	{"UNECONOMIC", 10, 159364},
	{"IRCII", 5, 159365},
	{"FELLY", 5, 159366},
	{"SCHLAGER", 8, 159367},
	{"CONTINGENTS", 11, 159368},
	{"CEED", 4, 159369},
	{"KOIKE", 5, 159370},
	{"BODYBOARDING", 12, 159371},
	{"SQUIRMED", 8, 159372},
	{"FILIPE", 6, 159373},
	{"NAPOCA", 6, 159374},
	{"NEWGEN", 6, 159375},
	{"PEEVED", 6, 159376},
	{"MICROGLIA", 9, 159377},
	{"HAREN", 5, 159378},
	{"KBITS", 5, 159379},
	{"WORMING", 7, 159380},
	{"PITOT", 5, 159381},
	{"DECOLONIZATION", 14, 159382},
	{"BINHEX", 6, 159383},
	{"COSM", 4, 159384},
	{"MOTIV", 5, 159385},
	{"MACPPC", 6, 159386},
	{"MACHYNLLETH", 11, 159387},
	{"SHOWREEL", 8, 159388},
	{"INFOPEI", 7, 159389},
	{"TCPXX", 5, 159390},
	{"SANGUE", 6, 159391},
	{"MOTORYACHT", 10, 159392},
	{"MATTIOLO", 8, 159393},
	{"CONSTRUCTIONAL", 14, 159394},
	{"LEWY", 4, 159395},
	{"FUTUREMARK", 10, 159396},
	{"RISLEY", 6, 159397},
	{"MICROMAIN", 9, 159398},
	{"OSTRACIZED", 10, 159399},
	{"MONTALVO", 8, 159400},
	{"CUTSCENES", 9, 159401},
	{"KALANI", 6, 159402},
	{"EXCRETA", 7, 159403},
	{"IMBALANCED", 10, 159404},
	{"CREWEL", 6, 159405},
	{"SSDD", 4, 159406},
	{"SERIALIZING", 11, 159407},
	{"LYFE", 4, 159408},
	{"VBG", 3, 159409},
	{"GWEFAN", 6, 159410},
	{"AOLCOM", 6, 159411},
	{"TAYLER", 6, 159412},
	{"THEOLOGIES", 10, 159413},
	{"ZYHA", 4, 159414},
	{"VSTU", 4, 159415},
	{"USSQ", 4, 159416},
	{"TYOG", 4, 159417},
	{"TVEX", 4, 159418},
	{"SUAV", 4, 159419},
	{"POZZ", 4, 159420},
	{"PERZ", 4, 159421},
	{"NWEU", 4, 159422},
	{"NTLL", 4, 159423},
	{"NGPY", 4, 159424},
	{"NFLQ", 4, 159425},
	{"MRTR", 4, 159426},
	{"MCGH", 4, 159427},
	{"KIJA", 4, 159428},
	{"INCG", 4, 159429},
	{"IFKA", 4, 159430},
	{"HMGU", 4, 159431},
	{"GZHI", 4, 159432},
	{"GIOF", 4, 159433},
	{"FYSU", 4, 159434},
	{"ERZB", 4, 159435},
	{"ENLL", 4, 159436},
	{"EDLC", 4, 159437},
	{"DYLU", 4, 159438},
	{"BMPC", 4, 159439},
	{"PURCH", 5, 159440},
	{"POLYMYXIN", 9, 159441},
	{"GLG", 3, 159442},
	{"MOREINFO", 8, 159443},
	{"GANCICLOVIR", 11, 159444},
	{"EDITBOXSTYLE", 12, 159445},
	{"KNEBWORTH", 9, 159446},
	{"PRINTMAKERS", 11, 159447},
	{"FIFIELD", 7, 159448},
	{"DURKEE", 6, 159449},
	{"REINSTALLATION", 14, 159450},
	{"MONTELLO", 8, 159451},
	{"CRINGING", 8, 159452},
	{"OEDILF", 6, 159453},
	{"BLOGSKINS", 9, 159454},
	{"ITPROPORTAL", 11, 159455},
	{"RIOD", 4, 159456},
	{"NANOCRYSTALLINE", 15, 159457},
	{"MAPE", 4, 159458},
	{"KANNO", 5, 159459},
	{"PRABHAKAR", 9, 159460},
	{"JUNGS", 5, 159461},
	{"MANGANO", 7, 159462},
	{"CARAN", 5, 159463},
	{"SYMON", 5, 159464},
	{"UCHI", 4, 159465},
	{"CONCERTA", 8, 159466},
	{"FELINA", 6, 159467},
	{"SANILAC", 7, 159468},
	{"ANCES", 5, 159469},
	{"PHOTOSHOPPED", 12, 159470},
	{"CEEDINGS", 8, 159471},
	{"PEEPHOLE", 8, 159472},
	{"INTERRELATION", 13, 159473},
	{"COMSOL", 6, 159474},
	{"TRAUMATISED", 11, 159475},
	{"MELLONS", 7, 159476},
	{"SINERGY", 7, 159477},
	{"DURAS", 5, 159478},
	{"PIFFLE", 6, 159479},
	{"KUMON", 5, 159480},
	{"RIVETER", 7, 159481},
	{"PAROLEE", 7, 159482},
	{"YTIZ", 4, 159483},
	{"XDEP", 4, 159484},
	{"WBUL", 4, 159485},
	{"VEKR", 4, 159486},
	{"UWAK", 4, 159487},
	{"UDNI", 4, 159488},
	{"SWOW", 4, 159489},
	{"RYLT", 4, 159490},
	{"RWIM", 4, 159491},
	{"NGPT", 4, 159492},
	{"NGCB", 4, 159493},
	{"NEZD", 4, 159494},
	{"LOTV", 4, 159495},
	{"KTAC", 4, 159496},
	{"KANL", 4, 159497},
	{"JUNP", 4, 159498},
	{"IUSK", 4, 159499},
	{"FCBS", 4, 159500},
	{"EXGE", 4, 159501},
	{"EGSD", 4, 159502},
	{"DKAD", 4, 159503},
	{"BREQ", 4, 159504},
	{"BBSB", 4, 159505},
	{"RESTATING", 9, 159506},
	{"DOBSONIAN", 9, 159507},
	{"ECHIDNA", 7, 159508},
	{"DEMONIZE", 8, 159509},
	{"HUNZA", 5, 159510},
	{"MANGOS", 6, 159511},
	{"GENDRON", 7, 159512},
	{"RASEN", 5, 159513},
	{"GHAZALI", 7, 159514},
	{"INTERWORKS", 10, 159515},
	{"TUONG", 5, 159516},
	{"TARIFFE", 7, 159517},
	{"OMNIWEB", 7, 159518},
	{"MARCIO", 6, 159519},
	{"MONOBLOC", 8, 159520},
	{"TUSHNET", 7, 159521},
	{"KLEINEN", 7, 159522},
	{"BOOKSENSE", 9, 159523},
	{"SUBLAYER", 8, 159524},
	{"CUTSCENE", 8, 159525},
	{"PENNZOIL", 8, 159526},
	{"CONSISTANTLY", 12, 159527},
	{"COATER", 6, 159528},
	{"ADITI", 5, 159529},
	{"ISOTRETINOIN", 12, 159530},
	{"POLYS", 5, 159531},
	{"DBGET", 5, 159532},
	{"BUGIL", 5, 159533},
	{"WITCHVOX", 8, 159534},
	{"RESEA", 5, 159535},
	{"PROBLEMEN", 9, 159536},
	{"EASINGTON", 9, 159537},
	{"ZHONGHUA", 8, 159538},
	{"TRINCOMALEE", 11, 159539},
	{"GREENHILLS", 10, 159540},
	{"TYRO", 4, 159541},
	{"CATHEY", 6, 159542},
	{"BULLFIGHT", 9, 159543},
	{"JUMPE", 5, 159544},
	{"CIVICRM", 7, 159545},
	{"DEMOGRAPHICALLY", 15, 159546},
	{"UEKAWA", 6, 159547},
	{"TRIDGE", 6, 159548},
	{"COLLINGSWOOD", 12, 159549},
	{"CHEY", 4, 159550},
	{"JABBERWOCKY", 11, 159551},
	{"PRUDEN", 6, 159552},
	{"TROWELS", 7, 159553},
	{"REAIS", 5, 159554},
	{"HEDLUND", 7, 159555},
	{"DEVERS", 6, 159556},
	{"WRACKING", 8, 159557},
	{"AIRBRUSHES", 10, 159558},
	{"KILBOURNE", 9, 159559},
	{"TOWNSITE", 8, 159560},
	{"ZORC", 4, 159561},
	{"XTEV", 4, 159562},
	{"VYAC", 4, 159563},
	{"UNHC", 4, 159564},
	{"ULFP", 4, 159565},
	{"UGFE", 4, 159566},
	{"SDYL", 4, 159567},
	{"RNLU", 4, 159568},
	{"RDYP", 4, 159569},
	{"NOKU", 4, 159570},
	{"MUMG", 4, 159571},
	{"MGAY", 4, 159572},
	{"HSLU", 4, 159573},
	{"GRYE", 4, 159574},
	{"GAAD", 4, 159575},
	{"FTLB", 4, 159576},
	{"COFU", 4, 159577},
	{"AGEX", 4, 159578},
	{"INTRODUCER", 10, 159579},
	{"BIOPROCESS", 10, 159580},
	{"MYALGIA", 7, 159581},
	{"MAURITIAN", 9, 159582},
	{"MFGR", 4, 159583},
	{"NUDEST", 6, 159584},
	{"PFB", 3, 159585},
	{"PLX", 3, 159586},
	{"GNUMAKEFILE", 11, 159587},
	{"CONCANAVALIN", 12, 159588},
	{"OUTSTRIP", 8, 159589},
	{"PAPS", 4, 159590},
	{"DEMERITS", 8, 159591},
	{"INSURABILITY", 12, 159592},
	{"EMPYRE", 6, 159593},
	{"REEFING", 7, 159594},
	{"HIGHWAYMAN", 10, 159595},
	{"CONTES", 6, 159596},
	{"MERIAN", 6, 159597},
	{"LIBERMAN", 8, 159598},
	{"CLOBBERED", 9, 159599},
	{"LFTP", 4, 159600},
	{"SACAGAWEA", 9, 159601},
	{"PREQUELS", 8, 159602},
	{"ROCKI", 5, 159603},
	{"LTRS", 4, 159604},
	{"HUSSARS", 7, 159605},
	{"FATHERLY", 8, 159606},
	{"COMPETETIVE", 11, 159607},
	{"HRSG", 4, 159608},
	{"BRIDGETT", 8, 159609},
	{"JEHU", 4, 159610},
	{"ABDULLA", 7, 159611},
	{"MEMORIE", 7, 159612},
	{"SAPHENOUS", 9, 159613},
	{"ACCOMMADATION", 13, 159614},
	{"ASTUCE", 6, 159615},
	{"REGISTRARSE", 11, 159616},
	{"ROLEN", 5, 159617},
	{"NAISMITH", 8, 159618},
	{"HISLOP", 6, 159619},
	{"CLAVICLE", 8, 159620},
	{"SCHOUTEN", 8, 159621},
	{"MISTA", 5, 159622},
	{"MERWIN", 6, 159623},
	{"SOUTHWARDS", 10, 159624},
	{"ISOMORPHISMS", 12, 159625},
	{"ASPIRATIONAL", 12, 159626},
	{"KEIICHI", 7, 159627},
	{"BITTON", 6, 159628},
	{"CHAOYANG", 8, 159629},
	{"TANNERSVILLE", 12, 159630},
	{"SWERVED", 7, 159631},
	{"QUANTIC", 7, 159632},
	{"GTPASES", 7, 159633},
	{"ROAMAN", 6, 159634},
	{"SKOWHEGAN", 9, 159635},
	{"FRESHRPMS", 9, 159636},
	{"ROFLMAO", 7, 159637},
	{"ZENU", 4, 159638},
	{"ZDOE", 4, 159639},
	{"XSCE", 4, 159640},
	{"XARM", 4, 159641},
	{"VYAI", 4, 159642},
	{"SPMF", 4, 159643},
	{"PMYM", 4, 159644},
	{"OBCL", 4, 159645},
	{"NZOF", 4, 159646},
	{"NUPY", 4, 159647},
	{"NBCF", 4, 159648},
	{"MGHA", 4, 159649},
	{"IDEZ", 4, 159650},
	{"GUYJ", 4, 159651},
	{"GGEM", 4, 159652},
	{"FEYW", 4, 159653},
	{"EKRS", 4, 159654},
	{"DDFE", 4, 159655},
	{"COXH", 4, 159656},
	{"ASYJ", 4, 159657},
	{"AIKM", 4, 159658},
	{"ACAY", 4, 159659},
	{"PSYCHOMETRICS", 13, 159660},
	{"STRIATA", 7, 159661},
	{"CISCOVIEW", 9, 159662},
	{"BLONDESENSE", 11, 159663},
	{"MOLIERE", 7, 159664},
	{"DUL", 3, 159665},
	{"RAMADAINN", 9, 159666},
	{"GLBTQ", 5, 159667},
	{"POPOVICH", 8, 159668},
	{"QUEBECOR", 8, 159669},
	{"MARWICK", 7, 159670},
	{"UNFEASIBLE", 10, 159671},
	{"EXPAN", 5, 159672},
	{"RECURRED", 8, 159673},
	{"CHAUSSURES", 10, 159674},
	{"RIBONUCLEOTIDE", 14, 159675},
	{"FEDDERS", 7, 159676},
	{"CHENIER", 7, 159677},
	{"GRAMMING", 8, 159678},
	{"AHCCCS", 6, 159679},
	{"HOLLERING", 9, 159680},
	{"ORISKANY", 8, 159681},
	{"ROAMS", 5, 159682},
	{"SANTERIA", 8, 159683},
	{"NECOA", 5, 159684},
	{"MARRIOTTHOTEL", 13, 159685},
	{"COCKEYSVILLE", 12, 159686},
	{"PALATAL", 7, 159687},
	{"GOBBLER", 7, 159688},
	{"GLITE", 5, 159689},
	{"ASTROGLIDE", 10, 159690},
	{"CHRISMAS", 8, 159691},
	{"MERDEKA", 7, 159692},
	{"ZUSATZKOSTEN", 12, 159693},
	{"GOVERNEMENT", 11, 159694},
	{"FUHR", 4, 159695},
	{"GIVEMEPINK", 10, 159696},
	{"FXCOP", 5, 159697},
	{"CALCINED", 8, 159698},
	{"NATURWISSENSCHAFTEN", 19, 159699},
	{"DUNSTER", 7, 159700},
	{"SPACELABS", 9, 159701},
	{"REOCCURRING", 11, 159702},
	{"COMPUTADORAS", 12, 159703},
	{"HEMOS", 5, 159704},
	{"REYNOLD", 7, 159705},
	{"INHALTE", 7, 159706},
	{"TETONS", 6, 159707},
	{"COLEFORD", 8, 159708},
	{"THECUS", 6, 159709},
	{"QMC", 3, 159710},
	{"DUCTILITY", 9, 159711},
	{"EXISTENTIALIST", 14, 159712},
	{"XORM", 4, 159713},
	{"TMRG", 4, 159714},
	{"SIRV", 4, 159715},
	{"RIYO", 4, 159716},
	{"REVG", 4, 159717},
	{"QUAP", 4, 159718},
	{"OKOD", 4, 159719},
	{"NMRP", 4, 159720},
	{"NDMF", 4, 159721},
	{"MYSD", 4, 159722},
	{"LMTA", 4, 159723},
	{"LMSG", 4, 159724},
	{"LIXM", 4, 159725},
	{"IOFW", 4, 159726},
	{"GNJO", 4, 159727},
	{"FPIO", 4, 159728},
	{"EBKI", 4, 159729},
	{"DUFR", 4, 159730},
	{"DKAG", 4, 159731},
	{"CIDF", 4, 159732},
	{"BUGB", 4, 159733},
	{"BHUS", 4, 159734},
	{"LAMOTT", 6, 159735},
	{"AMITURE", 7, 159736},
	{"HERBY", 5, 159737},
	{"COLOMBIANS", 10, 159738},
	{"MITSUKO", 7, 159739},
	{"ICEL", 4, 159740},
	{"TERRIFY", 7, 159741},
	{"COLLABORATORY", 13, 159742},
	{"CCESS", 5, 159743},
	{"INTEGRAND", 9, 159744},
	{"TOOHEY", 6, 159745},
	{"BESOFFENE", 9, 159746},
	{"VLY", 3, 159747},
	{"JAXB", 4, 159748},
	{"CAFFEINEGODDESS", 15, 159749},
	{"SIEBER", 6, 159750},
	{"ORGANISTS", 9, 159751},
	{"UNESCAPE", 8, 159752},
	{"JWZ", 3, 159753},
	{"BUGLER", 6, 159754},
	{"BODYSHOP", 8, 159755},
	{"LICENTIATE", 10, 159756},
	{"PERIODE", 7, 159757},
	{"RECCOMENDED", 11, 159758},
	{"INNERHALB", 9, 159759},
	{"LOCALI", 6, 159760},
	{"PIVEN", 5, 159761},
	{"HIGUCHI", 7, 159762},
	{"VIDEODISC", 9, 159763},
	{"THORSEN", 7, 159764},
	{"PHRACK", 6, 159765},
	{"INFLAMMABLE", 11, 159766},
	{"THETHIRDI", 9, 159767},
	{"DIFFUTILS", 9, 159768},
	{"CZECHIA", 7, 159769},
	{"ANTONYM", 7, 159770},
	{"STRANA", 6, 159771},
	{"INTERNEWS", 9, 159772},
	{"FORGOING", 8, 159773},
	{"FREUNDIN", 8, 159774},
	{"BESOS", 5, 159775},
	{"RESOLU", 6, 159776},
	{"REEPERBAHN", 10, 159777},
	{"PROGAM", 6, 159778},
	{"NASCO", 5, 159779},
	{"ACETYLGLUCOSAMINE", 17, 159780},
	{"GAMEON", 6, 159781},
	{"APPRENDI", 8, 159782},
	{"RUFFALO", 7, 159783},
	{"MAZA", 4, 159784},
	{"CANTIDAD", 8, 159785},
	{"SHIMADZU", 8, 159786},
	{"NOUGAT", 6, 159787},
	{"BUNIONS", 7, 159788},
	{"BPSK", 4, 159789},
	{"CONTATO", 7, 159790},
	{"MORWELL", 7, 159791},
	{"PCSC", 4, 159792},
	{"INERRANCY", 9, 159793},
	{"BORTHWICK", 9, 159794},
	{"STOCKAGE", 8, 159795},
	{"LIBERACE", 8, 159796},
	{"UNDERDARK", 9, 159797},
	{"DORAEMON", 8, 159798},
	{"PARKHILL", 8, 159799},
	{"VPHO", 4, 159800},
	{"VAPL", 4, 159801},
	{"TKRO", 4, 159802},
	{"TAPM", 4, 159803},
	{"SMRD", 4, 159804},
	{"ROUK", 4, 159805},
	{"PSOB", 4, 159806},
	{"PPPR", 4, 159807},
	{"PEXO", 4, 159808},
	{"OVOM", 4, 159809},
	{"OUIW", 4, 159810},
	{"NURD", 4, 159811},
	{"MREZ", 4, 159812},
	{"MNRE", 4, 159813},
	{"MBDI", 4, 159814},
	{"LRYU", 4, 159815},
	{"KHUG", 4, 159816},
	{"KDIC", 4, 159817},
	{"FYSA", 4, 159818},
	{"FLQU", 4, 159819},
	{"FDAC", 4, 159820},
	{"ESPW", 4, 159821},
	{"ECSM", 4, 159822},
	{"DDEJ", 4, 159823},
	{"CLUC", 4, 159824},
	{"BHAW", 4, 159825},
	{"ABIU", 4, 159826},
	{"COPULA", 6, 159827},
	{"UNDERCUTS", 9, 159828},
	{"DISOWNED", 8, 159829},
	{"TWIKIDOCGRAPHICS", 16, 159830},
	{"OHAUS", 5, 159831},
	{"JAHRBUCH", 8, 159832},
	{"SPAGNOLO", 8, 159833},
	{"RESPA", 5, 159834},
	{"SKELETOR", 8, 159835},
	{"LOGNAME", 7, 159836},
	{"SLEUTHING", 9, 159837},
	{"PERKO", 5, 159838},
	{"GIFTSHOP", 8, 159839},
	{"HAYESVILLE", 10, 159840},
	{"DEGF", 4, 159841},
	{"INTELLIGENTHIRE", 15, 159842},
	{"PHENELZINE", 10, 159843},
	{"SHELDRAKE", 9, 159844},
	{"YUG", 3, 159845},
	{"UNEARTHING", 10, 159846},
	{"PARLEMENT", 9, 159847},
	{"MEDALISTS", 9, 159848},
	{"VOIVOD", 6, 159849},
	{"SURMOUNT", 8, 159850},
	{"SPRINGBOKS", 10, 159851},
	{"PARISHAD", 8, 159852},
	{"REEVALUATED", 11, 159853},
	{"CLEARTYPE", 9, 159854},
	{"CARBARYL", 8, 159855},
	{"PSYCHOPATHS", 11, 159856},
	{"DEVPAPERS", 9, 159857},
	{"DOWNOAD", 7, 159858},
	{"ABERGELE", 8, 159859},
	{"SWIMMINGPOOL", 12, 159860},
	{"BOKU", 4, 159861},
	{"TRANNIE", 7, 159862},
	{"SEARSH", 6, 159863},
	{"HEADSHIP", 8, 159864},
	{"INVASIVENESS", 12, 159865},
	{"ESPECIAIS", 9, 159866},
	{"MBSF", 4, 159867},
	{"MARIJA", 6, 159868},
	{"CRANDON", 7, 159869},
	{"MULTIFACTORIAL", 14, 159870},
	{"HIROKI", 6, 159871},
	{"HELLENES", 8, 159872},
	{"OUTSTRIPS", 9, 159873},
	{"IFIC", 4, 159874},
	{"NEWSCASTER", 10, 159875},
	{"UNHEEDED", 8, 159876},
	{"MIYU", 4, 159877},
	{"FUOCO", 5, 159878},
	{"NIHILIST", 8, 159879},
	{"WRIGHTSON", 9, 159880},
	{"REVISER", 7, 159881},
	{"LABRADORS", 9, 159882},
	{"SIECLE", 6, 159883},
	{"YMOI", 4, 159884},
	{"WLAM", 4, 159885},
	{"UPIW", 4, 159886},
	{"UKKO", 4, 159887},
	{"UAWE", 4, 159888},
	{"TDEW", 4, 159889},
	{"SDEJ", 4, 159890},
	{"MBUG", 4, 159891},
	{"LALD", 4, 159892},
	{"KIGE", 4, 159893},
	{"IRKF", 4, 159894},
	{"FYEM", 4, 159895},
	{"FASG", 4, 159896},
	{"ERGK", 4, 159897},
	{"BYLS", 4, 159898},
	{"ADSJ", 4, 159899},
	{"AACB", 4, 159900},
	{"RAYGUN", 6, 159901},
	{"RECUSE", 6, 159902},
	{"QUALITYINN", 10, 159903},
	{"WATCHZONE", 9, 159904},
	{"NICHOLL", 7, 159905},
	{"METABOLIZE", 10, 159906},
	{"MOLITOR", 7, 159907},
	{"MANUFACTURINGTALK", 17, 159908},
	{"EWEB", 4, 159909},
	{"LINSENBACH", 10, 159910},
	{"DECOMPRESSED", 12, 159911},
	{"ZOOPHILE", 8, 159912},
	{"RADHAKRISHNAN", 13, 159913},
	{"SEATCH", 6, 159914},
	{"RAIMONDO", 8, 159915},
	{"SYMPTONS", 8, 159916},
	{"WILLOWDALE", 10, 159917},
	{"PAUSINI", 7, 159918},
	{"OJJDP", 5, 159919},
	{"DIACYLGLYCEROL", 14, 159920},
	{"FICTIONALIZED", 13, 159921},
	{"PROCLAIMERS", 11, 159922},
	{"SATCHELS", 8, 159923},
	{"APOLO", 5, 159924},
	{"RSLS", 4, 159925},
	{"RECODED", 7, 159926},
	{"POLYMORPHONUCLEAR", 17, 159927},
	{"HUNDLEY", 7, 159928},
	{"EBONICS", 7, 159929},
	{"MUNSCH", 6, 159930},
	{"UITOOLKIT", 9, 159931},
	{"PWCS", 4, 159932},
	{"EFFEX", 5, 159933},
	{"CAHOOTS", 7, 159934},
	{"LECROY", 6, 159935},
	{"MAGIS", 5, 159936},
	{"STAGNATE", 8, 159937},
	{"ALLBERY", 7, 159938},
	{"LITTRELL", 8, 159939},
	{"RECLAIMS", 8, 159940},
	{"AALST", 5, 159941},
	{"FEELER", 6, 159942},
	{"NIKKY", 5, 159943},
	{"ESAME", 5, 159944},
	{"MANTISSA", 8, 159945},
	{"RANDBURG", 8, 159946},
	{"ASHWIN", 6, 159947},
	{"RIPCURL", 7, 159948},
	{"VERSAL", 6, 159949},
	{"ROCCOBAROCCO", 12, 159950},
	{"MANUFACTUR", 10, 159951},
	{"STROGANOFF", 10, 159952},
	{"SKITTISH", 8, 159953},
	{"KOKANEE", 7, 159954},
	{"SACROSANCT", 10, 159955},
	{"CALLGIRL", 8, 159956},
	{"BAKODA", 6, 159957},
	{"TEENGIRL", 8, 159958},
	{"ZZIC", 4, 159959},
	{"XTDI", 4, 159960},
	{"WWIS", 4, 159961},
	{"VTUR", 4, 159962},
	{"TSUJ", 4, 159963},
	{"TEKR", 4, 159964},
	{"SXBO", 4, 159965},
	{"SUEV", 4, 159966},
	{"OXAP", 4, 159967},
	{"OPOB", 4, 159968},
	{"KSEQ", 4, 159969},
	{"JWHI", 4, 159970},
	{"FYHA", 4, 159971},
	{"FIXM", 4, 159972},
	{"DKOO", 4, 159973},
	{"CIDL", 4, 159974},
	{"CDSW", 4, 159975},
	{"WHACKY", 6, 159976},
	{"VARITEK", 7, 159977},
	{"SOLIMAN", 7, 159978},
	{"UNIWORLD", 8, 159979},
	{"THROMBOCYTOPENIC", 16, 159980},
	{"WRIGHTWOOD", 10, 159981},
	{"POCKETBOOKS", 11, 159982},
	{"AGNOSTICS", 9, 159983},
	{"CPEO", 4, 159984},
	{"BIRTHED", 7, 159985},
	{"RYANS", 5, 159986},
	{"EATONVILLE", 10, 159987},
	{"MINIT", 5, 159988},
	{"LEGALISM", 8, 159989},
	{"NOBU", 4, 159990},
	{"EQUILIBRATED", 12, 159991},
	{"PUF", 3, 159992},
	{"NEGUS", 5, 159993},
	{"CHROMATID", 9, 159994},
	{"SAVORED", 7, 159995},
	{"CLETUS", 6, 159996},
	{"CAMBELL", 7, 159997},
	{"DUCEPPE", 7, 159998},
	{"CRONOS", 6, 159999},
	{"MATERIALES", 10, 160000},
	{"RECTORS", 7, 160001},
	{"HIDDENCAM", 9, 160002},
	{"COMPULSIONS", 11, 160003},
	{"HANKIES", 7, 160004},
	{"BEVELLED", 8, 160005},
	{"VALUEPACK", 9, 160006},
	{"MELLE", 5, 160007},
	{"NETHERWORLD", 11, 160008},
	{"CALIFONE", 8, 160009},
	{"TRANSGENES", 10, 160010},
	{"DEDA", 4, 160011},
	{"VARIATE", 7, 160012},
	{"PULSATIL", 8, 160013},
	{"WOLLE", 5, 160014},
	{"PLASTICA", 8, 160015},
	{"STEFFENS", 8, 160016},
	{"BIATCH", 6, 160017},
	{"APPRENDRE", 9, 160018},
	{"HABITATIONS", 11, 160019},
	{"PULMICORT", 9, 160020},
	{"PWG", 3, 160021},
	{"DIPLO", 5, 160022},
	{"AUSTR", 5, 160023},
	{"WATERSHIP", 9, 160024},
	{"UNDERBODY", 9, 160025},
	{"CREMATORIES", 11, 160026},
	{"CANADY", 6, 160027},
	{"WARF", 4, 160028},
	{"SYLVESTRIS", 10, 160029},
	{"ENERGYWATCH", 11, 160030},
	{"COWERING", 8, 160031},
	{"PYELONEPHRITIS", 14, 160032},
	{"BICULTURAL", 10, 160033},
	{"OVERHEAR", 8, 160034},
	{"NANDI", 5, 160035},
	{"YLUD", 4, 160036},
	{"UXRE", 4, 160037},
	{"UAYL", 4, 160038},
	{"TUNV", 4, 160039},
	{"HREX", 4, 160040},
	{"FJAK", 4, 160041},
	{"FEBH", 4, 160042},
	{"DULW", 4, 160043},
	{"DCYR", 4, 160044},
	{"CEKR", 4, 160045},
	{"BCBU", 4, 160046},
	{"BBOU", 4, 160047},
	{"ATYL", 4, 160048},
	{"AGIK", 4, 160049},
	{"ISOPURE", 7, 160050},
	{"ANURADHA", 8, 160051},
	{"BOOOBS", 6, 160052},
	{"MOONSTRUCK", 10, 160053},
	{"VERSATA", 7, 160054},
	{"TRAMWAYS", 8, 160055},
	{"TAWDRY", 6, 160056},
	{"LASICA", 6, 160057},
	{"ARACHNIDS", 9, 160058},
	{"JUNCUS", 6, 160059},
	{"SCHER", 5, 160060},
	{"OCAL", 4, 160061},
	{"DOUBLETS", 8, 160062},
	{"PASK", 4, 160063},
	{"LAVAS", 5, 160064},
	{"MITOGENIC", 9, 160065},
	{"SYSADM", 6, 160066},
	{"KOBRA", 5, 160067},
	{"TURNABOUT", 9, 160068},
	{"MINDORO", 7, 160069},
	{"DNFORUM", 7, 160070},
	{"DIPYRIDAMOLE", 12, 160071},
	{"NOLOGIES", 8, 160072},
	{"MOLEC", 5, 160073},
	{"HENRIQUES", 9, 160074},
	{"SAINTES", 7, 160075},
	{"KINZIE", 6, 160076},
	{"CVSNOTICES", 10, 160077},
	{"BRUNETKA", 8, 160078},
	{"BEHRING", 7, 160079},
	{"MENKEN", 6, 160080},
	{"PUREED", 6, 160081},
	{"POMOC", 5, 160082},
	{"ELSNER", 6, 160083},
	{"GERDES", 6, 160084},
	{"ACTIVESHOPPER", 13, 160085},
	{"DEARCH", 6, 160086},
	{"WUTC", 4, 160087},
	{"WADEBRIDGE", 10, 160088},
	{"SUNTV", 5, 160089},
	{"SHEILD", 6, 160090},
	{"BUONA", 5, 160091},
	{"ALUE", 4, 160092},
	{"BELLER", 6, 160093},
	{"JETTISON", 8, 160094},
	{"CAMOMILE", 8, 160095},
	{"BENES", 5, 160096},
	{"RELOJES", 7, 160097},
	{"VONG", 4, 160098},
	{"OLIVO", 5, 160099},
	{"KINLOCH", 7, 160100},
	{"SKREWDRIVER", 11, 160101},
	{"WYNA", 4, 160102},
	{"WAFU", 4, 160103},
	{"UYAW", 4, 160104},
	{"RUKS", 4, 160105},
	{"ROEF", 4, 160106},
	{"PYBO", 4, 160107},
	{"PATQ", 4, 160108},
	{"NSRB", 4, 160109},
	{"MGAU", 4, 160110},
	{"LMMI", 4, 160111},
	{"KIML", 4, 160112},
	{"HAWM", 4, 160113},
	{"FEIW", 4, 160114},
	{"FAXO", 4, 160115},
	{"EWCD", 4, 160116},
	{"DRFA", 4, 160117},
	{"ATBB", 4, 160118},
	{"AHPL", 4, 160119},
	{"NOURISON", 8, 160120},
	{"MINDSHARE", 9, 160121},
	{"MESOAMERICAN", 12, 160122},
	{"TRIMLINE", 8, 160123},
	{"GASPARD", 7, 160124},
	{"NEUWIRTH", 8, 160125},
	{"MICHIANA", 8, 160126},
	{"PATHE", 5, 160127},
	{"DXM", 3, 160128},
	{"GBYTE", 5, 160129},
	{"DEPENDANCY", 10, 160130},
	{"SKALL", 5, 160131},
	{"SARDA", 5, 160132},
	{"EDIFF", 5, 160133},
	{"BIRKHAUSER", 10, 160134},
	{"CLONMEL", 7, 160135},
	{"SABRI", 5, 160136},
	{"GEODATA", 7, 160137},
	{"OBJECTNAME", 10, 160138},
	{"NEXXUS", 6, 160139},
	{"MEDIABLOG", 9, 160140},
	{"NUCLEONS", 8, 160141},
	{"KLEZ", 4, 160142},
	{"INTELLECTUALISM", 15, 160143},
	{"WALLMOUNT", 9, 160144},
	{"MILLON", 6, 160145},
	{"CANCE", 5, 160146},
	{"SHUMAKER", 8, 160147},
	{"ENVIROLINK", 10, 160148},
	{"MJC", 3, 160149},
	{"CANONIZED", 9, 160150},
	{"ORCHESTRATOR", 12, 160151},
	{"SOLICITOUS", 10, 160152},
	{"NUBIA", 5, 160153},
	{"KATZEN", 6, 160154},
	{"SPORTFOCUS", 10, 160155},
	{"MELES", 5, 160156},
	{"BEHRMAN", 7, 160157},
	{"LIBART", 6, 160158},
	{"FINDET", 6, 160159},
	{"ZEARCH", 6, 160160},
	{"MULLEIN", 7, 160161},
	{"BORERS", 6, 160162},
	{"PSIONICS", 8, 160163},
	{"COMFORTINN", 10, 160164},
	{"KOVALAM", 7, 160165},
	{"VORBEI", 6, 160166},
	{"LSEEK", 5, 160167},
	{"BLOGATHON", 9, 160168},
	{"JEEVAN", 6, 160169},
	{"GLAMIS", 6, 160170},
	{"CATTLEYA", 8, 160171},
	{"EMULATIONS", 10, 160172},
	{"HULKING", 7, 160173},
	{"PERSONALY", 9, 160174},
	{"BOSTONWORKS", 11, 160175},
	{"ZIEK", 4, 160176},
	{"YIMB", 4, 160177},
	{"USKR", 4, 160178},
	{"ULEK", 4, 160179},
	{"TZMO", 4, 160180},
	{"TWIZ", 4, 160181},
	{"RATQ", 4, 160182},
	{"PHYV", 4, 160183},
	{"ONPD", 4, 160184},
	{"OFIK", 4, 160185},
	{"NKYD", 4, 160186},
	{"NIMC", 4, 160187},
	{"KPEP", 4, 160188},
	{"GLOF", 4, 160189},
	{"FULQ", 4, 160190},
	{"EKUT", 4, 160191},
	{"EDIJ", 4, 160192},
	{"CSWR", 4, 160193},
	{"CLYE", 4, 160194},
	{"BWAT", 4, 160195},
	{"ATPC", 4, 160196},
	{"AMLY", 4, 160197},
	{"LOOSESTRIFE", 11, 160198},
	{"NETANYA", 7, 160199},
	{"REALIDAD", 8, 160200},
	{"PROFESSIONNELLE", 15, 160201},
	{"AFRICAINE", 9, 160202},
	{"SECONDE", 7, 160203},
	{"TOLLIVER", 8, 160204},
	{"SYNGRESS", 8, 160205},
	{"FLICS", 5, 160206},
	{"WEBMASTERING", 12, 160207},
	{"KLASSIK", 7, 160208},
	{"MACBRIDE", 8, 160209},
	{"SUTPHEN", 7, 160210},
	{"ANAME", 5, 160211},
	{"WSCC", 4, 160212},
	{"KASAI", 5, 160213},
	{"WHEATFIELD", 10, 160214},
	{"CARCASE", 7, 160215},
	{"JOWELL", 6, 160216},
	{"SUBDIV", 6, 160217},
	{"MELI", 4, 160218},
	{"CONEFLOWER", 10, 160219},
	{"WIKIDB", 6, 160220},
	{"CMIP", 4, 160221},
	{"NATARAJAN", 9, 160222},
	{"FOLTZ", 5, 160223},
	{"RETHYMNO", 8, 160224},
	{"BEAUTICIANS", 11, 160225},
	{"CHITCHAT", 8, 160226},
	{"PSUTILS", 7, 160227},
	{"HOTELCHANNEL", 12, 160228},
	{"MEGASPIDER", 10, 160229},
	{"KLAIPEDA", 8, 160230},
	{"CABALLEROS", 10, 160231},
	{"UNWOUND", 7, 160232},
	{"SUMAS", 5, 160233},
	{"RESTRUCTURES", 12, 160234},
	{"MEZZANINES", 10, 160235},
	{"NEWFANE", 7, 160236},
	{"WORKSITES", 9, 160237},
	{"EOVIA", 5, 160238},
	{"FAIRLINE", 8, 160239},
	{"YMRP", 4, 160240},
	{"VYHI", 4, 160241},
	{"ULWR", 4, 160242},
	{"UBTC", 4, 160243},
	{"STMD", 4, 160244},
	{"RNYI", 4, 160245},
	{"RAOL", 4, 160246},
	{"PTBL", 4, 160247},
	{"PDRU", 4, 160248},
	{"NIMW", 4, 160249},
	{"NDRG", 4, 160250},
	{"NDDM", 4, 160251},
	{"MMAE", 4, 160252},
	{"MIRD", 4, 160253},
	{"MCNI", 4, 160254},
	{"LTDC", 4, 160255},
	{"LHUL", 4, 160256},
	{"ISWW", 4, 160257},
	{"ILMK", 4, 160258},
	{"GYPH", 4, 160259},
	{"FKAP", 4, 160260},
	{"EPCB", 4, 160261},
	{"AWLW", 4, 160262},
	{"SIPHONING", 9, 160263},
	{"CRSE", 4, 160264},
	{"GOEDKOOP", 8, 160265},
	{"LOBLOLLY", 8, 160266},
	{"COKES", 5, 160267},
	{"CARUTHERS", 9, 160268},
	{"SHAMU", 5, 160269},
	{"NORMAS", 6, 160270},
	{"SPIDERING", 9, 160271},
	{"PINCUSHION", 10, 160272},
	{"PHOTOPERIOD", 11, 160273},
	{"MUSSINA", 7, 160274},
	{"WHICHE", 6, 160275},
	{"REFERENTS", 9, 160276},
	{"GRUSS", 5, 160277},
	{"BLOO", 4, 160278},
	{"MARINELAND", 10, 160279},
	{"LATINE", 6, 160280},
	{"SWARCH", 6, 160281},
	{"HIPPEL", 6, 160282},
	{"VENEZUELANS", 11, 160283},
	{"SNAPDRAGON", 10, 160284},
	{"LUANNE", 6, 160285},
	{"STRYCHNINE", 10, 160286},
	{"FEMAL", 5, 160287},
	{"CPANPLUS", 8, 160288},
	{"PERIENCE", 8, 160289},
	{"ABDULAZIZ", 9, 160290},
	{"ZEBRACLUB", 9, 160291},
	{"ZWIKI", 5, 160292},
	{"LAMPSON", 7, 160293},
	{"UNAPPRECIATED", 13, 160294},
	{"PERFORATING", 11, 160295},
	{"ARTEM", 5, 160296},
	{"PROGRES", 7, 160297},
	{"GENESI", 6, 160298},
	{"CLAYMONT", 8, 160299},
	{"SCHEVENINGEN", 12, 160300},
	{"FEILD", 5, 160301},
	{"LINATE", 6, 160302},
	{"SPRINTED", 8, 160303},
	{"CIVIS", 5, 160304},
	{"HYATTREGENCY", 12, 160305},
	{"DARVON", 6, 160306},
	{"CONSTI", 6, 160307},
	{"PSYCHOSES", 9, 160308},
	{"SYSTINET", 8, 160309},
	{"REVEILLE", 8, 160310},
	{"OURNAL", 6, 160311},
	{"BLIN", 4, 160312},
	{"SNAPSCAN", 8, 160313},
	{"SHTICK", 6, 160314},
	{"BRASSICACEAE", 12, 160315},
	{"OCEANUS", 7, 160316},
	{"JOANNES", 7, 160317},
	{"GARRISONS", 9, 160318},
	{"PLASTIK", 7, 160319},
	{"BACKSCATTERING", 14, 160320},
	{"PENNIS", 6, 160321},
	{"GAMETE", 6, 160322},
	{"FFIEC", 5, 160323},
	{"TOMKO", 5, 160324},
	{"ZUMANITY", 8, 160325},
	{"AKASHIC", 7, 160326},
	{"PIRRO", 5, 160327},
	{"ZEGA", 4, 160328},
	{"XSOF", 4, 160329},
	{"WLTE", 4, 160330},
	{"WLAC", 4, 160331},
	{"WHYU", 4, 160332},
	{"WHAW", 4, 160333},
	{"WAWR", 4, 160334},
	{"VRAJ", 4, 160335},
	{"VEJI", 4, 160336},
	{"TDFO", 4, 160337},
	{"SUIK", 4, 160338},
	{"NUBO", 4, 160339},
	{"MGIA", 4, 160340},
	{"LMPL", 4, 160341},
	{"KVIT", 4, 160342},
	{"GHAK", 4, 160343},
	{"FEPU", 4, 160344},
	{"FDAH", 4, 160345},
	{"EYDT", 4, 160346},
	{"EMHZ", 4, 160347},
	{"DYUR", 4, 160348},
	{"BAVE", 4, 160349},
	{"AZRI", 4, 160350},
	{"STARTEN", 7, 160351},
	{"HOLIDAYINNS", 11, 160352},
	{"DOPANT", 6, 160353},
	{"CAROLIN", 7, 160354},
	{"MILLERTON", 9, 160355},
	{"UNPLAYABLE", 10, 160356},
	{"FLYOUT", 6, 160357},
	{"BIZCHINA", 8, 160358},
	{"MYNX", 4, 160359},
	{"RIYA", 4, 160360},
	{"SPLASHY", 7, 160361},
	{"MBX", 3, 160362},
	{"YMATEB", 6, 160363},
	{"HARBOURFRONT", 12, 160364},
	{"SOURCEWELL", 10, 160365},
	{"FOLLETTE", 8, 160366},
	{"SAMEDAY", 7, 160367},
	{"ACONCAGUA", 9, 160368},
	{"PROTEAS", 7, 160369},
	{"DERRINGER", 9, 160370},
	{"FOODCOLLECTION", 14, 160371},
	{"PROFESSEUR", 10, 160372},
	{"ENDRE", 5, 160373},
	{"UNIREF", 6, 160374},
	{"RONEN", 5, 160375},
	{"NONLISTED", 9, 160376},
	{"STELL", 5, 160377},
	{"DILATOR", 7, 160378},
	{"CAMBY", 5, 160379},
	{"WAITOMO", 7, 160380},
	{"PUNX", 4, 160381},
	{"ORDINARIES", 10, 160382},
	{"HINDLE", 6, 160383},
	{"LEXINTON", 8, 160384},
	{"GERMINATED", 10, 160385},
	{"HILTONHOTEL", 11, 160386},
	{"STREAMBED", 9, 160387},
	{"SEMBILAN", 8, 160388},
	{"LECHNER", 7, 160389},
	{"SHAMES", 6, 160390},
	{"SCHICKEN", 8, 160391},
	{"PREDOMINATED", 12, 160392},
	{"JOHANNS", 7, 160393},
	{"BEESLEY", 7, 160394},
	{"COLORFULLY", 10, 160395},
	{"WILDEN", 6, 160396},
	{"DSRNA", 5, 160397},
	{"SUBCORTICAL", 11, 160398},
	{"HSQLDB", 6, 160399},
	{"TRANSDUCED", 10, 160400},
	{"ZYDE", 4, 160401},
	{"YIMT", 4, 160402},
	{"YEGA", 4, 160403},
	{"XBEG", 4, 160404},
	{"ULKC", 4, 160405},
	{"UKBU", 4, 160406},
	{"SDAX", 4, 160407},
	{"OLNR", 4, 160408},
	{"OKBL", 4, 160409},
	{"OBVA", 4, 160410},
	{"MALQ", 4, 160411},
	{"LILS", 4, 160412},
	{"IVRA", 4, 160413},
	{"HTUL", 4, 160414},
	{"GMEZ", 4, 160415},
	{"FMCK", 4, 160416},
	{"DRSM", 4, 160417},
	{"DFBI", 4, 160418},
	{"DAJI", 4, 160419},
	{"CRIL", 4, 160420},
	{"ATMD", 4, 160421},
	{"ANUW", 4, 160422},
	{"COSTUMERS", 9, 160423},
	{"AMERIWOOD", 9, 160424},
	{"COSTRUZIONI", 11, 160425},
	{"PERINEUM", 8, 160426},
	{"INFOCON", 7, 160427},
	{"NONQUALIFIED", 12, 160428},
	{"FERIENHAUS", 10, 160429},
	{"BBHUB", 5, 160430},
	{"CENTURA", 7, 160431},
	{"ARUNA", 5, 160432},
	{"HOWARDJOHNSONS", 14, 160433},
	{"WCU", 3, 160434},
	{"SOYMILK", 7, 160435},
	{"CAMPINA", 7, 160436},
	{"EMSC", 4, 160437},
	{"NCAP", 4, 160438},
	{"XYES", 4, 160439},
	{"WANCHAI", 7, 160440},
	{"ISTOCKPHOTO", 11, 160441},
	{"EPSF", 4, 160442},
	{"PITTANCE", 8, 160443},
	{"LTHR", 4, 160444},
	{"NAILTIQUES", 10, 160445},
	{"HAGENBUCH", 9, 160446},
	{"ZWJ", 3, 160447},
	{"ZFV", 3, 160448},
	{"XZL", 3, 160449},
	{"XQR", 3, 160450},
	{"XBQ", 3, 160451},
	{"UWQ", 3, 160452},
	{"QXX", 3, 160453},
	{"QQM", 3, 160454},
	{"PXZ", 3, 160455},
	{"PGZ", 3, 160456},
	{"GKZ", 3, 160457},
	{"BVK", 3, 160458},
	{"BPQ", 3, 160459},
	{"SEAGRAM", 7, 160460},
	{"HARTY", 5, 160461},
	{"MEDIACENTER", 11, 160462},
	{"LODDON", 6, 160463},
	{"UKAS", 4, 160464},
	{"SONSTIGE", 8, 160465},
	{"WAPAKONETA", 10, 160466},
	{"SESRCH", 6, 160467},
	{"ISRAPUNDIT", 10, 160468},
	{"HENRYETTA", 9, 160469},
	{"ANURA", 5, 160470},
	{"BRECKER", 7, 160471},
	{"SALACIOUS", 9, 160472},
	{"MATTIS", 6, 160473},
	{"EUROFIGHTER", 11, 160474},
	{"PHEOBI", 6, 160475},
	{"GIRONDE", 7, 160476},
	{"NESCAFE", 7, 160477},
	{"EPHRON", 6, 160478},
	{"GOSSE", 5, 160479},
	{"CRIMINOLOGIST", 13, 160480},
	{"LVALUE", 6, 160481},
	{"YUIN", 4, 160482},
	{"YEFR", 4, 160483},
	{"WTHL", 4, 160484},
	{"WETF", 4, 160485},
	{"ULSY", 4, 160486},
	{"UKSF", 4, 160487},
	{"SYEX", 4, 160488},
	{"RTAJ", 4, 160489},
	{"QIFO", 4, 160490},
	{"PYFI", 4, 160491},
	{"OKSK", 4, 160492},
	{"NJRO", 4, 160493},
	{"NGUO", 4, 160494},
	{"LOFZ", 4, 160495},
	{"KIMF", 4, 160496},
	{"GHUI", 4, 160497},
	{"EZID", 4, 160498},
	{"EKSK", 4, 160499},
	{"EFYT", 4, 160500},
	{"DYOK", 4, 160501},
	{"COBD", 4, 160502},
	{"BSOC", 4, 160503},
	{"AYOM", 4, 160504},
	{"AVYJ", 4, 160505},
	{"ANFC", 4, 160506},
	{"AMUA", 4, 160507},
	{"ALFV", 4, 160508},
	{"AGSL", 4, 160509},
	{"AFPE", 4, 160510},
	{"PHENERMINE", 10, 160511},
	{"ESCUTCHEON", 10, 160512},
	{"VIRTUEL", 7, 160513},
	{"YYNN", 4, 160514},
	{"WINGING", 7, 160515},
	{"EXISTEN", 7, 160516},
	{"ALCIBIADES", 10, 160517},
	{"SCHATTEN", 8, 160518},
	{"SAPIENT", 7, 160519},
	{"GRIPING", 7, 160520},
	{"GOOGLERS", 8, 160521},
	{"FOOF", 4, 160522},
	{"SURFDOM", 7, 160523},
	{"DICHLOROMETHANE", 15, 160524},
	{"HILD", 4, 160525},
	{"DEBYE", 5, 160526},
	{"FIREBLADE", 9, 160527},
	{"BERA", 4, 160528},
	{"CURDS", 5, 160529},
	{"SINFULNESS", 10, 160530},
	{"RECAPITULATION", 14, 160531},
	{"KUNIS", 5, 160532},
	{"TRUDGED", 7, 160533},
	{"SINNOTT", 7, 160534},
	{"HYDROPHOBICITY", 14, 160535},
	{"VAIDYA", 6, 160536},
	{"NOOKII", 6, 160537},
	{"JUNGER", 6, 160538},
	{"COMFORTINNS", 11, 160539},
	{"AHCC", 4, 160540},
	{"SKYDOME", 7, 160541},
	{"COLLEZIONI", 10, 160542},
	{"PONDING", 7, 160543},
	{"BAATHIST", 8, 160544},
	{"ASPENS", 6, 160545},
	{"OGLALA", 6, 160546},
	{"CREAKY", 6, 160547},
	{"DUPA", 4, 160548},
	{"HUMMED", 6, 160549},
	{"RESTOCKED", 9, 160550},
	{"SICHT", 5, 160551},
	{"NESSUN", 6, 160552},
	{"INNPOINTS", 9, 160553},
	{"HYATTHOTELS", 11, 160554},
	{"CHASSIDIC", 9, 160555},
	{"BOOKSELLING", 11, 160556},
	{"VOLKOV", 6, 160557},
	{"MICROBICIDES", 12, 160558},
	{"NEGLI", 5, 160559},
	{"CONVALESCENCE", 13, 160560},
	{"USEPACKAGE", 10, 160561},
	{"TUPOLEV", 7, 160562},
	{"VERITE", 6, 160563},
	{"TECHINDEX", 9, 160564},
	{"REBEKKA", 7, 160565},
	{"RUHRGEBIET", 10, 160566},
	{"MOTETS", 6, 160567},
	{"STROUT", 6, 160568},
	{"PROTEROZOIC", 11, 160569},
	{"LITHIC", 6, 160570},
	{"HOPATCONG", 9, 160571},
	{"HIJACKINGS", 10, 160572},
	{"PALY", 4, 160573},
	{"TROUSDALE", 9, 160574},
	{"CWNA", 4, 160575},
	{"DONALDS", 7, 160576},
	{"JIHADI", 6, 160577},
	{"SPADA", 5, 160578},
	{"VANILLI", 7, 160579},
	{"WOFY", 4, 160580},
	{"WBOL", 4, 160581},
	{"VREB", 4, 160582},
	{"UXBA", 4, 160583},
	{"UGIL", 4, 160584},
	{"PPIO", 4, 160585},
	{"NUXT", 4, 160586},
	{"FZAN", 4, 160587},
	{"DPMF", 4, 160588},
	{"BWAN", 4, 160589},
	{"BONV", 4, 160590},
	{"ARTQ", 4, 160591},
	{"MACQUEEN", 8, 160592},
	{"EDITRICE", 8, 160593},
	{"PRIAM", 5, 160594},
	{"USTAD", 5, 160595},
	{"WHISKS", 6, 160596},
	{"UNCEASING", 9, 160597},
	{"DISDAINFUL", 10, 160598},
	{"KNOWER", 6, 160599},
	{"PERMALINKS", 10, 160600},
	{"UNLOADS", 7, 160601},
	{"VQF", 3, 160602},
	{"CPPUNIT", 7, 160603},
	{"QUATERMASS", 10, 160604},
	{"MARTINET", 8, 160605},
	{"SPITALFIELDS", 12, 160606},
	{"BOSTICK", 7, 160607},
	{"MATANZAS", 8, 160608},
	{"MASHUPS", 7, 160609},
	{"SRARCH", 6, 160610},
	{"BACKBENCHER", 11, 160611},
	{"UNDULATOR", 9, 160612},
	{"CACKLING", 8, 160613},
	{"CARBONLESS", 10, 160614},
	{"BRAINTALK", 9, 160615},
	{"JTPA", 4, 160616},
	{"CHANGEPASSWORD", 14, 160617},
	{"COMFORTSUITES", 13, 160618},
	{"BLANCS", 6, 160619},
	{"NIXVUE", 6, 160620},
	{"FACKING", 7, 160621},
	{"SIBILITY", 8, 160622},
	{"ERATIONS", 8, 160623},
	{"WANKSTA", 7, 160624},
	{"DNSBL", 5, 160625},
	{"KOTOBUKIYA", 10, 160626},
	{"GARBANZOS", 9, 160627},
	{"COMITY", 6, 160628},
	{"PREBOOK", 7, 160629},
	{"BREAKROOM", 9, 160630},
	{"GOLDBERGER", 10, 160631},
	{"FILMOWY", 7, 160632},
	{"CWJOBS", 6, 160633},
	{"HINTERLANDS", 11, 160634},
	{"INCOR", 5, 160635},
	{"KLERK", 5, 160636},
	{"AVIDIN", 6, 160637},
	{"PAULISTA", 8, 160638},
	{"SPAHN", 5, 160639},
	{"FRERES", 6, 160640},
	{"NONSINGULAR", 11, 160641},
	{"BELI", 4, 160642},
	{"BACKLINK", 8, 160643},
	{"JIHADIS", 7, 160644},
	{"RESIDENCEINN", 12, 160645},
	{"ZTOP", 4, 160646},
	{"ZANW", 4, 160647},
	{"UIPT", 4, 160648},
	{"TUPJ", 4, 160649},
	{"RPPO", 4, 160650},
	{"RLPE", 4, 160651},
	{"POTK", 4, 160652},
	{"OZAL", 4, 160653},
	{"OXJU", 4, 160654},
	{"MPOD", 4, 160655},
	{"LIPJ", 4, 160656},
	{"KOPJ", 4, 160657},
	{"IKSD", 4, 160658},
	{"IKRO", 4, 160659},
	{"IBUD", 4, 160660},
	{"HUMU", 4, 160661},
	{"HIRY", 4, 160662},
	{"GTSU", 4, 160663},
	{"GOWW", 4, 160664},
	{"GOWD", 4, 160665},
	{"GOFQ", 4, 160666},
	{"GMMA", 4, 160667},
	{"EPYA", 4, 160668},
	{"DUOM", 4, 160669},
	{"CEZA", 4, 160670},
	{"ATLD", 4, 160671},
	{"ANFM", 4, 160672},
	{"SPIELMAN", 8, 160673},
	{"AMORTISED", 9, 160674},
	{"PROBATIONERS", 12, 160675},
	{"HINTERWELT", 10, 160676},
	{"HERZING", 7, 160677},
	{"AIMER", 5, 160678},
	{"SCRIPTWRITER", 12, 160679},
	{"HSIUNG", 6, 160680},
	{"XAUTH", 5, 160681},
	{"TREDEGAR", 8, 160682},
	{"LUMIANI", 7, 160683},
	{"SELECCIONAR", 11, 160684},
	{"RYUKYU", 6, 160685},
	{"ALLFUSION", 9, 160686},
	{"CARRELL", 7, 160687},
	{"KAKU", 4, 160688},
	{"BARBOURSVILLE", 13, 160689},
	{"PARSNIPS", 8, 160690},
	{"BEATDOWN", 8, 160691},
	{"TREMBLES", 8, 160692},
	{"MIKEN", 5, 160693},
	{"CAPITALIZES", 11, 160694},
	{"DAVON", 5, 160695},
	{"POSITRONS", 9, 160696},
	{"JOBSTER", 7, 160697},
	{"NACAA", 5, 160698},
	{"FACHBEREICH", 11, 160699},
	{"PAGEINDEX", 9, 160700},
	{"RENNY", 5, 160701},
	{"PLOTLINE", 8, 160702},
	{"GRACING", 7, 160703},
	{"DYAN", 4, 160704},
	{"COMPLEXTYPE", 11, 160705},
	{"SRCH", 4, 160706},
	{"GASKILL", 7, 160707},
	{"MULTIBAND", 9, 160708},
	{"GOUGES", 6, 160709},
	{"MODEN", 5, 160710},
	{"EURODOLLAR", 10, 160711},
	{"TBOKICH", 7, 160712},
	{"PISSARRO", 8, 160713},
	{"DRYLY", 5, 160714},
	{"SCALZI", 6, 160715},
	{"ELLIPSOIDAL", 11, 160716},
	{"RECOMMENDA", 10, 160717},
	{"BUK", 3, 160718},
	{"BISQUES", 7, 160719},
	{"SWADLINCOTE", 11, 160720},
	{"RALEY", 5, 160721},
	{"NAUMAN", 6, 160722},
	{"BUGZI", 5, 160723},
	{"STRICKLER", 9, 160724},
	{"SALAT", 5, 160725},
	{"LOWLIFE", 7, 160726},
	{"INGRATITUDE", 11, 160727},
	{"KARTA", 5, 160728},
	{"KALKAN", 6, 160729},
	{"YLUI", 4, 160730},
	{"WIEG", 4, 160731},
	{"VUZE", 4, 160732},
	{"UEUI", 4, 160733},
	{"SUUK", 4, 160734},
	{"POAL", 4, 160735},
	{"PFEN", 4, 160736},
	{"NULF", 4, 160737},
	{"LUAL", 4, 160738},
	{"KAIC", 4, 160739},
	{"JONF", 4, 160740},
	{"HOUY", 4, 160741},
	{"DPCS", 4, 160742},
	{"DEUL", 4, 160743},
	{"CBSP", 4, 160744},
	{"BOEC", 4, 160745},
	{"ACYU", 4, 160746},
	{"LRYICS", 6, 160747},
	{"FLEURIEU", 8, 160748},
	{"EUROLAND", 8, 160749},
	{"UPL", 3, 160750},
	{"GNOSTICS", 8, 160751},
	{"PATHOPHYSIOLOGICAL", 18, 160752},
	{"BRUTINI", 7, 160753},
	{"BETWS", 5, 160754},
	{"MARIOT", 6, 160755},
	{"AZMI", 4, 160756},
	{"JENISON", 7, 160757},
	{"POSTES", 6, 160758},
	{"DODECANESE", 10, 160759},
	{"PANDEMICS", 9, 160760},
	{"TAQMAN", 6, 160761},
	{"PREMONITIONS", 12, 160762},
	{"DURFEE", 6, 160763},
	{"SNEEZES", 7, 160764},
	{"METALLOPROTEINASES", 18, 160765},
	{"KERALANEXT", 10, 160766},
	{"FINUCANE", 8, 160767},
	{"DIGITREX", 8, 160768},
	{"HARRYHAUSEN", 11, 160769},
	{"ANTIVERT", 8, 160770},
	{"GLARES", 6, 160771},
	{"PARASITOID", 10, 160772},
	{"GRANDTEC", 8, 160773},
	{"GODT", 4, 160774},
	{"DODGEVILLE", 10, 160775},
	{"MARRIOTTHOTELS", 14, 160776},
	{"PRESCRIBERS", 11, 160777},
	{"BLAGOEVGRAD", 11, 160778},
	{"TUTION", 6, 160779},
	{"BURMEISTER", 10, 160780},
	{"WILDL", 5, 160781},
	{"KORFBALL", 8, 160782},
	{"AMNESIAC", 8, 160783},
	{"PECIAL", 6, 160784},
	{"PRELIMINARILY", 13, 160785},
	{"CARRER", 6, 160786},
	{"ROSADO", 6, 160787},
	{"LARGESSE", 8, 160788},
	{"JLABEL", 6, 160789},
	{"PRACTI", 6, 160790},
	{"EUROPAEA", 8, 160791},
	{"HUMPED", 6, 160792},
	{"SEARHC", 6, 160793},
	{"DORLAND", 7, 160794},
	{"EARHUGGER", 9, 160795},
	{"OVERDOSAGE", 10, 160796},
	{"HOLIDAYINNEXPRESS", 17, 160797},
	{"COUS", 4, 160798},
	{"DISBANDING", 10, 160799},
	{"CONFORTINN", 10, 160800},
	{"PHPBUILDER", 10, 160801},
	{"TUMESCENT", 9, 160802},
	{"MYCELIUM", 8, 160803},
	{"BLEARY", 6, 160804},
	{"YTYI", 4, 160805},
	{"XKER", 4, 160806},
	{"WUTA", 4, 160807},
	{"SHLU", 4, 160808},
	{"RSYC", 4, 160809},
	{"PUBW", 4, 160810},
	{"OYOK", 4, 160811},
	{"OPKA", 4, 160812},
	{"NGCC", 4, 160813},
	{"LPDO", 4, 160814},
	{"LIUC", 4, 160815},
	{"LHIB", 4, 160816},
	{"LGIG", 4, 160817},
	{"ILKD", 4, 160818},
	{"GBUM", 4, 160819},
	{"FEDL", 4, 160820},
	{"EVFW", 4, 160821},
	{"ECGA", 4, 160822},
	{"DBTH", 4, 160823},
	{"CYMR", 4, 160824},
	{"AJIG", 4, 160825},
	{"KITESURF", 8, 160826},
	{"PALATES", 7, 160827},
	{"GEOTEXTILE", 10, 160828},
	{"MOOIE", 5, 160829},
	{"SURFCONTROL", 11, 160830},
	{"HOGGARD", 7, 160831},
	{"WENLOCK", 7, 160832},
	{"SPLENECTOMY", 11, 160833},
	{"GALLIPOLIS", 10, 160834},
	{"MESOAMERICA", 11, 160835},
	{"RYOKAN", 6, 160836},
	{"TRMM", 4, 160837},
	{"BRIDALS", 7, 160838},
	{"GIMMIE", 6, 160839},
	{"PECORINO", 8, 160840},
	{"REBRANDING", 10, 160841},
	{"MUGSHOTS", 8, 160842},
	{"WORKLIST", 8, 160843},
	{"SUNROCKET", 9, 160844},
	{"ROWBOAT", 7, 160845},
	{"PERFECTIONS", 11, 160846},
	{"HPER", 4, 160847},
	{"PARMALAT", 8, 160848},
	{"SUBGENIUS", 9, 160849},
	{"STOKKE", 6, 160850},
	{"LIPOSOMAL", 9, 160851},
	{"HALEIWA", 7, 160852},
	{"AFFINIS", 7, 160853},
	{"FAREED", 6, 160854},
	{"MOSTRE", 6, 160855},
	{"WINDSONG", 8, 160856},
	{"CIXI", 4, 160857},
	{"BESSELJ", 7, 160858},
	{"MOZAMBICAN", 10, 160859},
	{"ZAJAC", 5, 160860},
	{"FAIRFEILD", 9, 160861},
	{"NEWWORLD", 8, 160862},
	{"INSTRUMEN", 9, 160863},
	{"MLIS", 4, 160864},
	{"CREAMERS", 8, 160865},
	{"CMSU", 4, 160866},
	{"CHILCOTIN", 9, 160867},
	{"UTERI", 5, 160868},
	{"SEARDH", 6, 160869},
	{"RESTIVE", 7, 160870},
	{"MELODIA", 7, 160871},
	{"ACTEUR", 6, 160872},
	{"ARRECIFE", 8, 160873},
	{"BISSETT", 7, 160874},
	{"MAHALA", 6, 160875},
	{"ERDC", 4, 160876},
	{"ALARA", 5, 160877},
	{"KETCHAM", 7, 160878},
	{"ZZIW", 4, 160879},
	{"YLWA", 4, 160880},
	{"YGIO", 4, 160881},
	{"WAHU", 4, 160882},
	{"VIOB", 4, 160883},
	{"VEXE", 4, 160884},
	{"ULSR", 4, 160885},
	{"UKPO", 4, 160886},
	{"THPP", 4, 160887},
	{"RMEU", 4, 160888},
	{"PPPA", 4, 160889},
	{"PDOR", 4, 160890},
	{"OXBY", 4, 160891},
	{"ONFD", 4, 160892},
	{"MPYS", 4, 160893},
	{"LSIB", 4, 160894},
	{"LOJO", 4, 160895},
	{"KCAF", 4, 160896},
	{"GDUO", 4, 160897},
	{"FFRY", 4, 160898},
	{"BSGE", 4, 160899},
	{"AWGI", 4, 160900},
	{"ABMU", 4, 160901},
	{"EMCEES", 6, 160902},
	{"MULTICENTRE", 11, 160903},
	{"GILLET", 6, 160904},
	{"HACKNEYED", 9, 160905},
	{"PSPELL", 6, 160906},
	{"FLAGELLUM", 9, 160907},
	{"HARDIMAN", 8, 160908},
	{"CANTICLE", 8, 160909},
	{"FARAD", 5, 160910},
	{"JAAKKO", 6, 160911},
	{"BARDO", 5, 160912},
	{"LUCIPO", 6, 160913},
	{"HANDBASKET", 10, 160914},
	{"PEINE", 5, 160915},
	{"NAIVETE", 7, 160916},
	{"TRUMPETED", 9, 160917},
	{"RAMBUNCTIOUS", 12, 160918},
	{"PLATEAUX", 8, 160919},
	{"EUROPESE", 8, 160920},
	{"DATAWRITE", 9, 160921},
	{"CIRCUITOUS", 10, 160922},
	{"FOREWARD", 8, 160923},
	{"DYSTROPHIN", 10, 160924},
	{"VCG", 3, 160925},
	{"SMOLTZ", 6, 160926},
	{"SAVASTORE", 9, 160927},
	{"SCOPUS", 6, 160928},
	{"KWAK", 4, 160929},
	{"POPLE", 5, 160930},
	{"CHOREOGRAPHIC", 13, 160931},
	{"SCAVENGE", 8, 160932},
	{"EXPIO", 5, 160933},
	{"FRIEDEN", 7, 160934},
	{"SHITTER", 7, 160935},
	{"UNMOTIVATED", 11, 160936},
	{"VORARLBERG", 10, 160937},
	{"IMPLORING", 9, 160938},
	{"SPEYSIDE", 8, 160939},
	{"SLEEPYCAT", 9, 160940},
	{"FREEGAY", 7, 160941},
	{"ENGULFING", 9, 160942},
	{"NETWORKWORLD", 12, 160943},
	{"BLOGSOME", 8, 160944},
	{"TRANSFORMA", 10, 160945},
	{"WIEDEMANN", 9, 160946},
	{"HYAMS", 5, 160947},
	{"ROCKHURST", 9, 160948},
	{"EMAD", 4, 160949},
	{"CRAZYFISTS", 10, 160950},
	{"LAWFORD", 7, 160951},
	{"ANTICON", 7, 160952},
	{"SCALLION", 8, 160953},
	{"REDBOOT", 7, 160954},
	{"GEBOORTE", 8, 160955},
	{"POSITIVIST", 10, 160956},
	{"SUBSCALES", 9, 160957},
	{"EREBUS", 6, 160958},
	{"OUABAIN", 7, 160959},
	{"FACELIFTS", 9, 160960},
	{"YWIZ", 4, 160961},
	{"YIKE", 4, 160962},
	{"YECC", 4, 160963},
	{"WOFV", 4, 160964},
	{"WIRR", 4, 160965},
	{"UPTG", 4, 160966},
	{"RPBY", 4, 160967},
	{"MIEV", 4, 160968},
	{"LHYB", 4, 160969},
	{"LELM", 4, 160970},
	{"IXCY", 4, 160971},
	{"IMIV", 4, 160972},
	{"HMUH", 4, 160973},
	{"DBOC", 4, 160974},
	{"CYAI", 4, 160975},
	{"BICN", 4, 160976},
	{"PROSCAN", 7, 160977},
	{"PROFILO", 7, 160978},
	{"ANDREEV", 7, 160979},
	{"KIRO", 4, 160980},
	{"SCROFA", 6, 160981},
	{"HEISLER", 7, 160982},
	{"SQUISHED", 8, 160983},
	{"ABRIDGE", 7, 160984},
	{"RESERPINE", 9, 160985},
	{"MAEMO", 5, 160986},
	{"PANATHINAIKOS", 13, 160987},
	{"MOWIE", 5, 160988},
	{"LUKASHENKO", 10, 160989},
	{"PICARDY", 7, 160990},
	{"ANOREX", 6, 160991},
	{"SPINDLER", 8, 160992},
	{"SACCHARINE", 10, 160993},
	{"BORSCHT", 7, 160994},
	{"RIGGERS", 7, 160995},
	{"HOLOGRAPH", 9, 160996},
	{"ROOMINESS", 9, 160997},
	{"BILSTON", 7, 160998},
	{"STANDER", 7, 160999},
	{"SHERDOG", 7, 161000},
	{"KENNELLY", 8, 161001},
	{"PHRASEBOOKS", 11, 161002},
	{"THORNBERRY", 10, 161003},
	{"MOVIELINK", 9, 161004},
	{"MANTOVA", 7, 161005},
	{"VIDIN", 5, 161006},
	{"CHARGEBACKS", 11, 161007},
	{"ORBACH", 6, 161008},
	{"NIDDM", 5, 161009},
	{"FORW", 4, 161010},
	{"CHARETTE", 8, 161011},
	{"APPIN", 5, 161012},
	{"RAMAD", 5, 161013},
	{"PASTRAMI", 8, 161014},
	{"COOKWORKS", 9, 161015},
	{"BOATWRIGHT", 10, 161016},
	{"MALEIC", 6, 161017},
	{"FUNDRAISE", 9, 161018},
	{"PAGAR", 5, 161019},
	{"CLEVES", 6, 161020},
	{"SHERTON", 7, 161021},
	{"BITRATES", 8, 161022},
	{"SCULPEY", 7, 161023},
	{"AUTHO", 5, 161024},
	{"MEXICANOS", 9, 161025},
	{"VMOD", 4, 161026},
	{"UYLK", 4, 161027},
	{"UUKY", 4, 161028},
	{"UTZT", 4, 161029},
	{"USBS", 4, 161030},
	{"UOFB", 4, 161031},
	{"UIZI", 4, 161032},
	{"SORX", 4, 161033},
	{"ROSZ", 4, 161034},
	{"PSKN", 4, 161035},
	{"PFES", 4, 161036},
	{"NPEM", 4, 161037},
	{"NGCN", 4, 161038},
	{"KJOU", 4, 161039},
	{"IAKW", 4, 161040},
	{"HMMA", 4, 161041},
	{"GZHA", 4, 161042},
	{"GMGR", 4, 161043},
	{"GLTD", 4, 161044},
	{"GGEL", 4, 161045},
	{"FCTO", 4, 161046},
	{"FAXN", 4, 161047},
	{"DVIP", 4, 161048},
	{"DIFG", 4, 161049},
	{"CNUC", 4, 161050},
	{"AXPE", 4, 161051},
	{"AUNB", 4, 161052},
	{"ADRB", 4, 161053},
	{"AARW", 4, 161054},
	{"PHOSPHATIDYLSERINE", 18, 161055},
	{"CERC", 4, 161056},
	{"LACTASE", 7, 161057},
	{"JPR", 3, 161058},
	{"AFGE", 4, 161059},
	{"GLISTEN", 7, 161060},
	{"MACKERRAS", 9, 161061},
	{"NYGAARD", 7, 161062},
	{"DELINQUENCIES", 13, 161063},
	{"OCOTILLO", 8, 161064},
	{"PICTRUES", 8, 161065},
	{"NORTHOLT", 8, 161066},
	{"BIBITEM", 7, 161067},
	{"USUALY", 6, 161068},
	{"TIVITIES", 8, 161069},
	{"RESEARCHSOFT", 12, 161070},
	{"LONDO", 5, 161071},
	{"HOMESTORE", 9, 161072},
	{"SPECTIVE", 8, 161073},
	{"FREEWHEEL", 9, 161074},
	{"BALKIN", 6, 161075},
	{"LATIFOLIA", 9, 161076},
	{"ROETHKE", 7, 161077},
	{"CLAUSSEN", 8, 161078},
	{"UNIDA", 5, 161079},
	{"MICROFILMED", 11, 161080},
	{"HOTELNET", 8, 161081},
	{"DORITOS", 7, 161082},
	{"MUTAT", 5, 161083},
	{"UMHLANGA", 8, 161084},
	{"CLUBBED", 7, 161085},
	{"TURNINGS", 8, 161086},
	{"SPERANZA", 8, 161087},
	{"DRESSEL", 7, 161088},
	{"NEWGATE", 7, 161089},
	{"HASSLER", 7, 161090},
	{"FREEBOARD", 9, 161091},
	{"PERFORMANC", 10, 161092},
	{"FOURM", 5, 161093},
	{"DOURO", 5, 161094},
	{"FOURPOINTS", 10, 161095},
	{"ACCESSABILITY", 13, 161096},
	{"ASTROLABE", 9, 161097},
	{"CAPOS", 5, 161098},
	{"BRUG", 4, 161099},
	{"TEGUISE", 7, 161100},
	{"UNBLEMISHED", 11, 161101},
	{"HOBY", 4, 161102},
	{"FEMI", 4, 161103},
	{"COBO", 4, 161104},
	{"ANDREASEN", 9, 161105},
	{"KARMAN", 6, 161106},
	{"COILOVERS", 9, 161107},
	{"TRENCHANT", 9, 161108},
	{"SUMTHIN", 7, 161109},
	{"SOLUCIONES", 10, 161110},
	{"BAMBOOZLED", 10, 161111},
	{"JEREMIE", 7, 161112},
	{"CYNTAF", 6, 161113},
	{"WINDOWLESS", 10, 161114},
	{"SMALE", 5, 161115},
	{"CHEVEUX", 7, 161116},
	{"MORROCCO", 8, 161117},
	{"PICES", 5, 161118},
	{"SCIONS", 6, 161119},
	{"AREND", 5, 161120},
	{"ZOOR", 4, 161121},
	{"ZEGR", 4, 161122},
	{"YAZO", 4, 161123},
	{"RTKU", 4, 161124},
	{"OYOW", 4, 161125},
	{"OYBY", 4, 161126},
	{"OMKH", 4, 161127},
	{"LOAP", 4, 161128},
	{"LDKO", 4, 161129},
	{"KMEO", 4, 161130},
	{"GHMR", 4, 161131},
	{"FCPL", 4, 161132},
	{"EVOF", 4, 161133},
	{"EVJE", 4, 161134},
	{"ERPW", 4, 161135},
	{"EIDY", 4, 161136},
	{"EBOV", 4, 161137},
	{"BFUS", 4, 161138},
	{"FWB", 3, 161139},
	{"POLIC", 5, 161140},
	{"GOERZEN", 7, 161141},
	{"RAMDA", 5, 161142},
	{"PARTURITION", 11, 161143},
	{"CONJUNCTIVA", 11, 161144},
	{"PILLBOX", 7, 161145},
	{"TENCH", 5, 161146},
	{"LADYKILLERS", 11, 161147},
	{"THTTPD", 6, 161148},
	{"NESSEBAR", 8, 161149},
	{"POSTMODERNIST", 13, 161150},
	{"LATAH", 5, 161151},
	{"HISTOPATHOLOGIC", 15, 161152},
	{"MASSIV", 6, 161153},
	{"MODINE", 6, 161154},
	{"GOODGEARGUIDE", 13, 161155},
	{"TEXES", 5, 161156},
	{"SIDHU", 5, 161157},
	{"RACHID", 6, 161158},
	{"SCHWARZER", 9, 161159},
	{"ENTEROBACTERIACEAE", 18, 161160},
	{"CASCARA", 7, 161161},
	{"ACUNETIX", 8, 161162},
	{"PHRASELISTS", 11, 161163},
	{"OSTEOPATH", 9, 161164},
	{"CONCEALERS", 10, 161165},
	{"AUTOMATICLY", 11, 161166},
	{"RRB", 3, 161167},
	{"MEDICATE", 8, 161168},
	{"LEACHED", 7, 161169},
	{"CARPENTIER", 10, 161170},
	{"LILLA", 5, 161171},
	{"EXAMINEE", 8, 161172},
	{"BUZZERS", 7, 161173},
	{"MARSUPIALS", 10, 161174},
	{"GALVEZ", 6, 161175},
	{"GULET", 5, 161176},
	{"AVERSIVE", 8, 161177},
	{"VOLLEYS", 7, 161178},
	{"SUCHERGEBNISSE", 14, 161179},
	{"GEEKBAY", 7, 161180},
	{"EVOX", 4, 161181},
	{"BLOODLETTING", 12, 161182},
	{"SNOWPLOW", 8, 161183},
	{"HOMMAGE", 7, 161184},
	{"FIERRO", 6, 161185},
	{"POLYAMINE", 9, 161186},
	{"ELAC", 4, 161187},
	{"RADDISSON", 9, 161188},
	{"OUTB", 4, 161189},
	{"CONDENSES", 9, 161190},
	{"WATERBERG", 9, 161191},
	{"SAWHNEY", 7, 161192},
	{"SKEWERED", 8, 161193},
	{"FURAN", 5, 161194},
	{"CORKER", 6, 161195},
	{"ROLLCALL", 8, 161196},
	{"SEARCJ", 6, 161197},
	{"COLLETON", 8, 161198},
	{"CATHARTON", 9, 161199},
	{"GIRLHOOD", 8, 161200},
	{"IUSTICE", 7, 161201},
	{"MIRANT", 6, 161202},
	{"MACINNIS", 8, 161203},
	{"FRESHENING", 10, 161204},
	{"BERNARDS", 8, 161205},
	{"MARJORY", 7, 161206},
	{"STRIPSLASHES", 12, 161207},
	{"ADLINK", 6, 161208},
	{"CHOMPING", 8, 161209},
	{"QUARTERMASTERS", 14, 161210},
	{"CARTONI", 7, 161211},
	{"YSOG", 4, 161212},
	{"UGSN", 4, 161213},
	{"TOGW", 4, 161214},
	{"SIMF", 4, 161215},
	{"REMW", 4, 161216},
	{"PPIH", 4, 161217},
	{"OWTY", 4, 161218},
	{"MPHU", 4, 161219},
	{"MGOF", 4, 161220},
	{"KOFQ", 4, 161221},
	{"HYOB", 4, 161222},
	{"DILB", 4, 161223},
	{"CUAR", 4, 161224},
	{"AUXF", 4, 161225},
	{"ATMF", 4, 161226},
	{"ASRD", 4, 161227},
	{"AGUD", 4, 161228},
	{"CRESENT", 7, 161229},
	{"NEDVED", 6, 161230},
	{"VBC", 3, 161231},
	{"COVILLE", 7, 161232},
	{"RILL", 4, 161233},
	{"UKP", 3, 161234},
	{"SCHEIKUNDE", 10, 161235},
	{"PSYCHOANALYST", 13, 161236},
	{"NORTHER", 7, 161237},
	{"AIRMASS", 7, 161238},
	{"SUPERCEDE", 9, 161239},
	{"CORER", 5, 161240},
	{"RELS", 4, 161241},
	{"HUNSTANTON", 10, 161242},
	{"KRINGLE", 7, 161243},
	{"JUGA", 4, 161244},
	{"RIZVI", 5, 161245},
	{"DEAFBLIND", 9, 161246},
	{"UNITO", 5, 161247},
	{"SUBACCOUNT", 10, 161248},
	{"COHOUSING", 9, 161249},
	{"BRIELLE", 7, 161250},
	{"AVMA", 4, 161251},
	{"MUNDUS", 6, 161252},
	{"THYMES", 6, 161253},
	{"LAIST", 5, 161254},
	{"CEDARTOWN", 9, 161255},
	{"ANDAR", 5, 161256},
	{"BOSMAN", 6, 161257},
	{"CHAVIS", 6, 161258},
	{"MIROS", 5, 161259},
	{"DEXY", 4, 161260},
	{"OUND", 4, 161261},
	{"CARIBEAN", 8, 161262},
	{"TWIKIPLUGINS", 12, 161263},
	{"LODGMENT", 8, 161264},
	{"SHOWIN", 6, 161265},
	{"PERDERE", 7, 161266},
	{"NAGRA", 5, 161267},
	{"DOCO", 4, 161268},
	{"CLUMSINESS", 10, 161269},
	{"MICROPOROUS", 11, 161270},
	{"TRANSLOCATIONS", 14, 161271},
	{"TECPREVIEW", 10, 161272},
	{"ILLIGAL", 7, 161273},
	{"ASCERTAINABLE", 13, 161274},
	{"TELEMATIC", 9, 161275},
	{"SEAGOVILLE", 10, 161276},
	{"DISPLAYSTRING", 13, 161277},
	{"BETFRED", 7, 161278},
	{"WITLESS", 7, 161279},
	{"PHOSPHOENOLPYRUVATE", 19, 161280},
	{"TENTERDEN", 9, 161281},
	{"WATASHI", 7, 161282},
	{"PULLIN", 6, 161283},
	{"MILKSHAKES", 10, 161284},
	{"PROCOMP", 7, 161285},
	{"YPHU", 4, 161286},
	{"YMEY", 4, 161287},
	{"YGLU", 4, 161288},
	{"WDSH", 4, 161289},
	{"TADC", 4, 161290},
	{"PURK", 4, 161291},
	{"PHBO", 4, 161292},
	{"OWDM", 4, 161293},
	{"NYRD", 4, 161294},
	{"MOPL", 4, 161295},
	{"LOZE", 4, 161296},
	{"JART", 4, 161297},
	{"INUD", 4, 161298},
	{"INPP", 4, 161299},
	{"EYUM", 4, 161300},
	{"AWKO", 4, 161301},
	{"AKUC", 4, 161302},
	{"IMPOSTERS", 9, 161303},
	{"BLUEDOOR", 8, 161304},
	{"AGBS", 4, 161305},
	{"LEATH", 5, 161306},
	{"SUPERSEEKER", 11, 161307},
	{"NORRELL", 7, 161308},
	{"MICROSOFTS", 10, 161309},
	{"GAMEAMP", 7, 161310},
	{"SESTRIERE", 9, 161311},
	{"EXCELENTE", 9, 161312},
	{"HIEBOOK", 7, 161313},
	{"REMADA", 6, 161314},
	{"QBOOSH", 6, 161315},
	{"DEBUNKS", 7, 161316},
	{"RENASSANCE", 10, 161317},
	{"EXIES", 5, 161318},
	{"SHAVLIK", 7, 161319},
	{"REGALE", 6, 161320},
	{"CYBELE", 6, 161321},
	{"NONCODING", 9, 161322},
	{"AMETHYSTS", 9, 161323},
	{"FREEPER", 7, 161324},
	{"MUNISING", 8, 161325},
	{"GOID", 4, 161326},
	{"UNSTUCK", 7, 161327},
	{"CHOWCHILLA", 10, 161328},
	{"AGUIAR", 6, 161329},
	{"ESCHEWING", 9, 161330},
	{"HDNET", 5, 161331},
	{"ESARCH", 6, 161332},
	{"RCAF", 4, 161333},
	{"BRACEWELL", 9, 161334},
	{"RLUG", 4, 161335},
	{"BITPROPHET", 10, 161336},
	{"KAZOOIE", 7, 161337},
	{"BALOONS", 7, 161338},
	{"CARIOCA", 7, 161339},
	{"HOWARDJOHNSON", 13, 161340},
	{"VIDEOBLOG", 9, 161341},
	{"GOLDSHIELD", 10, 161342},
	{"LORIEN", 6, 161343},
	{"SULFONATE", 9, 161344},
	{"COMPRESSIONS", 12, 161345},
	{"BITTORENT", 9, 161346},
	{"LINDROS", 7, 161347},
	{"OVERPAY", 7, 161348},
	{"CAROLUS", 7, 161349},
	{"WINDUP", 6, 161350},
	{"ICEMAKER", 8, 161351},
	{"ZAZA", 4, 161352},
	{"AGOSTINI", 8, 161353},
	{"ANDRONICUS", 10, 161354},
	{"GLYCOSAMINOGLYCANS", 18, 161355},
	{"NEVUS", 5, 161356},
	{"CENTAGE", 7, 161357},
	{"ETHNOBOTANY", 11, 161358},
	{"CRUS", 4, 161359},
	{"TRANYLCYPROMINE", 15, 161360},
	{"COMTRADE", 8, 161361},
	{"YAMW", 4, 161362},
	{"VIGE", 4, 161363},
	{"TSKR", 4, 161364},
	{"SEZF", 4, 161365},
	{"SDAB", 4, 161366},
	{"PLAA", 4, 161367},
	{"PAUC", 4, 161368},
	{"OYSJ", 4, 161369},
	{"OKFL", 4, 161370},
	{"NFEV", 4, 161371},
	{"KPHA", 4, 161372},
	{"KIPH", 4, 161373},
	{"KBOM", 4, 161374},
	{"IZRE", 4, 161375},
	{"FFEH", 4, 161376},
	{"EOLM", 4, 161377},
	{"EBIM", 4, 161378},
	{"DUHO", 4, 161379},
	{"DLAO", 4, 161380},
	{"BVAN", 4, 161381},
	{"BAQU", 4, 161382},
	{"ANYZ", 4, 161383},
	{"NEWTYPE", 7, 161384},
	{"AMAX", 4, 161385},
	{"DECONTAMINATED", 14, 161386},
	{"SUMATRAN", 8, 161387},
	{"LOCALIZATIONS", 13, 161388},
	{"CONNECTIX", 9, 161389},
	{"PURESTOCK", 9, 161390},
	{"DISSECTORS", 10, 161391},
	{"SLURRIES", 8, 161392},
	{"ICHTHYOLOGY", 11, 161393},
	{"CALLERID", 8, 161394},
	{"GOLDKABEL", 9, 161395},
	{"WOODHULL", 8, 161396},
	{"FEMINISTING", 11, 161397},
	{"TRENCHER", 8, 161398},
	{"PORCHER", 7, 161399},
	{"MUKUL", 5, 161400},
	{"NETRIX", 6, 161401},
	{"AMUSES", 6, 161402},
	{"PALLOR", 6, 161403},
	{"HECHINGER", 9, 161404},
	{"MELISA", 6, 161405},
	{"CARBAMATE", 9, 161406},
	{"EDGARDO", 7, 161407},
	{"SWASHBUCKLER", 12, 161408},
	{"FILK", 4, 161409},
	{"BLZ", 3, 161410},
	{"EXCULPATORY", 11, 161411},
	{"UNWHOLESOME", 11, 161412},
	{"FRESENIUS", 9, 161413},
	{"DBB", 3, 161414},
	{"COUNTRYINN", 10, 161415},
	{"BIERSTADT", 9, 161416},
	{"PARSIFAL", 8, 161417},
	{"ZWEIG", 5, 161418},
	{"COPRA", 5, 161419},
	{"GURLS", 5, 161420},
	{"REDROOFINN", 10, 161421},
	{"SEARXH", 6, 161422},
	{"FLAV", 4, 161423},
	{"ENTAILING", 9, 161424},
	{"MONTHY", 6, 161425},
	{"YURIY", 5, 161426},
	{"GALION", 6, 161427},
	{"JOURNEYMEN", 10, 161428},
	{"FILIPINAS", 9, 161429},
	{"LINEBREAK", 9, 161430},
	{"BOOKMATE", 8, 161431},
	{"BHATNAGAR", 9, 161432},
	{"UROKINASE", 9, 161433},
	{"DENSMORE", 8, 161434},
	{"MISATO", 6, 161435},
	{"GERHART", 7, 161436},
	{"KUGEL", 5, 161437},
	{"BAHAR", 5, 161438},
	{"TICKETSNOW", 10, 161439},
	{"ANTAGONIZE", 10, 161440},
	{"REGEXPS", 7, 161441},
	{"SUNSTEIN", 8, 161442},
	{"QUIRES", 6, 161443},
	{"ZEFA", 4, 161444},
	{"YMTO", 4, 161445},
	{"VVID", 4, 161446},
	{"ULTQ", 4, 161447},
	{"UEGL", 4, 161448},
	{"UDUS", 4, 161449},
	{"TPYR", 4, 161450},
	{"TECM", 4, 161451},
	{"RZIP", 4, 161452},
	{"QISW", 4, 161453},
	{"POGA", 4, 161454},
	{"OKHU", 4, 161455},
	{"MCBE", 4, 161456},
	{"LKAA", 4, 161457},
	{"LAKN", 4, 161458},
	{"KMIR", 4, 161459},
	{"GYAU", 4, 161460},
	{"GELK", 4, 161461},
	{"EODR", 4, 161462},
	{"CIGN", 4, 161463},
	{"BREH", 4, 161464},
	{"AURC", 4, 161465},
	{"SANDLIN", 7, 161466},
	{"HIPPOLYTE", 9, 161467},
	{"WESTCHASE", 9, 161468},
	{"TYROLEAN", 8, 161469},
	{"PHOSPHINE", 9, 161470},
	{"PLANESCAPE", 10, 161471},
	{"SLANE", 5, 161472},
	{"DATAPORTAL", 10, 161473},
	{"LECKIE", 6, 161474},
	{"ZHONGGUO", 8, 161475},
	{"REDROOF", 7, 161476},
	{"TINTAGEL", 8, 161477},
	{"BOSTROM", 7, 161478},
	{"DINUBA", 6, 161479},
	{"COMAIR", 6, 161480},
	{"POLYADENYLATION", 15, 161481},
	{"MAJEWSKI", 8, 161482},
	{"MARSA", 5, 161483},
	{"KAWAKAMI", 8, 161484},
	{"FRASE", 5, 161485},
	{"JAYCEE", 6, 161486},
	{"SILMARILLION", 12, 161487},
	{"GALLING", 7, 161488},
	{"DARKWAVE", 8, 161489},
	{"INTERMED", 8, 161490},
	{"POLYGONUM", 9, 161491},
	{"NEUROSES", 8, 161492},
	{"LOUW", 4, 161493},
	{"DAMION", 6, 161494},
	{"SEDAI", 5, 161495},
	{"NONTECHNICAL", 12, 161496},
	{"PHARMACODYNAMICS", 16, 161497},
	{"IARU", 4, 161498},
	{"AJINOMOTO", 9, 161499},
	{"PLANETWARE", 10, 161500},
	{"MELILOTI", 8, 161501},
	{"ACTUARIALLY", 11, 161502},
	{"FISICHELLA", 10, 161503},
	{"BLACKICE", 8, 161504},
	{"QUITTED", 7, 161505},
	{"ANGELIII", 8, 161506},
	{"TOMBA", 5, 161507},
	{"OOGIE", 5, 161508},
	{"SARSAPARILLA", 12, 161509},
	{"RAHM", 4, 161510},
	{"ORTONVILLE", 10, 161511},
	{"TRADECENTRE", 11, 161512},
	{"MUSTA", 5, 161513},
	{"BENZIE", 6, 161514},
	{"MINDJET", 7, 161515},
	{"FACEPIECE", 9, 161516},
	{"BEEFING", 7, 161517},
	{"NORTHUP", 7, 161518},
	{"XOFG", 4, 161519},
	{"TJAD", 4, 161520},
	{"RGFA", 4, 161521},
	{"RAZU", 4, 161522},
	{"PVIA", 4, 161523},
	{"OUZE", 4, 161524},
	{"OUYA", 4, 161525},
	{"OROJ", 4, 161526},
	{"OGED", 4, 161527},
	{"NTVB", 4, 161528},
	{"NHLR", 4, 161529},
	{"MRAW", 4, 161530},
	{"MOLU", 4, 161531},
	{"KURG", 4, 161532},
	{"KEZI", 4, 161533},
	{"JRAT", 4, 161534},
	{"IKWE", 4, 161535},
	{"ICZW", 4, 161536},
	{"HRIR", 4, 161537},
	{"FDRM", 4, 161538},
	{"ESPG", 4, 161539},
	{"ELKL", 4, 161540},
	{"ELGB", 4, 161541},
	{"DTMA", 4, 161542},
	{"CDIO", 4, 161543},
	{"SYNCE", 5, 161544},
	{"BOBWHITE", 8, 161545},
	{"DOVEY", 5, 161546},
	{"ECONLODGE", 9, 161547},
	{"CLASTIC", 7, 161548},
	{"PALLIDUM", 8, 161549},
	{"WILDSTROM", 9, 161550},
	{"BATTLESPACE", 11, 161551},
	{"EARTHSCAN", 9, 161552},
	{"PONTIS", 6, 161553},
	{"ASSERTTRUE", 10, 161554},
	{"PANTANAL", 8, 161555},
	{"MRLS", 4, 161556},
	{"STEPHON", 7, 161557},
	{"FUNN", 4, 161558},
	{"AMAND", 5, 161559},
	{"RECASTING", 9, 161560},
	{"IRRIGATING", 10, 161561},
	{"BRAWNY", 6, 161562},
	{"TEZUKA", 6, 161563},
	{"QUELLA", 6, 161564},
	{"LEMMER", 6, 161565},
	{"FUERON", 6, 161566},
	{"AMARIGE", 7, 161567},
	{"ONEIL", 5, 161568},
	{"REPUBS", 6, 161569},
	{"PEPPARD", 7, 161570},
	{"FYRE", 4, 161571},
	{"REGISTRA", 8, 161572},
	{"GERGEN", 6, 161573},
	{"SUPLEX", 6, 161574},
	{"PACIENTES", 9, 161575},
	{"INTERWAR", 8, 161576},
	{"GONAD", 5, 161577},
	{"BRAINDEAD", 9, 161578},
	{"BARBERRY", 8, 161579},
	{"INSITUTE", 8, 161580},
	{"LEMONHEADS", 10, 161581},
	{"SERVICEDESK", 11, 161582},
	{"COVARIANCES", 11, 161583},
	{"ROSETTANET", 10, 161584},
	{"MORVEN", 6, 161585},
	{"NUMDIST", 7, 161586},
	{"SCANDIUM", 8, 161587},
	{"NUMDOCID", 8, 161588},
	{"LIZZ", 4, 161589},
	{"HISTORICITY", 11, 161590},
	{"ARONA", 5, 161591},
	{"LIBEXECDIR", 10, 161592},
	{"FLYWEIGHT", 9, 161593},
	{"ANFY", 4, 161594},
	{"CROWNEPLAZA", 11, 161595},
	{"PRATTLE", 7, 161596},
	{"PARTAKERS", 9, 161597},
	{"PEDIA", 5, 161598},
	{"SIMCHA", 6, 161599},
	{"SHINNY", 6, 161600},
	{"DESENHO", 7, 161601},
	{"YELVERTON", 9, 161602},
	{"CLIMAT", 6, 161603},
	{"UNCITRAL", 8, 161604},
	{"VENTOLIN", 8, 161605},
	{"PIPEFITTERS", 11, 161606},
	{"ZULI", 4, 161607},
	{"YRAU", 4, 161608},
	{"YMPS", 4, 161609},
	{"VJAN", 4, 161610},
	{"TYPS", 4, 161611},
	{"TSMP", 4, 161612},
	{"TOWB", 4, 161613},
	{"RWAX", 4, 161614},
	{"PPIB", 4, 161615},
	{"PNEY", 4, 161616},
	{"PLTD", 4, 161617},
	{"MIEG", 4, 161618},
	{"LWEF", 4, 161619},
	{"JRRE", 4, 161620},
	{"HZAC", 4, 161621},
	{"HRUA", 4, 161622},
	{"FJEL", 4, 161623},
	{"DTAD", 4, 161624},
	{"DDTA", 4, 161625},
	{"AQAL", 4, 161626},
	{"BALLISTIX", 9, 161627},
	{"PINCHOT", 7, 161628},
	{"GERAN", 5, 161629},
	{"TUTHILL", 7, 161630},
	{"ILIUM", 5, 161631},
	{"AIRSTRIKES", 10, 161632},
	{"LIVY", 4, 161633},
	{"JAZZED", 6, 161634},
	{"ETHRIDGE", 8, 161635},
	{"INCORRUPTIBLE", 13, 161636},
	{"SANTAMARIA", 10, 161637},
	{"GERTLER", 7, 161638},
	{"COMDIAL", 7, 161639},
	{"CRATAEGUS", 9, 161640},
	{"MOTTLING", 8, 161641},
	{"LAQUITA", 7, 161642},
	{"PURITANISM", 10, 161643},
	{"LINCITY", 7, 161644},
	{"JASCO", 5, 161645},
	{"DRMS", 4, 161646},
	{"TESTBERICHTE", 12, 161647},
	{"WARRANTECH", 10, 161648},
	{"PREFILED", 8, 161649},
	{"LEMERIDIEN", 10, 161650},
	{"SECULARISTS", 11, 161651},
	{"GCOMPRIS", 8, 161652},
	{"EMERILWARE", 10, 161653},
	{"NCCI", 4, 161654},
	{"ROTATORS", 8, 161655},
	{"DABONE", 6, 161656},
	{"RECOV", 5, 161657},
	{"FLOSCAN", 7, 161658},
	{"BANDANNAS", 9, 161659},
	{"PARTNERSUCHE", 12, 161660},
	{"HAWARDEN", 8, 161661},
	{"BINTANG", 7, 161662},
	{"AINTREE", 7, 161663},
	{"WWR", 3, 161664},
	{"CHAPBOOKS", 9, 161665},
	{"HODGINS", 7, 161666},
	{"CARTHAGINIAN", 12, 161667},
	{"KIMBO", 5, 161668},
	{"GRATION", 7, 161669},
	{"SUDAMERICANA", 12, 161670},
	{"SPLINTING", 9, 161671},
	{"PURBECK", 7, 161672},
	{"OPTIMISTICALLY", 14, 161673},
	{"ASSOCIAT", 8, 161674},
	{"BIOTECHNIQUES", 13, 161675},
	{"PINUPS", 6, 161676},
	{"SHOWHOMES", 9, 161677},
	{"VANGO", 5, 161678},
	{"YEKA", 4, 161679},
	{"WFEW", 4, 161680},
	{"UMPN", 4, 161681},
	{"UDSF", 4, 161682},
	{"TYMY", 4, 161683},
	{"TYEG", 4, 161684},
	{"RLJU", 4, 161685},
	{"OZOR", 4, 161686},
	{"NKYC", 4, 161687},
	{"MTAU", 4, 161688},
	{"KJUD", 4, 161689},
	{"KCIV", 4, 161690},
	{"JSIM", 4, 161691},
	{"GGYI", 4, 161692},
	{"FYDE", 4, 161693},
	{"FOYL", 4, 161694},
	{"EUFE", 4, 161695},
	{"EBEX", 4, 161696},
	{"DVOM", 4, 161697},
	{"DPUF", 4, 161698},
	{"BOTK", 4, 161699},
	{"BOLV", 4, 161700},
	{"BDOL", 4, 161701},
	{"AYYU", 4, 161702},
	{"BIOMATERIAL", 11, 161703},
	{"BASIX", 5, 161704},
	{"SERVICEMASTER", 13, 161705},
	{"PUBLITEK", 8, 161706},
	{"CINGULATE", 9, 161707},
	{"SECURIT", 7, 161708},
	{"TAMP", 4, 161709},
	{"SPORTSHEETS", 11, 161710},
	{"VENEZIANA", 9, 161711},
	{"FUBUKI", 6, 161712},
	{"SNOBBY", 6, 161713},
	{"AUSWAHL", 7, 161714},
	{"SHERETON", 8, 161715},
	{"LAHR", 4, 161716},
	{"KOBIAN", 6, 161717},
	{"STUDIOTECH", 10, 161718},
	{"SHARATON", 8, 161719},
	{"UNBLOCKING", 10, 161720},
	{"HANDLOOM", 8, 161721},
	{"QUALITYINNS", 11, 161722},
	{"PMX", 3, 161723},
	{"ASSIDUOUSLY", 11, 161724},
	{"FUGA", 4, 161725},
	{"PLIMPTON", 8, 161726},
	{"NIBBLED", 7, 161727},
	{"HINCHCLIFFE", 11, 161728},
	{"EGGHEADS", 8, 161729},
	{"COGNIZABLE", 10, 161730},
	{"SECONDA", 7, 161731},
	{"RACT", 4, 161732},
	{"DELILLO", 7, 161733},
	{"DIALLED", 7, 161734},
	{"ASHLAR", 6, 161735},
	{"ENAMELWARE", 10, 161736},
	{"BOWMANS", 7, 161737},
	{"BITCOMET", 8, 161738},
	{"APPEASING", 9, 161739},
	{"MOGAS", 5, 161740},
	{"ACCTG", 5, 161741},
	{"SHELLSHOCK", 10, 161742},
	{"CRRCOOKIE", 9, 161743},
	{"SABOTEURS", 9, 161744},
	{"KILOBITS", 8, 161745},
	{"BOOZING", 7, 161746},
	{"NARMADA", 7, 161747},
	{"PIQUANT", 7, 161748},
	{"DIBA", 4, 161749},
	{"ERICKA", 6, 161750},
	{"KLOR", 4, 161751},
	{"GROND", 5, 161752},
	{"RADISSONHOTELS", 14, 161753},
	{"PAINTERLY", 9, 161754},
	{"WAITEC", 6, 161755},
	{"TULAREMIA", 9, 161756},
	{"CRINGED", 7, 161757},
	{"TORTUROUS", 9, 161758},
	{"LANOS", 5, 161759},
	{"WIMBERLY", 8, 161760},
	{"POLJOT", 6, 161761},
	{"SIMONI", 6, 161762},
	{"SETTEXT", 7, 161763},
	{"HUGHSON", 7, 161764},
	{"RADISSONHOTEL", 13, 161765},
	{"JAVABEAN", 8, 161766},
	{"DOUWE", 5, 161767},
	{"COSHH", 5, 161768},
	{"MICROZIDE", 9, 161769},
	{"MAGNO", 5, 161770},
	{"XNOV", 4, 161771},
	{"WAXA", 4, 161772},
	{"WALU", 4, 161773},
	{"VRAB", 4, 161774},
	{"VLAR", 4, 161775},
	{"UEZM", 4, 161776},
	{"RPDI", 4, 161777},
	{"RAOC", 4, 161778},
	{"NHUF", 4, 161779},
	{"MIDV", 4, 161780},
	{"KWRA", 4, 161781},
	{"KAAK", 4, 161782},
	{"IPGE", 4, 161783},
	{"HDPR", 4, 161784},
	{"EZTR", 4, 161785},
	{"EUXS", 4, 161786},
	{"EMRK", 4, 161787},
	{"EGUZ", 4, 161788},
	{"EFCR", 4, 161789},
	{"CUPN", 4, 161790},
	{"QTOPIA", 6, 161791},
	{"SEITENSPRUNG", 12, 161792},
	{"WONU", 4, 161793},
	{"AMNON", 5, 161794},
	{"LEEUWARDEN", 10, 161795},
	{"FAREAST", 7, 161796},
	{"ASADA", 5, 161797},
	{"HEXAPODA", 8, 161798},
	{"UNSERVED", 8, 161799},
	{"WINDGATE", 8, 161800},
	{"BUSINESSWOMEN", 13, 161801},
	{"SANGSTER", 8, 161802},
	{"MARGIT", 6, 161803},
	{"HVLP", 4, 161804},
	{"VERSIO", 6, 161805},
	{"TECATE", 6, 161806},
	{"CALLEN", 6, 161807},
	{"APPAREILS", 9, 161808},
	{"SPAMKILLER", 10, 161809},
	{"LEUTE", 5, 161810},
	{"ALLERGISTS", 10, 161811},
	{"PERENS", 6, 161812},
	{"SEBUM", 5, 161813},
	{"ONTROL", 6, 161814},
	{"FANTASYLAND", 11, 161815},
	{"BUNKYO", 6, 161816},
	{"UNRESERVEDLY", 12, 161817},
	{"NONAGRICULTURAL", 15, 161818},
	{"EXCULDING", 9, 161819},
	{"PENWORTHAM", 10, 161820},
	{"TATTLE", 6, 161821},
	{"LINDENWOOD", 10, 161822},
	{"MEDTERMS", 8, 161823},
	{"WHITESBURG", 10, 161824},
	{"BASTE", 5, 161825},
	{"CLENBUTEROL", 11, 161826},
	{"RACF", 4, 161827},
	{"DARKFURIES", 10, 161828},
	{"ESSELBACH", 9, 161829},
	{"DOMELEMENT", 10, 161830},
	{"LAQUINTAINNS", 12, 161831},
	{"GRAZER", 6, 161832},
	{"ECLECTICISM", 11, 161833},
	{"CONCOCT", 7, 161834},
	{"STRICKER", 8, 161835},
	{"MANIER", 6, 161836},
	{"OOCYSTS", 7, 161837},
	{"WILLST", 6, 161838},
	{"MSBUILD", 7, 161839},
	{"BESTED", 6, 161840},
	{"STANGE", 6, 161841},
	{"HEINEMAN", 8, 161842},
	{"BECCLES", 7, 161843},
	{"CAMPOUT", 7, 161844},
	{"AHMADI", 6, 161845},
	{"XXIN", 4, 161846},
	{"XFIE", 4, 161847},
	{"VSWH", 4, 161848},
	{"UMKA", 4, 161849},
	{"UABU", 4, 161850},
	{"SUEJ", 4, 161851},
	{"RLJO", 4, 161852},
	{"RETK", 4, 161853},
	{"PEEB", 4, 161854},
	{"OEYB", 4, 161855},
	{"NDBJ", 4, 161856},
	{"IKKN", 4, 161857},
	{"HUSV", 4, 161858},
	{"HRAK", 4, 161859},
	{"FMMA", 4, 161860},
	{"FGOU", 4, 161861},
	{"EVFL", 4, 161862},
	{"DUOD", 4, 161863},
	{"DMSN", 4, 161864},
	{"DEMD", 4, 161865},
	{"CBRU", 4, 161866},
	{"BKIL", 4, 161867},
	{"AXYE", 4, 161868},
	{"AURT", 4, 161869},
	{"AQAF", 4, 161870},
	{"APTJ", 4, 161871},
	{"DAILENEWS", 9, 161872},
	{"INSEPARABLY", 11, 161873},
	{"COCKPITS", 8, 161874},
	{"CROWNPLAZA", 10, 161875},
	{"EXTENDEDSTAYAMERICA", 19, 161876},
	{"SHEARATON", 9, 161877},
	{"ZADIE", 5, 161878},
	{"LOGD", 4, 161879},
	{"VILLETTE", 8, 161880},
	{"IVANOVICH", 9, 161881},
	{"TIMETABLED", 10, 161882},
	{"KORPS", 5, 161883},
	{"AEARCH", 6, 161884},
	{"CODEZWIZ", 8, 161885},
	{"MATIX", 5, 161886},
	{"ASPHERIC", 8, 161887},
	{"BRASSTECH", 9, 161888},
	{"ANTHERS", 7, 161889},
	{"PINLESS", 7, 161890},
	{"INTERCHANGEABILITY", 18, 161891},
	{"SAUTERNES", 9, 161892},
	{"JOURNEYSKIDZ", 12, 161893},
	{"YAXAY", 5, 161894},
	{"GINNING", 7, 161895},
	{"WESTINHOTELS", 12, 161896},
	{"BEDELIA", 7, 161897},
	{"WIEGHT", 6, 161898},
	{"ADAMSMARK", 9, 161899},
	{"CANONIZATION", 12, 161900},
	{"DEMETRIOS", 9, 161901},
	{"CORONAS", 7, 161902},
	{"REDROOFINNS", 11, 161903},
	{"SHASTRA", 7, 161904},
	{"OMNIHOTELS", 10, 161905},
	{"UNSINKABLE", 10, 161906},
	{"CRYPTS", 6, 161907},
	{"TWINKIES", 8, 161908},
	{"WESTINHOTEL", 11, 161909},
	{"ILAR", 4, 161910},
	{"AQUIS", 5, 161911},
	{"SEAECH", 6, 161912},
	{"BUTTONHOLE", 10, 161913},
	{"ANTVILLE", 8, 161914},
	{"IRENAEUS", 8, 161915},
	{"FOILING", 7, 161916},
	{"DONITA", 6, 161917},
	{"THANATOS", 8, 161918},
	{"FAMU", 4, 161919},
	{"CHIARI", 6, 161920},
	{"BIOMONITORING", 13, 161921},
	{"MOCCA", 5, 161922},
	{"AMERSUITES", 10, 161923},
	{"MPUSH", 5, 161924},
	{"BWRDD", 5, 161925},
	{"RENASANCE", 9, 161926},
	{"GASTROPODA", 10, 161927},
	{"EVOWIKI", 7, 161928},
	{"RETIEF", 6, 161929},
	{"OLDGRAY", 7, 161930},
	{"UNCIVILIZED", 11, 161931},
	{"MOOTS", 5, 161932},
	{"KATEY", 5, 161933},
	{"INSENSIBLE", 10, 161934},
	{"CARTAGE", 7, 161935},
	{"IMPEACHABLE", 11, 161936},
	{"GLIWICE", 7, 161937},
	{"MCGOLDRICK", 10, 161938},
	{"MANJI", 5, 161939},
	{"ENDREQ", 6, 161940},
	{"XITB", 4, 161941},
	{"TYMR", 4, 161942},
	{"TURV", 4, 161943},
	{"TEPG", 4, 161944},
	{"SMRW", 4, 161945},
	{"RAKC", 4, 161946},
	{"PSYW", 4, 161947},
	{"NZHU", 4, 161948},
	{"NLEP", 4, 161949},
	{"LAKK", 4, 161950},
	{"KAPH", 4, 161951},
	{"IPAV", 4, 161952},
	{"GOJA", 4, 161953},
	{"GNPH", 4, 161954},
	{"EBBT", 4, 161955},
	{"DUNV", 4, 161956},
	{"CGHE", 4, 161957},
	{"CEAJ", 4, 161958},
	{"ACOK", 4, 161959},
	{"SIMRAN", 6, 161960},
	{"WHISTLEBLOWING", 14, 161961},
	{"RYALL", 5, 161962},
	{"COTTO", 5, 161963},
	{"AMERSUITE", 9, 161964},
	{"COCKATOOS", 9, 161965},
	{"MUGGLES", 7, 161966},
	{"ASANAS", 6, 161967},
	{"HYDRATASE", 9, 161968},
	{"PAGLIA", 6, 161969},
	{"UKUK", 4, 161970},
	{"MIDDLEWESTERNER", 15, 161971},
	{"HAMDAN", 6, 161972},
	{"SNOWMAKING", 10, 161973},
	{"RADDB", 5, 161974},
	{"IMMEDI", 6, 161975},
	{"TERWILLIGER", 11, 161976},
	{"SECURI", 6, 161977},
	{"MICROTELINN", 11, 161978},
	{"SEASICK", 7, 161979},
	{"IHAVE", 5, 161980},
	{"EVENSONG", 8, 161981},
	{"BRENNEN", 7, 161982},
	{"PRQ", 3, 161983},
	{"COWBIRD", 7, 161984},
	{"REDOUBLE", 8, 161985},
	{"HAWTHORNSUITES", 14, 161986},
	{"THEODOSIUS", 10, 161987},
	{"DANONE", 6, 161988},
	{"FENESTRATION", 12, 161989},
	{"MICROTELL", 9, 161990},
	{"ARCNET", 6, 161991},
	{"MICHIO", 6, 161992},
	{"NASIONAL", 8, 161993},
	{"LIBERTE", 7, 161994},
	{"DREISER", 7, 161995},
	{"HARMONDSWORTH", 13, 161996},
	{"PRINTINGPRINTER", 15, 161997},
	{"EEARCH", 6, 161998},
	{"DEPHOSPHORYLATION", 17, 161999},
	{"WEARCH", 6, 162000},
	{"ROSTRUM", 7, 162001},
	{"DERIVABLE", 9, 162002},
	{"ABKHAZIAN", 9, 162003},
	{"BIGSCREEN", 9, 162004},
	{"EJACULATED", 10, 162005},
	{"PANNE", 5, 162006},
	{"ANCHO", 5, 162007},
	{"LIBROXEN", 8, 162008},
	{"SUMYCIN", 7, 162009},
	{"CANDELWOOD", 10, 162010},
	{"DEADLIFT", 8, 162011},
	{"CHOLLA", 6, 162012},
	{"AKIHABARA", 9, 162013},
	{"XDD", 3, 162014},
	{"WHENUA", 6, 162015},
	{"RENNASANCE", 10, 162016},
	{"ADSORBENT", 9, 162017},
	{"PCSTATS", 7, 162018},
	{"WEBWML", 6, 162019},
	{"OMNIHOTEL", 9, 162020},
	{"CRUET", 5, 162021},
	{"AMERICASUITES", 13, 162022},
	{"DENEUVE", 7, 162023},
	{"SUPERSAVER", 10, 162024},
	{"TZID", 4, 162025},
	{"GUSTINE", 7, 162026},
	{"MAILGATE", 8, 162027},
	{"WSWR", 4, 162028},
	{"WRAR", 4, 162029},
	{"WBYM", 4, 162030},
	{"UZZC", 4, 162031},
	{"USOD", 4, 162032},
	{"UORG", 4, 162033},
	{"THWY", 4, 162034},
	{"SACF", 4, 162035},
	{"RHPJ", 4, 162036},
	{"REGK", 4, 162037},
	{"PPLO", 4, 162038},
	{"LSHB", 4, 162039},
	{"LPAW", 4, 162040},
	{"KELR", 4, 162041},
	{"INRB", 4, 162042},
	{"IKUY", 4, 162043},
	{"ICZE", 4, 162044},
	{"HYLT", 4, 162045},
	{"HFIB", 4, 162046},
	{"FDOV", 4, 162047},
	{"FCFO", 4, 162048},
	{"ENMP", 4, 162049},
	{"EAUJ", 4, 162050},
	{"DUEE", 4, 162051},
	{"DDRB", 4, 162052},
	{"BBID", 4, 162053},
	{"PROIN", 5, 162054},
	{"SHAPLEY", 7, 162055},
	{"HAWTHORNESUITES", 15, 162056},
	{"NIPPERS", 7, 162057},
	{"XEXP", 4, 162058},
	{"OLLAR", 5, 162059},
	{"LAWCRAWLER", 10, 162060},
	{"DELOACH", 7, 162061},
	{"RFM", 3, 162062},
	{"YMLAEN", 6, 162063},
	{"MOORGATE", 8, 162064},
	{"HOMEWOODSUITES", 14, 162065},
	{"MELFORD", 7, 162066},
	{"CCBN", 4, 162067},
	{"SPURL", 5, 162068},
	{"PRYDZ", 5, 162069},
	{"FENFLURAMINE", 12, 162070},
	{"SABLES", 6, 162071},
	{"WOLFVILLE", 9, 162072},
	{"PRESA", 5, 162073},
	{"SMALLHOLDERS", 12, 162074},
	{"ROBICHAUD", 9, 162075},
	{"FFREE", 5, 162076},
	{"FAHY", 4, 162077},
	{"KETOPROFEN", 10, 162078},
	{"BOUMA", 5, 162079},
	{"XSANE", 5, 162080},
	{"CLOMIPRAMINE", 12, 162081},
	{"TITULO", 6, 162082},
	{"SHIRL", 5, 162083},
	{"ONLYSHADOW", 10, 162084},
	{"RESIS", 5, 162085},
	{"HINWEIS", 7, 162086},
	{"SEEKMEDIA", 9, 162087},
	{"XEARCH", 6, 162088},
	{"GUIDEWAY", 8, 162089},
	{"UNDERCURRENTS", 13, 162090},
	{"CHESSIE", 7, 162091},
	{"ADMONITIONS", 11, 162092},
	{"HOLBEIN", 7, 162093},
	{"MKC", 3, 162094},
	{"LUCKIE", 6, 162095},
	{"CITYTV", 6, 162096},
	{"JEDBURGH", 8, 162097},
	{"BETW", 4, 162098},
	{"ARKIV", 5, 162099},
	{"YUUGI", 5, 162100},
	{"MEDIABISTRO", 11, 162101},
	{"DALKEY", 6, 162102},
	{"LASSER", 6, 162103},
	{"GIFTEDNESS", 10, 162104},
	{"CATSUP", 6, 162105},
	{"KAPS", 4, 162106},
	{"EDLUND", 6, 162107},
	{"SIGTERM", 7, 162108},
	{"ELBERTON", 8, 162109},
	{"SHEWING", 7, 162110},
	{"SERUMS", 6, 162111},
	{"ROUBAIX", 7, 162112},
	{"OKAFOR", 6, 162113},
	{"RENNASSANCE", 11, 162114},
	{"SCROTAL", 7, 162115},
	{"DROXY", 5, 162116},
	{"OVERGRAZING", 11, 162117},
	{"SUELO", 5, 162118},
	{"EASTERNMOST", 11, 162119},
	{"FULLERENES", 10, 162120},
	{"DISTROWATCH", 11, 162121},
	{"YZEN", 4, 162122},
	{"YOCH", 4, 162123},
	{"XDAT", 4, 162124},
	{"WKNI", 4, 162125},
	{"WIEB", 4, 162126},
	{"WAXW", 4, 162127},
	{"UHIK", 4, 162128},
	{"TMRD", 4, 162129},
	{"TCMI", 4, 162130},
	{"SYAP", 4, 162131},
	{"RHIB", 4, 162132},
	{"PIAP", 4, 162133},
	{"ODTW", 4, 162134},
	{"MTLE", 4, 162135},
	{"LAZU", 4, 162136},
	{"JAGE", 4, 162137},
	{"IROZ", 4, 162138},
	{"SMCANT", 6, 162139},
	{"COWER", 5, 162140},
	{"SHANKER", 7, 162141},
	{"ADULTE", 6, 162142},
	{"CHEMAINUS", 9, 162143},
	{"AMBASSADE", 9, 162144},
	{"ERFAHREN", 8, 162145},
	{"GRIMSLEY", 8, 162146},
	{"PIGGIN", 6, 162147},
	{"COMMODO", 7, 162148},
	{"LARRABEE", 8, 162149},
	{"INTERSPECIES", 12, 162150},
	{"DISULFID", 8, 162151},
	{"NATURALMAX", 10, 162152},
	{"SEARCN", 6, 162153},
	{"WINSUP", 6, 162154},
	{"ROSENBLOOM", 10, 162155},
	{"GORGOROTH", 9, 162156},
	{"FRANNIE", 7, 162157},
	{"INFERIORS", 9, 162158},
	{"GUMMED", 6, 162159},
	{"REVITALISING", 12, 162160},
	{"RECKITT", 7, 162161},
	{"BETTYE", 6, 162162},
	{"DYIN", 4, 162163},
	{"GROSSI", 6, 162164},
	{"CHEQUER", 7, 162165},
	{"KODE", 4, 162166},
	{"SOUPY", 5, 162167},
	{"PROBATIONER", 11, 162168},
	{"COWDENBEATH", 11, 162169},
	{"SYNCOPATED", 10, 162170},
	{"HETEROTROPHIC", 13, 162171},
	{"NECTARINES", 10, 162172},
	{"BRINING", 7, 162173},
	{"TUCHMAN", 7, 162174},
	{"CRIMINALIZING", 13, 162175},
	{"ANDROGEL", 8, 162176},
	{"PROPRE", 6, 162177},
	{"GARVER", 6, 162178},
	{"WUNDERBLOG", 10, 162179},
	{"SEARVH", 6, 162180},
	{"REPROGRAMMED", 12, 162181},
	{"MASSIMILIANO", 12, 162182},
	{"MIRABEL", 7, 162183},
	{"INITAL", 6, 162184},
	{"IPPS", 4, 162185},
	{"CHARDIN", 7, 162186},
	{"SINGED", 6, 162187},
	{"NWCLASSIFIEDS", 13, 162188},
	{"REORGANIZES", 11, 162189},
	{"MCOS", 4, 162190},
	{"MICROARCHITECTURE", 17, 162191},
	{"TREHALOSE", 9, 162192},
	{"COMPANYNAME", 11, 162193},
	{"PRECEPTORS", 10, 162194},
	{"LOKA", 4, 162195},
	{"NABORS", 6, 162196},
	{"TENZIN", 6, 162197},
	{"SEARCB", 6, 162198},
	{"ZADEH", 5, 162199},
	{"RIKU", 4, 162200},
	{"ELWYN", 5, 162201},
	{"SLATKIN", 7, 162202},
	{"WOODRING", 8, 162203},
	{"NEATER", 6, 162204},
	{"VERMONTERS", 10, 162205},
	{"EMERCHANDISE", 12, 162206},
	{"BOLIC", 5, 162207},
	{"ATOMICS", 7, 162208},
	{"SELDON", 6, 162209},
	{"ROLI", 4, 162210},
	{"PALMTOPS", 8, 162211},
	{"CAVERS", 6, 162212},
	{"ZLYB", 4, 162213},
	{"YTID", 4, 162214},
	{"TSRD", 4, 162215},
	{"SILG", 4, 162216},
	{"RMUZ", 4, 162217},
	{"NOMD", 4, 162218},
	{"LMYD", 4, 162219},
	{"ISMK", 4, 162220},
	{"GAKO", 4, 162221},
	{"CKOK", 4, 162222},
	{"CIAV", 4, 162223},
	{"ABSR", 4, 162224},
	{"VPSP", 4, 162225},
	{"GALATEA", 7, 162226},
	{"MICROKERNEL", 11, 162227},
	{"SCUDERIA", 8, 162228},
	{"OLTRE", 5, 162229},
	{"SEQRCH", 6, 162230},
	{"PATROCINADOS", 12, 162231},
	{"MOSSER", 6, 162232},
	{"ESPECIALY", 9, 162233},
	{"TCLASS", 6, 162234},
	{"HALLES", 6, 162235},
	{"TULLAMORE", 9, 162236},
	{"TSAVO", 5, 162237},
	{"GIRD", 4, 162238},
	{"VANDERHOOF", 10, 162239},
	{"SLUMBERJACK", 11, 162240},
	{"FVFS", 4, 162241},
	{"BERENDT", 7, 162242},
	{"TERRITOIRE", 10, 162243},
	{"PSID", 4, 162244},
	{"FVFP", 4, 162245},
	{"DETENT", 6, 162246},
	{"PUBLICISING", 11, 162247},
	{"HUBLI", 5, 162248},
	{"CYBERSITTER", 11, 162249},
	{"PIERCES", 7, 162250},
	{"JUGEND", 6, 162251},
	{"POSTUN", 6, 162252},
	{"KJETIL", 6, 162253},
	{"FCDRV", 5, 162254},
	{"FCSEL", 5, 162255},
	{"KLEIDUNG", 8, 162256},
	{"QUANZHOU", 8, 162257},
	{"STELTER", 7, 162258},
	{"ERFAHRUNGEN", 11, 162259},
	{"GOODKIND", 8, 162260},
	{"ROSIGLITAZONE", 13, 162261},
	{"MISMANAGED", 10, 162262},
	{"DAYTRADING", 10, 162263},
	{"LACANCHE", 8, 162264},
	{"RELACORE", 8, 162265},
	{"SOLICITUDE", 10, 162266},
	{"LIGHTINGS", 9, 162267},
	{"CALIGARI", 8, 162268},
	{"CHAPA", 5, 162269},
	{"INTERWIKIPLUGIN", 15, 162270},
	{"STOPPIN", 7, 162271},
	{"KETTNER", 7, 162272},
	{"GUV", 3, 162273},
	{"SSARCH", 6, 162274},
	{"PAWNBROKER", 10, 162275},
	{"ROCKSHOX", 8, 162276},
	{"DAIRYLAND", 9, 162277},
	{"HYDROXYETHYL", 12, 162278},
	{"GLYNIS", 6, 162279},
	{"CALO", 4, 162280},
	{"EDERAL", 6, 162281},
	{"MONTESQUIEU", 11, 162282},
	{"BONNARD", 7, 162283},
	{"REVERENTLY", 10, 162284},
	{"MOTHMAN", 7, 162285},
	{"LEVELLAND", 9, 162286},
	{"TRAHAN", 6, 162287},
	{"GUARRAS", 7, 162288},
	{"DEIGN", 5, 162289},
	{"BALLZ", 5, 162290},
	{"YZIM", 4, 162291},
	{"XLET", 4, 162292},
	{"WJEW", 4, 162293},
	{"VAUS", 4, 162294},
	{"TVFR", 4, 162295},
	{"RYLM", 4, 162296},
	{"PCOT", 4, 162297},
	{"PARQ", 4, 162298},
	{"PAKH", 4, 162299},
	{"MRCU", 4, 162300},
	{"LDCY", 4, 162301},
	{"LCHT", 4, 162302},
	{"KUNC", 4, 162303},
	{"ILNU", 4, 162304},
	{"GKAY", 4, 162305},
	{"FTFU", 4, 162306},
	{"FIMG", 4, 162307},
	{"FETW", 4, 162308},
	{"EDYJ", 4, 162309},
	{"DSRS", 4, 162310},
	{"DMTV", 4, 162311},
	{"CYSL", 4, 162312},
	{"BJAR", 4, 162313},
	{"AZEC", 4, 162314},
	{"AFSW", 4, 162315},
	{"SEARFH", 6, 162316},
	{"THESAURUSES", 11, 162317},
	{"TEREPHTHALATE", 13, 162318},
	{"NONROAD", 7, 162319},
	{"SEZRCH", 6, 162320},
	{"XTRADIUS", 8, 162321},
	{"BLOGSMITH", 9, 162322},
	{"SDARCH", 6, 162323},
	{"HOMINY", 6, 162324},
	{"PASTEURELLA", 11, 162325},
	{"FAVREAU", 7, 162326},
	{"AELODAU", 7, 162327},
	{"RUCH", 4, 162328},
	{"MEXIA", 5, 162329},
	{"CRAWLSPACE", 10, 162330},
	{"USINE", 5, 162331},
	{"CETIRIZINE", 10, 162332},
	{"IRONBRIDGE", 10, 162333},
	{"VCAL", 4, 162334},
	{"DBCP", 4, 162335},
	{"FOGLIO", 6, 162336},
	{"SELEGILINE", 10, 162337},
	{"KOIRALA", 7, 162338},
	{"LACUSTRINE", 10, 162339},
	{"DOTING", 6, 162340},
	{"CARISMA", 7, 162341},
	{"ARCHAEAL", 8, 162342},
	{"HOMEBIRTH", 9, 162343},
	{"SPOHN", 5, 162344},
	{"PARIBUS", 7, 162345},
	{"PARISON", 7, 162346},
	{"FUERZA", 6, 162347},
	{"COMPOSITEUR", 11, 162348},
	{"TECHSMITH", 9, 162349},
	{"WENDYS", 6, 162350},
	{"DISFRUTA", 8, 162351},
	{"SCIENTI", 7, 162352},
	{"GLEDHILL", 8, 162353},
	{"AMERIPHONE", 10, 162354},
	{"SEARCU", 6, 162355},
	{"JMOL", 4, 162356},
	{"ANALES", 6, 162357},
	{"CALEN", 5, 162358},
	{"TAPPI", 5, 162359},
	{"CAMERAWORLD", 11, 162360},
	{"MAYPORT", 7, 162361},
	{"LEASEHOLDERS", 12, 162362},
	{"CSRC", 4, 162363},
	{"SEAFCH", 6, 162364},
	{"TERING", 6, 162365},
	{"CHEATIN", 7, 162366},
	{"CANALE", 6, 162367},
	{"MASINTER", 8, 162368},
	{"FLYCATCHERS", 11, 162369},
	{"ATTALA", 6, 162370},
	{"PHOTOTHERAPY", 12, 162371},
	{"JOHNTALINTYRE", 13, 162372},
	{"CANTA", 5, 162373},
	{"WITHVAL", 7, 162374},
	{"RDATA", 5, 162375},
	{"CHAREST", 7, 162376},
	{"CROZET", 6, 162377},
	{"SIMULAR", 7, 162378},
	{"REALFEEL", 8, 162379},
	{"SEWRCH", 6, 162380},
	{"CONVERTIBILITY", 14, 162381},
	{"CHAPT", 5, 162382},
	{"VOICEOVERS", 10, 162383},
	{"YGHU", 4, 162384},
	{"WGAI", 4, 162385},
	{"URBH", 4, 162386},
	{"UHAW", 4, 162387},
	{"TSDY", 4, 162388},
	{"SOUM", 4, 162389},
	{"PEGC", 4, 162390},
	{"OWRS", 4, 162391},
	{"OGJA", 4, 162392},
	{"MICZ", 4, 162393},
	{"LHAG", 4, 162394},
	{"LBTH", 4, 162395},
	{"KANF", 4, 162396},
	{"EZSF", 4, 162397},
	{"DRSP", 4, 162398},
	{"DDPE", 4, 162399},
	{"BYTS", 4, 162400},
	{"WHITTLED", 8, 162401},
	{"SKISET", 6, 162402},
	{"SUBRAMANIAM", 11, 162403},
	{"SNAPPLE", 7, 162404},
	{"MARBLING", 8, 162405},
	{"BLISTERED", 9, 162406},
	{"MANTOVANI", 9, 162407},
	{"STEPPARENT", 10, 162408},
	{"MEMORYX", 7, 162409},
	{"NEUROCHEMISTRY", 14, 162410},
	{"GRACY", 5, 162411},
	{"LEGUIZAMO", 9, 162412},
	{"JRB", 3, 162413},
	{"DISCREDITING", 12, 162414},
	{"INGRIAN", 7, 162415},
	{"DETEC", 5, 162416},
	{"SODUS", 5, 162417},
	{"GLITTERED", 9, 162418},
	{"QUADRATE", 8, 162419},
	{"DATALOG", 7, 162420},
	{"HURRICAN", 8, 162421},
	{"MEDIAATLANTIC", 13, 162422},
	{"DDTS", 4, 162423},
	{"HYPERTONIC", 10, 162424},
	{"SEEDER", 6, 162425},
	{"UNPOWERED", 9, 162426},
	{"RECOGNIZANCE", 12, 162427},
	{"PHOSPHOINOSITIDE", 16, 162428},
	{"AEGYPTI", 7, 162429},
	{"HANSEATIC", 9, 162430},
	{"CLENCH", 6, 162431},
	{"IMPINGING", 9, 162432},
	{"MACCA", 5, 162433},
	{"GAMASUTRA", 9, 162434},
	{"PESTERED", 8, 162435},
	{"BENNIS", 6, 162436},
	{"MATSURI", 7, 162437},
	{"EMULSIFIER", 10, 162438},
	{"ANTICODON", 9, 162439},
	{"KRISTEL", 7, 162440},
	{"METAPLASIA", 10, 162441},
	{"MOBLOGS", 7, 162442},
	{"HOLDREGE", 8, 162443},
	{"FRAICHE", 7, 162444},
	{"FANCHER", 7, 162445},
	{"SUONERIA", 8, 162446},
	{"REGUL", 5, 162447},
	{"PREEMINENCE", 11, 162448},
	{"CINESCAPE", 9, 162449},
	{"CBW", 3, 162450},
	{"COMPAREYOURCARE", 15, 162451},
	{"MAURIER", 7, 162452},
	{"COOLOOLA", 8, 162453},
	{"KEHR", 4, 162454},
	{"ANVSA", 5, 162455},
	{"COTTESLOE", 9, 162456},
	{"SIEGEN", 6, 162457},
	{"MINDLESSLY", 10, 162458},
	{"SHEARD", 6, 162459},
	{"COOLWEBSEARCH", 13, 162460},
	{"GOVERNMENTWIDE", 14, 162461},
	{"CARRIERA", 8, 162462},
	{"YOMO", 4, 162463},
	{"YIDS", 4, 162464},
	{"WSYE", 4, 162465},
	{"UTSJ", 4, 162466},
	{"UJAM", 4, 162467},
	{"TCYW", 4, 162468},
	{"RPSV", 4, 162469},
	{"REUI", 4, 162470},
	{"OPPC", 4, 162471},
	{"OLMR", 4, 162472},
	{"NYPS", 4, 162473},
	{"NDPD", 4, 162474},
	{"KNEG", 4, 162475},
	{"IACF", 4, 162476},
	{"HUYA", 4, 162477},
	{"FJUV", 4, 162478},
	{"FAXW", 4, 162479},
	{"ESPB", 4, 162480},
	{"EGDA", 4, 162481},
	{"DAEF", 4, 162482},
	{"CWEI", 4, 162483},
	{"BHAY", 4, 162484},
	{"ADDG", 4, 162485},
	{"MIFEPRISTONE", 12, 162486},
	{"COMORBIDITIES", 13, 162487},
	{"BILLOWS", 7, 162488},
	{"EIDSON", 6, 162489},
	{"CADDYSHACK", 10, 162490},
	{"RFIDINSIGHTS", 12, 162491},
	{"UNCONDITIONED", 13, 162492},
	{"FINGERPRINTED", 13, 162493},
	{"WALLEYES", 8, 162494},
	{"AEROPORT", 8, 162495},
	{"DEMUTH", 6, 162496},
	{"GLIRES", 6, 162497},
	{"RUGELEY", 7, 162498},
	{"FXINT", 5, 162499},
	{"BIENS", 5, 162500},
	{"KEILOR", 6, 162501},
	{"EADIE", 5, 162502},
	{"LOUVERED", 8, 162503},
	{"CARTED", 6, 162504},
	{"CAITANYA", 8, 162505},
	{"WBF", 3, 162506},
	{"FOOTSIE", 7, 162507},
	{"CLOVERS", 7, 162508},
	{"AABB", 4, 162509},
	{"SPEAKON", 7, 162510},
	{"WEEKNIGHTS", 10, 162511},
	{"TRADEABLE", 9, 162512},
	{"SHANNARA", 8, 162513},
	{"DETWEILER", 9, 162514},
	{"LEOL", 4, 162515},
	{"ANTICHOLINERGIC", 15, 162516},
	{"VALENCIANA", 10, 162517},
	{"CHURNS", 6, 162518},
	{"MUTILATE", 8, 162519},
	{"MATANUSKA", 9, 162520},
	{"PVG", 3, 162521},
	{"DESPOTS", 7, 162522},
	{"IVORIAN", 7, 162523},
	{"BALOO", 5, 162524},
	{"INTERESSIEREN", 13, 162525},
	{"STUMPAGE", 8, 162526},
	{"RAPPORTO", 8, 162527},
	{"GLARUS", 6, 162528},
	{"NAZAR", 5, 162529},
	{"HOLLINGWORTH", 12, 162530},
	{"AVRAM", 5, 162531},
	{"ZDAN", 4, 162532},
	{"WUHA", 4, 162533},
	{"UMOD", 4, 162534},
	{"TMRT", 4, 162535},
	{"TAGP", 4, 162536},
	{"SUMF", 4, 162537},
	{"PKEL", 4, 162538},
	{"NIRM", 4, 162539},
	{"NDXM", 4, 162540},
	{"NDPG", 4, 162541},
	{"MAEC", 4, 162542},
	{"KBOB", 4, 162543},
	{"JOUL", 4, 162544},
	{"JALS", 4, 162545},
	{"IKAU", 4, 162546},
	{"DOSK", 4, 162547},
	{"CKUM", 4, 162548},
	{"HEALTHINSITE", 12, 162549},
	{"FOURNET", 7, 162550},
	{"WHITTY", 6, 162551},
	{"MOMMIE", 6, 162552},
	{"GNAW", 4, 162553},
	{"RASBERRY", 8, 162554},
	{"TAMRA", 5, 162555},
	{"MOTORCAR", 8, 162556},
	{"HYDROXYAPATITE", 14, 162557},
	{"BANDIED", 7, 162558},
	{"WATKINSON", 9, 162559},
	{"LIEGT", 5, 162560},
	{"HETERODIMER", 11, 162561},
	{"IRBS", 4, 162562},
	{"OLTP", 4, 162563},
	{"GAMERZ", 6, 162564},
	{"DEVELOPMEN", 10, 162565},
	{"DESROSIERS", 10, 162566},
	{"SKILLSOFT", 9, 162567},
	{"CITYINSIDER", 11, 162568},
	{"CPVC", 4, 162569},
	{"SCHTICK", 7, 162570},
	{"TOPIRAMATE", 10, 162571},
	{"MEMCACHED", 9, 162572},
	{"WHINEY", 6, 162573},
	{"PIPETTING", 9, 162574},
	{"WOLK", 4, 162575},
	{"AMPHIBIA", 8, 162576},
	{"WINLINE", 7, 162577},
	{"VINDEN", 6, 162578},
	{"INDUCERS", 8, 162579},
	{"HRAKA", 5, 162580},
	{"SBCS", 4, 162581},
	{"KABLE", 5, 162582},
	{"SPATTER", 7, 162583},
	{"RIJK", 4, 162584},
	{"WEIHNACHTEN", 11, 162585},
	{"MVFR", 4, 162586},
	{"GUARDRAILS", 10, 162587},
	{"COLLIMATED", 10, 162588},
	{"POSTPROCESSING", 14, 162589},
	{"TEFC", 4, 162590},
	{"INFOHUB", 7, 162591},
	{"FAILTE", 6, 162592},
	{"ONLUNE", 6, 162593},
	{"UTILITES", 8, 162594},
	{"PERVERSELY", 10, 162595},
	{"EROX", 4, 162596},
	{"CHROMIC", 7, 162597},
	{"FOXE", 4, 162598},
	{"FUDAN", 5, 162599},
	{"REBUTTABLE", 10, 162600},
	{"DEROSA", 6, 162601},
	{"BORS", 4, 162602},
	{"STABLER", 7, 162603},
	{"BODYFAT", 7, 162604},
	{"WONDEROUS", 9, 162605},
	{"DUNBARTON", 9, 162606},
	{"EDOC", 4, 162607},
	{"WSIGN", 5, 162608},
	{"BARTSCH", 7, 162609},
	{"GORDINI", 7, 162610},
	{"TRANSFIGURED", 12, 162611},
	{"KFILE", 5, 162612},
	{"RRF", 3, 162613},
	{"ARKADY", 6, 162614},
	{"EXCRETORY", 9, 162615},
	{"TYPIFIES", 8, 162616},
	{"YROE", 4, 162617},
	{"YIMO", 4, 162618},
	{"WTOJ", 4, 162619},
	{"VSAY", 4, 162620},
	{"TVED", 4, 162621},
	{"RTEQ", 4, 162622},
	{"RPEW", 4, 162623},
	{"RJAL", 4, 162624},
	{"RGDP", 4, 162625},
	{"PAXS", 4, 162626},
	{"MOCL", 4, 162627},
	{"LKYS", 4, 162628},
	{"LGOH", 4, 162629},
	{"GWEM", 4, 162630},
	{"GPSU", 4, 162631},
	{"GOBV", 4, 162632},
	{"GIPR", 4, 162633},
	{"FHUB", 4, 162634},
	{"FFOT", 4, 162635},
	{"CSIZ", 4, 162636},
	{"CHZO", 4, 162637},
	{"BSRO", 4, 162638},
	{"AUXC", 4, 162639},
	{"VACCARO", 7, 162640},
	{"CLEARANCEWANT", 13, 162641},
	{"WATERSLIDE", 10, 162642},
	{"SORY", 4, 162643},
	{"DAUER", 5, 162644},
	{"FELONIOUS", 9, 162645},
	{"MASSEURS", 8, 162646},
	{"CITRA", 5, 162647},
	{"CHICKADEES", 10, 162648},
	{"AVANZADA", 8, 162649},
	{"THERMOPHILIC", 12, 162650},
	{"SMITHEREENS", 11, 162651},
	{"BRANDER", 7, 162652},
	{"HALLBERG", 8, 162653},
	{"STRATEGAETH", 11, 162654},
	{"OHASHI", 6, 162655},
	{"MANITOULIN", 10, 162656},
	{"TRANSPIRES", 10, 162657},
	{"FRUITA", 6, 162658},
	{"LOVINGTON", 9, 162659},
	{"QUIZZICAL", 9, 162660},
	{"KARRIERE", 8, 162661},
	{"TRANSCRIPTOME", 13, 162662},
	{"NCTC", 4, 162663},
	{"MAXILLA", 7, 162664},
	{"PECHANGA", 8, 162665},
	{"COUPER", 6, 162666},
	{"INFORMERS", 9, 162667},
	{"DIARRHEAL", 9, 162668},
	{"IAFD", 4, 162669},
	{"BOSER", 5, 162670},
	{"TOORAK", 6, 162671},
	{"WEATHERHEAD", 11, 162672},
	{"RESENTMENTS", 11, 162673},
	{"SELFHELP", 8, 162674},
	{"MONOCHROMATOR", 13, 162675},
	{"OPPORTUNTIES", 12, 162676},
	{"JALECO", 6, 162677},
	{"FUSXION", 7, 162678},
	{"KUMQUAT", 7, 162679},
	{"KEVORKIAN", 9, 162680},
	{"OHRID", 5, 162681},
	{"INTERNATIONALIZE", 16, 162682},
	{"ARCHDALE", 8, 162683},
	{"GRACEVILLE", 10, 162684},
	{"BRAQUE", 6, 162685},
	{"CAGING", 6, 162686},
	{"PATCHER", 7, 162687},
	{"DALTONS", 7, 162688},
	{"TERNATIONAL", 11, 162689},
	{"VATICANO", 8, 162690},
	{"DUNBLANE", 8, 162691},
	{"BOLEH", 5, 162692},
	{"POCK", 4, 162693},
	{"SWAPP", 5, 162694},
	{"SERR", 4, 162695},
	{"ZDEN", 4, 162696},
	{"YCAE", 4, 162697},
	{"WWSA", 4, 162698},
	{"UYSJ", 4, 162699},
	{"TGAD", 4, 162700},
	{"SUMC", 4, 162701},
	{"RLMO", 4, 162702},
	{"OJUV", 4, 162703},
	{"NBUK", 4, 162704},
	{"MNUR", 4, 162705},
	{"LZAH", 4, 162706},
	{"KUDI", 4, 162707},
	{"KOSL", 4, 162708},
	{"KOIC", 4, 162709},
	{"GAMT", 4, 162710},
	{"EUZB", 4, 162711},
	{"ERGJ", 4, 162712},
	{"CBYS", 4, 162713},
	{"SENSITIZE", 9, 162714},
	{"PYX", 3, 162715},
	{"BARTERED", 8, 162716},
	{"SUGARED", 7, 162717},
	{"DECORATIVES", 11, 162718},
	{"MOYLAN", 6, 162719},
	{"SCHIZO", 6, 162720},
	{"SPITTLE", 7, 162721},
	{"MCLENDON", 8, 162722},
	{"DEMERIT", 7, 162723},
	{"SHOULDST", 8, 162724},
	{"OSTERTAG", 8, 162725},
	{"POLITIKA", 8, 162726},
	{"GOVERNMENTENTERPRISE", 20, 162727},
	{"REORDERS", 8, 162728},
	{"EQUIVALENCIES", 13, 162729},
	{"CHILNET", 7, 162730},
	{"KINYARWANDA", 11, 162731},
	{"UNLIT", 5, 162732},
	{"BEHAVIORALLY", 12, 162733},
	{"LIBERALIZING", 12, 162734},
	{"PROTOCULTURE", 12, 162735},
	{"STIFLES", 7, 162736},
	{"WILLBE", 6, 162737},
	{"OPRA", 4, 162738},
	{"DIVERSI", 7, 162739},
	{"SARNOFF", 7, 162740},
	{"DESSAU", 6, 162741},
	{"JAWAD", 5, 162742},
	{"UNBIND", 6, 162743},
	{"COLCLOUGH", 9, 162744},
	{"PLAICE", 6, 162745},
	{"ROUNDNESS", 9, 162746},
	{"KRYLOV", 6, 162747},
	{"CATECHETICAL", 12, 162748},
	{"PUNCHBOWL", 9, 162749},
	{"THAPAR", 6, 162750},
	{"NATALI", 6, 162751},
	{"GROSZ", 5, 162752},
	{"ANALINGUS", 9, 162753},
	{"PYROCLASTIC", 11, 162754},
	{"NACIONES", 8, 162755},
	{"INCISORS", 8, 162756},
	{"RAMASWAMY", 9, 162757},
	{"ORKIN", 5, 162758},
	{"RAMATHIBODI", 11, 162759},
	{"PULPWOOD", 8, 162760},
	{"LIBITUM", 7, 162761},
	{"POSESSES", 8, 162762},
	{"BROMOCRIPTINE", 13, 162763},
	{"LIBM", 4, 162764},
	{"LOGSDON", 7, 162765},
	{"RAEBURN", 7, 162766},
	{"ACRIMONIOUS", 11, 162767},
	{"NAVARA", 6, 162768},
	{"CDSS", 4, 162769},
	{"SUBMINIATURE", 12, 162770},
	{"SCUFFING", 8, 162771},
	{"EDUHOUND", 8, 162772},
	{"ABBADO", 6, 162773},
	{"PULPITS", 7, 162774},
	{"ANNUITANTS", 10, 162775},
	{"FALLOWS", 7, 162776},
	{"BRITCHES", 8, 162777},
	{"ZISR", 4, 162778},
	{"WSEG", 4, 162779},
	{"WBLE", 4, 162780},
	{"WAYQ", 4, 162781},
	{"TIDW", 4, 162782},
	{"RLBR", 4, 162783},
	{"PUEN", 4, 162784},
	{"OZAP", 4, 162785},
	{"NDQI", 4, 162786},
	{"MUPH", 4, 162787},
	{"MORJ", 4, 162788},
	{"MIGI", 4, 162789},
	{"IZBA", 4, 162790},
	{"IFJE", 4, 162791},
	{"GNRI", 4, 162792},
	{"GMWA", 4, 162793},
	{"GILF", 4, 162794},
	{"FOKK", 4, 162795},
	{"EZPL", 4, 162796},
	{"ESMB", 4, 162797},
	{"ELKU", 4, 162798},
	{"EBME", 4, 162799},
	{"DOCW", 4, 162800},
	{"DDEO", 4, 162801},
	{"AEMU", 4, 162802},
	{"WARDING", 7, 162803},
	{"GETWIDTH", 8, 162804},
	{"UNBUTTONED", 10, 162805},
	{"SPCT", 4, 162806},
	{"BROT", 4, 162807},
	{"XDVI", 4, 162808},
	{"COASE", 5, 162809},
	{"HEINZE", 6, 162810},
	{"PSYCO", 5, 162811},
	{"HELMINTH", 8, 162812},
	{"GESTURAL", 8, 162813},
	{"ROTANA", 6, 162814},
	{"PERFUMERS", 9, 162815},
	{"RICES", 5, 162816},
	{"ROSEBERY", 8, 162817},
	{"RINGEN", 6, 162818},
	{"TYKE", 4, 162819},
	{"ADRENOCORTICAL", 14, 162820},
	{"ABACHA", 6, 162821},
	{"MELANESIAN", 10, 162822},
	{"WADDEN", 6, 162823},
	{"KOGAL", 5, 162824},
	{"MICHAELANGELO", 13, 162825},
	{"PURPOSIVE", 9, 162826},
	{"NONALCOHOLIC", 12, 162827},
	{"MODERNO", 7, 162828},
	{"EIFEL", 5, 162829},
	{"PHARMING", 8, 162830},
	{"NEUROCHEMICAL", 13, 162831},
	{"NASUWT", 6, 162832},
	{"FROLICS", 7, 162833},
	{"COMMODES", 8, 162834},
	{"RODIER", 6, 162835},
	{"IMAGESHOP", 9, 162836},
	{"DOORSTOP", 8, 162837},
	{"GROAT", 5, 162838},
	{"BFPO", 4, 162839},
	{"INTNL", 5, 162840},
	{"TRUAX", 5, 162841},
	{"CRUSIES", 7, 162842},
	{"BPAY", 4, 162843},
	{"PREFERITI", 9, 162844},
	{"GHOSTVIEW", 9, 162845},
	{"TROPICALIS", 10, 162846},
	{"MLUG", 4, 162847},
	{"LISTOWEL", 8, 162848},
	{"GALLOPED", 8, 162849},
	{"WINDOWPANE", 10, 162850},
	{"COLLOQ", 6, 162851},
	{"RETOUCHPRO", 10, 162852},
	{"MATINS", 6, 162853},
	{"HOMEBREWING", 11, 162854},
	{"BRAWLER", 7, 162855},
	{"HIROAKI", 7, 162856},
	{"COOPERATOR", 10, 162857},
	{"AIGLE", 5, 162858},
	{"INTUITIONISTIC", 14, 162859},
	{"BIRDBATHS", 9, 162860},
	{"HOSTINGCATALOG", 14, 162861},
	{"RAJPUT", 6, 162862},
	{"ZLOV", 4, 162863},
	{"WEBV", 4, 162864},
	{"SROV", 4, 162865},
	{"SRDA", 4, 162866},
	{"SMRK", 4, 162867},
	{"PEYS", 4, 162868},
	{"LSEK", 4, 162869},
	{"LRAV", 4, 162870},
	{"LOYB", 4, 162871},
	{"LJAV", 4, 162872},
	{"LCWH", 4, 162873},
	{"LANQ", 4, 162874},
	{"KAYN", 4, 162875},
	{"HYSW", 4, 162876},
	{"GIMS", 4, 162877},
	{"GILP", 4, 162878},
	{"FWAC", 4, 162879},
	{"NETUI", 5, 162880},
	{"FORMES", 6, 162881},
	{"BALAD", 5, 162882},
	{"BOASTFULLY", 10, 162883},
	{"RINDGE", 6, 162884},
	{"MALADAPTIVE", 11, 162885},
	{"HEISEY", 6, 162886},
	{"CYF", 3, 162887},
	{"FAXPHONE", 8, 162888},
	{"SCHEETZ", 7, 162889},
	{"CREASY", 6, 162890},
	{"AMIGAOS", 7, 162891},
	{"KRIPALU", 7, 162892},
	{"PSYCHEDELICS", 12, 162893},
	{"MACDONNELL", 10, 162894},
	{"FENCERS", 7, 162895},
	{"PAMUKKALE", 9, 162896},
	{"PAWLING", 7, 162897},
	{"NWISWEB", 7, 162898},
	{"SAVIO", 5, 162899},
	{"ONILNE", 6, 162900},
	{"BELLOWING", 9, 162901},
	{"ABORIGINE", 9, 162902},
	{"DEPRESSES", 9, 162903},
	{"FINALPREFERENCES", 16, 162904},
	{"SAKIC", 5, 162905},
	{"QUICKVIEW", 9, 162906},
	{"PEARLIZED", 9, 162907},
	{"MONUC", 5, 162908},
	{"RAVENSCROFT", 11, 162909},
	{"PLATON", 6, 162910},
	{"HOLSWORTHY", 10, 162911},
	{"RUNSERVICES", 11, 162912},
	{"PLAG", 4, 162913},
	{"OPENSCOTLAND", 12, 162914},
	{"SPRINGTOWN", 10, 162915},
	{"PLAYNOW", 7, 162916},
	{"LEMBURG", 7, 162917},
	{"CARLINGFORD", 11, 162918},
	{"FLUO", 4, 162919},
	{"KARCH", 5, 162920},
	{"INFADELS", 8, 162921},
	{"ARCHS", 5, 162922},
	{"ESCL", 4, 162923},
	{"DIETPILLS", 9, 162924},
	{"LUTEA", 5, 162925},
	{"NYUNT", 5, 162926},
	{"PITTSYLVANIA", 12, 162927},
	{"WHATSONWHEN", 11, 162928},
	{"PICKEL", 6, 162929},
	{"MAKTOUM", 7, 162930},
	{"JANCIS", 6, 162931},
	{"TYLOR", 5, 162932},
	{"BIGNUM", 6, 162933},
	{"POWERSTROKE", 11, 162934},
	{"ABHORRENCE", 10, 162935},
	{"RETESTING", 9, 162936},
	{"PELLER", 6, 162937},
	{"BRAVURA", 7, 162938},
	{"PROLIFEBLOGS", 12, 162939},
	{"BULLDOZED", 9, 162940},
	{"ZADINA", 6, 162941},
	{"LUXEMBOURGISH", 13, 162942},
	{"FATHEAD", 7, 162943},
	{"NEEDLEMAN", 9, 162944},
	{"SHEERS", 6, 162945},
	{"SHAVUOT", 7, 162946},
	{"MILLIKAN", 8, 162947},
	{"OSTROWSKI", 9, 162948},
	{"MANORCARE", 9, 162949},
	{"ZSPO", 4, 162950},
	{"YPAW", 4, 162951},
	{"YAXI", 4, 162952},
	{"VUSE", 4, 162953},
	{"VDST", 4, 162954},
	{"SMRL", 4, 162955},
	{"POSW", 4, 162956},
	{"PMDI", 4, 162957},
	{"MBYJ", 4, 162958},
	{"LSNY", 4, 162959},
	{"LFTU", 4, 162960},
	{"LDAO", 4, 162961},
	{"KEEU", 4, 162962},
	{"GDPP", 4, 162963},
	{"GAVR", 4, 162964},
	{"FYOD", 4, 162965},
	{"FTJO", 4, 162966},
	{"FFVE", 4, 162967},
	{"FFAE", 4, 162968},
	{"CAAU", 4, 162969},
	{"KRAIG", 5, 162970},
	{"UPROMISE", 8, 162971},
	{"TABINDEX", 8, 162972},
	{"REDICK", 6, 162973},
	{"VERBO", 5, 162974},
	{"BIOENERGETICS", 13, 162975},
	{"MULTISET", 8, 162976},
	{"MOREX", 5, 162977},
	{"LAWMAKING", 9, 162978},
	{"MARKETA", 7, 162979},
	{"GOWRIE", 6, 162980},
	{"ENURESIS", 8, 162981},
	{"RIVINGTON", 9, 162982},
	{"GLEEVEC", 7, 162983},
	{"REVALUED", 8, 162984},
	{"REPLICABLE", 10, 162985},
	{"TRIGUE", 6, 162986},
	{"FASANO", 6, 162987},
	{"MUSICMAN", 8, 162988},
	{"MENTARY", 7, 162989},
	{"MESSIAEN", 8, 162990},
	{"CONTEMPORANEOUSLY", 17, 162991},
	{"SHOGHI", 6, 162992},
	{"STRIPPOKER", 10, 162993},
	{"REDSOX", 6, 162994},
	{"PADANG", 6, 162995},
	{"KAISHA", 6, 162996},
	{"ALFONS", 6, 162997},
	{"WRYLY", 5, 162998},
	{"ANDROGENIC", 10, 162999},
	{"SWEETENING", 10, 163000},
	{"WRU", 3, 163001},
	{"HOSTVOICE", 9, 163002},
	{"CROAKER", 7, 163003},
	{"NAYAR", 5, 163004},
	{"TRIALLED", 8, 163005},
	{"KHEPERA", 7, 163006},
	{"ENDCAP", 6, 163007},
	{"POLYA", 5, 163008},
	{"ECONOMICO", 9, 163009},
	{"STAPHYLOCOCCI", 13, 163010},
	{"ASHLY", 5, 163011},
	{"TQFP", 4, 163012},
	{"LOCHALSH", 8, 163013},
	{"NEXXTECH", 8, 163014},
	{"BLACKISH", 8, 163015},
	{"SETSWANA", 8, 163016},
	{"MULTILAYERS", 11, 163017},
	{"HACKWORTH", 9, 163018},
	{"VEATCH", 6, 163019},
	{"DEVLANCE", 8, 163020},
	{"VXD", 3, 163021},
	{"GORO", 4, 163022},
	{"EMME", 4, 163023},
	{"TRASTEVERE", 10, 163024},
	{"STATUT", 6, 163025},
	{"APRAXIA", 7, 163026},
	{"PTRABSTRACTBOX", 14, 163027},
	{"NUDITIES", 8, 163028},
	{"AHIMSA", 6, 163029},
	{"GRAFFITO", 8, 163030},
	{"INTERSECTORAL", 13, 163031},
	{"ZMAY", 4, 163032},
	{"ZELH", 4, 163033},
	{"XPUN", 4, 163034},
	{"XHTM", 4, 163035},
	{"WTIG", 4, 163036},
	{"UWHY", 4, 163037},
	{"UVIU", 4, 163038},
	{"UIDN", 4, 163039},
	{"RNOY", 4, 163040},
	{"PYMI", 4, 163041},
	{"OZCO", 4, 163042},
	{"NVIB", 4, 163043},
	{"NHLL", 4, 163044},
	{"MGMG", 4, 163045},
	{"LEZM", 4, 163046},
	{"JABL", 4, 163047},
	{"HMFO", 4, 163048},
	{"GGSE", 4, 163049},
	{"DWYO", 4, 163050},
	{"DUOF", 4, 163051},
	{"CKOA", 4, 163052},
	{"AVCH", 4, 163053},
	{"ASZL", 4, 163054},
	{"AKMU", 4, 163055},
	{"ACDU", 4, 163056},
	{"XJR", 3, 163057},
	{"FARTED", 6, 163058},
	{"CCIP", 4, 163059},
	{"APHORISM", 8, 163060},
	{"EXPLICITELY", 11, 163061},
	{"EMANATION", 9, 163062},
	{"NANOPUBLISHING", 14, 163063},
	{"NOLENSVILLE", 11, 163064},
	{"GROOTHUIS", 9, 163065},
	{"INOCULATE", 9, 163066},
	{"CRABAPPLE", 9, 163067},
	{"MISCREANTS", 10, 163068},
	{"FINDMOBILE", 10, 163069},
	{"JERSEYVILLE", 11, 163070},
	{"SIGIR", 5, 163071},
	{"ERENCES", 7, 163072},
	{"BRUNING", 7, 163073},
	{"BROOMALL", 8, 163074},
	{"MENSTYLE", 8, 163075},
	{"UNCTION", 7, 163076},
	{"REDAN", 5, 163077},
	{"NONMEDICAL", 10, 163078},
	{"ACCESSATLANTA", 13, 163079},
	{"AMPLICON", 8, 163080},
	{"MISFIRE", 7, 163081},
	{"BELARUSSIAN", 11, 163082},
	{"REGIE", 5, 163083},
	{"HEMAGGLUTININ", 13, 163084},
	{"DESIMONE", 8, 163085},
	{"RELEAS", 6, 163086},
	{"FINDJAVA", 8, 163087},
	{"FERSIWN", 7, 163088},
	{"CALCITRIOL", 10, 163089},
	{"VIRTUALISATION", 14, 163090},
	{"MOLTING", 7, 163091},
	{"FWBUILDER", 9, 163092},
	{"USPSTF", 6, 163093},
	{"QUESTUS", 7, 163094},
	{"ZENECA", 6, 163095},
	{"PARENCHYMAL", 11, 163096},
	{"BASSMASTER", 10, 163097},
	{"RBOT", 4, 163098},
	{"CMNTS", 5, 163099},
	{"PLACEMARKS", 10, 163100},
	{"BANES", 5, 163101},
	{"NANNOS", 6, 163102},
	{"FOGGER", 6, 163103},
	{"MASANORI", 8, 163104},
	{"LASONIC", 7, 163105},
	{"SEDRO", 5, 163106},
	{"TALBOTS", 7, 163107},
	{"SEGUIR", 6, 163108},
	{"FINDWINDOWS", 11, 163109},
	{"STEALERS", 8, 163110},
	{"NOBLEMEN", 8, 163111},
	{"ALBERTPACINO", 12, 163112},
	{"DUNSMORE", 8, 163113},
	{"TASSIMO", 7, 163114},
	{"PINSENT", 7, 163115},
	{"BANANZA", 7, 163116},
	{"FINDDEVELOPMENT", 15, 163117},
	{"FINDDISTRIBUTION", 16, 163118},
	{"YONSEI", 6, 163119},
	{"VIRTUALE", 8, 163120},
	{"BLML", 4, 163121},
	{"ROBUSTO", 7, 163122},
	{"FINDFINANCIAL", 13, 163123},
	{"BIRKETT", 7, 163124},
	{"BARQUE", 6, 163125},
	{"FINDSERVERS", 11, 163126},
	{"FINDHOSTING", 11, 163127},
	{"FINDGOVERNMENT", 14, 163128},
	{"OSKOBOINY", 9, 163129},
	{"FINDEBUSINESS", 13, 163130},
	{"FINDXSP", 7, 163131},
	{"SURBURBAN", 9, 163132},
	{"DERIDE", 6, 163133},
	{"FINDNETWORKING", 14, 163134},
	{"FINDMIDMARKET", 13, 163135},
	{"FINDSTORAGE", 11, 163136},
	{"FINDSECURITY", 12, 163137},
	{"TEACHOUT", 8, 163138},
	{"YWWW", 4, 163139},
	{"XLUT", 4, 163140},
	{"UKSU", 4, 163141},
	{"TVDO", 4, 163142},
	{"RIKM", 4, 163143},
	{"PYTE", 4, 163144},
	{"NCDO", 4, 163145},
	{"LZIN", 4, 163146},
	{"KDOI", 4, 163147},
	{"KAPT", 4, 163148},
	{"JOSP", 4, 163149},
	{"JAWB", 4, 163150},
	{"GIOD", 4, 163151},
	{"GGYD", 4, 163152},
	{"FYAB", 4, 163153},
	{"ECSF", 4, 163154},
	{"DPSI", 4, 163155},
	{"DAOL", 4, 163156},
	{"AHUF", 4, 163157},
	{"BEYROUTH", 8, 163158},
	{"NONALLOWABLE", 12, 163159},
	{"FINDSMALLBUSINESS", 17, 163160},
	{"FINDWEBSERVICES", 15, 163161},
	{"AVGFRE", 6, 163162},
	{"RUNTEST", 7, 163163},
	{"HOLUB", 5, 163164},
	{"VWXYZ", 5, 163165},
	{"FINDWHITEBOX", 12, 163166},
	{"DOGGONE", 7, 163167},
	{"NCHRP", 5, 163168},
	{"IMUM", 4, 163169},
	{"GERGELY", 7, 163170},
	{"BOLLETTINO", 10, 163171},
	{"TEMPURPEDIC", 11, 163172},
	{"LEPC", 4, 163173},
	{"KMD", 3, 163174},
	{"LOOSENS", 7, 163175},
	{"LGIC", 4, 163176},
	{"MACCALLUM", 9, 163177},
	{"RIGIDITIES", 10, 163178},
	{"DIRECTA", 7, 163179},
	{"GIROD", 5, 163180},
	{"QUERIE", 6, 163181},
	{"PRAGMATICALLY", 13, 163182},
	{"JACKSBORO", 9, 163183},
	{"ZAITSEV", 7, 163184},
	{"VALENTINI", 9, 163185},
	{"SPONTE", 6, 163186},
	{"ADRIAMYCIN", 10, 163187},
	{"VLG", 3, 163188},
	{"BEERMAT", 7, 163189},
	{"PLASTERER", 9, 163190},
	{"NEWMEXIKEN", 10, 163191},
	{"KERIKERI", 8, 163192},
	{"EBBERS", 6, 163193},
	{"LONICERA", 8, 163194},
	{"WEBRADIO", 8, 163195},
	{"CHERNOFF", 8, 163196},
	{"RUSSLAND", 8, 163197},
	{"YSTEMS", 6, 163198},
	{"LAJOS", 5, 163199},
	{"ALDEBURGH", 9, 163200},
	{"WINDSHIRT", 9, 163201},
	{"HURLBUT", 7, 163202},
	{"JULEP", 5, 163203},
	{"HOSPI", 5, 163204},
	{"ASPERGERS", 9, 163205},
	{"SPOONBILL", 9, 163206},
	{"PAYA", 4, 163207},
	{"CHENMING", 8, 163208},
	{"KAEL", 4, 163209},
	{"VOLKERDI", 8, 163210},
	{"ANRC", 4, 163211},
	{"SCHOLASTICA", 11, 163212},
	{"MICROSATELLITES", 15, 163213},
	{"REVOLUTIONISING", 15, 163214},
	{"PLAYSTATIONS", 12, 163215},
	{"KIRKE", 5, 163216},
	{"REDEPLOY", 8, 163217},
	{"MUSEI", 5, 163218},
	{"INMOBILIARIAS", 13, 163219},
	{"FARLOW", 6, 163220},
	{"LUBOMIR", 7, 163221},
	{"METAPRL", 7, 163222},
	{"CARRYOUT", 8, 163223},
	{"DPACKAGE", 8, 163224},
	{"AVBL", 4, 163225},
	{"AUMENTO", 7, 163226},
	{"ZVB", 3, 163227},
	{"WQY", 3, 163228},
	{"VZG", 3, 163229},
	{"VXG", 3, 163230},
	{"VQW", 3, 163231},
	{"VQL", 3, 163232},
	{"QPD", 3, 163233},
	{"KWZ", 3, 163234},
	{"KQF", 3, 163235},
	{"JWV", 3, 163236},
	{"CWQ", 3, 163237},
	{"MACMUSIC", 8, 163238},
	{"UNINSTALLATION", 14, 163239},
	{"YRST", 4, 163240},
	{"YCIS", 4, 163241},
	{"YALQ", 4, 163242},
	{"TAGC", 4, 163243},
	{"RCKA", 4, 163244},
	{"PBYG", 4, 163245},
	{"NLSU", 4, 163246},
	{"NEBB", 4, 163247},
	{"NDXE", 4, 163248},
	{"LTPI", 4, 163249},
	{"LHEK", 4, 163250},
	{"KYFE", 4, 163251},
	{"GPSE", 4, 163252},
	{"GHSG", 4, 163253},
	{"EGDI", 4, 163254},
	{"BLEZ", 4, 163255},
	{"FXWINDOW", 8, 163256},
	{"CALANDAR", 8, 163257},
	{"COMMEMORATIONS", 14, 163258},
	{"CAROTHERS", 9, 163259},
	{"YEHOSHUA", 8, 163260},
	{"JANEL", 5, 163261},
	{"ADVOCAAT", 8, 163262},
	{"KIRSTIN", 7, 163263},
	{"KUTZ", 4, 163264},
	{"HOUSEMAN", 8, 163265},
	{"NEWSLETTERSFORBES", 17, 163266},
	{"SOUTHARD", 8, 163267},
	{"CONFERENCESFORBES", 17, 163268},
	{"STRAKER", 7, 163269},
	{"ESPARZA", 7, 163270},
	{"SEDGES", 6, 163271},
	{"INGMARSTEIN", 11, 163272},
	{"POUNDERS", 8, 163273},
	{"BASTIDE", 7, 163274},
	{"PITILESS", 8, 163275},
	{"CASTELLANA", 10, 163276},
	{"SCLC", 4, 163277},
	{"MARKA", 5, 163278},
	{"ZWARTE", 6, 163279},
	{"DAAC", 4, 163280},
	{"HVAR", 4, 163281},
	{"DONATENOW", 9, 163282},
	{"CROSMAN", 7, 163283},
	{"SURFLINE", 8, 163284},
	{"WOOLS", 5, 163285},
	{"DOXEPIN", 7, 163286},
	{"RYLANDER", 8, 163287},
	{"ALPA", 4, 163288},
	{"PORTLY", 6, 163289},
	{"DIRECTIONALLY", 13, 163290},
	{"BLP", 3, 163291},
	{"REPLANT", 7, 163292},
	{"AEGINA", 6, 163293},
	{"NETMAIL", 7, 163294},
	{"NEUESTE", 7, 163295},
	{"WARMAN", 6, 163296},
	{"NUDEPICS", 8, 163297},
	{"SIEVING", 7, 163298},
	{"JANGLE", 6, 163299},
	{"GLENMONT", 8, 163300},
	{"DIERDRE", 7, 163301},
	{"ARSHAD", 6, 163302},
	{"SENORA", 6, 163303},
	{"LOUGHEED", 8, 163304},
	{"JARL", 4, 163305},
	{"BEAUTEOUS", 9, 163306},
	{"DRAGWAY", 7, 163307},
	{"SCAG", 4, 163308},
	{"AZNAVOUR", 8, 163309},
	{"CONVICTING", 10, 163310},
	{"DEATHWATCH", 10, 163311},
	{"VELD", 4, 163312},
	{"HOLLYOAKS", 9, 163313},
	{"TECHNOLGY", 9, 163314},
	{"HOLODECK", 8, 163315},
	{"BUJU", 4, 163316},
	{"HAZLITT", 7, 163317},
	{"ZEXP", 4, 163318},
	{"YCAC", 4, 163319},
	{"XFEA", 4, 163320},
	{"WKSG", 4, 163321},
	{"WDFO", 4, 163322},
	{"RSLL", 4, 163323},
	{"RIKC", 4, 163324},
	{"OZYG", 4, 163325},
	{"NZWA", 4, 163326},
	{"NGHC", 4, 163327},
	{"NFOB", 4, 163328},
	{"MEHD", 4, 163329},
	{"IZKI", 4, 163330},
	{"HODP", 4, 163331},
	{"EPVA", 4, 163332},
	{"EODU", 4, 163333},
	{"EDHR", 4, 163334},
	{"DCUD", 4, 163335},
	{"BYZI", 4, 163336},
	{"BBAH", 4, 163337},
	{"AWSY", 4, 163338},
	{"AUDF", 4, 163339},
	{"APAJ", 4, 163340},
	{"PATAGONIAN", 10, 163341},
	{"TORTA", 5, 163342},
	{"METABOTROPIC", 12, 163343},
	{"ENTERPR", 7, 163344},
	{"INETUTILS", 9, 163345},
	{"CHUECA", 6, 163346},
	{"ENZER", 5, 163347},
	{"ATRIARCH", 8, 163348},
	{"TRISPHOSPHATE", 13, 163349},
	{"DEANGELIS", 9, 163350},
	{"SASSARI", 7, 163351},
	{"BIOPYTHON", 9, 163352},
	{"CRYPTOSYSTEM", 12, 163353},
	{"UDM", 3, 163354},
	{"KYPROS", 6, 163355},
	{"PLOPPED", 7, 163356},
	{"OLIGOSACCHARIDE", 15, 163357},
	{"MODULARIZATION", 14, 163358},
	{"POLLENSA", 8, 163359},
	{"PLAYOUT", 7, 163360},
	{"POOKIE", 6, 163361},
	{"CONTRIVE", 8, 163362},
	{"RELEASABLE", 10, 163363},
	{"CATALYSED", 9, 163364},
	{"SCHILD", 6, 163365},
	{"APPFUSE", 7, 163366},
	{"PRAESENT", 8, 163367},
	{"TPTP", 4, 163368},
	{"MORTAGES", 8, 163369},
	{"HUGUENOTS", 9, 163370},
	{"HOSKIN", 6, 163371},
	{"BENTSEN", 7, 163372},
	{"ADVIES", 6, 163373},
	{"RODI", 4, 163374},
	{"CONCAVITY", 9, 163375},
	{"ESTIMABLE", 9, 163376},
	{"ELLORA", 6, 163377},
	{"TAGCRAWLER", 10, 163378},
	{"SCOWLED", 7, 163379},
	{"NOMOS", 5, 163380},
	{"MINISTRATION", 12, 163381},
	{"WILLET", 6, 163382},
	{"ENPC", 4, 163383},
	{"BIFOCALS", 8, 163384},
	{"FORC", 4, 163385},
	{"ROSTERED", 8, 163386},
	{"YSTYRIED", 8, 163387},
	{"CASADO", 6, 163388},
	{"PROTOS", 6, 163389},
	{"UNMOVIC", 7, 163390},
	{"SUMMATIONS", 10, 163391},
	{"CULLER", 6, 163392},
	{"ALLSORTS", 8, 163393},
	{"MAJORGEEKS", 10, 163394},
	{"FUNJET", 6, 163395},
	{"FRONTSIDE", 9, 163396},
	{"SHOUD", 5, 163397},
	{"VORONEZH", 8, 163398},
	{"TUSSOCK", 7, 163399},
	{"OPTIM", 5, 163400},
	{"WRIGGLE", 7, 163401},
	{"RADOVAN", 7, 163402},
	{"SUNOL", 5, 163403},
	{"SCLEROSING", 10, 163404},
	{"SITEMAPHELPCONTACT", 18, 163405},
	{"ASCERTAINMENT", 13, 163406},
	{"PLANETIZEN", 10, 163407},
	{"VOLATILIZATION", 14, 163408},
	{"IMPUDENT", 8, 163409},
	{"AYLESFORD", 9, 163410},
	{"ZZCL", 4, 163411},
	{"YNFO", 4, 163412},
	{"YFOG", 4, 163413},
	{"VSOF", 4, 163414},
	{"UGIR", 4, 163415},
	{"TZHU", 4, 163416},
	{"TMRL", 4, 163417},
	{"SWOK", 4, 163418},
	{"SMFI", 4, 163419},
	{"SFEV", 4, 163420},
	{"REGF", 4, 163421},
	{"PYBA", 4, 163422},
	{"POWW", 4, 163423},
	{"ORCT", 4, 163424},
	{"LUNP", 4, 163425},
	{"LFVE", 4, 163426},
	{"KYGE", 4, 163427},
	{"KAAB", 4, 163428},
	{"IXAF", 4, 163429},
	{"HOCY", 4, 163430},
	{"EXVA", 4, 163431},
	{"ESYB", 4, 163432},
	{"EDCF", 4, 163433},
	{"ECBD", 4, 163434},
	{"DCSU", 4, 163435},
	{"CCII", 4, 163436},
	{"BTIM", 4, 163437},
	{"BSAW", 4, 163438},
	{"AVSF", 4, 163439},
	{"AFIZ", 4, 163440},
	{"ENDPAD", 6, 163441},
	{"TRIAZINE", 8, 163442},
	{"FAROUDJA", 8, 163443},
	{"OPOIO", 5, 163444},
	{"IVETTE", 6, 163445},
	{"CONFIGURABILITY", 15, 163446},
	{"QUEN", 4, 163447},
	{"KEELBOAT", 8, 163448},
	{"UNIVERSITARIA", 13, 163449},
	{"INTEROPERATION", 14, 163450},
	{"SHUTTLING", 9, 163451},
	{"RARP", 4, 163452},
	{"CAPRIO", 6, 163453},
	{"WIBBLE", 6, 163454},
	{"ARCHDIOCESAN", 12, 163455},
	{"ROOP", 4, 163456},
	{"FURCAL", 6, 163457},
	{"DAMSELFLIES", 11, 163458},
	{"XLII", 4, 163459},
	{"MARCUSE", 7, 163460},
	{"FOCH", 4, 163461},
	{"MUDFLATS", 8, 163462},
	{"HERITAGES", 9, 163463},
	{"ESTEREL", 7, 163464},
	{"FREEWEBHOSTINGTALK", 18, 163465},
	{"NUMATIC", 7, 163466},
	{"SALCOMBE", 8, 163467},
	{"TORME", 5, 163468},
	{"PETTED", 6, 163469},
	{"MANNESMANN", 10, 163470},
	{"JAMAIL", 6, 163471},
	{"GREENIE", 7, 163472},
	{"ACDBMTEXT", 9, 163473},
	{"YOUSIF", 6, 163474},
	{"UKL", 3, 163475},
	{"TREELINE", 8, 163476},
	{"OPAMP", 5, 163477},
	{"DELIM", 5, 163478},
	{"PHILOMATH", 9, 163479},
	{"CYTHERIA", 8, 163480},
	{"RAINFED", 7, 163481},
	{"PRELINGER", 9, 163482},
	{"GRIOT", 5, 163483},
	{"SETGID", 6, 163484},
	{"TAKADA", 6, 163485},
	{"TRAORDINARY", 11, 163486},
	{"RWF", 3, 163487},
	{"CETERIS", 7, 163488},
	{"CODEPOINT", 9, 163489},
	{"CARTOGRAPHERS", 13, 163490},
	{"MEIST", 5, 163491},
	{"SIXWAYS", 7, 163492},
	{"MINNICK", 7, 163493},
	{"EPCOS", 5, 163494},
	{"ANDIAMO", 7, 163495},
	{"TASTERS", 7, 163496},
	{"PEMIUM", 6, 163497},
	{"TANKED", 6, 163498},
	{"DOMANI", 6, 163499},
	{"ARMLESS", 7, 163500},
	{"FFURFLEN", 8, 163501},
	{"KIRILENKO", 9, 163502},
	{"GALLER", 6, 163503},
	{"ACQUIRERS", 9, 163504},
	{"PRUDE", 5, 163505},
	{"DOMENECH", 8, 163506},
	{"ZNIC", 4, 163507},
	{"YLAX", 4, 163508},
	{"YAMR", 4, 163509},
	{"WIGT", 4, 163510},
	{"UBOO", 4, 163511},
	{"RIIL", 4, 163512},
	{"OELF", 4, 163513},
	{"NDMG", 4, 163514},
	{"MAUA", 4, 163515},
	{"LFAX", 4, 163516},
	{"LAIW", 4, 163517},
	{"KOUG", 4, 163518},
	{"HNBL", 4, 163519},
	{"HLOF", 4, 163520},
	{"GEMT", 4, 163521},
	{"EOBY", 4, 163522},
	{"EFUK", 4, 163523},
	{"EEUM", 4, 163524},
	{"DRNE", 4, 163525},
	{"AVIW", 4, 163526},
	{"AHDU", 4, 163527},
	{"BETTOR", 6, 163528},
	{"DUFFEY", 6, 163529},
	{"MATZAH", 6, 163530},
	{"CAPIRE", 6, 163531},
	{"PODESTA", 7, 163532},
	{"MATSONIC", 8, 163533},
	{"HEROICALLY", 10, 163534},
	{"WHITEHILL", 9, 163535},
	{"PEKOE", 5, 163536},
	{"MATAWAN", 7, 163537},
	{"SIFTER", 6, 163538},
	{"LPB", 3, 163539},
	{"PHOENICIANS", 11, 163540},
	{"OTAKON", 6, 163541},
	{"ENJOINING", 9, 163542},
	{"INSTANTON", 9, 163543},
	{"GANAR", 5, 163544},
	{"FAMSF", 5, 163545},
	{"WILLEN", 6, 163546},
	{"KOYAMA", 6, 163547},
	{"QUERYSTRING", 11, 163548},
	{"KAYAKER", 7, 163549},
	{"MILGRAIN", 8, 163550},
	{"SIHANOUKVILLE", 13, 163551},
	{"TEACHI", 6, 163552},
	{"PHOTOGRAPHICS", 13, 163553},
	{"AECINFO", 7, 163554},
	{"HAZLET", 6, 163555},
	{"FOODPIX", 7, 163556},
	{"VMLINUZ", 7, 163557},
	{"BELLAVISTA", 10, 163558},
	{"NAVONA", 6, 163559},
	{"DIPIETRO", 8, 163560},
	{"POTCHEFSTROOM", 13, 163561},
	{"ILLINGWORTH", 11, 163562},
	{"HUSTLED", 7, 163563},
	{"VENEMAN", 7, 163564},
	{"PATRI", 5, 163565},
	{"ISOCYANATE", 10, 163566},
	{"WASHINTON", 9, 163567},
	{"JINNY", 5, 163568},
	{"SQUAREPUSHER", 12, 163569},
	{"KWINANA", 7, 163570},
	{"SURREPTITIOUS", 13, 163571},
	{"MILLSBORO", 9, 163572},
	{"FRIENDSVILLE", 12, 163573},
	{"PETULANT", 8, 163574},
	{"HORNADY", 7, 163575},
	{"COMMUNICAT", 10, 163576},
	{"AAFUGIT", 7, 163577},
	{"MOVIMENTO", 9, 163578},
	{"BUSINE", 6, 163579},
	{"ZYRE", 4, 163580},
	{"YPOV", 4, 163581},
	{"XSOC", 4, 163582},
	{"XIFI", 4, 163583},
	{"VOPE", 4, 163584},
	{"UEOC", 4, 163585},
	{"SZLO", 4, 163586},
	{"SNUL", 4, 163587},
	{"SCOJ", 4, 163588},
	{"RRIZ", 4, 163589},
	{"PILF", 4, 163590},
	{"PEGL", 4, 163591},
	{"PEFL", 4, 163592},
	{"PBOB", 4, 163593},
	{"NPMM", 4, 163594},
	{"NDRR", 4, 163595},
	{"MYSG", 4, 163596},
	{"MBMO", 4, 163597},
	{"LPYR", 4, 163598},
	{"KNEU", 4, 163599},
	{"KFEI", 4, 163600},
	{"KEOG", 4, 163601},
	{"IZOR", 4, 163602},
	{"IUKI", 4, 163603},
	{"HDCA", 4, 163604},
	{"FRUP", 4, 163605},
	{"DYKS", 4, 163606},
	{"DTYS", 4, 163607},
	{"CHSV", 4, 163608},
	{"UNFURLED", 8, 163609},
	{"RUDGE", 5, 163610},
	{"UNICOI", 6, 163611},
	{"TEKNOR", 6, 163612},
	{"PARACLETE", 9, 163613},
	{"WICHTIG", 7, 163614},
	{"PROPRIATE", 9, 163615},
	{"INTEGRABILITY", 13, 163616},
	{"HOCHBERG", 8, 163617},
	{"KIMS", 4, 163618},
	{"SAUF", 4, 163619},
	{"OOPSLA", 6, 163620},
	{"MUKWONAGO", 9, 163621},
	{"UNDERHANDED", 11, 163622},
	{"NOTHERN", 7, 163623},
	{"NOWCAST", 7, 163624},
	{"TENTIAL", 7, 163625},
	{"RALPHS", 6, 163626},
	{"HYPOTHYROID", 11, 163627},
	{"WATARA", 6, 163628},
	{"JAFFER", 6, 163629},
	{"STYLISTICS", 10, 163630},
	{"BURRILL", 7, 163631},
	{"PIXELPAPERS", 11, 163632},
	{"SUPERTEK", 8, 163633},
	{"LEADBELLY", 9, 163634},
	{"HIBERNATING", 11, 163635},
	{"APPELBAUM", 9, 163636},
	{"SOLDI", 5, 163637},
	{"HELLBOUND", 9, 163638},
	{"ADSM", 4, 163639},
	{"EURODANCE", 9, 163640},
	{"BIOMETRY", 8, 163641},
	{"NXCARE", 6, 163642},
	{"ZOALS", 5, 163643},
	{"SKOLNICK", 8, 163644},
	{"PHYSICSANALYSIS", 15, 163645},
	{"MICROCIRCUITS", 13, 163646},
	{"IPYTHON", 7, 163647},
	{"FORTESCUE", 9, 163648},
	{"BLACKLISTING", 12, 163649},
	{"SHINGUARDS", 10, 163650},
	{"CHINAMAN", 8, 163651},
	{"ARDROSSAN", 9, 163652},
	{"MUZZY", 5, 163653},
	{"NCCC", 4, 163654},
	{"VYACHESLAV", 10, 163655},
	{"XCITE", 5, 163656},
	{"ICBA", 4, 163657},
	{"CONTAINERIZED", 13, 163658},
	{"CENTROS", 7, 163659},
	{"LVOV", 4, 163660},
	{"FOLKSY", 6, 163661},
	{"NONCHALANT", 10, 163662},
	{"POOPS", 5, 163663},
	{"ASSUMP", 6, 163664},
	{"WOLLASTON", 9, 163665},
	{"EBIZQ", 5, 163666},
	{"FIZIK", 5, 163667},
	{"DISLOYALTY", 10, 163668},
	{"BEVIN", 5, 163669},
	{"EXTCALENDAR", 11, 163670},
	{"GTECH", 5, 163671},
	{"TOBERMORY", 9, 163672},
	{"VAKNIN", 6, 163673},
	{"RANTHAMBORE", 11, 163674},
	{"WANSTEAD", 8, 163675},
	{"COMPUTEX", 8, 163676},
	{"LACONIC", 7, 163677},
	{"SOUNDBITES", 10, 163678},
	{"KAGAWA", 6, 163679},
	{"ZYDR", 4, 163680},
	{"ZMOV", 4, 163681},
	{"YPMS", 4, 163682},
	{"SVIZ", 4, 163683},
	{"RSPC", 4, 163684},
	{"POGU", 4, 163685},
	{"PDIG", 4, 163686},
	{"PCOF", 4, 163687},
	{"ORBW", 4, 163688},
	{"OPSJ", 4, 163689},
	{"OMGM", 4, 163690},
	{"NOCY", 4, 163691},
	{"NLEU", 4, 163692},
	{"NKCI", 4, 163693},
	{"NGZU", 4, 163694},
	{"MBIK", 4, 163695},
	{"KEZA", 4, 163696},
	{"HGIB", 4, 163697},
	{"FQUO", 4, 163698},
	{"FOLO", 4, 163699},
	{"FEUC", 4, 163700},
	{"EGRY", 4, 163701},
	{"BEGF", 4, 163702},
	{"METHODEN", 8, 163703},
	{"DININGCATERING", 14, 163704},
	{"BUTEO", 5, 163705},
	{"STEPP", 5, 163706},
	{"LEGWEAR", 7, 163707},
	{"AASTRA", 6, 163708},
	{"CCIM", 4, 163709},
	{"DISSENTS", 8, 163710},
	{"WESTWARDS", 9, 163711},
	{"ZHUMELL", 7, 163712},
	{"EQUIPOS", 7, 163713},
	{"SMARTDRAW", 9, 163714},
	{"FREDRIKSSON", 11, 163715},
	{"KEYER", 5, 163716},
	{"UNDERPARTS", 10, 163717},
	{"GUINEAN", 7, 163718},
	{"CHAUMONT", 8, 163719},
	{"ASKANCE", 7, 163720},
	{"POMERANTZ", 9, 163721},
	{"COMPUADD", 8, 163722},
	{"TURSER", 6, 163723},
	{"SADDLEWORTH", 11, 163724},
	{"LEYLA", 5, 163725},
	{"CEARCH", 6, 163726},
	{"MALESUADA", 9, 163727},
	{"SIGMATEK", 8, 163728},
	{"POLYAKOV", 8, 163729},
	{"MOBUTU", 6, 163730},
	{"AKTUELLEN", 9, 163731},
	{"BLIPS", 5, 163732},
	{"MISMA", 5, 163733},
	{"CRETIN", 6, 163734},
	{"CHERITON", 8, 163735},
	{"RECOUPED", 8, 163736},
	{"JAURON", 6, 163737},
	{"VLBA", 4, 163738},
	{"GEBURTSTAG", 10, 163739},
	{"KRANKS", 6, 163740},
	{"HAFER", 5, 163741},
	{"MIDATLANTIC", 11, 163742},
	{"APPLEYARD", 9, 163743},
	{"BINNEN", 6, 163744},
	{"AUDIOBLOG", 9, 163745},
	{"NATUROPATH", 10, 163746},
	{"RESTORIL", 8, 163747},
	{"AZJATKI", 7, 163748},
	{"LIVECYCLE", 9, 163749},
	{"SIKORSKI", 8, 163750},
	{"PARCELFORCE", 11, 163751},
	{"JSESSIONID", 10, 163752},
	{"FILMER", 6, 163753},
	{"PEDAGOGIES", 10, 163754},
	{"USATO", 5, 163755},
	{"UNTERGANG", 9, 163756},
	{"GOGEBIC", 7, 163757},
	{"CASTELLANI", 10, 163758},
	{"ACEVIEW", 7, 163759},
	{"CLOUSE", 6, 163760},
	{"FLYMO", 5, 163761},
	{"DARYA", 5, 163762},
	{"ZJOS", 4, 163763},
	{"WAMT", 4, 163764},
	{"VYSP", 4, 163765},
	{"UNCK", 4, 163766},
	{"UFAU", 4, 163767},
	{"UBPE", 4, 163768},
	{"RUMG", 4, 163769},
	{"OYDU", 4, 163770},
	{"OVOD", 4, 163771},
	{"NWAF", 4, 163772},
	{"MPEE", 4, 163773},
	{"MOKR", 4, 163774},
	{"LPOD", 4, 163775},
	{"KYYO", 4, 163776},
	{"FONP", 4, 163777},
	{"EMRR", 4, 163778},
	{"EICL", 4, 163779},
	{"BDRA", 4, 163780},
	{"AUMW", 4, 163781},
	{"AERY", 4, 163782},
	{"HARDON", 6, 163783},
	{"WAYPORT", 7, 163784},
	{"JANIK", 5, 163785},
	{"CARPING", 7, 163786},
	{"CHILKAT", 7, 163787},
	{"MACADDICT", 9, 163788},
	{"HASHEMI", 7, 163789},
	{"ASSAF", 5, 163790},
	{"TRIVETS", 7, 163791},
	{"PITBULLS", 8, 163792},
	{"BARONIAL", 8, 163793},
	{"EARING", 6, 163794},
	{"WINDEX", 6, 163795},
	{"STABLEFORD", 10, 163796},
	{"CHARRETTE", 9, 163797},
	{"PURVES", 6, 163798},
	{"LODOSS", 6, 163799},
	{"MIFUNE", 6, 163800},
	{"MIXINS", 6, 163801},
	{"REYE", 4, 163802},
	{"AMMONITE", 8, 163803},
	{"MADELEY", 7, 163804},
	{"SKOLL", 5, 163805},
	{"ZYME", 4, 163806},
	{"WALDBUSSER", 10, 163807},
	{"ORGE", 4, 163808},
	{"OVERBROOK", 9, 163809},
	{"SPTR", 4, 163810},
	{"JUNGHANS", 8, 163811},
	{"AFTERCOLLEGE", 12, 163812},
	{"SRPM", 4, 163813},
	{"MCVAY", 5, 163814},
	{"CINERAMA", 8, 163815},
	{"VWD", 3, 163816},
	{"LRICS", 5, 163817},
	{"DATGANIAD", 9, 163818},
	{"RACGP", 5, 163819},
	{"DENOUEMENT", 10, 163820},
	{"PKGTOOLS", 8, 163821},
	{"ARTICLEPRINT", 12, 163822},
	{"BELIED", 6, 163823},
	{"BERROCO", 7, 163824},
	{"OBLIQUITY", 9, 163825},
	{"GOLDWELL", 8, 163826},
	{"GLISH", 5, 163827},
	{"LURIA", 5, 163828},
	{"NIKONIANS", 9, 163829},
	{"NDER", 4, 163830},
	{"STICKIES", 8, 163831},
	{"RHEUMATOLOGISTS", 15, 163832},
	{"CONSONANCE", 10, 163833},
	{"ZGRA", 4, 163834},
	{"ZARN", 4, 163835},
	{"WTAC", 4, 163836},
	{"WOED", 4, 163837},
	{"WDCH", 4, 163838},
	{"VDSO", 4, 163839},
	{"UMJA", 4, 163840},
	{"SEBB", 4, 163841},
	{"RYOH", 4, 163842},
	{"RTZB", 4, 163843},
	{"PMYE", 4, 163844},
	{"OPVA", 4, 163845},
	{"NMRO", 4, 163846},
	{"MPSG", 4, 163847},
	{"LYTL", 4, 163848},
	{"LFQU", 4, 163849},
	{"IKIF", 4, 163850},
	{"ICHZ", 4, 163851},
	{"FMAO", 4, 163852},
	{"FLPA", 4, 163853},
	{"EYIR", 4, 163854},
	{"ELMB", 4, 163855},
	{"DXIN", 4, 163856},
	{"DSAJ", 4, 163857},
	{"DKUL", 4, 163858},
	{"DCAY", 4, 163859},
	{"CKYY", 4, 163860},
	{"BUDL", 4, 163861},
	{"BOOW", 4, 163862},
	{"BCDI", 4, 163863},
	{"AUXB", 4, 163864},
	{"MYNOVICA", 8, 163865},
	{"ULINE", 5, 163866},
	{"CADENZA", 7, 163867},
	{"KORTRIJK", 8, 163868},
	{"LMF", 3, 163869},
	{"SMETHPORT", 9, 163870},
	{"JOVEM", 5, 163871},
	{"EXCLUDABLE", 10, 163872},
	{"HOUSMAN", 7, 163873},
	{"TWIKIUSERAUTHENTICATION", 23, 163874},
	{"CYCLOHEXANE", 11, 163875},
	{"SATIRIC", 7, 163876},
	{"QUIVERED", 8, 163877},
	{"CLIPLESS", 8, 163878},
	{"REDSTART", 8, 163879},
	{"GAYLA", 5, 163880},
	{"BUDGIES", 7, 163881},
	{"MABEY", 5, 163882},
	{"OUTLOUD", 7, 163883},
	{"REJOINS", 7, 163884},
	{"LYNNETTE", 8, 163885},
	{"CAMELIA", 7, 163886},
	{"GRIMWOOD", 8, 163887},
	{"MENINA", 6, 163888},
	{"SANCTIMONIOUS", 13, 163889},
	{"MEARNS", 6, 163890},
	{"AOML", 4, 163891},
	{"LANNA", 5, 163892},
	{"KUMARA", 6, 163893},
	{"TUBAS", 5, 163894},
	{"HANBURY", 7, 163895},
	{"WURST", 5, 163896},
	{"WAZOO", 5, 163897},
	{"PHOSPHATIDYL", 12, 163898},
	{"EMDR", 4, 163899},
	{"DISCOASTER", 10, 163900},
	{"MINDI", 5, 163901},
	{"HORNUNG", 7, 163902},
	{"EBBS", 4, 163903},
	{"MEGIDDO", 7, 163904},
	{"ANYMETA", 7, 163905},
	{"RUBRIK", 6, 163906},
	{"GILMARTIN", 9, 163907},
	{"PEPTO", 5, 163908},
	{"ATOCHA", 6, 163909},
	{"RECUPERATING", 12, 163910},
	{"OBED", 4, 163911},
	{"PCTURES", 7, 163912},
	{"DYDDIAD", 7, 163913},
	{"BREWIN", 6, 163914},
	{"GUYER", 5, 163915},
	{"TOADSTOOL", 9, 163916},
	{"FUTUREBIOTICS", 13, 163917},
	{"DELETEDDOMAINS", 14, 163918},
	{"IMLS", 4, 163919},
	{"WHELPING", 8, 163920},
	{"SCHNAUZERS", 10, 163921},
	{"CAMERAMEN", 9, 163922},
	{"MISSIVES", 8, 163923},
	{"EZEK", 4, 163924},
	{"FLEXSCAN", 8, 163925},
	{"VERLICHTING", 11, 163926},
	{"TOXNET", 6, 163927},
	{"KESEY", 5, 163928},
	{"TVCR", 4, 163929},
	{"TLEZ", 4, 163930},
	{"RJOC", 4, 163931},
	{"RDYM", 4, 163932},
	{"PYIF", 4, 163933},
	{"PIRR", 4, 163934},
	{"PGFO", 4, 163935},
	{"NBJO", 4, 163936},
	{"MBSM", 4, 163937},
	{"LEAJ", 4, 163938},
	{"LBAM", 4, 163939},
	{"IUXI", 4, 163940},
	{"DYOC", 4, 163941},
	{"AURW", 4, 163942},
	{"AGIW", 4, 163943},
	{"BEAVERHEAD", 10, 163944},
	{"YELLIN", 6, 163945},
	{"STAMMERING", 10, 163946},
	{"BTTV", 4, 163947},
	{"LORMAN", 6, 163948},
	{"POURRAIT", 8, 163949},
	{"CUARDACH", 8, 163950},
	{"WEBSTART", 8, 163951},
	{"LECTURA", 7, 163952},
	{"XPORT", 5, 163953},
	{"RODENTICIDES", 12, 163954},
	{"LIFEV", 5, 163955},
	{"ALSTO", 5, 163956},
	{"WAKED", 5, 163957},
	{"VIDIEO", 6, 163958},
	{"SNUBS", 5, 163959},
	{"PLANTARUM", 9, 163960},
	{"WINGHAM", 7, 163961},
	{"TOPSPIN", 7, 163962},
	{"MIDPHASE", 8, 163963},
	{"STREAMBANK", 10, 163964},
	{"SCHNOOR", 7, 163965},
	{"ALTMANN", 7, 163966},
	{"NOKIAN", 6, 163967},
	{"EUROGRAPHICS", 12, 163968},
	{"WATERSTON", 9, 163969},
	{"GIRVAN", 6, 163970},
	{"DISFUNCTION", 11, 163971},
	{"CERTIFICATO", 11, 163972},
	{"ZUBER", 5, 163973},
	{"POMEROL", 7, 163974},
	{"LOGIS", 5, 163975},
	{"AQUEST", 6, 163976},
	{"SOLAIRE", 7, 163977},
	{"CONTACTAR", 9, 163978},
	{"DOSPAN", 6, 163979},
	{"MUSWELL", 7, 163980},
	{"JADU", 4, 163981},
	{"INDER", 5, 163982},
	{"ULTRAVOX", 8, 163983},
	{"MAGNIFIES", 9, 163984},
	{"ISOFLAVONE", 10, 163985},
	{"POWERUP", 7, 163986},
	{"MERCOLA", 7, 163987},
	{"GOTZ", 4, 163988},
	{"SPANSION", 8, 163989},
	{"PPQ", 3, 163990},
	{"CHILLYS", 7, 163991},
	{"ADVERBIAL", 9, 163992},
	{"CONOMIC", 7, 163993},
	{"OIML", 4, 163994},
	{"ELIMITE", 7, 163995},
	{"AGIUS", 5, 163996},
	{"GHOSTWRITER", 11, 163997},
	{"SMTPMAILHOST", 12, 163998},
	{"FOOLSCAP", 8, 163999},
	{"CELLULOSIC", 10, 164000},
	{"POPY", 4, 164001},
	{"SCHIZOPHRENICS", 14, 164002},
	{"STAIRWELLS", 10, 164003},
	{"NELSONVILLE", 11, 164004},
	{"THERESIA", 8, 164005},
	{"EVANGELIZING", 12, 164006},
	{"ZFAM", 4, 164007},
	{"YTUT", 4, 164008},
	{"YARL", 4, 164009},
	{"VCHR", 4, 164010},
	{"UKTU", 4, 164011},
	{"UASM", 4, 164012},
	{"SYGR", 4, 164013},
	{"ROPN", 4, 164014},
	{"OCKQ", 4, 164015},
	{"MSEW", 4, 164016},
	{"MPOB", 4, 164017},
	{"KVOI", 4, 164018},
	{"JOBK", 4, 164019},
	{"IOBL", 4, 164020},
	{"ESKC", 4, 164021},
	{"DPME", 4, 164022},
	{"ATPY", 4, 164023},
	{"AHMC", 4, 164024},
	{"AGCH", 4, 164025},
	{"TERRIS", 6, 164026},
	{"SORTE", 5, 164027},
	{"INULIN", 6, 164028},
	{"BRACH", 5, 164029},
	{"STRITCH", 7, 164030},
	{"SCOTTDALE", 9, 164031},
	{"ENTREGA", 7, 164032},
	{"LOCALSTATEDIR", 13, 164033},
	{"NCFTP", 5, 164034},
	{"MITTY", 5, 164035},
	{"LIMITES", 7, 164036},
	{"PAHL", 4, 164037},
	{"HEENAN", 6, 164038},
	{"ISHOW", 5, 164039},
	{"CALMA", 5, 164040},
	{"TURBOCHARGERS", 13, 164041},
	{"HOSTPAPERS", 10, 164042},
	{"FIBRINOLYSIS", 12, 164043},
	{"KUHLMANN", 8, 164044},
	{"RIGHTWARD", 9, 164045},
	{"OPINIONE", 8, 164046},
	{"AFTERNIC", 8, 164047},
	{"RUNSOLVER", 9, 164048},
	{"GUICHARD", 8, 164049},
	{"HOMETOWNS", 9, 164050},
	{"CLEAVERS", 8, 164051},
	{"CASAVANT", 8, 164052},
	{"KOHEN", 5, 164053},
	{"JAINA", 5, 164054},
	{"ALDERMASTON", 11, 164055},
	{"NAVTEQ", 6, 164056},
	{"EDEVCAFE", 8, 164057},
	{"AEROMEXICO", 10, 164058},
	{"WOLPERT", 7, 164059},
	{"SPECIALISMS", 11, 164060},
	{"ATRAC", 5, 164061},
	{"PADDIES", 7, 164062},
	{"ESOLUTIONS", 10, 164063},
	{"WRB", 3, 164064},
	{"LUGARES", 7, 164065},
	{"VJACHESLAV", 10, 164066},
	{"UNMEASURED", 10, 164067},
	{"ATOMICITY", 9, 164068},
	{"MEDIAPLAZZA", 11, 164069},
	{"VERTO", 5, 164070},
	{"TRABZON", 7, 164071},
	{"NEARCTIC", 8, 164072},
	{"PANNELL", 7, 164073},
	{"HEPATOTOXICITY", 14, 164074},
	{"KYSER", 5, 164075},
	{"ASPIN", 5, 164076},
	{"GLASTO", 6, 164077},
	{"STATUETTES", 10, 164078},
	{"XABU", 4, 164079},
	{"WIIC", 4, 164080},
	{"WIBE", 4, 164081},
	{"WEAM", 4, 164082},
	{"SZAP", 4, 164083},
	{"RDJR", 4, 164084},
	{"OKOZ", 4, 164085},
	{"OFGP", 4, 164086},
	{"MCME", 4, 164087},
	{"KUFU", 4, 164088},
	{"IAKR", 4, 164089},
	{"FAXR", 4, 164090},
	{"EDCT", 4, 164091},
	{"DPPE", 4, 164092},
	{"DLAH", 4, 164093},
	{"CSVO", 4, 164094},
	{"CGOR", 4, 164095},
	{"CEHY", 4, 164096},
	{"ATUX", 4, 164097},
	{"FOOTSTOOLS", 10, 164098},
	{"BUGG", 4, 164099},
	{"TALLMADGE", 9, 164100},
	{"SCHULTZE", 8, 164101},
	{"NUBES", 5, 164102},
	{"PROPAGATORS", 11, 164103},
	{"LEMHI", 5, 164104},
	{"BRUMBY", 6, 164105},
	{"OMNIFILE", 8, 164106},
	{"COPLANAR", 8, 164107},
	{"LADBROKE", 8, 164108},
	{"ARICA", 5, 164109},
	{"ACCM", 4, 164110},
	{"QUANTILES", 9, 164111},
	{"DEFLATIONARY", 12, 164112},
	{"PANTAGES", 8, 164113},
	{"MCGRIFF", 7, 164114},
	{"ADICIONAR", 9, 164115},
	{"MAENT", 5, 164116},
	{"CEBE", 4, 164117},
	{"ACCIPITER", 9, 164118},
	{"HARDWAREPAPERS", 14, 164119},
	{"LARGEHEARTED", 12, 164120},
	{"PEEPLES", 7, 164121},
	{"TURGEON", 7, 164122},
	{"AFLP", 4, 164123},
	{"TRICEP", 6, 164124},
	{"SCOWCROFT", 9, 164125},
	{"CANNINGTON", 10, 164126},
	{"UNGA", 4, 164127},
	{"DEFEET", 6, 164128},
	{"LUMPING", 7, 164129},
	{"AMDOCS", 6, 164130},
	{"WATKIN", 6, 164131},
	{"TABSTOP", 7, 164132},
	{"RANTED", 6, 164133},
	{"LAFOND", 6, 164134},
	{"GHILLIE", 7, 164135},
	{"EXTD", 4, 164136},
	{"JIBS", 4, 164137},
	{"NEWSTAND", 8, 164138},
	{"AZULI", 5, 164139},
	{"BESSELK", 7, 164140},
	{"SEOPAPERS", 9, 164141},
	{"OMAKE", 5, 164142},
	{"GEGEBEN", 7, 164143},
	{"CHADBOURNE", 10, 164144},
	{"WHOTEL", 6, 164145},
	{"LIBXINE", 7, 164146},
	{"CATALYZING", 10, 164147},
	{"ROMANUM", 7, 164148},
	{"URZA", 4, 164149},
	{"ZSRE", 4, 164150},
	{"XSWI", 4, 164151},
	{"VYPE", 4, 164152},
	{"UOYS", 4, 164153},
	{"TMRW", 4, 164154},
	{"SPYD", 4, 164155},
	{"SMSR", 4, 164156},
	{"RKMH", 4, 164157},
	{"RGGO", 4, 164158},
	{"PWEH", 4, 164159},
	{"OLUD", 4, 164160},
	{"NJRS", 4, 164161},
	{"MYGL", 4, 164162},
	{"MRTI", 4, 164163},
	{"LNME", 4, 164164},
	{"LABP", 4, 164165},
	{"KGIL", 4, 164166},
	{"IBUC", 4, 164167},
	{"GYAF", 4, 164168},
	{"FNOP", 4, 164169},
	{"FIDR", 4, 164170},
	{"DURL", 4, 164171},
	{"ATMW", 4, 164172},
	{"WASHINGS", 8, 164173},
	{"LUMPECTOMY", 10, 164174},
	{"OMMITTEE", 8, 164175},
	{"KELLOGGS", 8, 164176},
	{"CODENAMED", 9, 164177},
	{"PALLY", 5, 164178},
	{"PUSHTO", 6, 164179},
	{"FLORISTRY", 9, 164180},
	{"WEIGHTLESSNESS", 14, 164181},
	{"RADIOCOMMUNICATION", 18, 164182},
	{"INVOLVEMENTS", 12, 164183},
	{"EHOBBIES", 8, 164184},
	{"MATEJ", 5, 164185},
	{"NBSPHTTP", 8, 164186},
	{"SCHUSTE", 7, 164187},
	{"LIBAN", 5, 164188},
	{"SLAMDANCE", 9, 164189},
	{"SAMACHAR", 8, 164190},
	{"GUYOT", 5, 164191},
	{"CRAVENS", 7, 164192},
	{"AMPOULE", 7, 164193},
	{"WRQ", 3, 164194},
	{"COLNAGO", 7, 164195},
	{"HARBAUGH", 8, 164196},
	{"DRAGONSHARD", 11, 164197},
	{"POLYAMINES", 10, 164198},
	{"KAIBA", 5, 164199},
	{"STRUNZ", 6, 164200},
	{"FREDERIKSEN", 11, 164201},
	{"FLATWATER", 9, 164202},
	{"IYAD", 4, 164203},
	{"BRYANSTON", 9, 164204},
	{"TWINGE", 6, 164205},
	{"TABULATING", 10, 164206},
	{"PLAYAZ", 6, 164207},
	{"BENDY", 5, 164208},
	{"HUBBARDSTON", 11, 164209},
	{"CULTUS", 6, 164210},
	{"URBINA", 6, 164211},
	{"TELLURIUM", 9, 164212},
	{"ZULA", 4, 164213},
	{"CONTORTIONIST", 13, 164214},
	{"AIRLINK", 7, 164215},
	{"TRUDGING", 8, 164216},
	{"LIMESTONES", 10, 164217},
	{"MEMORIALIZE", 11, 164218},
	{"RAMSTEIN", 8, 164219},
	{"ACCOMODATES", 11, 164220},
	{"PENES", 5, 164221},
	{"DISTILLATES", 11, 164222},
	{"CAPSTAR", 7, 164223},
	{"CANTANKEROUS", 12, 164224},
	{"ROSHI", 5, 164225},
	{"NARCISSE", 8, 164226},
	{"STELLASTARR", 11, 164227},
	{"PINYON", 6, 164228},
	{"WDPL", 4, 164229},
	{"PHFI", 4, 164230},
	{"PEIW", 4, 164231},
	{"OGYJ", 4, 164232},
	{"OFIJ", 4, 164233},
	{"MNIV", 4, 164234},
	{"MMCM", 4, 164235},
	{"LPHP", 4, 164236},
	{"LGOP", 4, 164237},
	{"GMWI", 4, 164238},
	{"GGNO", 4, 164239},
	{"FYSE", 4, 164240},
	{"EMCB", 4, 164241},
	{"DYTY", 4, 164242},
	{"COEV", 4, 164243},
	{"BPOW", 4, 164244},
	{"BBAD", 4, 164245},
	{"AZLI", 4, 164246},
	{"ATWU", 4, 164247},
	{"AFIK", 4, 164248},
	{"MBMS", 4, 164249},
	{"LOVESICK", 8, 164250},
	{"BRECKSVILLE", 11, 164251},
	{"JAPANISE", 8, 164252},
	{"BOTCH", 5, 164253},
	{"CAVIEZEL", 8, 164254},
	{"DRONFIELD", 9, 164255},
	{"FEASTED", 7, 164256},
	{"REASSESSING", 11, 164257},
	{"ARIMIDEX", 8, 164258},
	{"BLONDI", 6, 164259},
	{"CNNSI", 5, 164260},
	{"TELIASONERA", 11, 164261},
	{"MCGUINN", 7, 164262},
	{"AMPANG", 6, 164263},
	{"REBUKES", 7, 164264},
	{"BLUEBELLS", 9, 164265},
	{"CARAFES", 7, 164266},
	{"TANGIPAHOA", 10, 164267},
	{"SPIRENT", 7, 164268},
	{"CGPA", 4, 164269},
	{"LILONGWE", 8, 164270},
	{"IUKA", 4, 164271},
	{"CARROM", 6, 164272},
	{"CRUISECONTROL", 13, 164273},
	{"SYMBOLISES", 10, 164274},
	{"COLQUHOUN", 9, 164275},
	{"AVISYNTH", 8, 164276},
	{"TEVET", 5, 164277},
	{"CHORA", 5, 164278},
	{"QUADRILLE", 9, 164279},
	{"ESTABROOK", 9, 164280},
	{"UNSPORTSMANLIKE", 15, 164281},
	{"INCONNU", 7, 164282},
	{"METHVEN", 7, 164283},
	{"INTERCAMBIO", 11, 164284},
	{"TEXTUTILS", 9, 164285},
	{"LIBIO", 5, 164286},
	{"GRANDDAD", 8, 164287},
	{"EARTHRISE", 9, 164288},
	{"DECEM", 5, 164289},
	{"VOCED", 5, 164290},
	{"ESDJCO", 6, 164291},
	{"LUCRETIUS", 9, 164292},
	{"DELIVERYPHENTERMINE", 19, 164293},
	{"MOUSEEVENT", 10, 164294},
	{"LONGTOWN", 8, 164295},
	{"PATANJALI", 9, 164296},
	{"SPRACH", 6, 164297},
	{"YELV", 4, 164298},
	{"TJOL", 4, 164299},
	{"OCPR", 4, 164300},
	{"NOLM", 4, 164301},
	{"NDTP", 4, 164302},
	{"MBHE", 4, 164303},
	{"IRNB", 4, 164304},
	{"IFSW", 4, 164305},
	{"HGUL", 4, 164306},
	{"HEXV", 4, 164307},
	{"GRAJ", 4, 164308},
	{"GAOW", 4, 164309},
	{"ERRN", 4, 164310},
	{"EDUX", 4, 164311},
	{"BRIQ", 4, 164312},
	{"BOUK", 4, 164313},
	{"BEMB", 4, 164314},
	{"FELIDAE", 7, 164315},
	{"QUINTANILLA", 11, 164316},
	{"EXCO", 4, 164317},
	{"TAXBRAIN", 8, 164318},
	{"PARVATI", 7, 164319},
	{"SONICALLY", 9, 164320},
	{"ARAMID", 6, 164321},
	{"NULLABLE", 8, 164322},
	{"OMMISSION", 9, 164323},
	{"SSPC", 4, 164324},
	{"JUGUETES", 8, 164325},
	{"MORALISTIC", 10, 164326},
	{"RATELOCAL", 9, 164327},
	{"DONGLES", 7, 164328},
	{"HAAKON", 6, 164329},
	{"CEPS", 4, 164330},
	{"CLINCHES", 8, 164331},
	{"WHITLOW", 7, 164332},
	{"FECHAS", 6, 164333},
	{"IHRES", 5, 164334},
	{"LOCKSLEY", 8, 164335},
	{"LEGALISED", 9, 164336},
	{"OUTSTANDINGLY", 13, 164337},
	{"BIGGIO", 6, 164338},
	{"JPGRAPH", 7, 164339},
	{"KAZORUM", 7, 164340},
	{"GRAFIKA", 7, 164341},
	{"DOCTEUR", 7, 164342},
	{"ARMORS", 6, 164343},
	{"CAMMY", 5, 164344},
	{"DILLARDS", 8, 164345},
	{"CONCIOUS", 8, 164346},
	{"COCKATIELS", 10, 164347},
	{"SYKESVILLE", 10, 164348},
	{"COMANDO", 7, 164349},
	{"DENKTASH", 8, 164350},
	{"BMM", 3, 164351},
	{"LERCHE", 6, 164352},
	{"ENERGISED", 9, 164353},
	{"TUTORIALES", 10, 164354},
	{"SEMTECH", 7, 164355},
	{"ALPH", 4, 164356},
	{"MEUBLES", 7, 164357},
	{"NEOADJUVANT", 11, 164358},
	{"DISCONNECTIONS", 14, 164359},
	{"GAYHEART", 8, 164360},
	{"CARTSHOPPING", 12, 164361},
	{"VLUCHT", 6, 164362},
	{"SUIVANTS", 8, 164363},
	{"SENSITISATION", 13, 164364},
	{"MULTISOURCE", 11, 164365},
	{"IPCP", 4, 164366},
	{"BLAUSTEIN", 9, 164367},
	{"VENEERED", 8, 164368},
	{"JUNKITZ", 7, 164369},
	{"TEKES", 5, 164370},
	{"REPP", 4, 164371},
	{"UNDERCOAT", 9, 164372},
	{"PRGM", 4, 164373},
	{"NETWORX", 7, 164374},
	{"XSMA", 4, 164375},
	{"WIJU", 4, 164376},
	{"VABR", 4, 164377},
	{"SCPL", 4, 164378},
	{"PUPD", 4, 164379},
	{"PPGR", 4, 164380},
	{"OERG", 4, 164381},
	{"MWWW", 4, 164382},
	{"LHUT", 4, 164383},
	{"KUKO", 4, 164384},
	{"KICR", 4, 164385},
	{"IURI", 4, 164386},
	{"HEXW", 4, 164387},
	{"GGYH", 4, 164388},
	{"GFIC", 4, 164389},
	{"EYDW", 4, 164390},
	{"DSTF", 4, 164391},
	{"CWOE", 4, 164392},
	{"BCRI", 4, 164393},
	{"BAUH", 4, 164394},
	{"AKFL", 4, 164395},
	{"ORGANO", 6, 164396},
	{"VECTORIZED", 10, 164397},
	{"NORDLAND", 8, 164398},
	{"SHUPP", 5, 164399},
	{"MAYWEATHER", 10, 164400},
	{"WHOME", 5, 164401},
	{"LGM", 3, 164402},
	{"BRONCHOALVEOLAR", 15, 164403},
	{"PERSOL", 6, 164404},
	{"DEACTIVATING", 12, 164405},
	{"REPRESSING", 10, 164406},
	{"CACS", 4, 164407},
	{"YELM", 4, 164408},
	{"NANOGRAM", 8, 164409},
	{"HEMATOPOIESIS", 13, 164410},
	{"PHOTOLITHOGRAPHY", 16, 164411},
	{"ENMESHED", 8, 164412},
	{"NANTERRE", 8, 164413},
	{"LEGALISE", 8, 164414},
	{"EINAUDI", 7, 164415},
	{"EDUMINE", 7, 164416},
	{"SARTORE", 7, 164417},
	{"PROTHONOTARY", 12, 164418},
	{"OBION", 5, 164419},
	{"NAVIGATIE", 9, 164420},
	{"IMPEDANCES", 10, 164421},
	{"XMLSPY", 6, 164422},
	{"CELULARES", 9, 164423},
	{"ADONTHELL", 9, 164424},
	{"BINET", 5, 164425},
	{"TATJANA", 7, 164426},
	{"UNCRITICALLY", 12, 164427},
	{"PARVUM", 6, 164428},
	{"MISHMASH", 8, 164429},
	{"FAMILIARES", 10, 164430},
	{"GOURLEY", 7, 164431},
	{"PENDERGAST", 10, 164432},
	{"PEGRAM", 6, 164433},
	{"TARBERT", 7, 164434},
	{"MITROVICA", 9, 164435},
	{"KETOACIDOSIS", 12, 164436},
	{"INICIATIVA", 10, 164437},
	{"GIDGET", 6, 164438},
	{"FUNCTIONALISM", 13, 164439},
	{"NONSTATIONARY", 13, 164440},
	{"ALBERGUES", 9, 164441},
	{"ICEBREAKERS", 11, 164442},
	{"BRITRAIL", 8, 164443},
	{"AQUAMETER", 9, 164444},
	{"SUZANA", 6, 164445},
	{"HEALTHILY", 9, 164446},
	{"STYLEWRITER", 11, 164447},
	{"ESCHEWED", 8, 164448},
	{"UTOPIAS", 7, 164449},
	{"EMBROIDERIES", 12, 164450},
	{"LOLITI", 6, 164451},
	{"BUNTINGS", 8, 164452},
	{"KBCAFE", 6, 164453},
	{"MAJIC", 5, 164454},
	{"UMNO", 4, 164455},
	{"RFX", 3, 164456},
	{"MINIBB", 6, 164457},
	{"YRTO", 4, 164458},
	{"YDSE", 4, 164459},
	{"YCHS", 4, 164460},
	{"WUAN", 4, 164461},
	{"USMR", 4, 164462},
	{"UAGI", 4, 164463},
	{"TUGB", 4, 164464},
	{"TOYF", 4, 164465},
	{"RAGC", 4, 164466},
	{"PMYC", 4, 164467},
	{"PKAN", 4, 164468},
	{"PHSU", 4, 164469},
	{"PEDQ", 4, 164470},
	{"OLHU", 4, 164471},
	{"NWYA", 4, 164472},
	{"MUIN", 4, 164473},
	{"MCTO", 4, 164474},
	{"LRAF", 4, 164475},
	{"LOYF", 4, 164476},
	{"KUFO", 4, 164477},
	{"KIDU", 4, 164478},
	{"IXAB", 4, 164479},
	{"IPHY", 4, 164480},
	{"IFYN", 4, 164481},
	{"GEYI", 4, 164482},
	{"EZGA", 4, 164483},
	{"ENKM", 4, 164484},
	{"CHTL", 4, 164485},
	{"CBCC", 4, 164486},
	{"BYDY", 4, 164487},
	{"BBAB", 4, 164488},
	{"AYSZ", 4, 164489},
	{"AWVE", 4, 164490},
	{"AORV", 4, 164491},
	{"BOOKE", 5, 164492},
	{"CRISTIANA", 9, 164493},
	{"ORTLIEB", 7, 164494},
	{"SHINGO", 6, 164495},
	{"UNROLLING", 9, 164496},
	{"HENTOFF", 7, 164497},
	{"INGENIO", 7, 164498},
	{"CELLMARGINS", 11, 164499},
	{"SONANCE", 7, 164500},
	{"LOULOU", 6, 164501},
	{"INTELLECTS", 10, 164502},
	{"FLAINE", 6, 164503},
	{"POPOVIC", 7, 164504},
	{"DIABETE", 7, 164505},
	{"BRAWLING", 8, 164506},
	{"VEUT", 4, 164507},
	{"SHOTTS", 6, 164508},
	{"KIERON", 6, 164509},
	{"GODDAM", 6, 164510},
	{"GELATINOUS", 10, 164511},
	{"TSAVORITE", 9, 164512},
	{"WINDSOCKS", 9, 164513},
	{"SCHAFF", 6, 164514},
	{"RESPONSABILIDAD", 15, 164515},
	{"MEILLEURES", 10, 164516},
	{"EPPLEY", 6, 164517},
	{"CORIO", 5, 164518},
	{"AHNENTAFEL", 10, 164519},
	{"THINKPADS", 9, 164520},
	{"HCPL", 4, 164521},
	{"CENTIMETRE", 10, 164522},
	{"ACORP", 5, 164523},
	{"SOMAN", 5, 164524},
	{"QUICKFINDER", 11, 164525},
	{"PARTITO", 7, 164526},
	{"IRONMONGERY", 11, 164527},
	{"GOOGLEPLEX", 10, 164528},
	{"CSPI", 4, 164529},
	{"ANETTA", 6, 164530},
	{"WALLPLATES", 10, 164531},
	{"GLASSCOCK", 9, 164532},
	{"HETEROCHROMATIN", 15, 164533},
	{"MONAT", 5, 164534},
	{"TEREX", 5, 164535},
	{"MERAH", 5, 164536},
	{"FIGUR", 5, 164537},
	{"SWILL", 5, 164538},
	{"GENTLEMANLY", 11, 164539},
	{"LAMOTRIGINE", 11, 164540},
	{"BODYBOARDS", 10, 164541},
	{"MERON", 5, 164542},
	{"DAIMON", 6, 164543},
	{"ZOONOSES", 8, 164544},
	{"PARTYLITE", 9, 164545},
	{"RAINDANCE", 9, 164546},
	{"UPTICK", 6, 164547},
	{"BABER", 5, 164548},
	{"VOXSON", 6, 164549},
	{"HOSPITALIST", 11, 164550},
	{"UNDERBRUSH", 10, 164551},
	{"ORANJE", 6, 164552},
	{"PEDROS", 6, 164553},
	{"ASSIM", 5, 164554},
	{"HISTOCHEMISTRY", 14, 164555},
	{"BATTICALOA", 10, 164556},
	{"WESTPARK", 8, 164557},
	{"WANTLIST", 8, 164558},
	{"BEMOAN", 6, 164559},
	{"ZZIT", 4, 164560},
	{"YAGN", 4, 164561},
	{"WYCL", 4, 164562},
	{"WENP", 4, 164563},
	{"WAKS", 4, 164564},
	{"UZHE", 4, 164565},
	{"UYGH", 4, 164566},
	{"SRDE", 4, 164567},
	{"ODSJ", 4, 164568},
	{"MWIR", 4, 164569},
	{"MMEP", 4, 164570},
	{"MFRU", 4, 164571},
	{"LURU", 4, 164572},
	{"KLUT", 4, 164573},
	{"KGOS", 4, 164574},
	{"GTED", 4, 164575},
	{"GCOE", 4, 164576},
	{"FDAU", 4, 164577},
	{"EPPH", 4, 164578},
	{"ECUD", 4, 164579},
	{"DRCL", 4, 164580},
	{"DDAZ", 4, 164581},
	{"BCSG", 4, 164582},
	{"AUPL", 4, 164583},
	{"ARLN", 4, 164584},
	{"APVI", 4, 164585},
	{"FAIRTAX", 7, 164586},
	{"DISSAPOINTING", 13, 164587},
	{"ASTHENIC", 8, 164588},
	{"WAITSFIELD", 10, 164589},
	{"SHUNTED", 7, 164590},
	{"GLIAC", 5, 164591},
	{"INFOMEDIA", 9, 164592},
	{"OFWAT", 5, 164593},
	{"FORSAKING", 9, 164594},
	{"DORDT", 5, 164595},
	{"RIGDON", 6, 164596},
	{"COUL", 4, 164597},
	{"KTVT", 4, 164598},
	{"LOGISTICALLY", 12, 164599},
	{"KNIEVEL", 7, 164600},
	{"CENTRIPETAL", 11, 164601},
	{"SHLEIFER", 8, 164602},
	{"SOUVENT", 7, 164603},
	{"HANKOOK", 7, 164604},
	{"HARIS", 5, 164605},
	{"CEREBRUM", 8, 164606},
	{"YVR", 3, 164607},
	{"JOCKSTRAP", 9, 164608},
	{"DAVA", 4, 164609},
	{"SCHRADE", 7, 164610},
	{"LENINISM", 8, 164611},
	{"DARKFALL", 8, 164612},
	{"DEFECTIONS", 10, 164613},
	{"ANDRIA", 6, 164614},
	{"MURRAH", 6, 164615},
	{"SCUBAPRO", 8, 164616},
	{"BIGBREASTLOVERS", 15, 164617},
	{"VIEJAS", 6, 164618},
	{"TUGGERANONG", 11, 164619},
	{"AUTOSHIP", 8, 164620},
	{"ARCUATE", 7, 164621},
	{"SCORPIUS", 8, 164622},
	{"ANAPHORA", 8, 164623},
	{"JCAMERON", 8, 164624},
	{"PLUMSTEAD", 9, 164625},
	{"MITTON", 6, 164626},
	{"MUNICIPIO", 9, 164627},
	{"DISCOTHEQUES", 12, 164628},
	{"TAXUS", 5, 164629},
	{"SBINDIR", 7, 164630},
	{"BLANKLEY", 8, 164631},
	{"BOBBED", 6, 164632},
	{"LCU", 3, 164633},
	{"BUTIONS", 7, 164634},
	{"DIVERSITIES", 11, 164635},
	{"GOUDEN", 6, 164636},
	{"FLATFISH", 8, 164637},
	{"FUGATE", 6, 164638},
	{"PARMIGIANO", 10, 164639},
	{"PONTUS", 6, 164640},
	{"FILEHUNGRY", 10, 164641},
	{"SHINYA", 6, 164642},
	{"PARTNERPROGRAMM", 15, 164643},
	{"NETNATION", 9, 164644},
	{"NELFINAVIR", 10, 164645},
	{"NAKNEK", 6, 164646},
	{"ERRINGTON", 9, 164647},
	{"CHATTERTON", 10, 164648},
	{"UNINTELLIGENT", 13, 164649},
	{"POGROM", 6, 164650},
	{"MONADS", 6, 164651},
	{"COOPERA", 7, 164652},
	{"XYLO", 4, 164653},
	{"VUVU", 4, 164654},
	{"VEEB", 4, 164655},
	{"UERK", 4, 164656},
	{"TOVC", 4, 164657},
	{"TAWK", 4, 164658},
	{"OXEX", 4, 164659},
	{"MJEA", 4, 164660},
	{"LMYK", 4, 164661},
	{"LFEF", 4, 164662},
	{"KYAM", 4, 164663},
	{"KMOM", 4, 164664},
	{"HMRB", 4, 164665},
	{"HLOP", 4, 164666},
	{"GIPO", 4, 164667},
	{"GAYG", 4, 164668},
	{"FTUT", 4, 164669},
	{"EPYE", 4, 164670},
	{"DWAX", 4, 164671},
	{"DSUK", 4, 164672},
	{"BCDO", 4, 164673},
	{"MALINA", 6, 164674},
	{"KAHUKU", 6, 164675},
	{"LOUDONVILLE", 11, 164676},
	{"SAKATA", 6, 164677},
	{"CANCERCHROM", 11, 164678},
	{"SPEAKOUT", 8, 164679},
	{"CARK", 4, 164680},
	{"CENTRAAL", 8, 164681},
	{"AKRO", 4, 164682},
	{"ORIGO", 5, 164683},
	{"DETONATING", 10, 164684},
	{"CRACKLES", 8, 164685},
	{"HOLIES", 6, 164686},
	{"COLLABO", 7, 164687},
	{"HUFFLEPUFF", 10, 164688},
	{"ALNICO", 6, 164689},
	{"FORTEC", 6, 164690},
	{"COULSDON", 8, 164691},
	{"BATERIA", 7, 164692},
	{"ASBJORN", 7, 164693},
	{"ANNEXING", 8, 164694},
	{"REMOUNT", 7, 164695},
	{"KINDERGARDEN", 12, 164696},
	{"VRIEND", 6, 164697},
	{"SAPIR", 5, 164698},
	{"GRANDDADDY", 10, 164699},
	{"GOOGIE", 6, 164700},
	{"ENYCE", 5, 164701},
	{"XSRC", 4, 164702},
	{"DESIGNATORS", 11, 164703},
	{"FUNDIES", 7, 164704},
	{"WASTEWATERS", 11, 164705},
	{"ASYLUMS", 7, 164706},
	{"SATIRES", 7, 164707},
	{"COFFER", 6, 164708},
	{"COSTLIEST", 9, 164709},
	{"RAVAGING", 8, 164710},
	{"MCQUAID", 7, 164711},
	{"FRIA", 4, 164712},
	{"DEPRECIATING", 12, 164713},
	{"SHARONVILLE", 11, 164714},
	{"RAREFIED", 8, 164715},
	{"CQC", 3, 164716},
	{"INITIALED", 9, 164717},
	{"NEBEL", 5, 164718},
	{"CAVETT", 6, 164719},
	{"ZAHID", 5, 164720},
	{"GLEICHZEITIG", 12, 164721},
	{"LLAWER", 6, 164722},
	{"PHPINFO", 7, 164723},
	{"CRACKIN", 7, 164724},
	{"WEBELOS", 7, 164725},
	{"VESTMENT", 8, 164726},
	{"GRIDSKIPPER", 11, 164727},
	{"ADELSON", 7, 164728},
	{"WYRD", 4, 164729},
	{"LEYES", 5, 164730},
	{"DIAERESIS", 9, 164731},
	{"SEMATECH", 8, 164732},
	{"LAZE", 4, 164733},
	{"UNBURNED", 8, 164734},
	{"DEPRECATE", 9, 164735},
	{"WIEW", 4, 164736},
	{"UUNT", 4, 164737},
	{"TIRP", 4, 164738},
	{"SYFE", 4, 164739},
	{"RHMS", 4, 164740},
	{"NUOV", 4, 164741},
	{"MDIM", 4, 164742},
	{"DYOB", 4, 164743},
	{"DYJE", 4, 164744},
	{"ATZU", 4, 164745},
	{"QUANTARAY", 9, 164746},
	{"SLOVENIJA", 9, 164747},
	{"MULTIPLICITIES", 14, 164748},
	{"TRANSCRANIAL", 12, 164749},
	{"LOOKALIKES", 10, 164750},
	{"GREATBUYBOOKS", 13, 164751},
	{"CROSSREFS", 9, 164752},
	{"REMASTERING", 11, 164753},
	{"BLUED", 5, 164754},
	{"IMAGEFOLIO", 10, 164755},
	{"ANNOTATOR", 9, 164756},
	{"KEEBLE", 6, 164757},
	{"DOOGIE", 6, 164758},
	{"DECEMBRIST", 10, 164759},
	{"UNTAR", 5, 164760},
	{"FURLING", 7, 164761},
	{"GBB", 3, 164762},
	{"MLADIC", 6, 164763},
	{"KASHA", 5, 164764},
	{"SERAIT", 6, 164765},
	{"EXPLOSIVELY", 11, 164766},
	{"PARTIALS", 8, 164767},
	{"CAHOON", 6, 164768},
	{"CYMUNEDOL", 9, 164769},
	{"PRADER", 6, 164770},
	{"FUDD", 4, 164771},
	{"CHIVALROUS", 10, 164772},
	{"SCRIBBLINGS", 11, 164773},
	{"USMA", 4, 164774},
	{"VICARS", 6, 164775},
	{"MITCHELLVILLE", 13, 164776},
	{"RATIONALIZATIONS", 16, 164777},
	{"OVERRULING", 10, 164778},
	{"DURCHSUCHEN", 11, 164779},
	{"BURDENING", 9, 164780},
	{"CARBER", 6, 164781},
	{"JUDIT", 5, 164782},
	{"TRANSONIC", 9, 164783},
	{"ETERS", 5, 164784},
	{"MINORCA", 7, 164785},
	{"GENDARMERIE", 11, 164786},
	{"XYBERNAUT", 9, 164787},
	{"SHIKATRONICS", 12, 164788},
	{"PEAPOD", 6, 164789},
	{"HYBRIDOMA", 9, 164790},
	{"WAGRAM", 6, 164791},
	{"NORMES", 6, 164792},
	{"NABC", 4, 164793},
	{"KONNTE", 6, 164794},
	{"GROENE", 6, 164795},
	{"CRYPTOZOOLOGY", 13, 164796},
	{"UNDERPOWERED", 12, 164797},
	{"LAMINATIONS", 11, 164798},
	{"CALVINO", 7, 164799},
	{"SOLITTLETIME", 12, 164800},
	{"OBSTINACY", 9, 164801},
	{"KEYWAY", 6, 164802},
	{"KHOR", 4, 164803},
	{"TELLO", 5, 164804},
	{"OMNIMEDIA", 9, 164805},
	{"FORCLOSURES", 11, 164806},
	{"PROPAGANDISTS", 13, 164807},
	{"ZECR", 4, 164808},
	{"YIOR", 4, 164809},
	{"WOBJ", 4, 164810},
	{"UINJ", 4, 164811},
	{"SLIU", 4, 164812},
	{"RRSU", 4, 164813},
	{"OMZO", 4, 164814},
	{"LSIP", 4, 164815},
	{"LPFE", 4, 164816},
	{"LFFL", 4, 164817},
	{"JRCO", 4, 164818},
	{"IDKH", 4, 164819},
	{"HUNY", 4, 164820},
	{"FSRA", 4, 164821},
	{"FLHE", 4, 164822},
	{"FBYD", 4, 164823},
	{"DJIS", 4, 164824},
	{"BOYJ", 4, 164825},
	{"AKUG", 4, 164826},
	{"AJED", 4, 164827},
	{"GALLIERS", 8, 164828},
	{"COLLARDS", 8, 164829},
	{"SOGGIORNO", 9, 164830},
	{"LANDSMAN", 8, 164831},
	{"MUZ", 3, 164832},
	{"QOTD", 4, 164833},
	{"SPURLING", 8, 164834},
	{"JANELL", 6, 164835},
	{"OBERHAUSEN", 10, 164836},
	{"BOOTSTRAPPED", 12, 164837},
	{"JETSAM", 6, 164838},
	{"RAMO", 4, 164839},
	{"MOUNTAINVIEW", 12, 164840},
	{"TOWNERS", 7, 164841},
	{"CACHONDAS", 9, 164842},
	{"SUBSAHARAN", 10, 164843},
	{"ARTPRICE", 8, 164844},
	{"LUMINOSITIES", 12, 164845},
	{"LOXTON", 6, 164846},
	{"XWAVE", 5, 164847},
	{"TELECENTRE", 10, 164848},
	{"WEDNESBURY", 10, 164849},
	{"GODHRA", 6, 164850},
	{"SMILIN", 6, 164851},
	{"LEYTONSTONE", 11, 164852},
	{"ETERM", 5, 164853},
	{"FILNER", 6, 164854},
	{"SUBPAGE", 7, 164855},
	{"FEEDWATER", 9, 164856},
	{"CONTRASTIVE", 11, 164857},
	{"KYPRO", 5, 164858},
	{"PLAMEGATE", 9, 164859},
	{"REFOCUSED", 9, 164860},
	{"LLER", 4, 164861},
	{"GREATAUPAIR", 11, 164862},
	{"FABLESS", 7, 164863},
	{"CAKED", 5, 164864},
	{"KOWALCZYK", 9, 164865},
	{"JEOPARDIZES", 11, 164866},
	{"EXUMA", 5, 164867},
	{"FGLRX", 5, 164868},
	{"STREATOR", 8, 164869},
	{"ESKDALE", 7, 164870},
	{"HABIBI", 6, 164871},
	{"CELANESE", 8, 164872},
	{"SCORESHEET", 10, 164873},
	{"ALFANO", 6, 164874},
	{"TAPCO", 5, 164875},
	{"WEBCAB", 6, 164876},
	{"WEBKING", 7, 164877},
	{"REASSURES", 9, 164878},
	{"LUTEUM", 6, 164879},
	{"DELUDE", 6, 164880},
	{"PROGRAMGUIDE", 12, 164881},
	{"PREPON", 6, 164882},
	{"SIMILES", 7, 164883},
	{"GEOCACHE", 8, 164884},
	{"ENTEBBE", 7, 164885},
	{"SPAMBOTS", 8, 164886},
	{"ZZAO", 4, 164887},
	{"ZYOF", 4, 164888},
	{"YENB", 4, 164889},
	{"VEYN", 4, 164890},
	{"USCD", 4, 164891},
	{"UARL", 4, 164892},
	{"TVSU", 4, 164893},
	{"TDCO", 4, 164894},
	{"RUKU", 4, 164895},
	{"RMYJ", 4, 164896},
	{"PTYD", 4, 164897},
	{"PPIP", 4, 164898},
	{"ONCM", 4, 164899},
	{"MOYL", 4, 164900},
	{"MIKN", 4, 164901},
	{"MGMM", 4, 164902},
	{"HUWH", 4, 164903},
	{"HRUK", 4, 164904},
	{"EYDC", 4, 164905},
	{"EMIV", 4, 164906},
	{"DINX", 4, 164907},
	{"DHUF", 4, 164908},
	{"AZLO", 4, 164909},
	{"EVOLU", 5, 164910},
	{"COLORINGS", 9, 164911},
	{"AKASAKA", 7, 164912},
	{"SHERBERT", 8, 164913},
	{"RUSHCLIFFE", 10, 164914},
	{"NEWSROUND", 9, 164915},
	{"EXSTREAM", 8, 164916},
	{"THEATRICALLY", 12, 164917},
	{"SEEME", 5, 164918},
	{"LANESBORO", 9, 164919},
	{"AHOMGALLS", 9, 164920},
	{"GRAVITAS", 8, 164921},
	{"WHEELBARROWS", 12, 164922},
	{"NOLINE", 6, 164923},
	{"LIBERIANS", 9, 164924},
	{"ENGLISHTOWN", 11, 164925},
	{"ROWSE", 5, 164926},
	{"GEEKCHAT", 8, 164927},
	{"MALORY", 6, 164928},
	{"PARMENTER", 9, 164929},
	{"MAGISTERIUM", 11, 164930},
	{"PUERTAS", 7, 164931},
	{"KOSTUNICA", 9, 164932},
	{"LAMINAT", 7, 164933},
	{"UTHMAN", 6, 164934},
	{"RECEDES", 7, 164935},
	{"WROTH", 5, 164936},
	{"ARTBEATS", 8, 164937},
	{"DIVESTMENTS", 11, 164938},
	{"NINCO", 5, 164939},
	{"SYSADMINS", 9, 164940},
	{"SCENARI", 7, 164941},
	{"MANFREDI", 8, 164942},
	{"GERAS", 5, 164943},
	{"PREGUNTA", 8, 164944},
	{"EMETIC", 6, 164945},
	{"PLOTTELE", 8, 164946},
	{"SOPWITH", 7, 164947},
	{"PERSONALI", 9, 164948},
	{"TRANSPORTA", 10, 164949},
	{"AMADA", 5, 164950},
	{"XGCC", 4, 164951},
	{"MOBIBLU", 7, 164952},
	{"HERMANSON", 9, 164953},
	{"GESTELLT", 8, 164954},
	{"MORDAUNT", 8, 164955},
	{"MECOSTA", 7, 164956},
	{"WEISEL", 6, 164957},
	{"PHOOEY", 6, 164958},
	{"CALAN", 5, 164959},
	{"POWNAL", 6, 164960},
	{"EVALS", 5, 164961},
	{"PHAGOCYTIC", 10, 164962},
	{"DEBORD", 6, 164963},
	{"STARBRIGHT", 10, 164964},
	{"LONGHAIRED", 10, 164965},
	{"HOLDE", 5, 164966},
	{"KONERKO", 7, 164967},
	{"GABARDINE", 9, 164968},
	{"LOCHS", 5, 164969},
	{"CONTRAINDICATION", 16, 164970},
	{"SEAWEEDS", 8, 164971},
	{"ALITY", 5, 164972},
	{"CVX", 3, 164973},
	{"WEBWARE", 7, 164974},
	{"METSO", 5, 164975},
	{"DUTCHER", 7, 164976},
	{"STRUCTURALIST", 13, 164977},
	{"POLKAS", 6, 164978},
	{"WLSC", 4, 164979},
	{"UZAS", 4, 164980},
	{"UYAA", 4, 164981},
	{"TAYY", 4, 164982},
	{"SBLV", 4, 164983},
	{"POOJ", 4, 164984},
	{"NOVU", 4, 164985},
	{"KAIJ", 4, 164986},
	{"INWU", 4, 164987},
	{"IGVA", 4, 164988},
	{"EDGP", 4, 164989},
	{"EBBB", 4, 164990},
	{"DXEN", 4, 164991},
	{"BYNS", 4, 164992},
	{"CAPITALE", 8, 164993},
	{"CALLIGRAPHER", 12, 164994},
	{"WERTHEIMER", 10, 164995},
	{"ADCALLS", 7, 164996},
	{"PTLIB", 5, 164997},
	{"STEAMBOATS", 10, 164998},
	{"NATURELLES", 10, 164999},
	{"SUBSTANTIATING", 14, 165000},
	{"PSYCHODRAMA", 11, 165001},
	{"LEHNER", 6, 165002},
	{"VOLCANOS", 8, 165003},
	{"JOBO", 4, 165004},
	{"CORTIJO", 7, 165005},
	{"MUTA", 4, 165006},
	{"DORMONT", 7, 165007},
	{"BAILEE", 6, 165008},
	{"TONISE", 6, 165009},
	{"TOWERED", 7, 165010},
	{"GAULEY", 6, 165011},
	{"COBBLESTONES", 12, 165012},
	{"GLAUS", 5, 165013},
	{"COONAWARRA", 10, 165014},
	{"NOSEBLEEDS", 10, 165015},
	{"MUSTAD", 6, 165016},
	{"TUBERCLE", 8, 165017},
	{"HESSER", 6, 165018},
	{"SALESMANSHIP", 12, 165019},
	{"MITHAI", 6, 165020},
	{"FASTNESS", 8, 165021},
	{"KLEMPERER", 9, 165022},
	{"CAPUANO", 7, 165023},
	{"TIFIED", 6, 165024},
	{"ELEMENTA", 8, 165025},
	{"KLEGECELL", 9, 165026},
	{"ANODIC", 6, 165027},
	{"ASISTENCIA", 10, 165028},
	{"NAUTICOMP", 9, 165029},
	{"SCHRECK", 7, 165030},
	{"CHECKSTYLE", 10, 165031},
	{"GAUTAMA", 7, 165032},
	{"UNGUIDED", 8, 165033},
	{"SUNDRIE", 7, 165034},
	{"LAOREET", 7, 165035},
	{"WEBDIARY", 8, 165036},
	{"CYFLE", 5, 165037},
	{"MOVANT", 6, 165038},
	{"KASYANOV", 8, 165039},
	{"ANASTASIOS", 10, 165040},
	{"SPECIFICA", 9, 165041},
	{"NEUGEBAUER", 10, 165042},
	{"HEALTHNET", 9, 165043},
	{"VISITEURS", 9, 165044},
	{"QFF", 3, 165045},
	{"KALL", 4, 165046},
	{"ASAMI", 5, 165047},
	{"CENTROIDS", 9, 165048},
	{"KNUCKLEHEAD", 11, 165049},
	{"COMBINABLE", 10, 165050},
	{"MISQUOTED", 9, 165051},
	{"ELEIFEND", 8, 165052},
	{"ALLEYNE", 7, 165053},
	{"WNLU", 4, 165054},
	{"VDAS", 4, 165055},
	{"UFLE", 4, 165056},
	{"TCDE", 4, 165057},
	{"TAMG", 4, 165058},
	{"SKUM", 4, 165059},
	{"SHYC", 4, 165060},
	{"SCFR", 4, 165061},
	{"ROGY", 4, 165062},
	{"RNIX", 4, 165063},
	{"PBEE", 4, 165064},
	{"PAMW", 4, 165065},
	{"OTMC", 4, 165066},
	{"OMBN", 4, 165067},
	{"NTKR", 4, 165068},
	{"NGDW", 4, 165069},
	{"LOSZ", 4, 165070},
	{"IOFG", 4, 165071},
	{"IGAK", 4, 165072},
	{"HTYG", 4, 165073},
	{"HGRU", 4, 165074},
	{"GBAH", 4, 165075},
	{"BNCO", 4, 165076},
	{"BLJA", 4, 165077},
	{"APGE", 4, 165078},
	{"ANVL", 4, 165079},
	{"ACYV", 4, 165080},
	{"ALSATIAN", 8, 165081},
	{"FILARIASIS", 10, 165082},
	{"RIBES", 5, 165083},
	{"MOUSING", 7, 165084},
	{"POLYTOPES", 9, 165085},
	{"BENTH", 5, 165086},
	{"RUNGA", 5, 165087},
	{"PALINDROMES", 11, 165088},
	{"UGGABUGGA", 9, 165089},
	{"GERRARDS", 8, 165090},
	{"KUNZE", 5, 165091},
	{"UNRIGHTEOUS", 11, 165092},
	{"CYNTHIANA", 9, 165093},
	{"SWITCHPLATE", 11, 165094},
	{"WAPELLO", 7, 165095},
	{"TORPOR", 6, 165096},
	{"XLC", 3, 165097},
	{"NANNING", 7, 165098},
	{"AFBEELDINGEN", 12, 165099},
	{"FOURTY", 6, 165100},
	{"GENDERTALK", 10, 165101},
	{"CHEVIGNON", 9, 165102},
	{"ZATIONS", 7, 165103},
	{"BURES", 5, 165104},
	{"LOGY", 4, 165105},
	{"VOCABULA", 8, 165106},
	{"HARDWICKE", 9, 165107},
	{"COMPLEXATION", 12, 165108},
	{"AESTIVUM", 8, 165109},
	{"NASUM", 5, 165110},
	{"LESER", 5, 165111},
	{"BUILTH", 6, 165112},
	{"IMPUGNED", 8, 165113},
	{"MANSOOR", 7, 165114},
	{"ORLOV", 5, 165115},
	{"CRETA", 5, 165116},
	{"DESECRATED", 10, 165117},
	{"TRANSGRESSED", 12, 165118},
	{"ESSINGTON", 9, 165119},
	{"KOJAK", 5, 165120},
	{"BAYERISCHE", 10, 165121},
	{"ABIERTO", 7, 165122},
	{"WATERMILL", 9, 165123},
	{"SINGEL", 6, 165124},
	{"BXABSTRACTBOX", 13, 165125},
	{"NAIRNSHIRE", 10, 165126},
	{"UNDERCOOKED", 11, 165127},
	{"PASSERBY", 8, 165128},
	{"MISANTHROPE", 11, 165129},
	{"BADDELEY", 8, 165130},
	{"HERTHA", 6, 165131},
	{"SCAPULA", 7, 165132},
	{"BURTS", 5, 165133},
	{"CRYOTHERAPY", 11, 165134},
	{"SINFONIETTA", 11, 165135},
	{"SHLD", 4, 165136},
	{"WAVENEY", 7, 165137},
	{"PUBLIQUES", 9, 165138},
	{"PATERNOSTER", 11, 165139},
	{"LENGUAJE", 8, 165140},
	{"VREELAND", 8, 165141},
	{"VIGNE", 5, 165142},
	{"RAVELLO", 7, 165143},
	{"ZNOW", 4, 165144},
	{"YNND", 4, 165145},
	{"WOFK", 4, 165146},
	{"RYNB", 4, 165147},
	{"OXSU", 4, 165148},
	{"ONKF", 4, 165149},
	{"LNAC", 4, 165150},
	{"LEIX", 4, 165151},
	{"KYAP", 4, 165152},
	{"KIAG", 4, 165153},
	{"IMKO", 4, 165154},
	{"EZEU", 4, 165155},
	{"EDUH", 4, 165156},
	{"EBDI", 4, 165157},
	{"EBCE", 4, 165158},
	{"DKYO", 4, 165159},
	{"DEEQ", 4, 165160},
	{"DEDZ", 4, 165161},
	{"DCPO", 4, 165162},
	{"CVEI", 4, 165163},
	{"BYNB", 4, 165164},
	{"BPTO", 4, 165165},
	{"BBSE", 4, 165166},
	{"NESTERS", 7, 165167},
	{"METHODNAME", 10, 165168},
	{"DARTON", 6, 165169},
	{"SUBARCTIC", 9, 165170},
	{"YUGA", 4, 165171},
	{"ANWENDUNGEN", 11, 165172},
	{"LAZLO", 5, 165173},
	{"TINTON", 6, 165174},
	{"DCCP", 4, 165175},
	{"RAWDON", 6, 165176},
	{"GLABRA", 6, 165177},
	{"DYNAMAT", 7, 165178},
	{"KOVAC", 5, 165179},
	{"BODNAR", 6, 165180},
	{"MINESTRONE", 10, 165181},
	{"ANNAL", 5, 165182},
	{"CHOSUN", 6, 165183},
	{"ELECTROCONVULSIVE", 17, 165184},
	{"SALIVATING", 10, 165185},
	{"KALASHNIKOV", 11, 165186},
	{"DAWSONVILLE", 11, 165187},
	{"MAMBOT", 6, 165188},
	{"BRACCO", 6, 165189},
	{"PABA", 4, 165190},
	{"GROESBECK", 9, 165191},
	{"ENDEARED", 8, 165192},
	{"APICS", 5, 165193},
	{"ARSENE", 6, 165194},
	{"DISUNITY", 8, 165195},
	{"FASHIONTRIBES", 13, 165196},
	{"BRUMFIELD", 9, 165197},
	{"CHIARK", 6, 165198},
	{"BILI", 4, 165199},
	{"PECKED", 6, 165200},
	{"BLUMENFELD", 10, 165201},
	{"NACIONALES", 10, 165202},
	{"GORILLAMASK", 11, 165203},
	{"ATHEX", 5, 165204},
	{"XDCC", 4, 165205},
	{"NAILSEA", 7, 165206},
	{"GANON", 5, 165207},
	{"CATID", 5, 165208},
	{"DONOT", 5, 165209},
	{"BANKSTON", 8, 165210},
	{"AARONSON", 8, 165211},
	{"TOUCHLINE", 9, 165212},
	{"PUKKA", 5, 165213},
	{"JONESY", 6, 165214},
	{"BALAN", 5, 165215},
	{"SIGNONSANDIEGO", 14, 165216},
	{"SOCIEDADES", 10, 165217},
	{"COLONNE", 7, 165218},
	{"BASSMAN", 7, 165219},
	{"MUMTAZ", 6, 165220},
	{"ABATTOIRS", 9, 165221},
	{"DOZED", 5, 165222},
	{"OUTSTRIPPED", 11, 165223},
	{"OUTPACING", 9, 165224},
	{"ROGGE", 5, 165225},
	{"CHALDEANS", 9, 165226},
	{"PROCESSO", 8, 165227},
	{"HYPERX", 6, 165228},
	{"SERVICESEMPLOYMENT", 18, 165229},
	{"ABRUZZI", 7, 165230},
	{"IFMA", 4, 165231},
	{"PERSEPOLIS", 10, 165232},
	{"PHYLA", 5, 165233},
	{"MORONEY", 7, 165234},
	{"AMERADA", 7, 165235},
	{"ARMAGNAC", 8, 165236},
	{"KSGENWEB", 8, 165237},
	{"YAUR", 4, 165238},
	{"WATV", 4, 165239},
	{"WALH", 4, 165240},
	{"VAPE", 4, 165241},
	{"UYUN", 4, 165242},
	{"UKOT", 4, 165243},
	{"TKOM", 4, 165244},
	{"SWAF", 4, 165245},
	{"SPMM", 4, 165246},
	{"RGPL", 4, 165247},
	{"RGAH", 4, 165248},
	{"OLMH", 4, 165249},
	{"OKYL", 4, 165250},
	{"NUMD", 4, 165251},
	{"LAHG", 4, 165252},
	{"IMBF", 4, 165253},
	{"IJOK", 4, 165254},
	{"EYKU", 4, 165255},
	{"EKEC", 4, 165256},
	{"DMOE", 4, 165257},
	{"DJED", 4, 165258},
	{"CDOG", 4, 165259},
	{"AZUY", 4, 165260},
	{"AMUH", 4, 165261},
	{"PERDU", 5, 165262},
	{"PORI", 4, 165263},
	{"REPAST", 6, 165264},
	{"RELIABLITY", 10, 165265},
	{"THERMOPOLIS", 11, 165266},
	{"SNAKING", 7, 165267},
	{"DECOMMISSION", 12, 165268},
	{"SPHYNX", 6, 165269},
	{"OLATE", 5, 165270},
	{"ATOMISTIC", 9, 165271},
	{"POSTMARKS", 9, 165272},
	{"GEMFIBROZIL", 11, 165273},
	{"BARBARELLA", 10, 165274},
	{"TRIANGULATIONS", 14, 165275},
	{"LITTELFUSE", 10, 165276},
	{"JUK", 3, 165277},
	{"RHAMES", 6, 165278},
	{"SADD", 4, 165279},
	{"SHRUBLAND", 9, 165280},
	{"EXTRON", 6, 165281},
	{"KREDIT", 6, 165282},
	{"CAMBODIANS", 10, 165283},
	{"PEYROUX", 7, 165284},
	{"LONVIG", 6, 165285},
	{"IACP", 4, 165286},
	{"MAJESTICALLY", 12, 165287},
	{"RESEAU", 6, 165288},
	{"POSSIBILE", 9, 165289},
	{"CAUL", 4, 165290},
	{"SHAPELESS", 9, 165291},
	{"BODYWEAR", 8, 165292},
	{"MAKAHA", 6, 165293},
	{"UTED", 4, 165294},
	{"VISSEN", 6, 165295},
	{"TRENDLINE", 9, 165296},
	{"QUATERNIONS", 11, 165297},
	{"NORVAL", 6, 165298},
	{"CHAVE", 5, 165299},
	{"NGCHD", 5, 165300},
	{"SYSTEMA", 7, 165301},
	{"MISCELANEOUS", 12, 165302},
	{"CLEARCUBE", 9, 165303},
	{"CONTRITE", 8, 165304},
	{"PREDATED", 8, 165305},
	{"REFLEXIVELY", 11, 165306},
	{"GAJA", 4, 165307},
	{"GROMER", 6, 165308},
	{"SCENA", 5, 165309},
	{"POSSIBILITES", 12, 165310},
	{"NUTSEDGE", 8, 165311},
	{"TOOTSIES", 8, 165312},
	{"BFM", 3, 165313},
	{"BEACHHEAD", 9, 165314},
	{"IMMACULATA", 10, 165315},
	{"DECRYPTS", 8, 165316},
	{"ANGIER", 6, 165317},
	{"ZUZANA", 6, 165318},
	{"PFFT", 4, 165319},
	{"KDEUI", 5, 165320},
	{"MANZ", 4, 165321},
	{"CARNEVALE", 9, 165322},
	{"ABSTRACTLY", 10, 165323},
	{"SHAOXING", 8, 165324},
	{"TUVA", 4, 165325},
	{"DANIE", 5, 165326},
	{"AMMOUNT", 7, 165327},
	{"YYID", 4, 165328},
	{"YIBM", 4, 165329},
	{"WLYU", 4, 165330},
	{"VLAT", 4, 165331},
	{"RUEX", 4, 165332},
	{"RSOK", 4, 165333},
	{"RHAK", 4, 165334},
	{"PMBO", 4, 165335},
	{"NUXU", 4, 165336},
	{"NDPN", 4, 165337},
	{"MSMY", 4, 165338},
	{"MMMO", 4, 165339},
	{"IDDS", 4, 165340},
	{"EVIX", 4, 165341},
	{"ESKD", 4, 165342},
	{"EPCM", 4, 165343},
	{"EKUO", 4, 165344},
	{"EKPU", 4, 165345},
	{"EKMR", 4, 165346},
	{"EGOK", 4, 165347},
	{"COYI", 4, 165348},
	{"BATK", 4, 165349},
	{"MYLOGO", 6, 165350},
	{"RYTON", 5, 165351},
	{"CABRA", 5, 165352},
	{"TEMPESTSANS", 11, 165353},
	{"NAEYC", 5, 165354},
	{"ROOME", 5, 165355},
	{"GREENPORT", 9, 165356},
	{"LIPOPHILIC", 10, 165357},
	{"CONJUNCTIVAL", 12, 165358},
	{"GPSDRIVE", 8, 165359},
	{"NONSIGNIFICANT", 14, 165360},
	{"ERLICH", 6, 165361},
	{"MALAHIDE", 8, 165362},
	{"HIGHVELD", 8, 165363},
	{"ACINETOBACTER", 13, 165364},
	{"ALIMENTAIRE", 11, 165365},
	{"SAYREVILLE", 10, 165366},
	{"POCKETSTATION", 13, 165367},
	{"BRUSHSTROKES", 12, 165368},
	{"PAGNELL", 7, 165369},
	{"GWIN", 4, 165370},
	{"CLAIRSVILLE", 11, 165371},
	{"ALVESTRAND", 10, 165372},
	{"HOILDAY", 7, 165373},
	{"OJIBWA", 6, 165374},
	{"SARRAF", 6, 165375},
	{"NURHALIZA", 9, 165376},
	{"ELMONT", 6, 165377},
	{"STUDDARD", 8, 165378},
	{"DELAMERE", 8, 165379},
	{"LUKASZ", 6, 165380},
	{"WAUSHARA", 8, 165381},
	{"LIGHTENS", 8, 165382},
	{"TWITCHES", 8, 165383},
	{"STYLEBOOK", 9, 165384},
	{"TAGCLOUD", 8, 165385},
	{"CLOMIPHENE", 10, 165386},
	{"ACCOUNTHELPABOUT", 16, 165387},
	{"DASHIELL", 8, 165388},
	{"AMBRIDGE", 8, 165389},
	{"PURSED", 6, 165390},
	{"KLEENE", 6, 165391},
	{"ANFON", 5, 165392},
	{"BALAKLAVA", 9, 165393},
	{"SNUGGLES", 8, 165394},
	{"PHOTOJOURNALISTS", 16, 165395},
	{"PANTOPRAZOLE", 12, 165396},
	{"FANTASIZING", 11, 165397},
	{"CANADACANADA", 12, 165398},
	{"VEDIOS", 6, 165399},
	{"CHARTPLOTTER", 12, 165400},
	{"BADMAN", 6, 165401},
	{"TICULARLY", 9, 165402},
	{"KRISTALLNACHT", 13, 165403},
	{"LINKDUMP", 8, 165404},
	{"CLAUSTROPHOBIA", 14, 165405},
	{"ABUTMENTS", 9, 165406},
	{"PILZ", 4, 165407},
	{"ENDZONE", 7, 165408},
	{"GLONASS", 7, 165409},
	{"VACUUMED", 8, 165410},
	{"POTATOE", 7, 165411},
	{"HTMLSPECIALCHARS", 16, 165412},
	{"TURQUIE", 7, 165413},
	{"DPX", 3, 165414},
	{"RAFTERY", 7, 165415},
	{"ISOFLURANE", 10, 165416},
	{"EMPATH", 6, 165417},
	{"PRINCIPIO", 9, 165418},
	{"IMPRESARIO", 10, 165419},
	{"TECHNOCRATS", 11, 165420},
	{"XWEN", 4, 165421},
	{"XDOW", 4, 165422},
	{"WWFI", 4, 165423},
	{"WRSQ", 4, 165424},
	{"TZSP", 4, 165425},
	{"THUJ", 4, 165426},
	{"RNGH", 4, 165427},
	{"RMSJ", 4, 165428},
	{"PRTH", 4, 165429},
	{"PHWE", 4, 165430},
	{"OZOM", 4, 165431},
	{"NVAG", 4, 165432},
	{"NOUK", 4, 165433},
	{"MHAG", 4, 165434},
	{"MEKU", 4, 165435},
	{"LSMD", 4, 165436},
	{"LPDR", 4, 165437},
	{"KJEN", 4, 165438},
	{"KHID", 4, 165439},
	{"HULB", 4, 165440},
	{"GYMB", 4, 165441},
	{"GUDI", 4, 165442},
	{"GSEW", 4, 165443},
	{"GDUK", 4, 165444},
	{"FTUM", 4, 165445},
	{"EWTG", 4, 165446},
	{"EBAW", 4, 165447},
	{"DZAK", 4, 165448},
	{"DYOL", 4, 165449},
	{"DXRA", 4, 165450},
	{"DKOC", 4, 165451},
	{"DKHO", 4, 165452},
	{"BUMK", 4, 165453},
	{"AALD", 4, 165454},
	{"COKESBURY", 9, 165455},
	{"POWERPOINTS", 11, 165456},
	{"WEBACCESS", 9, 165457},
	{"AUDIOMETRY", 10, 165458},
	{"DTPA", 4, 165459},
	{"AUTHORHOUSE", 11, 165460},
	{"ARND", 4, 165461},
	{"ALGORITHMICALLY", 15, 165462},
	{"SIMILASAN", 9, 165463},
	{"KERNELNEWBIES", 13, 165464},
	{"BALLIOL", 7, 165465},
	{"FRISBY", 6, 165466},
	{"VILMA", 5, 165467},
	{"VADUZ", 5, 165468},
	{"ENCONTRARON", 11, 165469},
	{"WATERSLIDES", 11, 165470},
	{"ENTREATED", 9, 165471},
	{"ASINIUS", 7, 165472},
	{"ROCKSTEADY", 10, 165473},
	{"MARGINALIZE", 11, 165474},
	{"JPILOT", 6, 165475},
	{"MMDB", 4, 165476},
	{"GAUDIKERNEL", 11, 165477},
	{"TRANSAT", 7, 165478},
	{"AGGRAVATES", 10, 165479},
	{"PRIMOS", 6, 165480},
	{"DESTEFANO", 9, 165481},
	{"HAVER", 5, 165482},
	{"BIZARE", 6, 165483},
	{"REDMON", 6, 165484},
	{"SAFF", 4, 165485},
	{"AMBOISE", 7, 165486},
	{"GAMED", 5, 165487},
	{"HELIOPOLIS", 10, 165488},
	{"CHEL", 4, 165489},
	{"CARUS", 5, 165490},
	{"BALERS", 6, 165491},
	{"AMIRI", 5, 165492},
	{"SHOPLET", 7, 165493},
	{"CONEJOS", 7, 165494},
	{"YRICS", 5, 165495},
	{"THROMBOEMBOLIC", 14, 165496},
	{"SMOCKING", 8, 165497},
	{"KWIATKOWSKI", 11, 165498},
	{"TROTWOOD", 8, 165499},
	{"CAROLEE", 7, 165500},
	{"CONSUMERIST", 11, 165501},
	{"COTTBUS", 7, 165502},
	{"VAAL", 4, 165503},
	{"BERZERK", 7, 165504},
	{"RIGHTEOUSLY", 11, 165505},
	{"ONEFORALL", 9, 165506},
	{"MARVELLED", 9, 165507},
	{"SPRINGFORM", 10, 165508},
	{"WDOS", 4, 165509},
	{"UJUM", 4, 165510},
	{"UEZE", 4, 165511},
	{"RYLD", 4, 165512},
	{"RSOX", 4, 165513},
	{"RJUI", 4, 165514},
	{"RBOJ", 4, 165515},
	{"ONCF", 4, 165516},
	{"NJOP", 4, 165517},
	{"NDDT", 4, 165518},
	{"LYNY", 4, 165519},
	{"IDUT", 4, 165520},
	{"ICYU", 4, 165521},
	{"HGLI", 4, 165522},
	{"FEAW", 4, 165523},
	{"EUPV", 4, 165524},
	{"DYTW", 4, 165525},
	{"ASRB", 4, 165526},
	{"EMBASE", 6, 165527},
	{"TEODORO", 7, 165528},
	{"NETNAMES", 8, 165529},
	{"DALENE", 6, 165530},
	{"FENGSHUI", 8, 165531},
	{"WHITEELO", 8, 165532},
	{"MOONIE", 6, 165533},
	{"RESIZES", 7, 165534},
	{"NEPHRON", 7, 165535},
	{"EURASIANET", 10, 165536},
	{"PREENING", 8, 165537},
	{"MPOWER", 6, 165538},
	{"CLICHY", 6, 165539},
	{"BOSTOCK", 7, 165540},
	{"UCOL", 4, 165541},
	{"CHAINRING", 9, 165542},
	{"DESTA", 5, 165543},
	{"SPEDISCI", 8, 165544},
	{"HONEOYE", 7, 165545},
	{"PUTIDA", 6, 165546},
	{"SCREEDS", 7, 165547},
	{"ETHERINGTON", 11, 165548},
	{"MAHALIA", 7, 165549},
	{"CRYPTOGRAPHICALLY", 17, 165550},
	{"SEDUCTIONS", 10, 165551},
	{"RUSHKOFF", 8, 165552},
	{"COSMETOLOGIST", 13, 165553},
	{"WEBCD", 5, 165554},
	{"SLACKTIVIST", 11, 165555},
	{"REMEDIOS", 8, 165556},
	{"GRANJA", 6, 165557},
	{"PORTUGU", 7, 165558},
	{"TANGATA", 7, 165559},
	{"DOKIC", 5, 165560},
	{"LOGI", 4, 165561},
	{"AUFGRUND", 8, 165562},
	{"BUBER", 5, 165563},
	{"MAKS", 4, 165564},
	{"WIMMERA", 7, 165565},
	{"KUEHL", 5, 165566},
	{"PROPITIOUS", 10, 165567},
	{"ARANA", 5, 165568},
	{"SEARCT", 6, 165569},
	{"COCC", 4, 165570},
	{"ORGANISATIE", 11, 165571},
	{"ALTIS", 5, 165572},
	{"WALEED", 6, 165573},
	{"WEJO", 4, 165574},
	{"UXEN", 4, 165575},
	{"UETY", 4, 165576},
	{"TKUB", 4, 165577},
	{"SGUM", 4, 165578},
	{"RGSB", 4, 165579},
	{"MNOG", 4, 165580},
	{"LMCE", 4, 165581},
	{"LIXP", 4, 165582},
	{"LIFM", 4, 165583},
	{"KSKY", 4, 165584},
	{"JVOD", 4, 165585},
	{"IOLL", 4, 165586},
	{"IIGR", 4, 165587},
	{"IBLU", 4, 165588},
	{"GUSK", 4, 165589},
	{"FMDA", 4, 165590},
	{"EWKO", 4, 165591},
	{"EFSK", 4, 165592},
	{"CISK", 4, 165593},
	{"CHAQ", 4, 165594},
	{"DOMESTICITY", 11, 165595},
	{"DASHWOOD", 8, 165596},
	{"GIGASTUDIO", 10, 165597},
	{"FANON", 5, 165598},
	{"INSURENCE", 9, 165599},
	{"APOC", 4, 165600},
	{"ALKENES", 7, 165601},
	{"SEARCHIN", 8, 165602},
	{"RAILCARS", 8, 165603},
	{"INPUTTED", 8, 165604},
	{"CHASTISE", 8, 165605},
	{"FOOR", 4, 165606},
	{"BROMINATED", 10, 165607},
	{"CANNER", 6, 165608},
	{"BREAKDANCING", 12, 165609},
	{"ZIPLOC", 6, 165610},
	{"INVETERATE", 10, 165611},
	{"PRECONDITIONER", 14, 165612},
	{"TRIMETHYL", 9, 165613},
	{"PENETRATOR", 10, 165614},
	{"MAINSTREAMED", 12, 165615},
	{"INFLIXIMAB", 10, 165616},
	{"LFM", 3, 165617},
	{"TDOC", 4, 165618},
	{"CODIMENSION", 11, 165619},
	{"WOLIN", 5, 165620},
	{"DEVAN", 5, 165621},
	{"BABYSTYLE", 9, 165622},
	{"APOMORPHINE", 11, 165623},
	{"PEACEFULNESS", 12, 165624},
	{"VIVAX", 5, 165625},
	{"FOOTS", 5, 165626},
	{"CGGGC", 5, 165627},
	{"ANGLOGOLD", 9, 165628},
	{"PRINTHEADS", 10, 165629},
	{"FISCHLER", 8, 165630},
	{"EXTOLLED", 8, 165631},
	{"UPX", 3, 165632},
	{"ELCO", 4, 165633},
	{"ISOMERIZATION", 13, 165634},
	{"PEPTIDOGLYCAN", 13, 165635},
	{"STEADICAM", 9, 165636},
	{"WINBOARD", 8, 165637},
	{"HERMANS", 7, 165638},
	{"RESTRUCTURINGS", 14, 165639},
	{"LITTERATURE", 11, 165640},
	{"FIFOS", 5, 165641},
	{"LANGLAUF", 8, 165642},
	{"SCROGGINS", 9, 165643},
	{"PONTO", 5, 165644},
	{"CHMOUEL", 7, 165645},
	{"CARNOT", 6, 165646},
	{"ZELAND", 6, 165647},
	{"ZOWI", 4, 165648},
	{"YRDI", 4, 165649},
	{"YLID", 4, 165650},
	{"VYAL", 4, 165651},
	{"TMPF", 4, 165652},
	{"SIDW", 4, 165653},
	{"PRAF", 4, 165654},
	{"PJEF", 4, 165655},
	{"ONPY", 4, 165656},
	{"MVON", 4, 165657},
	{"LDEY", 4, 165658},
	{"KHRI", 4, 165659},
	{"JUBL", 4, 165660},
	{"GUIB", 4, 165661},
	{"GGUO", 4, 165662},
	{"GAKK", 4, 165663},
	{"EVBE", 4, 165664},
	{"ETVD", 4, 165665},
	{"DMRF", 4, 165666},
	{"CYSF", 4, 165667},
	{"CGON", 4, 165668},
	{"BYAO", 4, 165669},
	{"BIWO", 4, 165670},
	{"AURR", 4, 165671},
	{"APYB", 4, 165672},
	{"HYPERHIDROSIS", 13, 165673},
	{"TIGBLOG", 7, 165674},
	{"MIFFY", 5, 165675},
	{"MARIGOLDS", 9, 165676},
	{"BYLINED", 7, 165677},
	{"PNEU", 4, 165678},
	{"MASCHINEN", 9, 165679},
	{"FGETSS", 6, 165680},
	{"BURTONATOR", 10, 165681},
	{"THOMPSONVILLE", 13, 165682},
	{"NEOUS", 5, 165683},
	{"ABSENTLY", 8, 165684},
	{"WORTLEY", 7, 165685},
	{"KASHMIRIS", 9, 165686},
	{"VANTURE", 7, 165687},
	{"SOMMERFELD", 10, 165688},
	{"TRUSTKILL", 9, 165689},
	{"PROMOCIONES", 11, 165690},
	{"PROMIS", 6, 165691},
	{"FLUOROQUINOLONES", 16, 165692},
	{"RAILGUN", 7, 165693},
	{"NATACHA", 7, 165694},
	{"SALAMA", 6, 165695},
	{"KAMIYA", 6, 165696},
	{"JOBLO", 5, 165697},
	{"LAUSD", 5, 165698},
	{"GOODENOUGH", 10, 165699},
	{"AUTOVERMIETUNG", 14, 165700},
	{"AUTOSAVE", 8, 165701},
	{"KALIN", 5, 165702},
	{"TORTOISESVN", 11, 165703},
	{"GOOLWA", 6, 165704},
	{"CADW", 4, 165705},
	{"ROADSTERS", 9, 165706},
	{"PACKETLOSS", 10, 165707},
	{"BREIT", 5, 165708},
	{"PROPOR", 6, 165709},
	{"MASAMI", 6, 165710},
	{"COPSE", 5, 165711},
	{"KEENELAND", 9, 165712},
	{"OCRACOKE", 8, 165713},
	{"CARBOHYD", 8, 165714},
	{"VWF", 3, 165715},
	{"ASPLINUX", 8, 165716},
	{"DAYANA", 6, 165717},
	{"UREASE", 6, 165718},
	{"ESPADA", 6, 165719},
	{"YKRU", 4, 165720},
	{"UBAV", 4, 165721},
	{"SPDA", 4, 165722},
	{"QLSE", 4, 165723},
	{"OGSY", 4, 165724},
	{"NNGU", 4, 165725},
	{"NDFS", 4, 165726},
	{"LNWO", 4, 165727},
	{"KOYE", 4, 165728},
	{"FALV", 4, 165729},
	{"DRUZ", 4, 165730},
	{"COBM", 4, 165731},
	{"NAZGUL", 6, 165732},
	{"MYLYRICS", 8, 165733},
	{"BHUSHAN", 7, 165734},
	{"KEMPTHORNE", 10, 165735},
	{"TWINNED", 7, 165736},
	{"EROTICS", 7, 165737},
	{"CHATTO", 6, 165738},
	{"WINSTANLEY", 10, 165739},
	{"HIGHWAYMEN", 10, 165740},
	{"BLACKELO", 8, 165741},
	{"VOORWAARDEN", 11, 165742},
	{"YELLER", 6, 165743},
	{"PROFFERS", 8, 165744},
	{"MEPERIDINE", 10, 165745},
	{"BOOTDISK", 8, 165746},
	{"ASILOMAR", 8, 165747},
	{"CUBBIE", 6, 165748},
	{"SPHEROID", 8, 165749},
	{"REORIENT", 8, 165750},
	{"EROTYCZNE", 9, 165751},
	{"ORATORS", 7, 165752},
	{"FRITILLARY", 10, 165753},
	{"KARTEL", 6, 165754},
	{"BLACKWALL", 9, 165755},
	{"ASHGABAT", 8, 165756},
	{"INCORRIGIBLE", 12, 165757},
	{"CONFIT", 6, 165758},
	{"DAHR", 4, 165759},
	{"BENJY", 5, 165760},
	{"GURDWARA", 8, 165761},
	{"BODEWIG", 7, 165762},
	{"BWM", 3, 165763},
	{"ANTEATER", 8, 165764},
	{"ACTRICES", 8, 165765},
	{"NICKIE", 6, 165766},
	{"BENAZIR", 7, 165767},
	{"BADWARE", 7, 165768},
	{"ABATING", 7, 165769},
	{"LEVELLERS", 9, 165770},
	{"KLSE", 4, 165771},
	{"BONZI", 5, 165772},
	{"KELSEYVILLE", 11, 165773},
	{"GROVETON", 8, 165774},
	{"FLAGGEN", 7, 165775},
	{"MOONRAKER", 9, 165776},
	{"EGRR", 4, 165777},
	{"MCKERNAN", 8, 165778},
	{"SONORE", 6, 165779},
	{"GENECARD", 8, 165780},
	{"FEIGNING", 8, 165781},
	{"CHAPPAQUA", 9, 165782},
	{"MAJURO", 6, 165783},
	{"CRESCO", 6, 165784},
	{"ANTEX", 5, 165785},
	{"TELELOGIC", 9, 165786},
	{"HAEMATOLOGICAL", 14, 165787},
	{"ENDYMION", 8, 165788},
	{"BALLPLAYERS", 11, 165789},
	{"VEBLEN", 6, 165790},
	{"PASSANT", 7, 165791},
	{"SPREADSHIRT", 11, 165792},
	{"DISRUPTOR", 9, 165793},
	{"DESING", 6, 165794},
	{"MICROATX", 8, 165795},
	{"KEMMERER", 8, 165796},
	{"MOUSES", 6, 165797},
	{"DENZIL", 6, 165798},
	{"PANOSE", 6, 165799},
	{"GLEANINGS", 9, 165800},
	{"BCK", 3, 165801},
	{"HOLANDA", 7, 165802},
	{"GAPES", 5, 165803},
	{"SILVERLEAF", 10, 165804},
	{"STRTOK", 6, 165805},
	{"QUIZNOS", 7, 165806},
	{"GRIMAUD", 7, 165807},
	{"MCQUILLAN", 9, 165808},
	{"USIM", 4, 165809},
	{"SYNDICAT", 8, 165810},
	{"LYNDONVILLE", 11, 165811},
	{"YIUS", 4, 165812},
	{"YDWR", 4, 165813},
	{"YCAG", 4, 165814},
	{"WOUP", 4, 165815},
	{"WIGN", 4, 165816},
	{"TOKB", 4, 165817},
	{"TMLS", 4, 165818},
	{"RMRP", 4, 165819},
	{"RCWI", 4, 165820},
	{"RAJT", 4, 165821},
	{"RAJN", 4, 165822},
	{"PCWO", 4, 165823},
	{"OXEL", 4, 165824},
	{"NJIG", 4, 165825},
	{"NEDZ", 4, 165826},
	{"MRTE", 4, 165827},
	{"LHUD", 4, 165828},
	{"KYKO", 4, 165829},
	{"JAEG", 4, 165830},
	{"ICOX", 4, 165831},
	{"HYJA", 4, 165832},
	{"EYIW", 4, 165833},
	{"EOGL", 4, 165834},
	{"DSMD", 4, 165835},
	{"DRHU", 4, 165836},
	{"DDFI", 4, 165837},
	{"BHUB", 4, 165838},
	{"AUPP", 4, 165839},
	{"ANLC", 4, 165840},
	{"AGHY", 4, 165841},
	{"LIPPI", 5, 165842},
	{"MOJITO", 6, 165843},
	{"GAMELINK", 8, 165844},
	{"CAFFREY", 7, 165845},
	{"ANTLERLESS", 10, 165846},
	{"MMPI", 4, 165847},
	{"TABLETPC", 8, 165848},
	{"SODALITE", 8, 165849},
	{"MEGATRENDS", 10, 165850},
	{"UNFOGGED", 8, 165851},
	{"TENENBAUM", 9, 165852},
	{"SUCRALOSE", 9, 165853},
	{"GIGAS", 5, 165854},
	{"AFTAB", 5, 165855},
	{"TOTTY", 5, 165856},
	{"MUNICIPALLY", 11, 165857},
	{"ICEMAT", 6, 165858},
	{"CIRCULARLY", 10, 165859},
	{"UNWRAPPING", 10, 165860},
	{"TELECINE", 8, 165861},
	{"AMSLER", 6, 165862},
	{"PESSIMISTS", 10, 165863},
	{"FACTLY", 6, 165864},
	{"EARLYBIRD", 9, 165865},
	{"NORTHCOTT", 9, 165866},
	{"SHAHEED", 7, 165867},
	{"COELICOLOR", 10, 165868},
	{"AZARIA", 6, 165869},
	{"ATTRIBUT", 8, 165870},
	{"MHRA", 4, 165871},
	{"FMB", 3, 165872},
	{"SEALIFT", 7, 165873},
	{"LIVELIEST", 9, 165874},
	{"ORDONNANCE", 10, 165875},
	{"MILKMEN", 7, 165876},
	{"TOLLBOOTH", 9, 165877},
	{"GCOV", 4, 165878},
	{"BLACKMAILED", 11, 165879},
	{"SIXTIETH", 8, 165880},
	{"BOXE", 4, 165881},
	{"THAMESMEAD", 10, 165882},
	{"REPROOF", 7, 165883},
	{"CONTROLLO", 9, 165884},
	{"LIANNE", 6, 165885},
	{"SECULARIZATION", 14, 165886},
	{"LOUDEN", 6, 165887},
	{"VESNA", 5, 165888},
	{"JDB", 3, 165889},
	{"ALKYLATING", 10, 165890},
	{"VAUGHT", 6, 165891},
	{"DINAS", 5, 165892},
	{"RENDON", 6, 165893},
	{"SMOKESTACK", 10, 165894},
	{"CARTERTON", 9, 165895},
	{"BEITH", 5, 165896},
	{"KRAMNIK", 7, 165897},
	{"ELSTER", 6, 165898},
	{"TRUM", 4, 165899},
	{"KAREOKE", 7, 165900},
	{"JLG", 3, 165901},
	{"KESSELMAN", 9, 165902},
	{"UNIVERSALISTS", 13, 165903},
	{"TREASONOUS", 10, 165904},
	{"MISPRINT", 8, 165905},
	{"ZADOK", 5, 165906},
	{"SEZNAM", 6, 165907},
	{"DIVERTICULOSIS", 14, 165908},
	{"SHAMOKIN", 8, 165909},
	{"TARNISHING", 10, 165910},
	{"HOBNAIL", 7, 165911},
	{"FISCHE", 6, 165912},
	{"BLOWUP", 6, 165913},
	{"SVGALIB", 7, 165914},
	{"UHEW", 4, 165915},
	{"UGAO", 4, 165916},
	{"UENL", 4, 165917},
	{"UDSU", 4, 165918},
	{"SOUF", 4, 165919},
	{"SKSJ", 4, 165920},
	{"RYMD", 4, 165921},
	{"RUXO", 4, 165922},
	{"RSSR", 4, 165923},
	{"RMQU", 4, 165924},
	{"MTVI", 4, 165925},
	{"LGEE", 4, 165926},
	{"JATU", 4, 165927},
	{"GNDU", 4, 165928},
	{"FBYB", 4, 165929},
	{"EYDN", 4, 165930},
	{"EULI", 4, 165931},
	{"ESKB", 4, 165932},
	{"ERWU", 4, 165933},
	{"CROQ", 4, 165934},
	{"CECY", 4, 165935},
	{"BIXB", 4, 165936},
	{"UNICELLULAR", 11, 165937},
	{"DEFN", 4, 165938},
	{"KIERA", 5, 165939},
	{"DORAVILLE", 9, 165940},
	{"PROPIONIC", 9, 165941},
	{"ALDERWOOD", 9, 165942},
	{"STANGL", 6, 165943},
	{"IZARD", 5, 165944},
	{"NETKIT", 6, 165945},
	{"BOWRON", 6, 165946},
	{"EMPA", 4, 165947},
	{"HIGHWATER", 9, 165948},
	{"FILETS", 6, 165949},
	{"TARHEELS", 8, 165950},
	{"CONSPIRATORIAL", 14, 165951},
	{"UNKN", 4, 165952},
	{"TRUSCOTT", 8, 165953},
	{"TAMBOURINES", 11, 165954},
	{"STERNS", 6, 165955},
	{"NONCONFORMIST", 13, 165956},
	{"DAGENS", 6, 165957},
	{"BAISER", 6, 165958},
	{"RETINOIDS", 9, 165959},
	{"NOVALOGIC", 9, 165960},
	{"HALLSVILLE", 10, 165961},
	{"VENIAM", 6, 165962},
	{"EUCALYPT", 8, 165963},
	{"SIVY", 4, 165964},
	{"HALOGENS", 8, 165965},
	{"LEVITATE", 8, 165966},
	{"UDHR", 4, 165967},
	{"TEHRANI", 7, 165968},
	{"DEFENCEMAN", 10, 165969},
	{"CCOM", 4, 165970},
	{"SOLIDIFYING", 11, 165971},
	{"FORRESTAL", 9, 165972},
	{"WIJK", 4, 165973},
	{"INFEC", 5, 165974},
	{"CREDULOUS", 9, 165975},
	{"XLF", 3, 165976},
	{"CONVENTO", 8, 165977},
	{"ARRHENIUS", 9, 165978},
	{"SWPPP", 5, 165979},
	{"EINECS", 6, 165980},
	{"INFLECTIONS", 11, 165981},
	{"AMAZONCOM", 9, 165982},
	{"KPM", 3, 165983},
	{"NOSCRIPT", 8, 165984},
	{"CICK", 4, 165985},
	{"BEBEL", 5, 165986},
	{"MATTERN", 7, 165987},
	{"ROSPA", 5, 165988},
	{"PUZZLEMENT", 10, 165989},
	{"MOLALLA", 7, 165990},
	{"CREADO", 6, 165991},
	{"UVWXYZ", 6, 165992},
	{"FIXABLE", 7, 165993},
	{"FIVEFOLD", 8, 165994},
	{"ZREA", 4, 165995},
	{"ZEMU", 4, 165996},
	{"YDCA", 4, 165997},
	{"UPUB", 4, 165998},
	{"UPPM", 4, 165999},
	{"UMAE", 4, 166000},
	{"UKYU", 4, 166001},
	{"TMVP", 4, 166002},
	{"SBNB", 4, 166003},
	{"RXAV", 4, 166004},
	{"RTEK", 4, 166005},
	{"PTYE", 4, 166006},
	{"PIWO", 4, 166007},
	{"OYDF", 4, 166008},
	{"ONKB", 4, 166009},
	{"OCYS", 4, 166010},
	{"NCKI", 4, 166011},
	{"NAZU", 4, 166012},
	{"MPBI", 4, 166013},
	{"LTCE", 4, 166014},
	{"LPMT", 4, 166015},
	{"JOCO", 4, 166016},
	{"JACH", 4, 166017},
	{"IILL", 4, 166018},
	{"HIDL", 4, 166019},
	{"GIDR", 4, 166020},
	{"FVIB", 4, 166021},
	{"EVSW", 4, 166022},
	{"DRTA", 4, 166023},
	{"BBAW", 4, 166024},
	{"APJU", 4, 166025},
	{"HEALTHFINDER", 12, 166026},
	{"SYMBIONT", 8, 166027},
	{"LINTEL", 6, 166028},
	{"NUCLEOSYNTHESIS", 15, 166029},
	{"ROCIO", 5, 166030},
	{"PEGI", 4, 166031},
	{"BEERY", 5, 166032},
	{"ALLORA", 6, 166033},
	{"JUNCTIONAL", 10, 166034},
	{"SCARPETTA", 9, 166035},
	{"ABDI", 4, 166036},
	{"LYRICSBOX", 9, 166037},
	{"KETTLEBELL", 10, 166038},
	{"ACTIVIDAD", 9, 166039},
	{"STEERABLE", 9, 166040},
	{"VAKANTIEHUISJE", 14, 166041},
	{"BENTHOS", 7, 166042},
	{"INDUCTIONS", 10, 166043},
	{"DIRTIER", 7, 166044},
	{"OMAK", 4, 166045},
	{"GEHRING", 7, 166046},
	{"AMLA", 4, 166047},
	{"KIMBA", 5, 166048},
	{"GARTMORE", 8, 166049},
	{"DYNAMOS", 7, 166050},
	{"BASSAM", 6, 166051},
	{"DWNLOAD", 7, 166052},
	{"BLONDY", 6, 166053},
	{"NIEMINEN", 8, 166054},
	{"CATHAL", 6, 166055},
	{"RITHMS", 6, 166056},
	{"STRUMENTI", 9, 166057},
	{"LANGENSCHEIDT", 13, 166058},
	{"BIFUNCTIONAL", 12, 166059},
	{"ZXD", 3, 166060},
	{"ZVC", 3, 166061},
	{"ZPJ", 3, 166062},
	{"ZKZ", 3, 166063},
	{"ZJD", 3, 166064},
	{"YXQ", 3, 166065},
	{"XZC", 3, 166066},
	{"XWG", 3, 166067},
	{"XQW", 3, 166068},
	{"WQF", 3, 166069},
	{"VQV", 3, 166070},
	{"RZQ", 3, 166071},
	{"QVF", 3, 166072},
	{"QQV", 3, 166073},
	{"PBQ", 3, 166074},
	{"GQG", 3, 166075},
	{"URPMI", 5, 166076},
	{"RENOMA", 6, 166077},
	{"LANGDEVEL", 9, 166078},
	{"DRAT", 4, 166079},
	{"HEREUPON", 8, 166080},
	{"BIOAVAILABLE", 12, 166081},
	{"RUBIX", 5, 166082},
	{"CLOD", 4, 166083},
	{"CATTANEO", 8, 166084},
	{"ACIAR", 5, 166085},
	{"PAPERCRAFT", 10, 166086},
	{"SHAKUHACHI", 10, 166087},
	{"SPACECENTER", 11, 166088},
	{"ABSORBENTS", 10, 166089},
	{"MAGNOLIOPSIDA", 13, 166090},
	{"TSUYOSHI", 8, 166091},
	{"ALARIC", 6, 166092},
	{"ACTIONLISTENER", 14, 166093},
	{"KAKASHI", 7, 166094},
	{"AUSTRALI", 8, 166095},
	{"BENEFICENCE", 11, 166096},
	{"LOMONOSOV", 9, 166097},
	{"GCOS", 4, 166098},
	{"HEXAGRAM", 8, 166099},
	{"CASTEEL", 7, 166100},
	{"ISTRATION", 9, 166101},
	{"EVANDER", 7, 166102},
	{"LITTE", 5, 166103},
	{"LONGMANS", 8, 166104},
	{"ANATEX", 6, 166105},
	{"ENERGI", 6, 166106},
	{"ROLLOUTS", 8, 166107},
	{"SOFTEK", 6, 166108},
	{"CARTWHEEL", 9, 166109},
	{"CALCULA", 7, 166110},
	{"YELLOWJACKETS", 13, 166111},
	{"SAILPLANE", 9, 166112},
	{"QUADRAAT", 8, 166113},
	{"DTSTAMP", 7, 166114},
	{"YOUNGE", 6, 166115},
	{"TEDD", 4, 166116},
	{"LENTON", 6, 166117},
	{"MUSO", 4, 166118},
	{"SUDARSHAN", 9, 166119},
	{"TOWPATH", 7, 166120},
	{"SAMAJ", 5, 166121},
	{"YRAK", 4, 166122},
	{"YDWH", 4, 166123},
	{"WLAG", 4, 166124},
	{"RGVA", 4, 166125},
	{"RGEX", 4, 166126},
	{"ORUF", 4, 166127},
	{"OCWH", 4, 166128},
	{"NPDF", 4, 166129},
	{"LTUI", 4, 166130},
	{"LACW", 4, 166131},
	{"KUBL", 4, 166132},
	{"JDAN", 4, 166133},
	{"INYV", 4, 166134},
	{"GTUT", 4, 166135},
	{"GSUT", 4, 166136},
	{"FBAP", 4, 166137},
	{"ENGZ", 4, 166138},
	{"ENCB", 4, 166139},
	{"EEDQ", 4, 166140},
	{"BBTO", 4, 166141},
	{"AFLS", 4, 166142},
	{"OBSERV", 6, 166143},
	{"FISCALE", 7, 166144},
	{"EYETV", 5, 166145},
	{"SKUKUZA", 7, 166146},
	{"IMPREGNABLE", 11, 166147},
	{"GELDERLAND", 10, 166148},
	{"MALTIN", 6, 166149},
	{"DEMYELINATING", 13, 166150},
	{"WINPLANET", 9, 166151},
	{"CELLINK", 7, 166152},
	{"SHORELAND", 9, 166153},
	{"TRIAC", 5, 166154},
	{"LIBARKRPG", 9, 166155},
	{"IMME", 4, 166156},
	{"AFFERENTS", 9, 166157},
	{"HEPTACHLOR", 10, 166158},
	{"MAKAVELI", 8, 166159},
	{"GIBCO", 5, 166160},
	{"CREDENZAS", 9, 166161},
	{"ACUNA", 5, 166162},
	{"BROCA", 5, 166163},
	{"SORTFIELD", 9, 166164},
	{"PROFILERS", 9, 166165},
	{"MALINOWSKI", 10, 166166},
	{"MURRELLS", 8, 166167},
	{"MIDILAND", 8, 166168},
	{"IDMS", 4, 166169},
	{"KRAY", 4, 166170},
	{"WONDERIN", 8, 166171},
	{"SOUIX", 5, 166172},
	{"SELENITE", 8, 166173},
	{"POCA", 4, 166174},
	{"ETYMOLOGICAL", 12, 166175},
	{"MODULER", 7, 166176},
	{"KLEDING", 7, 166177},
	{"SULFONAMIDES", 12, 166178},
	{"STOPWORDS", 9, 166179},
	{"GRANDSTREAM", 11, 166180},
	{"LOXLEY", 6, 166181},
	{"BISCOE", 6, 166182},
	{"SHAPEWORKS", 10, 166183},
	{"DESSEN", 6, 166184},
	{"OVERSAMPLING", 12, 166185},
	{"GREA", 4, 166186},
	{"EBAYS", 5, 166187},
	{"BVM", 3, 166188},
	{"PENMANSHIP", 10, 166189},
	{"INDIVIDUATION", 13, 166190},
	{"DECIDABILITY", 12, 166191},
	{"FABRCOP", 7, 166192},
	{"ANGHENION", 9, 166193},
	{"DODGSON", 7, 166194},
	{"BRIGHTVIEW", 10, 166195},
	{"REVALIDATE", 10, 166196},
	{"AGUADILLA", 9, 166197},
	{"CREON", 5, 166198},
	{"ULTRALIFE", 9, 166199},
	{"DIMACS", 6, 166200},
	{"BARBEAU", 7, 166201},
	{"AUTOFINDER", 10, 166202},
	{"BERNAT", 6, 166203},
	{"IMPERFECTS", 10, 166204},
	{"GVRD", 4, 166205},
	{"ANNALENA", 8, 166206},
	{"INFOBUTTON", 10, 166207},
	{"BOISVERT", 8, 166208},
	{"TIPPET", 6, 166209},
	{"TETRAMER", 8, 166210},
	{"INSTIGATING", 11, 166211},
	{"GIRDED", 6, 166212},
	{"UNAUTHENTICATED", 15, 166213},
	{"ZLEL", 4, 166214},
	{"YOPO", 4, 166215},
	{"YNNP", 4, 166216},
	{"YDRS", 4, 166217},
	{"WGLI", 4, 166218},
	{"VOMA", 4, 166219},
	{"RNEQ", 4, 166220},
	{"RAMZ", 4, 166221},
	{"PJAN", 4, 166222},
	{"PAUD", 4, 166223},
	{"OBCE", 4, 166224},
	{"MAAW", 4, 166225},
	{"LUFO", 4, 166226},
	{"LIDV", 4, 166227},
	{"IZQU", 4, 166228},
	{"IZAC", 4, 166229},
	{"INBM", 4, 166230},
	{"IBIB", 4, 166231},
	{"HKOL", 4, 166232},
	{"GSAK", 4, 166233},
	{"GORZ", 4, 166234},
	{"DYSY", 4, 166235},
	{"DIOK", 4, 166236},
	{"CTUB", 4, 166237},
	{"CJOI", 4, 166238},
	{"CDUO", 4, 166239},
	{"BSOP", 4, 166240},
	{"BCAG", 4, 166241},
	{"INTERFEROMETERS", 15, 166242},
	{"GOLCONDA", 8, 166243},
	{"INDAIN", 6, 166244},
	{"MANIKIN", 7, 166245},
	{"ADENOVIRAL", 10, 166246},
	{"LASERACTIVE", 11, 166247},
	{"EDIUS", 5, 166248},
	{"KETOSIS", 7, 166249},
	{"EETING", 6, 166250},
	{"SANDA", 5, 166251},
	{"CONNERSVILLE", 12, 166252},
	{"CONDESA", 7, 166253},
	{"FIGA", 4, 166254},
	{"CLIFDEN", 7, 166255},
	{"BESSY", 5, 166256},
	{"WESTCOUNTRY", 11, 166257},
	{"BRILEY", 6, 166258},
	{"RENU", 4, 166259},
	{"CPUFREQ", 7, 166260},
	{"INSCRIBE", 8, 166261},
	{"CASTELLANOS", 11, 166262},
	{"BONAVISTA", 9, 166263},
	{"KENROY", 6, 166264},
	{"VUOI", 4, 166265},
	{"CRAZING", 7, 166266},
	{"GUNSHIPS", 8, 166267},
	{"USFA", 4, 166268},
	{"WURZBURG", 8, 166269},
	{"ADELANTE", 8, 166270},
	{"ADDITEM", 7, 166271},
	{"CHEAPCAT", 8, 166272},
	{"GIFTCARD", 8, 166273},
	{"TOEKOMST", 8, 166274},
	{"DISMEMBER", 9, 166275},
	{"DOGUE", 5, 166276},
	{"REVOCATIONS", 11, 166277},
	{"JULIANO", 7, 166278},
	{"SERENELY", 8, 166279},
	{"YYVSP", 5, 166280},
	{"KYEONG", 6, 166281},
	{"NELLO", 5, 166282},
	{"MANZANO", 7, 166283},
	{"BOJAN", 5, 166284},
	{"MTGS", 4, 166285},
	{"NOSING", 6, 166286},
	{"ELECTROPLATED", 13, 166287},
	{"CAMEJO", 6, 166288},
	{"HADCORE", 7, 166289},
	{"FMJ", 3, 166290},
	{"TREPONEMA", 9, 166291},
	{"DREIDEL", 7, 166292},
	{"BELLEZZA", 8, 166293},
	{"TALKGOLD", 8, 166294},
	{"TULLAMARINE", 11, 166295},
	{"MISPERCEPTION", 13, 166296},
	{"MELNICK", 7, 166297},
	{"UNREALISTICALLY", 15, 166298},
	{"DECREMENTED", 11, 166299},
	{"XTAB", 4, 166300},
	{"VTOR", 4, 166301},
	{"UXCA", 4, 166302},
	{"TKME", 4, 166303},
	{"PROZ", 4, 166304},
	{"PHDO", 4, 166305},
	{"PGLA", 4, 166306},
	{"MMSH", 4, 166307},
	{"KSNU", 4, 166308},
	{"FVIG", 4, 166309},
	{"FBEY", 4, 166310},
	{"ELIY", 4, 166311},
	{"DTFO", 4, 166312},
	{"DRVE", 4, 166313},
	{"CPUM", 4, 166314},
	{"CFUR", 4, 166315},
	{"BPST", 4, 166316},
	{"BLSR", 4, 166317},
	{"KARRI", 5, 166318},
	{"DYSPHORIA", 9, 166319},
	{"CMSC", 4, 166320},
	{"RISKE", 5, 166321},
	{"DYERS", 5, 166322},
	{"IMMUNOGENIC", 11, 166323},
	{"UNCASVILLE", 10, 166324},
	{"PINARELLO", 9, 166325},
	{"TRINTEC", 7, 166326},
	{"MODY", 4, 166327},
	{"CIENEGA", 7, 166328},
	{"ENFERMEDADES", 12, 166329},
	{"TOBRAMYCIN", 10, 166330},
	{"SHOOL", 5, 166331},
	{"KEMBLA", 6, 166332},
	{"SHOWSTOPPERS", 12, 166333},
	{"RUPRECHT", 8, 166334},
	{"PILATUS", 7, 166335},
	{"RAPPRESENTA", 11, 166336},
	{"CROWED", 6, 166337},
	{"VINSCHEN", 8, 166338},
	{"IMMUNOCYTOCHEMICAL", 18, 166339},
	{"NONCLASSIFIED", 13, 166340},
	{"MAUCH", 5, 166341},
	{"ORQUESTA", 8, 166342},
	{"IMPERMANENCE", 12, 166343},
	{"IMPROVERS", 9, 166344},
	{"RAYED", 5, 166345},
	{"BOWENS", 6, 166346},
	{"SPCC", 4, 166347},
	{"KOESTER", 7, 166348},
	{"CIRCUITO", 8, 166349},
	{"TROYAN", 6, 166350},
	{"VENTURERS", 9, 166351},
	{"GCRC", 4, 166352},
	{"MURI", 4, 166353},
	{"CHINLE", 6, 166354},
	{"GEMOLOGICAL", 11, 166355},
	{"TERRAMAR", 8, 166356},
	{"GUARINO", 7, 166357},
	{"FACIAS", 6, 166358},
	{"BLKS", 4, 166359},
	{"COURTOIS", 8, 166360},
	{"MEALEY", 6, 166361},
	{"EIRIK", 5, 166362},
	{"ZHEL", 4, 166363},
	{"YFID", 4, 166364},
	{"WBIS", 4, 166365},
	{"TZPR", 4, 166366},
	{"TLOL", 4, 166367},
	{"RRIR", 4, 166368},
	{"PASG", 4, 166369},
	{"NIFU", 4, 166370},
	{"MKAS", 4, 166371},
	{"KCOW", 4, 166372},
	{"JSMI", 4, 166373},
	{"IKWI", 4, 166374},
	{"ICIB", 4, 166375},
	{"HOXF", 4, 166376},
	{"HMRM", 4, 166377},
	{"HAYP", 4, 166378},
	{"GOGY", 4, 166379},
	{"EGMU", 4, 166380},
	{"DOLU", 4, 166381},
	{"DKWA", 4, 166382},
	{"ARBC", 4, 166383},
	{"MEGABBS", 7, 166384},
	{"THEUSCLINICS", 12, 166385},
	{"PULLUP", 6, 166386},
	{"EFLAGS", 6, 166387},
	{"HUBBERT", 7, 166388},
	{"COOPED", 6, 166389},
	{"OVERWROUGHT", 11, 166390},
	{"SMETHWICK", 9, 166391},
	{"PHILEX", 6, 166392},
	{"VIVACITY", 8, 166393},
	{"RECI", 4, 166394},
	{"GHEORGHE", 8, 166395},
	{"COMPUTERISATION", 15, 166396},
	{"YUKA", 4, 166397},
	{"INCONTROVERTIBLE", 16, 166398},
	{"LOUISANA", 8, 166399},
	{"NOTNAMED", 8, 166400},
	{"SONNENSCHEIN", 12, 166401},
	{"LIBPTH", 6, 166402},
	{"HOSHINO", 7, 166403},
	{"HOOPLE", 6, 166404},
	{"BONNETT", 7, 166405},
	{"FORENOON", 8, 166406},
	{"BIBA", 4, 166407},
	{"DRYDAY", 6, 166408},
	{"TPMCAFE", 7, 166409},
	{"FOTOSERVE", 9, 166410},
	{"DAMAS", 5, 166411},
	{"CLOTTED", 7, 166412},
	{"SPEERS", 6, 166413},
	{"BITPEDIA", 8, 166414},
	{"KAGAKU", 6, 166415},
	{"SEVERLY", 7, 166416},
	{"HUMANO", 6, 166417},
	{"TEFILLIN", 8, 166418},
	{"PUSHUPS", 7, 166419},
	{"ENGLANDS", 8, 166420},
	{"OSTROW", 6, 166421},
	{"SOUNDMAX", 8, 166422},
	{"PAUS", 4, 166423},
	{"GATSO", 5, 166424},
	{"LOVETTE", 7, 166425},
	{"CHIEH", 5, 166426},
	{"FARNWORTH", 9, 166427},
	{"WAFA", 4, 166428},
	{"ALHAURIN", 8, 166429},
	{"HARVE", 5, 166430},
	{"EXPY", 4, 166431},
	{"MOBIELE", 7, 166432},
	{"SNOWBOOTS", 9, 166433},
	{"NETSCOUT", 8, 166434},
	{"STARTINGPOINTS", 14, 166435},
	{"DRUMSTICK", 9, 166436},
	{"APPROPIATE", 10, 166437},
	{"SHEEZY", 6, 166438},
	{"INCISOR", 7, 166439},
	{"SOCIALI", 7, 166440},
	{"KAPTUR", 6, 166441},
	{"CLOUSEAU", 8, 166442},
	{"RBR", 3, 166443},
	{"INGAAS", 6, 166444},
	{"TRUTHINESS", 10, 166445},
	{"IPROUTE", 7, 166446},
	{"DELACORTE", 9, 166447},
	{"JOLYON", 6, 166448},
	{"PASHLEY", 7, 166449},
	{"CERTITUDE", 9, 166450},
	{"POPO", 4, 166451},
	{"MARSHALLED", 10, 166452},
	{"ZIOF", 4, 166453},
	{"YGAD", 4, 166454},
	{"XPAI", 4, 166455},
	{"WFEM", 4, 166456},
	{"UEZP", 4, 166457},
	{"TVTR", 4, 166458},
	{"RUZH", 4, 166459},
	{"RLFI", 4, 166460},
	{"REAZ", 4, 166461},
	{"LSHY", 4, 166462},
	{"LJUK", 4, 166463},
	{"KMRA", 4, 166464},
	{"IKEX", 4, 166465},
	{"IDYW", 4, 166466},
	{"DVOD", 4, 166467},
	{"DTBA", 4, 166468},
	{"DDPO", 4, 166469},
	{"CSBL", 4, 166470},
	{"ANWU", 4, 166471},
	{"AKSY", 4, 166472},
	{"AFPR", 4, 166473},
	{"OVEREXPOSED", 11, 166474},
	{"MUPAD", 5, 166475},
	{"DUPLEXER", 8, 166476},
	{"ADVO", 4, 166477},
	{"AMMONITES", 9, 166478},
	{"CENTEREDNESS", 12, 166479},
	{"HANTUCHOVA", 10, 166480},
	{"ORNISH", 6, 166481},
	{"NOTAM", 5, 166482},
	{"BREGMAN", 7, 166483},
	{"SENILITY", 8, 166484},
	{"PLAGIARISED", 11, 166485},
	{"PERLIO", 6, 166486},
	{"STAMBAUGH", 9, 166487},
	{"FATTAH", 6, 166488},
	{"BALLERINAS", 10, 166489},
	{"IMPRESORA", 9, 166490},
	{"EDIZIONI", 8, 166491},
	{"APPROVINGLY", 11, 166492},
	{"WAIF", 4, 166493},
	{"HIDER", 5, 166494},
	{"ADALAH", 6, 166495},
	{"WESTERHAM", 9, 166496},
	{"GAETA", 5, 166497},
	{"RIEDER", 6, 166498},
	{"BARIELLE", 8, 166499},
	{"HARTSTRINGS", 11, 166500},
	{"BITTORRENTS", 11, 166501},
	{"JPAMPERE", 8, 166502},
	{"ANKYRIN", 7, 166503},
	{"HEYES", 5, 166504},
	{"RUDER", 5, 166505},
	{"TEEVEE", 6, 166506},
	{"LACHINE", 7, 166507},
	{"DICOT", 5, 166508},
	{"DIVORCEE", 8, 166509},
	{"SITOSTEROL", 10, 166510},
	{"UNIDENTIFIABLE", 14, 166511},
	{"ADGRUNT", 7, 166512},
	{"SUFFUSED", 8, 166513},
	{"TILBUD", 6, 166514},
	{"DISSED", 6, 166515},
	{"IURP", 4, 166516},
	{"BEECHWORTH", 10, 166517},
	{"FOXWOOD", 7, 166518},
	{"BUJUMBURA", 9, 166519},
	{"VIRTUAGIRL", 10, 166520},
	{"FANDEN", 6, 166521},
	{"FORGONE", 7, 166522},
	{"MALAKOFF", 8, 166523},
	{"INSTAGIB", 8, 166524},
	{"NONMETROPOLITAN", 15, 166525},
	{"NARU", 4, 166526},
	{"VIDEOCABLEPLUG", 14, 166527},
	{"COMVERSE", 8, 166528},
	{"KUNDERA", 7, 166529},
	{"TETBURY", 7, 166530},
	{"IPRATROPIUM", 11, 166531},
	{"GEGEVENS", 8, 166532},
	{"BHARGAVA", 8, 166533},
	{"CHATBOT", 7, 166534},
	{"SHORTNAME", 9, 166535},
	{"CHESSBASE", 9, 166536},
	{"ALTIJD", 6, 166537},
	{"OASDI", 5, 166538},
	{"MANTZ", 5, 166539},
	{"MODRA", 5, 166540},
	{"LOCKD", 5, 166541},
	{"ENTERITIDIS", 11, 166542},
	{"STOPOVERS", 9, 166543},
	{"SIDIOUS", 7, 166544},
	{"ZUMB", 4, 166545},
	{"TLBF", 4, 166546},
	{"SJED", 4, 166547},
	{"SGTR", 4, 166548},
	{"RSFT", 4, 166549},
	{"PMYO", 4, 166550},
	{"NJCA", 4, 166551},
	{"LBYK", 4, 166552},
	{"JIGA", 4, 166553},
	{"ILAJ", 4, 166554},
	{"HEXL", 4, 166555},
	{"GLAG", 4, 166556},
	{"DPAB", 4, 166557},
	{"CTWR", 4, 166558},
	{"PROBALY", 7, 166559},
	{"PANAGIOTIS", 10, 166560},
	{"BLADERUNNER", 11, 166561},
	{"VINBLASTINE", 11, 166562},
	{"MTRJ", 4, 166563},
	{"CYTIDINE", 8, 166564},
	{"PAJARO", 6, 166565},
	{"CHALLENG", 8, 166566},
	{"BUSTARD", 7, 166567},
	{"ARTLESS", 7, 166568},
	{"PAESI", 5, 166569},
	{"STATISTIKA", 10, 166570},
	{"SNAPFILES", 9, 166571},
	{"INNOCENTI", 9, 166572},
	{"INTERCASINO", 11, 166573},
	{"RAILPAGE", 8, 166574},
	{"LEGENDA", 7, 166575},
	{"VILLARAIGOSA", 12, 166576},
	{"ROTHENBURG", 10, 166577},
	{"TAKAYUKI", 8, 166578},
	{"GARANTIZADO", 11, 166579},
	{"VLIEGTUIG", 9, 166580},
	{"MORNE", 5, 166581},
	{"MILONGA", 7, 166582},
	{"TETERBORO", 9, 166583},
	{"WHITEFORD", 9, 166584},
	{"INDEO", 5, 166585},
	{"ANTIPHOSPHOLIPID", 16, 166586},
	{"ALLARDYCE", 9, 166587},
	{"MINOCQUA", 8, 166588},
	{"USWEST", 6, 166589},
	{"EXMT", 4, 166590},
	{"ERZURUM", 7, 166591},
	{"DOOKU", 5, 166592},
	{"HOWSE", 5, 166593},
	{"DUPIONI", 7, 166594},
	{"COWED", 5, 166595},
	{"GERY", 4, 166596},
	{"MAUGHAN", 7, 166597},
	{"SALMONELLOSIS", 13, 166598},
	{"GRIPSHIFT", 9, 166599},
	{"MECHASSAULT", 11, 166600},
	{"PRECHARGE", 9, 166601},
	{"LLOEGR", 6, 166602},
	{"ARLANDA", 7, 166603},
	{"AUXILLARY", 9, 166604},
	{"DATER", 5, 166605},
	{"EYECANDY", 8, 166606},
	{"MIDDX", 5, 166607},
	{"LANC", 4, 166608},
	{"BIOTURBATION", 12, 166609},
	{"ASTROTURF", 9, 166610},
	{"REGENERATES", 11, 166611},
	{"IMMUNOCHEMICALS", 15, 166612},
	{"KALKI", 5, 166613},
	{"INACCESSIBILITY", 15, 166614},
	{"OPERS", 5, 166615},
	{"DROMORE", 7, 166616},
	{"QUEBEKO", 7, 166617},
	{"SCRIPTALIAS", 11, 166618},
	{"POURNELLE", 9, 166619},
	{"CHILTERNS", 9, 166620},
	{"MEISEL", 6, 166621},
	{"BREZHNEV", 8, 166622},
	{"TRAILL", 6, 166623},
	{"PONGO", 5, 166624},
	{"ZACR", 4, 166625},
	{"XAGR", 4, 166626},
	{"UIZO", 4, 166627},
	{"RGGA", 4, 166628},
	{"RAWV", 4, 166629},
	{"PRYC", 4, 166630},
	{"NOLB", 4, 166631},
	{"NGHM", 4, 166632},
	{"LUBJ", 4, 166633},
	{"KLEU", 4, 166634},
	{"KJEF", 4, 166635},
	{"GOSG", 4, 166636},
	{"FHUT", 4, 166637},
	{"EMGU", 4, 166638},
	{"CSGI", 4, 166639},
	{"COXO", 4, 166640},
	{"BTEL", 4, 166641},
	{"BRZE", 4, 166642},
	{"BJER", 4, 166643},
	{"ARCZ", 4, 166644},
	{"AGEZ", 4, 166645},
	{"PYQT", 4, 166646},
	{"IPADDR", 6, 166647},
	{"TUZLA", 5, 166648},
	{"REHEATING", 9, 166649},
	{"LONGUEUR", 8, 166650},
	{"FLIGHTLESS", 10, 166651},
	{"ORCAD", 5, 166652},
	{"DAHAB", 5, 166653},
	{"BUKA", 4, 166654},
	{"TYPHOONANUBIS", 13, 166655},
	{"FXP", 3, 166656},
	{"TELEMARKING", 11, 166657},
	{"EPAGE", 5, 166658},
	{"DEEPS", 5, 166659},
	{"TYMPANIC", 8, 166660},
	{"REGISTRIERUNG", 13, 166661},
	{"MONSOONS", 8, 166662},
	{"SOFC", 4, 166663},
	{"COUNTERFEITS", 12, 166664},
	{"FARREN", 6, 166665},
	{"PREPROCESSED", 12, 166666},
	{"CHAMPUS", 7, 166667},
	{"CACM", 4, 166668},
	{"SAMBIT", 6, 166669},
	{"WINSYSTEMS", 10, 166670},
	{"KUTJE", 5, 166671},
	{"MATAMOROS", 9, 166672},
	{"AMERICANIZED", 12, 166673},
	{"SOLTI", 5, 166674},
	{"WIGEON", 6, 166675},
	{"WHITACRE", 8, 166676},
	{"SCHUTTE", 7, 166677},
	{"PROMOTIE", 8, 166678},
	{"MWSF", 4, 166679},
	{"LOGTOOL", 7, 166680},
	{"GHATS", 5, 166681},
	{"WASTEBASKETS", 12, 166682},
	{"LANKANS", 7, 166683},
	{"LIBERATES", 9, 166684},
	{"FORGER", 6, 166685},
	{"KALBARRI", 8, 166686},
	{"HUGECOCK", 8, 166687},
	{"FCGI", 4, 166688},
	{"PUDGY", 5, 166689},
	{"GALATI", 6, 166690},
	{"WICHARD", 7, 166691},
	{"SALONGA", 7, 166692},
	{"HEXEN", 5, 166693},
	{"FSCM", 4, 166694},
	{"OPENBC", 6, 166695},
	{"BROKENNESS", 10, 166696},
	{"CHIKS", 5, 166697},
	{"BUSIED", 6, 166698},
	{"CLEARDEV", 8, 166699},
	{"YOUSSOU", 7, 166700},
	{"OLERACEA", 8, 166701},
	{"FLUORIDATED", 11, 166702},
	{"PATONS", 6, 166703},
	{"REFRIDGERATOR", 13, 166704},
	{"NICOLO", 6, 166705},
	{"SEAGCH", 6, 166706},
	{"ECOVER", 6, 166707},
	{"ASIANTAETH", 10, 166708},
	{"APIRL", 5, 166709},
	{"RALPHIE", 7, 166710},
	{"PARTENKIRCHEN", 13, 166711},
	{"OWNLOAD", 7, 166712},
	{"GREENVALE", 9, 166713},
	{"EIGHTFOLD", 9, 166714},
	{"ZLEY", 4, 166715},
	{"YNSC", 4, 166716},
	{"VYPO", 4, 166717},
	{"UGNI", 4, 166718},
	{"UBIM", 4, 166719},
	{"RYAO", 4, 166720},
	{"RMEQ", 4, 166721},
	{"RDRD", 4, 166722},
	{"RCPU", 4, 166723},
	{"LTUC", 4, 166724},
	{"LIMK", 4, 166725},
	{"LILB", 4, 166726},
	{"LHOB", 4, 166727},
	{"HUMW", 4, 166728},
	{"GYOL", 4, 166729},
	{"GPAV", 4, 166730},
	{"COSK", 4, 166731},
	{"APPB", 4, 166732},
	{"AGHW", 4, 166733},
	{"BOURDAIN", 8, 166734},
	{"WOODSHED", 8, 166735},
	{"SABR", 4, 166736},
	{"VENIR", 5, 166737},
	{"PROFITEERS", 10, 166738},
	{"MOUNTJOY", 8, 166739},
	{"DUBLE", 5, 166740},
	{"TRICERATOPS", 11, 166741},
	{"SUCKERED", 8, 166742},
	{"DAMERON", 7, 166743},
	{"EUDICOTYLEDONS", 14, 166744},
	{"HISCORES", 8, 166745},
	{"GARBERVILLE", 11, 166746},
	{"BULTE", 5, 166747},
	{"RAGO", 4, 166748},
	{"METROLAND", 9, 166749},
	{"HOMELOAN", 8, 166750},
	{"ESCAPEES", 8, 166751},
	{"DEVINCI", 7, 166752},
	{"XBX", 3, 166753},
	{"OPENMOSIX", 9, 166754},
	{"BAROCCO", 7, 166755},
	{"MOBZY", 5, 166756},
	{"TRAILOR", 7, 166757},
	{"FOTOALBUM", 9, 166758},
	{"VROUWEN", 7, 166759},
	{"EMMITSBURG", 10, 166760},
	{"TRISTANIA", 9, 166761},
	{"SPECIA", 6, 166762},
	{"BRYD", 4, 166763},
	{"SACHER", 6, 166764},
	{"SEREVENT", 8, 166765},
	{"QUORN", 5, 166766},
	{"ASCENTIAL", 9, 166767},
	{"SCAUP", 5, 166768},
	{"IQUITOS", 7, 166769},
	{"VALENCIENNES", 12, 166770},
	{"LUPA", 4, 166771},
	{"BAHAMUT", 7, 166772},
	{"TALLGRASS", 9, 166773},
	{"ADVA", 4, 166774},
	{"KOMT", 4, 166775},
	{"NOBLESSE", 8, 166776},
	{"ACOUNT", 6, 166777},
	{"LAMBING", 7, 166778},
	{"FIALA", 5, 166779},
	{"TRANQUILIZER", 12, 166780},
	{"ZOOMINFO", 8, 166781},
	{"LENAPE", 6, 166782},
	{"JOSTLING", 8, 166783},
	{"VRP", 3, 166784},
	{"STRATH", 6, 166785},
	{"RADIKAL", 7, 166786},
	{"BRIOLETTE", 9, 166787},
	{"WKLV", 4, 166788},
	{"INLOGGEN", 8, 166789},
	{"BXTYPE", 6, 166790},
	{"KALEIDOSCOPIC", 13, 166791},
	{"SATIETY", 7, 166792},
	{"STRADBROKE", 10, 166793},
	{"ABSINTH", 7, 166794},
	{"QUIST", 5, 166795},
	{"THIBODEAUX", 10, 166796},
	{"YWAM", 4, 166797},
	{"VOJVODINA", 9, 166798},
	{"LBX", 3, 166799},
	{"NYPA", 4, 166800},
	{"CRYSTALLOGR", 11, 166801},
	{"AUNTIES", 7, 166802},
	{"INSTIT", 6, 166803},
	{"BEWERTEN", 8, 166804},
	{"SULK", 4, 166805},
	{"FIRETRAP", 8, 166806},
	{"SHADOWBOXING", 12, 166807},
	{"KORBEN", 6, 166808},
	{"YNCS", 4, 166809},
	{"YILE", 4, 166810},
	{"VYBR", 4, 166811},
	{"UVAT", 4, 166812},
	{"ULPF", 4, 166813},
	{"RJOL", 4, 166814},
	{"RFBI", 4, 166815},
	{"PJUL", 4, 166816},
	{"OEDR", 4, 166817},
	{"OBUG", 4, 166818},
	{"KNAR", 4, 166819},
	{"KILC", 4, 166820},
	{"IKAV", 4, 166821},
	{"HOGL", 4, 166822},
	{"GMCO", 4, 166823},
	{"GITJ", 4, 166824},
	{"FLUH", 4, 166825},
	{"COEW", 4, 166826},
	{"CHEJ", 4, 166827},
	{"AXSP", 4, 166828},
	{"AJKO", 4, 166829},
	{"AGSR", 4, 166830},
	{"PROSIGNIA", 9, 166831},
	{"HALLUCINATING", 13, 166832},
	{"CROCKS", 6, 166833},
	{"IKONOS", 6, 166834},
	{"LASHAWN", 7, 166835},
	{"JENCKS", 6, 166836},
	{"ADMINI", 6, 166837},
	{"PUSHBUTTONS", 11, 166838},
	{"TRAVELODGES", 11, 166839},
	{"SEAWCH", 6, 166840},
	{"DBQ", 3, 166841},
	{"SPRIT", 5, 166842},
	{"CORSHAM", 7, 166843},
	{"BLEY", 4, 166844},
	{"TRANSCANADA", 11, 166845},
	{"SUPR", 4, 166846},
	{"NIFFENEGGER", 11, 166847},
	{"HUNLEY", 6, 166848},
	{"LYNCHED", 7, 166849},
	{"TOLERABLY", 9, 166850},
	{"ESWC", 4, 166851},
	{"PWY", 3, 166852},
	{"CONSANGUINITY", 13, 166853},
	{"MACCLENNY", 9, 166854},
	{"BREATHLESSNESS", 14, 166855},
	{"ICOL", 4, 166856},
	{"NICKLEBY", 8, 166857},
	{"MICROMAT", 8, 166858},
	{"SFARCH", 6, 166859},
	{"KIJKEN", 6, 166860},
	{"NEWTS", 5, 166861},
	{"LUPINUS", 7, 166862},
	{"REPTILIA", 8, 166863},
	{"NAUSICAA", 8, 166864},
	{"CONVULSION", 10, 166865},
	{"ZORRAS", 6, 166866},
	{"ADENOSYLMETHIONINE", 18, 166867},
	{"VITAMINIC", 9, 166868},
	{"PRESSO", 6, 166869},
	{"REPHLEX", 7, 166870},
	{"FULKERSON", 9, 166871},
	{"SLUMBERING", 10, 166872},
	{"HAMEED", 6, 166873},
	{"GANACHE", 7, 166874},
	{"WEBDESIGNER", 11, 166875},
	{"KIMBERLITE", 10, 166876},
	{"STOCKXPERT", 10, 166877},
	{"GLYCERYL", 8, 166878},
	{"HERACLITUS", 10, 166879},
	{"BEHAVIORISM", 11, 166880},
	{"RSCH", 4, 166881},
	{"RAABE", 5, 166882},
	{"IMANI", 5, 166883},
	{"FREEPINT", 8, 166884},
	{"NUSSBAUMONDESIGN", 16, 166885},
	{"GENTLEMENS", 10, 166886},
	{"LYNDSAY", 7, 166887},
	{"QEARCH", 6, 166888},
	{"CHICHI", 6, 166889},
	{"HANZO", 5, 166890},
	{"SCOOL", 5, 166891},
	{"SALLISAW", 8, 166892},
	{"PRANKSTERS", 10, 166893},
	{"EXTERMINATORS", 13, 166894},
	{"SEMICIRCLE", 10, 166895},
	{"SEMUA", 5, 166896},
	{"COEAECIENTS", 11, 166897},
	{"CINEMATOGRAPHERS", 16, 166898},
	{"TREGO", 5, 166899},
	{"STROSS", 6, 166900},
	{"POMARE", 6, 166901},
	{"ZAKO", 4, 166902},
	{"YUSR", 4, 166903},
	{"XAFF", 4, 166904},
	{"UMGI", 4, 166905},
	{"SCMO", 4, 166906},
	{"RXES", 4, 166907},
	{"RNKO", 4, 166908},
	{"OBPL", 4, 166909},
	{"NMYU", 4, 166910},
	{"NCFI", 4, 166911},
	{"MPIP", 4, 166912},
	{"GYDU", 4, 166913},
	{"GLUI", 4, 166914},
	{"ESWW", 4, 166915},
	{"EGMT", 4, 166916},
	{"DOIK", 4, 166917},
	{"CAEM", 4, 166918},
	{"BYIV", 4, 166919},
	{"AXYI", 4, 166920},
	{"SALTASH", 7, 166921},
	{"GAMETAP", 7, 166922},
	{"PICOSECOND", 10, 166923},
	{"CORPORAT", 8, 166924},
	{"WHIPTAIL", 8, 166925},
	{"VIENT", 5, 166926},
	{"SQUINTED", 8, 166927},
	{"CLYNE", 5, 166928},
	{"PXC", 3, 166929},
	{"SONALI", 6, 166930},
	{"RUEL", 4, 166931},
	{"CAFO", 4, 166932},
	{"WYTHNOS", 7, 166933},
	{"VERENIGDE", 9, 166934},
	{"PROGRESSIVISM", 13, 166935},
	{"EXAGGERATIONS", 13, 166936},
	{"SARD", 4, 166937},
	{"DDJ", 3, 166938},
	{"TORQ", 4, 166939},
	{"SUPERSCRIPTBOX", 14, 166940},
	{"RESIT", 5, 166941},
	{"VANDERPOOL", 10, 166942},
	{"YOSHIE", 6, 166943},
	{"VMLINUX", 7, 166944},
	{"REPLACMENT", 10, 166945},
	{"MEETIN", 6, 166946},
	{"THELEMA", 7, 166947},
	{"CHUKCHI", 7, 166948},
	{"RECEIPE", 7, 166949},
	{"BRICKLIN", 8, 166950},
	{"SPARROWHAWK", 11, 166951},
	{"FUNAGAIN", 8, 166952},
	{"DHILLON", 7, 166953},
	{"CHOROIDAL", 9, 166954},
	{"WIPS", 4, 166955},
	{"TRITECH", 7, 166956},
	{"OFOTO", 5, 166957},
	{"HELSINGIN", 9, 166958},
	{"MANTENIMIENTO", 13, 166959},
	{"GRG", 3, 166960},
	{"WILLIA", 6, 166961},
	{"TWIX", 4, 166962},
	{"HENTY", 5, 166963},
	{"BLOKUS", 6, 166964},
	{"ASTRAWARE", 9, 166965},
	{"CDFG", 4, 166966},
	{"SVENSON", 7, 166967},
	{"EUTECTIC", 8, 166968},
	{"COBALAMIN", 9, 166969},
	{"BURRESS", 7, 166970},
	{"PHARMAGENX", 10, 166971},
	{"EDITORSHIP", 10, 166972},
	{"FOOSE", 5, 166973},
	{"JAMBO", 5, 166974},
	{"PIXELPOST", 9, 166975},
	{"FYNBOS", 6, 166976},
	{"KEACH", 5, 166977},
	{"JADI", 4, 166978},
	{"AIKIWEB", 7, 166979},
	{"WHISKEYTOWN", 11, 166980},
	{"ZEKA", 4, 166981},
	{"YVLA", 4, 166982},
	{"YNUN", 4, 166983},
	{"YMST", 4, 166984},
	{"WBOB", 4, 166985},
	{"UPWR", 4, 166986},
	{"SPSW", 4, 166987},
	{"RWIZ", 4, 166988},
	{"RJAD", 4, 166989},
	{"RCYF", 4, 166990},
	{"OVIW", 4, 166991},
	{"OMUH", 4, 166992},
	{"OFMN", 4, 166993},
	{"OELR", 4, 166994},
	{"MUNW", 4, 166995},
	{"LFCU", 4, 166996},
	{"JRHI", 4, 166997},
	{"GNUL", 4, 166998},
	{"FUPD", 4, 166999},
	{"FNAD", 4, 167000},
	{"FLLE", 4, 167001},
	{"FBUB", 4, 167002},
	{"EVLO", 4, 167003},
	{"EOLL", 4, 167004},
	{"EDXA", 4, 167005},
	{"DRGI", 4, 167006},
	{"ABPE", 4, 167007},
	{"WEBUI", 5, 167008},
	{"RAPTUROUS", 9, 167009},
	{"ACETATES", 8, 167010},
	{"PANTER", 6, 167011},
	{"EGGPLANTS", 9, 167012},
	{"MYFYRWYR", 8, 167013},
	{"OSCILLATES", 10, 167014},
	{"TWENTYSOMETHING", 15, 167015},
	{"CASSELS", 7, 167016},
	{"WASHITA", 7, 167017},
	{"CHANSTATS", 9, 167018},
	{"HORTICULTURIST", 14, 167019},
	{"ERPS", 4, 167020},
	{"ALLOWOVERRIDE", 13, 167021},
	{"YASUO", 5, 167022},
	{"UNOBTRUSIVELY", 13, 167023},
	{"CBOOS", 5, 167024},
	{"AEROBIE", 7, 167025},
	{"ORLOFF", 6, 167026},
	{"ERCP", 4, 167027},
	{"GRAVESITE", 9, 167028},
	{"VISM", 4, 167029},
	{"NAVAHO", 6, 167030},
	{"METALLIZATION", 13, 167031},
	{"BOVARY", 6, 167032},
	{"REMER", 5, 167033},
	{"KABAT", 5, 167034},
	{"MILLSAP", 7, 167035},
	{"FLYBALL", 7, 167036},
	{"CWOP", 4, 167037},
	{"MCKENDREE", 9, 167038},
	{"KHYBER", 6, 167039},
	{"HARLINGTON", 10, 167040},
	{"SEARCM", 6, 167041},
	{"INTRINSYC", 9, 167042},
	{"DRR", 3, 167043},
	{"SWIVELING", 9, 167044},
	{"SASSON", 6, 167045},
	{"LOTOS", 5, 167046},
	{"REDBUD", 6, 167047},
	{"NATCH", 5, 167048},
	{"COBS", 4, 167049},
	{"HANNUKAH", 8, 167050},
	{"PREISS", 6, 167051},
	{"DALMATIONS", 10, 167052},
	{"TICKETALERTS", 12, 167053},
	{"IFAIL", 5, 167054},
	{"LLEDO", 5, 167055},
	{"PEOPEL", 6, 167056},
	{"SABES", 5, 167057},
	{"HYDROGEOLOGICAL", 15, 167058},
	{"MSDSS", 5, 167059},
	{"ZARG", 4, 167060},
	{"WFRU", 4, 167061},
	{"VROC", 4, 167062},
	{"TVOU", 4, 167063},
	{"RNEJ", 4, 167064},
	{"PYWO", 4, 167065},
	{"PTIF", 4, 167066},
	{"IUNG", 4, 167067},
	{"IKSP", 4, 167068},
	{"IKKU", 4, 167069},
	{"HJAL", 4, 167070},
	{"GNGE", 4, 167071},
	{"GLUK", 4, 167072},
	{"GIAU", 4, 167073},
	{"EBVR", 4, 167074},
	{"DIIM", 4, 167075},
	{"CIEX", 4, 167076},
	{"BSVI", 4, 167077},
	{"AZIF", 4, 167078},
	{"AGFI", 4, 167079},
	{"POWERSELLERS", 12, 167080},
	{"FLYBRIDGE", 9, 167081},
	{"COAHOMA", 7, 167082},
	{"SWEETMAN", 8, 167083},
	{"GODPARENTS", 10, 167084},
	{"VISTING", 7, 167085},
	{"MESSAGEID", 9, 167086},
	{"PICNO", 5, 167087},
	{"AUTOBOT", 7, 167088},
	{"STREETERVILLE", 13, 167089},
	{"DIHYDROTESTOSTERONE", 19, 167090},
	{"STRU", 4, 167091},
	{"GAMEWRIGHT", 10, 167092},
	{"DIFFUSES", 8, 167093},
	{"VEGE", 4, 167094},
	{"VITRIFICATION", 13, 167095},
	{"IVICA", 5, 167096},
	{"FASALYZER", 9, 167097},
	{"CATALPA", 7, 167098},
	{"MANEJO", 6, 167099},
	{"TUNEWEAR", 8, 167100},
	{"RUMAH", 5, 167101},
	{"CRYSTALLIN", 10, 167102},
	{"MCMULLIN", 8, 167103},
	{"BALUSTRADES", 11, 167104},
	{"CHOICEST", 8, 167105},
	{"GOSTATS", 7, 167106},
	{"SEURAT", 6, 167107},
	{"SEATBACK", 8, 167108},
	{"MGW", 3, 167109},
	{"UGAS", 4, 167110},
	{"ADVUEU", 6, 167111},
	{"EZLN", 4, 167112},
	{"FAIRYTOPIA", 10, 167113},
	{"TEMPESTUOUS", 11, 167114},
	{"CETYL", 5, 167115},
	{"MONSERRAT", 9, 167116},
	{"MINCHIN", 7, 167117},
	{"ROSENDALE", 9, 167118},
	{"HANKIN", 6, 167119},
	{"CREOLES", 7, 167120},
	{"UMUC", 4, 167121},
	{"DOTTK", 5, 167122},
	{"VAILLANT", 8, 167123},
	{"OBOES", 5, 167124},
	{"DOMAINKEY", 9, 167125},
	{"IMAGEPRO", 8, 167126},
	{"BRAINSTORMS", 11, 167127},
	{"DWONLOAD", 8, 167128},
	{"COMMUNIC", 8, 167129},
	{"CREMER", 6, 167130},
	{"FOXHOLE", 7, 167131},
	{"DELIMITING", 10, 167132},
	{"LIBSDL", 6, 167133},
	{"MATSUMURA", 9, 167134},
	{"WSYN", 4, 167135},
	{"WPOU", 4, 167136},
	{"UDWO", 4, 167137},
	{"SCBE", 4, 167138},
	{"RPUZ", 4, 167139},
	{"RGPS", 4, 167140},
	{"PYGA", 4, 167141},
	{"POMI", 4, 167142},
	{"PHGO", 4, 167143},
	{"PCSW", 4, 167144},
	{"PAKT", 4, 167145},
	{"OYCL", 4, 167146},
	{"NOMB", 4, 167147},
	{"NGOY", 4, 167148},
	{"MOWR", 4, 167149},
	{"KSYA", 4, 167150},
	{"KMOB", 4, 167151},
	{"IACB", 4, 167152},
	{"HRUI", 4, 167153},
	{"HALZ", 4, 167154},
	{"GSTF", 4, 167155},
	{"GCOH", 4, 167156},
	{"FFJE", 4, 167157},
	{"FCAG", 4, 167158},
	{"FAKH", 4, 167159},
	{"EBEQ", 4, 167160},
	{"DRPO", 4, 167161},
	{"BICD", 4, 167162},
	{"BECB", 4, 167163},
	{"ADTY", 4, 167164},
	{"ABEU", 4, 167165},
	{"TERMINIX", 8, 167166},
	{"WDCS", 4, 167167},
	{"KUMASI", 6, 167168},
	{"ETHNIK", 6, 167169},
	{"PIXELMAN", 8, 167170},
	{"INICIAR", 7, 167171},
	{"SUCCUBUS", 8, 167172},
	{"DROGUE", 6, 167173},
	{"NYISO", 5, 167174},
	{"KNOTWORK", 8, 167175},
	{"RANTER", 6, 167176},
	{"DMTECH", 6, 167177},
	{"FRODSHAM", 8, 167178},
	{"CHARLI", 6, 167179},
	{"UMEA", 4, 167180},
	{"SALLEY", 6, 167181},
	{"DHOW", 4, 167182},
	{"BIRKDALE", 8, 167183},
	{"RESTARAUNT", 10, 167184},
	{"POULTER", 7, 167185},
	{"FABIOLA", 7, 167186},
	{"FOOTCARE", 8, 167187},
	{"DEMULTIPLEXER", 13, 167188},
	{"CARAS", 5, 167189},
	{"BAMBOOS", 7, 167190},
	{"VCOM", 4, 167191},
	{"NEWSTICKER", 10, 167192},
	{"MOWIES", 6, 167193},
	{"MBSTRING", 8, 167194},
	{"LISIEUX", 7, 167195},
	{"USINVESTMENT", 12, 167196},
	{"GRANDPARENTING", 14, 167197},
	{"VILLEFRANCHE", 12, 167198},
	{"CENELEC", 7, 167199},
	{"KOOTENAYS", 9, 167200},
	{"RBAC", 4, 167201},
	{"CASSA", 5, 167202},
	{"CREDI", 5, 167203},
	{"BRACKENRIDGE", 12, 167204},
	{"QUIZZ", 5, 167205},
	{"NOTICIA", 7, 167206},
	{"FFDSHOW", 7, 167207},
	{"WITHROW", 7, 167208},
	{"GUILDWARS", 9, 167209},
	{"SUND", 4, 167210},
	{"SUEXEC", 6, 167211},
	{"BEWLEY", 6, 167212},
	{"DERMOTT", 7, 167213},
	{"SUDA", 4, 167214},
	{"HARDWIRE", 8, 167215},
	{"HYPOGRAPHY", 10, 167216},
	{"SIGNORA", 7, 167217},
	{"REHBERG", 7, 167218},
	{"RAMPTON", 7, 167219},
	{"LOEWENSTEIN", 11, 167220},
	{"HUMANIZED", 9, 167221},
	{"COSPAR", 6, 167222},
	{"PASIG", 5, 167223},
	{"INVISIBLES", 10, 167224},
	{"PERICARDIUM", 11, 167225},
	{"FLITTING", 8, 167226},
	{"NASIK", 5, 167227},
	{"CONJUGACY", 9, 167228},
	{"XOANON", 6, 167229},
	{"MISTROKE", 8, 167230},
	{"UPORTAL", 7, 167231},
	{"KNACKERED", 9, 167232},
	{"STABILE", 7, 167233},
	{"LABORIOUSLY", 11, 167234},
	{"LIQUI", 5, 167235},
	{"GINTER", 6, 167236},
	{"PUTE", 4, 167237},
	{"YLLU", 4, 167238},
	{"WEAF", 4, 167239},
	{"UVEI", 4, 167240},
	{"UNIW", 4, 167241},
	{"TKUM", 4, 167242},
	{"SUOF", 4, 167243},
	{"REKG", 4, 167244},
	{"RAQR", 4, 167245},
	{"ONXM", 4, 167246},
	{"OFGS", 4, 167247},
	{"KMYB", 4, 167248},
	{"KMHO", 4, 167249},
	{"HIJU", 4, 167250},
	{"HBYJ", 4, 167251},
	{"GGAU", 4, 167252},
	{"GBOG", 4, 167253},
	{"FNUN", 4, 167254},
	{"FMUG", 4, 167255},
	{"EOKW", 4, 167256},
	{"EJTW", 4, 167257},
	{"DAHW", 4, 167258},
	{"AWBI", 4, 167259},
	{"ANMV", 4, 167260},
	{"MONOSODIUM", 10, 167261},
	{"CANDELARIA", 10, 167262},
	{"DOSCH", 5, 167263},
	{"MDEQ", 4, 167264},
	{"WEIDE", 5, 167265},
	{"SEBORRHEIC", 10, 167266},
	{"PHENTERIMINE", 12, 167267},
	{"INMOST", 6, 167268},
	{"TENSHI", 6, 167269},
	{"PYLORIC", 7, 167270},
	{"PIRO", 4, 167271},
	{"TRCDSEMBLNEW", 12, 167272},
	{"LIBEXIF", 7, 167273},
	{"PAESE", 5, 167274},
	{"JEHAN", 5, 167275},
	{"VORHANDEN", 9, 167276},
	{"RDMA", 4, 167277},
	{"POESIE", 6, 167278},
	{"LAFORGE", 7, 167279},
	{"CAMILLERI", 9, 167280},
	{"WORDINGS", 8, 167281},
	{"TRIAS", 5, 167282},
	{"SNUFFED", 7, 167283},
	{"ROYSE", 5, 167284},
	{"TAGAN", 5, 167285},
	{"INSTALAR", 8, 167286},
	{"TRIGON", 6, 167287},
	{"BIRDFEEDER", 10, 167288},
	{"TORK", 4, 167289},
	{"MOUNTIAN", 8, 167290},
	{"KRONEN", 6, 167291},
	{"FORTEAN", 7, 167292},
	{"MAJCOM", 6, 167293},
	{"HALYARD", 7, 167294},
	{"STONG", 5, 167295},
	{"DOUJIN", 6, 167296},
	{"CANNOT", 6, 167297},
	{"NEWSWEEKLY", 10, 167298},
	{"MIDRIFF", 7, 167299},
	{"HUTCHENS", 8, 167300},
	{"MILLIBARS", 9, 167301},
	{"FIXIN", 5, 167302},
	{"IPDS", 4, 167303},
	{"VACHE", 5, 167304},
	{"KROC", 4, 167305},
	{"EASTVIEW", 8, 167306},
	{"SPACEMEN", 8, 167307},
	{"CHADHA", 6, 167308},
	{"INETU", 5, 167309},
	{"KABUTO", 6, 167310},
	{"ARTILCE", 7, 167311},
	{"MELUNGEON", 9, 167312},
	{"LORDY", 5, 167313},
	{"WILLINGBORO", 11, 167314},
	{"HILLARIOUS", 10, 167315},
	{"DEMONOLOGY", 10, 167316},
	{"PROMED", 6, 167317},
	{"WHELEN", 6, 167318},
	{"MUELHENS", 8, 167319},
	{"SLIGHTED", 8, 167320},
	{"PROACHES", 8, 167321},
	{"CYLONS", 6, 167322},
	{"APOLLONIA", 9, 167323},
	{"RHOMB", 5, 167324},
	{"ERSTELLTE", 9, 167325},
	{"BASTYR", 6, 167326},
	{"ZSPA", 4, 167327},
	{"VSFI", 4, 167328},
	{"ULIR", 4, 167329},
	{"RIRU", 4, 167330},
	{"RIPV", 4, 167331},
	{"RIIG", 4, 167332},
	{"RCSO", 4, 167333},
	{"QUOU", 4, 167334},
	{"PMYH", 4, 167335},
	{"OMDY", 4, 167336},
	{"OEYG", 4, 167337},
	{"NYIW", 4, 167338},
	{"NLLA", 4, 167339},
	{"NCIM", 4, 167340},
	{"MYUP", 4, 167341},
	{"MUKT", 4, 167342},
	{"MIJU", 4, 167343},
	{"LOPY", 4, 167344},
	{"JUTT", 4, 167345},
	{"IBOY", 4, 167346},
	{"GJOY", 4, 167347},
	{"GDPW", 4, 167348},
	{"FCWA", 4, 167349},
	{"DUSV", 4, 167350},
	{"COEC", 4, 167351},
	{"MOSELY", 6, 167352},
	{"LOGOTOPIC", 9, 167353},
	{"CONTESTABLE", 11, 167354},
	{"JANKE", 5, 167355},
	{"TRANSMIS", 8, 167356},
	{"CASSADY", 7, 167357},
	{"TORAY", 5, 167358},
	{"KAYSVILLE", 9, 167359},
	{"TEKKEON", 7, 167360},
	{"BANDO", 5, 167361},
	{"VENTRILO", 8, 167362},
	{"KEINEN", 6, 167363},
	{"NPWS", 4, 167364},
	{"WAUNAKEE", 8, 167365},
	{"VADA", 4, 167366},
	{"MANER", 5, 167367},
	{"HAGIWARA", 8, 167368},
	{"MARJAN", 6, 167369},
	{"STAMMER", 7, 167370},
	{"KOPEL", 5, 167371},
	{"INORDINATELY", 12, 167372},
	{"ANTIFOULING", 11, 167373},
	{"BURRY", 5, 167374},
	{"FIDGET", 6, 167375},
	{"PRESSBOARD", 10, 167376},
	{"EMBARAZO", 8, 167377},
	{"STLPORT", 7, 167378},
	{"FBRANCH", 7, 167379},
	{"MAQUOKETA", 9, 167380},
	{"URLACHER", 8, 167381},
	{"MACMURRAY", 9, 167382},
	{"GRANDSTANDING", 13, 167383},
	{"ANALI", 5, 167384},
	{"FIGHTBACK", 9, 167385},
	{"MYDNS", 5, 167386},
	{"GIGANTES", 8, 167387},
	{"EICHER", 6, 167388},
	{"POPULARIZATION", 14, 167389},
	{"ADENYLYL", 8, 167390},
	{"STOCKMFR", 8, 167391},
	{"PRCHINA", 7, 167392},
	{"MOOSIC", 6, 167393},
	{"SCOPA", 5, 167394},
	{"BORST", 5, 167395},
	{"TYPI", 4, 167396},
	{"PINAS", 5, 167397},
	{"CHILDHOODS", 10, 167398},
	{"PINELAND", 8, 167399},
	{"COMPREHENDS", 11, 167400},
	{"CLOTHIERS", 9, 167401},
	{"PSGML", 5, 167402},
	{"FUAD", 4, 167403},
	{"MOORABBIN", 9, 167404},
	{"EXTROVERT", 9, 167405},
	{"HOTELBEWERTUNGEN", 16, 167406},
	{"GLEAMS", 6, 167407},
	{"YKLA", 4, 167408},
	{"UJII", 4, 167409},
	{"RRUC", 4, 167410},
	{"RAWY", 4, 167411},
	{"OBUZ", 4, 167412},
	{"OARL", 4, 167413},
	{"NKTU", 4, 167414},
	{"MZON", 4, 167415},
	{"MRIM", 4, 167416},
	{"IERQ", 4, 167417},
	{"GIBA", 4, 167418},
	{"FNBA", 4, 167419},
	{"BAIP", 4, 167420},
	{"AKOK", 4, 167421},
	{"AFAX", 4, 167422},
	{"INTERM", 6, 167423},
	{"INDEMNITEE", 10, 167424},
	{"NEBULIZERS", 10, 167425},
	{"BLOGDRIVE", 9, 167426},
	{"LILTING", 7, 167427},
	{"BEYERDYNAMIC", 12, 167428},
	{"MIDHEAVEN", 9, 167429},
	{"CHEESEBURGERS", 13, 167430},
	{"PELGRANE", 8, 167431},
	{"RIVERBOATS", 10, 167432},
	{"SECRE", 5, 167433},
	{"BOCCIA", 6, 167434},
	{"SIRLEAF", 7, 167435},
	{"RIETVELD", 8, 167436},
	{"KOCHER", 6, 167437},
	{"IRTF", 4, 167438},
	{"SWORDSMEN", 9, 167439},
	{"MCCASKILL", 9, 167440},
	{"SIEGES", 6, 167441},
	{"SPORTSCENTRE", 12, 167442},
	{"SKETCHUP", 8, 167443},
	{"SCACCHI", 7, 167444},
	{"MCDORMAND", 9, 167445},
	{"PARTICLEBOARD", 13, 167446},
	{"MOCO", 4, 167447},
	{"MAGNIFIQUE", 10, 167448},
	{"BAULKHAM", 8, 167449},
	{"MATERIALI", 9, 167450},
	{"CARICA", 6, 167451},
	{"KENSAL", 6, 167452},
	{"SPINSANITY", 10, 167453},
	{"OLIVOS", 6, 167454},
	{"TINYINT", 7, 167455},
	{"POLLUX", 6, 167456},
	{"SPEEDSTEP", 9, 167457},
	{"NAVSEA", 6, 167458},
	{"SIEBEN", 6, 167459},
	{"TPHCM", 5, 167460},
	{"SIGC", 4, 167461},
	{"INWIN", 5, 167462},
	{"MAILX", 5, 167463},
	{"KAHNEMAN", 8, 167464},
	{"MELONI", 6, 167465},
	{"NEWSBOY", 7, 167466},
	{"SHAMUS", 6, 167467},
	{"HERBOLOGY", 9, 167468},
	{"BROEK", 5, 167469},
	{"MUZZLES", 7, 167470},
	{"FLAGYL", 6, 167471},
	{"VIVACIOUSLY", 11, 167472},
	{"BUCHNER", 7, 167473},
	{"VOIGTLANDER", 11, 167474},
	{"CANCRO", 6, 167475},
	{"BACUP", 5, 167476},
	{"BALINT", 6, 167477},
	{"CYTOCHROMES", 11, 167478},
	{"SYRUPY", 6, 167479},
	{"PELEG", 5, 167480},
	{"YHUF", 4, 167481},
	{"PISJ", 4, 167482},
	{"PACB", 4, 167483},
	{"ORRT", 4, 167484},
	{"OMSV", 4, 167485},
	{"OLZO", 4, 167486},
	{"NYIC", 4, 167487},
	{"NWWE", 4, 167488},
	{"NKYP", 4, 167489},
	{"NKQU", 4, 167490},
	{"LSHF", 4, 167491},
	{"IXFU", 4, 167492},
	{"IRUB", 4, 167493},
	{"IMPC", 4, 167494},
	{"HDAW", 4, 167495},
	{"EUKU", 4, 167496},
	{"EMNL", 4, 167497},
	{"DFOW", 4, 167498},
	{"CLYP", 4, 167499},
	{"BYOI", 4, 167500},
	{"AALF", 4, 167501},
	{"STUTTGARTER", 11, 167502},
	{"GRANTSTELEVISIONSCONSUMER", 25, 167503},
	{"SWFTEXT", 7, 167504},
	{"CELTEL", 6, 167505},
	{"MACKINLAY", 9, 167506},
	{"ACCURA", 6, 167507},
	{"GIDLEY", 6, 167508},
	{"BALLANCE", 8, 167509},
	{"ATHOLL", 6, 167510},
	{"METROPOLITANA", 13, 167511},
	{"BALLEW", 6, 167512},
	{"DOWNREGULATION", 14, 167513},
	{"COMI", 4, 167514},
	{"YANGZHOU", 8, 167515},
	{"PUNIC", 5, 167516},
	{"COLLEAGUEEMAIL", 14, 167517},
	{"ALAMIN", 6, 167518},
	{"ARTERIOSUS", 10, 167519},
	{"PDMS", 4, 167520},
	{"NECTION", 7, 167521},
	{"PARTYGAMING", 11, 167522},
	{"LUCRE", 5, 167523},
	{"SOCAN", 5, 167524},
	{"PEGA", 4, 167525},
	{"COMPLIANCY", 10, 167526},
	{"ZUCCHERO", 8, 167527},
	{"XCEED", 5, 167528},
	{"PRECIPITOUSLY", 13, 167529},
	{"ROSLE", 5, 167530},
	{"SIZZLES", 7, 167531},
	{"TOMALES", 7, 167532},
	{"COMPULSIVELY", 12, 167533},
	{"CYNDY", 5, 167534},
	{"ILION", 5, 167535},
	{"FBLA", 4, 167536},
	{"TURNIN", 6, 167537},
	{"KOTTER", 6, 167538},
	{"FULANI", 6, 167539},
	{"COLLECTIVIST", 12, 167540},
	{"ATECH", 5, 167541},
	{"BESOUGHT", 8, 167542},
	{"VINTNER", 7, 167543},
	{"POSTRETIREMENT", 14, 167544},
	{"HASSY", 5, 167545},
	{"UNSCREWING", 10, 167546},
	{"DOAR", 4, 167547},
	{"LUF", 3, 167548},
	{"CRONK", 5, 167549},
	{"ROCKETING", 9, 167550},
	{"KWOH", 4, 167551},
	{"CHGRP", 5, 167552},
	{"ACROSTIC", 8, 167553},
	{"MODIFIANT", 9, 167554},
	{"ZAANDAM", 7, 167555},
	{"ALAWAR", 6, 167556},
	{"DEBARY", 6, 167557},
	{"CLAUSEWITZ", 10, 167558},
	{"XAWA", 4, 167559},
	{"THPC", 4, 167560},
	{"SKTR", 4, 167561},
	{"RSUK", 4, 167562},
	{"RJIA", 4, 167563},
	{"RJAF", 4, 167564},
	{"RIMY", 4, 167565},
	{"REXG", 4, 167566},
	{"RDZI", 4, 167567},
	{"QUIO", 4, 167568},
	{"PWIS", 4, 167569},
	{"OMFT", 4, 167570},
	{"MDAW", 4, 167571},
	{"KOVC", 4, 167572},
	{"JOAK", 4, 167573},
	{"HWEP", 4, 167574},
	{"GPES", 4, 167575},
	{"DDSR", 4, 167576},
	{"DANQ", 4, 167577},
	{"ANLP", 4, 167578},
	{"SPEEDPLAY", 9, 167579},
	{"VUELO", 5, 167580},
	{"TORUN", 5, 167581},
	{"PREPRODUCTION", 13, 167582},
	{"FEATU", 5, 167583},
	{"PISANI", 6, 167584},
	{"RIVARD", 6, 167585},
	{"HAPAG", 5, 167586},
	{"GRISTLE", 7, 167587},
	{"KADA", 4, 167588},
	{"REFRACTED", 9, 167589},
	{"JURKAT", 6, 167590},
	{"NMHC", 4, 167591},
	{"STEELES", 7, 167592},
	{"RICCO", 5, 167593},
	{"SYSKLOGD", 8, 167594},
	{"CHIASSON", 8, 167595},
	{"FALDO", 5, 167596},
	{"ROCKALL", 7, 167597},
	{"CONFIGURA", 9, 167598},
	{"IDISK", 5, 167599},
	{"DEGASSING", 9, 167600},
	{"SSESSMENT", 9, 167601},
	{"JDG", 3, 167602},
	{"TIBBS", 5, 167603},
	{"WEALDEN", 7, 167604},
	{"DEVCOUNTER", 10, 167605},
	{"ONLNIE", 6, 167606},
	{"FOSSUM", 6, 167607},
	{"VOLLEDIGE", 9, 167608},
	{"KORGANIZER", 10, 167609},
	{"SPACEBORNE", 10, 167610},
	{"ADVERTENTIE", 11, 167611},
	{"VIDEOSZ", 7, 167612},
	{"SAMAN", 5, 167613},
	{"HUNKER", 6, 167614},
	{"ABOR", 4, 167615},
	{"LIBGCRYPT", 9, 167616},
	{"BUYAGIFT", 8, 167617},
	{"TURI", 4, 167618},
	{"BERATUNG", 8, 167619},
	{"MIDIAN", 6, 167620},
	{"WILLENHALL", 10, 167621},
	{"MICKIE", 6, 167622},
	{"NATPE", 5, 167623},
	{"DEPLORES", 8, 167624},
	{"JIMINY", 6, 167625},
	{"MANCHIN", 7, 167626},
	{"NOISEMAKERS", 11, 167627},
	{"ANTARI", 6, 167628},
	{"REHOVOT", 7, 167629},
	{"INTERSYSTEMS", 12, 167630},
	{"BRIGHTMAIL", 10, 167631},
	{"STANDA", 6, 167632},
	{"RESTRICTOR", 10, 167633},
	{"NAZIR", 5, 167634},
	{"PHOSPHOPROTEINS", 15, 167635},
	{"FRIENDTELL", 10, 167636},
	{"CHARLE", 6, 167637},
	{"LINCOLNVILLE", 12, 167638},
	{"JETLINER", 8, 167639},
	{"EPIRUS", 6, 167640},
	{"ZPL", 3, 167641},
	{"IPOINTS", 7, 167642},
	{"CURREY", 6, 167643},
	{"VIDEOBLOGGING", 13, 167644},
	{"ZZMA", 4, 167645},
	{"WMUN", 4, 167646},
	{"URQA", 4, 167647},
	{"URMS", 4, 167648},
	{"RAKM", 4, 167649},
	{"OMYV", 4, 167650},
	{"LYKU", 4, 167651},
	{"KOAK", 4, 167652},
	{"IPCI", 4, 167653},
	{"FIGY", 4, 167654},
	{"EPCT", 4, 167655},
	{"EDCN", 4, 167656},
	{"DSLY", 4, 167657},
	{"DICV", 4, 167658},
	{"DFUG", 4, 167659},
	{"BCSW", 4, 167660},
	{"AVSM", 4, 167661},
	{"NETJUKE", 7, 167662},
	{"BERTON", 6, 167663},
	{"ADAK", 4, 167664},
	{"LAURYL", 6, 167665},
	{"HYPERTERMINAL", 13, 167666},
	{"FANTASTIQUE", 11, 167667},
	{"DIGIBLAST", 9, 167668},
	{"ARANEAE", 7, 167669},
	{"FERNY", 5, 167670},
	{"BLUESTEM", 8, 167671},
	{"SENECIO", 7, 167672},
	{"HARGIS", 6, 167673},
	{"MARIT", 5, 167674},
	{"PANTOTHENATE", 12, 167675},
	{"GEZONDHEIDSZORG", 15, 167676},
	{"SOFTBALLS", 9, 167677},
	{"ANACONDAS", 9, 167678},
	{"TILBAGE", 7, 167679},
	{"TRACHEOPHYTA", 12, 167680},
	{"MRX", 3, 167681},
	{"SDSM", 4, 167682},
	{"RTPI", 4, 167683},
	{"REACTANCE", 9, 167684},
	{"IITTALA", 7, 167685},
	{"ASTERN", 6, 167686},
	{"WILDOMAR", 8, 167687},
	{"SAXEXCEPTION", 12, 167688},
	{"LEFRANC", 7, 167689},
	{"PELTED", 6, 167690},
	{"NSPIRE", 6, 167691},
	{"STOUTLY", 7, 167692},
	{"FLEXCODERS", 10, 167693},
	{"SPECTRIN", 8, 167694},
	{"STRATHAIRN", 10, 167695},
	{"PCSUPERDEALS", 12, 167696},
	{"VERGNE", 6, 167697},
	{"VANDOREN", 8, 167698},
	{"EPIPHANIES", 10, 167699},
	{"LINDORFF", 8, 167700},
	{"FLOATY", 6, 167701},
	{"IPPR", 4, 167702},
	{"DISKUS", 6, 167703},
	{"CLAYWORKS", 9, 167704},
	{"VESTIGIAL", 9, 167705},
	{"GLASSED", 7, 167706},
	{"INSINUATING", 11, 167707},
	{"MASIH", 5, 167708},
	{"MIROKU", 6, 167709},
	{"GASTHOF", 7, 167710},
	{"FACILITATIVE", 12, 167711},
	{"INVENTORYVIEW", 13, 167712},
	{"BAGOT", 5, 167713},
	{"FORMAC", 6, 167714},
	{"KITARO", 6, 167715},
	{"CARSS", 5, 167716},
	{"CUFFLINK", 8, 167717},
	{"BEZOS", 5, 167718},
	{"SRFI", 4, 167719},
	{"MMW", 3, 167720},
	{"BOUDJNAH", 8, 167721},
	{"EDMUNDSON", 9, 167722},
	{"RETREADING", 10, 167723},
	{"MALU", 4, 167724},
	{"HAYNIE", 6, 167725},
	{"PHOTODIODES", 11, 167726},
	{"PENNYROYAL", 10, 167727},
	{"YAJE", 4, 167728},
	{"XBAC", 4, 167729},
	{"UEXC", 4, 167730},
	{"TYLT", 4, 167731},
	{"RYNC", 4, 167732},
	{"RPMF", 4, 167733},
	{"ROBF", 4, 167734},
	{"OFXM", 4, 167735},
	{"OCHK", 4, 167736},
	{"LSIW", 4, 167737},
	{"LNAP", 4, 167738},
	{"LAKW", 4, 167739},
	{"KYOG", 4, 167740},
	{"KTUE", 4, 167741},
	{"KDJO", 4, 167742},
	{"GOLT", 4, 167743},
	{"ELUJ", 4, 167744},
	{"DSKR", 4, 167745},
	{"DPIM", 4, 167746},
	{"DCSI", 4, 167747},
	{"CMIR", 4, 167748},
	{"CKJR", 4, 167749},
	{"CCIL", 4, 167750},
	{"BTIF", 4, 167751},
	{"BOTU", 4, 167752},
	{"BOOC", 4, 167753},
	{"TRUCKED", 7, 167754},
	{"KONTRON", 7, 167755},
	{"CHAMBERY", 8, 167756},
	{"ADENOSYL", 8, 167757},
	{"ZAWYA", 5, 167758},
	{"SIGHUP", 6, 167759},
	{"RECONFIRMED", 11, 167760},
	{"CEYHAN", 6, 167761},
	{"TEVION", 6, 167762},
	{"EVATT", 5, 167763},
	{"LAREN", 5, 167764},
	{"SUBINTERFACES", 13, 167765},
	{"VLM", 3, 167766},
	{"CARDIOSPORT", 11, 167767},
	{"SEROPREVALENCE", 14, 167768},
	{"BARDON", 6, 167769},
	{"CHORI", 5, 167770},
	{"MMII", 4, 167771},
	{"PICHON", 6, 167772},
	{"DAPIBUS", 7, 167773},
	{"AUGE", 4, 167774},
	{"SIBIU", 5, 167775},
	{"LEIB", 4, 167776},
	{"PERMITE", 7, 167777},
	{"COLLARBONE", 10, 167778},
	{"KEAUHOU", 7, 167779},
	{"DESCHANEL", 9, 167780},
	{"AMODAU", 6, 167781},
	{"ANTHURIUM", 9, 167782},
	{"COMPANHIA", 9, 167783},
	{"URG", 3, 167784},
	{"SPEEDUPS", 8, 167785},
	{"PRAZOSIN", 8, 167786},
	{"DIEMEN", 6, 167787},
	{"CONTINUITIES", 12, 167788},
	{"UNEQUALLY", 9, 167789},
	{"EMBRYOPHYTA", 11, 167790},
	{"CANDELABRAS", 11, 167791},
	{"TRUMPETING", 10, 167792},
	{"FIORD", 5, 167793},
	{"VPM", 3, 167794},
	{"DEQUE", 5, 167795},
	{"WUMM", 4, 167796},
	{"OBLINE", 6, 167797},
	{"CROWTHORNE", 10, 167798},
	{"INDIAS", 6, 167799},
	{"JADES", 5, 167800},
	{"FLX", 3, 167801},
	{"GESSO", 5, 167802},
	{"SYNDROM", 7, 167803},
	{"TIREE", 5, 167804},
	{"FAIRLIGHT", 9, 167805},
	{"PRIVO", 5, 167806},
	{"AMEY", 4, 167807},
	{"LUXUARY", 7, 167808},
	{"NIPLES", 6, 167809},
	{"HOMEOPATHS", 10, 167810},
	{"LITMAN", 6, 167811},
	{"TRANSLUMINAL", 12, 167812},
	{"TANNEN", 6, 167813},
	{"PROFLIGATE", 10, 167814},
	{"PITTI", 5, 167815},
	{"CELEMONY", 8, 167816},
	{"SEFYDLIAD", 9, 167817},
	{"SATED", 5, 167818},
	{"VERWENDEN", 9, 167819},
	{"STAGNITO", 8, 167820},
	{"BEDRIJVEN", 9, 167821},
	{"EXPLANTS", 8, 167822},
	{"EXPANDAFTER", 11, 167823},
	{"ACTIVEMQ", 8, 167824},
	{"PHINN", 5, 167825},
	{"NEIWERT", 7, 167826},
	{"DUMPY", 5, 167827},
	{"YMWA", 4, 167828},
	{"YFUG", 4, 167829},
	{"XYIS", 4, 167830},
	{"UYUK", 4, 167831},
	{"UYEA", 4, 167832},
	{"UVUZ", 4, 167833},
	{"RMWR", 4, 167834},
	{"OYOM", 4, 167835},
	{"OJVO", 4, 167836},
	{"OEYL", 4, 167837},
	{"MDUK", 4, 167838},
	{"KSEG", 4, 167839},
	{"JAHW", 4, 167840},
	{"IMZO", 4, 167841},
	{"IBMW", 4, 167842},
	{"EZLI", 4, 167843},
	{"EKPI", 4, 167844},
	{"EJOD", 4, 167845},
	{"EGFI", 4, 167846},
	{"AKYF", 4, 167847},
	{"EUXTON", 6, 167848},
	{"TONALE", 6, 167849},
	{"MACNEWSWORLD", 12, 167850},
	{"GADGETEER", 9, 167851},
	{"BURKES", 6, 167852},
	{"WATTON", 6, 167853},
	{"POER", 4, 167854},
	{"OLUSEGUN", 8, 167855},
	{"DRUSUS", 6, 167856},
	{"ORDINATEURS", 11, 167857},
	{"AXELSFUN", 8, 167858},
	{"BORAL", 5, 167859},
	{"REPACKAGE", 9, 167860},
	{"ADEMCO", 6, 167861},
	{"SUPERCELL", 9, 167862},
	{"INTERACTIONAL", 13, 167863},
	{"CSPAN", 5, 167864},
	{"PROTEZIONE", 10, 167865},
	{"MARANELLO", 9, 167866},
	{"HIGHBROW", 8, 167867},
	{"CHIEMSEE", 8, 167868},
	{"PUSHIN", 6, 167869},
	{"APPRISE", 7, 167870},
	{"LURA", 4, 167871},
	{"COOTE", 5, 167872},
	{"DEMONIKA", 8, 167873},
	{"RUHL", 4, 167874},
	{"LBM", 3, 167875},
	{"INVERSIONES", 11, 167876},
	{"SYLLABIC", 8, 167877},
	{"QUIGGIN", 7, 167878},
	{"IMAD", 4, 167879},
	{"BOBTAIL", 7, 167880},
	{"VOGLER", 6, 167881},
	{"CICEK", 5, 167882},
	{"OUTRA", 5, 167883},
	{"DEFORMING", 9, 167884},
	{"RIEDELL", 7, 167885},
	{"HETEROZYGOTE", 12, 167886},
	{"NEWSPEAK", 8, 167887},
	{"COSTUMI", 7, 167888},
	{"BOTHE", 5, 167889},
	{"OVERESTIMATION", 14, 167890},
	{"FLUVANNA", 8, 167891},
	{"WURTTEMBERG", 11, 167892},
	{"EXACTSEARCH", 11, 167893},
	{"GODA", 4, 167894},
	{"GIMBAL", 6, 167895},
	{"NCPTT", 5, 167896},
	{"KAYLEIGH", 8, 167897},
	{"UNFORSEEN", 9, 167898},
	{"KRAKEN", 6, 167899},
	{"BEADY", 5, 167900},
	{"SEELYE", 6, 167901},
	{"VERONICAS", 9, 167902},
	{"KHAIMAH", 7, 167903},
	{"APPERCEPTION", 12, 167904},
	{"AUKTION", 7, 167905},
	{"YLIU", 4, 167906},
	{"YEWO", 4, 167907},
	{"VOYI", 4, 167908},
	{"VDWA", 4, 167909},
	{"URUO", 4, 167910},
	{"SSRW", 4, 167911},
	{"PTDR", 4, 167912},
	{"PSIW", 4, 167913},
	{"PRYI", 4, 167914},
	{"PHYX", 4, 167915},
	{"MGMS", 4, 167916},
	{"LUMU", 4, 167917},
	{"KMYH", 4, 167918},
	{"KBUN", 4, 167919},
	{"KACU", 4, 167920},
	{"FYMO", 4, 167921},
	{"FGUT", 4, 167922},
	{"BYLT", 4, 167923},
	{"ALNG", 4, 167924},
	{"ZIPREALTY", 9, 167925},
	{"SLAPSHOT", 8, 167926},
	{"ASSOCIATIONAL", 13, 167927},
	{"WINTERSET", 9, 167928},
	{"PEOLE", 5, 167929},
	{"SEASILVER", 9, 167930},
	{"TUAREG", 6, 167931},
	{"OBERST", 6, 167932},
	{"CEDIA", 5, 167933},
	{"PYAAR", 5, 167934},
	{"ABDICATED", 9, 167935},
	{"WUGNET", 6, 167936},
	{"KOMPUTER", 8, 167937},
	{"ASCOMYCOTA", 10, 167938},
	{"CATATONIC", 9, 167939},
	{"VEYRON", 6, 167940},
	{"SQUASHES", 8, 167941},
	{"TIFY", 4, 167942},
	{"REVERIES", 8, 167943},
	{"PRIMIGI", 7, 167944},
	{"SCOTTO", 6, 167945},
	{"OKAMURA", 7, 167946},
	{"CLIFFOSAKAJAPAN", 15, 167947},
	{"GODSPELL", 8, 167948},
	{"APRILS", 6, 167949},
	{"RELATOR", 7, 167950},
	{"HAUTEUR", 7, 167951},
	{"UNIVERSITATIS", 13, 167952},
	{"SULLIVANS", 9, 167953},
	{"RULESETS", 8, 167954},
	{"UNERRING", 8, 167955},
	{"SPINSILLY", 9, 167956},
	{"MCCUSKER", 8, 167957},
	{"ARTER", 5, 167958},
	{"GCMS", 4, 167959},
	{"STHENIC", 7, 167960},
	{"EYESAVE", 7, 167961},
	{"CIALS", 5, 167962},
	{"OECOLOGIA", 9, 167963},
	{"PARENTI", 7, 167964},
	{"EUER", 4, 167965},
	{"SERKIS", 6, 167966},
	{"WEDDINGTON", 10, 167967},
	{"AMETEUR", 7, 167968},
	{"PRITZKER", 8, 167969},
	{"TAFB", 4, 167970},
	{"SPACESHIPONE", 12, 167971},
	{"ESOMEPRAZOLE", 12, 167972},
	{"UEMURA", 6, 167973},
	{"SERLING", 7, 167974},
	{"WAFTING", 7, 167975},
	{"ROHL", 4, 167976},
	{"HEADBANGER", 10, 167977},
	{"UNREACHED", 9, 167978},
	{"ISOPROPANOL", 11, 167979},
	{"PACKATAC", 8, 167980},
	{"DATREK", 6, 167981},
	{"REFRACTOMETER", 13, 167982},
	{"BIONET", 6, 167983},
	{"PRECISA", 7, 167984},
	{"MASKHADOV", 9, 167985},
	{"GLASHUTTE", 9, 167986},
	{"SHRADER", 7, 167987},
	{"POPPEN", 6, 167988},
	{"BURLING", 7, 167989},
	{"WHINER", 6, 167990},
	{"STROMBOLI", 9, 167991},
	{"SLIPPY", 6, 167992},
	{"ELECTRONI", 9, 167993},
	{"BERGENFIELD", 11, 167994},
	{"MAULER", 6, 167995},
	{"ZZFO", 4, 167996},
	{"WDWE", 4, 167997},
	{"TUMR", 4, 167998},
	{"SAMJ", 4, 167999},
	{"PPSY", 4, 168000},
	{"PMUR", 4, 168001},
	{"OMCB", 4, 168002},
	{"OKUI", 4, 168003},
	{"MUKE", 4, 168004},
	{"LTDP", 4, 168005},
	{"LRHO", 4, 168006},
	{"LIUX", 4, 168007},
	{"EXBY", 4, 168008},
	{"EGBL", 4, 168009},
	{"EDBM", 4, 168010},
	{"CYGN", 4, 168011},
	{"CGUA", 4, 168012},
	{"BURQ", 4, 168013},
	{"BTLO", 4, 168014},
	{"BKNO", 4, 168015},
	{"BIFU", 4, 168016},
	{"AVWA", 4, 168017},
	{"AUBS", 4, 168018},
	{"ACPU", 4, 168019},
	{"MAGICS", 6, 168020},
	{"REDECORATED", 11, 168021},
	{"LIBRANET", 8, 168022},
	{"SOFTGEL", 7, 168023},
	{"SCIENTIA", 8, 168024},
	{"BLOTCH", 6, 168025},
	{"BLASER", 6, 168026},
	{"ANTIEPILEPTIC", 13, 168027},
	{"RUSTBELT", 8, 168028},
	{"QUOGUE", 6, 168029},
	{"CRATON", 6, 168030},
	{"BELITTLING", 10, 168031},
	{"TRELLEBORG", 10, 168032},
	{"CARREL", 6, 168033},
	{"JABALPUR", 8, 168034},
	{"SMBCLIENT", 9, 168035},
	{"SHEEPSHEAD", 10, 168036},
	{"NYQUIL", 6, 168037},
	{"DRAZEN", 6, 168038},
	{"KINGAROY", 8, 168039},
	{"INFORMACJE", 10, 168040},
	{"PHOTS", 5, 168041},
	{"JUSTINA", 7, 168042},
	{"OCTREOTIDE", 10, 168043},
	{"CRDS", 4, 168044},
	{"EBROCHURES", 10, 168045},
	{"VITOL", 5, 168046},
	{"ARNG", 4, 168047},
	{"UNSHAKABLE", 10, 168048},
	{"GYNAECOLOGISTS", 14, 168049},
	{"FUJIKO", 6, 168050},
	{"TITILLATING", 11, 168051},
	{"QUICKSORT", 9, 168052},
	{"GROSSMANN", 9, 168053},
	{"PCAOB", 5, 168054},
	{"NONEXISTENCE", 12, 168055},
	{"DENIZEN", 7, 168056},
	{"MANTEGNA", 8, 168057},
	{"ELEGIAC", 7, 168058},
	{"SAVAS", 5, 168059},
	{"FFESTINIOG", 10, 168060},
	{"RUSTIN", 6, 168061},
	{"LYRICISTS", 9, 168062},
	{"MULTIBEAM", 9, 168063},
	{"HICSS", 5, 168064},
	{"GOGGIN", 6, 168065},
	{"FREDERICKSON", 12, 168066},
	{"ARTIFICIALINTEL", 15, 168067},
	{"WILM", 4, 168068},
	{"BIVOUAC", 7, 168069},
	{"SUPERJOINT", 10, 168070},
	{"SPACEWALK", 9, 168071},
	{"ORNERY", 6, 168072},
	{"HAMMY", 5, 168073},
	{"CARVEDILOL", 10, 168074},
	{"GPCR", 4, 168075},
	{"BVPI", 4, 168076},
	{"SUPERSCRIPTS", 12, 168077},
	{"SECESSIONIST", 12, 168078},
	{"NULLFONT", 8, 168079},
	{"MVOIES", 6, 168080},
	{"ZISF", 4, 168081},
	{"WDUN", 4, 168082},
	{"TVFI", 4, 168083},
	{"SEKR", 4, 168084},
	{"RZEI", 4, 168085},
	{"RMUK", 4, 168086},
	{"PILB", 4, 168087},
	{"NUNZ", 4, 168088},
	{"NUGI", 4, 168089},
	{"NPMF", 4, 168090},
	{"LNUN", 4, 168091},
	{"JITR", 4, 168092},
	{"IXSY", 4, 168093},
	{"INZW", 4, 168094},
	{"IFLY", 4, 168095},
	{"HUBT", 4, 168096},
	{"HEWV", 4, 168097},
	{"HBUG", 4, 168098},
	{"GOWT", 4, 168099},
	{"FCWH", 4, 168100},
	{"EKCE", 4, 168101},
	{"EBFI", 4, 168102},
	{"DTVT", 4, 168103},
	{"CINU", 4, 168104},
	{"BIDM", 4, 168105},
	{"BEAZ", 4, 168106},
	{"BBSD", 4, 168107},
	{"AVSP", 4, 168108},
	{"AMTY", 4, 168109},
	{"MATSU", 5, 168110},
	{"REMEMBERANCE", 12, 168111},
	{"MADDALENA", 9, 168112},
	{"OWAIN", 5, 168113},
	{"NEWBERN", 7, 168114},
	{"WHEELSET", 8, 168115},
	{"CONCLU", 6, 168116},
	{"DARKBLUE", 8, 168117},
	{"HILFREICH", 9, 168118},
	{"ANAESTHETIST", 12, 168119},
	{"RIVERBANKS", 10, 168120},
	{"GDVD", 4, 168121},
	{"CMES", 4, 168122},
	{"SYMINGTON", 9, 168123},
	{"MAHLON", 6, 168124},
	{"BRONC", 5, 168125},
	{"OPENDEMOCRACY", 13, 168126},
	{"LEZZIES", 7, 168127},
	{"LAFUMA", 6, 168128},
	{"CINEMATHEQUE", 12, 168129},
	{"SIMILAC", 7, 168130},
	{"GAINFULLY", 9, 168131},
	{"DOGGEDLY", 8, 168132},
	{"GONORRHOEA", 10, 168133},
	{"PREMIERING", 10, 168134},
	{"SAMCO", 5, 168135},
	{"MCCATHIENEVILE", 14, 168136},
	{"IMMED", 5, 168137},
	{"ROSEBUDS", 8, 168138},
	{"JEANE", 5, 168139},
	{"FASTETHERNET", 12, 168140},
	{"BOXX", 4, 168141},
	{"SYSTEMEN", 8, 168142},
	{"REDPATH", 7, 168143},
	{"LOCKMAN", 7, 168144},
	{"ECKART", 6, 168145},
	{"TATTOOD", 7, 168146},
	{"MINET", 5, 168147},
	{"VALUEERROR", 10, 168148},
	{"THIMPHU", 7, 168149},
	{"BRIOCHE", 7, 168150},
	{"CSTRIKE", 7, 168151},
	{"BOGUT", 5, 168152},
	{"BALDI", 5, 168153},
	{"LEATHERWOOD", 11, 168154},
	{"CAROLINIANS", 11, 168155},
	{"UALITY", 6, 168156},
	{"ROGIER", 6, 168157},
	{"AKKADIAN", 8, 168158},
	{"VLADO", 5, 168159},
	{"BORCHERS", 8, 168160},
	{"HERMANO", 7, 168161},
	{"FLOSSIN", 7, 168162},
	{"CARHART", 7, 168163},
	{"CARLINVILLE", 11, 168164},
	{"SIXONETONOFFUN", 14, 168165},
	{"LOGONS", 6, 168166},
	{"REVERBERATIONS", 14, 168167},
	{"CALGON", 6, 168168},
	{"EPISIOTOMY", 10, 168169},
	{"SPELEN", 6, 168170},
	{"LADYSHIP", 8, 168171},
	{"PACOIMA", 7, 168172},
	{"KNEELED", 7, 168173},
	{"BUCKLIN", 7, 168174},
	{"LONGE", 5, 168175},
	{"RIRE", 4, 168176},
	{"ALCAM", 5, 168177},
	{"ZYBE", 4, 168178},
	{"YMAZ", 4, 168179},
	{"YETJ", 4, 168180},
	{"XYLA", 4, 168181},
	{"WURS", 4, 168182},
	{"UZHI", 4, 168183},
	{"UYRA", 4, 168184},
	{"UXKE", 4, 168185},
	{"UKEJ", 4, 168186},
	{"TPIK", 4, 168187},
	{"TJIL", 4, 168188},
	{"RYAE", 4, 168189},
	{"RPUE", 4, 168190},
	{"OPIX", 4, 168191},
	{"OKOC", 4, 168192},
	{"OEYW", 4, 168193},
	{"NGBC", 4, 168194},
	{"MPAQ", 4, 168195},
	{"MLYL", 4, 168196},
	{"HLDQ", 4, 168197},
	{"HCYP", 4, 168198},
	{"GIEJ", 4, 168199},
	{"FQIN", 4, 168200},
	{"EMRW", 4, 168201},
	{"EJOV", 4, 168202},
	{"CBLE", 4, 168203},
	{"HEIFETZ", 7, 168204},
	{"DANGOS", 6, 168205},
	{"BULLONEY", 8, 168206},
	{"SCANDANAVIAN", 12, 168207},
	{"PTOLEMAIC", 9, 168208},
	{"WAPPINGERS", 10, 168209},
	{"MARCHA", 6, 168210},
	{"EDUBUNTU", 8, 168211},
	{"UNDERREPORTED", 13, 168212},
	{"SHIVAJI", 7, 168213},
	{"NESTLINGS", 9, 168214},
	{"COMMI", 5, 168215},
	{"CHEMDEX", 7, 168216},
	{"KREWE", 5, 168217},
	{"DEFAMED", 7, 168218},
	{"SOLUBILIZED", 11, 168219},
	{"LLW", 3, 168220},
	{"CALEND", 6, 168221},
	{"TOOLBOOK", 8, 168222},
	{"MBG", 3, 168223},
	{"PROBLEMATICAL", 13, 168224},
	{"SPERME", 6, 168225},
	{"CYCLERY", 7, 168226},
	{"CORNFLAKES", 10, 168227},
	{"CAFR", 4, 168228},
	{"ALAINA", 6, 168229},
	{"HICKOX", 6, 168230},
	{"FUZZIES", 7, 168231},
	{"SOMER", 5, 168232},
	{"WILLMOTT", 8, 168233},
	{"POSTINST", 8, 168234},
	{"TITLEINDEX", 10, 168235},
	{"TANDEN", 6, 168236},
	{"CAMDENTON", 9, 168237},
	{"SIMMERS", 7, 168238},
	{"ROBBO", 5, 168239},
	{"MICELLAR", 8, 168240},
	{"VCCS", 4, 168241},
	{"KREISLER", 8, 168242},
	{"GODERICH", 8, 168243},
	{"BIFOLD", 6, 168244},
	{"LEXICOGRAPHIC", 13, 168245},
	{"HVACR", 5, 168246},
	{"ESCAPEE", 7, 168247},
	{"FREEBURG", 8, 168248},
	{"CRACKLED", 8, 168249},
	{"DALA", 4, 168250},
	{"XFC", 3, 168251},
	{"NATRA", 5, 168252},
	{"UMBRELLO", 8, 168253},
	{"BODHISATTVAS", 12, 168254},
	{"ARTIEST", 7, 168255},
	{"PREMACHANDRAN", 13, 168256},
	{"DOWNTON", 7, 168257},
	{"PLEN", 4, 168258},
	{"LIBGNOMEPRINT", 13, 168259},
	{"SUNGAI", 6, 168260},
	{"UNCOMMENTED", 11, 168261},
	{"GRANTSTELEVISIONS", 17, 168262},
	{"PHOSPHOTYROSINE", 15, 168263},
	{"HISSY", 5, 168264},
	{"CAMIS", 5, 168265},
	{"DEFENCELESS", 11, 168266},
	{"ZOOMER", 6, 168267},
	{"STANTHORPE", 10, 168268},
	{"PRICKING", 8, 168269},
	{"PALANCE", 7, 168270},
	{"ROTHERHITHE", 11, 168271},
	{"LEVITZ", 6, 168272},
	{"KIPS", 4, 168273},
	{"SHORTIE", 7, 168274},
	{"MOBBED", 6, 168275},
	{"HENDY", 5, 168276},
	{"EXPROPRIATED", 12, 168277},
	{"YKAZ", 4, 168278},
	{"WNUC", 4, 168279},
	{"USKT", 4, 168280},
	{"UHUN", 4, 168281},
	{"ROBN", 4, 168282},
	{"PMEI", 4, 168283},
	{"OYKE", 4, 168284},
	{"OCTM", 4, 168285},
	{"MJAS", 4, 168286},
	{"MESZ", 4, 168287},
	{"KAYP", 4, 168288},
	{"JTRA", 4, 168289},
	{"IJDE", 4, 168290},
	{"HOPV", 4, 168291},
	{"GGOF", 4, 168292},
	{"ELUZ", 4, 168293},
	{"CRME", 4, 168294},
	{"BTAC", 4, 168295},
	{"AICF", 4, 168296},
	{"SPURR", 5, 168297},
	{"HEALTHBEAT", 10, 168298},
	{"UNIVERSUM", 9, 168299},
	{"ROSIER", 6, 168300},
	{"COLORANT", 8, 168301},
	{"INTERLOCUTORS", 13, 168302},
	{"PLASTIQUE", 9, 168303},
	{"INVALIDS", 8, 168304},
	{"EILAND", 6, 168305},
	{"BELLSHILL", 9, 168306},
	{"SUREWOOD", 8, 168307},
	{"DHONI", 5, 168308},
	{"HARDWAR", 7, 168309},
	{"LIBEREC", 7, 168310},
	{"HARBOURING", 10, 168311},
	{"AMERIQUE", 8, 168312},
	{"WOOMERA", 7, 168313},
	{"CATGEEK", 7, 168314},
	{"DOWNSVIEW", 9, 168315},
	{"RHYOLITE", 8, 168316},
	{"UNPRIVILEGED", 12, 168317},
	{"WOTY", 4, 168318},
	{"RESEAR", 6, 168319},
	{"WINNIPESAUKEE", 13, 168320},
	{"NCLR", 4, 168321},
	{"GOUNA", 5, 168322},
	{"CARRI", 5, 168323},
	{"BLACKGIRLS", 10, 168324},
	{"USEDCAR", 7, 168325},
	{"LAPWING", 7, 168326},
	{"WHITWELL", 8, 168327},
	{"ELLMAN", 6, 168328},
	{"SQUEE", 5, 168329},
	{"ELPHINSTONE", 11, 168330},
	{"DROITE", 6, 168331},
	{"PAGEL", 5, 168332},
	{"WAPITI", 6, 168333},
	{"BATTLECRY", 9, 168334},
	{"FASTENS", 7, 168335},
	{"RESERV", 6, 168336},
	{"CANTILEVERED", 12, 168337},
	{"PAYSAGE", 7, 168338},
	{"MPK", 3, 168339},
	{"MOTGAGE", 7, 168340},
	{"CASCADA", 7, 168341},
	{"DECIMATE", 8, 168342},
	{"MEGATECH", 8, 168343},
	{"EUKANUBA", 8, 168344},
	{"ECKARDT", 7, 168345},
	{"SABU", 4, 168346},
	{"SCOOBIE", 7, 168347},
	{"ECLAC", 5, 168348},
	{"TURLINGTON", 10, 168349},
	{"CREWING", 7, 168350},
	{"SAMPDORIA", 9, 168351},
	{"FLESHLY", 7, 168352},
	{"MINDSEED", 8, 168353},
	{"BEDREST", 7, 168354},
	{"FLATTENS", 8, 168355},
	{"PILLOWTOP", 9, 168356},
	{"HERZL", 5, 168357},
	{"SPANISCH", 8, 168358},
	{"MUSIQUES", 8, 168359},
	{"PRICELEAP", 9, 168360},
	{"MAXLEN", 6, 168361},
	{"YEMU", 4, 168362},
	{"WEIW", 4, 168363},
	{"WBIO", 4, 168364},
	{"ULFH", 4, 168365},
	{"UGSY", 4, 168366},
	{"UGAP", 4, 168367},
	{"UDPO", 4, 168368},
	{"SZAG", 4, 168369},
	{"SMCF", 4, 168370},
	{"RFSI", 4, 168371},
	{"OYMY", 4, 168372},
	{"OFRP", 4, 168373},
	{"NKIG", 4, 168374},
	{"MVPC", 4, 168375},
	{"MPEV", 4, 168376},
	{"MBYU", 4, 168377},
	{"LYSV", 4, 168378},
	{"KYNA", 4, 168379},
	{"KMAJ", 4, 168380},
	{"IAGL", 4, 168381},
	{"FKWA", 4, 168382},
	{"FEYN", 4, 168383},
	{"DULJ", 4, 168384},
	{"COBZ", 4, 168385},
	{"CBIG", 4, 168386},
	{"BCBR", 4, 168387},
	{"AWGE", 4, 168388},
	{"SIERPINSKI", 10, 168389},
	{"WICHMANN", 8, 168390},
	{"MACHETES", 8, 168391},
	{"LATERS", 6, 168392},
	{"AMPEX", 5, 168393},
	{"FAIRES", 6, 168394},
	{"NONIONIC", 8, 168395},
	{"AIPHONE", 7, 168396},
	{"SHIMMERY", 8, 168397},
	{"STRIVEN", 7, 168398},
	{"GRANGEVILLE", 11, 168399},
	{"POSTUREPEDIC", 12, 168400},
	{"MEZMERIZE", 9, 168401},
	{"TERMLY", 6, 168402},
	{"INPUTDEVICE", 11, 168403},
	{"LURCHED", 7, 168404},
	{"LAMARCK", 7, 168405},
	{"BLOTCHES", 8, 168406},
	{"CADES", 5, 168407},
	{"MEUDON", 6, 168408},
	{"REANIMATION", 11, 168409},
	{"KRIST", 5, 168410},
	{"BEAUTYSLEUTH", 12, 168411},
	{"PICE", 4, 168412},
	{"LESZEK", 6, 168413},
	{"MEMETIC", 7, 168414},
	{"JUBAL", 5, 168415},
	{"MONTELEONE", 10, 168416},
	{"PERSOON", 7, 168417},
	{"DEMARIA", 7, 168418},
	{"MCADOO", 6, 168419},
	{"JANEZ", 5, 168420},
	{"HOMELINK", 8, 168421},
	{"BARTEK", 6, 168422},
	{"SCHEID", 6, 168423},
	{"DAZZLER", 7, 168424},
	{"BELASCO", 7, 168425},
	{"CRADLEY", 7, 168426},
	{"FORENZA", 7, 168427},
	{"HALBERSTAM", 10, 168428},
	{"EDCS", 4, 168429},
	{"MATCHMAKERS", 11, 168430},
	{"ALIFORNIA", 9, 168431},
	{"NIGHTSHOT", 9, 168432},
	{"ILMINSTER", 9, 168433},
	{"BOGER", 5, 168434},
	{"HERRE", 5, 168435},
	{"COSET", 5, 168436},
	{"WRM", 3, 168437},
	{"TRANZ", 5, 168438},
	{"TOURDATES", 9, 168439},
	{"DLB", 3, 168440},
	{"ASPLEY", 6, 168441},
	{"KILLINGWORTH", 12, 168442},
	{"FLYBOY", 6, 168443},
	{"DIDANOSINE", 10, 168444},
	{"COCH", 4, 168445},
	{"STEPFAMILIES", 12, 168446},
	{"REDEEMS", 7, 168447},
	{"ORKNEYS", 7, 168448},
	{"EXTRAFUNS", 9, 168449},
	{"PHRMA", 5, 168450},
	{"OPOIOS", 6, 168451},
	{"ECOLAB", 6, 168452},
	{"WOODCLIFF", 9, 168453},
	{"MISHNA", 6, 168454},
	{"EVISIT", 6, 168455},
	{"MAILLE", 6, 168456},
	{"STATIVE", 7, 168457},
	{"YMRC", 4, 168458},
	{"VASR", 4, 168459},
	{"SXRA", 4, 168460},
	{"SGWE", 4, 168461},
	{"RWOV", 4, 168462},
	{"RAJB", 4, 168463},
	{"PRAJ", 4, 168464},
	{"MYAV", 4, 168465},
	{"JGER", 4, 168466},
	{"IGUC", 4, 168467},
	{"EKVE", 4, 168468},
	{"EEMV", 4, 168469},
	{"CKOM", 4, 168470},
	{"ALVS", 4, 168471},
	{"ZELAZNY", 7, 168472},
	{"PISTIL", 6, 168473},
	{"INSCRIBER", 9, 168474},
	{"DRUZE", 5, 168475},
	{"PERDOMO", 7, 168476},
	{"MULTITASK", 9, 168477},
	{"PILLER", 6, 168478},
	{"PEROVSKITE", 10, 168479},
	{"INDIR", 5, 168480},
	{"ILLEGITIMACY", 12, 168481},
	{"SHARUTILS", 9, 168482},
	{"WHUT", 4, 168483},
	{"INFROMATION", 11, 168484},
	{"SUPERSOFT", 9, 168485},
	{"SHIPBUILDERS", 12, 168486},
	{"KOHAN", 5, 168487},
	{"LEGEN", 5, 168488},
	{"RETRIVE", 7, 168489},
	{"HADAS", 5, 168490},
	{"LEEMAN", 6, 168491},
	{"GAMBINO", 7, 168492},
	{"MISSTEP", 7, 168493},
	{"DIVALPROEX", 10, 168494},
	{"STRAPSE", 7, 168495},
	{"PNLINE", 6, 168496},
	{"SAXBY", 5, 168497},
	{"MUTIPLE", 7, 168498},
	{"VEREINIGTE", 10, 168499},
	{"BINOCHE", 7, 168500},
	{"MEHRA", 5, 168501},
	{"MAPPLETHORPE", 12, 168502},
	{"SHREWS", 6, 168503},
	{"OURCE", 5, 168504},
	{"UKAEA", 5, 168505},
	{"ROUNDEL", 7, 168506},
	{"CYFFREDINOL", 11, 168507},
	{"OOIONS", 6, 168508},
	{"OBERLAND", 8, 168509},
	{"VARGHESE", 8, 168510},
	{"NORTHUMBRIAN", 12, 168511},
	{"JAVAPOLIS", 9, 168512},
	{"FIXATIONS", 9, 168513},
	{"BLUTH", 5, 168514},
	{"DCMI", 4, 168515},
	{"CCHS", 4, 168516},
	{"BOOKWATCH", 9, 168517},
	{"FATIH", 5, 168518},
	{"CHIPPY", 6, 168519},
	{"BAGNALL", 7, 168520},
	{"PATHAK", 6, 168521},
	{"APPREHENDING", 12, 168522},
	{"BASSA", 5, 168523},
	{"SYMBIOS", 7, 168524},
	{"LISTMANAGER", 11, 168525},
	{"HOMEOSTATIC", 11, 168526},
	{"GRIES", 5, 168527},
	{"GRITTED", 7, 168528},
	{"CALZONE", 7, 168529},
	{"TARANTULAS", 10, 168530},
	{"HOCHSCHULEN", 11, 168531},
	{"DIGITALI", 8, 168532},
	{"DECORATES", 9, 168533},
	{"CLOZE", 5, 168534},
	{"WERDE", 5, 168535},
	{"INSINUATE", 9, 168536},
	{"HIGHMARK", 8, 168537},
	{"YSEU", 4, 168538},
	{"WDAI", 4, 168539},
	{"VOJV", 4, 168540},
	{"VGRA", 4, 168541},
	{"UYTR", 4, 168542},
	{"TWYO", 4, 168543},
	{"TJUV", 4, 168544},
	{"RMNU", 4, 168545},
	{"OLRS", 4, 168546},
	{"OGHL", 4, 168547},
	{"ODAZ", 4, 168548},
	{"NGLB", 4, 168549},
	{"NCMO", 4, 168550},
	{"MMCL", 4, 168551},
	{"KEZE", 4, 168552},
	{"IRKK", 4, 168553},
	{"HVIG", 4, 168554},
	{"FBYE", 4, 168555},
	{"DMSC", 4, 168556},
	{"DDTW", 4, 168557},
	{"CTEU", 4, 168558},
	{"CKCY", 4, 168559},
	{"BYSG", 4, 168560},
	{"BNIC", 4, 168561},
	{"ALCZ", 4, 168562},
	{"VASANT", 6, 168563},
	{"ACTEBIS", 7, 168564},
	{"ONRAIT", 6, 168565},
	{"DEADENING", 9, 168566},
	{"VALMOREL", 8, 168567},
	{"DESIDERATA", 10, 168568},
	{"MYOTIS", 6, 168569},
	{"GUSEV", 5, 168570},
	{"FORLAG", 6, 168571},
	{"CCRC", 4, 168572},
	{"FROEHLICH", 9, 168573},
	{"ANNOTE", 6, 168574},
	{"MALENA", 6, 168575},
	{"MOCHI", 5, 168576},
	{"SEPTIMUS", 8, 168577},
	{"STYLEGUIDE", 10, 168578},
	{"BASOLATERAL", 11, 168579},
	{"TCLP", 4, 168580},
	{"FROID", 5, 168581},
	{"ENVOI", 5, 168582},
	{"AUTOCOCKER", 10, 168583},
	{"PIXTAL", 6, 168584},
	{"LPAR", 4, 168585},
	{"CHEAPSKATE", 10, 168586},
	{"ANGELE", 6, 168587},
	{"BROADVISION", 11, 168588},
	{"ENDOGENOUSLY", 12, 168589},
	{"PIOSENKI", 8, 168590},
	{"DOLT", 4, 168591},
	{"REAPPORTIONMENT", 15, 168592},
	{"LMK", 3, 168593},
	{"SALM", 4, 168594},
	{"JIGGER", 6, 168595},
	{"READLINK", 8, 168596},
	{"ABCDEFGHIJKLMNOPQRSTU", 21, 168597},
	{"SOFTBACK", 8, 168598},
	{"PEELU", 5, 168599},
	{"ALBINONI", 8, 168600},
	{"MIDCOM", 6, 168601},
	{"PIGGIE", 6, 168602},
	{"EUROPES", 7, 168603},
	{"WYLLIE", 6, 168604},
	{"ZARAH", 5, 168605},
	{"SUSCIPIT", 8, 168606},
	{"DEDMAN", 6, 168607},
	{"WATTENBERG", 10, 168608},
	{"HINSTANCE", 9, 168609},
	{"PROPRIA", 7, 168610},
	{"CRANLEIGH", 9, 168611},
	{"HEXAGONS", 8, 168612},
	{"ALUMINIZED", 10, 168613},
	{"SIZEGENETICS", 12, 168614},
	{"BRADWELL", 8, 168615},
	{"MASSARO", 7, 168616},
	{"STUBAI", 6, 168617},
	{"FARISH", 6, 168618},
	{"ZAWE", 4, 168619},
	{"YIKA", 4, 168620},
	{"YEUG", 4, 168621},
	{"WURB", 4, 168622},
	{"UEZL", 4, 168623},
	{"TTUP", 4, 168624},
	{"THRD", 4, 168625},
	{"SRWH", 4, 168626},
	{"RSGT", 4, 168627},
	{"RIBY", 4, 168628},
	{"PYGR", 4, 168629},
	{"PWEW", 4, 168630},
	{"OIDV", 4, 168631},
	{"MDTH", 4, 168632},
	{"MBEV", 4, 168633},
	{"KLLO", 4, 168634},
	{"KCUB", 4, 168635},
	{"JEWR", 4, 168636},
	{"IXEX", 4, 168637},
	{"IDDW", 4, 168638},
	{"GYYO", 4, 168639},
	{"GSLY", 4, 168640},
	{"GEKK", 4, 168641},
	{"DRSS", 4, 168642},
	{"DKMA", 4, 168643},
	{"CBYR", 4, 168644},
	{"BSFE", 4, 168645},
	{"BAIF", 4, 168646},
	{"ARMJ", 4, 168647},
	{"DEGARMO", 7, 168648},
	{"GARI", 4, 168649},
	{"MEROVINGIAN", 11, 168650},
	{"SCHREEF", 7, 168651},
	{"SCARLETS", 8, 168652},
	{"GETCITED", 8, 168653},
	{"AGREEABLY", 9, 168654},
	{"SCOUTED", 7, 168655},
	{"QDR", 3, 168656},
	{"INTIME", 6, 168657},
	{"MARSHLANDS", 10, 168658},
	{"OVERREACTION", 12, 168659},
	{"LUTHERVILLE", 11, 168660},
	{"PERENNIALLY", 11, 168661},
	{"CONSISTORY", 10, 168662},
	{"SHINTARO", 8, 168663},
	{"AYTON", 5, 168664},
	{"USROBOTICS", 10, 168665},
	{"EGOYAN", 6, 168666},
	{"DEANO", 5, 168667},
	{"CHIPDOCS", 8, 168668},
	{"SPLENDORS", 9, 168669},
	{"PHOTIUS", 7, 168670},
	{"WESTERMAN", 9, 168671},
	{"CONTRAILS", 9, 168672},
	{"WINDFARM", 8, 168673},
	{"TRITTON", 7, 168674},
	{"RAMANATHAN", 10, 168675},
	{"GEOGHEGAN", 9, 168676},
	{"ALLROUND", 8, 168677},
	{"PORTHMADOG", 10, 168678},
	{"INTERESSANTE", 12, 168679},
	{"THALIS", 6, 168680},
	{"TREMBLREL", 9, 168681},
	{"SWIPES", 6, 168682},
	{"TITULKY", 7, 168683},
	{"PRIMEUR", 7, 168684},
	{"ESTED", 5, 168685},
	{"KRIGING", 7, 168686},
	{"RASPUTINA", 9, 168687},
	{"BUSINESSBUSINESS", 16, 168688},
	{"NAKES", 5, 168689},
	{"YOGAWITHMOBY", 12, 168690},
	{"GYAN", 4, 168691},
	{"TEABAGS", 7, 168692},
	{"KAYCEE", 6, 168693},
	{"HOUNDSTOOTH", 11, 168694},
	{"EGINE", 5, 168695},
	{"STEAMS", 6, 168696},
	{"PANDYA", 6, 168697},
	{"HYWEL", 5, 168698},
	{"NOVEM", 5, 168699},
	{"YAMANASHI", 9, 168700},
	{"PARTITE", 7, 168701},
	{"OXYGENATES", 10, 168702},
	{"EHEIM", 5, 168703},
	{"RIGI", 4, 168704},
	{"TELANGIECTASIA", 14, 168705},
	{"SMCC", 4, 168706},
	{"CAPSTAN", 7, 168707},
	{"NICCI", 5, 168708},
	{"MACAULEY", 8, 168709},
	{"DONELL", 6, 168710},
	{"TRIVAGO", 7, 168711},
	{"FIDI", 4, 168712},
	{"APARS", 5, 168713},
	{"VIRGE", 5, 168714},
	{"DYNAMICTYPE", 11, 168715},
	{"EXUDATE", 7, 168716},
	{"ANTITUSSIVE", 11, 168717},
	{"ELDS", 4, 168718},
	{"ZZSA", 4, 168719},
	{"YAKR", 4, 168720},
	{"XERX", 4, 168721},
	{"WIRO", 4, 168722},
	{"UDIP", 4, 168723},
	{"TYDW", 4, 168724},
	{"TVMI", 4, 168725},
	{"NYUM", 4, 168726},
	{"NPUG", 4, 168727},
	{"NGML", 4, 168728},
	{"LNOF", 4, 168729},
	{"LAHP", 4, 168730},
	{"HRAU", 4, 168731},
	{"FPIZ", 4, 168732},
	{"FELC", 4, 168733},
	{"FAWK", 4, 168734},
	{"DOYA", 4, 168735},
	{"DGYP", 4, 168736},
	{"DADK", 4, 168737},
	{"CRIO", 4, 168738},
	{"BHIK", 4, 168739},
	{"AYUL", 4, 168740},
	{"TELEPHON", 8, 168741},
	{"MILLONES", 8, 168742},
	{"NEICE", 5, 168743},
	{"GASHAPON", 8, 168744},
	{"TRACKBACKED", 11, 168745},
	{"SIMBERG", 7, 168746},
	{"NOVIAS", 6, 168747},
	{"HACKLE", 6, 168748},
	{"CLAIT", 5, 168749},
	{"GAMBON", 6, 168750},
	{"DEIRA", 5, 168751},
	{"GEMPLUS", 7, 168752},
	{"NOAKES", 6, 168753},
	{"HUDSONVILLE", 11, 168754},
	{"MASTURBATOR", 11, 168755},
	{"BLACKTHORN", 10, 168756},
	{"FORESTDALE", 10, 168757},
	{"OUNCIL", 6, 168758},
	{"MORPHIX", 7, 168759},
	{"TURKOMAN", 8, 168760},
	{"TRATAMIENTOS", 12, 168761},
	{"PRASANNA", 8, 168762},
	{"FEINT", 5, 168763},
	{"JJC", 3, 168764},
	{"MUSCOVITE", 9, 168765},
	{"DOMITIAN", 8, 168766},
	{"JCLISTTAB", 9, 168767},
	{"LJUBICIC", 8, 168768},
	{"ANALISI", 7, 168769},
	{"MASTIN", 6, 168770},
	{"LANDRETH", 8, 168771},
	{"CRAFTSTER", 9, 168772},
	{"FTBFS", 5, 168773},
	{"JOURNO", 6, 168774},
	{"PURSUER", 7, 168775},
	{"HYPERINFLATION", 14, 168776},
	{"POULAIN", 7, 168777},
	{"MAGAZINESFORBES", 15, 168778},
	{"BERMUDAS", 8, 168779},
	{"NIGHTHAWKS", 10, 168780},
	{"LETTO", 5, 168781},
	{"WRAPPINGS", 9, 168782},
	{"DURKAN", 6, 168783},
	{"USADOS", 6, 168784},
	{"STARLINE", 8, 168785},
	{"IZABELLA", 8, 168786},
	{"KACI", 4, 168787},
	{"SOMERFIELD", 10, 168788},
	{"ROUTABLE", 8, 168789},
	{"RIDS", 4, 168790},
	{"DYCAM", 5, 168791},
	{"SHOLOM", 6, 168792},
	{"BALLENTINE", 10, 168793},
	{"BOOKHAM", 7, 168794},
	{"LETTERATURA", 11, 168795},
	{"ZOWH", 4, 168796},
	{"YITJ", 4, 168797},
	{"VSOU", 4, 168798},
	{"UZET", 4, 168799},
	{"SPNW", 4, 168800},
	{"RZAL", 4, 168801},
	{"RYEH", 4, 168802},
	{"RTOZ", 4, 168803},
	{"RGHN", 4, 168804},
	{"PYHI", 4, 168805},
	{"PMHO", 4, 168806},
	{"MJAR", 4, 168807},
	{"LUNV", 4, 168808},
	{"KSUL", 4, 168809},
	{"IXEP", 4, 168810},
	{"GAUZ", 4, 168811},
	{"FETZ", 4, 168812},
	{"FDVD", 4, 168813},
	{"ERFF", 4, 168814},
	{"DBUE", 4, 168815},
	{"CYQU", 4, 168816},
	{"CPUN", 4, 168817},
	{"BOXU", 4, 168818},
	{"ACSY", 4, 168819},
	{"CUSPS", 5, 168820},
	{"KUZNETSOVA", 10, 168821},
	{"PANDORAS", 8, 168822},
	{"GLYCOSYLASE", 11, 168823},
	{"EXPECIALLY", 10, 168824},
	{"SOUTHOLD", 8, 168825},
	{"CHPT", 4, 168826},
	{"SUPPLT", 6, 168827},
	{"BALDESSARINI", 12, 168828},
	{"ENGENHARIA", 10, 168829},
	{"DARKRED", 7, 168830},
	{"KALAKAUA", 8, 168831},
	{"GREENMOUNT", 10, 168832},
	{"ISOCHRONOUS", 11, 168833},
	{"CENTO", 5, 168834},
	{"DCSHOECOUSA", 11, 168835},
	{"HILLERMAN", 9, 168836},
	{"RESCALED", 8, 168837},
	{"FRX", 3, 168838},
	{"WINDPOWER", 9, 168839},
	{"PACHARD", 7, 168840},
	{"INTIMRASUR", 10, 168841},
	{"CYRILLE", 7, 168842},
	{"COUNCILMEN", 10, 168843},
	{"ACHEBE", 6, 168844},
	{"MAGNATUNE", 9, 168845},
	{"ITEMISED", 8, 168846},
	{"DAUNTED", 7, 168847},
	{"REPUTATIONAL", 12, 168848},
	{"PREFLOP", 7, 168849},
	{"CIMMYT", 6, 168850},
	{"MARCIL", 6, 168851},
	{"HANIF", 5, 168852},
	{"HCBS", 4, 168853},
	{"EVENTO", 6, 168854},
	{"CHITWA", 6, 168855},
	{"FASSBINDER", 10, 168856},
	{"HALFTONES", 9, 168857},
	{"SETCOLOR", 8, 168858},
	{"CANDIDO", 7, 168859},
	{"FLOURNOY", 8, 168860},
	{"TECHNIKON", 9, 168861},
	{"ORRIS", 5, 168862},
	{"PHENCYCLIDINE", 13, 168863},
	{"GWELER", 6, 168864},
	{"MIMAS", 5, 168865},
	{"HOOKAHS", 7, 168866},
	{"CIRCULARITY", 11, 168867},
	{"SANDBAG", 7, 168868},
	{"RECALIBRATION", 13, 168869},
	{"HAVERSTRAW", 10, 168870},
	{"HENDLER", 7, 168871},
	{"FULTZ", 5, 168872},
	{"WESTIES", 7, 168873},
	{"WAXWING", 7, 168874},
	{"LACUS", 5, 168875},
	{"THALASSO", 8, 168876},
	{"MICROSD", 7, 168877},
	{"ANONYME", 7, 168878},
	{"FICIENT", 7, 168879},
	{"MCCAMMON", 8, 168880},
	{"LOISLAW", 7, 168881},
	{"ZYPE", 4, 168882},
	{"ZEIR", 4, 168883},
	{"YBHA", 4, 168884},
	{"XILA", 4, 168885},
	{"WLRI", 4, 168886},
	{"WFLU", 4, 168887},
	{"USIQ", 4, 168888},
	{"UOTU", 4, 168889},
	{"TMSC", 4, 168890},
	{"TIRV", 4, 168891},
	{"SBUO", 4, 168892},
	{"RLLC", 4, 168893},
	{"OYTU", 4, 168894},
	{"OARY", 4, 168895},
	{"NYIK", 4, 168896},
	{"NGBB", 4, 168897},
	{"NEZF", 4, 168898},
	{"MIYO", 4, 168899},
	{"LIOZ", 4, 168900},
	{"KJAY", 4, 168901},
	{"FOFK", 4, 168902},
	{"ELMF", 4, 168903},
	{"DLBS", 4, 168904},
	{"DCBE", 4, 168905},
	{"CCPL", 4, 168906},
	{"BBIY", 4, 168907},
	{"ABFI", 4, 168908},
	{"PICU", 4, 168909},
	{"VIRES", 5, 168910},
	{"BADLAND", 7, 168911},
	{"HYALINE", 7, 168912},
	{"TAPIR", 5, 168913},
	{"REPERTOIRES", 11, 168914},
	{"CHATELAINE", 10, 168915},
	{"CARDEW", 6, 168916},
	{"SANGAM", 6, 168917},
	{"DUENDE", 6, 168918},
	{"HENSHALL", 8, 168919},
	{"MOTEGI", 6, 168920},
	{"EXPUNGEMENT", 11, 168921},
	{"EIDDO", 5, 168922},
	{"CORCOVADO", 9, 168923},
	{"SOFTLANDMARK", 12, 168924},
	{"CATERA", 6, 168925},
	{"LUSCOMBE", 8, 168926},
	{"BAMM", 4, 168927},
	{"KABBALISTIC", 11, 168928},
	{"STANDOFFS", 9, 168929},
	{"YUSEF", 5, 168930},
	{"BLURT", 5, 168931},
	{"PERQUIMANS", 10, 168932},
	{"SYMES", 5, 168933},
	{"SWISSAIR", 8, 168934},
	{"TEMPI", 5, 168935},
	{"SCHOOLE", 7, 168936},
	{"PUREVOLUME", 10, 168937},
	{"COWBRIDGE", 9, 168938},
	{"ALIYA", 5, 168939},
	{"ABOLISHMENT", 11, 168940},
	{"ALVISO", 6, 168941},
	{"ANNVILLE", 8, 168942},
	{"LABX", 4, 168943},
	{"DENOM", 5, 168944},
	{"KONGA", 5, 168945},
	{"CAMPIONE", 8, 168946},
	{"FRANKLAND", 9, 168947},
	{"INCINERATE", 10, 168948},
	{"COMPERE", 7, 168949},
	{"BLACKONWHITE", 12, 168950},
	{"BIOCHEMISTS", 11, 168951},
	{"BEDRIDDEN", 9, 168952},
	{"CHANCELLERY", 11, 168953},
	{"RETICULATION", 12, 168954},
	{"LEXICOGRAPHY", 12, 168955},
	{"WOLFS", 5, 168956},
	{"MOMENI", 6, 168957},
	{"DEFRANCO", 8, 168958},
	{"DAMARALAND", 10, 168959},
	{"MONTAVISTA", 10, 168960},
	{"LENGES", 6, 168961},
	{"AURORE", 6, 168962},
	{"MOUNDSVILLE", 11, 168963},
	{"CRADLING", 8, 168964},
	{"SUPREMACISTS", 12, 168965},
	{"ATTAR", 5, 168966},
	{"PEACHLAND", 9, 168967},
	{"EGELAND", 7, 168968},
	{"DOMINANTS", 9, 168969},
	{"CNFS", 4, 168970},
	{"BERZERKER", 9, 168971},
	{"ZXU", 3, 168972},
	{"YQG", 3, 168973},
	{"XZX", 3, 168974},
	{"XJX", 3, 168975},
	{"VKJ", 3, 168976},
	{"VFK", 3, 168977},
	{"UQJ", 3, 168978},
	{"PKX", 3, 168979},
	{"PJY", 3, 168980},
	{"MKQ", 3, 168981},
	{"LQQ", 3, 168982},
	{"KZG", 3, 168983},
	{"KBX", 3, 168984},
	{"JZM", 3, 168985},
	{"JXD", 3, 168986},
	{"JVY", 3, 168987},
	{"BACHATA", 7, 168988},
	{"NEURONE", 7, 168989},
	{"MARCOPOLO", 9, 168990},
	{"BUNYIP", 6, 168991},
	{"ZIRB", 4, 168992},
	{"UNSJ", 4, 168993},
	{"UGWO", 4, 168994},
	{"TVSM", 4, 168995},
	{"TCBE", 4, 168996},
	{"SDUO", 4, 168997},
	{"RPFI", 4, 168998},
	{"OIZU", 4, 168999},
	{"NKNU", 4, 169000},
	{"MSQM", 4, 169001},
	{"MCOH", 4, 169002},
	{"LPVI", 4, 169003},
	{"GYBR", 4, 169004},
	{"FNCA", 4, 169005},
	{"FFEF", 4, 169006},
	{"FELP", 4, 169007},
	{"EKUP", 4, 169008},
	{"DZIO", 4, 169009},
	{"ATBM", 4, 169010},
	{"SZTAKI", 6, 169011},
	{"COUPLETS", 8, 169012},
	{"BEEZ", 4, 169013},
	{"PALMGEAR", 8, 169014},
	{"SOCIALISTIC", 11, 169015},
	{"NBATV", 5, 169016},
	{"KESLER", 6, 169017},
	{"TERRIGENOUS", 11, 169018},
	{"DOLGELLAU", 9, 169019},
	{"NARROWNESS", 10, 169020},
	{"NONCOMPLIANT", 12, 169021},
	{"COMPETION", 9, 169022},
	{"DWELLETH", 8, 169023},
	{"APOD", 4, 169024},
	{"NUCLEARE", 8, 169025},
	{"MOGELIJK", 8, 169026},
	{"SUBQUERIES", 10, 169027},
	{"NGDC", 4, 169028},
	{"KENDALLVILLE", 12, 169029},
	{"AHLUWALIA", 9, 169030},
	{"SAMAD", 5, 169031},
	{"ASPRIN", 6, 169032},
	{"CONVENORS", 9, 169033},
	{"MISSOURIAN", 10, 169034},
	{"HENTEI", 6, 169035},
	{"GAMO", 4, 169036},
	{"YEATES", 6, 169037},
	{"FIRSTENERGY", 11, 169038},
	{"NAPCO", 5, 169039},
	{"VINEET", 6, 169040},
	{"QMUL", 4, 169041},
	{"LYNSEY", 6, 169042},
	{"FABIENNE", 8, 169043},
	{"STITCHERY", 9, 169044},
	{"KALAU", 5, 169045},
	{"CALBIOCHEM", 10, 169046},
	{"MORTUARIES", 10, 169047},
	{"RESTR", 5, 169048},
	{"MOUSTACHES", 10, 169049},
	{"CONVERTISSEUR", 13, 169050},
	{"SIEGLER", 7, 169051},
	{"CARDIORESPIRATORY", 17, 169052},
	{"MANZONI", 7, 169053},
	{"STETTLER", 8, 169054},
	{"DIMENSIONE", 10, 169055},
	{"GOODTIMES", 9, 169056},
	{"GALAXIA", 7, 169057},
	{"DEFACEMENT", 10, 169058},
	{"SELFRIDGES", 10, 169059},
	{"MULTIBAY", 8, 169060},
	{"YANIV", 5, 169061},
	{"INDEF", 5, 169062},
	{"BRUITAGES", 9, 169063},
	{"ANETTE", 6, 169064},
	{"SUBLIST", 7, 169065},
	{"BNETD", 5, 169066},
	{"EOLAS", 5, 169067},
	{"NTERNET", 7, 169068},
	{"ILOHAMAIL", 9, 169069},
	{"SNOCOUNTRY", 10, 169070},
	{"TERRANO", 7, 169071},
	{"GIDE", 4, 169072},
	{"SPEKTRUM", 8, 169073},
	{"IMCLONE", 7, 169074},
	{"DDRAM", 5, 169075},
	{"CROSSWIND", 9, 169076},
	{"VIOLENCIA", 9, 169077},
	{"HEINRICHS", 9, 169078},
	{"CANOPEN", 7, 169079},
	{"BLACKFISH", 9, 169080},
	{"BRUSHWOOD", 9, 169081},
	{"BRIA", 4, 169082},
	{"TRANSLOCATED", 12, 169083},
	{"KLR", 3, 169084},
	{"YMEH", 4, 169085},
	{"YKIE", 4, 169086},
	{"XBOA", 4, 169087},
	{"WAQU", 4, 169088},
	{"SJEL", 4, 169089},
	{"RKYP", 4, 169090},
	{"RJAB", 4, 169091},
	{"RFSY", 4, 169092},
	{"REUE", 4, 169093},
	{"RAWG", 4, 169094},
	{"PUSK", 4, 169095},
	{"PPSM", 4, 169096},
	{"PBUL", 4, 169097},
	{"ONPG", 4, 169098},
	{"KJAR", 4, 169099},
	{"FHIK", 4, 169100},
	{"ENLD", 4, 169101},
	{"EGGD", 4, 169102},
	{"EFGR", 4, 169103},
	{"AERU", 4, 169104},
	{"HOTMALL", 7, 169105},
	{"KPBS", 4, 169106},
	{"FRECUENCIA", 10, 169107},
	{"UPDOS", 5, 169108},
	{"BOOKERS", 7, 169109},
	{"ARROGANTLY", 10, 169110},
	{"TRAURIG", 7, 169111},
	{"XCONQ", 5, 169112},
	{"WACHUSETT", 9, 169113},
	{"PRONATION", 9, 169114},
	{"PESTERING", 9, 169115},
	{"MARKETNET", 9, 169116},
	{"COPERTINA", 9, 169117},
	{"LIEUX", 5, 169118},
	{"KINCADE", 7, 169119},
	{"BARRICADED", 10, 169120},
	{"LORILLARD", 9, 169121},
	{"BOLDON", 6, 169122},
	{"LARYNGOSCOPE", 12, 169123},
	{"BALLYCASTLE", 11, 169124},
	{"STAVELEY", 8, 169125},
	{"PILLAGING", 9, 169126},
	{"ANYWAYZ", 7, 169127},
	{"THEATRICS", 9, 169128},
	{"RIENCE", 6, 169129},
	{"CARVOEIRO", 9, 169130},
	{"UNLIMITEDNET", 12, 169131},
	{"MATERIALE", 9, 169132},
	{"SEADREAM", 8, 169133},
	{"CRUISERWEIGHT", 13, 169134},
	{"CHIHULY", 7, 169135},
	{"LAGOA", 5, 169136},
	{"VINGT", 5, 169137},
	{"LEUCOVORIN", 10, 169138},
	{"MAQUIS", 6, 169139},
	{"DREDGES", 7, 169140},
	{"ZIZEK", 5, 169141},
	{"GALVA", 5, 169142},
	{"WINFRIED", 8, 169143},
	{"DUOTONE", 7, 169144},
	{"SICKO", 5, 169145},
	{"RANKINE", 7, 169146},
	{"FROND", 5, 169147},
	{"SCHUCO", 6, 169148},
	{"UNTYPED", 7, 169149},
	{"TACUBA", 6, 169150},
	{"IMMUNOGENETICS", 14, 169151},
	{"DRWXRWSR", 8, 169152},
	{"VARDY", 5, 169153},
	{"NATIONALISATION", 15, 169154},
	{"BALLO", 5, 169155},
	{"VALKENBURG", 10, 169156},
	{"CENOTAPH", 8, 169157},
	{"COOLE", 5, 169158},
	{"MANTICORE", 9, 169159},
	{"CECA", 4, 169160},
	{"ADAPTIVELY", 10, 169161},
	{"PENWITH", 7, 169162},
	{"CYCLINS", 7, 169163},
	{"CICCIOLINA", 10, 169164},
	{"PHENYLKETONURIA", 15, 169165},
	{"PARSEC", 6, 169166},
	{"VIBBER", 6, 169167},
	{"ILYICH", 6, 169168},
	{"MERKIN", 6, 169169},
	{"ATTITASH", 8, 169170},
	{"CIGUATERA", 9, 169171},
	{"WEBAIM", 6, 169172},
	{"HENSCHEL", 8, 169173},
	{"AQUABATS", 8, 169174},
	{"BLANCHETTE", 10, 169175},
	{"VBP", 3, 169176},
	{"PERLES", 6, 169177},
	{"IMAGESOURCE", 11, 169178},
	{"WABBIT", 6, 169179},
	{"YAMUNA", 6, 169180},
	{"GEOPHYSICIST", 12, 169181},
	{"XQUE", 4, 169182},
	{"VSIG", 4, 169183},
	{"SYEV", 4, 169184},
	{"OWAJ", 4, 169185},
	{"OAPC", 4, 169186},
	{"MUNP", 4, 169187},
	{"LZEI", 4, 169188},
	{"LYNJ", 4, 169189},
	{"LHIW", 4, 169190},
	{"IAMQ", 4, 169191},
	{"GPPG", 4, 169192},
	{"FKAY", 4, 169193},
	{"DICN", 4, 169194},
	{"CRAR", 4, 169195},
	{"CEYC", 4, 169196},
	{"CCWH", 4, 169197},
	{"AOLY", 4, 169198},
	{"ANUV", 4, 169199},
	{"AFPI", 4, 169200},
	{"RWADA", 5, 169201},
	{"HYPERMARKET", 11, 169202},
	{"GUPPIES", 7, 169203},
	{"BROSSARD", 8, 169204},
	{"STREETSBORO", 11, 169205},
	{"ORGANOPHOSPHORUS", 16, 169206},
	{"BINNIE", 6, 169207},
	{"DOLOMITI", 8, 169208},
	{"BUNGLING", 8, 169209},
	{"PERIPATETIC", 11, 169210},
	{"NEMETSCHEK", 10, 169211},
	{"BMBF", 4, 169212},
	{"SHOUL", 5, 169213},
	{"RECOLLECTED", 11, 169214},
	{"ANATOMIE", 8, 169215},
	{"TRIBALISM", 9, 169216},
	{"POMORIE", 7, 169217},
	{"MALARKEY", 8, 169218},
	{"BOKA", 4, 169219},
	{"PRIVATBILDER", 12, 169220},
	{"HERAEUS", 7, 169221},
	{"DETERMINER", 10, 169222},
	{"CHROMATICITY", 12, 169223},
	{"RYMER", 5, 169224},
	{"REICHENBACH", 11, 169225},
	{"BOOKMAKING", 10, 169226},
	{"SKIDDED", 7, 169227},
	{"MKTS", 4, 169228},
	{"IMPEL", 5, 169229},
	{"FOMENT", 6, 169230},
	{"SCHLECHT", 8, 169231},
	{"QUIMICA", 7, 169232},
	{"ABUSIVO", 7, 169233},
	{"MAMMOTHS", 8, 169234},
	{"EXPECTANTLY", 11, 169235},
	{"SACCADE", 7, 169236},
	{"RECEIV", 6, 169237},
	{"CORTNEY", 7, 169238},
	{"CONDORCET", 9, 169239},
	{"PROFESSIONNELS", 14, 169240},
	{"ECHOLOT", 7, 169241},
	{"KNAP", 4, 169242},
	{"NANOELECTRONICS", 15, 169243},
	{"STAFFAN", 7, 169244},
	{"PERCHING", 8, 169245},
	{"BRONWEN", 7, 169246},
	{"WBMP", 4, 169247},
	{"FREEDELIVERY", 12, 169248},
	{"INCX", 4, 169249},
	{"SOLUM", 5, 169250},
	{"SLAGLE", 6, 169251},
	{"RAMETERS", 8, 169252},
	{"LEARMONTH", 9, 169253},
	{"BIENES", 6, 169254},
	{"BROILING", 8, 169255},
	{"GANGWAY", 7, 169256},
	{"UTHER", 5, 169257},
	{"DESTRUCTO", 9, 169258},
	{"BIAGIO", 6, 169259},
	{"MAYFLY", 6, 169260},
	{"GOODSBOATING", 12, 169261},
	{"ZAOR", 4, 169262},
	{"WVAC", 4, 169263},
	{"VYMI", 4, 169264},
	{"VYLA", 4, 169265},
	{"VIEY", 4, 169266},
	{"VERX", 4, 169267},
	{"USZK", 4, 169268},
	{"TXRA", 4, 169269},
	{"REYV", 4, 169270},
	{"PINQ", 4, 169271},
	{"ONBP", 4, 169272},
	{"NEZB", 4, 169273},
	{"LURP", 4, 169274},
	{"GVUL", 4, 169275},
	{"GOLG", 4, 169276},
	{"FFYF", 4, 169277},
	{"DRCR", 4, 169278},
	{"BMCO", 4, 169279},
	{"BLAL", 4, 169280},
	{"JORDANIANS", 10, 169281},
	{"MATERION", 8, 169282},
	{"LOGOTYPES", 9, 169283},
	{"STREPTOPHYTA", 12, 169284},
	{"SPEEDSTREAM", 11, 169285},
	{"TANTALUS", 8, 169286},
	{"WAKO", 4, 169287},
	{"BRATWURST", 9, 169288},
	{"VUPOINT", 7, 169289},
	{"MADHAVAN", 8, 169290},
	{"PRESBYOPIA", 10, 169291},
	{"QUADRIPLEGIC", 12, 169292},
	{"RAPACIOUS", 9, 169293},
	{"GAPDH", 5, 169294},
	{"ADZE", 4, 169295},
	{"ENDORSER", 8, 169296},
	{"CULTISTS", 8, 169297},
	{"UNIQUEMENT", 10, 169298},
	{"LARGENT", 7, 169299},
	{"CHATTOPADHYAY", 13, 169300},
	{"ADER", 4, 169301},
	{"SEARAY", 6, 169302},
	{"ROXANE", 6, 169303},
	{"DEBASED", 7, 169304},
	{"BARER", 5, 169305},
	{"OZRIC", 5, 169306},
	{"PERCOLATOR", 10, 169307},
	{"CERTIFICADO", 11, 169308},
	{"ARIUS", 5, 169309},
	{"DRAVIDIAN", 9, 169310},
	{"CONCUBINES", 10, 169311},
	{"POLYGAMOUS", 10, 169312},
	{"LYIRCS", 6, 169313},
	{"JOGGED", 6, 169314},
	{"DAUD", 4, 169315},
	{"BATHWATER", 9, 169316},
	{"YUKIHIRO", 8, 169317},
	{"XILO", 4, 169318},
	{"SENTIDO", 7, 169319},
	{"WAHHABI", 7, 169320},
	{"PACKA", 5, 169321},
	{"EPIDERMIDIS", 11, 169322},
	{"MERDE", 5, 169323},
	{"DHALIWAL", 8, 169324},
	{"ENTANGLE", 8, 169325},
	{"TERRINE", 7, 169326},
	{"PYGMIES", 7, 169327},
	{"USATE", 5, 169328},
	{"STEEPNESS", 9, 169329},
	{"ARSENATE", 8, 169330},
	{"STATISTIKEN", 11, 169331},
	{"ORGANIZATIONALLY", 16, 169332},
	{"SOKAL", 5, 169333},
	{"SACTO", 5, 169334},
	{"GOTTINGEN", 9, 169335},
	{"ETREE", 5, 169336},
	{"VIAREGGIO", 9, 169337},
	{"PHOTOESAGE", 10, 169338},
	{"FRANCHI", 7, 169339},
	{"CHILDRE", 7, 169340},
	{"CHAREN", 6, 169341},
	{"KULTURE", 7, 169342},
	{"EPIX", 4, 169343},
	{"WUB", 3, 169344},
	{"PURITANICAL", 11, 169345},
	{"SONERA", 6, 169346},
	{"MEDJUGORJE", 10, 169347},
	{"UBIQUITINATION", 14, 169348},
	{"PBXS", 4, 169349},
	{"BCRA", 4, 169350},
	{"CAPACIOUS", 9, 169351},
	{"BAGNARA", 7, 169352},
	{"XMOT", 4, 169353},
	{"XKIN", 4, 169354},
	{"SEGC", 4, 169355},
	{"RDRB", 4, 169356},
	{"OUGD", 4, 169357},
	{"ORVT", 4, 169358},
	{"OFUF", 4, 169359},
	{"OBYU", 4, 169360},
	{"NXME", 4, 169361},
	{"MYTV", 4, 169362},
	{"MUFT", 4, 169363},
	{"MFTI", 4, 169364},
	{"LTVO", 4, 169365},
	{"LELR", 4, 169366},
	{"KORK", 4, 169367},
	{"HUDB", 4, 169368},
	{"EPVO", 4, 169369},
	{"DYUM", 4, 169370},
	{"AWKR", 4, 169371},
	{"AQBU", 4, 169372},
	{"YOUSELF", 7, 169373},
	{"SUNDANCER", 9, 169374},
	{"OUTFIELDERS", 11, 169375},
	{"ABRAHAMIC", 9, 169376},
	{"PREFECTS", 8, 169377},
	{"AFFLIATE", 8, 169378},
	{"SILESIAN", 8, 169379},
	{"MAINTENENCE", 11, 169380},
	{"DOWDELL", 7, 169381},
	{"CONSTRICT", 9, 169382},
	{"CAMBRAI", 7, 169383},
	{"CLEW", 4, 169384},
	{"INORDER", 7, 169385},
	{"CPCC", 4, 169386},
	{"FECA", 4, 169387},
	{"DOMEN", 5, 169388},
	{"BISCAY", 6, 169389},
	{"BILLE", 5, 169390},
	{"WAYFINDER", 9, 169391},
	{"CARPENTERSVILLE", 15, 169392},
	{"CHICKA", 6, 169393},
	{"SQUA", 4, 169394},
	{"BENTLY", 6, 169395},
	{"PANCETTA", 8, 169396},
	{"ALCOOL", 6, 169397},
	{"MESTIZO", 7, 169398},
	{"PAHLAVI", 7, 169399},
	{"POKIES", 6, 169400},
	{"JENNYS", 6, 169401},
	{"CHOLESKY", 8, 169402},
	{"SAGITTIS", 8, 169403},
	{"AIRGAS", 6, 169404},
	{"JCIFS", 5, 169405},
	{"ENPOWER", 7, 169406},
	{"AERYN", 5, 169407},
	{"SUTHERLIN", 9, 169408},
	{"BRANNIGAN", 9, 169409},
	{"PREVENTER", 9, 169410},
	{"PATRISTIC", 9, 169411},
	{"UNROLLED", 8, 169412},
	{"CUETEC", 6, 169413},
	{"LOKE", 4, 169414},
	{"HOUDE", 5, 169415},
	{"FTID", 4, 169416},
	{"AMERICANIZATION", 15, 169417},
	{"COGSCI", 6, 169418},
	{"FARINGTON", 9, 169419},
	{"CIANS", 5, 169420},
	{"ALIENATES", 9, 169421},
	{"INTERRUPTUS", 11, 169422},
	{"HAKONE", 6, 169423},
	{"CONTINOUSLY", 11, 169424},
	{"TAMBOUR", 7, 169425},
	{"HORVITZ", 7, 169426},
	{"POROS", 5, 169427},
	{"OBLATE", 6, 169428},
	{"NTUPLE", 6, 169429},
	{"CANDLING", 8, 169430},
	{"DOWNLOWD", 8, 169431},
	{"KASHYAP", 7, 169432},
	{"DELETTO", 7, 169433},
	{"SMARMY", 6, 169434},
	{"CLOTRIMAZOLE", 12, 169435},
	{"PROPIEDADES", 11, 169436},
	{"DATABOOK", 8, 169437},
	{"HEIRAT", 6, 169438},
	{"FREEP", 5, 169439},
	{"SHRUBLANDS", 10, 169440},
	{"MARSON", 6, 169441},
	{"RIGHTHAND", 9, 169442},
	{"WNDU", 4, 169443},
	{"WSUS", 4, 169444},
	{"HAMMORABI", 9, 169445},
	{"BARNEVELD", 9, 169446},
	{"POUSSIN", 7, 169447},
	{"ZLAF", 4, 169448},
	{"WESR", 4, 169449},
	{"UDEQ", 4, 169450},
	{"TOJP", 4, 169451},
	{"SDYE", 4, 169452},
	{"SBAZ", 4, 169453},
	{"NUXK", 4, 169454},
	{"NDMW", 4, 169455},
	{"MIOC", 4, 169456},
	{"KSSY", 4, 169457},
	{"KNAU", 4, 169458},
	{"JOWH", 4, 169459},
	{"JLIS", 4, 169460},
	{"IMSV", 4, 169461},
	{"EYNM", 4, 169462},
	{"EBIF", 4, 169463},
	{"DVDM", 4, 169464},
	{"DMCF", 4, 169465},
	{"DCPU", 4, 169466},
	{"CDYN", 4, 169467},
	{"BASG", 4, 169468},
	{"AURF", 4, 169469},
	{"AGYO", 4, 169470},
	{"FUNBRAIN", 8, 169471},
	{"FBP", 3, 169472},
	{"SALIERI", 7, 169473},
	{"KEULEN", 6, 169474},
	{"KURI", 4, 169475},
	{"GHALI", 5, 169476},
	{"SCHLEICH", 8, 169477},
	{"FROUD", 5, 169478},
	{"PWL", 3, 169479},
	{"PERIPH", 6, 169480},
	{"MINITURE", 8, 169481},
	{"CARSTENS", 8, 169482},
	{"TAMAULIPAS", 10, 169483},
	{"OVERSPENDING", 12, 169484},
	{"GARANG", 6, 169485},
	{"CODEY", 5, 169486},
	{"WATCHWORD", 9, 169487},
	{"PATHOBIOLOGY", 12, 169488},
	{"TINBERGEN", 9, 169489},
	{"PUNCHER", 7, 169490},
	{"BERLEI", 6, 169491},
	{"SILAT", 5, 169492},
	{"CONJUCTION", 10, 169493},
	{"RUSHFORD", 8, 169494},
	{"ICSU", 4, 169495},
	{"DEPORTE", 7, 169496},
	{"MEMORABLY", 9, 169497},
	{"KOOLAID", 7, 169498},
	{"MIXA", 4, 169499},
	{"MANOMETER", 9, 169500},
	{"INGEBORG", 8, 169501},
	{"DRUMMED", 7, 169502},
	{"BHAJANS", 7, 169503},
	{"PASSIONATA", 10, 169504},
	{"CLEAVAGES", 9, 169505},
	{"HYPOGLYCAEMIA", 13, 169506},
	{"TURDUS", 6, 169507},
	{"HAYRIDE", 7, 169508},
	{"ELEONORA", 8, 169509},
	{"VERGING", 7, 169510},
	{"SZCZERBIAK", 10, 169511},
	{"OSDPD", 5, 169512},
	{"MOPAC", 5, 169513},
	{"DOLISOS", 7, 169514},
	{"ITVCON", 6, 169515},
	{"REFORMISTS", 10, 169516},
	{"LIONHEAD", 8, 169517},
	{"RAJON", 5, 169518},
	{"SAVESET", 7, 169519},
	{"MONGE", 5, 169520},
	{"LOONIES", 7, 169521},
	{"HANDYS", 6, 169522},
	{"ACCLIMATE", 9, 169523},
	{"SZUL", 4, 169524},
	{"LQQK", 4, 169525},
	{"EVENTCALENDAR", 13, 169526},
	{"APPURTENANT", 11, 169527},
	{"URETHRITIS", 10, 169528},
	{"INTERDICT", 9, 169529},
	{"BEANTOWN", 8, 169530},
	{"DANIKA", 6, 169531},
	{"JOEUSER", 7, 169532},
	{"DRUMMONDVILLE", 13, 169533},
	{"GEPLAATST", 9, 169534},
	{"PODZ", 4, 169535},
	{"MRNUMBER", 8, 169536},
	{"TMPFS", 5, 169537},
	{"YWAC", 4, 169538},
	{"XALB", 4, 169539},
	{"WJAN", 4, 169540},
	{"TEKL", 4, 169541},
	{"PPWO", 4, 169542},
	{"PAIM", 4, 169543},
	{"ODJE", 4, 169544},
	{"MBUB", 4, 169545},
	{"GSOG", 4, 169546},
	{"GIGW", 4, 169547},
	{"FJAG", 4, 169548},
	{"EYAY", 4, 169549},
	{"DMRE", 4, 169550},
	{"CKYV", 4, 169551},
	{"BWET", 4, 169552},
	{"BALJ", 4, 169553},
	{"AKIG", 4, 169554},
	{"AADR", 4, 169555},
	{"GRAW", 4, 169556},
	{"CHARTRAND", 9, 169557},
	{"ADJOURNS", 8, 169558},
	{"HYDROFOIL", 9, 169559},
	{"RIVALING", 8, 169560},
	{"WILBANKS", 8, 169561},
	{"OSPAR", 5, 169562},
	{"XPLORER", 7, 169563},
	{"LENGE", 5, 169564},
	{"VITEK", 5, 169565},
	{"BROOMSTICKS", 11, 169566},
	{"CHONBURI", 8, 169567},
	{"MCWILLIAM", 9, 169568},
	{"HEADSCARF", 9, 169569},
	{"CFIDS", 5, 169570},
	{"SMAP", 4, 169571},
	{"SCAMPER", 7, 169572},
	{"FILEID", 6, 169573},
	{"MEMESTREAMS", 11, 169574},
	{"WALLENSTEIN", 11, 169575},
	{"TWINSTUFF", 9, 169576},
	{"BANU", 4, 169577},
	{"LASING", 6, 169578},
	{"MARYA", 5, 169579},
	{"GREEKTOWN", 9, 169580},
	{"FANTASIZED", 10, 169581},
	{"CARBONELL", 9, 169582},
	{"BLACKETT", 8, 169583},
	{"ROBOFORM", 8, 169584},
	{"PHYLOGENETICS", 13, 169585},
	{"FERNDOWN", 8, 169586},
	{"DEVOUTLY", 8, 169587},
	{"IMHOFF", 6, 169588},
	{"CATTERICK", 9, 169589},
	{"BMV", 3, 169590},
	{"TRANSMIGRATION", 14, 169591},
	{"ADREVOLVER", 10, 169592},
	{"CHIGWELL", 8, 169593},
	{"MEANEY", 6, 169594},
	{"BRANIGAN", 8, 169595},
	{"AMANPOUR", 8, 169596},
	{"ROSING", 6, 169597},
	{"DESHALB", 7, 169598},
	{"REDOUBT", 7, 169599},
	{"WILNER", 6, 169600},
	{"GUALALA", 7, 169601},
	{"OLNINE", 6, 169602},
	{"MEUS", 4, 169603},
	{"IREM", 4, 169604},
	{"FAIRINGS", 8, 169605},
	{"BOOTFLASH", 9, 169606},
	{"REVISIONISTS", 12, 169607},
	{"ANSCHAUEN", 9, 169608},
	{"BLAHBLAH", 8, 169609},
	{"CERVINIA", 8, 169610},
	{"BUNKA", 5, 169611},
	{"DEPARTAMENT", 11, 169612},
	{"DYSMENORRHEA", 12, 169613},
	{"HADDIX", 6, 169614},
	{"ALYESKA", 7, 169615},
	{"PIERMONT", 8, 169616},
	{"ZAPI", 4, 169617},
	{"YGOH", 4, 169618},
	{"YFEI", 4, 169619},
	{"YEBO", 4, 169620},
	{"XICM", 4, 169621},
	{"XCOY", 4, 169622},
	{"WPHE", 4, 169623},
	{"WMDA", 4, 169624},
	{"UGNO", 4, 169625},
	{"UEDJ", 4, 169626},
	{"TKRU", 4, 169627},
	{"PHDT", 4, 169628},
	{"NMMO", 4, 169629},
	{"NDSZ", 4, 169630},
	{"MLEC", 4, 169631},
	{"KWEP", 4, 169632},
	{"IEDQ", 4, 169633},
	{"GGHE", 4, 169634},
	{"FYPO", 4, 169635},
	{"FKOT", 4, 169636},
	{"ESZK", 4, 169637},
	{"ENCD", 4, 169638},
	{"EFBY", 4, 169639},
	{"DKAW", 4, 169640},
	{"MRCLASS", 7, 169641},
	{"LASEK", 5, 169642},
	{"KERK", 4, 169643},
	{"DULANEY", 7, 169644},
	{"DETAILER", 8, 169645},
	{"CONVOLUTIONAL", 13, 169646},
	{"SINKERS", 7, 169647},
	{"REVENANT", 8, 169648},
	{"VIDEX", 5, 169649},
	{"INSTIL", 6, 169650},
	{"VENECIA", 7, 169651},
	{"NEWDOC", 6, 169652},
	{"FUZZINESS", 9, 169653},
	{"BOASTFUL", 8, 169654},
	{"ENUMERATORS", 11, 169655},
	{"SACCADES", 8, 169656},
	{"TERPANDRUS", 10, 169657},
	{"ISOPRENE", 8, 169658},
	{"BILIOUS", 7, 169659},
	{"PKY", 3, 169660},
	{"LEUBSDORF", 9, 169661},
	{"CIENTS", 6, 169662},
	{"MAZURKA", 7, 169663},
	{"INKTEC", 6, 169664},
	{"GREVILLE", 8, 169665},
	{"DYNAUDIO", 8, 169666},
	{"ARCTURA", 7, 169667},
	{"CINEMANOW", 9, 169668},
	{"RHINOVIRUS", 10, 169669},
	{"ERRICO", 6, 169670},
	{"ZEROTH", 6, 169671},
	{"MENUE", 5, 169672},
	{"DISPOSERS", 9, 169673},
	{"YAKI", 4, 169674},
	{"STONEWALLING", 12, 169675},
	{"RADSTOCK", 8, 169676},
	{"ABRAMOVICH", 10, 169677},
	{"COMBIN", 6, 169678},
	{"LEXY", 4, 169679},
	{"POWERD", 6, 169680},
	{"MUNFORD", 7, 169681},
	{"COLDBLOODED", 11, 169682},
	{"HOZELOCK", 8, 169683},
	{"DEVELPMENT", 10, 169684},
	{"BAKHTIN", 7, 169685},
	{"DENKI", 5, 169686},
	{"LADSPA", 6, 169687},
	{"ORSINI", 6, 169688},
	{"AMARAY", 6, 169689},
	{"OVIPOSITION", 11, 169690},
	{"BRILLOUIN", 9, 169691},
	{"BRDU", 4, 169692},
	{"VPBS", 4, 169693},
	{"SQUISHDOT", 9, 169694},
	{"BOULES", 6, 169695},
	{"COPAL", 5, 169696},
	{"DESPONDENCY", 11, 169697},
	{"MARJOLEIN", 9, 169698},
	{"COMPENSATORS", 12, 169699},
	{"BAMS", 4, 169700},
	{"DISHEVELED", 10, 169701},
	{"TROIA", 5, 169702},
	{"MIKTEX", 6, 169703},
	{"XOBA", 4, 169704},
	{"VNOW", 4, 169705},
	{"UFUN", 4, 169706},
	{"ROGT", 4, 169707},
	{"OUXI", 4, 169708},
	{"ORLT", 4, 169709},
	{"OPYH", 4, 169710},
	{"NYAY", 4, 169711},
	{"NTGM", 4, 169712},
	{"NJUP", 4, 169713},
	{"LFGI", 4, 169714},
	{"KJAK", 4, 169715},
	{"IFYG", 4, 169716},
	{"HMYI", 4, 169717},
	{"HEZP", 4, 169718},
	{"FPHR", 4, 169719},
	{"FLAZ", 4, 169720},
	{"EZRO", 4, 169721},
	{"ESBB", 4, 169722},
	{"ECSL", 4, 169723},
	{"DRFI", 4, 169724},
	{"DDRP", 4, 169725},
	{"CDFO", 4, 169726},
	{"BOCE", 4, 169727},
	{"AEUM", 4, 169728},
	{"ITLL", 4, 169729},
	{"CLICQUOT", 8, 169730},
	{"USITC", 5, 169731},
	{"EXCLAMATIONS", 12, 169732},
	{"UNSEASONABLY", 12, 169733},
	{"NEXTSTUDENT", 11, 169734},
	{"BLUESMAN", 8, 169735},
	{"FRIE", 4, 169736},
	{"ASVAB", 5, 169737},
	{"SCHLATTER", 9, 169738},
	{"BRODIT", 6, 169739},
	{"LIEFERBAR", 9, 169740},
	{"BIZZ", 4, 169741},
	{"EXTRATROPICAL", 13, 169742},
	{"SATINY", 6, 169743},
	{"LACTONE", 7, 169744},
	{"FRAGMENTING", 11, 169745},
	{"RIVKIN", 6, 169746},
	{"DOWNPLAYS", 9, 169747},
	{"ARPEGGIO", 8, 169748},
	{"FILMBUG", 7, 169749},
	{"TARGHEE", 7, 169750},
	{"POSTMASTERS", 11, 169751},
	{"PERNOD", 6, 169752},
	{"THEYVE", 6, 169753},
	{"TARBELL", 7, 169754},
	{"NEGOCIO", 7, 169755},
	{"HOLLEN", 6, 169756},
	{"ALLEGORIES", 10, 169757},
	{"MOLLUSC", 7, 169758},
	{"ABYSSAL", 7, 169759},
	{"REZONED", 7, 169760},
	{"LISTOLOGY", 9, 169761},
	{"BHABHA", 6, 169762},
	{"MISBEHAVIOUR", 12, 169763},
	{"HECKE", 5, 169764},
	{"STEVEDORING", 11, 169765},
	{"RADIN", 5, 169766},
	{"FENTERMINE", 10, 169767},
	{"TRIANG", 6, 169768},
	{"GOOSSENS", 8, 169769},
	{"REALI", 5, 169770},
	{"GLATT", 5, 169771},
	{"ENTONCES", 8, 169772},
	{"SARTORI", 7, 169773},
	{"PARECIDO", 8, 169774},
	{"DEMILITARIZED", 13, 169775},
	{"VERENA", 6, 169776},
	{"GARDENDALE", 10, 169777},
	{"EPUS", 4, 169778},
	{"ZEBEDEE", 7, 169779},
	{"COPYSCAPE", 9, 169780},
	{"MIYA", 4, 169781},
	{"EVENSON", 7, 169782},
	{"BULLWHIP", 8, 169783},
	{"TRUDGE", 6, 169784},
	{"SDMI", 4, 169785},
	{"JAMESVILLE", 10, 169786},
	{"BICICLETA", 9, 169787},
	{"XANEX", 5, 169788},
	{"GILBY", 5, 169789},
	{"MINCING", 7, 169790},
	{"CLASTS", 6, 169791},
	{"MSNM", 4, 169792},
	{"TECTED", 6, 169793},
	{"SCURRIED", 8, 169794},
	{"KRYPTONICS", 10, 169795},
	{"PYROS", 5, 169796},
	{"VIZIO", 5, 169797},
	{"PROCOM", 6, 169798},
	{"NEVERFAIL", 9, 169799},
	{"SUITLAND", 8, 169800},
	{"DUTAILIER", 9, 169801},
	{"LAGERS", 6, 169802},
	{"KITSCHY", 7, 169803},
	{"EEUU", 4, 169804},
	{"HAPP", 4, 169805},
	{"SETZT", 5, 169806},
	{"HOMESICKNESS", 12, 169807},
	{"CONTATTO", 8, 169808},
	{"ZAKW", 4, 169809},
	{"YPTC", 4, 169810},
	{"UPTF", 4, 169811},
	{"TODM", 4, 169812},
	{"SRCO", 4, 169813},
	{"SMGO", 4, 169814},
	{"SCDI", 4, 169815},
	{"PHIK", 4, 169816},
	{"OLZH", 4, 169817},
	{"OFPB", 4, 169818},
	{"NMCP", 4, 169819},
	{"MBEM", 4, 169820},
	{"LTPU", 4, 169821},
	{"LLNB", 4, 169822},
	{"LFFS", 4, 169823},
	{"JODH", 4, 169824},
	{"JAPU", 4, 169825},
	{"IKOB", 4, 169826},
	{"FPYR", 4, 169827},
	{"FBUZ", 4, 169828},
	{"DRBU", 4, 169829},
	{"DAKT", 4, 169830},
	{"BCSF", 4, 169831},
	{"ASRP", 4, 169832},
	{"AKTU", 4, 169833},
	{"PERELE", 6, 169834},
	{"DIRECTIVITY", 11, 169835},
	{"BIRKENAU", 8, 169836},
	{"ARABA", 5, 169837},
	{"VIMENTIN", 8, 169838},
	{"MERVIN", 6, 169839},
	{"METAMORPHOSED", 13, 169840},
	{"WILDHEARTS", 10, 169841},
	{"HUSSY", 5, 169842},
	{"THEHUNS", 7, 169843},
	{"HEARTGARD", 9, 169844},
	{"STOICISM", 8, 169845},
	{"CONGREGATED", 11, 169846},
	{"ACHILLEA", 8, 169847},
	{"GOKO", 4, 169848},
	{"SEHGAL", 6, 169849},
	{"BIZMINER", 8, 169850},
	{"MELQUIADES", 10, 169851},
	{"DRAMATICA", 9, 169852},
	{"PRICENOIA", 9, 169853},
	{"HYDROXYSTEROID", 14, 169854},
	{"COVETOUS", 8, 169855},
	{"GIBLETS", 7, 169856},
	{"TRIANA", 6, 169857},
	{"NANOGEN", 7, 169858},
	{"MARILYNNE", 9, 169859},
	{"KDEADMIN", 8, 169860},
	{"DOCKINGSTATION", 14, 169861},
	{"RPCV", 4, 169862},
	{"EWER", 4, 169863},
	{"UATION", 6, 169864},
	{"SPARTAK", 7, 169865},
	{"POWERCONNECT", 12, 169866},
	{"SUPERFEET", 9, 169867},
	{"MADRUGADA", 9, 169868},
	{"GMAN", 4, 169869},
	{"MUSUEM", 6, 169870},
	{"GROOTSTE", 8, 169871},
	{"MASAAKI", 7, 169872},
	{"ISAKSON", 7, 169873},
	{"MELANOCYTES", 11, 169874},
	{"RALSTONIA", 9, 169875},
	{"DOUX", 4, 169876},
	{"EXHUMATION", 10, 169877},
	{"PANFISH", 7, 169878},
	{"VOLODYMYR", 9, 169879},
	{"MNGT", 4, 169880},
	{"MARKSTARMER", 11, 169881},
	{"EVELETH", 7, 169882},
	{"BUTTKICKER", 10, 169883},
	{"MAMBAZO", 7, 169884},
	{"NITPICKING", 10, 169885},
	{"INFORMES", 8, 169886},
	{"BENFLEET", 8, 169887},
	{"PENTATONIC", 10, 169888},
	{"SUBSAMPLES", 10, 169889},
	{"BRIGITTA", 8, 169890},
	{"DDEFNYDDIO", 10, 169891},
	{"ORREFORS", 8, 169892},
	{"SETPROPERTY", 11, 169893},
	{"SWETSWISE", 9, 169894},
	{"CRANKSET", 8, 169895},
	{"LOGINJOIN", 9, 169896},
	{"BRARY", 5, 169897},
	{"PHLTA", 5, 169898},
	{"HAFFNER", 7, 169899},
	{"WEAKERTHANS", 11, 169900},
	{"RAPPIN", 6, 169901},
	{"YSYD", 4, 169902},
	{"WTGI", 4, 169903},
	{"UCTY", 4, 169904},
	{"UAFA", 4, 169905},
	{"TMRE", 4, 169906},
	{"THBP", 4, 169907},
	{"RTVM", 4, 169908},
	{"RLUP", 4, 169909},
	{"RIZW", 4, 169910},
	{"RAJW", 4, 169911},
	{"PPOD", 4, 169912},
	{"ORHP", 4, 169913},
	{"LIUN", 4, 169914},
	{"LAVH", 4, 169915},
	{"ILTV", 4, 169916},
	{"GNIK", 4, 169917},
	{"GGSL", 4, 169918},
	{"FARV", 4, 169919},
	{"EFKE", 4, 169920},
	{"CKJI", 4, 169921},
	{"AWHU", 4, 169922},
	{"AIGG", 4, 169923},
	{"INSTILLATION", 12, 169924},
	{"POTEAU", 6, 169925},
	{"CLIR", 4, 169926},
	{"HAUSCHKA", 8, 169927},
	{"BASHRC", 6, 169928},
	{"BOATLOAD", 8, 169929},
	{"INNATELY", 8, 169930},
	{"DIRECTE", 7, 169931},
	{"RAHAL", 5, 169932},
	{"PIMENTO", 7, 169933},
	{"HYSTERICS", 9, 169934},
	{"WATROUS", 7, 169935},
	{"OVALBUMIN", 9, 169936},
	{"WILBY", 5, 169937},
	{"JOCKEYING", 9, 169938},
	{"DROPING", 7, 169939},
	{"ESSAOUIRA", 9, 169940},
	{"POLITIKH", 8, 169941},
	{"WAPEN", 5, 169942},
	{"SHDSL", 5, 169943},
	{"FOXBOROUGH", 10, 169944},
	{"PROCURES", 8, 169945},
	{"ALRIGHTY", 8, 169946},
	{"EPBC", 4, 169947},
	{"LOGOED", 6, 169948},
	{"GOODLATTE", 9, 169949},
	{"EHOME", 5, 169950},
	{"METODO", 6, 169951},
	{"STIMME", 6, 169952},
	{"RATDVD", 6, 169953},
	{"HENLE", 5, 169954},
	{"CARQUEST", 8, 169955},
	{"HEMMINGWAY", 10, 169956},
	{"AMELIORATED", 11, 169957},
	{"ACEITE", 6, 169958},
	{"SWIRLY", 6, 169959},
	{"CONCERNE", 8, 169960},
	{"VOCALIZATION", 12, 169961},
	{"TACHIBANA", 9, 169962},
	{"PUJOL", 5, 169963},
	{"ROTMAN", 6, 169964},
	{"PACKARDBELL", 11, 169965},
	{"KALYMNOS", 8, 169966},
	{"UTER", 4, 169967},
	{"TRANSKEI", 8, 169968},
	{"CHANCEN", 7, 169969},
	{"ABAC", 4, 169970},
	{"ZOLLINGER", 9, 169971},
	{"STEAMBOY", 8, 169972},
	{"MEGUIARS", 8, 169973},
	{"MAIHOF", 6, 169974},
	{"ILLYRIA", 7, 169975},
	{"GHOULIES", 8, 169976},
	{"TRANSLUCENCY", 12, 169977},
	{"JALOPY", 6, 169978},
	{"FEIGENBAUM", 10, 169979},
	{"IMPERIALISTIC", 13, 169980},
	{"THAPA", 5, 169981},
	{"SIALKOT", 7, 169982},
	{"PLEDGEBANKBETA", 14, 169983},
	{"HYPOTENSIVE", 11, 169984},
	{"KUANTAN", 7, 169985},
	{"PLEASANTS", 9, 169986},
	{"PASOLINI", 8, 169987},
	{"WUHRER", 6, 169988},
	{"ZZET", 4, 169989},
	{"YSJI", 4, 169990},
	{"WLUN", 4, 169991},
	{"UXNE", 4, 169992},
	{"UKEY", 4, 169993},
	{"UIWH", 4, 169994},
	{"TPCO", 4, 169995},
	{"RSRY", 4, 169996},
	{"PSPH", 4, 169997},
	{"NALX", 4, 169998},
	{"MWET", 4, 169999},
	{"MKNI", 4, 170000},
	{"LMOC", 4, 170001},
	{"IGSR", 4, 170002},
	{"HMSD", 4, 170003},
	{"GFEU", 4, 170004},
	{"FAMN", 4, 170005},
	{"EZZI", 4, 170006},
	{"CCOE", 4, 170007},
	{"ATVR", 4, 170008},
	{"ORCHESTER", 9, 170009},
	{"DEVOURS", 7, 170010},
	{"TAKAHIRO", 8, 170011},
	{"JAPONICUS", 9, 170012},
	{"SOLUZIONE", 9, 170013},
	{"SANDESTIN", 9, 170014},
	{"BARRI", 5, 170015},
	{"GARBUTT", 7, 170016},
	{"MONIC", 5, 170017},
	{"MEDIAMONKEY", 11, 170018},
	{"MAILNOTIFY", 10, 170019},
	{"NIHRD", 5, 170020},
	{"MANAGEME", 8, 170021},
	{"GASKINS", 7, 170022},
	{"MAHOU", 5, 170023},
	{"CXM", 3, 170024},
	{"TEACHERNET", 10, 170025},
	{"KIVU", 4, 170026},
	{"ARTSELECT", 9, 170027},
	{"AMTECH", 6, 170028},
	{"MATICALLY", 9, 170029},
	{"CROY", 4, 170030},
	{"WAISTS", 6, 170031},
	{"CLAYDON", 7, 170032},
	{"BERRYHILL", 9, 170033},
	{"NENZELIUS", 9, 170034},
	{"CLIPSE", 6, 170035},
	{"BOUDIN", 6, 170036},
	{"CAREL", 5, 170037},
	{"FACHHOCHSCHULE", 14, 170038},
	{"ELIZONDO", 8, 170039},
	{"HACKLES", 7, 170040},
	{"VILLAR", 6, 170041},
	{"FOGGIA", 6, 170042},
	{"DEMOTE", 6, 170043},
	{"CAPED", 5, 170044},
	{"POLARIZERS", 10, 170045},
	{"REOPERATION", 11, 170046},
	{"JUDAEA", 6, 170047},
	{"WASG", 4, 170048},
	{"LEDEN", 5, 170049},
	{"NAGARJUNA", 9, 170050},
	{"IPARENTING", 10, 170051},
	{"BACKPAY", 7, 170052},
	{"EASYXTAL", 8, 170053},
	{"CAMERATA", 8, 170054},
	{"TUBAN", 5, 170055},
	{"PCTEL", 5, 170056},
	{"PRESCRIPTIONPHENTERMINE", 23, 170057},
	{"VULCANIZED", 10, 170058},
	{"MWW", 3, 170059},
	{"BBTONUKE", 8, 170060},
	{"FIRERED", 7, 170061},
	{"QUIDAM", 6, 170062},
	{"FAIRCLOTH", 9, 170063},
	{"CARSMART", 8, 170064},
	{"DGCOMMUNITIES", 13, 170065},
	{"BYFLEET", 7, 170066},
	{"SALAMON", 7, 170067},
	{"RECOVERABILITY", 14, 170068},
	{"BLINN", 5, 170069},
	{"APIARY", 6, 170070},
	{"SAMBROOK", 8, 170071},
	{"PLOYED", 6, 170072},
	{"ISKRA", 5, 170073},
	{"INTERDEPENDENCY", 15, 170074},
	{"RAVENLOFT", 9, 170075},
	{"POTENTATE", 9, 170076},
	{"WRINGER", 7, 170077},
	{"DOOFUS", 6, 170078},
	{"ACCUSYNC", 8, 170079},
	{"AZUMA", 5, 170080},
	{"LAFCO", 5, 170081},
	{"HTMLENTITIES", 12, 170082},
	{"GRAPPLER", 8, 170083},
	{"BARBARITY", 9, 170084},
	{"MADDING", 7, 170085},
	{"WBCSD", 5, 170086},
	{"MFX", 3, 170087},
	{"ANNEAL", 6, 170088},
	{"ZUNO", 4, 170089},
	{"ZILF", 4, 170090},
	{"YLSU", 4, 170091},
	{"YLMA", 4, 170092},
	{"UMIY", 4, 170093},
	{"TYRH", 4, 170094},
	{"PWID", 4, 170095},
	{"PBOW", 4, 170096},
	{"ORWY", 4, 170097},
	{"ORVP", 4, 170098},
	{"NURL", 4, 170099},
	{"NILG", 4, 170100},
	{"LYUK", 4, 170101},
	{"LUPC", 4, 170102},
	{"LMYA", 4, 170103},
	{"GAEB", 4, 170104},
	{"ENYF", 4, 170105},
	{"DPLI", 4, 170106},
	{"DOXW", 4, 170107},
	{"AVAV", 4, 170108},
	{"EXTIRPATED", 10, 170109},
	{"DEERS", 5, 170110},
	{"DAHIL", 5, 170111},
	{"DOONE", 5, 170112},
	{"BEGAY", 5, 170113},
	{"CARBACHOL", 9, 170114},
	{"LOEHMANN", 8, 170115},
	{"BRYANS", 6, 170116},
	{"RHAETO", 6, 170117},
	{"TRANSCUTANEOUS", 14, 170118},
	{"BAYSTACK", 8, 170119},
	{"VOICEMAILS", 10, 170120},
	{"KOTKA", 5, 170121},
	{"POPEN", 5, 170122},
	{"CRUDUP", 6, 170123},
	{"RAMM", 4, 170124},
	{"PROCURA", 7, 170125},
	{"CHARLATAN", 9, 170126},
	{"WHITEOUT", 8, 170127},
	{"WDAY", 4, 170128},
	{"ESURE", 5, 170129},
	{"ELECTROMAGNET", 13, 170130},
	{"ICONATOR", 8, 170131},
	{"XVF", 3, 170132},
	{"FLESHING", 8, 170133},
	{"PIRSIG", 6, 170134},
	{"SECTORIAL", 9, 170135},
	{"MCCONVILLE", 10, 170136},
	{"KBABEL", 6, 170137},
	{"PERMANGANATE", 12, 170138},
	{"GRIGORY", 7, 170139},
	{"CORIA", 5, 170140},
	{"SLOUCHING", 9, 170141},
	{"PRIVADA", 7, 170142},
	{"NISQUALLY", 9, 170143},
	{"SUSCEPTIBILITIES", 16, 170144},
	{"NITPICK", 7, 170145},
	{"PLAITED", 7, 170146},
	{"CONCEPTDRAW", 11, 170147},
	{"APHTHASOL", 9, 170148},
	{"SEBEL", 5, 170149},
	{"ARAP", 4, 170150},
	{"SHARAD", 6, 170151},
	{"COREOPSIS", 9, 170152},
	{"NARDIL", 6, 170153},
	{"FLOE", 4, 170154},
	{"MANTHORP", 8, 170155},
	{"ARCHIEVE", 8, 170156},
	{"BAGSHOT", 7, 170157},
	{"SURTOUT", 7, 170158},
	{"LEHIGHTON", 9, 170159},
	{"BUKU", 4, 170160},
	{"SHEEPS", 6, 170161},
	{"LYRICZ", 6, 170162},
	{"ZZRO", 4, 170163},
	{"ZAHR", 4, 170164},
	{"YHOY", 4, 170165},
	{"YDIX", 4, 170166},
	{"RYSJ", 4, 170167},
	{"RUSJ", 4, 170168},
	{"RMTV", 4, 170169},
	{"RDYG", 4, 170170},
	{"RDRH", 4, 170171},
	{"RDMD", 4, 170172},
	{"PROQ", 4, 170173},
	{"PPEP", 4, 170174},
	{"PHMI", 4, 170175},
	{"PBIT", 4, 170176},
	{"ORRC", 4, 170177},
	{"OFHD", 4, 170178},
	{"NACB", 4, 170179},
	{"MIKL", 4, 170180},
	{"MCEO", 4, 170181},
	{"JMAY", 4, 170182},
	{"IKVA", 4, 170183},
	{"GRPG", 4, 170184},
	{"GPAW", 4, 170185},
	{"FBYZ", 4, 170186},
	{"EDRT", 4, 170187},
	{"DRSO", 4, 170188},
	{"DAGB", 4, 170189},
	{"BHOM", 4, 170190},
	{"COMMUNITYDISABLED", 17, 170191},
	{"BERKEY", 6, 170192},
	{"AGONIES", 7, 170193},
	{"KRIYA", 5, 170194},
	{"MISJUDGED", 9, 170195},
	{"BATTLEMECH", 10, 170196},
	{"MAEDCHEN", 8, 170197},
	{"AJANTA", 6, 170198},
	{"CASL", 4, 170199},
	{"SCIENCEFICTION", 14, 170200},
	{"ECMASCRIPT", 10, 170201},
	{"ROTARIAN", 8, 170202},
	{"MASASHI", 7, 170203},
	{"GMAP", 4, 170204},
	{"PURYEAR", 7, 170205},
	{"BESANCON", 8, 170206},
	{"WRITHED", 7, 170207},
	{"DJC", 3, 170208},
	{"SAMIUDDIN", 9, 170209},
	{"MEALTIMES", 9, 170210},
	{"KINLEY", 6, 170211},
	{"CYHOEDD", 7, 170212},
	{"CONCIOUSNESS", 12, 170213},
	{"BEINE", 5, 170214},
	{"WITTMANN", 8, 170215},
	{"MYSOURCE", 8, 170216},
	{"SACRO", 5, 170217},
	{"BUFFEREDREADER", 14, 170218},
	{"FRANKLINVILLE", 13, 170219},
	{"VOLTAREN", 8, 170220},
	{"HOUSEMAID", 9, 170221},
	{"FILEZILLA", 9, 170222},
	{"MINITOKYO", 9, 170223},
	{"EURYDICE", 8, 170224},
	{"UNDESERVING", 11, 170225},
	{"MESILLA", 7, 170226},
	{"ATROVENT", 8, 170227},
	{"ZILVER", 6, 170228},
	{"SWETT", 5, 170229},
	{"PORCUPINES", 10, 170230},
	{"CONDEMNATIONS", 13, 170231},
	{"GLYCOSIDE", 9, 170232},
	{"CASIN", 5, 170233},
	{"KIDSPOST", 8, 170234},
	{"MISION", 6, 170235},
	{"UNTRUTH", 7, 170236},
	{"BIOPICS", 7, 170237},
	{"NOOTKA", 6, 170238},
	{"EUROTECH", 8, 170239},
	{"YELO", 4, 170240},
	{"DOCSWELL", 8, 170241},
	{"HOKITIKA", 8, 170242},
	{"GSTAAD", 6, 170243},
	{"OXIDISED", 8, 170244},
	{"NEOSTRATA", 9, 170245},
	{"FRAXINUS", 8, 170246},
	{"LEHANE", 6, 170247},
	{"CONVEYER", 8, 170248},
	{"BULLHORN", 8, 170249},
	{"OVERSIMPLIFICATION", 18, 170250},
	{"KRAWCZYK", 8, 170251},
	{"DIRECTEMENT", 11, 170252},
	{"JOVANOVICH", 10, 170253},
	{"MEDIAGEAR", 9, 170254},
	{"MUMMIFIED", 9, 170255},
	{"PENDAFLEX", 9, 170256},
	{"PIGEONHOLE", 10, 170257},
	{"GYANENDRA", 9, 170258},
	{"PERNA", 5, 170259},
	{"BAIDU", 5, 170260},
	{"TONSILLECTOMY", 13, 170261},
	{"PREYED", 6, 170262},
	{"MSEK", 4, 170263},
	{"ZTOF", 4, 170264},
	{"WUPN", 4, 170265},
	{"WSIC", 4, 170266},
	{"VDWI", 4, 170267},
	{"UXIT", 4, 170268},
	{"UDIW", 4, 170269},
	{"UDCR", 4, 170270},
	{"UBGA", 4, 170271},
	{"THBF", 4, 170272},
	{"RUOU", 4, 170273},
	{"RHEV", 4, 170274},
	{"RAVS", 4, 170275},
	{"PHJO", 4, 170276},
	{"OYEX", 4, 170277},
	{"OIVU", 4, 170278},
	{"OBZU", 4, 170279},
	{"OALY", 4, 170280},
	{"NMUI", 4, 170281},
	{"MRLU", 4, 170282},
	{"MIZR", 4, 170283},
	{"FUPI", 4, 170284},
	{"FMWA", 4, 170285},
	{"CAFW", 4, 170286},
	{"KALEIDO", 7, 170287},
	{"EXTRUDE", 7, 170288},
	{"RELENT", 6, 170289},
	{"FARMACIA", 8, 170290},
	{"MAZDASPEED", 10, 170291},
	{"FXCM", 4, 170292},
	{"SIMLOCK", 7, 170293},
	{"MAIK", 4, 170294},
	{"TELNETD", 7, 170295},
	{"CALABRO", 7, 170296},
	{"SIVANANDA", 9, 170297},
	{"DAGE", 4, 170298},
	{"ZILLAH", 6, 170299},
	{"CHIGNIK", 7, 170300},
	{"LITHOTRIPSY", 11, 170301},
	{"VERBA", 5, 170302},
	{"REXALL", 6, 170303},
	{"REAVIS", 6, 170304},
	{"MOXON", 5, 170305},
	{"HEALTHVISION", 12, 170306},
	{"PMQUOTE", 7, 170307},
	{"CAPENSIS", 8, 170308},
	{"OROFINO", 7, 170309},
	{"ONKINE", 6, 170310},
	{"ELUXURY", 7, 170311},
	{"SILBERSCHATZ", 12, 170312},
	{"PHAEDRA", 7, 170313},
	{"SPIDERWEB", 9, 170314},
	{"JAIMIE", 6, 170315},
	{"CONSORTIUMS", 11, 170316},
	{"SUPEROSITY", 10, 170317},
	{"CAVEMEN", 7, 170318},
	{"TOYRKIA", 7, 170319},
	{"CROPSCIENCE", 11, 170320},
	{"HOLEY", 5, 170321},
	{"SUSU", 4, 170322},
	{"HARDDRIVES", 10, 170323},
	{"PEACEFROG", 9, 170324},
	{"VIGLEN", 6, 170325},
	{"KONTOR", 6, 170326},
	{"CANONICALIZATION", 16, 170327},
	{"GUGINO", 6, 170328},
	{"OLDY", 4, 170329},
	{"JMM", 3, 170330},
	{"ANSOFT", 6, 170331},
	{"POLYMORPH", 9, 170332},
	{"MEANIE", 6, 170333},
	{"ADENOSINETRIPHOSPHATASE", 23, 170334},
	{"HORSEHAIR", 9, 170335},
	{"GEWURZTRAMINER", 14, 170336},
	{"SUPERPOP", 8, 170337},
	{"GUNSMITHING", 11, 170338},
	{"ANTHROPIC", 9, 170339},
	{"NEUROPATHIES", 12, 170340},
	{"FAXON", 5, 170341},
	{"AYUB", 4, 170342},
	{"ZFIR", 4, 170343},
	{"ZAGE", 4, 170344},
	{"YULA", 4, 170345},
	{"YIGE", 4, 170346},
	{"WNLY", 4, 170347},
	{"USAJ", 4, 170348},
	{"UGDA", 4, 170349},
	{"TROZ", 4, 170350},
	{"SPYK", 4, 170351},
	{"SIRU", 4, 170352},
	{"SARJ", 4, 170353},
	{"SALJ", 4, 170354},
	{"PHYJ", 4, 170355},
	{"PEYA", 4, 170356},
	{"LTMY", 4, 170357},
	{"LTJA", 4, 170358},
	{"LMAV", 4, 170359},
	{"LDPM", 4, 170360},
	{"KINQ", 4, 170361},
	{"IPKN", 4, 170362},
	{"FITK", 4, 170363},
	{"DIWR", 4, 170364},
	{"AYLY", 4, 170365},
	{"AVVI", 4, 170366},
	{"ACMU", 4, 170367},
	{"TRAJE", 5, 170368},
	{"THEOTOKOS", 9, 170369},
	{"SLINGBACK", 9, 170370},
	{"INTERWEAVING", 12, 170371},
	{"IMRT", 4, 170372},
	{"CAPRIATI", 8, 170373},
	{"LLR", 3, 170374},
	{"KEVINROSE", 9, 170375},
	{"RBCS", 4, 170376},
	{"LWV", 3, 170377},
	{"DISAGGREGATE", 12, 170378},
	{"STOUFFVILLE", 11, 170379},
	{"CRACKHEAD", 9, 170380},
	{"HAGELIN", 7, 170381},
	{"TRILOBITES", 10, 170382},
	{"NORETHINDRONE", 13, 170383},
	{"EJAKULATION", 11, 170384},
	{"COMMERZBANK", 11, 170385},
	{"ARRIGO", 6, 170386},
	{"ZENTURI", 7, 170387},
	{"ILLUST", 6, 170388},
	{"ULIMIT", 6, 170389},
	{"PAYFLOW", 7, 170390},
	{"EPSCOR", 6, 170391},
	{"SEINEM", 6, 170392},
	{"DAYAL", 5, 170393},
	{"CAMALICH", 8, 170394},
	{"ENDFOR", 6, 170395},
	{"HOLZMAN", 7, 170396},
	{"HANDELT", 7, 170397},
	{"NIGHTWATCH", 10, 170398},
	{"UNADVERTISED", 12, 170399},
	{"EXPRESSVU", 9, 170400},
	{"BERI", 4, 170401},
	{"MKINITRD", 8, 170402},
	{"TAHRIR", 6, 170403},
	{"SWITCHBOARDS", 12, 170404},
	{"TYPOY", 5, 170405},
	{"MANDARINS", 9, 170406},
	{"SFORZA", 6, 170407},
	{"ROBBINSVILLE", 12, 170408},
	{"ANACRON", 7, 170409},
	{"INCOLLECTION", 12, 170410},
	{"INDIFFERENTLY", 13, 170411},
	{"EZQUEST", 7, 170412},
	{"TAMPINES", 8, 170413},
	{"HCTZ", 4, 170414},
	{"NEVIL", 5, 170415},
	{"TREET", 5, 170416},
	{"SNUGRIDE", 8, 170417},
	{"PETTUS", 6, 170418},
	{"CRAWBAR", 7, 170419},
	{"BECOUSE", 7, 170420},
	{"HYDEN", 5, 170421},
	{"GOMMA", 5, 170422},
	{"MANKIW", 6, 170423},
	{"SORRENTINO", 10, 170424},
	{"PROGRAMINTERNATIONAL", 20, 170425},
	{"PANICKY", 7, 170426},
	{"MARTELLO", 8, 170427},
	{"SHUNS", 5, 170428},
	{"ROKEBY", 6, 170429},
	{"EXEEXT", 6, 170430},
	{"TEILE", 5, 170431},
	{"DESENSITIZED", 12, 170432},
	{"RINOS", 5, 170433},
	{"RETINUE", 7, 170434},
	{"WARRENS", 7, 170435},
	{"PCCW", 4, 170436},
	{"HERTZOG", 7, 170437},
	{"BOGOMIPS", 8, 170438},
	{"ZEAW", 4, 170439},
	{"YVAI", 4, 170440},
	{"XPOT", 4, 170441},
	{"UTYQ", 4, 170442},
	{"TMLB", 4, 170443},
	{"RKOI", 4, 170444},
	{"REVF", 4, 170445},
	{"QUOJ", 4, 170446},
	{"LFAK", 4, 170447},
	{"KOWO", 4, 170448},
	{"ILDQ", 4, 170449},
	{"HIRV", 4, 170450},
	{"EMWC", 4, 170451},
	{"DVIZ", 4, 170452},
	{"DPAA", 4, 170453},
	{"CMUT", 4, 170454},
	{"BSUC", 4, 170455},
	{"ATJP", 4, 170456},
	{"CARDROOM", 8, 170457},
	{"PARANG", 6, 170458},
	{"ASPERA", 6, 170459},
	{"VAMPIRIC", 8, 170460},
	{"PRINCO", 6, 170461},
	{"HOMEOPATH", 9, 170462},
	{"JEFFERSONIAN", 12, 170463},
	{"SHIPPABLE", 9, 170464},
	{"SHAWMUT", 7, 170465},
	{"ROOMFUL", 7, 170466},
	{"BERTSCH", 7, 170467},
	{"EXCLU", 5, 170468},
	{"CHRISTAIN", 9, 170469},
	{"GRUFFUDD", 8, 170470},
	{"KANAI", 5, 170471},
	{"HERTZBERG", 9, 170472},
	{"HULDA", 5, 170473},
	{"IMPOSTORS", 9, 170474},
	{"GUFF", 4, 170475},
	{"LOPER", 5, 170476},
	{"USAAF", 5, 170477},
	{"PRIVILEDGE", 10, 170478},
	{"STEHEN", 6, 170479},
	{"CONSUMATING", 11, 170480},
	{"OLDBOY", 6, 170481},
	{"FLYLEAF", 7, 170482},
	{"OSSERVATORIO", 12, 170483},
	{"CVV", 3, 170484},
	{"BRAWLS", 6, 170485},
	{"SUBCLAVIAN", 10, 170486},
	{"KIDORABLE", 9, 170487},
	{"SWISSINFO", 9, 170488},
	{"QMJHL", 5, 170489},
	{"DERANGEMENT", 11, 170490},
	{"RUTT", 4, 170491},
	{"ACARD", 5, 170492},
	{"PANELLISTS", 10, 170493},
	{"SOURCEAGENCY", 12, 170494},
	{"SWATHS", 6, 170495},
	{"MESMO", 5, 170496},
	{"DEFOGGER", 8, 170497},
	{"THOUGHOUT", 9, 170498},
	{"CRISPLY", 7, 170499},
	{"LABRADOODLE", 11, 170500},
	{"FFEL", 4, 170501},
	{"THOLE", 5, 170502},
	{"GUMPTION", 8, 170503},
	{"BIRDWELL", 8, 170504},
	{"HANDCARVED", 10, 170505},
	{"FAIRLIE", 7, 170506},
	{"XTEND", 5, 170507},
	{"SUBCRIBE", 8, 170508},
	{"GANASSI", 7, 170509},
	{"OSVERSION", 9, 170510},
	{"WALANG", 6, 170511},
	{"EXTANG", 6, 170512},
	{"CLAMBAKE", 8, 170513},
	{"HINAUS", 6, 170514},
	{"INOTROPIC", 9, 170515},
	{"SPLICER", 7, 170516},
	{"EPICTETUS", 9, 170517},
	{"MANICOTTI", 9, 170518},
	{"BOUNDEDNESS", 11, 170519},
	{"TOOLSTATION", 11, 170520},
	{"PWYLLGOR", 8, 170521},
	{"KINDERGARTNERS", 14, 170522},
	{"VARIEGATA", 9, 170523},
	{"TOPKAPI", 7, 170524},
	{"MUISC", 5, 170525},
	{"CARPS", 5, 170526},
	{"TECHCENTER", 10, 170527},
	{"HEYMANN", 7, 170528},
	{"LAUDERHILL", 10, 170529},
	{"IMPERTINENT", 11, 170530},
	{"CARLIE", 6, 170531},
	{"UDAE", 4, 170532},
	{"TIMV", 4, 170533},
	{"RZOR", 4, 170534},
	{"PIML", 4, 170535},
	{"OPSV", 4, 170536},
	{"NDTJ", 4, 170537},
	{"MAEB", 4, 170538},
	{"KYDR", 4, 170539},
	{"KVET", 4, 170540},
	{"KJAG", 4, 170541},
	{"KEVL", 4, 170542},
	{"KBAB", 4, 170543},
	{"IVVI", 4, 170544},
	{"HSRU", 4, 170545},
	{"GYPU", 4, 170546},
	{"FMTV", 4, 170547},
	{"FBIF", 4, 170548},
	{"DOHY", 4, 170549},
	{"DHEZ", 4, 170550},
	{"BOGR", 4, 170551},
	{"AWKN", 4, 170552},
	{"GCMD", 4, 170553},
	{"INTRANSIGENCE", 13, 170554},
	{"OHLINE", 6, 170555},
	{"GUILHERME", 9, 170556},
	{"DAHON", 5, 170557},
	{"HARIHARAN", 9, 170558},
	{"DOMAN", 5, 170559},
	{"TALAL", 5, 170560},
	{"EYESTRAIN", 9, 170561},
	{"INTERSTED", 9, 170562},
	{"SHENANGO", 8, 170563},
	{"ISOBUTYL", 8, 170564},
	{"OUVRIR", 6, 170565},
	{"SUNNYBANK", 9, 170566},
	{"DOLLING", 7, 170567},
	{"TSCALARTYPE", 11, 170568},
	{"BUFFETED", 8, 170569},
	{"PREYS", 5, 170570},
	{"BLANDY", 6, 170571},
	{"CAROLERS", 8, 170572},
	{"YOSHIAKI", 8, 170573},
	{"HYDRALAZINE", 11, 170574},
	{"NASSCOM", 7, 170575},
	{"THINKMATE", 9, 170576},
	{"POSTALCODE", 10, 170577},
	{"BARTA", 5, 170578},
	{"LOCKSTEP", 8, 170579},
	{"CERD", 4, 170580},
	{"CHILDFREE", 9, 170581},
	{"GASCONADE", 9, 170582},
	{"MENTALISM", 9, 170583},
	{"DARKLIGHT", 9, 170584},
	{"STELLATE", 8, 170585},
	{"PHYSIOGNOMY", 11, 170586},
	{"IAFF", 4, 170587},
	{"PARDUBICE", 9, 170588},
	{"DEFLATING", 9, 170589},
	{"SALVAJE", 7, 170590},
	{"HECUBA", 6, 170591},
	{"BARBITURATE", 11, 170592},
	{"DUDAS", 5, 170593},
	{"OISEAU", 6, 170594},
	{"HEPARAN", 7, 170595},
	{"ENCASE", 6, 170596},
	{"MCCASLIN", 8, 170597},
	{"ROOKWOOD", 8, 170598},
	{"MCKEITH", 7, 170599},
	{"EXOGENOUSLY", 11, 170600},
	{"ANTIDEPRESSIVE", 14, 170601},
	{"ERIES", 5, 170602},
	{"SAEHAN", 6, 170603},
	{"QEYNOS", 6, 170604},
	{"YNNY", 4, 170605},
	{"YAMH", 4, 170606},
	{"WGAV", 4, 170607},
	{"WBLI", 4, 170608},
	{"VYPI", 4, 170609},
	{"TDAP", 4, 170610},
	{"RNTF", 4, 170611},
	{"OMRD", 4, 170612},
	{"NIFG", 4, 170613},
	{"NDFB", 4, 170614},
	{"MPHC", 4, 170615},
	{"MFTA", 4, 170616},
	{"LSMR", 4, 170617},
	{"LIFP", 4, 170618},
	{"LHAQ", 4, 170619},
	{"KLUC", 4, 170620},
	{"KIUN", 4, 170621},
	{"IVAF", 4, 170622},
	{"IRYG", 4, 170623},
	{"GRYG", 4, 170624},
	{"FGEM", 4, 170625},
	{"EDDM", 4, 170626},
	{"ECKJ", 4, 170627},
	{"EBHU", 4, 170628},
	{"DWII", 4, 170629},
	{"CYEL", 4, 170630},
	{"CUNL", 4, 170631},
	{"CLAK", 4, 170632},
	{"ANCB", 4, 170633},
	{"BEHOOVES", 8, 170634},
	{"CFW", 3, 170635},
	{"ALIQUIPPA", 9, 170636},
	{"METACOGNITIVE", 13, 170637},
	{"VERVAIN", 7, 170638},
	{"AMATRICE", 8, 170639},
	{"FLUTIE", 6, 170640},
	{"QUARTIC", 7, 170641},
	{"MISSHAPEN", 9, 170642},
	{"SCRUBBY", 7, 170643},
	{"JEDOCH", 6, 170644},
	{"MADHUR", 6, 170645},
	{"LIVEABLE", 8, 170646},
	{"SHOUTBLOCK", 10, 170647},
	{"INCAN", 5, 170648},
	{"TYNEMOUTH", 9, 170649},
	{"YACHTSMAN", 9, 170650},
	{"SGIAN", 5, 170651},
	{"QUINKAN", 7, 170652},
	{"DIAMONIQUE", 10, 170653},
	{"GROUNDCOVER", 11, 170654},
	{"ALEKSANDRA", 10, 170655},
	{"ESPOUSES", 8, 170656},
	{"CATTERIES", 9, 170657},
	{"GENOTOXICITY", 12, 170658},
	{"EXPOR", 5, 170659},
	{"DREAMWORLD", 10, 170660},
	{"VERSCHICKEN", 11, 170661},
	{"GNOPERNICUS", 11, 170662},
	{"NOVIKOV", 7, 170663},
	{"INVALIDES", 9, 170664},
	{"CANDLEMAKING", 12, 170665},
	{"BEUR", 4, 170666},
	{"TOUCHSCREENS", 12, 170667},
	{"MARSHALING", 10, 170668},
	{"SPARTINA", 8, 170669},
	{"MYOGENIC", 8, 170670},
	{"LINPHONE", 8, 170671},
	{"TAIJIQUAN", 9, 170672},
	{"DEMIREL", 7, 170673},
	{"SISTRIX", 7, 170674},
	{"MADLIB", 6, 170675},
	{"PHOTOIONIZATION", 15, 170676},
	{"LASERCORNER", 11, 170677},
	{"PUMMEL", 6, 170678},
	{"POPULARIZE", 10, 170679},
	{"HYDROGENAUDIO", 13, 170680},
	{"MOTORBOATS", 10, 170681},
	{"UNPOLISHED", 10, 170682},
	{"ABRAMOWITZ", 10, 170683},
	{"SHALALA", 7, 170684},
	{"RAITH", 5, 170685},
	{"DOBUTAMINE", 10, 170686},
	{"VALES", 5, 170687},
	{"STROIES", 7, 170688},
	{"AIOLI", 5, 170689},
	{"STARTDATE", 9, 170690},
	{"STEADINESS", 10, 170691},
	{"CEASELESSLY", 11, 170692},
	{"MCWHIRTER", 9, 170693},
	{"LAVAZZA", 7, 170694},
	{"REINVIGORATED", 13, 170695},
	{"WATERBEDS", 9, 170696},
	{"SYNTHESISE", 10, 170697},
	{"GAUSE", 5, 170698},
	{"DISCHARF", 8, 170699},
	{"ZDAS", 4, 170700},
	{"ZAFF", 4, 170701},
	{"XDIG", 4, 170702},
	{"WSOD", 4, 170703},
	{"UOWO", 4, 170704},
	{"UNZA", 4, 170705},
	{"TTJU", 4, 170706},
	{"SUKK", 4, 170707},
	{"SRYD", 4, 170708},
	{"RMNI", 4, 170709},
	{"RLRA", 4, 170710},
	{"RFFS", 4, 170711},
	{"PUBB", 4, 170712},
	{"PJER", 4, 170713},
	{"OWYI", 4, 170714},
	{"NOLC", 4, 170715},
	{"MTVV", 4, 170716},
	{"MLBS", 4, 170717},
	{"MCAW", 4, 170718},
	{"HRWA", 4, 170719},
	{"HOLK", 4, 170720},
	{"HLWH", 4, 170721},
	{"HLFO", 4, 170722},
	{"HFCH", 4, 170723},
	{"GWAK", 4, 170724},
	{"GSMY", 4, 170725},
	{"FYAK", 4, 170726},
	{"FRYT", 4, 170727},
	{"EVVI", 4, 170728},
	{"EUZE", 4, 170729},
	{"ERCW", 4, 170730},
	{"COGD", 4, 170731},
	{"AXPU", 4, 170732},
	{"IRISHMEN", 8, 170733},
	{"SOURCELABS", 10, 170734},
	{"NEURITE", 7, 170735},
	{"DEVIKA", 6, 170736},
	{"NUDI", 4, 170737},
	{"DIAPASON", 8, 170738},
	{"PROSPEKT", 8, 170739},
	{"BOOTSPLASH", 10, 170740},
	{"SUBGOAL", 7, 170741},
	{"REPLANTED", 9, 170742},
	{"OPENAIR", 7, 170743},
	{"NISMS", 5, 170744},
	{"CHARMES", 7, 170745},
	{"DEHYDRATORS", 11, 170746},
	{"BEDRIJF", 7, 170747},
	{"SELLY", 5, 170748},
	{"ORGANIZACIONES", 14, 170749},
	{"CUVETTE", 7, 170750},
	{"HADAMARD", 8, 170751},
	{"KEXI", 4, 170752},
	{"BASERUNNING", 11, 170753},
	{"POLICYAFFILIATE", 15, 170754},
	{"SLANGRTL", 8, 170755},
	{"APIDOC", 6, 170756},
	{"PORPHYRINS", 10, 170757},
	{"ROCKIT", 6, 170758},
	{"GINOBILI", 8, 170759},
	{"CHERRIE", 7, 170760},
	{"DISPOSSESSION", 13, 170761},
	{"FORMALISE", 9, 170762},
	{"GMTV", 4, 170763},
	{"CLAGETT", 7, 170764},
	{"PURP", 4, 170765},
	{"BROXTOWE", 8, 170766},
	{"HOUSECAT", 8, 170767},
	{"DUNHUANG", 8, 170768},
	{"WRITEBACK", 9, 170769},
	{"ANVIN", 5, 170770},
	{"BOBBER", 6, 170771},
	{"SHOELESS", 8, 170772},
	{"ORDERFORM", 9, 170773},
	{"MCCLURG", 7, 170774},
	{"FEDERATE", 8, 170775},
	{"ODONNELL", 8, 170776},
	{"SUCCOR", 6, 170777},
	{"NAFF", 4, 170778},
	{"MACDILL", 7, 170779},
	{"HALFBACK", 8, 170780},
	{"MARKETPLACEPRIVACY", 18, 170781},
	{"ARBUS", 5, 170782},
	{"OCTAHEDRAL", 10, 170783},
	{"ZAHEER", 6, 170784},
	{"TIJDSCHRIFT", 11, 170785},
	{"MEASURER", 8, 170786},
	{"IOFFERLITE", 10, 170787},
	{"BRANCHE", 7, 170788},
	{"NADIM", 5, 170789},
	{"LEZBIAN", 7, 170790},
	{"CANNABUDS", 9, 170791},
	{"SPAFFORD", 8, 170792},
	{"INOCULATIONS", 12, 170793},
	{"TELECENTRES", 11, 170794},
	{"LIBRARYTHING", 12, 170795},
	{"AIRDEFENSE", 10, 170796},
	{"GALLACHER", 9, 170797},
	{"ELECTROL", 8, 170798},
	{"SWIPING", 7, 170799},
	{"CASALS", 6, 170800},
	{"EUSKADI", 7, 170801},
	{"PEARCY", 6, 170802},
	{"ISENGARD", 8, 170803},
	{"FREMDGEHEN", 10, 170804},
	{"EFECTO", 6, 170805},
	{"RETREAD", 7, 170806},
	{"XBMC", 4, 170807},
	{"POCT", 4, 170808},
	{"ZULL", 4, 170809},
	{"ZISD", 4, 170810},
	{"UOIF", 4, 170811},
	{"UBLJ", 4, 170812},
	{"OUMB", 4, 170813},
	{"OJOC", 4, 170814},
	{"OBGI", 4, 170815},
	{"MYJE", 4, 170816},
	{"MRUD", 4, 170817},
	{"MPID", 4, 170818},
	{"LEKW", 4, 170819},
	{"LAIP", 4, 170820},
	{"GNMU", 4, 170821},
	{"GMCD", 4, 170822},
	{"FKAU", 4, 170823},
	{"EVFR", 4, 170824},
	{"EUTC", 4, 170825},
	{"ANKZ", 4, 170826},
	{"SMUTS", 5, 170827},
	{"VIREMIA", 7, 170828},
	{"NEWCO", 5, 170829},
	{"FEMINIZED", 9, 170830},
	{"CARTO", 5, 170831},
	{"ONLINW", 6, 170832},
	{"VIRGINMEGASTORES", 16, 170833},
	{"FLEXOGRAPHIC", 12, 170834},
	{"HEISER", 6, 170835},
	{"LINDFIELD", 9, 170836},
	{"CYNNIG", 6, 170837},
	{"AGUE", 4, 170838},
	{"ATTENDERS", 9, 170839},
	{"RECOMPILATION", 13, 170840},
	{"JORNAL", 6, 170841},
	{"HAGGADAH", 8, 170842},
	{"SOURCELINES", 11, 170843},
	{"ESCOLAR", 7, 170844},
	{"SUDAH", 5, 170845},
	{"STARSCREAM", 10, 170846},
	{"CURETTAGE", 9, 170847},
	{"OWENSVILLE", 10, 170848},
	{"SODDEN", 6, 170849},
	{"HELPE", 5, 170850},
	{"FRANCESC", 8, 170851},
	{"CHANGEMENTS", 11, 170852},
	{"UNAVAILING", 10, 170853},
	{"RIMFIRE", 7, 170854},
	{"BRADT", 5, 170855},
	{"FRUSTRATINGLY", 13, 170856},
	{"VAGABONDS", 9, 170857},
	{"HIGHTSTOWN", 10, 170858},
	{"FISTULAS", 8, 170859},
	{"REICHS", 6, 170860},
	{"RAMUS", 5, 170861},
	{"ACROMEGALY", 10, 170862},
	{"RAHEEM", 6, 170863},
	{"THINKBABY", 9, 170864},
	{"HEMENWAY", 8, 170865},
	{"SOUNDSCAN", 9, 170866},
	{"CIALES", 6, 170867},
	{"GILBERTSVILLE", 13, 170868},
	{"RUSIAN", 6, 170869},
	{"ENANTIOMERS", 11, 170870},
	{"GOWING", 6, 170871},
	{"BROMAS", 6, 170872},
	{"TOWHEE", 6, 170873},
	{"DPOF", 4, 170874},
	{"XTEDDY", 6, 170875},
	{"ALLPM", 5, 170876},
	{"STANWELL", 8, 170877},
	{"MEYRIN", 6, 170878},
	{"JAAFARI", 7, 170879},
	{"SEMICONDUCTING", 14, 170880},
	{"IRREVERENCE", 11, 170881},
	{"WAKW", 4, 170882},
	{"VARW", 4, 170883},
	{"UKSC", 4, 170884},
	{"UKIF", 4, 170885},
	{"TEKW", 4, 170886},
	{"RMTU", 4, 170887},
	{"PTHP", 4, 170888},
	{"PPSR", 4, 170889},
	{"PPIF", 4, 170890},
	{"OWDN", 4, 170891},
	{"OMUA", 4, 170892},
	{"MVUL", 4, 170893},
	{"MUDP", 4, 170894},
	{"MSOY", 4, 170895},
	{"KUPJ", 4, 170896},
	{"INZF", 4, 170897},
	{"GANQ", 4, 170898},
	{"FKHO", 4, 170899},
	{"EPCP", 4, 170900},
	{"ENRB", 4, 170901},
	{"DWOW", 4, 170902},
	{"CBES", 4, 170903},
	{"AWJA", 4, 170904},
	{"ATVP", 4, 170905},
	{"ALLX", 4, 170906},
	{"UNSEEDED", 8, 170907},
	{"SLEEKER", 7, 170908},
	{"INTERNATIONAAL", 14, 170909},
	{"LEFTWARD", 8, 170910},
	{"GYMNEMA", 7, 170911},
	{"FLYLIGHT", 8, 170912},
	{"DYNEGY", 6, 170913},
	{"LESAGE", 6, 170914},
	{"WASHINGTONIAN", 13, 170915},
	{"AUSTRA", 6, 170916},
	{"UNLIM", 5, 170917},
	{"ICHIBAN", 7, 170918},
	{"RELEGATE", 8, 170919},
	{"PROGRAMSHOPPING", 15, 170920},
	{"MORESOME", 8, 170921},
	{"CMAX", 4, 170922},
	{"CBX", 3, 170923},
	{"ABERCORN", 8, 170924},
	{"TUNEL", 5, 170925},
	{"NANOPHASE", 9, 170926},
	{"DEMINT", 6, 170927},
	{"CRYPTOSPORIDIOSIS", 17, 170928},
	{"SHEFFER", 7, 170929},
	{"REMIC", 5, 170930},
	{"CHAISES", 7, 170931},
	{"STATESMANSHIP", 13, 170932},
	{"ACCOMPAGNATRICI", 15, 170933},
	{"STWFLBP", 7, 170934},
	{"PAPST", 5, 170935},
	{"WUFTPD", 6, 170936},
	{"TOXICANT", 8, 170937},
	{"POPOLO", 6, 170938},
	{"NATOMAS", 7, 170939},
	{"SANER", 5, 170940},
	{"TENDRE", 6, 170941},
	{"KELBY", 5, 170942},
	{"EUROTIQUE", 9, 170943},
	{"SPLENDORA", 9, 170944},
	{"GRAYBAR", 7, 170945},
	{"CHULCLONGKORN", 13, 170946},
	{"LIEFERUNG", 9, 170947},
	{"VOLATILITIES", 12, 170948},
	{"MUSHTAQ", 7, 170949},
	{"LIBUSB", 6, 170950},
	{"ALTQ", 4, 170951},
	{"GROSSBERG", 9, 170952},
	{"SHAPIRA", 7, 170953},
	{"PROPRIETORSHIPS", 15, 170954},
	{"SWAIM", 5, 170955},
	{"HALLA", 5, 170956},
	{"SABLEFISH", 9, 170957},
	{"JOHNSMITH", 9, 170958},
	{"SCHLAFLY", 8, 170959},
	{"RACCONTO", 8, 170960},
	{"IFOSFAMIDE", 10, 170961},
	{"ZEEBRUGGE", 9, 170962},
	{"DEMORALIZING", 12, 170963},
	{"TASTIEST", 8, 170964},
	{"RISTO", 5, 170965},
	{"FRIZZY", 6, 170966},
	{"SPANJE", 6, 170967},
	{"SOLFATARICUS", 12, 170968},
	{"ONDCP", 5, 170969},
	{"PREST", 5, 170970},
	{"PCPS", 4, 170971},
	{"UNSOLVABLE", 10, 170972},
	{"BUNZ", 4, 170973},
	{"SYNUCLEIN", 9, 170974},
	{"STALLWORTH", 10, 170975},
	{"WINDO", 5, 170976},
	{"DISILLUSION", 11, 170977},
	{"KOOPA", 5, 170978},
	{"NUBA", 4, 170979},
	{"LADINO", 6, 170980},
	{"YTIB", 4, 170981},
	{"YJAV", 4, 170982},
	{"XINL", 4, 170983},
	{"WETD", 4, 170984},
	{"VIPR", 4, 170985},
	{"UMPJ", 4, 170986},
	{"UKBE", 4, 170987},
	{"TLLS", 4, 170988},
	{"TCMO", 4, 170989},
	{"RWII", 4, 170990},
	{"OULN", 4, 170991},
	{"MRIA", 4, 170992},
	{"MAUB", 4, 170993},
	{"LKYA", 4, 170994},
	{"KKUN", 4, 170995},
	{"JDER", 4, 170996},
	{"IACG", 4, 170997},
	{"HLEP", 4, 170998},
	{"GIGH", 4, 170999},
	{"GEEB", 4, 171000},
	{"FZIN", 4, 171001},
	{"FELG", 4, 171002},
	{"EVMI", 4, 171003},
	{"ERZL", 4, 171004},
	{"ECBR", 4, 171005},
	{"CTSQ", 4, 171006},
	{"AXYW", 4, 171007},
	{"AXUS", 4, 171008},
	{"AEDR", 4, 171009},
	{"ACOY", 4, 171010},
	{"SINISE", 6, 171011},
	{"WLC", 3, 171012},
	{"EMIGRE", 6, 171013},
	{"AXBOE", 5, 171014},
	{"REVI", 4, 171015},
	{"SAKAGUCHI", 9, 171016},
	{"FREEPERS", 8, 171017},
	{"WISDOMS", 7, 171018},
	{"FROCKS", 6, 171019},
	{"ARGENTA", 7, 171020},
	{"VNBIZ", 5, 171021},
	{"CPIA", 4, 171022},
	{"PHPLIB", 6, 171023},
	{"PONER", 5, 171024},
	{"EGIL", 4, 171025},
	{"LIFEBLOG", 8, 171026},
	{"PARKINS", 7, 171027},
	{"MECHAN", 6, 171028},
	{"LEBER", 5, 171029},
	{"DOCENTS", 7, 171030},
	{"RUNAROUND", 9, 171031},
	{"OPPOSABLE", 9, 171032},
	{"ACCLIMATIZATION", 15, 171033},
	{"WERTHEIM", 8, 171034},
	{"CASSATION", 9, 171035},
	{"THRONGED", 8, 171036},
	{"HISTCITE", 8, 171037},
	{"SIVELY", 6, 171038},
	{"WATERFIELD", 10, 171039},
	{"MELANSON", 8, 171040},
	{"OXTED", 5, 171041},
	{"PUPPETMASTER", 12, 171042},
	{"DRTV", 4, 171043},
	{"POMPINI", 7, 171044},
	{"ABAYA", 5, 171045},
	{"BESEECHING", 10, 171046},
	{"CATMAN", 6, 171047},
	{"MYISLA", 6, 171048},
	{"BLYSS", 5, 171049},
	{"WIGGLER", 7, 171050},
	{"GUSSETS", 7, 171051},
	{"ASPER", 5, 171052},
	{"REEDSVILLE", 10, 171053},
	{"NEWEL", 5, 171054},
	{"IRKSOME", 7, 171055},
	{"ROCKETBOOM", 10, 171056},
	{"UNKNOW", 6, 171057},
	{"EXOCRINE", 8, 171058},
	{"STARPULSE", 9, 171059},
	{"YCOMP", 5, 171060},
	{"BERGGREN", 8, 171061},
	{"BATTENS", 7, 171062},
	{"HDBK", 4, 171063},
	{"NAQP", 4, 171064},
	{"FORTNER", 7, 171065},
	{"AVILES", 6, 171066},
	{"SEMIARID", 8, 171067},
	{"RACAL", 5, 171068},
	{"DVDXCOPY", 8, 171069},
	{"BLL", 3, 171070},
	{"ICMS", 4, 171071},
	{"VIBORG", 6, 171072},
	{"KRAUTROCK", 9, 171073},
	{"CITEULIKE", 9, 171074},
	{"ESOTERICA", 9, 171075},
	{"SHOPKO", 6, 171076},
	{"CHCS", 4, 171077},
	{"CERTIFICAZIONE", 14, 171078},
	{"TAWNYA", 6, 171079},
	{"INFANTINO", 9, 171080},
	{"ENDOTOXINS", 10, 171081},
	{"HJEMMESIDE", 10, 171082},
	{"UGSS", 4, 171083},
	{"PROFESOR", 8, 171084},
	{"BXM", 3, 171085},
	{"MCGONAGALL", 10, 171086},
	{"BURGESSES", 9, 171087},
	{"OXYGENATE", 9, 171088},
	{"QASR", 4, 171089},
	{"PROFESIONALES", 13, 171090},
	{"ADMN", 4, 171091},
	{"CHEMOPREVENTION", 15, 171092},
	{"COGEN", 5, 171093},
	{"GOONISH", 7, 171094},
	{"ABBESS", 6, 171095},
	{"ZUAN", 4, 171096},
	{"VEYG", 4, 171097},
	{"UQUO", 4, 171098},
	{"UKSP", 4, 171099},
	{"RPUF", 4, 171100},
	{"RPTA", 4, 171101},
	{"ROTM", 4, 171102},
	{"RNEK", 4, 171103},
	{"RJUG", 4, 171104},
	{"RBHE", 4, 171105},
	{"PBID", 4, 171106},
	{"NSPP", 4, 171107},
	{"LYEY", 4, 171108},
	{"LTZH", 4, 171109},
	{"KOVR", 4, 171110},
	{"IOFD", 4, 171111},
	{"FSTF", 4, 171112},
	{"FHEJ", 4, 171113},
	{"DYMY", 4, 171114},
	{"CSFU", 4, 171115},
	{"PALESTRINA", 10, 171116},
	{"IMMUNOPRECIPITATED", 18, 171117},
	{"QUENCHER", 8, 171118},
	{"MINUIT", 6, 171119},
	{"MSNCOM", 6, 171120},
	{"GOOGLER", 7, 171121},
	{"CAHEN", 5, 171122},
	{"BIENNIALLY", 10, 171123},
	{"ROENTGEN", 8, 171124},
	{"IMMUNOASSAYS", 12, 171125},
	{"FIRETEAM", 8, 171126},
	{"BIOLAGE", 7, 171127},
	{"BILLINGSGATE", 12, 171128},
	{"URSO", 4, 171129},
	{"PARAMETERIZATIONS", 17, 171130},
	{"DTEND", 5, 171131},
	{"FETTERMAN", 9, 171132},
	{"WAIMANALO", 9, 171133},
	{"NUBS", 4, 171134},
	{"SERONEGATIVE", 12, 171135},
	{"THERMOCLINE", 11, 171136},
	{"RECIPIE", 7, 171137},
	{"UNCOUNTED", 9, 171138},
	{"TALLON", 6, 171139},
	{"COMPARAR", 8, 171140},
	{"EFFACING", 8, 171141},
	{"ORGASAM", 7, 171142},
	{"HYPERCOM", 8, 171143},
	{"GEODYNAMICS", 11, 171144},
	{"TRANSCENDER", 11, 171145},
	{"YOURSELFER", 10, 171146},
	{"SQUIRTED", 8, 171147},
	{"SCHOOLROOM", 10, 171148},
	{"VARUS", 5, 171149},
	{"LILT", 4, 171150},
	{"POLITICKING", 11, 171151},
	{"TERRASSE", 8, 171152},
	{"INTRACTABILITY", 14, 171153},
	{"CBEDS", 5, 171154},
	{"AMATI", 5, 171155},
	{"ECOMMER", 7, 171156},
	{"AEROGEL", 7, 171157},
	{"SHOGI", 5, 171158},
	{"COURSEY", 7, 171159},
	{"FRANKED", 7, 171160},
	{"PROTE", 5, 171161},
	{"ELLUM", 5, 171162},
	{"MOSTLYCLEAN", 11, 171163},
	{"FLOOBLE", 7, 171164},
	{"BACTERIOPHAGES", 14, 171165},
	{"PLANUS", 6, 171166},
	{"GEIER", 5, 171167},
	{"FURI", 4, 171168},
	{"DEFERENS", 8, 171169},
	{"BOTHNER", 7, 171170},
	{"WHITEFLY", 8, 171171},
	{"GORDONSVILLE", 12, 171172},
	{"GOURGEOUS", 9, 171173},
	{"GILMANTON", 9, 171174},
	{"TEUFEL", 6, 171175},
	{"BSMT", 4, 171176},
	{"PENTACHLOROPHENOL", 17, 171177},
	{"TRAILORS", 8, 171178},
	{"POLICYMAKER", 11, 171179},
	{"BORROMEO", 8, 171180},
	{"IRONDEQUOIT", 11, 171181},
	{"TOCHNOG", 7, 171182},
	{"SENSORINEURAL", 13, 171183},
	{"MEDALLISTS", 10, 171184},
	{"CRUCIFORM", 9, 171185},
	{"GESTED", 6, 171186},
	{"YNYR", 4, 171187},
	{"YATQ", 4, 171188},
	{"WOCY", 4, 171189},
	{"UCDE", 4, 171190},
	{"TBOC", 4, 171191},
	{"SPDI", 4, 171192},
	{"SFCH", 4, 171193},
	{"SCUW", 4, 171194},
	{"RZAD", 4, 171195},
	{"RTRS", 4, 171196},
	{"RTAZ", 4, 171197},
	{"ROTB", 4, 171198},
	{"RBPO", 4, 171199},
	{"LWAD", 4, 171200},
	{"LHOD", 4, 171201},
	{"IVIV", 4, 171202},
	{"HPOC", 4, 171203},
	{"GZHE", 4, 171204},
	{"ERVT", 4, 171205},
	{"DIRG", 4, 171206},
	{"BECF", 4, 171207},
	{"TRNAS", 5, 171208},
	{"BERTOLT", 7, 171209},
	{"ERALLY", 6, 171210},
	{"UYGHUR", 6, 171211},
	{"TEASPOONFUL", 11, 171212},
	{"WARPATH", 7, 171213},
	{"FGL", 3, 171214},
	{"HOOCHIE", 7, 171215},
	{"HERBIVOROUS", 11, 171216},
	{"CIENTOS", 7, 171217},
	{"OPCH", 4, 171218},
	{"GREATBUYUSA", 11, 171219},
	{"WESTELL", 7, 171220},
	{"RMU", 3, 171221},
	{"COURNOT", 7, 171222},
	{"KOKORO", 6, 171223},
	{"FEUERSTEIN", 10, 171224},
	{"DEXA", 4, 171225},
	{"KAMPUNG", 7, 171226},
	{"BLADENSBURG", 11, 171227},
	{"ELETTRICO", 9, 171228},
	{"MACUSER", 7, 171229},
	{"BOTSFORD", 8, 171230},
	{"AREAGUIDES", 10, 171231},
	{"DEXEDRINE", 9, 171232},
	{"RAMBLED", 7, 171233},
	{"CDRTOOLS", 8, 171234},
	{"DOENLOAD", 8, 171235},
	{"GUERO", 5, 171236},
	{"EJABBERD", 8, 171237},
	{"CLINGER", 7, 171238},
	{"AUTOCAR", 7, 171239},
	{"DHARAMSALA", 10, 171240},
	{"ADENO", 5, 171241},
	{"UKRAINA", 7, 171242},
	{"BERTIN", 6, 171243},
	{"BASEBOARDS", 10, 171244},
	{"MONTA", 5, 171245},
	{"GLADESVILLE", 11, 171246},
	{"KONGSBERG", 9, 171247},
	{"GRADIENTE", 9, 171248},
	{"AKUMA", 5, 171249},
	{"SCREENPRINTED", 13, 171250},
	{"BIGGERS", 7, 171251},
	{"FCIC", 4, 171252},
	{"ULTRABAY", 8, 171253},
	{"JAPANIES", 8, 171254},
	{"BYELORUSSIA", 11, 171255},
	{"KNEADED", 7, 171256},
	{"HERPA", 5, 171257},
	{"HALLECK", 7, 171258},
	{"GREENSPUN", 9, 171259},
	{"MICROCASSETTE", 13, 171260},
	{"HOTSWAP", 7, 171261},
	{"GOOP", 4, 171262},
	{"BLUEROOM", 8, 171263},
	{"WAYBILL", 7, 171264},
	{"RGU", 3, 171265},
	{"IRAM", 4, 171266},
	{"IRREVERSIBILITY", 15, 171267},
	{"GROVENET", 8, 171268},
	{"SEMIPRECIOUS", 12, 171269},
	{"MAHNOMEN", 8, 171270},
	{"CESKA", 5, 171271},
	{"GULU", 4, 171272},
	{"PRAYERFULLY", 11, 171273},
	{"OXYMORONS", 9, 171274},
	{"SPIC", 4, 171275},
	{"SECANT", 6, 171276},
	{"PROPHESIES", 10, 171277},
	{"SINOPE", 6, 171278},
	{"CASEBACK", 8, 171279},
	{"ZNIK", 4, 171280},
	{"ZEFU", 4, 171281},
	{"YTEG", 4, 171282},
	{"YDTO", 4, 171283},
	{"YBAH", 4, 171284},
	{"XTVE", 4, 171285},
	{"XTHU", 4, 171286},
	{"UTYJ", 4, 171287},
	{"UODI", 4, 171288},
	{"ULZA", 4, 171289},
	{"UHOM", 4, 171290},
	{"SCGO", 4, 171291},
	{"RVII", 4, 171292},
	{"RUEU", 4, 171293},
	{"RSDY", 4, 171294},
	{"OCOG", 4, 171295},
	{"NGCM", 4, 171296},
	{"MMSS", 4, 171297},
	{"IPBI", 4, 171298},
	{"INDZ", 4, 171299},
	{"HUGT", 4, 171300},
	{"HFUS", 4, 171301},
	{"FEIC", 4, 171302},
	{"EKML", 4, 171303},
	{"EGJE", 4, 171304},
	{"EDIY", 4, 171305},
	{"DURF", 4, 171306},
	{"DRPR", 4, 171307},
	{"DKOD", 4, 171308},
	{"BYBP", 4, 171309},
	{"BIVINS", 6, 171310},
	{"SOCIODEMOGRAPHIC", 16, 171311},
	{"FERTILISED", 10, 171312},
	{"WYCK", 4, 171313},
	{"BASHA", 5, 171314},
	{"CONTAMINATES", 12, 171315},
	{"EMOTICONES", 10, 171316},
	{"PARTNERVERMITTLUNG", 18, 171317},
	{"ODENTON", 7, 171318},
	{"BISLAMA", 7, 171319},
	{"LUCLIN", 6, 171320},
	{"SHINOBU", 7, 171321},
	{"DEFUSED", 7, 171322},
	{"DIATRIBES", 9, 171323},
	{"MORPHEMES", 9, 171324},
	{"CHARMAN", 7, 171325},
	{"UVSC", 4, 171326},
	{"THESITE", 7, 171327},
	{"BAMBU", 5, 171328},
	{"WETCANVAS", 9, 171329},
	{"GALEA", 5, 171330},
	{"CRABBING", 8, 171331},
	{"EXUM", 4, 171332},
	{"MARGULIS", 8, 171333},
	{"DEVELO", 6, 171334},
	{"ACCURIST", 8, 171335},
	{"FIMMEL", 6, 171336},
	{"LECTRA", 6, 171337},
	{"SWISSBIT", 8, 171338},
	{"ROSSE", 5, 171339},
	{"MASUR", 5, 171340},
	{"ANTIVIRALS", 10, 171341},
	{"ROUNTREE", 8, 171342},
	{"PINSKI", 6, 171343},
	{"KNBC", 4, 171344},
	{"GARGLE", 6, 171345},
	{"EMANATIONS", 10, 171346},
	{"KINGBIRD", 8, 171347},
	{"VEILING", 7, 171348},
	{"FRONTBASE", 9, 171349},
	{"SQUANDERING", 11, 171350},
	{"ALTIMETERS", 10, 171351},
	{"WAHRHEIT", 8, 171352},
	{"REGALOS", 7, 171353},
	{"YAROSLAVL", 9, 171354},
	{"COUNTERCLAIMS", 13, 171355},
	{"BLOJSOM", 7, 171356},
	{"SULEKHA", 7, 171357},
	{"HORNBILL", 8, 171358},
	{"RECRUTEMENT", 11, 171359},
	{"EAECIENT", 8, 171360},
	{"PLUMA", 5, 171361},
	{"RCK", 3, 171362},
	{"QUARTUS", 7, 171363},
	{"MICHOACAN", 9, 171364},
	{"QUIESCENCE", 10, 171365},
	{"CONCEPTUALISATION", 17, 171366},
	{"FOODSERVICES", 12, 171367},
	{"ENDTAB", 6, 171368},
	{"PENALIZING", 10, 171369},
	{"YUDHOYONO", 9, 171370},
	{"WIKIDATA", 8, 171371},
	{"DOXAZOSIN", 9, 171372},
	{"BERTIL", 6, 171373},
	{"REORGANISED", 11, 171374},
	{"MIHAIL", 6, 171375},
	{"GILET", 5, 171376},
	{"SANLAM", 6, 171377},
	{"KIDDIN", 6, 171378},
	{"MADFISH", 7, 171379},
	{"AUTOPIA", 7, 171380},
	{"SUME", 4, 171381},
	{"RESOLVERS", 9, 171382},
	{"TSCHECHISCHE", 12, 171383},
	{"SYSINFO", 7, 171384},
	{"GFM", 3, 171385},
	{"HOQUIAM", 7, 171386},
	{"WIDOWHOOD", 9, 171387},
	{"YJUI", 4, 171388},
	{"XWAR", 4, 171389},
	{"WGAN", 4, 171390},
	{"WATD", 4, 171391},
	{"UUAN", 4, 171392},
	{"UACR", 4, 171393},
	{"TSUV", 4, 171394},
	{"PUTK", 4, 171395},
	{"PLYJ", 4, 171396},
	{"NIXV", 4, 171397},
	{"MUPR", 4, 171398},
	{"MUKO", 4, 171399},
	{"MMUM", 4, 171400},
	{"MFEM", 4, 171401},
	{"LLTV", 4, 171402},
	{"LIEX", 4, 171403},
	{"LBYU", 4, 171404},
	{"KZON", 4, 171405},
	{"KWHP", 4, 171406},
	{"KMHT", 4, 171407},
	{"JCON", 4, 171408},
	{"HRAZ", 4, 171409},
	{"GOPF", 4, 171410},
	{"FSPY", 4, 171411},
	{"EGHZ", 4, 171412},
	{"DMUF", 4, 171413},
	{"CCWO", 4, 171414},
	{"BUGE", 4, 171415},
	{"HORNCASTLE", 10, 171416},
	{"INOSINE", 7, 171417},
	{"TURBOGEARS", 10, 171418},
	{"MIRABEAU", 8, 171419},
	{"WEBID", 5, 171420},
	{"FODD", 4, 171421},
	{"CDNX", 4, 171422},
	{"OICTURES", 8, 171423},
	{"BURRUS", 6, 171424},
	{"SWARTHY", 7, 171425},
	{"TAUBE", 5, 171426},
	{"CONSUMP", 7, 171427},
	{"CHRYSOTILE", 10, 171428},
	{"MEACHER", 7, 171429},
	{"IMOTI", 5, 171430},
	{"ABYSSINIA", 9, 171431},
	{"WSXGA", 5, 171432},
	{"STRACZYNSKI", 11, 171433},
	{"METROACTIVE", 11, 171434},
	{"PALIMPSEST", 10, 171435},
	{"BOROWSKI", 8, 171436},
	{"FANGLED", 7, 171437},
	{"BOIVIN", 6, 171438},
	{"XGP", 3, 171439},
	{"EUROLITE", 8, 171440},
	{"SELECCION", 9, 171441},
	{"WIGGLED", 7, 171442},
	{"CLINI", 5, 171443},
	{"CHLORDIAZEPOXIDE", 16, 171444},
	{"ARBITERS", 8, 171445},
	{"REGGIANO", 8, 171446},
	{"SUPERLATTICES", 13, 171447},
	{"BUILDOUT", 8, 171448},
	{"CHAYA", 5, 171449},
	{"CASTALIA", 8, 171450},
	{"REDR", 4, 171451},
	{"MASAMUNE", 8, 171452},
	{"MINNIS", 6, 171453},
	{"ISOSCELES", 9, 171454},
	{"DELICA", 6, 171455},
	{"POPULAIRES", 10, 171456},
	{"MAZON", 5, 171457},
	{"POETICALLY", 10, 171458},
	{"WATERSTONE", 10, 171459},
	{"FREDERIQUE", 10, 171460},
	{"SPARKLER", 8, 171461},
	{"POTENTILLA", 10, 171462},
	{"KALEY", 5, 171463},
	{"VIROLOGICAL", 11, 171464},
	{"GOPI", 4, 171465},
	{"ATMORE", 6, 171466},
	{"GEOFFROY", 8, 171467},
	{"ROOKE", 5, 171468},
	{"OLSZEWSKI", 9, 171469},
	{"BYNG", 4, 171470},
	{"PERSISTANCE", 11, 171471},
	{"ZPAS", 4, 171472},
	{"ZKOS", 4, 171473},
	{"YIMH", 4, 171474},
	{"WSUL", 4, 171475},
	{"UYGA", 4, 171476},
	{"UORM", 4, 171477},
	{"UCYT", 4, 171478},
	{"TPIM", 4, 171479},
	{"SYUS", 4, 171480},
	{"ROFX", 4, 171481},
	{"OVWO", 4, 171482},
	{"NMUE", 4, 171483},
	{"NKHM", 4, 171484},
	{"LMGE", 4, 171485},
	{"KVAC", 4, 171486},
	{"HPUM", 4, 171487},
	{"HHUL", 4, 171488},
	{"GLAA", 4, 171489},
	{"FIXP", 4, 171490},
	{"EXJU", 4, 171491},
	{"ECYI", 4, 171492},
	{"DEZM", 4, 171493},
	{"BMWI", 4, 171494},
	{"BFIE", 4, 171495},
	{"AHJU", 4, 171496},
	{"AFDE", 4, 171497},
	{"DURANCE", 7, 171498},
	{"GABRIELLI", 9, 171499},
	{"PROLIFE", 7, 171500},
	{"FARNESE", 7, 171501},
	{"LANDFILLING", 11, 171502},
	{"RIPOSTE", 7, 171503},
	{"POPING", 6, 171504},
	{"PHOTOSPHERE", 11, 171505},
	{"AMPARO", 6, 171506},
	{"ORGASIMS", 8, 171507},
	{"MADRONE", 7, 171508},
	{"AMATER", 6, 171509},
	{"PAYNES", 6, 171510},
	{"MINCER", 6, 171511},
	{"EREFERENCE", 10, 171512},
	{"MOLEHILL", 8, 171513},
	{"VANEISA", 7, 171514},
	{"ZZYY", 4, 171515},
	{"KUNO", 4, 171516},
	{"ORFEO", 5, 171517},
	{"COROT", 5, 171518},
	{"TAEKWON", 7, 171519},
	{"QTRS", 4, 171520},
	{"CHID", 4, 171521},
	{"KOSTENLOSES", 11, 171522},
	{"VECTORIAL", 9, 171523},
	{"ESTING", 6, 171524},
	{"RALLISPORT", 10, 171525},
	{"COMPAS", 6, 171526},
	{"LONNY", 5, 171527},
	{"BRASELTON", 9, 171528},
	{"MENACES", 7, 171529},
	{"PIRACETAM", 9, 171530},
	{"HOTMAI", 6, 171531},
	{"DIRETTA", 7, 171532},
	{"SECRETIN", 8, 171533},
	{"SOUSSE", 6, 171534},
	{"OLIGOPEPTIDES", 13, 171535},
	{"DESIR", 5, 171536},
	{"NJCAA", 5, 171537},
	{"MCMILLIN", 8, 171538},
	{"AMBLING", 7, 171539},
	{"PLWHA", 5, 171540},
	{"KENDELL", 7, 171541},
	{"SHINNING", 8, 171542},
	{"NEUROBEHAVIORAL", 15, 171543},
	{"HOBOS", 5, 171544},
	{"POSTEROUTLINE", 13, 171545},
	{"CLY", 3, 171546},
	{"BIALETTI", 8, 171547},
	{"WEBHOSTS", 8, 171548},
	{"POLLOK", 6, 171549},
	{"SMIRKY", 6, 171550},
	{"LOUGHRAN", 8, 171551},
	{"SOCIOLINGUISTIC", 15, 171552},
	{"LYSOL", 5, 171553},
	{"NASDA", 5, 171554},
	{"WYRICK", 6, 171555},
	{"PATION", 6, 171556},
	{"SITESEEING", 10, 171557},
	{"EXTRAVERSION", 12, 171558},
	{"SELFHTML", 8, 171559},
	{"PERILOUSLY", 10, 171560},
	{"DSYSTEMCFGFILE", 14, 171561},
	{"NUMBED", 6, 171562},
	{"REVAL", 5, 171563},
	{"IMAGINAL", 8, 171564},
	{"ELECTROTHERAPY", 14, 171565},
	{"KMDL", 4, 171566},
	{"YJAG", 4, 171567},
	{"XLOV", 4, 171568},
	{"VETD", 4, 171569},
	{"USUT", 4, 171570},
	{"SHGL", 4, 171571},
	{"RTMR", 4, 171572},
	{"RPSK", 4, 171573},
	{"ROUH", 4, 171574},
	{"RIYE", 4, 171575},
	{"RIGD", 4, 171576},
	{"NDPW", 4, 171577},
	{"MUGE", 4, 171578},
	{"LIUA", 4, 171579},
	{"LADG", 4, 171580},
	{"KYSL", 4, 171581},
	{"HNGL", 4, 171582},
	{"DKNU", 4, 171583},
	{"CYSR", 4, 171584},
	{"AXVA", 4, 171585},
	{"AMOZ", 4, 171586},
	{"AMMD", 4, 171587},
	{"AEUP", 4, 171588},
	{"AEKJ", 4, 171589},
	{"ABBT", 4, 171590},
	{"BAYOSPHERE", 10, 171591},
	{"CREMORNE", 8, 171592},
	{"CHEYNEY", 7, 171593},
	{"MUINE", 5, 171594},
	{"LINCHPIN", 8, 171595},
	{"CRISPUS", 7, 171596},
	{"PHONAK", 6, 171597},
	{"RVM", 3, 171598},
	{"ENMU", 4, 171599},
	{"IPVSADM", 7, 171600},
	{"PIONEX", 6, 171601},
	{"BREATHITT", 9, 171602},
	{"HUFFING", 7, 171603},
	{"ACTEURS", 7, 171604},
	{"REGEL", 5, 171605},
	{"PENNIE", 6, 171606},
	{"MESSORE", 7, 171607},
	{"FAVORITS", 8, 171608},
	{"CHANNELIZATION", 14, 171609},
	{"UNCA", 4, 171610},
	{"DOSIMETERS", 10, 171611},
	{"VACCINATING", 11, 171612},
	{"ANIVERSARY", 10, 171613},
	{"RAFIQ", 5, 171614},
	{"ZITHER", 6, 171615},
	{"OBVIOUSNESS", 11, 171616},
	{"PYROXENE", 8, 171617},
	{"TYPER", 5, 171618},
	{"BLACKWYRM", 9, 171619},
	{"SETSOCKOPT", 10, 171620},
	{"BATHES", 6, 171621},
	{"CERNY", 5, 171622},
	{"MANGAL", 6, 171623},
	{"ARCHIES", 7, 171624},
	{"ENTEROTOXIN", 11, 171625},
	{"DINSDALE", 8, 171626},
	{"PORTHOLES", 9, 171627},
	{"IPCONFIG", 8, 171628},
	{"THEYLL", 6, 171629},
	{"SMARTASS", 8, 171630},
	{"DROVER", 6, 171631},
	{"MENTALIST", 9, 171632},
	{"COLONISED", 9, 171633},
	{"DEERHOUND", 9, 171634},
	{"TESSAR", 6, 171635},
	{"ORIEN", 5, 171636},
	{"PRECUT", 6, 171637},
	{"BAREN", 5, 171638},
	{"PINGO", 5, 171639},
	{"BELEM", 5, 171640},
	{"RIZZI", 5, 171641},
	{"FBIS", 4, 171642},
	{"UNICYCLES", 9, 171643},
	{"SERPICO", 7, 171644},
	{"LUKER", 5, 171645},
	{"CHUMBO", 6, 171646},
	{"DOGMATISM", 9, 171647},
	{"CLONTECH", 8, 171648},
	{"ABZORB", 6, 171649},
	{"KANBAN", 6, 171650},
	{"IMMIGRATING", 11, 171651},
	{"PHOTOSHOOTS", 11, 171652},
	{"MODU", 4, 171653},
	{"LAMARR", 6, 171654},
	{"ANGRIER", 7, 171655},
	{"CYPERACEAE", 10, 171656},
	{"RUSA", 4, 171657},
	{"KOSKI", 5, 171658},
	{"MECO", 4, 171659},
	{"DEIGHTON", 8, 171660},
	{"MANEUVERABLE", 12, 171661},
	{"ZOBACZ", 6, 171662},
	{"POSAY", 5, 171663},
	{"PARASITOIDS", 11, 171664},
	{"FREUDENBERG", 11, 171665},
	{"ELKA", 4, 171666},
	{"MISAPPLIED", 10, 171667},
	{"NEUROSCIENTISTS", 15, 171668},
	{"ZURU", 4, 171669},
	{"YDYS", 4, 171670},
	{"XSCR", 4, 171671},
	{"XADE", 4, 171672},
	{"WMEO", 4, 171673},
	{"TDGA", 4, 171674},
	{"SKDA", 4, 171675},
	{"SKBO", 4, 171676},
	{"PMPE", 4, 171677},
	{"OZEF", 4, 171678},
	{"NBHU", 4, 171679},
	{"MOGH", 4, 171680},
	{"MDYN", 4, 171681},
	{"LKAY", 4, 171682},
	{"IXAM", 4, 171683},
	{"GKEI", 4, 171684},
	{"FHOG", 4, 171685},
	{"EKTU", 4, 171686},
	{"ECEU", 4, 171687},
	{"DDPL", 4, 171688},
	{"CYKI", 4, 171689},
	{"GRADIUS", 7, 171690},
	{"BHAJAN", 6, 171691},
	{"ROSTRAL", 7, 171692},
	{"COMPATIBLITY", 12, 171693},
	{"CHASSEUR", 8, 171694},
	{"RISD", 4, 171695},
	{"ANGELICO", 8, 171696},
	{"NUDEGIRLS", 9, 171697},
	{"GRUDGING", 8, 171698},
	{"GIJON", 5, 171699},
	{"ORLEAN", 6, 171700},
	{"KRAI", 4, 171701},
	{"KEYNSHAM", 8, 171702},
	{"GERONTOLOGISTS", 14, 171703},
	{"RECIPROCALLY", 12, 171704},
	{"PARAPHRASES", 11, 171705},
	{"INHERITABLE", 11, 171706},
	{"FOOTBALLING", 11, 171707},
	{"CUTENEWS", 8, 171708},
	{"WSRC", 4, 171709},
	{"SUNDA", 5, 171710},
	{"OPTIND", 6, 171711},
	{"LADUE", 5, 171712},
	{"NBONDS", 6, 171713},
	{"AUTHORIAL", 9, 171714},
	{"JVIEWS", 6, 171715},
	{"CDNOW", 5, 171716},
	{"APPNAME", 7, 171717},
	{"OFFWORLD", 8, 171718},
	{"GERIATR", 7, 171719},
	{"BENCHED", 7, 171720},
	{"SPACIOUSNESS", 12, 171721},
	{"FREEDIVING", 10, 171722},
	{"QUANITY", 7, 171723},
	{"DARC", 4, 171724},
	{"AXSM", 4, 171725},
	{"RASK", 4, 171726},
	{"POLIBLOG", 8, 171727},
	{"EGGHEAD", 7, 171728},
	{"HERMOSILLO", 10, 171729},
	{"DUCING", 6, 171730},
	{"LYC", 3, 171731},
	{"ESTEC", 5, 171732},
	{"DAOUD", 5, 171733},
	{"TOPNOTCH", 8, 171734},
	{"MASTERMINDED", 12, 171735},
	{"EFFUSIONS", 9, 171736},
	{"MEMCMP", 6, 171737},
	{"PRWQYPOYRGOS", 12, 171738},
	{"OMNIVOROUS", 10, 171739},
	{"SNARED", 6, 171740},
	{"BROGUE", 6, 171741},
	{"ALLEMAN", 7, 171742},
	{"KUMARATUNGA", 11, 171743},
	{"DIALTONE", 8, 171744},
	{"IPEC", 4, 171745},
	{"LIBPATH", 7, 171746},
	{"BENDA", 5, 171747},
	{"JUSTI", 5, 171748},
	{"ROUNDY", 6, 171749},
	{"PASSETH", 7, 171750},
	{"GRAVIES", 7, 171751},
	{"PANTHERA", 8, 171752},
	{"NICKE", 5, 171753},
	{"GRUNDFOS", 8, 171754},
	{"GRET", 4, 171755},
	{"SMUGLY", 6, 171756},
	{"TRAINZ", 6, 171757},
	{"ZIEGFELD", 8, 171758},
	{"INTRAVENTRICULAR", 16, 171759},
	{"TOLLY", 5, 171760},
	{"FPB", 3, 171761},
	{"FYND", 4, 171762},
	{"VALPO", 5, 171763},
	{"MULHERES", 8, 171764},
	{"ATTENUATING", 11, 171765},
	{"MAXSIZE", 7, 171766},
	{"ARGUEMENTS", 10, 171767},
	{"BANKSHARES", 10, 171768},
	{"SENNETT", 7, 171769},
	{"REACHER", 7, 171770},
	{"DEFCLASS", 8, 171771},
	{"YDDO", 4, 171772},
	{"XIMO", 4, 171773},
	{"WESK", 4, 171774},
	{"UMGU", 4, 171775},
	{"THUF", 4, 171776},
	{"SMPF", 4, 171777},
	{"SKGA", 4, 171778},
	{"OMNY", 4, 171779},
	{"NUML", 4, 171780},
	{"MPIG", 4, 171781},
	{"LSPY", 4, 171782},
	{"JRBO", 4, 171783},
	{"IPVE", 4, 171784},
	{"HEDZ", 4, 171785},
	{"EZCH", 4, 171786},
	{"ESDF", 4, 171787},
	{"EILU", 4, 171788},
	{"EDRF", 4, 171789},
	{"DKOV", 4, 171790},
	{"DEHR", 4, 171791},
	{"BFAN", 4, 171792},
	{"AQBE", 4, 171793},
	{"SUBFLOOR", 8, 171794},
	{"NUCLEOPHILIC", 12, 171795},
	{"PLAXO", 5, 171796},
	{"TREKNATURE", 10, 171797},
	{"POSTMODERNITY", 13, 171798},
	{"DELPHOS", 7, 171799},
	{"BURPING", 7, 171800},
	{"SQUEAKED", 8, 171801},
	{"SPERMICIDE", 10, 171802},
	{"MULLANE", 7, 171803},
	{"DOWNHILLING", 11, 171804},
	{"QUEBECERS", 9, 171805},
	{"COMMENTPLUGIN", 13, 171806},
	{"ACTINS", 6, 171807},
	{"MEDLIN", 6, 171808},
	{"SPECTRALLY", 10, 171809},
	{"GOOLSBY", 7, 171810},
	{"ALKANE", 6, 171811},
	{"OVERREACHING", 12, 171812},
	{"IDDO", 4, 171813},
	{"BESSEY", 6, 171814},
	{"SQLRELAY", 8, 171815},
	{"KOURI", 5, 171816},
	{"PUFFINESS", 9, 171817},
	{"WOHNUNGEN", 9, 171818},
	{"ADRC", 4, 171819},
	{"BEEFCAKE", 8, 171820},
	{"SEANCE", 6, 171821},
	{"BEARDSTOWN", 10, 171822},
	{"MELITA", 6, 171823},
	{"SYDOW", 5, 171824},
	{"SHIAWASSEE", 10, 171825},
	{"STILLED", 7, 171826},
	{"QUAT", 4, 171827},
	{"METALLO", 7, 171828},
	{"FLOWERPOT", 9, 171829},
	{"XKR", 3, 171830},
	{"SCHNYDER", 8, 171831},
	{"PENTAZOCINE", 11, 171832},
	{"BEKIJKEN", 8, 171833},
	{"FINNERAN", 8, 171834},
	{"TENEX", 5, 171835},
	{"IPODOBSERVER", 12, 171836},
	{"ACTIF", 5, 171837},
	{"MYERSON", 7, 171838},
	{"RUGBYHEAVEN", 11, 171839},
	{"RICKERT", 7, 171840},
	{"ASPHALTIC", 9, 171841},
	{"ALAYHI", 6, 171842},
	{"TUNITIES", 8, 171843},
	{"VIETNAMNET", 10, 171844},
	{"AFBEELDING", 10, 171845},
	{"MOKSHA", 6, 171846},
	{"GUERNICA", 8, 171847},
	{"SORBENTS", 8, 171848},
	{"HALEIGH", 7, 171849},
	{"ELTIMA", 6, 171850},
	{"DEBKAFILE", 9, 171851},
	{"STRATHROY", 9, 171852},
	{"FFORDE", 6, 171853},
	{"INSTITUTIONEN", 13, 171854},
	{"CHEEKBONES", 10, 171855},
	{"HARMONISING", 11, 171856},
	{"HAPEVILLE", 9, 171857},
	{"PRESALES", 8, 171858},
	{"LIBGDK", 6, 171859},
	{"REFRAME", 7, 171860},
	{"SECURITIZED", 11, 171861},
	{"LORENTZIAN", 10, 171862},
	{"LIFEFORCE", 9, 171863},
	{"KAHANE", 6, 171864},
	{"YNWO", 4, 171865},
	{"XMAI", 4, 171866},
	{"XGET", 4, 171867},
	{"WWIR", 4, 171868},
	{"VSLI", 4, 171869},
	{"URZE", 4, 171870},
	{"RIRV", 4, 171871},
	{"PVOI", 4, 171872},
	{"OPIZ", 4, 171873},
	{"NEKL", 4, 171874},
	{"KAMC", 4, 171875},
	{"JADH", 4, 171876},
	{"IXRI", 4, 171877},
	{"IXCR", 4, 171878},
	{"ISPB", 4, 171879},
	{"IKFO", 4, 171880},
	{"FUPG", 4, 171881},
	{"FFRS", 4, 171882},
	{"ERLC", 4, 171883},
	{"BOSB", 4, 171884},
	{"BBUI", 4, 171885},
	{"GORES", 5, 171886},
	{"FIZZLED", 7, 171887},
	{"DEPENDANCIES", 12, 171888},
	{"DEITEL", 6, 171889},
	{"BYGONES", 7, 171890},
	{"RYDYM", 5, 171891},
	{"SEMOLINA", 8, 171892},
	{"MCTAGGART", 9, 171893},
	{"ASSEZ", 5, 171894},
	{"MENTRE", 6, 171895},
	{"JHEP", 4, 171896},
	{"MEMEPOOL", 8, 171897},
	{"MANAGEMEN", 9, 171898},
	{"AHLBERG", 7, 171899},
	{"DTAP", 4, 171900},
	{"FINITENESS", 10, 171901},
	{"OLEDB", 5, 171902},
	{"NCCP", 4, 171903},
	{"BYATT", 5, 171904},
	{"TRANSBORDER", 11, 171905},
	{"WEBISTE", 7, 171906},
	{"CONTENTEDLY", 11, 171907},
	{"PERFUMER", 8, 171908},
	{"FESTUCA", 7, 171909},
	{"KINEPOLIS", 9, 171910},
	{"MVNO", 4, 171911},
	{"INUKTITUT", 9, 171912},
	{"INSTITUTIONALIZING", 18, 171913},
	{"MISREPRESENTS", 13, 171914},
	{"INCOGNITA", 9, 171915},
	{"ROUGHEST", 8, 171916},
	{"LGP", 3, 171917},
	{"GOYER", 5, 171918},
	{"LOVIE", 5, 171919},
	{"HEGELIAN", 8, 171920},
	{"STEPSONS", 8, 171921},
	{"BRUMLEY", 7, 171922},
	{"WORLDCON", 8, 171923},
	{"EMULSIFIERS", 11, 171924},
	{"RMAX", 4, 171925},
	{"RIFFLES", 7, 171926},
	{"ENTREATIES", 10, 171927},
	{"VIRII", 5, 171928},
	{"ALESSIA", 7, 171929},
	{"GDNET", 5, 171930},
	{"RIDICULING", 10, 171931},
	{"THEMODERATEVOICE", 16, 171932},
	{"SQUARESPACE", 11, 171933},
	{"DAYLONG", 7, 171934},
	{"DAMIANI", 7, 171935},
	{"MOGA", 4, 171936},
	{"YANAGISAWA", 10, 171937},
	{"GELLERT", 7, 171938},
	{"RECE", 4, 171939},
	{"PARADIGMA", 9, 171940},
	{"ALTERNATIONS", 12, 171941},
	{"GOLDDIGGER", 10, 171942},
	{"SHUNDE", 6, 171943},
	{"RINSHO", 6, 171944},
	{"HOROLOGIUM", 10, 171945},
	{"PENITENCE", 9, 171946},
	{"CONIDIA", 7, 171947},
	{"BWD", 3, 171948},
	{"PEEPER", 6, 171949},
	{"PHILOSOPHIZING", 14, 171950},
	{"COREQ", 5, 171951},
	{"HOLBERG", 7, 171952},
	{"ZECL", 4, 171953},
	{"YNDS", 4, 171954},
	{"XROA", 4, 171955},
	{"VMON", 4, 171956},
	{"VADD", 4, 171957},
	{"UKUA", 4, 171958},
	{"UJAI", 4, 171959},
	{"UGYO", 4, 171960},
	{"TLAX", 4, 171961},
	{"SHUW", 4, 171962},
	{"RMOZ", 4, 171963},
	{"RBSU", 4, 171964},
	{"QUOK", 4, 171965},
	{"PTUM", 4, 171966},
	{"NTUG", 4, 171967},
	{"MOSG", 4, 171968},
	{"IHYD", 4, 171969},
	{"HUPC", 4, 171970},
	{"EZOL", 4, 171971},
	{"EPOB", 4, 171972},
	{"EDPT", 4, 171973},
	{"DNAY", 4, 171974},
	{"DBIE", 4, 171975},
	{"ACYJ", 4, 171976},
	{"SUICIDEGIRL", 11, 171977},
	{"DISCOURS", 8, 171978},
	{"OKUMURA", 7, 171979},
	{"BARO", 4, 171980},
	{"AVAILS", 6, 171981},
	{"ASSASIN", 7, 171982},
	{"SUEDED", 6, 171983},
	{"HENKES", 6, 171984},
	{"FENRIS", 6, 171985},
	{"SPEICHERN", 9, 171986},
	{"LOUCKS", 6, 171987},
	{"MEDITATOR", 9, 171988},
	{"ALLGEMEINES", 11, 171989},
	{"CUISIPRO", 8, 171990},
	{"KOSMO", 5, 171991},
	{"SMARTSUITE", 10, 171992},
	{"DIRETTAMENTE", 12, 171993},
	{"VIVIANA", 7, 171994},
	{"VELVETS", 7, 171995},
	{"SECURITYMETRICS", 15, 171996},
	{"SPALLATION", 10, 171997},
	{"SKINBASE", 8, 171998},
	{"SCHEHERAZADE", 12, 171999},
	{"KITEN", 5, 172000},
	{"KIOSLAVE", 8, 172001},
	{"SAXES", 5, 172002},
	{"CHACHA", 6, 172003},
	{"CONCORDAT", 9, 172004},
	{"STRTOLOWER", 10, 172005},
	{"BATTERER", 8, 172006},
	{"ESCALON", 7, 172007},
	{"COMPLETER", 9, 172008},
	{"BODYART", 7, 172009},
	{"WSRF", 4, 172010},
	{"ALLTIME", 7, 172011},
	{"DESIREABLE", 10, 172012},
	{"STREIT", 6, 172013},
	{"BELLIN", 6, 172014},
	{"CROWFOOT", 8, 172015},
	{"RUMIKO", 6, 172016},
	{"SOURCEBIZ", 9, 172017},
	{"SMEAL", 5, 172018},
	{"RECEVOIR", 8, 172019},
	{"XBOARD", 6, 172020},
	{"TACTFULLY", 9, 172021},
	{"MESSMER", 7, 172022},
	{"HOWTOFORGE", 10, 172023},
	{"PACON", 5, 172024},
	{"NEILB", 5, 172025},
	{"LASHLEY", 7, 172026},
	{"ARNON", 5, 172027},
	{"MISTRES", 7, 172028},
	{"VEECO", 5, 172029},
	{"RAUSCHENBERG", 12, 172030},
	{"DEFROSTING", 10, 172031},
	{"LUD", 3, 172032},
	{"SIDDHA", 6, 172033},
	{"SCPS", 4, 172034},
	{"TVERSKY", 7, 172035},
	{"JONESES", 7, 172036},
	{"AUTOMNE", 7, 172037},
	{"TRILINGUAL", 10, 172038},
	{"REPROACHED", 10, 172039},
	{"MANIS", 5, 172040},
	{"ANESTHETISTS", 12, 172041},
	{"ACIDIFIED", 9, 172042},
	{"SPEAKE", 6, 172043},
	{"ENIGMAIL", 8, 172044},
	{"YAMANAKA", 8, 172045},
	{"ROUNDTREE", 9, 172046},
	{"HERUNTERLADEN", 13, 172047},
	{"GTGT", 4, 172048},
	{"HAWL", 4, 172049},
	{"GERICHT", 7, 172050},
	{"SOLNA", 5, 172051},
	{"BYSSHE", 6, 172052},
	{"PACIOTTI", 8, 172053},
	{"EXPERINCE", 9, 172054},
	{"YTHG", 4, 172055},
	{"YNJO", 4, 172056},
	{"XWAT", 4, 172057},
	{"XSEV", 4, 172058},
	{"WSAZ", 4, 172059},
	{"WISY", 4, 172060},
	{"WHYV", 4, 172061},
	{"USZO", 4, 172062},
	{"TOWM", 4, 172063},
	{"SYJO", 4, 172064},
	{"SAZU", 4, 172065},
	{"RSAJ", 4, 172066},
	{"RMRR", 4, 172067},
	{"PSMY", 4, 172068},
	{"OXVE", 4, 172069},
	{"OUJA", 4, 172070},
	{"OFKS", 4, 172071},
	{"OBUB", 4, 172072},
	{"NUCA", 4, 172073},
	{"LDJI", 4, 172074},
	{"LBOG", 4, 172075},
	{"LAKY", 4, 172076},
	{"HUGL", 4, 172077},
	{"HUBW", 4, 172078},
	{"GPAA", 4, 172079},
	{"EZUK", 4, 172080},
	{"EPGU", 4, 172081},
	{"EMBT", 4, 172082},
	{"DZHO", 4, 172083},
	{"DJAT", 4, 172084},
	{"DFUZ", 4, 172085},
	{"CKMD", 4, 172086},
	{"CDPI", 4, 172087},
	{"SALDANA", 7, 172088},
	{"BBLS", 4, 172089},
	{"TIMMER", 6, 172090},
	{"SUDHA", 5, 172091},
	{"NZERN", 5, 172092},
	{"PINGUS", 6, 172093},
	{"MASCARPONE", 10, 172094},
	{"NYSDEC", 6, 172095},
	{"COMAR", 5, 172096},
	{"MESOTHERAPY", 11, 172097},
	{"CTAP", 4, 172098},
	{"CONCERTATION", 12, 172099},
	{"FOCALLENGTH", 11, 172100},
	{"WOOPS", 5, 172101},
	{"RITU", 4, 172102},
	{"BORDE", 5, 172103},
	{"VACATURE", 8, 172104},
	{"MYCOLOGICAL", 11, 172105},
	{"HANDWASH", 8, 172106},
	{"DIARYRINGS", 10, 172107},
	{"FURTH", 5, 172108},
	{"EELGRASS", 8, 172109},
	{"RUNEBOUND", 9, 172110},
	{"HYPERSNAP", 9, 172111},
	{"SOLIDO", 6, 172112},
	{"MOVSI", 5, 172113},
	{"SLUSHER", 7, 172114},
	{"SCUP", 4, 172115},
	{"MOTET", 5, 172116},
	{"COMMISH", 7, 172117},
	{"ALLOGRAFTS", 10, 172118},
	{"CARROS", 6, 172119},
	{"ZFG", 3, 172120},
	{"YQY", 3, 172121},
	{"XZP", 3, 172122},
	{"XVK", 3, 172123},
	{"XUU", 3, 172124},
	{"XBJ", 3, 172125},
	{"VXY", 3, 172126},
	{"VJJ", 3, 172127},
	{"QPK", 3, 172128},
	{"KVX", 3, 172129},
	{"KFQ", 3, 172130},
	{"JZD", 3, 172131},
	{"GWZ", 3, 172132},
	{"FZX", 3, 172133},
	{"DQJ", 3, 172134},
	{"CZX", 3, 172135},
	{"CQX", 3, 172136},
	{"BZV", 3, 172137},
	{"SOUTHWIND", 9, 172138},
	{"CHARITYSHOP", 11, 172139},
	{"EDGEWISE", 8, 172140},
	{"MOTTOS", 6, 172141},
	{"KLINGELTONE", 11, 172142},
	{"PLUNGERS", 8, 172143},
	{"LANSFORD", 8, 172144},
	{"RACEHORSES", 10, 172145},
	{"AAFES", 5, 172146},
	{"WHEELSKINS", 10, 172147},
	{"MAVENS", 6, 172148},
	{"INDRE", 5, 172149},
	{"MORNINGGLORY", 12, 172150},
	{"KALEB", 5, 172151},
	{"AVEENO", 6, 172152},
	{"MUNNAR", 6, 172153},
	{"SAFETIES", 8, 172154},
	{"ANUARY", 6, 172155},
	{"SARNA", 5, 172156},
	{"FLORDIA", 7, 172157},
	{"LIVET", 5, 172158},
	{"SCANPAN", 7, 172159},
	{"NYNEX", 5, 172160},
	{"OUTFOXED", 8, 172161},
	{"CHAUVINIST", 10, 172162},
	{"HIGHSCORES", 10, 172163},
	{"ENGINS", 6, 172164},
	{"TAUTOU", 6, 172165},
	{"MUSICTALK", 9, 172166},
	{"SPNG", 4, 172167},
	{"SCHMIT", 6, 172168},
	{"RUSSEN", 6, 172169},
	{"INTRAWEST", 9, 172170},
	{"DELAURO", 7, 172171},
	{"DRUNKARDS", 9, 172172},
	{"SCJP", 4, 172173},
	{"ITALIANATE", 10, 172174},
	{"ZIPR", 4, 172175},
	{"YSUA", 4, 172176},
	{"XARR", 4, 172177},
	{"UNPM", 4, 172178},
	{"UDVA", 4, 172179},
	{"SCTR", 4, 172180},
	{"RAVD", 4, 172181},
	{"POUG", 4, 172182},
	{"PEVO", 4, 172183},
	{"OFMH", 4, 172184},
	{"MSGL", 4, 172185},
	{"KOKW", 4, 172186},
	{"IFTK", 4, 172187},
	{"DPEY", 4, 172188},
	{"CIDH", 4, 172189},
	{"BSOW", 4, 172190},
	{"AUNU", 4, 172191},
	{"ATQB", 4, 172192},
	{"AKYB", 4, 172193},
	{"ADSQ", 4, 172194},
	{"PEGBOARD", 8, 172195},
	{"STEUER", 6, 172196},
	{"LIBAPT", 6, 172197},
	{"NSTAR", 5, 172198},
	{"LOVEDAY", 7, 172199},
	{"AMOL", 4, 172200},
	{"MIMES", 5, 172201},
	{"AGATSTON", 8, 172202},
	{"THORTON", 7, 172203},
	{"MACMASTER", 9, 172204},
	{"NORMOTENSIVE", 12, 172205},
	{"GLCNAC", 6, 172206},
	{"DANTON", 6, 172207},
	{"GULLWING", 8, 172208},
	{"CLIOPATRIA", 10, 172209},
	{"LIFESTRIDE", 10, 172210},
	{"HELLGATE", 8, 172211},
	{"CHAZZ", 5, 172212},
	{"ELKHOUND", 8, 172213},
	{"NARRANDERA", 10, 172214},
	{"LUCIOUS", 7, 172215},
	{"RANIA", 5, 172216},
	{"WATERSON", 8, 172217},
	{"HURRIES", 7, 172218},
	{"AMALGAMATE", 10, 172219},
	{"BLUMER", 6, 172220},
	{"ASHTEAD", 7, 172221},
	{"FURYK", 5, 172222},
	{"AMBRE", 5, 172223},
	{"MICROTIME", 9, 172224},
	{"ANTIPERSONNEL", 13, 172225},
	{"MULINO", 6, 172226},
	{"SIEGAL", 6, 172227},
	{"PNEUMOCONIOSIS", 14, 172228},
	{"HUILE", 5, 172229},
	{"AUTOCRINE", 9, 172230},
	{"LAUNCELOT", 9, 172231},
	{"HORRORPOPS", 10, 172232},
	{"CLUSTALW", 8, 172233},
	{"POTENTE", 7, 172234},
	{"RHUMBA", 6, 172235},
	{"FOLOWING", 8, 172236},
	{"ERZSEBET", 8, 172237},
	{"SQUEEZEBOX", 10, 172238},
	{"TOOMER", 6, 172239},
	{"PRAWNY", 6, 172240},
	{"TWOSOME", 7, 172241},
	{"SMOLENSK", 8, 172242},
	{"PARENTHESIZED", 13, 172243},
	{"HERSCH", 6, 172244},
	{"GCAP", 4, 172245},
	{"BUBBLEJET", 9, 172246},
	{"BAMBOOZLE", 9, 172247},
	{"ZALE", 4, 172248},
	{"TCNJ", 4, 172249},
	{"VIONNET", 7, 172250},
	{"BFK", 3, 172251},
	{"BAGGALLINI", 10, 172252},
	{"TZEDAKAH", 8, 172253},
	{"TERRENO", 7, 172254},
	{"CANIN", 5, 172255},
	{"DANELLE", 7, 172256},
	{"PIGOTT", 6, 172257},
	{"CHICAEROTICANET", 15, 172258},
	{"YLSA", 4, 172259},
	{"YADT", 4, 172260},
	{"WYNT", 4, 172261},
	{"WABB", 4, 172262},
	{"UOPT", 4, 172263},
	{"UOMG", 4, 172264},
	{"UIPR", 4, 172265},
	{"RSAQ", 4, 172266},
	{"RASZ", 4, 172267},
	{"PTSY", 4, 172268},
	{"PSEQ", 4, 172269},
	{"OYLS", 4, 172270},
	{"OKYM", 4, 172271},
	{"OKYA", 4, 172272},
	{"NKLL", 4, 172273},
	{"NBCM", 4, 172274},
	{"MWEV", 4, 172275},
	{"MVOI", 4, 172276},
	{"MMFO", 4, 172277},
	{"MLDQ", 4, 172278},
	{"LUZI", 4, 172279},
	{"KEIP", 4, 172280},
	{"IJIW", 4, 172281},
	{"HYJU", 4, 172282},
	{"FLBE", 4, 172283},
	{"ELOZ", 4, 172284},
	{"DRTE", 4, 172285},
	{"CIEM", 4, 172286},
	{"CDIM", 4, 172287},
	{"BYUA", 4, 172288},
	{"AORJ", 4, 172289},
	{"INDAH", 5, 172290},
	{"SUBSTRUCTURES", 13, 172291},
	{"TWEEDE", 6, 172292},
	{"DSTORE", 6, 172293},
	{"GERMANYGERMANY", 14, 172294},
	{"COLLABORA", 9, 172295},
	{"BLAIRSTOWN", 10, 172296},
	{"REPORTLAB", 9, 172297},
	{"CAPD", 4, 172298},
	{"OUVERT", 6, 172299},
	{"MALY", 4, 172300},
	{"BORDERCOLOR", 11, 172301},
	{"PETUNIAS", 8, 172302},
	{"GRAVESHAM", 9, 172303},
	{"MENUHIN", 7, 172304},
	{"LAGNIAPPE", 9, 172305},
	{"EUROSTARS", 9, 172306},
	{"PHOSPHORIBOSYLTRANSFERASE", 25, 172307},
	{"KITTREDGE", 9, 172308},
	{"DIVULGING", 9, 172309},
	{"ULTRACHROME", 11, 172310},
	{"DUCHESSE", 8, 172311},
	{"SETATTR", 7, 172312},
	{"NAIVASHA", 8, 172313},
	{"ANDRIY", 6, 172314},
	{"MIGLIOR", 7, 172315},
	{"CARONDELET", 10, 172316},
	{"ABDUCTORS", 9, 172317},
	{"JURGENS", 7, 172318},
	{"HODDESDON", 9, 172319},
	{"PARATUBERCULOSIS", 16, 172320},
	{"NEEDIEST", 8, 172321},
	{"NOWY", 4, 172322},
	{"LIFERAFTS", 9, 172323},
	{"LSPCI", 5, 172324},
	{"YAMASAKI", 8, 172325},
	{"MOLINOS", 7, 172326},
	{"SPELVIN", 7, 172327},
	{"CHEERIO", 7, 172328},
	{"PARENTIS", 8, 172329},
	{"ABLECOMMERCE", 12, 172330},
	{"EXPRESSIBLE", 11, 172331},
	{"THIRDAGE", 8, 172332},
	{"JNANA", 5, 172333},
	{"ABDOMINALS", 10, 172334},
	{"STWITHPOLICIES", 14, 172335},
	{"POSIZIONAMENTO", 14, 172336},
	{"EXCRETE", 7, 172337},
	{"STREHLE", 7, 172338},
	{"POWERVIEW", 9, 172339},
	{"DISKLABEL", 9, 172340},
	{"LONDONS", 7, 172341},
	{"BISHOPSGATE", 11, 172342},
	{"BLOWDOWN", 8, 172343},
	{"ALTOIDS", 7, 172344},
	{"LOWENTHAL", 9, 172345},
	{"RESOURSES", 9, 172346},
	{"MINGLES", 7, 172347},
	{"XENU", 4, 172348},
	{"WXGTK", 5, 172349},
	{"STRAFE", 6, 172350},
	{"INTERNING", 9, 172351},
	{"XVIEW", 5, 172352},
	{"HELPINGS", 8, 172353},
	{"GOALPOSTS", 9, 172354},
	{"CUNENE", 6, 172355},
	{"BLIMPIE", 7, 172356},
	{"MALTODEXTRIN", 12, 172357},
	{"DECKLINK", 8, 172358},
	{"CELLNET", 7, 172359},
	{"UNDERSHIRT", 10, 172360},
	{"SOMETING", 8, 172361},
	{"ULTRAS", 6, 172362},
	{"FAKTOR", 6, 172363},
	{"DISMANTLERS", 11, 172364},
	{"CLAYART", 7, 172365},
	{"DJB", 3, 172366},
	{"JULLIE", 6, 172367},
	{"DJERBA", 6, 172368},
	{"FOTOGRAPHIC", 11, 172369},
	{"ANDRU", 5, 172370},
	{"HOSTCOUNT", 9, 172371},
	{"SUPPO", 5, 172372},
	{"RODENTICIDE", 11, 172373},
	{"SADAM", 5, 172374},
	{"XVIS", 4, 172375},
	{"VIAJ", 4, 172376},
	{"PTGA", 4, 172377},
	{"PMEF", 4, 172378},
	{"NZUE", 4, 172379},
	{"MRNI", 4, 172380},
	{"MPMP", 4, 172381},
	{"LLDQ", 4, 172382},
	{"LCYO", 4, 172383},
	{"INPM", 4, 172384},
	{"IBPR", 4, 172385},
	{"HUNM", 4, 172386},
	{"HLIP", 4, 172387},
	{"GGPR", 4, 172388},
	{"GDPO", 4, 172389},
	{"FTKI", 4, 172390},
	{"EYDD", 4, 172391},
	{"EMRL", 4, 172392},
	{"ELMP", 4, 172393},
	{"CDTO", 4, 172394},
	{"JETPACK", 7, 172395},
	{"PARTICULARES", 12, 172396},
	{"KLYNE", 5, 172397},
	{"CORRALS", 7, 172398},
	{"LAEL", 4, 172399},
	{"COLOQUE", 7, 172400},
	{"ICBMS", 5, 172401},
	{"UNMEE", 5, 172402},
	{"RECTITUDE", 9, 172403},
	{"GIFFIN", 6, 172404},
	{"RESOLVABLE", 10, 172405},
	{"ORTHOPHOSPHATE", 14, 172406},
	{"ZAKIM", 5, 172407},
	{"RASUL", 5, 172408},
	{"CERNED", 6, 172409},
	{"ISQL", 4, 172410},
	{"LUVOX", 5, 172411},
	{"BLAIRS", 6, 172412},
	{"UMLAUTS", 7, 172413},
	{"POLARIZATIONS", 13, 172414},
	{"NEWSBOT", 7, 172415},
	{"PRACTIONER", 10, 172416},
	{"GROUPID", 7, 172417},
	{"SEMBLE", 6, 172418},
	{"GNOMON", 6, 172419},
	{"LIBBIND", 7, 172420},
	{"COMPULINK", 9, 172421},
	{"CIMINO", 6, 172422},
	{"KLEAN", 5, 172423},
	{"PINGER", 6, 172424},
	{"TAOYUAN", 7, 172425},
	{"KASEI", 5, 172426},
	{"SOCIOPATHIC", 11, 172427},
	{"SWINNERTON", 10, 172428},
	{"ENTLY", 5, 172429},
	{"ENGEN", 5, 172430},
	{"STRATS", 6, 172431},
	{"BHIKKHUS", 8, 172432},
	{"TORSDAG", 7, 172433},
	{"ABDUCTOR", 8, 172434},
	{"HEIMANN", 7, 172435},
	{"ALCUIN", 6, 172436},
	{"AIRPLUSXTREMEG", 14, 172437},
	{"REGN", 4, 172438},
	{"DIMMITT", 7, 172439},
	{"JAILBREAK", 9, 172440},
	{"JACQ", 4, 172441},
	{"GARRETSON", 9, 172442},
	{"DEADPOOL", 8, 172443},
	{"PALEOCENE", 9, 172444},
	{"XAMPP", 5, 172445},
	{"KARENA", 6, 172446},
	{"BOYERTOWN", 9, 172447},
	{"HATHOR", 6, 172448},
	{"RECONSTRUCTIONIST", 17, 172449},
	{"FINEMAN", 7, 172450},
	{"ERREICHEN", 9, 172451},
	{"JADEITE", 7, 172452},
	{"COZENS", 6, 172453},
	{"BOSCOBEL", 8, 172454},
	{"DENIERS", 7, 172455},
	{"ENCIRCLES", 9, 172456},
	{"GARRATT", 7, 172457},
	{"UNHIDE", 6, 172458},
	{"SCAGGS", 6, 172459},
	{"NETWORKABLE", 11, 172460},
	{"RECTA", 5, 172461},
	{"KIRCHBERG", 9, 172462},
	{"IWITHPREFIX", 11, 172463},
	{"TIDUS", 5, 172464},
	{"INTERJECT", 9, 172465},
	{"SCOTIANS", 8, 172466},
	{"CUTICLES", 8, 172467},
	{"GABAERGIC", 9, 172468},
	{"SECUNDA", 7, 172469},
	{"NSGMLS", 6, 172470},
	{"DBV", 3, 172471},
	{"TORPEDOED", 9, 172472},
	{"JORDEN", 6, 172473},
	{"SHAWS", 5, 172474},
	{"CSLI", 4, 172475},
	{"CASTLEMAN", 9, 172476},
	{"SYNOO", 5, 172477},
	{"CISCOSECURE", 11, 172478},
	{"YGEM", 4, 172479},
	{"WDBU", 4, 172480},
	{"VILK", 4, 172481},
	{"UPII", 4, 172482},
	{"UIZH", 4, 172483},
	{"TZGR", 4, 172484},
	{"SAPM", 4, 172485},
	{"ROTF", 4, 172486},
	{"OWIJ", 4, 172487},
	{"OPYD", 4, 172488},
	{"OPMY", 4, 172489},
	{"NFUJ", 4, 172490},
	{"MBHO", 4, 172491},
	{"LMOA", 4, 172492},
	{"LCUN", 4, 172493},
	{"HUBL", 4, 172494},
	{"HDWA", 4, 172495},
	{"GJAV", 4, 172496},
	{"GHZA", 4, 172497},
	{"FOFV", 4, 172498},
	{"FDOS", 4, 172499},
	{"EVSM", 4, 172500},
	{"ECSR", 4, 172501},
	{"EACD", 4, 172502},
	{"DCAO", 4, 172503},
	{"CYHU", 4, 172504},
	{"CCRY", 4, 172505},
	{"BFEL", 4, 172506},
	{"BEVU", 4, 172507},
	{"BDEP", 4, 172508},
	{"AUBL", 4, 172509},
	{"AGBY", 4, 172510},
	{"ABUO", 4, 172511},
	{"HENDRIE", 7, 172512},
	{"ALUCARD", 7, 172513},
	{"MECONIUM", 8, 172514},
	{"ARING", 5, 172515},
	{"MONSEY", 6, 172516},
	{"FARBIGE", 7, 172517},
	{"ROWNEY", 6, 172518},
	{"SWEEDEN", 7, 172519},
	{"VALUETYPE", 9, 172520},
	{"ALGECIRAS", 9, 172521},
	{"VILLI", 5, 172522},
	{"GRASSLIST", 9, 172523},
	{"PRIMERGY", 8, 172524},
	{"MODCHIPS", 8, 172525},
	{"MISUSES", 7, 172526},
	{"KASSE", 5, 172527},
	{"MOSHIACH", 8, 172528},
	{"UNCLEANNESS", 11, 172529},
	{"RECOMPUTED", 10, 172530},
	{"NARRATIONS", 10, 172531},
	{"SLIMMED", 7, 172532},
	{"SUBSTITUTABILITY", 16, 172533},
	{"LETTORE", 7, 172534},
	{"ISOMETRY", 8, 172535},
	{"WHIPPER", 7, 172536},
	{"AARONSW", 7, 172537},
	{"DNANGEL", 7, 172538},
	{"SDWA", 4, 172539},
	{"VIENS", 5, 172540},
	{"KJZZ", 4, 172541},
	{"NSARRAY", 7, 172542},
	{"PRIED", 5, 172543},
	{"SUPPLICATIONS", 13, 172544},
	{"ONLIND", 6, 172545},
	{"TITLER", 6, 172546},
	{"CHATILLON", 9, 172547},
	{"FOLDOUT", 7, 172548},
	{"DOUSE", 5, 172549},
	{"THOMASSON", 9, 172550},
	{"CONCURSO", 8, 172551},
	{"SADHU", 5, 172552},
	{"RITZY", 5, 172553},
	{"JALALABAD", 9, 172554},
	{"PREITY", 6, 172555},
	{"CROTEAU", 7, 172556},
	{"JINGO", 5, 172557},
	{"RATEMAKING", 10, 172558},
	{"LASTMODIFIED", 12, 172559},
	{"SANTINO", 7, 172560},
	{"BECH", 4, 172561},
	{"BUTTPLUG", 8, 172562},
	{"POLLINATOR", 10, 172563},
	{"NIWOT", 5, 172564},
	{"DUNSTON", 7, 172565},
	{"AKASHA", 6, 172566},
	{"VERANDAHS", 9, 172567},
	{"CICI", 4, 172568},
	{"THEDA", 5, 172569},
	{"PIPKIN", 6, 172570},
	{"BOFORS", 6, 172571},
	{"SELZNICK", 8, 172572},
	{"OUTLOOKSOFT", 11, 172573},
	{"GUSTIN", 6, 172574},
	{"BEKINS", 6, 172575},
	{"ISTAR", 5, 172576},
	{"FLIGHTLINE", 10, 172577},
	{"ONELY", 5, 172578},
	{"MOBERG", 6, 172579},
	{"DEPORTMENT", 10, 172580},
	{"DEKOK", 5, 172581},
	{"CONNECTER", 9, 172582},
	{"ONLKNE", 6, 172583},
	{"QUOTIDIAN", 9, 172584},
	{"ZYHE", 4, 172585},
	{"ZSCA", 4, 172586},
	{"YNYA", 4, 172587},
	{"YDGO", 4, 172588},
	{"XAGE", 4, 172589},
	{"UXAS", 4, 172590},
	{"UMOX", 4, 172591},
	{"TCOX", 4, 172592},
	{"PVIN", 4, 172593},
	{"PTJA", 4, 172594},
	{"PTAU", 4, 172595},
	{"OLLJ", 4, 172596},
	{"OERD", 4, 172597},
	{"MUER", 4, 172598},
	{"LKAH", 4, 172599},
	{"LIZC", 4, 172600},
	{"KLYV", 4, 172601},
	{"JETM", 4, 172602},
	{"HYXI", 4, 172603},
	{"GLAL", 4, 172604},
	{"ESKF", 4, 172605},
	{"BIBLIOPHILE", 11, 172606},
	{"HORSERIDING", 11, 172607},
	{"POLYMERIZED", 11, 172608},
	{"TEMPRANILLO", 11, 172609},
	{"STEELWORK", 9, 172610},
	{"LETITCIA", 8, 172611},
	{"EKONOMI", 7, 172612},
	{"MARCHANDISES", 12, 172613},
	{"JUHL", 4, 172614},
	{"AMARTYA", 7, 172615},
	{"NACHTCLUB", 9, 172616},
	{"MYOCLONUS", 9, 172617},
	{"RECIPS", 6, 172618},
	{"WMNS", 4, 172619},
	{"INVIDIOUS", 9, 172620},
	{"FREEHOLDER", 10, 172621},
	{"BIBLIOTHEEK", 11, 172622},
	{"ABORTUS", 7, 172623},
	{"SVERIGES", 8, 172624},
	{"SIGACTION", 9, 172625},
	{"IREX", 4, 172626},
	{"VIRG", 4, 172627},
	{"MUNSELL", 7, 172628},
	{"KKKK", 4, 172629},
	{"FREDERICO", 9, 172630},
	{"BURNTWOOD", 9, 172631},
	{"DPDT", 4, 172632},
	{"PIANTA", 6, 172633},
	{"MYLENE", 6, 172634},
	{"GETAC", 5, 172635},
	{"JOGO", 4, 172636},
	{"GRIEGO", 6, 172637},
	{"FOUNDPROOF", 10, 172638},
	{"VISSCHER", 8, 172639},
	{"COWRA", 5, 172640},
	{"ZANETTI", 7, 172641},
	{"TUBERC", 6, 172642},
	{"WETEN", 5, 172643},
	{"CNPS", 4, 172644},
	{"OUTTAKE", 7, 172645},
	{"ACTUA", 5, 172646},
	{"SHAWINIGAN", 10, 172647},
	{"SCATMAN", 7, 172648},
	{"PITTWATER", 9, 172649},
	{"ONPINE", 6, 172650},
	{"INVESTIGACION", 13, 172651},
	{"NETCAT", 6, 172652},
	{"HENNIKER", 8, 172653},
	{"SHITLOAD", 8, 172654},
	{"NETCENTER", 9, 172655},
	{"NUVEEN", 6, 172656},
	{"CAPPLETS", 8, 172657},
	{"FUEHRER", 7, 172658},
	{"IMAGEVIEW", 9, 172659},
	{"MOLLUSCAN", 9, 172660},
	{"HAURAKI", 7, 172661},
	{"MINHO", 5, 172662},
	{"SKEENA", 6, 172663},
	{"CROM", 4, 172664},
	{"DIFFEOMORPHISM", 14, 172665},
	{"COMPOS", 6, 172666},
	{"BIRDDOG", 7, 172667},
	{"BENIGNI", 7, 172668},
	{"ROMANOW", 7, 172669},
	{"SEARCHLIGHTS", 12, 172670},
	{"INTENET", 7, 172671},
	{"DATENBANKEN", 11, 172672},
	{"OAXACAN", 7, 172673},
	{"COMPACTIFICATION", 16, 172674},
	{"TRANSIENCE", 10, 172675},
	{"SETOFF", 6, 172676},
	{"SERAPHIC", 8, 172677},
	{"VDL", 3, 172678},
	{"STENHOUSE", 9, 172679},
	{"WEIGHBRIDGES", 12, 172680},
	{"GEDANKEN", 8, 172681},
	{"ALIGHTED", 8, 172682},
	{"POSET", 5, 172683},
	{"ZARC", 4, 172684},
	{"YYMC", 4, 172685},
	{"XROL", 4, 172686},
	{"WREI", 4, 172687},
	{"UKAO", 4, 172688},
	{"UJIR", 4, 172689},
	{"UIBE", 4, 172690},
	{"ROGW", 4, 172691},
	{"PBYJ", 4, 172692},
	{"OOJU", 4, 172693},
	{"NMEF", 4, 172694},
	{"NFCT", 4, 172695},
	{"NFCN", 4, 172696},
	{"MIAK", 4, 172697},
	{"MHOF", 4, 172698},
	{"LVAP", 4, 172699},
	{"KYAF", 4, 172700},
	{"HUIC", 4, 172701},
	{"HAYC", 4, 172702},
	{"FIBM", 4, 172703},
	{"EORQ", 4, 172704},
	{"DJEM", 4, 172705},
	{"DGNO", 4, 172706},
	{"BUYV", 4, 172707},
	{"BFIG", 4, 172708},
	{"MEDISAVE", 8, 172709},
	{"WEDDINGBELLS", 12, 172710},
	{"PROMETHEAN", 10, 172711},
	{"MALEVOLENCE", 11, 172712},
	{"FLOWRATE", 8, 172713},
	{"CODEHAUS", 8, 172714},
	{"AUMIX", 5, 172715},
	{"KESTEVEN", 8, 172716},
	{"PHOTOBLOGRING", 13, 172717},
	{"AERONAUTIC", 10, 172718},
	{"WARRENSVILLE", 12, 172719},
	{"DXP", 3, 172720},
	{"WETTEN", 6, 172721},
	{"OPORTUNITIES", 12, 172722},
	{"ALCALDE", 7, 172723},
	{"SOTHYS", 6, 172724},
	{"METHODOLOGICALLY", 16, 172725},
	{"JUDICATURE", 10, 172726},
	{"ANTSY", 5, 172727},
	{"BILLINGHURST", 12, 172728},
	{"PREMED", 6, 172729},
	{"LYMPHOPROLIFERATIVE", 19, 172730},
	{"WRAL", 4, 172731},
	{"KEKE", 4, 172732},
	{"RAMCO", 5, 172733},
	{"AMANTI", 6, 172734},
	{"VIGUEUR", 7, 172735},
	{"THROOP", 6, 172736},
	{"FOULKES", 7, 172737},
	{"DISTRIBUTER", 11, 172738},
	{"VITAMINAS", 9, 172739},
	{"SHOESHINE", 9, 172740},
	{"ANOTTERCHAOS", 12, 172741},
	{"REEDSBURG", 9, 172742},
	{"ARNOLDS", 7, 172743},
	{"PEERFLIX", 8, 172744},
	{"DETERMINA", 9, 172745},
	{"LENOXX", 6, 172746},
	{"BOSNA", 5, 172747},
	{"INCORROUT", 9, 172748},
	{"EINZELNE", 8, 172749},
	{"HINDLIMB", 8, 172750},
	{"WHEELSETS", 9, 172751},
	{"WEERGEVEN", 9, 172752},
	{"NOSTRUD", 7, 172753},
	{"ZZGL", 4, 172754},
	{"BODMAN", 6, 172755},
	{"PSEUDOGENES", 11, 172756},
	{"NONBLOCKING", 11, 172757},
	{"EDINGER", 7, 172758},
	{"ORGANOGENESIS", 13, 172759},
	{"SLAPPY", 6, 172760},
	{"ERATED", 6, 172761},
	{"AUGLAIZE", 8, 172762},
	{"MORPHOMETRICS", 13, 172763},
	{"MANHATTANVILLE", 14, 172764},
	{"LYICS", 5, 172765},
	{"JETBOIL", 7, 172766},
	{"DALITE", 6, 172767},
	{"ARVENSIS", 8, 172768},
	{"MYWEB", 5, 172769},
	{"DYSTOPIAN", 9, 172770},
	{"ZZYO", 4, 172771},
	{"YTHF", 4, 172772},
	{"ULUD", 4, 172773},
	{"UDME", 4, 172774},
	{"UDDR", 4, 172775},
	{"SVIP", 4, 172776},
	{"STDW", 4, 172777},
	{"SEPC", 4, 172778},
	{"SBYZ", 4, 172779},
	{"RGSL", 4, 172780},
	{"REPN", 4, 172781},
	{"RELN", 4, 172782},
	{"PWEI", 4, 172783},
	{"PTJU", 4, 172784},
	{"PIFA", 4, 172785},
	{"OALJ", 4, 172786},
	{"NUKK", 4, 172787},
	{"NMIF", 4, 172788},
	{"MIRF", 4, 172789},
	{"MELZ", 4, 172790},
	{"KBUD", 4, 172791},
	{"IOMY", 4, 172792},
	{"FKUW", 4, 172793},
	{"FIXU", 4, 172794},
	{"EVDR", 4, 172795},
	{"ENGJ", 4, 172796},
	{"EMUA", 4, 172797},
	{"DULF", 4, 172798},
	{"DLOE", 4, 172799},
	{"DBAA", 4, 172800},
	{"CHUH", 4, 172801},
	{"CBOW", 4, 172802},
	{"BZUM", 4, 172803},
	{"AHBY", 4, 172804},
	{"EXHORTING", 9, 172805},
	{"TENUTA", 6, 172806},
	{"PLACENAMES", 10, 172807},
	{"WORKPACKAGE", 11, 172808},
	{"LIBATION", 8, 172809},
	{"ESERVICE", 8, 172810},
	{"KIRTAN", 6, 172811},
	{"KYRENIA", 7, 172812},
	{"FACIT", 5, 172813},
	{"AFROMAN", 7, 172814},
	{"VALRICO", 7, 172815},
	{"POCOMOKE", 8, 172816},
	{"FLIGHTSIM", 9, 172817},
	{"SCULLS", 6, 172818},
	{"SOIENT", 6, 172819},
	{"MIASMA", 6, 172820},
	{"LEVENE", 6, 172821},
	{"SEBADOH", 7, 172822},
	{"INSTANTIATES", 12, 172823},
	{"ANDYS", 5, 172824},
	{"HYPERTENS", 9, 172825},
	{"INTERACTOR", 10, 172826},
	{"CUIDADOS", 8, 172827},
	{"UPPORT", 6, 172828},
	{"UMBCTAC", 7, 172829},
	{"PLASMIN", 7, 172830},
	{"BLATTER", 7, 172831},
	{"DOSEMU", 6, 172832},
	{"COUPLA", 6, 172833},
	{"EASTSOUND", 9, 172834},
	{"BREMZEN", 7, 172835},
	{"FACILIDADES", 11, 172836},
	{"OFFIZIELLE", 10, 172837},
	{"MAINSTAYS", 9, 172838},
	{"MULTICS", 7, 172839},
	{"FLYBE", 5, 172840},
	{"DUAS", 4, 172841},
	{"ECHNICAL", 8, 172842},
	{"CHOCKS", 6, 172843},
	{"GLIST", 5, 172844},
	{"EMBREE", 6, 172845},
	{"PLDI", 4, 172846},
	{"ASTRONAUTICAL", 13, 172847},
	{"STASIA", 6, 172848},
	{"FALLSTON", 8, 172849},
	{"ANGIOSPERM", 10, 172850},
	{"RECHTS", 6, 172851},
	{"ROADTRIPS", 9, 172852},
	{"JOVICA", 6, 172853},
	{"IBOC", 4, 172854},
	{"HAFTA", 5, 172855},
	{"BAGATELLE", 9, 172856},
	{"GPMDB", 5, 172857},
	{"CONVENERS", 9, 172858},
	{"PRESERVERS", 10, 172859},
	{"FRANKO", 6, 172860},
	{"DIGIMARC", 8, 172861},
	{"SMITHING", 8, 172862},
	{"GAUSSIANS", 9, 172863},
	{"DEMOCRATIZING", 13, 172864},
	{"MCENERY", 7, 172865},
	{"CHAINE", 6, 172866},
	{"REVOLUTIONISED", 14, 172867},
	{"UCITA", 5, 172868},
	{"LIETUVOS", 8, 172869},
	{"ZHEJ", 4, 172870},
	{"YMRU", 4, 172871},
	{"WWSE", 4, 172872},
	{"UEXT", 4, 172873},
	{"SPFI", 4, 172874},
	{"RMOY", 4, 172875},
	{"RDYR", 4, 172876},
	{"OPWR", 4, 172877},
	{"MILG", 4, 172878},
	{"LTDB", 4, 172879},
	{"LEMV", 4, 172880},
	{"LAXW", 4, 172881},
	{"JADW", 4, 172882},
	{"INUB", 4, 172883},
	{"IKLU", 4, 172884},
	{"GUEQ", 4, 172885},
	{"EXKI", 4, 172886},
	{"EDDJ", 4, 172887},
	{"CUHA", 4, 172888},
	{"AKDJ", 4, 172889},
	{"AHUW", 4, 172890},
	{"SERVATION", 9, 172891},
	{"BELLOVIN", 8, 172892},
	{"KILGOUR", 7, 172893},
	{"BITESIZE", 8, 172894},
	{"PINNEY", 6, 172895},
	{"TEAROOM", 7, 172896},
	{"DUKINFIELD", 10, 172897},
	{"HOMECONTACT", 11, 172898},
	{"SWOOPS", 6, 172899},
	{"SCHWEIGER", 9, 172900},
	{"INCLUYE", 7, 172901},
	{"URM", 3, 172902},
	{"SURESHOT", 8, 172903},
	{"KOMPONENTER", 11, 172904},
	{"BILLEDER", 8, 172905},
	{"SLOMAN", 6, 172906},
	{"GOVERNORATES", 12, 172907},
	{"LAMOTHE", 7, 172908},
	{"RIMROCK", 7, 172909},
	{"NONCHALANTLY", 12, 172910},
	{"ARSES", 5, 172911},
	{"BANCOS", 6, 172912},
	{"HAIRPINS", 8, 172913},
	{"TRESPASSER", 10, 172914},
	{"ONLINS", 6, 172915},
	{"ETALK", 5, 172916},
	{"JUHANI", 6, 172917},
	{"HANDSTAND", 9, 172918},
	{"OFTC", 4, 172919},
	{"DAWOOD", 6, 172920},
	{"GRAFEI", 6, 172921},
	{"ANUPAM", 6, 172922},
	{"METAWARE", 8, 172923},
	{"TIMELESSNESS", 12, 172924},
	{"GOGEAR", 6, 172925},
	{"ARTF", 4, 172926},
	{"TYPECAST", 8, 172927},
	{"RELM", 4, 172928},
	{"TRAMMEL", 7, 172929},
	{"COBRE", 5, 172930},
	{"PREISAGENTUREN", 14, 172931},
	{"MOLESTIE", 8, 172932},
	{"ICKES", 5, 172933},
	{"TSUKI", 5, 172934},
	{"COUPEVILLE", 10, 172935},
	{"IRRESPONSIBLY", 13, 172936},
	{"BUGZ", 4, 172937},
	{"SALADE", 6, 172938},
	{"MYCROFT", 7, 172939},
	{"TATARS", 6, 172940},
	{"SPECIALSPRE", 11, 172941},
	{"CHOREA", 6, 172942},
	{"WKTS", 4, 172943},
	{"ISTOOK", 6, 172944},
	{"IFINDER", 7, 172945},
	{"CALATRAVA", 9, 172946},
	{"SCHEUER", 7, 172947},
	{"PRESTONSBURG", 12, 172948},
	{"ZMAS", 4, 172949},
	{"XDEG", 4, 172950},
	{"WWPA", 4, 172951},
	{"WWBA", 4, 172952},
	{"WAZU", 4, 172953},
	{"VYSC", 4, 172954},
	{"RSZE", 4, 172955},
	{"RLTA", 4, 172956},
	{"RKYR", 4, 172957},
	{"PSJA", 4, 172958},
	{"PODL", 4, 172959},
	{"LSEJ", 4, 172960},
	{"LAAU", 4, 172961},
	{"KFAV", 4, 172962},
	{"IXVO", 4, 172963},
	{"GMCG", 4, 172964},
	{"FMEH", 4, 172965},
	{"ELCY", 4, 172966},
	{"ASKV", 4, 172967},
	{"AHCL", 4, 172968},
	{"AGQU", 4, 172969},
	{"ADIQ", 4, 172970},
	{"CBSE", 4, 172971},
	{"ACQIRIS", 7, 172972},
	{"OLIGOMER", 8, 172973},
	{"MELANCON", 8, 172974},
	{"LEGAULT", 7, 172975},
	{"GENG", 4, 172976},
	{"SUBBED", 6, 172977},
	{"POPKIN", 6, 172978},
	{"KIMBOLTON", 9, 172979},
	{"HERBIVORY", 9, 172980},
	{"REGD", 4, 172981},
	{"HARSHA", 6, 172982},
	{"DEFENSIVENESS", 13, 172983},
	{"WINNINGEST", 10, 172984},
	{"SPREES", 6, 172985},
	{"SOLDERLESS", 10, 172986},
	{"DRENCHING", 9, 172987},
	{"ISOZYMES", 8, 172988},
	{"LAVROV", 6, 172989},
	{"SRIKANTH", 8, 172990},
	{"PORTHCAWL", 9, 172991},
	{"MITGCM", 6, 172992},
	{"SHERE", 5, 172993},
	{"PROFESSIONA", 11, 172994},
	{"NARVA", 5, 172995},
	{"DONEC", 5, 172996},
	{"ABATEMENTS", 10, 172997},
	{"BYWYD", 5, 172998},
	{"CEILI", 5, 172999},
	{"ADDHANDLER", 10, 173000},
	{"BROADAX", 7, 173001},
	{"CRINKLED", 8, 173002},
	{"FORGISS", 7, 173003},
	{"EPIMERASE", 9, 173004},
	{"VIDEOCHIP", 9, 173005},
	{"BRAEMER", 7, 173006},
	{"RAYO", 4, 173007},
	{"BACHUS", 6, 173008},
	{"VERHAAL", 7, 173009},
	{"ALACRA", 6, 173010},
	{"NEWSBREAK", 9, 173011},
	{"SUBI", 4, 173012},
	{"RAGGIO", 6, 173013},
	{"BARONA", 6, 173014},
	{"CLDC", 4, 173015},
	{"SIDERS", 6, 173016},
	{"RHIZOSPHERE", 11, 173017},
	{"WESTAR", 6, 173018},
	{"CAPTAINSTABBIN", 14, 173019},
	{"PRIETA", 6, 173020},
	{"MORPHIN", 7, 173021},
	{"HARLECH", 7, 173022},
	{"THIJS", 5, 173023},
	{"REITMAN", 7, 173024},
	{"DETONATORS", 10, 173025},
	{"GTKSOURCEVIEW", 13, 173026},
	{"ADVOGATO", 8, 173027},
	{"CHIENS", 6, 173028},
	{"LNLINE", 6, 173029},
	{"LAIDBACK", 8, 173030},
	{"PRANCE", 6, 173031},
	{"ANTONIONI", 9, 173032},
	{"UNDERFUNDING", 12, 173033},
	{"WIEBETECH", 9, 173034},
	{"PHYLLO", 6, 173035},
	{"WHATMAN", 7, 173036},
	{"LEPRAE", 6, 173037},
	{"KAZAK", 5, 173038},
	{"ADRIALIN", 8, 173039},
	{"BAWA", 4, 173040},
	{"BCLA", 4, 173041},
	{"KEYSET", 6, 173042},
	{"SHLIBS", 6, 173043},
	{"MOUNTIES", 8, 173044},
	{"CIRKUS", 6, 173045},
	{"BRICKLEY", 8, 173046},
	{"HEELER", 6, 173047},
	{"CROSSGEN", 8, 173048},
	{"BEHRENDT", 8, 173049},
	{"NCOL", 4, 173050},
	{"KETOROLAC", 9, 173051},
	{"PADRON", 6, 173052},
	{"ETIKETTEN", 9, 173053},
	{"SPROG", 5, 173054},
	{"GHGS", 4, 173055},
	{"FIXPOINT", 8, 173056},
	{"ALLPOLITICS", 11, 173057},
	{"WESTERFIELD", 11, 173058},
	{"ZMON", 4, 173059},
	{"YMUG", 4, 173060},
	{"YDEO", 4, 173061},
	{"XPIE", 4, 173062},
	{"TOZU", 4, 173063},
	{"TADB", 4, 173064},
	{"SUML", 4, 173065},
	{"RYEW", 4, 173066},
	{"RACD", 4, 173067},
	{"OEPL", 4, 173068},
	{"MNWE", 4, 173069},
	{"JIBU", 4, 173070},
	{"IZOM", 4, 173071},
	{"IBMH", 4, 173072},
	{"GMYI", 4, 173073},
	{"FFYH", 4, 173074},
	{"DLSQ", 4, 173075},
	{"AZCA", 4, 173076},
	{"AMUF", 4, 173077},
	{"ACYY", 4, 173078},
	{"REFITTED", 8, 173079},
	{"GUARANTIES", 10, 173080},
	{"SPEECHD", 7, 173081},
	{"WEARHOUSE", 9, 173082},
	{"NERR", 4, 173083},
	{"BAGGIE", 6, 173084},
	{"MANITOBANS", 10, 173085},
	{"ALLOK", 5, 173086},
	{"LALU", 4, 173087},
	{"LANDMASS", 8, 173088},
	{"AUTOSTREAM", 10, 173089},
	{"APPLETREE", 9, 173090},
	{"LAPSING", 7, 173091},
	{"MALTZ", 5, 173092},
	{"COBH", 4, 173093},
	{"ENVIROFACTS", 11, 173094},
	{"SOJG", 4, 173095},
	{"MCEACHERN", 9, 173096},
	{"JMW", 3, 173097},
	{"ULTRALINK", 9, 173098},
	{"FRODE", 5, 173099},
	{"IVERS", 5, 173100},
	{"HAROON", 6, 173101},
	{"PAEDIATR", 8, 173102},
	{"GROOVER", 7, 173103},
	{"YONHAP", 6, 173104},
	{"DOOP", 4, 173105},
	{"BUDDE", 5, 173106},
	{"PACSAFE", 7, 173107},
	{"KONNO", 5, 173108},
	{"ADLAI", 5, 173109},
	{"ACHIEVA", 7, 173110},
	{"CHAIKIN", 7, 173111},
	{"SUPPLICANT", 10, 173112},
	{"LINLEY", 6, 173113},
	{"AMIDA", 5, 173114},
	{"DESHLER", 7, 173115},
	{"SUIVRE", 6, 173116},
	{"MQM", 3, 173117},
	{"RECOMMEN", 8, 173118},
	{"EDIFICES", 8, 173119},
	{"OPENSTEP", 8, 173120},
	{"PRINTWRITER", 11, 173121},
	{"BERNA", 5, 173122},
	{"OBJETIVO", 8, 173123},
	{"KEWELL", 6, 173124},
	{"GRUEL", 5, 173125},
	{"IDEQ", 4, 173126},
	{"TELEWORKERS", 11, 173127},
	{"TRANSGRESSIVE", 13, 173128},
	{"REINTERPRETED", 13, 173129},
	{"NAVRATILOVA", 11, 173130},
	{"NOFWS", 5, 173131},
	{"MISTIC", 6, 173132},
	{"TOURNEAU", 8, 173133},
	{"NIZATION", 8, 173134},
	{"ACETYLATED", 10, 173135},
	{"DECRIMINALIZATION", 17, 173136},
	{"FLENSBURG", 9, 173137},
	{"FERIENWOHNUNGEN", 15, 173138},
	{"DEVILLA", 7, 173139},
	{"CRITI", 5, 173140},
	{"SHIEL", 5, 173141},
	{"TRAVELTRAVEL", 12, 173142},
	{"WEREN", 5, 173143},
	{"FING", 4, 173144},
	{"YELU", 4, 173145},
	{"VOCW", 4, 173146},
	{"ULLQ", 4, 173147},
	{"UDTR", 4, 173148},
	{"RKYT", 4, 173149},
	{"PUPM", 4, 173150},
	{"PISV", 4, 173151},
	{"OFGB", 4, 173152},
	{"NNDU", 4, 173153},
	{"LMPI", 4, 173154},
	{"LBDE", 4, 173155},
	{"KIGR", 4, 173156},
	{"KERQ", 4, 173157},
	{"GAOC", 4, 173158},
	{"CNNR", 4, 173159},
	{"BECM", 4, 173160},
	{"ARRF", 4, 173161},
	{"AZIENDE", 7, 173162},
	{"MENKE", 5, 173163},
	{"DOODLING", 8, 173164},
	{"DECENTRALIZE", 12, 173165},
	{"ABORD", 5, 173166},
	{"ORRICK", 6, 173167},
	{"DOORBELLS", 9, 173168},
	{"DISCOGRAFIA", 11, 173169},
	{"JOBBERS", 7, 173170},
	{"GRIESE", 6, 173171},
	{"FASTTRAC", 8, 173172},
	{"EXASPERATING", 12, 173173},
	{"CRESPI", 6, 173174},
	{"TAKAKO", 6, 173175},
	{"TRADUCCIONES", 12, 173176},
	{"CONDONES", 8, 173177},
	{"TREED", 5, 173178},
	{"YUSUKE", 6, 173179},
	{"FOLKSONGS", 9, 173180},
	{"HENDRIKS", 8, 173181},
	{"CLERIDES", 8, 173182},
	{"COMPAC", 6, 173183},
	{"PREFERRABLY", 11, 173184},
	{"AIRMAX", 6, 173185},
	{"UNDERLAIN", 9, 173186},
	{"NETINFO", 7, 173187},
	{"MUGGY", 5, 173188},
	{"GRIEVOUSLY", 10, 173189},
	{"ATOMIZATION", 11, 173190},
	{"RATIONED", 8, 173191},
	{"SAPPER", 6, 173192},
	{"ARVID", 5, 173193},
	{"LOOFAH", 6, 173194},
	{"LEBOWITZ", 8, 173195},
	{"KPL", 3, 173196},
	{"NEUROFEEDBACK", 13, 173197},
	{"CHEQUERS", 8, 173198},
	{"MAILLISTS", 9, 173199},
	{"HAUTS", 5, 173200},
	{"TAGISH", 6, 173201},
	{"CHRISTS", 7, 173202},
	{"SEERSUCKER", 10, 173203},
	{"PARTOUT", 7, 173204},
	{"CALIFORNICATION", 15, 173205},
	{"CRICKETING", 10, 173206},
	{"ARTIMA", 6, 173207},
	{"BEDA", 4, 173208},
	{"MHZXSCALE", 9, 173209},
	{"CAPPY", 5, 173210},
	{"PERPETRATING", 12, 173211},
	{"CULLOWHEE", 9, 173212},
	{"UGX", 3, 173213},
	{"KNOWABLE", 8, 173214},
	{"CDCS", 4, 173215},
	{"MYSQLADMIN", 10, 173216},
	{"WHEELIES", 8, 173217},
	{"FAPE", 4, 173218},
	{"UNVERSITY", 9, 173219},
	{"PILLAY", 6, 173220},
	{"MEIKLE", 6, 173221},
	{"CJP", 3, 173222},
	{"SUBSUMES", 8, 173223},
	{"SINAR", 5, 173224},
	{"TIGHTPOKER", 10, 173225},
	{"MILLOY", 6, 173226},
	{"COLLOCATIONS", 12, 173227},
	{"PROGESTINS", 10, 173228},
	{"ROMBERG", 7, 173229},
	{"LYTICS", 6, 173230},
	{"ENTRUSTING", 10, 173231},
	{"LADSON", 6, 173232},
	{"GOTOASSIST", 10, 173233},
	{"BULLSH", 6, 173234},
	{"SABLEVM", 7, 173235},
	{"POTEET", 6, 173236},
	{"NONCOMMISSIONED", 15, 173237},
	{"KAUI", 4, 173238},
	{"FSANZ", 5, 173239},
	{"ZEITLIN", 7, 173240},
	{"WUERZBURG", 9, 173241},
	{"RESCALE", 7, 173242},
	{"GRINDLEY", 8, 173243},
	{"CYTARABINE", 10, 173244},
	{"VFU", 3, 173245},
	{"HESITANCY", 9, 173246},
	{"SCOTUSBLOG", 10, 173247},
	{"PEANO", 5, 173248},
	{"ANDRIS", 6, 173249},
	{"PACU", 4, 173250},
	{"OCAU", 4, 173251},
	{"PLOYEE", 6, 173252},
	{"DWYANE", 6, 173253},
	{"ZIWH", 4, 173254},
	{"ZELN", 4, 173255},
	{"UZAF", 4, 173256},
	{"UGSG", 4, 173257},
	{"TIPW", 4, 173258},
	{"PTUE", 4, 173259},
	{"OVWE", 4, 173260},
	{"NZWE", 4, 173261},
	{"MKUR", 4, 173262},
	{"LFSM", 4, 173263},
	{"JUND", 4, 173264},
	{"IXCI", 4, 173265},
	{"HYKE", 4, 173266},
	{"GLEQ", 4, 173267},
	{"FFKN", 4, 173268},
	{"EKYA", 4, 173269},
	{"EGSR", 4, 173270},
	{"CYCU", 4, 173271},
	{"CWRO", 4, 173272},
	{"CKZA", 4, 173273},
	{"AWKF", 4, 173274},
	{"FRYDERYK", 8, 173275},
	{"RESTATEMENTS", 12, 173276},
	{"HOLLERED", 8, 173277},
	{"KELSON", 6, 173278},
	{"PUSHL", 5, 173279},
	{"BAEZA", 5, 173280},
	{"TURABIAN", 8, 173281},
	{"COURTE", 6, 173282},
	{"CARJACKING", 10, 173283},
	{"GUNA", 4, 173284},
	{"CHAFED", 6, 173285},
	{"KENNEN", 6, 173286},
	{"ARKET", 5, 173287},
	{"TRAMPAS", 7, 173288},
	{"SEFFNER", 7, 173289},
	{"SELECCIONE", 10, 173290},
	{"DISALLOWABLE", 12, 173291},
	{"WASHDOWN", 8, 173292},
	{"SHIVAE", 6, 173293},
	{"JCOMPONENT", 10, 173294},
	{"ABHIJIT", 7, 173295},
	{"MACROLIDE", 9, 173296},
	{"ARMORER", 7, 173297},
	{"FRITTATA", 8, 173298},
	{"WITHDRAWLS", 10, 173299},
	{"LISTLEVEL", 9, 173300},
	{"AGIP", 4, 173301},
	{"BARZANI", 7, 173302},
	{"SEAMING", 7, 173303},
	{"MYMUSIC", 7, 173304},
	{"AIRTICKETS", 10, 173305},
	{"NAMETAG", 7, 173306},
	{"HIROHITO", 8, 173307},
	{"INTERPOSITION", 13, 173308},
	{"GENETICA", 8, 173309},
	{"DEFATTR", 7, 173310},
	{"JOBSINEDUCATION", 15, 173311},
	{"SHOJO", 5, 173312},
	{"DEALLOCATION", 12, 173313},
	{"TABARD", 6, 173314},
	{"CALLINGS", 8, 173315},
	{"BOOTSY", 6, 173316},
	{"SATISFACTIONS", 13, 173317},
	{"DISTRUSTFUL", 11, 173318},
	{"BENSONS", 7, 173319},
	{"SASTRY", 6, 173320},
	{"LODESTAR", 8, 173321},
	{"RECONSTRUCTS", 12, 173322},
	{"SCHALLPLATTEN", 13, 173323},
	{"LIFTON", 6, 173324},
	{"ARHIVA", 6, 173325},
	{"UOFL", 4, 173326},
	{"ROCKETMAN", 9, 173327},
	{"BARBIZON", 8, 173328},
	{"RUSIA", 5, 173329},
	{"CRYSIS", 6, 173330},
	{"TOYODA", 6, 173331},
	{"HOOKY", 5, 173332},
	{"CRANLEY", 7, 173333},
	{"EBNER", 5, 173334},
	{"RANDOMISATION", 13, 173335},
	{"IDDM", 4, 173336},
	{"XSYM", 4, 173337},
	{"WEYS", 4, 173338},
	{"VEKU", 4, 173339},
	{"USXM", 4, 173340},
	{"UGPM", 4, 173341},
	{"SZOR", 4, 173342},
	{"RYJI", 4, 173343},
	{"RWOE", 4, 173344},
	{"ROAW", 4, 173345},
	{"RIFD", 4, 173346},
	{"RESZ", 4, 173347},
	{"POBE", 4, 173348},
	{"OXRO", 4, 173349},
	{"OCMI", 4, 173350},
	{"NIDC", 4, 173351},
	{"MKIM", 4, 173352},
	{"IKUA", 4, 173353},
	{"IGCU", 4, 173354},
	{"GSTL", 4, 173355},
	{"FOWI", 4, 173356},
	{"EKJA", 4, 173357},
	{"EHYU", 4, 173358},
	{"HENTAY", 6, 173359},
	{"CONTRAC", 7, 173360},
	{"ARMADILLOS", 10, 173361},
	{"GREENLAWN", 9, 173362},
	{"HAMNER", 6, 173363},
	{"JETTISONED", 10, 173364},
	{"SCHIAVONE", 9, 173365},
	{"CDSC", 4, 173366},
	{"HOLIC", 5, 173367},
	{"AGRAVE", 6, 173368},
	{"CONTEMPORY", 10, 173369},
	{"STORICO", 7, 173370},
	{"ARNESON", 7, 173371},
	{"CEBALLOS", 8, 173372},
	{"KARLHEINZ", 9, 173373},
	{"PITTSBURGHLIVE", 14, 173374},
	{"HAMON", 5, 173375},
	{"RYDEN", 5, 173376},
	{"IMPHAL", 6, 173377},
	{"HEARTTHROB", 10, 173378},
	{"SOPHMORE", 8, 173379},
	{"FLAVELL", 7, 173380},
	{"GABANNA", 7, 173381},
	{"SUPERCREW", 9, 173382},
	{"HOMESTAND", 9, 173383},
	{"FREEVO", 6, 173384},
	{"MICROBIOLOGISTS", 15, 173385},
	{"BOUSE", 5, 173386},
	{"AAMES", 5, 173387},
	{"FREQS", 5, 173388},
	{"INEFFICIENTLY", 13, 173389},
	{"INCREDULOUSLY", 13, 173390},
	{"XIPH", 4, 173391},
	{"REPRODUCIBLES", 13, 173392},
	{"LERMA", 5, 173393},
	{"PREGNENOLONE", 12, 173394},
	{"ARTICULOS", 9, 173395},
	{"OBSEQUIOUS", 10, 173396},
	{"MAYBANK", 7, 173397},
	{"HICKER", 6, 173398},
	{"OWCP", 4, 173399},
	{"GIONAL", 6, 173400},
	{"BLAGUE", 6, 173401},
	{"RELATEDWWW", 10, 173402},
	{"LENING", 6, 173403},
	{"SARTOR", 6, 173404},
	{"MOYENS", 6, 173405},
	{"HALION", 6, 173406},
	{"REGROW", 6, 173407},
	{"SIXBIT", 6, 173408},
	{"KATIF", 5, 173409},
	{"TAILWIND", 8, 173410},
	{"NCVER", 5, 173411},
	{"HEIGH", 5, 173412},
	{"GART", 4, 173413},
	{"ROUGHNECKS", 10, 173414},
	{"TONEXPRESS", 10, 173415},
	{"SKYMILES", 8, 173416},
	{"PIPI", 4, 173417},
	{"BALU", 4, 173418},
	{"SACHIKO", 7, 173419},
	{"OSWIN", 5, 173420},
	{"INTERTWINE", 10, 173421},
	{"INPLANTS", 8, 173422},
	{"KUMARAKOM", 9, 173423},
	{"JAGA", 4, 173424},
	{"LEPRECHAUNS", 11, 173425},
	{"AILERONS", 8, 173426},
	{"AJEDREZ", 7, 173427},
	{"COTLER", 6, 173428},
	{"YNGS", 4, 173429},
	{"VBIL", 4, 173430},
	{"TFRY", 4, 173431},
	{"TDUG", 4, 173432},
	{"SLUL", 4, 173433},
	{"RZEM", 4, 173434},
	{"ONWB", 4, 173435},
	{"NIKR", 4, 173436},
	{"NGKW", 4, 173437},
	{"MVPW", 4, 173438},
	{"MTVC", 4, 173439},
	{"MMRE", 4, 173440},
	{"KFIF", 4, 173441},
	{"IZWI", 4, 173442},
	{"GIMG", 4, 173443},
	{"FACY", 4, 173444},
	{"EPEK", 4, 173445},
	{"EGUC", 4, 173446},
	{"CUSV", 4, 173447},
	{"CKEG", 4, 173448},
	{"MENCIA", 6, 173449},
	{"SOLOGIG", 7, 173450},
	{"DISSOLUTE", 9, 173451},
	{"LUHRMANN", 8, 173452},
	{"ESTWING", 7, 173453},
	{"BETRAYALS", 9, 173454},
	{"DILATON", 7, 173455},
	{"CLEARNOVA", 9, 173456},
	{"JOHNE", 5, 173457},
	{"YALA", 4, 173458},
	{"WSBK", 4, 173459},
	{"HELIPORTS", 9, 173460},
	{"ROISIN", 6, 173461},
	{"JAUNDICED", 9, 173462},
	{"PITCHSHIFTER", 12, 173463},
	{"WALDOCK", 7, 173464},
	{"CMW", 3, 173465},
	{"VISTANA", 7, 173466},
	{"RECK", 4, 173467},
	{"ONGAR", 5, 173468},
	{"PEDE", 4, 173469},
	{"WHOREHOUSE", 10, 173470},
	{"TOWLEROAD", 9, 173471},
	{"ASTOUNDINGLY", 12, 173472},
	{"DIRTBAG", 7, 173473},
	{"ENCARNACION", 11, 173474},
	{"JEMAAH", 6, 173475},
	{"MAKAROV", 7, 173476},
	{"ADDITIONALITY", 13, 173477},
	{"KORBEL", 6, 173478},
	{"AMBION", 6, 173479},
	{"ESCULENTUM", 10, 173480},
	{"MONASTIR", 8, 173481},
	{"SABAL", 5, 173482},
	{"INTSIZE", 7, 173483},
	{"PROCAINE", 8, 173484},
	{"KHATIB", 6, 173485},
	{"MYSKINA", 7, 173486},
	{"BRIEFEST", 8, 173487},
	{"LAMPLIGHT", 9, 173488},
	{"HYDROXYTRYPTAMINE", 17, 173489},
	{"CLAVULANATE", 11, 173490},
	{"ATOMICAGGREGATE", 15, 173491},
	{"MISTRUSTFUL", 11, 173492},
	{"SHARPSHOOTERS", 13, 173493},
	{"WAZA", 4, 173494},
	{"SCHNITZEL", 9, 173495},
	{"RSMMC", 5, 173496},
	{"HARTINGTON", 10, 173497},
	{"NEUROTRANSMISSION", 17, 173498},
	{"INTERVENER", 10, 173499},
	{"MKG", 3, 173500},
	{"HEREON", 6, 173501},
	{"DEUTSCHSPRACHIGE", 16, 173502},
	{"BUTTRESSED", 10, 173503},
	{"SEMIANNUALLY", 12, 173504},
	{"KILLBOX", 7, 173505},
	{"REMEDIATED", 10, 173506},
	{"COEVOLUTION", 11, 173507},
	{"YOOP", 4, 173508},
	{"WLMA", 4, 173509},
	{"WEEC", 4, 173510},
	{"VMAD", 4, 173511},
	{"UKUI", 4, 173512},
	{"TYNY", 4, 173513},
	{"ROEK", 4, 173514},
	{"RIUL", 4, 173515},
	{"OOLQ", 4, 173516},
	{"OFPF", 4, 173517},
	{"NODF", 4, 173518},
	{"LIUZ", 4, 173519},
	{"KKEP", 4, 173520},
	{"HUKI", 4, 173521},
	{"GPEP", 4, 173522},
	{"FLFR", 4, 173523},
	{"FCCT", 4, 173524},
	{"CURN", 4, 173525},
	{"CBSD", 4, 173526},
	{"AQQA", 4, 173527},
	{"ANRP", 4, 173528},
	{"AAMP", 4, 173529},
	{"MUKHTAR", 7, 173530},
	{"DEISEL", 6, 173531},
	{"AVALEHELE", 9, 173532},
	{"SPORTSDAY", 9, 173533},
	{"DRUGGIST", 8, 173534},
	{"USETHREADS", 10, 173535},
	{"KOMBUCHA", 8, 173536},
	{"ABSOLU", 6, 173537},
	{"AMATUR", 6, 173538},
	{"SPINNIN", 7, 173539},
	{"ROCKHILL", 8, 173540},
	{"KORTH", 5, 173541},
	{"BOWMANVILLE", 11, 173542},
	{"MRCGP", 5, 173543},
	{"LCOM", 4, 173544},
	{"TAVOLO", 6, 173545},
	{"LOCATER", 7, 173546},
	{"HOUSESHARE", 10, 173547},
	{"TELESEMINAR", 11, 173548},
	{"PHOTOMULTIPLIER", 15, 173549},
	{"DUMBRELLA", 9, 173550},
	{"PREAPPROVED", 11, 173551},
	{"RECEPIES", 8, 173552},
	{"IBASE", 5, 173553},
	{"UNPRINCIPLED", 12, 173554},
	{"SWEATED", 7, 173555},
	{"LIETH", 5, 173556},
	{"FORMULAR", 8, 173557},
	{"PEPLE", 5, 173558},
	{"USERADD", 7, 173559},
	{"REPORTSTOCK", 11, 173560},
	{"LYRIDS", 6, 173561},
	{"SVETA", 5, 173562},
	{"SEGNALA", 7, 173563},
	{"REZULIN", 7, 173564},
	{"IKARI", 5, 173565},
	{"TWYLA", 5, 173566},
	{"HERFORD", 7, 173567},
	{"FABIANO", 7, 173568},
	{"CLASSIQUES", 10, 173569},
	{"ATRIZ", 5, 173570},
	{"ASTROBOY", 8, 173571},
	{"SLOUGHS", 7, 173572},
	{"CLECKHEATON", 11, 173573},
	{"CHASIN", 6, 173574},
	{"OVERSIMPLIFIED", 14, 173575},
	{"MONOBLOCK", 9, 173576},
	{"BACKSPIN", 8, 173577},
	{"RETARDER", 8, 173578},
	{"BELLHOP", 7, 173579},
	{"PHYTONUTRIENTS", 14, 173580},
	{"SPEARFISHING", 12, 173581},
	{"POPLITEAL", 9, 173582},
	{"HEDIS", 5, 173583},
	{"FLINCHED", 8, 173584},
	{"DIDA", 4, 173585},
	{"RENUKA", 6, 173586},
	{"NBMA", 4, 173587},
	{"PIXAGOGO", 8, 173588},
	{"CALIS", 5, 173589},
	{"HUMERAL", 7, 173590},
	{"MAILOUT", 7, 173591},
	{"LISTADO", 7, 173592},
	{"ROIG", 4, 173593},
	{"STURMOVIK", 9, 173594},
	{"GRATERS", 7, 173595},
	{"FOXTONS", 7, 173596},
	{"PIPECLAMP", 9, 173597},
	{"ZEER", 4, 173598},
	{"MICROMACHINING", 14, 173599},
	{"QUANTIZER", 9, 173600},
	{"DORNAN", 6, 173601},
	{"ACKGROUND", 9, 173602},
	{"NEUCHATEL", 9, 173603},
	{"LICENSABLE", 10, 173604},
	{"ELECTROCARDIOGRAPHIC", 20, 173605},
	{"ECONET", 6, 173606},
	{"SCRAPPIN", 8, 173607},
	{"RESULTATEN", 10, 173608},
	{"BOXSCORES", 9, 173609},
	{"COSMI", 5, 173610},
	{"OMPANY", 6, 173611},
	{"UNCOMPETITIVE", 13, 173612},
	{"JUGGLES", 7, 173613},
	{"BLEMISHED", 9, 173614},
	{"PACIFICATION", 12, 173615},
	{"DRUMWASTER", 10, 173616},
	{"KEIKI", 5, 173617},
	{"NITROGENOUS", 11, 173618},
	{"WINTERIZING", 11, 173619},
	{"TUDENT", 6, 173620},
	{"DESTRUCTIVENESS", 15, 173621},
	{"AACUTE", 6, 173622},
	{"YTHP", 4, 173623},
	{"YKUN", 4, 173624},
	{"YKUM", 4, 173625},
	{"XTJU", 4, 173626},
	{"TUPV", 4, 173627},
	{"SUWE", 4, 173628},
	{"SUFR", 4, 173629},
	{"RZEJ", 4, 173630},
	{"RUZT", 4, 173631},
	{"RIPG", 4, 173632},
	{"QWOU", 4, 173633},
	{"PADP", 4, 173634},
	{"OUGG", 4, 173635},
	{"OPZO", 4, 173636},
	{"ONML", 4, 173637},
	{"OEYC", 4, 173638},
	{"OCME", 4, 173639},
	{"MPBR", 4, 173640},
	{"ISRY", 4, 173641},
	{"HHUB", 4, 173642},
	{"EGUJ", 4, 173643},
	{"DIGL", 4, 173644},
	{"DFUJ", 4, 173645},
	{"COBC", 4, 173646},
	{"CHYU", 4, 173647},
	{"BVRE", 4, 173648},
	{"GANGSTAS", 8, 173649},
	{"EMUL", 4, 173650},
	{"ANSGAR", 6, 173651},
	{"MUSCULO", 7, 173652},
	{"SACKCLOTH", 9, 173653},
	{"WAAAY", 5, 173654},
	{"RIYAD", 5, 173655},
	{"RECOMMENDABLE", 13, 173656},
	{"APOSTATES", 9, 173657},
	{"DISPENSARIES", 12, 173658},
	{"PATHOLOGICALLY", 14, 173659},
	{"SMUCKER", 7, 173660},
	{"PELLETED", 8, 173661},
	{"LIBDPS", 6, 173662},
	{"ENTAMOEBA", 9, 173663},
	{"RESERVABLE", 10, 173664},
	{"ELSTREE", 7, 173665},
	{"TOTTORI", 7, 173666},
	{"REGISTERD", 9, 173667},
	{"ONOINE", 6, 173668},
	{"MIDDLEMARCH", 11, 173669},
	{"NIAMEY", 6, 173670},
	{"BREATHERS", 9, 173671},
	{"TORP", 4, 173672},
	{"MAIDAN", 6, 173673},
	{"OREL", 4, 173674},
	{"ORYCTOLAGUS", 11, 173675},
	{"AKIBA", 5, 173676},
	{"ELLSBERG", 8, 173677},
	{"CVF", 3, 173678},
	{"OSHER", 5, 173679},
	{"NNPG", 4, 173680},
	{"HEERENVEEN", 10, 173681},
	{"PHILOSPHY", 9, 173682},
	{"ENRAPTURED", 10, 173683},
	{"NEARSIGHTEDNESS", 15, 173684},
	{"MAHILA", 6, 173685},
	{"OPTIMISATIONS", 13, 173686},
	{"VPATH", 5, 173687},
	{"GRABEN", 6, 173688},
	{"SKOPELOS", 8, 173689},
	{"CYMA", 4, 173690},
	{"TATIVE", 6, 173691},
	{"AIRCONDITIONED", 14, 173692},
	{"SAROVA", 6, 173693},
	{"TECHONOLOGY", 11, 173694},
	{"NEILSEN", 7, 173695},
	{"OVERSTATING", 11, 173696},
	{"MATUR", 5, 173697},
	{"PROMASTER", 9, 173698},
	{"ARISS", 5, 173699},
	{"OVERCAPACITY", 12, 173700},
	{"CARPACCIO", 9, 173701},
	{"KNEELAND", 8, 173702},
	{"GELDINGS", 8, 173703},
	{"WHIZLABS", 8, 173704},
	{"SISKIN", 6, 173705},
	{"TANGUAY", 7, 173706},
	{"BETTANY", 7, 173707},
	{"AXOR", 4, 173708},
	{"RESUSPENSION", 12, 173709},
	{"KREIDER", 7, 173710},
	{"INDIQUE", 7, 173711},
	{"ROTFL", 5, 173712},
	{"COLLECTI", 8, 173713},
	{"MERWIMP", 7, 173714},
	{"TROTTIER", 8, 173715},
	{"JAPUNDIT", 8, 173716},
	{"BOEUF", 5, 173717},
	{"SPORTSWRITER", 12, 173718},
	{"ZMOR", 4, 173719},
	{"ZESG", 4, 173720},
	{"TCUI", 4, 173721},
	{"SOKF", 4, 173722},
	{"RRDI", 4, 173723},
	{"RAJH", 4, 173724},
	{"PMCL", 4, 173725},
	{"OPNU", 4, 173726},
	{"OICC", 4, 173727},
	{"OGOY", 4, 173728},
	{"ODIZ", 4, 173729},
	{"NAUV", 4, 173730},
	{"MMEY", 4, 173731},
	{"MAJL", 4, 173732},
	{"LYZA", 4, 173733},
	{"LAPK", 4, 173734},
	{"KADJ", 4, 173735},
	{"HFAU", 4, 173736},
	{"FLLO", 4, 173737},
	{"ESLC", 4, 173738},
	{"CIDM", 4, 173739},
	{"AUXE", 4, 173740},
	{"AUGD", 4, 173741},
	{"APJA", 4, 173742},
	{"SPRENGER", 8, 173743},
	{"VANADYL", 7, 173744},
	{"BASSLINES", 9, 173745},
	{"AMINOGLYCOSIDE", 14, 173746},
	{"NICKTOONS", 9, 173747},
	{"FAASSEN", 7, 173748},
	{"NATIONALISED", 12, 173749},
	{"FOURIE", 6, 173750},
	{"LAZO", 4, 173751},
	{"ERDOS", 5, 173752},
	{"RANGELEY", 8, 173753},
	{"CLORE", 5, 173754},
	{"BARG", 4, 173755},
	{"PRIVADO", 7, 173756},
	{"MUDSLIDE", 8, 173757},
	{"FIDGETY", 7, 173758},
	{"COLLICULUS", 10, 173759},
	{"BARROOM", 7, 173760},
	{"TRIDIAGONAL", 11, 173761},
	{"WELSCH", 6, 173762},
	{"NOVOS", 5, 173763},
	{"DOOLIN", 6, 173764},
	{"SXRD", 4, 173765},
	{"THROMBOPHLEBITIS", 16, 173766},
	{"MULTIHULL", 9, 173767},
	{"BICICLETTA", 10, 173768},
	{"CUYAMACA", 8, 173769},
	{"CHUKKA", 6, 173770},
	{"KLIEN", 5, 173771},
	{"PLTS", 4, 173772},
	{"DEVNET", 6, 173773},
	{"EXTINGUISHES", 12, 173774},
	{"EQUIVA", 6, 173775},
	{"SUNDRESS", 8, 173776},
	{"PIRANESI", 8, 173777},
	{"SWETS", 5, 173778},
	{"CCDLFLAGS", 9, 173779},
	{"CARSEATS", 8, 173780},
	{"TIGRINYA", 8, 173781},
	{"FUSSELL", 7, 173782},
	{"BACITRACIN", 10, 173783},
	{"AGRESSION", 9, 173784},
	{"TRIFORCE", 8, 173785},
	{"SPIGOTS", 7, 173786},
	{"PODHORETZ", 9, 173787},
	{"DYSLIPIDEMIA", 12, 173788},
	{"INTRIGUINGLY", 12, 173789},
	{"UKIYO", 5, 173790},
	{"PREN", 4, 173791},
	{"CEROC", 5, 173792},
	{"MUGGS", 5, 173793},
	{"HYSLOP", 6, 173794},
	{"DPUC", 4, 173795},
	{"SPAHR", 5, 173796},
	{"POGROMS", 7, 173797},
	{"VITRIFIED", 9, 173798},
	{"SOUNDMAN", 8, 173799},
	{"BURCHARD", 8, 173800},
	{"SPERMIDINE", 10, 173801},
	{"CARDFINANCELOANCREDIT", 21, 173802},
	{"SCHOOLTEACHERS", 14, 173803},
	{"DISOWN", 6, 173804},
	{"MILITARIZED", 11, 173805},
	{"HUMANITARIANS", 13, 173806},
	{"SIGNO", 5, 173807},
	{"SUPERCHUNK", 10, 173808},
	{"SONIX", 5, 173809},
	{"RECORDIST", 9, 173810},
	{"UNIMOG", 6, 173811},
	{"UNODC", 5, 173812},
	{"DAMO", 4, 173813},
	{"BUETTNER", 8, 173814},
	{"HAWKMAN", 7, 173815},
	{"GOUGED", 6, 173816},
	{"INVERELL", 8, 173817},
	{"DEHAVEN", 7, 173818},
	{"COMPUTERTALKSHOP", 16, 173819},
	{"PHENTREMINE", 11, 173820},
	{"CONNTRACK", 9, 173821},
	{"YRAZ", 4, 173822},
	{"XTGU", 4, 173823},
	{"WLEL", 4, 173824},
	{"WHUG", 4, 173825},
	{"TWYN", 4, 173826},
	{"SBNM", 4, 173827},
	{"RNKN", 4, 173828},
	{"POLU", 4, 173829},
	{"PDOF", 4, 173830},
	{"OVGE", 4, 173831},
	{"MHAC", 4, 173832},
	{"MEXG", 4, 173833},
	{"MBUK", 4, 173834},
	{"LUTR", 4, 173835},
	{"LMTI", 4, 173836},
	{"LEMJ", 4, 173837},
	{"IKOP", 4, 173838},
	{"GPAM", 4, 173839},
	{"EDPG", 4, 173840},
	{"DEZF", 4, 173841},
	{"BNUM", 4, 173842},
	{"BDIN", 4, 173843},
	{"SOPHISTRY", 9, 173844},
	{"ORRVILLE", 8, 173845},
	{"COSMETICALLY", 12, 173846},
	{"KERIK", 5, 173847},
	{"BUFFOONS", 8, 173848},
	{"STAGNATING", 10, 173849},
	{"PHREAK", 6, 173850},
	{"DOWNLOUD", 8, 173851},
	{"WIEST", 5, 173852},
	{"OXALIC", 6, 173853},
	{"TELECONVERTER", 13, 173854},
	{"ROTONDA", 7, 173855},
	{"TERPSTRA", 8, 173856},
	{"ASSOCS", 6, 173857},
	{"REDSTAR", 7, 173858},
	{"ILLUMINED", 9, 173859},
	{"FIELDERS", 8, 173860},
	{"SOFTWARECOMPUTER", 16, 173861},
	{"RAGAS", 5, 173862},
	{"MOBLE", 5, 173863},
	{"MITUTOYO", 8, 173864},
	{"LOQUITUR", 8, 173865},
	{"DOMECQ", 6, 173866},
	{"LEVELTEXT", 9, 173867},
	{"FENRIR", 6, 173868},
	{"DHCPCD", 6, 173869},
	{"CONNETICUT", 10, 173870},
	{"ROCKNE", 6, 173871},
	{"AMOROSO", 7, 173872},
	{"DISALLOWS", 9, 173873},
	{"ZAZEN", 5, 173874},
	{"MEHLIS", 6, 173875},
	{"VIAGARA", 7, 173876},
	{"BADENOCH", 8, 173877},
	{"MINATION", 8, 173878},
	{"CONCERTGEBOUW", 13, 173879},
	{"COMPREHEN", 9, 173880},
	{"AGONIZED", 8, 173881},
	{"DEFRAGMENT", 10, 173882},
	{"LIVELLO", 7, 173883},
	{"LEADTIME", 8, 173884},
	{"TMPFILE", 7, 173885},
	{"HERBARIA", 8, 173886},
	{"CEMEX", 5, 173887},
	{"SOUFRIERE", 9, 173888},
	{"PARTTIME", 8, 173889},
	{"BEWILD", 6, 173890},
	{"SINGALONG", 9, 173891},
	{"GRAFX", 5, 173892},
	{"DECONTAMINATE", 13, 173893},
	{"AMIEL", 5, 173894},
	{"SETENABLED", 10, 173895},
	{"PRANGE", 6, 173896},
	{"DURBAR", 6, 173897},
	{"NETLINE", 7, 173898},
	{"DIDS", 4, 173899},
	{"WACCAMAW", 8, 173900},
	{"OLSR", 4, 173901},
	{"PECORA", 6, 173902},
	{"BRAZENLY", 8, 173903},
	{"CASTELBAJAC", 11, 173904},
	{"OVEREXTENDED", 12, 173905},
	{"GOODCHILD", 9, 173906},
	{"LLYFRAU", 7, 173907},
	{"POWEREX", 7, 173908},
	{"RETROSPECTIVES", 14, 173909},
	{"MAUVAIS", 7, 173910},
	{"RUDA", 4, 173911},
	{"RESTRAINS", 9, 173912},
	{"POLOIDAL", 8, 173913},
	{"LEGNO", 5, 173914},
	{"GRANTORS", 8, 173915},
	{"PAGEBOOKMARK", 12, 173916},
	{"OVERSPEND", 9, 173917},
	{"NUNZIATA", 8, 173918},
	{"CELLSUIT", 8, 173919},
	{"CATECHOL", 8, 173920},
	{"PICKPOCKET", 10, 173921},
	{"TREATERS", 8, 173922},
	{"TAMALPAIS", 9, 173923},
	{"PREFFERED", 9, 173924},
	{"WUNS", 4, 173925},
	{"WRYW", 4, 173926},
	{"WCIN", 4, 173927},
	{"WBYC", 4, 173928},
	{"SLSU", 4, 173929},
	{"PGIS", 4, 173930},
	{"OXAD", 4, 173931},
	{"OEYM", 4, 173932},
	{"MRQU", 4, 173933},
	{"MNIR", 4, 173934},
	{"LAVP", 4, 173935},
	{"KYSW", 4, 173936},
	{"KGIN", 4, 173937},
	{"HBAP", 4, 173938},
	{"FTVO", 4, 173939},
	{"FNAB", 4, 173940},
	{"FGMA", 4, 173941},
	{"EPMP", 4, 173942},
	{"DGAE", 4, 173943},
	{"DAIP", 4, 173944},
	{"CURZ", 4, 173945},
	{"AQRE", 4, 173946},
	{"UNAPPROPRIATED", 14, 173947},
	{"YAPP", 4, 173948},
	{"HENDRA", 6, 173949},
	{"EARWAX", 6, 173950},
	{"CGCCC", 5, 173951},
	{"ZINTA", 5, 173952},
	{"GLUCURONIDASE", 13, 173953},
	{"WARBLING", 8, 173954},
	{"MASERS", 6, 173955},
	{"UNHURRIED", 9, 173956},
	{"SHRIVELED", 9, 173957},
	{"MACALISTER", 10, 173958},
	{"ANTHRACNOSE", 11, 173959},
	{"FRACTIOUS", 9, 173960},
	{"BARNSTEAD", 9, 173961},
	{"ANNMARIE", 8, 173962},
	{"ZCATALOG", 8, 173963},
	{"FLORIDAUSA", 10, 173964},
	{"DSUS", 4, 173965},
	{"DISRUPTORS", 10, 173966},
	{"CONVE", 5, 173967},
	{"COLORJET", 8, 173968},
	{"CONFORMABLE", 11, 173969},
	{"TOOTHY", 6, 173970},
	{"PREDICATION", 11, 173971},
	{"PFEIL", 5, 173972},
	{"SHIPSTORE", 9, 173973},
	{"DDX", 3, 173974},
	{"IMPRISONING", 11, 173975},
	{"CHEESECLOTH", 11, 173976},
	{"IQAIR", 5, 173977},
	{"INCONGRUITY", 11, 173978},
	{"FORMULARIES", 11, 173979},
	{"OSTEOPOROTIC", 12, 173980},
	{"USELESSLY", 9, 173981},
	{"EVALUATABLE", 11, 173982},
	{"CITYNET", 7, 173983},
	{"ARCHAMBAULT", 11, 173984},
	{"BRAZED", 6, 173985},
	{"STANDLEY", 8, 173986},
	{"INTROSPECTOR", 12, 173987},
	{"VIDCAPS", 7, 173988},
	{"TRIBUTIONS", 10, 173989},
	{"TUTSIS", 6, 173990},
	{"ESPECIES", 8, 173991},
	{"EQUIREMENTS", 11, 173992},
	{"QUINNY", 6, 173993},
	{"GALLANTLY", 9, 173994},
	{"ATUTOR", 6, 173995},
	{"VAUDREUIL", 9, 173996},
	{"PAINFULL", 8, 173997},
	{"PHILIPPS", 8, 173998},
	{"PIEZAS", 6, 173999},
	{"COEFS", 5, 174000},
	{"COBE", 4, 174001},
	{"PREJUDGMENT", 11, 174002},
	{"RESONABLE", 9, 174003},
	{"REFORMULATE", 11, 174004},
	{"OKUDA", 5, 174005},
	{"ILLUMINATORS", 12, 174006},
	{"SUNCORP", 7, 174007},
	{"EARTHMAN", 8, 174008},
	{"ULAMA", 5, 174009},
	{"SEAQUEST", 8, 174010},
	{"ECTODERM", 8, 174011},
	{"SPORTSMANS", 10, 174012},
	{"PLANETES", 8, 174013},
	{"BENDED", 6, 174014},
	{"FRAGRANCED", 10, 174015},
	{"SYSTAT", 6, 174016},
	{"ROIMHE", 6, 174017},
	{"DRANG", 5, 174018},
	{"QUITTERS", 8, 174019},
	{"LINYANTI", 8, 174020},
	{"LDDLFLAGS", 9, 174021},
	{"MULTILINGUALISM", 15, 174022},
	{"KSIMUS", 6, 174023},
	{"SWANZEY", 7, 174024},
	{"TAINMENT", 8, 174025},
	{"SABRINE", 7, 174026},
	{"KEMCO", 5, 174027},
	{"DOLLARIZATION", 13, 174028},
	{"DISBELIEVERS", 12, 174029},
	{"YUIC", 4, 174030},
	{"UTZW", 4, 174031},
	{"UAVI", 4, 174032},
	{"TBIP", 4, 174033},
	{"SMTV", 4, 174034},
	{"ROLJ", 4, 174035},
	{"NYBM", 4, 174036},
	{"NGUZ", 4, 174037},
	{"NAKK", 4, 174038},
	{"MKEV", 4, 174039},
	{"LHEJ", 4, 174040},
	{"LEVT", 4, 174041},
	{"KOAR", 4, 174042},
	{"KALG", 4, 174043},
	{"IXVE", 4, 174044},
	{"HEBG", 4, 174045},
	{"GHYS", 4, 174046},
	{"GGEE", 4, 174047},
	{"FPOD", 4, 174048},
	{"EZSU", 4, 174049},
	{"ENWY", 4, 174050},
	{"EKVO", 4, 174051},
	{"DIYY", 4, 174052},
	{"DEYS", 4, 174053},
	{"CGUN", 4, 174054},
	{"BUGO", 4, 174055},
	{"AYUD", 4, 174056},
	{"TILLERY", 7, 174057},
	{"WOLDS", 5, 174058},
	{"MOUTHGUARD", 10, 174059},
	{"LESEDI", 6, 174060},
	{"INCRIMINATE", 11, 174061},
	{"DUNNETT", 7, 174062},
	{"ABERFOYLE", 9, 174063},
	{"MILGROM", 7, 174064},
	{"KAZUYA", 6, 174065},
	{"NUDGES", 6, 174066},
	{"LEVELNUMBERS", 12, 174067},
	{"OSTEOCLASTS", 11, 174068},
	{"MORET", 5, 174069},
	{"GCCVERSION", 10, 174070},
	{"BUSWAY", 6, 174071},
	{"BUESCHER", 8, 174072},
	{"HABITUS", 7, 174073},
	{"GROOVIE", 7, 174074},
	{"SHENKER", 7, 174075},
	{"ENJOI", 5, 174076},
	{"PORC", 4, 174077},
	{"AIRC", 4, 174078},
	{"XMIT", 4, 174079},
	{"MWB", 3, 174080},
	{"COLLABORATIVES", 14, 174081},
	{"WAUPUN", 6, 174082},
	{"MEGABUCKS", 9, 174083},
	{"MENSAH", 6, 174084},
	{"DROPPERS", 8, 174085},
	{"SINEX", 5, 174086},
	{"SCAREY", 6, 174087},
	{"POIGNANTLY", 10, 174088},
	{"FLUORANTHENE", 12, 174089},
	{"MEDIUMSHIP", 10, 174090},
	{"OMIDYAR", 7, 174091},
	{"DEPOPULATION", 12, 174092},
	{"UNTIRING", 8, 174093},
	{"LIBGPG", 6, 174094},
	{"WYRM", 4, 174095},
	{"COMBUSTIBLES", 12, 174096},
	{"CHANNELNEWSASIA", 15, 174097},
	{"KHAM", 4, 174098},
	{"BENVENUTI", 9, 174099},
	{"BAWDEN", 6, 174100},
	{"DIPLOMATIQUE", 12, 174101},
	{"HOSTELRY", 8, 174102},
	{"SLUMBERS", 8, 174103},
	{"HANGE", 5, 174104},
	{"MISAKI", 6, 174105},
	{"FORFEITING", 10, 174106},
	{"DIWRNOD", 7, 174107},
	{"REDFEATHER", 10, 174108},
	{"MECHANIZE", 9, 174109},
	{"VOLKS", 5, 174110},
	{"ENSCF", 5, 174111},
	{"SUBTIDAL", 8, 174112},
	{"KEMPO", 5, 174113},
	{"BEIRA", 5, 174114},
	{"BRER", 4, 174115},
	{"ZAIDI", 5, 174116},
	{"UMRA", 4, 174117},
	{"EXPELS", 6, 174118},
	{"DOMENIC", 7, 174119},
	{"FERTIG", 6, 174120},
	{"ZEIGER", 6, 174121},
	{"KUNDAN", 6, 174122},
	{"BWR", 3, 174123},
	{"HUMPHRY", 7, 174124},
	{"SEEDBED", 7, 174125},
	{"NEOPET", 6, 174126},
	{"BASCO", 5, 174127},
	{"CONSOLIDATIONFREE", 17, 174128},
	{"TOTALEMENT", 10, 174129},
	{"CATANZARO", 9, 174130},
	{"FRYSTYK", 7, 174131},
	{"COARSENING", 10, 174132},
	{"ANTIINFLAMMATORY", 16, 174133},
	{"TIONARY", 7, 174134},
	{"SAHUARITA", 9, 174135},
	{"NUMBERLESS", 10, 174136},
	{"ADDLESTONE", 10, 174137},
	{"INTITULED", 9, 174138},
	{"YZEI", 4, 174139},
	{"XKNO", 4, 174140},
	{"XIMS", 4, 174141},
	{"WLSS", 4, 174142},
	{"VEZT", 4, 174143},
	{"UTTP", 4, 174144},
	{"TOMZ", 4, 174145},
	{"TMFT", 4, 174146},
	{"TABF", 4, 174147},
	{"SYGE", 4, 174148},
	{"SDRB", 4, 174149},
	{"RZAP", 4, 174150},
	{"RDEJ", 4, 174151},
	{"PFLU", 4, 174152},
	{"PEEM", 4, 174153},
	{"ORFH", 4, 174154},
	{"NTVR", 4, 174155},
	{"MOMF", 4, 174156},
	{"MMDI", 4, 174157},
	{"LBWA", 4, 174158},
	{"LAFC", 4, 174159},
	{"KJEL", 4, 174160},
	{"HURJ", 4, 174161},
	{"GFIB", 4, 174162},
	{"GARJ", 4, 174163},
	{"EPVI", 4, 174164},
	{"EGYN", 4, 174165},
	{"DROK", 4, 174166},
	{"DHRU", 4, 174167},
	{"DDNO", 4, 174168},
	{"CSVE", 4, 174169},
	{"BKIT", 4, 174170},
	{"ANZW", 4, 174171},
	{"AMNW", 4, 174172},
	{"AJEL", 4, 174173},
	{"MINARD", 6, 174174},
	{"BIZOPPS", 7, 174175},
	{"INTEMPERANCE", 12, 174176},
	{"DHLWSEIS", 8, 174177},
	{"VALUECLICK", 10, 174178},
	{"PROTOPLASTS", 11, 174179},
	{"PYFTPD", 6, 174180},
	{"TWILA", 5, 174181},
	{"MURR", 4, 174182},
	{"FONSI", 5, 174183},
	{"MATHLINKS", 9, 174184},
	{"COUNTEREXAMPLES", 15, 174185},
	{"PEMEX", 5, 174186},
	{"MARLEEN", 7, 174187},
	{"ICTURES", 7, 174188},
	{"NAVAS", 5, 174189},
	{"BELIN", 5, 174190},
	{"ULLADULLA", 9, 174191},
	{"USBID", 5, 174192},
	{"BHATTACHARYYA", 13, 174193},
	{"WINEX", 5, 174194},
	{"PROSIECT", 8, 174195},
	{"INFOTEC", 7, 174196},
	{"SUBMERGENCE", 11, 174197},
	{"MACINNES", 8, 174198},
	{"TAXCO", 5, 174199},
	{"MANKO", 5, 174200},
	{"BHAKTIVEDANTA", 13, 174201},
	{"EAVESDROPPER", 12, 174202},
	{"LISTERINE", 9, 174203},
	{"BRIERE", 6, 174204},
	{"FULLERS", 7, 174205},
	{"PENNINES", 8, 174206},
	{"VISNETIC", 8, 174207},
	{"TOWBARS", 7, 174208},
	{"THOUS", 5, 174209},
	{"DITKA", 5, 174210},
	{"HARBHAJAN", 9, 174211},
	{"PERPETUA", 8, 174212},
	{"STRATEGIZING", 12, 174213},
	{"MELCO", 5, 174214},
	{"CHARADRIUS", 10, 174215},
	{"PSTRICKS", 8, 174216},
	{"PISCATAQUIS", 11, 174217},
	{"WOODSTOVE", 9, 174218},
	{"PHYTOREMEDIATION", 16, 174219},
	{"EXPANSIONIST", 12, 174220},
	{"GENCON", 6, 174221},
	{"PRINTSERVER", 11, 174222},
	{"CASSIDEY", 8, 174223},
	{"MAECUFF", 7, 174224},
	{"DEFINITENESS", 12, 174225},
	{"ISELLSURPLUS", 12, 174226},
	{"VASED", 5, 174227},
	{"SATEL", 5, 174228},
	{"REPROVED", 8, 174229},
	{"NUMERATION", 10, 174230},
	{"LATAM", 5, 174231},
	{"INTERLEAGUE", 11, 174232},
	{"ALEXANDROV", 10, 174233},
	{"SULFA", 5, 174234},
	{"PRIVATION", 9, 174235},
	{"EQUIS", 5, 174236},
	{"ALRESFORD", 9, 174237},
	{"DEFINTION", 9, 174238},
	{"YLYC", 4, 174239},
	{"XFAI", 4, 174240},
	{"WSLU", 4, 174241},
	{"WPUL", 4, 174242},
	{"WMIX", 4, 174243},
	{"UCOO", 4, 174244},
	{"SULG", 4, 174245},
	{"SLUP", 4, 174246},
	{"SJUB", 4, 174247},
	{"PODN", 4, 174248},
	{"OYBI", 4, 174249},
	{"LYUB", 4, 174250},
	{"LOOW", 4, 174251},
	{"LFEU", 4, 174252},
	{"IDYF", 4, 174253},
	{"HSFU", 4, 174254},
	{"HEFG", 4, 174255},
	{"HAVL", 4, 174256},
	{"GUIM", 4, 174257},
	{"GTVA", 4, 174258},
	{"GGIB", 4, 174259},
	{"FIDL", 4, 174260},
	{"EVAJ", 4, 174261},
	{"EPAJ", 4, 174262},
	{"EMAQ", 4, 174263},
	{"DSOQ", 4, 174264},
	{"CUCH", 4, 174265},
	{"BHIG", 4, 174266},
	{"BBYN", 4, 174267},
	{"ATRD", 4, 174268},
	{"REPTON", 6, 174269},
	{"ECCENTRICS", 10, 174270},
	{"VISUALISING", 11, 174271},
	{"OLIVARES", 8, 174272},
	{"VERTICLE", 8, 174273},
	{"ALAIKUM", 7, 174274},
	{"LAMESA", 6, 174275},
	{"FORGIVABLE", 10, 174276},
	{"CENTRATION", 10, 174277},
	{"ONDAATJE", 8, 174278},
	{"KINOKUNIYA", 10, 174279},
	{"TECHDIS", 7, 174280},
	{"RAVALLI", 7, 174281},
	{"GRIMACED", 8, 174282},
	{"WESTEN", 6, 174283},
	{"CCAS", 4, 174284},
	{"LAMKIN", 6, 174285},
	{"DIVISIVENESS", 12, 174286},
	{"WYLUG", 5, 174287},
	{"NAYARIT", 7, 174288},
	{"CALCS", 5, 174289},
	{"SCOTER", 6, 174290},
	{"CASTELLA", 8, 174291},
	{"BRUNETTI", 8, 174292},
	{"BABAK", 5, 174293},
	{"PROTRUDES", 9, 174294},
	{"LEGITIMIZED", 11, 174295},
	{"KEOHANE", 7, 174296},
	{"PEEVISH", 7, 174297},
	{"MODETHREADED", 12, 174298},
	{"MUSCI", 5, 174299},
	{"TAPIO", 5, 174300},
	{"LBG", 3, 174301},
	{"DIPEPTIDE", 9, 174302},
	{"MICKAEL", 7, 174303},
	{"HIGBEE", 6, 174304},
	{"TECHNOLOGI", 10, 174305},
	{"CREMAX", 6, 174306},
	{"LAMIA", 5, 174307},
	{"SIMIEN", 6, 174308},
	{"PEDAGOGUE", 9, 174309},
	{"VISONIK", 7, 174310},
	{"HUSKIE", 6, 174311},
	{"SPLASHDOWN", 10, 174312},
	{"ALECIA", 6, 174313},
	{"GODOY", 5, 174314},
	{"SOOTHSAYER", 10, 174315},
	{"NAJIB", 5, 174316},
	{"MARIUSZ", 7, 174317},
	{"SEALABLE", 8, 174318},
	{"TUROW", 5, 174319},
	{"KANYA", 5, 174320},
	{"RAADT", 5, 174321},
	{"UNIPHASE", 8, 174322},
	{"FACINGS", 7, 174323},
	{"MULTIFORM", 9, 174324},
	{"SITERING", 8, 174325},
	{"NORDIN", 6, 174326},
	{"THANGS", 6, 174327},
	{"DOUBLESIZE", 10, 174328},
	{"IPEX", 4, 174329},
	{"USEMYMALLOC", 11, 174330},
	{"APPLIQUED", 9, 174331},
	{"RECETA", 6, 174332},
	{"PERCUSSIONISTS", 14, 174333},
	{"MONTRES", 7, 174334},
	{"LAMPANG", 7, 174335},
	{"SOSUA", 5, 174336},
	{"COMPLUTENSE", 11, 174337},
	{"UNMAPPED", 8, 174338},
	{"PIATTI", 6, 174339},
	{"MORADABAD", 9, 174340},
	{"SUNITA", 6, 174341},
	{"DEMONIZING", 10, 174342},
	{"BOALT", 5, 174343},
	{"HARDWARES", 9, 174344},
	{"YKOV", 4, 174345},
	{"XBEI", 4, 174346},
	{"WGIL", 4, 174347},
	{"VYMO", 4, 174348},
	{"UDUM", 4, 174349},
	{"TZKR", 4, 174350},
	{"TOGY", 4, 174351},
	{"TEUL", 4, 174352},
	{"RRSS", 4, 174353},
	{"RBOV", 4, 174354},
	{"ORPY", 4, 174355},
	{"OMZI", 4, 174356},
	{"OJIR", 4, 174357},
	{"NUXF", 4, 174358},
	{"NTZU", 4, 174359},
	{"NDTK", 4, 174360},
	{"MPJO", 4, 174361},
	{"MAEU", 4, 174362},
	{"KSGL", 4, 174363},
	{"KISY", 4, 174364},
	{"KIMY", 4, 174365},
	{"ITUB", 4, 174366},
	{"GMAB", 4, 174367},
	{"GBUZ", 4, 174368},
	{"FSOB", 4, 174369},
	{"FSEB", 4, 174370},
	{"EVFO", 4, 174371},
	{"ESDV", 4, 174372},
	{"ENZC", 4, 174373},
	{"ECCT", 4, 174374},
	{"BRUY", 4, 174375},
	{"BJRK", 4, 174376},
	{"AZWH", 4, 174377},
	{"AXAP", 4, 174378},
	{"AVKA", 4, 174379},
	{"ATGW", 4, 174380},
	{"MARIC", 5, 174381},
	{"STARCITYGAMES", 13, 174382},
	{"PEUPLE", 6, 174383},
	{"CARBERRY", 8, 174384},
	{"DESCANSO", 8, 174385},
	{"SPURTING", 8, 174386},
	{"WAITSTAFF", 9, 174387},
	{"HERCULANEUM", 11, 174388},
	{"AXTON", 5, 174389},
	{"WASIM", 5, 174390},
	{"SQUARESOFT", 10, 174391},
	{"VXR", 3, 174392},
	{"SIRAH", 5, 174393},
	{"SAALE", 5, 174394},
	{"MMUG", 4, 174395},
	{"HIGHGEAR", 8, 174396},
	{"SPECTROM", 8, 174397},
	{"CUTZ", 4, 174398},
	{"CARTHAGINIANS", 13, 174399},
	{"REIMANN", 7, 174400},
	{"MANIN", 5, 174401},
	{"LACKLUSTRE", 10, 174402},
	{"LAVERTON", 8, 174403},
	{"SAMPLINGS", 9, 174404},
	{"NODAWAY", 7, 174405},
	{"FLORI", 5, 174406},
	{"GORM", 4, 174407},
	{"CONSTITU", 8, 174408},
	{"URLENCODE", 9, 174409},
	{"SOCIAUX", 7, 174410},
	{"MONKEYPOX", 9, 174411},
	{"ROSMAN", 6, 174412},
	{"IMPRO", 5, 174413},
	{"ROSYTH", 6, 174414},
	{"LESNAR", 6, 174415},
	{"RESCINDING", 10, 174416},
	{"RANTINGPROFS", 12, 174417},
	{"HRITHIK", 7, 174418},
	{"FILMIC", 6, 174419},
	{"MILITARE", 8, 174420},
	{"HERSHEL", 7, 174421},
	{"ESURANCE", 8, 174422},
	{"WATCHMAKERS", 11, 174423},
	{"SOHODECOR", 9, 174424},
	{"MFB", 3, 174425},
	{"NONFOOD", 7, 174426},
	{"FASTTRAK", 8, 174427},
	{"MICHELINE", 9, 174428},
	{"CDDA", 4, 174429},
	{"TATTON", 6, 174430},
	{"INDELIBLY", 9, 174431},
	{"MICROWORLD", 10, 174432},
	{"OVERREPRESENTED", 15, 174433},
	{"APHELION", 8, 174434},
	{"CHASIS", 6, 174435},
	{"NICKLAS", 7, 174436},
	{"HOMEPORT", 8, 174437},
	{"STAKEOUT", 8, 174438},
	{"LFB", 3, 174439},
	{"REDKNAPP", 8, 174440},
	{"PEKAR", 5, 174441},
	{"REZENSENT", 9, 174442},
	{"AMIKA", 5, 174443},
	{"XWRA", 4, 174444},
	{"DECRYING", 8, 174445},
	{"PERTURB", 7, 174446},
	{"SYMBOLISE", 9, 174447},
	{"ISTORY", 6, 174448},
	{"JARRY", 5, 174449},
	{"THIEU", 5, 174450},
	{"FAXBACK", 7, 174451},
	{"ZUCH", 4, 174452},
	{"YTHY", 4, 174453},
	{"XCOA", 4, 174454},
	{"WLSF", 4, 174455},
	{"UDVI", 4, 174456},
	{"TMLI", 4, 174457},
	{"TMAF", 4, 174458},
	{"RMRH", 4, 174459},
	{"PCPR", 4, 174460},
	{"OWLN", 4, 174461},
	{"OMCK", 4, 174462},
	{"NIMF", 4, 174463},
	{"MNPR", 4, 174464},
	{"LVDI", 4, 174465},
	{"LFSL", 4, 174466},
	{"LEBC", 4, 174467},
	{"IDZI", 4, 174468},
	{"GWWW", 4, 174469},
	{"GEXO", 4, 174470},
	{"GBYK", 4, 174471},
	{"FDEU", 4, 174472},
	{"EDFT", 4, 174473},
	{"CNNF", 4, 174474},
	{"CKOI", 4, 174475},
	{"BOZA", 4, 174476},
	{"AJLI", 4, 174477},
	{"CMAN", 4, 174478},
	{"BOUWER", 6, 174479},
	{"GONER", 5, 174480},
	{"WEAVINGS", 8, 174481},
	{"FILLCOLOR", 9, 174482},
	{"CATCODE", 7, 174483},
	{"KILCHER", 7, 174484},
	{"FRAZETTA", 8, 174485},
	{"BIGCHEESE", 9, 174486},
	{"SUBMERSION", 10, 174487},
	{"FECTED", 6, 174488},
	{"NUXE", 4, 174489},
	{"MONOPOLES", 9, 174490},
	{"CHAIT", 5, 174491},
	{"CENTERFORCE", 11, 174492},
	{"RECONFIRMATION", 14, 174493},
	{"BEUYS", 5, 174494},
	{"OVERPRESSURE", 12, 174495},
	{"MARKOVIC", 8, 174496},
	{"PRESENTI", 8, 174497},
	{"SIGNIFICA", 9, 174498},
	{"NANSEN", 6, 174499},
	{"FUNKTIONEN", 10, 174500},
	{"BLACKMORES", 10, 174501},
	{"STAIRMASTER", 11, 174502},
	{"ICEY", 4, 174503},
	{"EICHHORN", 8, 174504},
	{"FREAKSHOW", 9, 174505},
	{"VICIA", 5, 174506},
	{"CEPENDANT", 9, 174507},
	{"SIGNIFIER", 9, 174508},
	{"TRAUMATOLOGY", 12, 174509},
	{"GEEZERS", 7, 174510},
	{"CRUELTIES", 9, 174511},
	{"STEIG", 5, 174512},
	{"RBG", 3, 174513},
	{"UNINVOLVED", 10, 174514},
	{"SUGARFREE", 9, 174515},
	{"EQUANT", 6, 174516},
	{"MARIGOT", 7, 174517},
	{"PIMENTA", 7, 174518},
	{"KISSEL", 6, 174519},
	{"NNPGX", 5, 174520},
	{"FRYEBURG", 8, 174521},
	{"PSNR", 4, 174522},
	{"NASTIER", 7, 174523},
	{"DILEMA", 6, 174524},
	{"DALLAGLIO", 9, 174525},
	{"ROHTAK", 6, 174526},
	{"PRODUKTEN", 9, 174527},
	{"WEBATTACK", 9, 174528},
	{"FLORESVILLE", 11, 174529},
	{"PICARESQUE", 10, 174530},
	{"CCSE", 4, 174531},
	{"DOLLIE", 6, 174532},
	{"WILLACY", 7, 174533},
	{"BRITANNIQUE", 11, 174534},
	{"UNSEREN", 7, 174535},
	{"THROTTLES", 9, 174536},
	{"SYNODS", 6, 174537},
	{"PHOSPHIDE", 9, 174538},
	{"MAILRINGS", 9, 174539},
	{"DIGICO", 6, 174540},
	{"CADENCES", 8, 174541},
	{"FUNKMASTER", 10, 174542},
	{"XLAT", 4, 174543},
	{"XANY", 4, 174544},
	{"WMEI", 4, 174545},
	{"WJES", 4, 174546},
	{"VYSM", 4, 174547},
	{"VETB", 4, 174548},
	{"UGAG", 4, 174549},
	{"UBEX", 4, 174550},
	{"SLBS", 4, 174551},
	{"RYDY", 4, 174552},
	{"ORCZ", 4, 174553},
	{"OFUJ", 4, 174554},
	{"NYUT", 4, 174555},
	{"KSIW", 4, 174556},
	{"KAAD", 4, 174557},
	{"IXGU", 4, 174558},
	{"HYCU", 4, 174559},
	{"HAVU", 4, 174560},
	{"GUIC", 4, 174561},
	{"FIME", 4, 174562},
	{"FCPR", 4, 174563},
	{"FANV", 4, 174564},
	{"ERJP", 4, 174565},
	{"EPAX", 4, 174566},
	{"EKMF", 4, 174567},
	{"DFOD", 4, 174568},
	{"DBCE", 4, 174569},
	{"CTAY", 4, 174570},
	{"CLAL", 4, 174571},
	{"CKIV", 4, 174572},
	{"BYCN", 4, 174573},
	{"BSPU", 4, 174574},
	{"APFU", 4, 174575},
	{"AALG", 4, 174576},
	{"CILT", 4, 174577},
	{"FLUKES", 6, 174578},
	{"CHEOL", 5, 174579},
	{"LAMERS", 6, 174580},
	{"GOBACK", 6, 174581},
	{"CRYPTOSYSTEMS", 13, 174582},
	{"BELCOURT", 8, 174583},
	{"GELLING", 7, 174584},
	{"UUNNIIVVEERRSSIITTYY", 20, 174585},
	{"SLAVISH", 7, 174586},
	{"MIRAI", 5, 174587},
	{"PEARY", 5, 174588},
	{"PRESENTENCE", 11, 174589},
	{"ODILE", 5, 174590},
	{"SWCD", 4, 174591},
	{"RECUEIL", 7, 174592},
	{"JURADO", 6, 174593},
	{"BAWLING", 7, 174594},
	{"XDELTA", 6, 174595},
	{"FLYBOOK", 7, 174596},
	{"MASARYK", 7, 174597},
	{"FBG", 3, 174598},
	{"SEDAR", 5, 174599},
	{"ORGONE", 6, 174600},
	{"AWESTRUCK", 9, 174601},
	{"SANGYEDOLMA", 11, 174602},
	{"BOZMAN", 6, 174603},
	{"BOSAK", 5, 174604},
	{"BLUER", 5, 174605},
	{"RACEMOSA", 8, 174606},
	{"CONCESSIONAIRES", 15, 174607},
	{"AFRICANUS", 9, 174608},
	{"TRANSFEREES", 11, 174609},
	{"PAUN", 4, 174610},
	{"NUTRICOLOGY", 11, 174611},
	{"FELICITOUS", 10, 174612},
	{"MACEDO", 6, 174613},
	{"WHITMER", 7, 174614},
	{"OUTGUNNED", 9, 174615},
	{"DUTRA", 5, 174616},
	{"RPCS", 4, 174617},
	{"GWC", 3, 174618},
	{"WDG", 3, 174619},
	{"LINGWOOD", 8, 174620},
	{"BOTHAM", 6, 174621},
	{"GETCWD", 6, 174622},
	{"SUTURING", 8, 174623},
	{"CHADS", 5, 174624},
	{"CARAVEL", 7, 174625},
	{"OCCOQUAN", 8, 174626},
	{"BEQUIA", 6, 174627},
	{"QUICKY", 6, 174628},
	{"MARLETTE", 8, 174629},
	{"ENDSTREAM", 9, 174630},
	{"CALLES", 6, 174631},
	{"SKUESPILLER", 11, 174632},
	{"OVERCLOCKER", 11, 174633},
	{"NECROMANCY", 10, 174634},
	{"DONAU", 5, 174635},
	{"PLAUDITS", 8, 174636},
	{"WENDLAND", 8, 174637},
	{"SCHOONERS", 9, 174638},
	{"MYCKET", 6, 174639},
	{"GLYCAEMIC", 9, 174640},
	{"GARANTIERTE", 11, 174641},
	{"CHACUN", 6, 174642},
	{"APROTININ", 9, 174643},
	{"SEVRES", 6, 174644},
	{"MURZYNKI", 8, 174645},
	{"OJLINE", 6, 174646},
	{"MYSTIFY", 7, 174647},
	{"DLEXT", 5, 174648},
	{"NATIVIDAD", 9, 174649},
	{"TULIA", 5, 174650},
	{"REMISSIONS", 10, 174651},
	{"ISCRIZIONE", 10, 174652},
	{"POREC", 5, 174653},
	{"KALOS", 5, 174654},
	{"ORKING", 6, 174655},
	{"EKPROSWPOS", 10, 174656},
	{"SKYWATCH", 8, 174657},
	{"SUREMENTS", 9, 174658},
	{"MOWGLI", 6, 174659},
	{"ZBAS", 4, 174660},
	{"XITC", 4, 174661},
	{"WIIV", 4, 174662},
	{"VCAS", 4, 174663},
	{"UUPT", 4, 174664},
	{"TCZE", 4, 174665},
	{"SYAW", 4, 174666},
	{"SSPM", 4, 174667},
	{"SMUE", 4, 174668},
	{"SBNF", 4, 174669},
	{"RYUM", 4, 174670},
	{"RPAA", 4, 174671},
	{"QIFR", 4, 174672},
	{"PMEO", 4, 174673},
	{"OVOB", 4, 174674},
	{"NPPT", 4, 174675},
	{"NDRZ", 4, 174676},
	{"MBSL", 4, 174677},
	{"LVEV", 4, 174678},
	{"LUZH", 4, 174679},
	{"LHAK", 4, 174680},
	{"LDUG", 4, 174681},
	{"HFIC", 4, 174682},
	{"HAZM", 4, 174683},
	{"GMRE", 4, 174684},
	{"EPVE", 4, 174685},
	{"DEFJ", 4, 174686},
	{"TORCS", 5, 174687},
	{"REGOLITH", 8, 174688},
	{"CUSD", 4, 174689},
	{"SERG", 4, 174690},
	{"PEMPHIGUS", 9, 174691},
	{"CXL", 3, 174692},
	{"POSITING", 8, 174693},
	{"FILTON", 6, 174694},
	{"ROUGHY", 6, 174695},
	{"LORIENT", 7, 174696},
	{"SINOPEC", 7, 174697},
	{"NIPC", 4, 174698},
	{"JOHNSONGRASS", 12, 174699},
	{"RCG", 3, 174700},
	{"MADERO", 6, 174701},
	{"GEFILMT", 7, 174702},
	{"DEMANDER", 8, 174703},
	{"WENIGER", 7, 174704},
	{"BAME", 4, 174705},
	{"PILTON", 6, 174706},
	{"PERSONALSS", 10, 174707},
	{"ECKHARD", 7, 174708},
	{"EADY", 4, 174709},
	{"BIBER", 5, 174710},
	{"DUSTBUSTER", 10, 174711},
	{"MENTHA", 6, 174712},
	{"SEKUNDEN", 8, 174713},
	{"RESISTENCE", 10, 174714},
	{"DOIRON", 6, 174715},
	{"ELTERN", 6, 174716},
	{"LOCALIZES", 9, 174717},
	{"BESPACIFIC", 10, 174718},
	{"WDB", 3, 174719},
	{"PUTCHAR", 7, 174720},
	{"NIRMALA", 7, 174721},
	{"DAMMAM", 6, 174722},
	{"CHEMUSA", 7, 174723},
	{"NACHBARIN", 9, 174724},
	{"EPERM", 5, 174725},
	{"TORNEO", 6, 174726},
	{"SPRINGHOUSE", 11, 174727},
	{"DESKBAR", 7, 174728},
	{"STREAKER", 8, 174729},
	{"SHILLS", 6, 174730},
	{"SARVER", 6, 174731},
	{"ROEBLING", 8, 174732},
	{"VARDEN", 6, 174733},
	{"DNAJ", 4, 174734},
	{"XMLNODE", 7, 174735},
	{"BLW", 3, 174736},
	{"UNDERACHIEVEMENT", 16, 174737},
	{"TRILOBITE", 9, 174738},
	{"NESAF", 5, 174739},
	{"ADEPTS", 6, 174740},
	{"LOGP", 4, 174741},
	{"GEOSYNCHRONOUS", 14, 174742},
	{"SOPHISTICATE", 12, 174743},
	{"PANK", 4, 174744},
	{"YOPY", 4, 174745},
	{"MULLION", 7, 174746},
	{"STIGMATIZATION", 14, 174747},
	{"CONTROLING", 10, 174748},
	{"ZIEMBA", 6, 174749},
	{"TYSABRI", 7, 174750},
	{"INCAPACITATING", 14, 174751},
	{"FABRA", 5, 174752},
	{"PLAYERDVD", 9, 174753},
	{"MARGINALIA", 10, 174754},
	{"CUNICULUS", 9, 174755},
	{"MAJORLY", 7, 174756},
	{"MYNAME", 6, 174757},
	{"REMIXER", 7, 174758},
	{"WNEU", 4, 174759},
	{"URBC", 4, 174760},
	{"UHLA", 4, 174761},
	{"SPIF", 4, 174762},
	{"RWEK", 4, 174763},
	{"RONQ", 4, 174764},
	{"PGON", 4, 174765},
	{"OVTR", 4, 174766},
	{"ORRW", 4, 174767},
	{"OMRP", 4, 174768},
	{"NUSJ", 4, 174769},
	{"NDRL", 4, 174770},
	{"MNUC", 4, 174771},
	{"LKOP", 4, 174772},
	{"KAIP", 4, 174773},
	{"HPIG", 4, 174774},
	{"HOMJ", 4, 174775},
	{"GIJU", 4, 174776},
	{"FYEV", 4, 174777},
	{"FEUE", 4, 174778},
	{"EZDA", 4, 174779},
	{"TERAHERTZ", 9, 174780},
	{"SAVON", 5, 174781},
	{"HAPLOGROUP", 10, 174782},
	{"CASSY", 5, 174783},
	{"CCCDLFLAGS", 10, 174784},
	{"DFDS", 4, 174785},
	{"THERIAULT", 9, 174786},
	{"GANDA", 5, 174787},
	{"GRADINGS", 8, 174788},
	{"MARLEE", 6, 174789},
	{"ZETIA", 5, 174790},
	{"LOBS", 4, 174791},
	{"RIBEYE", 6, 174792},
	{"BRZ", 3, 174793},
	{"SOAPMAKING", 10, 174794},
	{"BANDIDAS", 8, 174795},
	{"MONOVALENT", 10, 174796},
	{"MEENAKSHI", 9, 174797},
	{"ZUMWALT", 7, 174798},
	{"SRINIVASA", 9, 174799},
	{"UNCROWDED", 9, 174800},
	{"REKHTER", 7, 174801},
	{"FAIZ", 4, 174802},
	{"WAEL", 4, 174803},
	{"REVITALISATION", 14, 174804},
	{"GIFLIB", 6, 174805},
	{"ISAMU", 5, 174806},
	{"SNOOD", 5, 174807},
	{"MORPHIC", 7, 174808},
	{"GRUDEN", 6, 174809},
	{"BALEARICS", 9, 174810},
	{"ESTATAL", 7, 174811},
	{"HARDBOILED", 10, 174812},
	{"POLANDBORDERSURNAMES", 20, 174813},
	{"NAAFI", 5, 174814},
	{"TANTEK", 6, 174815},
	{"CLEFTS", 6, 174816},
	{"TRION", 5, 174817},
	{"QUICKEYS", 8, 174818},
	{"FONTOPIA", 8, 174819},
	{"HELIANTHUS", 10, 174820},
	{"UNFORGETABLE", 12, 174821},
	{"JOGS", 4, 174822},
	{"KAMPPETER", 9, 174823},
	{"OSSEOUS", 7, 174824},
	{"SUBER", 5, 174825},
	{"HONORIFIC", 9, 174826},
	{"KAMELEON", 8, 174827},
	{"LOITA", 5, 174828},
	{"HAHAHAHAHAHA", 12, 174829},
	{"DENDROICA", 9, 174830},
	{"PAPROCKI", 8, 174831},
	{"PELZ", 4, 174832},
	{"UWHARRIE", 8, 174833},
	{"MPIRUN", 6, 174834},
	{"ELBRIDGE", 8, 174835},
	{"MACHOL", 6, 174836},
	{"KAPITAL", 7, 174837},
	{"DWEUD", 5, 174838},
	{"UNDERHAND", 9, 174839},
	{"NICKENT", 7, 174840},
	{"MERAMEC", 7, 174841},
	{"CAPEVERDE", 9, 174842},
	{"TARGUM", 6, 174843},
	{"SOPHIST", 7, 174844},
	{"HAIKUS", 6, 174845},
	{"RETROACTIVITY", 13, 174846},
	{"KINGSBURG", 9, 174847},
	{"METLOX", 6, 174848},
	{"COOLANTS", 8, 174849},
	{"FLOWERGIRL", 10, 174850},
	{"ASSISTENZA", 10, 174851},
	{"WACS", 4, 174852},
	{"YDLO", 4, 174853},
	{"XTUN", 4, 174854},
	{"XOWN", 4, 174855},
	{"WEGM", 4, 174856},
	{"WDSE", 4, 174857},
	{"URGK", 4, 174858},
	{"ULUB", 4, 174859},
	{"UEYA", 4, 174860},
	{"PIRY", 4, 174861},
	{"PACF", 4, 174862},
	{"OZOL", 4, 174863},
	{"OCYA", 4, 174864},
	{"MMCO", 4, 174865},
	{"MLEM", 4, 174866},
	{"KLOD", 4, 174867},
	{"HYRS", 4, 174868},
	{"HLUX", 4, 174869},
	{"HKAY", 4, 174870},
	{"GXIN", 4, 174871},
	{"GGUT", 4, 174872},
	{"GDPT", 4, 174873},
	{"EMGL", 4, 174874},
	{"DGIU", 4, 174875},
	{"CRUA", 4, 174876},
	{"CGUY", 4, 174877},
	{"BYUC", 4, 174878},
	{"AMYN", 4, 174879},
	{"ACIU", 4, 174880},
	{"TASKMASTER", 10, 174881},
	{"GIGUERE", 7, 174882},
	{"ELFEN", 5, 174883},
	{"CARRYFORWARD", 12, 174884},
	{"HEIMAT", 6, 174885},
	{"LEAFING", 7, 174886},
	{"STIKFAS", 7, 174887},
	{"SAPONINS", 8, 174888},
	{"BANKI", 5, 174889},
	{"SHEPHERDSVILLE", 14, 174890},
	{"ANSWERBANK", 10, 174891},
	{"MICRODIA", 8, 174892},
	{"ELWES", 5, 174893},
	{"IDOLATROUS", 10, 174894},
	{"SECUNDUM", 8, 174895},
	{"SLUGGED", 7, 174896},
	{"USBOOKS", 7, 174897},
	{"TRED", 4, 174898},
	{"WHATSNEW", 8, 174899},
	{"TRANSLATABLE", 12, 174900},
	{"ERKKI", 5, 174901},
	{"WIKICULTURE", 11, 174902},
	{"USCENSUS", 8, 174903},
	{"SEPRACOR", 8, 174904},
	{"RICCARTON", 9, 174905},
	{"CYHOEDDIADAU", 12, 174906},
	{"SMOULDERING", 11, 174907},
	{"KIDDOS", 6, 174908},
	{"ICDS", 4, 174909},
	{"DLSRC", 5, 174910},
	{"ANGIOEDEMA", 10, 174911},
	{"PETRARCH", 8, 174912},
	{"DEMETRIOU", 9, 174913},
	{"HAMMAM", 6, 174914},
	{"BOATENG", 7, 174915},
	{"TRADESPEOPLE", 12, 174916},
	{"MICROTOUCH", 10, 174917},
	{"TATSUO", 6, 174918},
	{"SAUR", 4, 174919},
	{"SURANCE", 7, 174920},
	{"JOHANNESEN", 10, 174921},
	{"INBOARDS", 8, 174922},
	{"UNTERSUCHUNG", 12, 174923},
	{"MERLO", 5, 174924},
	{"MALTI", 5, 174925},
	{"INTEMPO", 7, 174926},
	{"REDACTION", 9, 174927},
	{"POLYTHEISM", 10, 174928},
	{"ULRIKA", 6, 174929},
	{"PARTHASARATHY", 13, 174930},
	{"RESOR", 5, 174931},
	{"DURABRAND", 9, 174932},
	{"BODLEY", 6, 174933},
	{"USEPERLIO", 9, 174934},
	{"VARIAS", 6, 174935},
	{"ASHURST", 7, 174936},
	{"DEERWOOD", 8, 174937},
	{"MAUPASSANT", 10, 174938},
	{"USBC", 4, 174939},
	{"ETHNOLOGICAL", 12, 174940},
	{"VOCABULARIO", 11, 174941},
	{"SUBSILVER", 9, 174942},
	{"LONGSIZE", 8, 174943},
	{"GLOGLE", 6, 174944},
	{"WEBTECH", 7, 174945},
	{"GETHEIGHT", 9, 174946},
	{"REVELLERS", 9, 174947},
	{"HIGHSCORE", 9, 174948},
	{"FRASERBURGH", 11, 174949},
	{"LINKSLINKS", 10, 174950},
	{"BLUEWAVESTUDIOS", 15, 174951},
	{"MIDGES", 6, 174952},
	{"SHENZHOU", 8, 174953},
	{"BIVY", 4, 174954},
	{"VSOR", 4, 174955},
	{"UFAX", 4, 174956},
	{"UEOB", 4, 174957},
	{"UDDT", 4, 174958},
	{"PODM", 4, 174959},
	{"PHSR", 4, 174960},
	{"OARW", 4, 174961},
	{"NYSQ", 4, 174962},
	{"NAKM", 4, 174963},
	{"MSNU", 4, 174964},
	{"MFAU", 4, 174965},
	{"LKYC", 4, 174966},
	{"KYRU", 4, 174967},
	{"KPOU", 4, 174968},
	{"KDIG", 4, 174969},
	{"JAPO", 4, 174970},
	{"IGKE", 4, 174971},
	{"IAUG", 4, 174972},
	{"GWEK", 4, 174973},
	{"GDAO", 4, 174974},
	{"FKET", 4, 174975},
	{"FFOA", 4, 174976},
	{"EEFM", 4, 174977},
	{"DZOE", 4, 174978},
	{"CYSD", 4, 174979},
	{"BECP", 4, 174980},
	{"BCAU", 4, 174981},
	{"REBUFF", 6, 174982},
	{"HIPPOCRATIC", 11, 174983},
	{"HONGO", 5, 174984},
	{"OURSE", 5, 174985},
	{"SERVITA", 7, 174986},
	{"BIOCHIP", 7, 174987},
	{"USESHRPLIB", 10, 174988},
	{"WEYRICH", 7, 174989},
	{"SOFFT", 5, 174990},
	{"HIRSCHMAN", 9, 174991},
	{"PUROLATOR", 9, 174992},
	{"CHEOPS", 6, 174993},
	{"BUNGA", 5, 174994},
	{"EPAPER", 6, 174995},
	{"AVAIBLE", 7, 174996},
	{"AMEEN", 5, 174997},
	{"MEROS", 5, 174998},
	{"APPELLATIONS", 12, 174999},
	{"STOKELY", 7, 175000},
	{"GLOBALIST", 9, 175001},
	{"MALACHY", 7, 175002},
	{"MARMION", 7, 175003},
	{"BOONDOGGLE", 10, 175004},
	{"SUBCARRIER", 10, 175005},
	{"GOJO", 4, 175006},
	{"DESMET", 6, 175007},
	{"DISCUSION", 9, 175008},
	{"FEATHERLITE", 11, 175009},
	{"DRAUGHTSMAN", 11, 175010},
	{"QUITCLAIM", 9, 175011},
	{"PONAPE", 6, 175012},
	{"HEMAGGLUTINATION", 16, 175013},
	{"EGNOS", 5, 175014},
	{"SPOLSKY", 7, 175015},
	{"INTERES", 7, 175016},
	{"MARYHILL", 8, 175017},
	{"BOULET", 6, 175018},
	{"LGV", 3, 175019},
	{"CANDYLAND", 9, 175020},
	{"VERANDAS", 8, 175021},
	{"NIENTE", 6, 175022},
	{"SAFFIR", 6, 175023},
	{"BORRELL", 7, 175024},
	{"BEGAWAN", 7, 175025},
	{"PSYCHEDELLIC", 12, 175026},
	{"SPENCERVILLE", 12, 175027},
	{"SEVIN", 5, 175028},
	{"EUTAW", 5, 175029},
	{"BALLOONED", 9, 175030},
	{"KALLISTI", 8, 175031},
	{"SCREENCASTS", 11, 175032},
	{"KOVALEV", 7, 175033},
	{"COLORI", 6, 175034},
	{"CLUBZONE", 8, 175035},
	{"VALKYRIES", 9, 175036},
	{"TRAVELHOTEL", 11, 175037},
	{"LNER", 4, 175038},
	{"LEBIH", 5, 175039},
	{"TECHNOCRATIC", 12, 175040},
	{"ADDSLASHES", 10, 175041},
	{"BOOKFELLAS", 10, 175042},
	{"FREESPEAK", 9, 175043},
	{"NANOOSE", 7, 175044},
	{"DOCSTRING", 9, 175045},
	{"LEACOCK", 7, 175046},
	{"REESTABLISHMENT", 15, 175047},
	{"ARCACHON", 8, 175048},
	{"ANNOUCE", 7, 175049},
	{"SAGETV", 6, 175050},
	{"AIML", 4, 175051},
	{"ANGSTY", 6, 175052},
	{"ELIOTT", 6, 175053},
	{"SIKORA", 6, 175054},
	{"SHOOTOUTS", 9, 175055},
	{"SUKHOI", 6, 175056},
	{"MULI", 4, 175057},
	{"YASUSHI", 7, 175058},
	{"PUBBLICO", 8, 175059},
	{"GASPER", 6, 175060},
	{"MEDIDAS", 7, 175061},
	{"ZZOI", 4, 175062},
	{"YMOA", 4, 175063},
	{"XVOL", 4, 175064},
	{"WDGA", 4, 175065},
	{"RZAW", 4, 175066},
	{"RIHU", 4, 175067},
	{"PTVE", 4, 175068},
	{"PBSI", 4, 175069},
	{"OKGI", 4, 175070},
	{"NIUK", 4, 175071},
	{"MLAF", 4, 175072},
	{"GUOD", 4, 175073},
	{"FOSW", 4, 175074},
	{"CTZO", 4, 175075},
	{"CFUL", 4, 175076},
	{"CEXH", 4, 175077},
	{"BIUM", 4, 175078},
	{"BCAD", 4, 175079},
	{"AQWE", 4, 175080},
	{"KUOMINTANG", 10, 175081},
	{"VERSURI", 7, 175082},
	{"LIBBONOBOUI", 11, 175083},
	{"KAFE", 4, 175084},
	{"NATIONJOB", 9, 175085},
	{"DEPALMA", 7, 175086},
	{"GASIFIER", 8, 175087},
	{"BIRLEY", 6, 175088},
	{"CANET", 5, 175089},
	{"ALLISTON", 8, 175090},
	{"PONTI", 5, 175091},
	{"KANGOO", 6, 175092},
	{"IMRAY", 5, 175093},
	{"TAISHO", 6, 175094},
	{"RAYBESTOS", 9, 175095},
	{"ALIGNBYTES", 10, 175096},
	{"CYTOKERATIN", 11, 175097},
	{"CARDD", 5, 175098},
	{"GRINGOS", 7, 175099},
	{"ZELLERS", 7, 175100},
	{"LAURSEN", 7, 175101},
	{"STIMPSON", 8, 175102},
	{"FLAVONOID", 9, 175103},
	{"PINDAR", 6, 175104},
	{"JASONS", 6, 175105},
	{"SPALL", 5, 175106},
	{"TOURISTER", 9, 175107},
	{"OTOLARYNGOLOGISTS", 17, 175108},
	{"NATUROPATHS", 11, 175109},
	{"IGCC", 4, 175110},
	{"SHENK", 5, 175111},
	{"ONLJNE", 6, 175112},
	{"EXPANSIONARY", 12, 175113},
	{"DARKMAN", 7, 175114},
	{"ACARI", 5, 175115},
	{"PUBCON", 6, 175116},
	{"DORNOCH", 7, 175117},
	{"CBMS", 4, 175118},
	{"DALSTON", 7, 175119},
	{"ZINDA", 5, 175120},
	{"PTRSIZE", 7, 175121},
	{"MARIED", 6, 175122},
	{"BLUEHOST", 8, 175123},
	{"INCIDENTLY", 10, 175124},
	{"HINTZ", 5, 175125},
	{"LEEDOM", 6, 175126},
	{"ALLDATA", 7, 175127},
	{"SICILIANO", 9, 175128},
	{"MLADEN", 6, 175129},
	{"ISCARIOT", 8, 175130},
	{"HARAHAN", 7, 175131},
	{"HEDDON", 6, 175132},
	{"CAERLEON", 8, 175133},
	{"ANGWIN", 6, 175134},
	{"BURGENLAND", 10, 175135},
	{"BOMBAST", 7, 175136},
	{"UNERASE", 7, 175137},
	{"HINCHINBROOK", 12, 175138},
	{"ZYKLON", 6, 175139},
	{"WOMBATS", 7, 175140},
	{"SUBDIVIDING", 11, 175141},
	{"CATBIRD", 7, 175142},
	{"SOYEZ", 5, 175143},
	{"HASSOCKS", 8, 175144},
	{"FREESTYLER", 10, 175145},
	{"ALANNAH", 7, 175146},
	{"SUSCRIBE", 8, 175147},
	{"LCFG", 4, 175148},
	{"ERCIM", 5, 175149},
	{"CALD", 4, 175150},
	{"LORSCH", 6, 175151},
	{"BATEAUX", 7, 175152},
	{"KCNA", 4, 175153},
	{"DOWAGIAC", 8, 175154},
	{"GYRA", 4, 175155},
	{"DEREGULATE", 10, 175156},
	{"PATCHKRAFT", 10, 175157},
	{"PEARLE", 6, 175158},
	{"SOMENTE", 7, 175159},
	{"REUSCH", 6, 175160},
	{"WYAHOO", 6, 175161},
	{"MICROBREWERY", 12, 175162},
	{"IMPOUNDING", 10, 175163},
	{"REALNAME", 8, 175164},
	{"IMPULSIVELY", 11, 175165},
	{"ZAPS", 4, 175166},
	{"MVB", 3, 175167},
	{"BLABLA", 6, 175168},
	{"LIFERAFT", 8, 175169},
	{"CUARTO", 6, 175170},
	{"BLACKDOWN", 9, 175171},
	{"WNAY", 4, 175172},
	{"WKNE", 4, 175173},
	{"VPRI", 4, 175174},
	{"VOVE", 4, 175175},
	{"VODS", 4, 175176},
	{"TYUM", 4, 175177},
	{"RUYA", 4, 175178},
	{"RUKE", 4, 175179},
	{"PPEG", 4, 175180},
	{"PMEG", 4, 175181},
	{"PLCI", 4, 175182},
	{"OXAV", 4, 175183},
	{"OMHZ", 4, 175184},
	{"NIRW", 4, 175185},
	{"ISGY", 4, 175186},
	{"ISCG", 4, 175187},
	{"IBAP", 4, 175188},
	{"IAGG", 4, 175189},
	{"GIOB", 4, 175190},
	{"FFKA", 4, 175191},
	{"FEID", 4, 175192},
	{"DDAE", 4, 175193},
	{"CYSB", 4, 175194},
	{"CUSJ", 4, 175195},
	{"BYRS", 4, 175196},
	{"BUGW", 4, 175197},
	{"AWOV", 4, 175198},
	{"DIVEMASTER", 10, 175199},
	{"AGRON", 5, 175200},
	{"GIGGLY", 6, 175201},
	{"GRANTH", 6, 175202},
	{"CHIPLEY", 7, 175203},
	{"TTAERROR", 8, 175204},
	{"NOGAMI", 6, 175205},
	{"MOYE", 4, 175206},
	{"PAPAKURA", 8, 175207},
	{"LACP", 4, 175208},
	{"WARIOWARE", 9, 175209},
	{"INVERTORS", 9, 175210},
	{"TREADER", 7, 175211},
	{"TUSKER", 6, 175212},
	{"DEMAG", 5, 175213},
	{"GOVIND", 6, 175214},
	{"CODESOURCERY", 12, 175215},
	{"OFFSHOOTS", 9, 175216},
	{"GIUSTO", 6, 175217},
	{"BTCC", 4, 175218},
	{"DIRECTSOUND", 11, 175219},
	{"MILCH", 5, 175220},
	{"INTRASPECIFIC", 13, 175221},
	{"IVIG", 4, 175222},
	{"KLAVIER", 7, 175223},
	{"MACINTEL", 8, 175224},
	{"ARLEY", 5, 175225},
	{"SILBERMOND", 10, 175226},
	{"BELSON", 6, 175227},
	{"SCREWPULL", 9, 175228},
	{"KIMMI", 5, 175229},
	{"KNLINE", 6, 175230},
	{"HLDGS", 5, 175231},
	{"DANNIL", 6, 175232},
	{"AIDC", 4, 175233},
	{"TEENMODEL", 9, 175234},
	{"DEVELOPABLE", 11, 175235},
	{"GICS", 4, 175236},
	{"RECH", 4, 175237},
	{"CHARADES", 8, 175238},
	{"VIALTA", 6, 175239},
	{"MOULINS", 7, 175240},
	{"CANALETTO", 9, 175241},
	{"YAQUI", 5, 175242},
	{"RICHIESTA", 9, 175243},
	{"BONDSMEN", 8, 175244},
	{"CANASTOTA", 9, 175245},
	{"KITTRELL", 8, 175246},
	{"DEPREDATIONS", 12, 175247},
	{"FINDHERE", 8, 175248},
	{"WIKITRAVEL", 10, 175249},
	{"LAER", 4, 175250},
	{"ENFOCUS", 7, 175251},
	{"AANMELDEN", 9, 175252},
	{"BIBLIOTEK", 9, 175253},
	{"ATTRIBUTEERROR", 14, 175254},
	{"GODSKITCHEN", 11, 175255},
	{"SPYRUS", 6, 175256},
	{"ROXAS", 5, 175257},
	{"DECILES", 7, 175258},
	{"JIMG", 4, 175259},
	{"PANGASINAN", 10, 175260},
	{"KOSNIK", 6, 175261},
	{"ENGVALL", 7, 175262},
	{"DOWNLOAS", 8, 175263},
	{"ROSEMAN", 7, 175264},
	{"WINCANTON", 9, 175265},
	{"YMWH", 4, 175266},
	{"YGHA", 4, 175267},
	{"XMUL", 4, 175268},
	{"XELO", 4, 175269},
	{"XAUT", 4, 175270},
	{"SVSC", 4, 175271},
	{"OMRC", 4, 175272},
	{"NUEJ", 4, 175273},
	{"MNMA", 4, 175274},
	{"LKUM", 4, 175275},
	{"KMYC", 4, 175276},
	{"IEWK", 4, 175277},
	{"IBMT", 4, 175278},
	{"GYJO", 4, 175279},
	{"FKYL", 4, 175280},
	{"EBBH", 4, 175281},
	{"DFOA", 4, 175282},
	{"DBMW", 4, 175283},
	{"CAHY", 4, 175284},
	{"AKIV", 4, 175285},
	{"POCKETMEDIA", 11, 175286},
	{"HIZBALLAH", 9, 175287},
	{"VULNWATCH", 9, 175288},
	{"RAPAMYCIN", 9, 175289},
	{"NONFUNCTIONAL", 13, 175290},
	{"NOVOGEN", 7, 175291},
	{"HAWKSBILL", 9, 175292},
	{"SLIC", 4, 175293},
	{"AVOIDANT", 8, 175294},
	{"TORTOISESHELL", 13, 175295},
	{"DEWS", 4, 175296},
	{"USEPOSIX", 8, 175297},
	{"MICRODEVICES", 12, 175298},
	{"GAZZA", 5, 175299},
	{"HOTELOPIA", 9, 175300},
	{"MOBILEPHONE", 11, 175301},
	{"KALT", 4, 175302},
	{"BAGHOUSE", 8, 175303},
	{"MOLLOHAN", 8, 175304},
	{"LEBO", 4, 175305},
	{"INSYNC", 6, 175306},
	{"DALTREY", 7, 175307},
	{"CRICKLEWOOD", 11, 175308},
	{"TRAPPE", 6, 175309},
	{"PEDICLE", 7, 175310},
	{"DIAMINE", 7, 175311},
	{"RAMSBOTTOM", 10, 175312},
	{"BALCONETTE", 10, 175313},
	{"TEMERITY", 8, 175314},
	{"SUPERCONTIG", 11, 175315},
	{"LIBDEM", 6, 175316},
	{"HEARTLIGHT", 10, 175317},
	{"COLLUSIVE", 9, 175318},
	{"MCROBERTS", 9, 175319},
	{"CROSSDRESS", 10, 175320},
	{"ATLARGE", 7, 175321},
	{"FERT", 4, 175322},
	{"HANDELS", 7, 175323},
	{"RWP", 3, 175324},
	{"NETREG", 6, 175325},
	{"UNDERSTUDY", 10, 175326},
	{"UNAMORTIZED", 11, 175327},
	{"DECISIS", 7, 175328},
	{"OROPHARYNGEAL", 13, 175329},
	{"MANISTIQUE", 10, 175330},
	{"ALAC", 4, 175331},
	{"MLLE", 4, 175332},
	{"BROGDEN", 7, 175333},
	{"SVEIN", 5, 175334},
	{"NIPON", 5, 175335},
	{"BRUMBIES", 8, 175336},
	{"GESENDET", 8, 175337},
	{"LYRCIS", 6, 175338},
	{"PLACENCIA", 9, 175339},
	{"TRYPTIC", 7, 175340},
	{"CHAITANYA", 9, 175341},
	{"TOWELLING", 9, 175342},
	{"ELUDING", 7, 175343},
	{"ADVENTITIOUS", 12, 175344},
	{"MEMCACHE", 8, 175345},
	{"ZEAXANTHIN", 10, 175346},
	{"HIMAGE", 6, 175347},
	{"LELIA", 5, 175348},
	{"KITANA", 6, 175349},
	{"KAHIT", 5, 175350},
	{"INTERDIT", 8, 175351},
	{"ALLOYED", 7, 175352},
	{"ALAB", 4, 175353},
	{"ANAESTHESIOLOGY", 15, 175354},
	{"INTERGLACIAL", 12, 175355},
	{"FAMIGLIE", 8, 175356},
	{"HOREHOUND", 9, 175357},
	{"SANKYO", 6, 175358},
	{"NORTHCENTRAL", 12, 175359},
	{"SPARKES", 7, 175360},
	{"BARMAID", 7, 175361},
	{"QML", 3, 175362},
	{"POTENTIATED", 11, 175363},
	{"WEENIES", 7, 175364},
	{"XCRO", 4, 175365},
	{"UYJU", 4, 175366},
	{"UKEV", 4, 175367},
	{"UGEY", 4, 175368},
	{"UCAH", 4, 175369},
	{"TUEF", 4, 175370},
	{"SHUJ", 4, 175371},
	{"RWAH", 4, 175372},
	{"RFFA", 4, 175373},
	{"POGL", 4, 175374},
	{"OLZI", 4, 175375},
	{"OFHB", 4, 175376},
	{"LYTV", 4, 175377},
	{"LILJ", 4, 175378},
	{"LFIW", 4, 175379},
	{"KSOY", 4, 175380},
	{"IZAP", 4, 175381},
	{"IVGA", 4, 175382},
	{"GIDB", 4, 175383},
	{"FURW", 4, 175384},
	{"EUWH", 4, 175385},
	{"DUKU", 4, 175386},
	{"CHUW", 4, 175387},
	{"BJAN", 4, 175388},
	{"BILC", 4, 175389},
	{"ABVI", 4, 175390},
	{"FINACIAL", 8, 175391},
	{"MOSSE", 5, 175392},
	{"CHONDRITES", 10, 175393},
	{"CORKED", 6, 175394},
	{"CHUY", 4, 175395},
	{"NLINES", 6, 175396},
	{"KULIK", 5, 175397},
	{"DELUGED", 7, 175398},
	{"ALGOR", 5, 175399},
	{"SMUD", 4, 175400},
	{"NUDEWOMEN", 9, 175401},
	{"HARTOG", 6, 175402},
	{"STORMI", 6, 175403},
	{"FLEECY", 6, 175404},
	{"PHOTOGRAPHIES", 13, 175405},
	{"TURKCE", 6, 175406},
	{"DINKINS", 7, 175407},
	{"LATVISKI", 8, 175408},
	{"SWICKI", 6, 175409},
	{"STANWYCK", 8, 175410},
	{"RAVO", 4, 175411},
	{"HIRAI", 5, 175412},
	{"ORBIFOLD", 8, 175413},
	{"SHOKO", 5, 175414},
	{"MXM", 3, 175415},
	{"TIPLE", 5, 175416},
	{"LUCKED", 6, 175417},
	{"WALDENBOOKS", 11, 175418},
	{"SPOSATO", 7, 175419},
	{"ACGME", 5, 175420},
	{"YSHOO", 5, 175421},
	{"INSOLVENCIES", 12, 175422},
	{"ABACA", 5, 175423},
	{"IMPERIALE", 9, 175424},
	{"MICROFILTER", 11, 175425},
	{"BREY", 4, 175426},
	{"ASIATISCHE", 10, 175427},
	{"HETEROSKEDASTICITY", 18, 175428},
	{"QUINTETS", 8, 175429},
	{"CRIN", 4, 175430},
	{"SHYNE", 5, 175431},
	{"REBOUNDERS", 10, 175432},
	{"BERGERE", 7, 175433},
	{"DRAO", 4, 175434},
	{"KPNX", 4, 175435},
	{"INHERITANCES", 12, 175436},
	{"BEKKER", 6, 175437},
	{"ADOLESC", 7, 175438},
	{"AFMA", 4, 175439},
	{"YCHWANEGOL", 10, 175440},
	{"FANELLI", 7, 175441},
	{"PEFORMANCE", 10, 175442},
	{"NEWDOW", 6, 175443},
	{"YAYOI", 5, 175444},
	{"KOSKIN", 6, 175445},
	{"PYROGRAPHY", 10, 175446},
	{"MCGUFFEY", 8, 175447},
	{"CYFEIRIAD", 9, 175448},
	{"DDOTS", 5, 175449},
	{"LOCKERROOM", 10, 175450},
	{"OZONA", 5, 175451},
	{"OSSETT", 6, 175452},
	{"VENEZIANO", 9, 175453},
	{"NEWSNET", 7, 175454},
	{"BIETEN", 6, 175455},
	{"SKYWORTH", 8, 175456},
	{"MDADM", 5, 175457},
	{"ANTELOPES", 9, 175458},
	{"SSOCIATION", 10, 175459},
	{"SCREENCAST", 10, 175460},
	{"FANTACY", 7, 175461},
	{"YAAR", 4, 175462},
	{"MCKECHNIE", 9, 175463},
	{"EXOSKELETON", 11, 175464},
	{"FLUNK", 5, 175465},
	{"CATUS", 5, 175466},
	{"ZWG", 3, 175467},
	{"ZBJ", 3, 175468},
	{"XJD", 3, 175469},
	{"XDQ", 3, 175470},
	{"WYQ", 3, 175471},
	{"WQV", 3, 175472},
	{"VZB", 3, 175473},
	{"VQC", 3, 175474},
	{"UFQ", 3, 175475},
	{"QMQ", 3, 175476},
	{"PVZ", 3, 175477},
	{"MJX", 3, 175478},
	{"LQK", 3, 175479},
	{"KZX", 3, 175480},
	{"KPQ", 3, 175481},
	{"JXR", 3, 175482},
	{"GVZ", 3, 175483},
	{"DZQ", 3, 175484},
	{"BQJ", 3, 175485},
	{"OUTPUTFILE", 10, 175486},
	{"LEYDIG", 6, 175487},
	{"WACONIA", 7, 175488},
	{"TERRITORIALITY", 14, 175489},
	{"KOINONIA", 8, 175490},
	{"GWM", 3, 175491},
	{"BIGAMY", 6, 175492},
	{"AMSCO", 5, 175493},
	{"GAUDIO", 6, 175494},
	{"DISSAPPOINTED", 13, 175495},
	{"XTBY", 4, 175496},
	{"VARP", 4, 175497},
	{"VADU", 4, 175498},
	{"RNDB", 4, 175499},
	{"RISZ", 4, 175500},
	{"REOX", 4, 175501},
	{"RECM", 4, 175502},
	{"RAIY", 4, 175503},
	{"QUAV", 4, 175504},
	{"ONYY", 4, 175505},
	{"NWEY", 4, 175506},
	{"NMRH", 4, 175507},
	{"LJIN", 4, 175508},
	{"JEEL", 4, 175509},
	{"GAAF", 4, 175510},
	{"EMNC", 4, 175511},
	{"DPRY", 4, 175512},
	{"DETM", 4, 175513},
	{"DDLO", 4, 175514},
	{"CNEV", 4, 175515},
	{"AIMG", 4, 175516},
	{"AFBE", 4, 175517},
	{"FRWY", 4, 175518},
	{"KIBAKI", 6, 175519},
	{"EXEMPLAIRE", 10, 175520},
	{"BOOTSTRAPS", 10, 175521},
	{"DAUB", 4, 175522},
	{"PAEAN", 5, 175523},
	{"BFGF", 4, 175524},
	{"THORAZINE", 9, 175525},
	{"VELVIA", 6, 175526},
	{"BLUMENAUER", 10, 175527},
	{"LITTLEROCK", 10, 175528},
	{"UNANSWERABLE", 12, 175529},
	{"DARKENS", 7, 175530},
	{"MCCANTS", 7, 175531},
	{"IGARASHI", 8, 175532},
	{"EXCELLENCIES", 12, 175533},
	{"BARNETTE", 8, 175534},
	{"AMASA", 5, 175535},
	{"HOLISM", 6, 175536},
	{"JERKER", 6, 175537},
	{"TALEN", 5, 175538},
	{"KEVEN", 5, 175539},
	{"ARCHSTONE", 9, 175540},
	{"RANCILIO", 8, 175541},
	{"RAJAGOPALAN", 11, 175542},
	{"BACIO", 5, 175543},
	{"CAHABA", 6, 175544},
	{"SCHNEIDERMAN", 12, 175545},
	{"EMPIRIC", 7, 175546},
	{"STRAHL", 6, 175547},
	{"REJESTRACJA", 11, 175548},
	{"NAZARBAYEV", 10, 175549},
	{"HIZBOLLAH", 9, 175550},
	{"GLOBETROTTING", 13, 175551},
	{"DERON", 5, 175552},
	{"CARRAGEENAN", 11, 175553},
	{"VERSUFFIX", 9, 175554},
	{"OUNDLE", 6, 175555},
	{"LACTOCOCCUS", 11, 175556},
	{"JORAN", 5, 175557},
	{"NATURESERVE", 11, 175558},
	{"HADLOCK", 7, 175559},
	{"GOTDOTNET", 9, 175560},
	{"NSLP", 4, 175561},
	{"CALPUNDIT", 9, 175562},
	{"INDIETRO", 8, 175563},
	{"ELLINGSON", 9, 175564},
	{"GRUBE", 5, 175565},
	{"CARETTA", 7, 175566},
	{"EXPERTOS", 8, 175567},
	{"SOCIETA", 7, 175568},
	{"ZINNI", 5, 175569},
	{"WUNUSED", 7, 175570},
	{"ELNORA", 6, 175571},
	{"COOLEDIT", 8, 175572},
	{"TURBOT", 6, 175573},
	{"WORMERS", 7, 175574},
	{"LOOKOUTS", 8, 175575},
	{"GARNOME", 7, 175576},
	{"RENORMALIZED", 12, 175577},
	{"NEXTWAVE", 8, 175578},
	{"GIRDWOOD", 8, 175579},
	{"KORO", 4, 175580},
	{"SEABORNE", 8, 175581},
	{"KCB", 3, 175582},
	{"FISHBEIN", 8, 175583},
	{"FATTORIA", 8, 175584},
	{"SUMMONSES", 9, 175585},
	{"SYMMETRIX", 9, 175586},
	{"KARNS", 5, 175587},
	{"CRISTI", 6, 175588},
	{"WRAPABLES", 9, 175589},
	{"FLUXUS", 6, 175590},
	{"LAMBRO", 6, 175591},
	{"GEDICHT", 7, 175592},
	{"BPRO", 4, 175593},
	{"TABLEMOUNTING", 13, 175594},
	{"SULAIMAN", 8, 175595},
	{"INTIMIDATOR", 11, 175596},
	{"BETTENCOURT", 11, 175597},
	{"ATQUE", 5, 175598},
	{"WMATA", 5, 175599},
	{"BOMAR", 5, 175600},
	{"UNTAINTED", 9, 175601},
	{"HANUKAH", 7, 175602},
	{"DISORIENTING", 12, 175603},
	{"WIAC", 4, 175604},
	{"LORIA", 5, 175605},
	{"CARBAMOYL", 9, 175606},
	{"LONGLONGSIZE", 12, 175607},
	{"BROGLIE", 7, 175608},
	{"BADAL", 5, 175609},
	{"MADAMA", 6, 175610},
	{"WICKERSHAM", 10, 175611},
	{"REDEVELOPING", 12, 175612},
	{"OTTMAR", 6, 175613},
	{"EIGENSCHAFTEN", 13, 175614},
	{"CONTENDERE", 10, 175615},
	{"SCRATCHER", 9, 175616},
	{"SLAYS", 5, 175617},
	{"ZMIL", 4, 175618},
	{"YUPC", 4, 175619},
	{"WVEG", 4, 175620},
	{"WLEE", 4, 175621},
	{"WIML", 4, 175622},
	{"UKIY", 4, 175623},
	{"UKAF", 4, 175624},
	{"TCDO", 4, 175625},
	{"RZHE", 4, 175626},
	{"REMF", 4, 175627},
	{"PSUF", 4, 175628},
	{"ONXP", 4, 175629},
	{"NJED", 4, 175630},
	{"MSKO", 4, 175631},
	{"MAEF", 4, 175632},
	{"IODY", 4, 175633},
	{"GSUH", 4, 175634},
	{"FYCH", 4, 175635},
	{"FUEG", 4, 175636},
	{"FSYH", 4, 175637},
	{"DLLA", 4, 175638},
	{"CYBL", 4, 175639},
	{"BYDJ", 4, 175640},
	{"AYUA", 4, 175641},
	{"AUMU", 4, 175642},
	{"AKJA", 4, 175643},
	{"KIRCH", 5, 175644},
	{"CREES", 5, 175645},
	{"FERM", 4, 175646},
	{"PIZAZZ", 6, 175647},
	{"REVERBERATE", 11, 175648},
	{"DESICCATED", 10, 175649},
	{"LAMBERTON", 9, 175650},
	{"EZTRIP", 6, 175651},
	{"AUDIOCABLEPLUG", 14, 175652},
	{"FFW", 3, 175653},
	{"CCSU", 4, 175654},
	{"WHIRRING", 8, 175655},
	{"MAILBACK", 8, 175656},
	{"FOREVERMORE", 11, 175657},
	{"CONSOMMATION", 12, 175658},
	{"AGDER", 5, 175659},
	{"BORMANN", 7, 175660},
	{"JOINTERS", 8, 175661},
	{"DAYSPRING", 9, 175662},
	{"SPECTIVELY", 10, 175663},
	{"BELZ", 4, 175664},
	{"MINISITES", 9, 175665},
	{"TAXIING", 7, 175666},
	{"TSARIST", 7, 175667},
	{"KATZMAIER", 9, 175668},
	{"FOYERS", 6, 175669},
	{"ANANAS", 6, 175670},
	{"SOURC", 5, 175671},
	{"MALMBERG", 8, 175672},
	{"MISERLY", 7, 175673},
	{"KALLIKREIN", 10, 175674},
	{"PLAYFAIR", 8, 175675},
	{"SHARABLE", 8, 175676},
	{"MONESSEN", 8, 175677},
	{"THUMBED", 7, 175678},
	{"PROTIEN", 7, 175679},
	{"WLU", 3, 175680},
	{"DEXIMAGE", 8, 175681},
	{"NOVELLI", 7, 175682},
	{"COLLEZIONE", 10, 175683},
	{"RADIOSONDE", 10, 175684},
	{"VAJA", 4, 175685},
	{"TROTH", 5, 175686},
	{"LINKABLE", 8, 175687},
	{"CONTEMPTUOUSLY", 14, 175688},
	{"TAHINI", 6, 175689},
	{"ALSTYNE", 7, 175690},
	{"TEAKWOOD", 8, 175691},
	{"ORDI", 4, 175692},
	{"TOWELETTES", 10, 175693},
	{"ASPINWALL", 9, 175694},
	{"MOISE", 5, 175695},
	{"DECOMPOSABLE", 12, 175696},
	{"SWFMOVIE", 8, 175697},
	{"FREUNDINNEN", 11, 175698},
	{"VISITANTES", 10, 175699},
	{"CONCORSO", 8, 175700},
	{"CANADAIR", 8, 175701},
	{"MURRYSVILLE", 11, 175702},
	{"DIFFERENTS", 10, 175703},
	{"DEFORD", 6, 175704},
	{"SUGARING", 8, 175705},
	{"BARATOS", 7, 175706},
	{"METAFONT", 8, 175707},
	{"WALKERVILLE", 11, 175708},
	{"MERCAPTOETHANOL", 15, 175709},
	{"BISPHOSPHONATES", 15, 175710},
	{"ANTIRETROVIRALS", 15, 175711},
	{"BHATTI", 6, 175712},
	{"KEIJI", 5, 175713},
	{"MANGLER", 7, 175714},
	{"DISTILLS", 8, 175715},
	{"DIAMONTE", 8, 175716},
	{"OBERMAN", 7, 175717},
	{"IDEOLOGUE", 9, 175718},
	{"FREQUENTING", 11, 175719},
	{"BIGLEY", 6, 175720},
	{"BANTAMS", 7, 175721},
	{"BOPCRIS", 7, 175722},
	{"VULCANS", 7, 175723},
	{"TAMIKA", 6, 175724},
	{"KPILOT", 6, 175725},
	{"ZAKIR", 5, 175726},
	{"LUCKEY", 6, 175727},
	{"FSTAT", 5, 175728},
	{"VSWO", 4, 175729},
	{"USIX", 4, 175730},
	{"RJOD", 4, 175731},
	{"RHOV", 4, 175732},
	{"REJC", 4, 175733},
	{"QICI", 4, 175734},
	{"PIMI", 4, 175735},
	{"OUDV", 4, 175736},
	{"OTCP", 4, 175737},
	{"OMPC", 4, 175738},
	{"ODMY", 4, 175739},
	{"MWOF", 4, 175740},
	{"HPRU", 4, 175741},
	{"HBYU", 4, 175742},
	{"GSIB", 4, 175743},
	{"FMYJ", 4, 175744},
	{"FESR", 4, 175745},
	{"FBUM", 4, 175746},
	{"EPIF", 4, 175747},
	{"DJUB", 4, 175748},
	{"DGLY", 4, 175749},
	{"AHPU", 4, 175750},
	{"ADTV", 4, 175751},
	{"ADIJ", 4, 175752},
	{"SEIRUS", 6, 175753},
	{"MANNES", 6, 175754},
	{"SWISSLINE", 9, 175755},
	{"VAISALA", 7, 175756},
	{"CELERITY", 8, 175757},
	{"WACKIEST", 8, 175758},
	{"FURIA", 5, 175759},
	{"GROTTOES", 8, 175760},
	{"WINTERBOURNE", 12, 175761},
	{"SPAUN", 5, 175762},
	{"PRIMORSKO", 9, 175763},
	{"THICKENER", 9, 175764},
	{"SUPERLINK", 9, 175765},
	{"ARLON", 5, 175766},
	{"NAVIGATIONACCESSORY", 19, 175767},
	{"NSURANCE", 8, 175768},
	{"MARTHE", 6, 175769},
	{"GDCM", 4, 175770},
	{"COMPARETO", 9, 175771},
	{"NRCA", 4, 175772},
	{"MILLINER", 8, 175773},
	{"HODGMAN", 7, 175774},
	{"DORRANCE", 8, 175775},
	{"CRMA", 4, 175776},
	{"POOLDAWG", 8, 175777},
	{"CEFACT", 6, 175778},
	{"CARIE", 5, 175779},
	{"LCSH", 4, 175780},
	{"GYNAECOL", 8, 175781},
	{"SEPPO", 5, 175782},
	{"BRUTALIZED", 10, 175783},
	{"SYSTEEM", 7, 175784},
	{"ALLEGORIA", 9, 175785},
	{"REINSPECTION", 12, 175786},
	{"NSWIS", 5, 175787},
	{"SHECHEM", 7, 175788},
	{"SHOBHAA", 7, 175789},
	{"KOMMA", 5, 175790},
	{"BARFORD", 7, 175791},
	{"WHITEBALANCE", 12, 175792},
	{"PUSHBACK", 8, 175793},
	{"DESEMBER", 8, 175794},
	{"ANTIPODEAN", 10, 175795},
	{"CATCHALL", 8, 175796},
	{"STERIL", 6, 175797},
	{"TWIKIFUNCMODULE", 15, 175798},
	{"RAWA", 4, 175799},
	{"LMDS", 4, 175800},
	{"SCHOMBURG", 9, 175801},
	{"ORDERNR", 7, 175802},
	{"PROTAC", 6, 175803},
	{"CCCCG", 5, 175804},
	{"INFORMATIO", 10, 175805},
	{"BLASE", 5, 175806},
	{"ISLAMOPHOBIA", 12, 175807},
	{"STUUR", 5, 175808},
	{"DEBBUGS", 7, 175809},
	{"EARLIES", 7, 175810},
	{"AVRDUDE", 7, 175811},
	{"LEVOTHYROXINE", 13, 175812},
	{"RILES", 5, 175813},
	{"ETWORK", 6, 175814},
	{"ANTIPROTON", 10, 175815},
	{"TREJO", 5, 175816},
	{"HERRENSCHMIDT", 13, 175817},
	{"SUBHUMANS", 9, 175818},
	{"STAMEN", 6, 175819},
	{"SHOPE", 5, 175820},
	{"ZUYA", 4, 175821},
	{"ZTOR", 4, 175822},
	{"UPKA", 4, 175823},
	{"UNMY", 4, 175824},
	{"TDAC", 4, 175825},
	{"SWOV", 4, 175826},
	{"RMIZ", 4, 175827},
	{"RKZO", 4, 175828},
	{"RGLY", 4, 175829},
	{"RBJO", 4, 175830},
	{"ORZU", 4, 175831},
	{"OLLV", 4, 175832},
	{"KPEE", 4, 175833},
	{"IUWA", 4, 175834},
	{"IDAX", 4, 175835},
	{"HUML", 4, 175836},
	{"HLLE", 4, 175837},
	{"GJAK", 4, 175838},
	{"GDOD", 4, 175839},
	{"DUFA", 4, 175840},
	{"DILW", 4, 175841},
	{"DEIV", 4, 175842},
	{"CHYG", 4, 175843},
	{"BDER", 4, 175844},
	{"VBPORTAL", 8, 175845},
	{"OOLTEWAH", 8, 175846},
	{"DISSENTER", 9, 175847},
	{"BRIKO", 5, 175848},
	{"FLUNKED", 7, 175849},
	{"SHABAZZ", 7, 175850},
	{"MELLIFERA", 9, 175851},
	{"RICKLES", 7, 175852},
	{"EXONERATE", 9, 175853},
	{"BUNTY", 5, 175854},
	{"SIZZLIN", 7, 175855},
	{"BAROS", 5, 175856},
	{"DLSE", 4, 175857},
	{"PHOTOPC", 7, 175858},
	{"PIOGLITAZONE", 12, 175859},
	{"NAPUS", 5, 175860},
	{"LBD", 3, 175861},
	{"JAVASERVICE", 11, 175862},
	{"WOME", 4, 175863},
	{"CHIARELLO", 9, 175864},
	{"IBERO", 5, 175865},
	{"MARMORA", 7, 175866},
	{"CACHORRO", 8, 175867},
	{"HADITHS", 7, 175868},
	{"MILGRAM", 7, 175869},
	{"TWITCHY", 7, 175870},
	{"CRECIMIENTO", 11, 175871},
	{"FAMILYS", 7, 175872},
	{"BMPR", 4, 175873},
	{"GPDF", 4, 175874},
	{"HEMORRHAGES", 11, 175875},
	{"TIMBO", 5, 175876},
	{"AMERIGO", 7, 175877},
	{"BOXEN", 5, 175878},
	{"LONGDBLSIZE", 11, 175879},
	{"FILI", 4, 175880},
	{"RIGHTED", 7, 175881},
	{"LOWDER", 6, 175882},
	{"SALONEN", 7, 175883},
	{"IRION", 5, 175884},
	{"WFALL", 5, 175885},
	{"GIMMES", 6, 175886},
	{"RVAL", 4, 175887},
	{"LAMU", 4, 175888},
	{"LAMDA", 5, 175889},
	{"INTERLAKE", 9, 175890},
	{"WHITTINGHAM", 11, 175891},
	{"SUBLICENSED", 11, 175892},
	{"YAHOOMAIL", 9, 175893},
	{"TANGENTIALLY", 12, 175894},
	{"QUIKBOOK", 8, 175895},
	{"DINARD", 6, 175896},
	{"MCGAW", 5, 175897},
	{"DRACHMA", 7, 175898},
	{"BECKIE", 6, 175899},
	{"AURIC", 5, 175900},
	{"LONGACRE", 8, 175901},
	{"KOLL", 4, 175902},
	{"GEELAN", 6, 175903},
	{"BERNARDIN", 9, 175904},
	{"EGGDEV", 6, 175905},
	{"ARAMA", 5, 175906},
	{"FBDEV", 5, 175907},
	{"ALBENZA", 7, 175908},
	{"SAYD", 4, 175909},
	{"ROPS", 4, 175910},
	{"QUINCEY", 7, 175911},
	{"ELECTROLESS", 11, 175912},
	{"ARENBERG", 8, 175913},
	{"PHENTEMINE", 10, 175914},
	{"DENERVATION", 11, 175915},
	{"ARTAUD", 6, 175916},
	{"DIGERATI", 8, 175917},
	{"ZLEP", 4, 175918},
	{"ZCLU", 4, 175919},
	{"ZAVE", 4, 175920},
	{"YAPT", 4, 175921},
	{"UNCS", 4, 175922},
	{"TMCI", 4, 175923},
	{"SMYU", 4, 175924},
	{"NKYM", 4, 175925},
	{"NECW", 4, 175926},
	{"MOMU", 4, 175927},
	{"MFEN", 4, 175928},
	{"MEZH", 4, 175929},
	{"LSUH", 4, 175930},
	{"KIRY", 4, 175931},
	{"IVAU", 4, 175932},
	{"HAGW", 4, 175933},
	{"EVJA", 4, 175934},
	{"ETYY", 4, 175935},
	{"DZAP", 4, 175936},
	{"CKMR", 4, 175937},
	{"CEOG", 4, 175938},
	{"BYUK", 4, 175939},
	{"AACW", 4, 175940},
	{"MAIRI", 5, 175941},
	{"CAUDALIE", 8, 175942},
	{"RUPAUL", 6, 175943},
	{"OVULATE", 7, 175944},
	{"LEWYS", 5, 175945},
	{"BUGGE", 5, 175946},
	{"ROYALLE", 7, 175947},
	{"TRAVAILLER", 10, 175948},
	{"KRISH", 5, 175949},
	{"RIGHTFAX", 8, 175950},
	{"LUKENS", 6, 175951},
	{"SOLITARE", 8, 175952},
	{"MALOCCLUSION", 12, 175953},
	{"LASERJETS", 9, 175954},
	{"YOGANANDA", 9, 175955},
	{"IMPERISHABLE", 12, 175956},
	{"LAUZON", 6, 175957},
	{"ISHPEMING", 9, 175958},
	{"SWINNEY", 7, 175959},
	{"RUSSOUND", 8, 175960},
	{"DEGEN", 5, 175961},
	{"EASTPAK", 7, 175962},
	{"PUPPETEERS", 10, 175963},
	{"DTIC", 4, 175964},
	{"ZIAD", 4, 175965},
	{"SOURS", 5, 175966},
	{"PPU", 3, 175967},
	{"IEICE", 5, 175968},
	{"CAILIN", 6, 175969},
	{"SPURN", 5, 175970},
	{"MAHONE", 6, 175971},
	{"ILLUMINANCE", 11, 175972},
	{"PROLIFERATOR", 12, 175973},
	{"INSTILLS", 8, 175974},
	{"MCDUFF", 6, 175975},
	{"INSOLATION", 10, 175976},
	{"SOLR", 4, 175977},
	{"AURORAS", 7, 175978},
	{"AARC", 4, 175979},
	{"HYPERSURFACE", 12, 175980},
	{"SANDRAS", 7, 175981},
	{"CUSA", 4, 175982},
	{"DYMOND", 6, 175983},
	{"FAMISHED", 8, 175984},
	{"SEPARATENESS", 12, 175985},
	{"ROMPING", 7, 175986},
	{"LIONSHARE", 9, 175987},
	{"OOZED", 5, 175988},
	{"MOLDE", 5, 175989},
	{"ANTISEMITIC", 11, 175990},
	{"FORTSON", 7, 175991},
	{"MAROCCO", 7, 175992},
	{"REBLOGGED", 9, 175993},
	{"ESCUCHAR", 8, 175994},
	{"GODWIT", 6, 175995},
	{"CARAVANE", 8, 175996},
	{"MATUREWOMEN", 11, 175997},
	{"JOANA", 5, 175998},
	{"CUANTO", 6, 175999},
	{"CENTAVOS", 8, 176000},
	{"DANISCO", 7, 176001},
	{"SPYWARES", 8, 176002},
	{"DEPONENT", 8, 176003},
	{"BOGEL", 5, 176004},
	{"RIVERGATE", 9, 176005},
	{"SINFULLY", 8, 176006},
	{"WEBVIEW", 7, 176007},
	{"DUNIX", 5, 176008},
	{"DISCOV", 6, 176009},
	{"GUFFEY", 6, 176010},
	{"WEISSTEIN", 9, 176011},
	{"LITTERBOX", 9, 176012},
	{"LEISTER", 7, 176013},
	{"DUNGARVAN", 9, 176014},
	{"TRIUNFO", 7, 176015},
	{"YTEW", 4, 176016},
	{"WDIC", 4, 176017},
	{"WAPH", 4, 176018},
	{"UODL", 4, 176019},
	{"UMOA", 4, 176020},
	{"UHIM", 4, 176021},
	{"UBYR", 4, 176022},
	{"TZIG", 4, 176023},
	{"STLB", 4, 176024},
	{"SRSC", 4, 176025},
	{"SAMV", 4, 176026},
	{"RKOD", 4, 176027},
	{"OKCU", 4, 176028},
	{"LIDY", 4, 176029},
	{"LAED", 4, 176030},
	{"HMCN", 4, 176031},
	{"EPOY", 4, 176032},
	{"DSEU", 4, 176033},
	{"BILG", 4, 176034},
	{"TRASPORTI", 9, 176035},
	{"PYKE", 4, 176036},
	{"TERRANS", 7, 176037},
	{"STOCKLEY", 8, 176038},
	{"NIXED", 5, 176039},
	{"FOOOD", 5, 176040},
	{"CHAK", 4, 176041},
	{"PASION", 6, 176042},
	{"BRUEGEL", 7, 176043},
	{"RESERVAR", 8, 176044},
	{"MAROOCHY", 8, 176045},
	{"CONTIENT", 8, 176046},
	{"NERSC", 5, 176047},
	{"KIDNAPS", 7, 176048},
	{"QUINAULT", 8, 176049},
	{"BURKA", 5, 176050},
	{"RACCONTI", 8, 176051},
	{"MULITPLE", 8, 176052},
	{"VANYA", 5, 176053},
	{"KISHIMOTO", 9, 176054},
	{"THIOCYANATE", 11, 176055},
	{"POSSONO", 7, 176056},
	{"EARNIE", 6, 176057},
	{"AMSOUTH", 7, 176058},
	{"ULNA", 4, 176059},
	{"CARCINOEMBRYONIC", 16, 176060},
	{"GENERALIZABILITY", 16, 176061},
	{"FINGERLINGS", 11, 176062},
	{"TEMPDIR", 7, 176063},
	{"DEVRAIT", 7, 176064},
	{"BIDDEN", 6, 176065},
	{"HENSIVE", 7, 176066},
	{"TROXEL", 6, 176067},
	{"JAMON", 5, 176068},
	{"FALCK", 5, 176069},
	{"EMARKET", 7, 176070},
	{"FLORISTIC", 9, 176071},
	{"AMEDIA", 6, 176072},
	{"UNLIQUIDATED", 12, 176073},
	{"JBM", 3, 176074},
	{"FEETS", 5, 176075},
	{"KITTEL", 6, 176076},
	{"PALMATUM", 8, 176077},
	{"TUILERIES", 9, 176078},
	{"HYNDBURN", 8, 176079},
	{"CRASHWORTHINESS", 15, 176080},
	{"AMBON", 5, 176081},
	{"OUTLANDS", 8, 176082},
	{"HALVORSEN", 9, 176083},
	{"BLACKHEAD", 9, 176084},
	{"NETSEMINAR", 10, 176085},
	{"SIDLEY", 6, 176086},
	{"MIYATA", 6, 176087},
	{"LIQUIFIED", 9, 176088},
	{"BRINCKERHOFF", 12, 176089},
	{"CNTRY", 5, 176090},
	{"ARTERIOLES", 10, 176091},
	{"HAARP", 5, 176092},
	{"TOWABLE", 7, 176093},
	{"JAIDEE", 6, 176094},
	{"NIXES", 5, 176095},
	{"DAHAN", 5, 176096},
	{"HAGANAH", 7, 176097},
	{"AIRSIDE", 7, 176098},
	{"ARDO", 4, 176099},
	{"TSUTOMU", 7, 176100},
	{"DEODORIZER", 10, 176101},
	{"BIPEDAL", 7, 176102},
	{"VPIM", 4, 176103},
	{"EXTENDIBLE", 10, 176104},
	{"BROCKLEY", 8, 176105},
	{"SUBLIM", 6, 176106},
	{"RINGETTE", 8, 176107},
	{"ALPHASMART", 10, 176108},
	{"TEREST", 6, 176109},
	{"METU", 4, 176110},
	{"WEBCITY", 7, 176111},
	{"NIMBY", 5, 176112},
	{"VIRTUALITY", 10, 176113},
	{"STREPTOKINASE", 13, 176114},
	{"ACTUALIZADAS", 12, 176115},
	{"TOLLGATE", 8, 176116},
	{"INTRODUC", 8, 176117},
	{"LORRI", 5, 176118},
	{"RLL", 3, 176119},
	{"FLUES", 5, 176120},
	{"PGDIP", 5, 176121},
	{"BREADBOARD", 10, 176122},
	{"ADDITIVITY", 10, 176123},
	{"WELLSBORO", 9, 176124},
	{"RETRIED", 7, 176125},
	{"LAURENTIIS", 10, 176126},
	{"WETP", 4, 176127},
	{"VFWP", 4, 176128},
	{"SDRJ", 4, 176129},
	{"SCPU", 4, 176130},
	{"POLG", 4, 176131},
	{"NZYO", 4, 176132},
	{"NJIC", 4, 176133},
	{"MBSK", 4, 176134},
	{"LOAG", 4, 176135},
	{"LMYW", 4, 176136},
	{"KMEC", 4, 176137},
	{"JAYJ", 4, 176138},
	{"GPHR", 4, 176139},
	{"GNIL", 4, 176140},
	{"GAKH", 4, 176141},
	{"FPIX", 4, 176142},
	{"EWOZ", 4, 176143},
	{"ETUF", 4, 176144},
	{"EDDB", 4, 176145},
	{"CDOL", 4, 176146},
	{"BGUN", 4, 176147},
	{"AVOK", 4, 176148},
	{"AMYV", 4, 176149},
	{"AICM", 4, 176150},
	{"SAMEN", 5, 176151},
	{"BANEN", 5, 176152},
	{"KOONING", 7, 176153},
	{"KIKUYU", 6, 176154},
	{"ISSARIES", 8, 176155},
	{"CONTRAIRE", 9, 176156},
	{"WADES", 5, 176157},
	{"VASILI", 6, 176158},
	{"ROOMIES", 7, 176159},
	{"URP", 3, 176160},
	{"REALISABLE", 10, 176161},
	{"BIOLUMINESCENCE", 15, 176162},
	{"GEOMORPHOLOGICAL", 16, 176163},
	{"YANTAI", 6, 176164},
	{"WCONVERSION", 11, 176165},
	{"MIER", 4, 176166},
	{"GAFFES", 6, 176167},
	{"VIOLETA", 7, 176168},
	{"DISPENSABLE", 11, 176169},
	{"REDEPLOYED", 10, 176170},
	{"DEELEY", 6, 176171},
	{"CORRIERE", 8, 176172},
	{"SAMBAR", 6, 176173},
	{"MASPETH", 7, 176174},
	{"STARTUPLIST", 11, 176175},
	{"LLOSA", 5, 176176},
	{"ALLMYPAGES", 10, 176177},
	{"PLINK", 5, 176178},
	{"THEATRELAND", 11, 176179},
	{"REATTACH", 8, 176180},
	{"DINOVO", 6, 176181},
	{"UNITARITY", 9, 176182},
	{"CHOUDHARY", 9, 176183},
	{"DRYLANDS", 8, 176184},
	{"INTERMODULATION", 15, 176185},
	{"BAJOS", 5, 176186},
	{"RESOLVCONF", 10, 176187},
	{"SHRINKWRAPPED", 13, 176188},
	{"LIMOSINE", 8, 176189},
	{"TAGLESS", 7, 176190},
	{"EPIRB", 5, 176191},
	{"ONEGIN", 6, 176192},
	{"MONOPOLIZED", 11, 176193},
	{"MALTY", 5, 176194},
	{"REDRESSING", 10, 176195},
	{"ANTHROPOSOPHY", 13, 176196},
	{"ABSTRUSE", 8, 176197},
	{"SHILTON", 7, 176198},
	{"NZQA", 4, 176199},
	{"NIGP", 4, 176200},
	{"IOADDR", 6, 176201},
	{"CHRISTIANIA", 11, 176202},
	{"DIRETTORE", 9, 176203},
	{"PONGAL", 6, 176204},
	{"PETROVICH", 9, 176205},
	{"HANDIT", 6, 176206},
	{"EMBRYONAL", 9, 176207},
	{"JERGENS", 7, 176208},
	{"SHAKEOUT", 8, 176209},
	{"SADOWSKI", 8, 176210},
	{"STRIPLING", 9, 176211},
	{"OUTPLAYED", 9, 176212},
	{"LIBIDL", 6, 176213},
	{"RECUSAL", 7, 176214},
	{"ALNUS", 5, 176215},
	{"HALDOL", 6, 176216},
	{"OVERSHADOWING", 13, 176217},
	{"ANTOFAGASTA", 11, 176218},
	{"SPANAWAY", 8, 176219},
	{"SMOLYAN", 7, 176220},
	{"HAGSTROM", 8, 176221},
	{"SUCCOUR", 7, 176222},
	{"BAGG", 4, 176223},
	{"METHOW", 6, 176224},
	{"SLOVENSKEJ", 10, 176225},
	{"ACADIE", 6, 176226},
	{"QUOTIDIEN", 9, 176227},
	{"MOOSEHEAD", 9, 176228},
	{"FOOTWAY", 7, 176229},
	{"VERLEIH", 7, 176230},
	{"OLDLIBS", 7, 176231},
	{"BULLI", 5, 176232},
	{"BRITOOL", 7, 176233},
	{"TENCOR", 6, 176234},
	{"GYP", 3, 176235},
	{"LINUXARKIVET", 12, 176236},
	{"YAMBA", 5, 176237},
	{"PHOTICK", 7, 176238},
	{"EXHEDRA", 7, 176239},
	{"PERRONE", 7, 176240},
	{"BEANBAGS", 8, 176241},
	{"BANCHORY", 8, 176242},
	{"MEEP", 4, 176243},
	{"FAIRLESS", 8, 176244},
	{"YUSN", 4, 176245},
	{"VREO", 4, 176246},
	{"UZSA", 4, 176247},
	{"UOAR", 4, 176248},
	{"UHLM", 4, 176249},
	{"TELJ", 4, 176250},
	{"SPNU", 4, 176251},
	{"RZYS", 4, 176252},
	{"RPSN", 4, 176253},
	{"RMVP", 4, 176254},
	{"RDCC", 4, 176255},
	{"OKEK", 4, 176256},
	{"OGIM", 4, 176257},
	{"LUIC", 4, 176258},
	{"LIRU", 4, 176259},
	{"LEBH", 4, 176260},
	{"LCIG", 4, 176261},
	{"KOXF", 4, 176262},
	{"HAZU", 4, 176263},
	{"GYVO", 4, 176264},
	{"GOPB", 4, 176265},
	{"FIDG", 4, 176266},
	{"EPGI", 4, 176267},
	{"EMRF", 4, 176268},
	{"EMMR", 4, 176269},
	{"DICJ", 4, 176270},
	{"DHYM", 4, 176271},
	{"CNND", 4, 176272},
	{"CAKI", 4, 176273},
	{"BUNB", 4, 176274},
	{"BUMJ", 4, 176275},
	{"BTBY", 4, 176276},
	{"BCMI", 4, 176277},
	{"ALVU", 4, 176278},
	{"AHCR", 4, 176279},
	{"TELEKINESIS", 11, 176280},
	{"GOTICKETS", 9, 176281},
	{"BULENT", 6, 176282},
	{"HFSUTILS", 8, 176283},
	{"WHIZZING", 8, 176284},
	{"HESSLE", 6, 176285},
	{"FIXX", 4, 176286},
	{"REINVENTS", 9, 176287},
	{"MCQS", 4, 176288},
	{"HEADMAN", 7, 176289},
	{"MOBRIDGE", 8, 176290},
	{"OFFICEGIRLS", 11, 176291},
	{"GLIMMERS", 8, 176292},
	{"PGW", 3, 176293},
	{"WALVIS", 6, 176294},
	{"DOWNTOWNS", 9, 176295},
	{"PACEM", 5, 176296},
	{"FORSYTHIA", 9, 176297},
	{"CAMBRO", 6, 176298},
	{"SERVICEGUARD", 12, 176299},
	{"PARFUME", 7, 176300},
	{"PARAG", 5, 176301},
	{"MSYS", 4, 176302},
	{"SPOTTIE", 7, 176303},
	{"FRAS", 4, 176304},
	{"HONESDALE", 9, 176305},
	{"ELDA", 4, 176306},
	{"ARCHITOSH", 9, 176307},
	{"FLFLFLFL", 8, 176308},
	{"DISPERSES", 9, 176309},
	{"BARLEAN", 7, 176310},
	{"ADVI", 4, 176311},
	{"JARO", 4, 176312},
	{"TACKTICK", 8, 176313},
	{"SOLUCIENT", 9, 176314},
	{"SCOOPER", 7, 176315},
	{"IMAKEFILE", 9, 176316},
	{"BARGING", 7, 176317},
	{"ACTIVEPERL", 10, 176318},
	{"DIRECTORYNEW", 12, 176319},
	{"LAMOUREUX", 9, 176320},
	{"ESCALADA", 8, 176321},
	{"CYRADM", 6, 176322},
	{"MACALLAN", 8, 176323},
	{"ENTRENAMIENTO", 13, 176324},
	{"BARBEL", 6, 176325},
	{"SCHELLENBERG", 12, 176326},
	{"FTER", 4, 176327},
	{"EFFEITHIOL", 10, 176328},
	{"CLEARPATH", 9, 176329},
	{"CHARTE", 6, 176330},
	{"ROSENFIELD", 10, 176331},
	{"WOLMAN", 6, 176332},
	{"LIMITA", 6, 176333},
	{"FONTERRA", 8, 176334},
	{"ULSAN", 5, 176335},
	{"CURRUMBIN", 9, 176336},
	{"BRESNAHAN", 9, 176337},
	{"PROTEAN", 7, 176338},
	{"DECOMPRESSING", 13, 176339},
	{"ONTOP", 5, 176340},
	{"DAHLIN", 6, 176341},
	{"BONDE", 5, 176342},
	{"BIALYSTOK", 9, 176343},
	{"FRUNNY", 6, 176344},
	{"SASKTEL", 7, 176345},
	{"COSTON", 6, 176346},
	{"POSIBILIDAD", 11, 176347},
	{"MOTORSPT", 8, 176348},
	{"EUROMILLIONS", 12, 176349},
	{"CENTRALIZES", 11, 176350},
	{"LIBXFT", 6, 176351},
	{"EYEBRIGHT", 9, 176352},
	{"ARMBRUSTER", 10, 176353},
	{"MELLOWED", 8, 176354},
	{"KARMAPA", 7, 176355},
	{"MELLOTRON", 9, 176356},
	{"DOWNLAODS", 9, 176357},
	{"MAPVIEWER", 9, 176358},
	{"WARMERDAM", 9, 176359},
	{"MYATT", 5, 176360},
	{"TRILLING", 8, 176361},
	{"THOMASS", 7, 176362},
	{"ENCONTRARAS", 11, 176363},
	{"YRCA", 4, 176364},
	{"YIGU", 4, 176365},
	{"WSSL", 4, 176366},
	{"WLBU", 4, 176367},
	{"VYGU", 4, 176368},
	{"URUC", 4, 176369},
	{"UORW", 4, 176370},
	{"SHUY", 4, 176371},
	{"NTUF", 4, 176372},
	{"LUWE", 4, 176373},
	{"IEMY", 4, 176374},
	{"IDLT", 4, 176375},
	{"HPCO", 4, 176376},
	{"HEZD", 4, 176377},
	{"GUNJ", 4, 176378},
	{"FIXC", 4, 176379},
	{"FEOV", 4, 176380},
	{"EWCW", 4, 176381},
	{"CEOK", 4, 176382},
	{"AOFY", 4, 176383},
	{"ALMV", 4, 176384},
	{"AFBO", 4, 176385},
	{"AADU", 4, 176386},
	{"NANTONG", 7, 176387},
	{"EXPOSURETIME", 12, 176388},
	{"XMLWRITER", 9, 176389},
	{"ILITA", 5, 176390},
	{"SUSTRANS", 8, 176391},
	{"INTERNATIONALEN", 15, 176392},
	{"PHREAKING", 9, 176393},
	{"CARSD", 5, 176394},
	{"NIFICANTLY", 10, 176395},
	{"KARAMANLIS", 10, 176396},
	{"PORTREE", 7, 176397},
	{"SHOWNOTES", 9, 176398},
	{"MONOGRAMMING", 12, 176399},
	{"SANSON", 6, 176400},
	{"USRA", 4, 176401},
	{"CHERENKOV", 9, 176402},
	{"OPENMOTIF", 9, 176403},
	{"CISD", 4, 176404},
	{"DELAHUNT", 8, 176405},
	{"LINKIT", 6, 176406},
	{"EBENSO", 6, 176407},
	{"CONVECTOR", 9, 176408},
	{"JUICEBOX", 8, 176409},
	{"CRASSUS", 7, 176410},
	{"MASTIFFS", 8, 176411},
	{"EXPANDO", 7, 176412},
	{"SAMARAS", 7, 176413},
	{"KOSOVARS", 8, 176414},
	{"MANCOS", 6, 176415},
	{"ROSENCRANTZ", 11, 176416},
	{"CATHRINE", 8, 176417},
	{"SECRETARIA", 10, 176418},
	{"NATURALISATION", 14, 176419},
	{"STEINEM", 7, 176420},
	{"PJRST", 5, 176421},
	{"ARRESTEES", 9, 176422},
	{"OPENWIN", 7, 176423},
	{"HORICON", 7, 176424},
	{"WSIB", 4, 176425},
	{"PEATLANDS", 9, 176426},
	{"CONTIGUITY", 10, 176427},
	{"SALLIS", 6, 176428},
	{"ABITA", 5, 176429},
	{"RAMER", 5, 176430},
	{"DARENET", 7, 176431},
	{"CATTLEMAN", 9, 176432},
	{"FLEXWIKI", 8, 176433},
	{"FINDABILITY", 11, 176434},
	{"MORTS", 5, 176435},
	{"PRETTIES", 8, 176436},
	{"PBG", 3, 176437},
	{"DYNCORP", 7, 176438},
	{"POWERADE", 8, 176439},
	{"ECOLOGIES", 9, 176440},
	{"PRESUPPOSED", 11, 176441},
	{"MILLOR", 6, 176442},
	{"CUSSION", 7, 176443},
	{"HUBERMAN", 8, 176444},
	{"PAINTSVILLE", 11, 176445},
	{"SAWADA", 6, 176446},
	{"RETRACING", 9, 176447},
	{"RAMADHAN", 8, 176448},
	{"LYRCS", 5, 176449},
	{"FRV", 3, 176450},
	{"SWEETGRASS", 10, 176451},
	{"RICCIARDI", 9, 176452},
	{"SCREWTAPE", 9, 176453},
	{"NEWSLINES", 9, 176454},
	{"YAPC", 4, 176455},
	{"KARIYA", 6, 176456},
	{"ZIKS", 4, 176457},
	{"YRUF", 4, 176458},
	{"YKET", 4, 176459},
	{"WKHA", 4, 176460},
	{"UOPA", 4, 176461},
	{"UDBY", 4, 176462},
	{"UANK", 4, 176463},
	{"UAFI", 4, 176464},
	{"TECW", 4, 176465},
	{"RUVE", 4, 176466},
	{"RFWI", 4, 176467},
	{"PAAM", 4, 176468},
	{"OUXW", 4, 176469},
	{"NGOJ", 4, 176470},
	{"MKEI", 4, 176471},
	{"LPHG", 4, 176472},
	{"LFCI", 4, 176473},
	{"GGOU", 4, 176474},
	{"FKOB", 4, 176475},
	{"FGEL", 4, 176476},
	{"EWCC", 4, 176477},
	{"EMCQ", 4, 176478},
	{"EKUD", 4, 176479},
	{"EFOM", 4, 176480},
	{"ALMG", 4, 176481},
	{"HAGMAN", 6, 176482},
	{"BILDERLOUNGE", 12, 176483},
	{"POWERTEC", 8, 176484},
	{"CHUFFED", 7, 176485},
	{"WOOP", 4, 176486},
	{"CAMBIA", 6, 176487},
	{"PLAYES", 6, 176488},
	{"PANTOLIANO", 10, 176489},
	{"LAPELS", 6, 176490},
	{"SUPERPASS", 9, 176491},
	{"MALLER", 6, 176492},
	{"IDEX", 4, 176493},
	{"LOUPES", 6, 176494},
	{"SIMILITUDE", 10, 176495},
	{"APOLLONIUS", 10, 176496},
	{"RDER", 4, 176497},
	{"NAUSEATED", 9, 176498},
	{"STAGER", 6, 176499},
	{"LOHSE", 5, 176500},
	{"TRACHOMA", 8, 176501},
	{"SERVENT", 7, 176502},
	{"VERDURE", 7, 176503},
	{"VISIONE", 7, 176504},
	{"ZAYE", 4, 176505},
	{"SWARD", 5, 176506},
	{"BENOA", 5, 176507},
	{"RPGA", 4, 176508},
	{"EXCLUSIVENESS", 13, 176509},
	{"ANWENDUNG", 9, 176510},
	{"VESTAVIA", 8, 176511},
	{"SHARLENE", 8, 176512},
	{"ESSIEN", 6, 176513},
	{"DMIN", 4, 176514},
	{"MISAPPLICATION", 14, 176515},
	{"FORSE", 5, 176516},
	{"BOSUN", 5, 176517},
	{"SHERRIFF", 8, 176518},
	{"DEINES", 6, 176519},
	{"DERMANEW", 8, 176520},
	{"ENTRENCH", 8, 176521},
	{"UNSCRAMBLE", 10, 176522},
	{"CERCO", 5, 176523},
	{"ZIATECH", 7, 176524},
	{"RECLINED", 8, 176525},
	{"NSTITUTE", 8, 176526},
	{"PROCTORS", 8, 176527},
	{"LUCEY", 5, 176528},
	{"WEETZIE", 7, 176529},
	{"QUICKPOLL", 9, 176530},
	{"SPINNEY", 7, 176531},
	{"SENGER", 6, 176532},
	{"KAMAT", 5, 176533},
	{"LAIBACH", 7, 176534},
	{"DRENTHE", 7, 176535},
	{"DEDI", 4, 176536},
	{"THROBBED", 8, 176537},
	{"MILNES", 6, 176538},
	{"FEATHERSTON", 11, 176539},
	{"ARDEA", 5, 176540},
	{"POSTERIORLY", 11, 176541},
	{"DIVINES", 7, 176542},
	{"CASSELMAN", 9, 176543},
	{"WSRT", 4, 176544},
	{"TETRAGONAL", 10, 176545},
	{"PODEMOS", 7, 176546},
	{"EDMUNDO", 7, 176547},
	{"PROSTRATION", 11, 176548},
	{"NIEHAUS", 7, 176549},
	{"AMAP", 4, 176550},
	{"WRETCHEDNESS", 12, 176551},
	{"ADMIS", 5, 176552},
	{"ZYCA", 4, 176553},
	{"YVEO", 4, 176554},
	{"YLPH", 4, 176555},
	{"YJUV", 4, 176556},
	{"XMRE", 4, 176557},
	{"WNIL", 4, 176558},
	{"UYET", 4, 176559},
	{"USKU", 4, 176560},
	{"UAVO", 4, 176561},
	{"TTVC", 4, 176562},
	{"SKVA", 4, 176563},
	{"RUWE", 4, 176564},
	{"RFDO", 4, 176565},
	{"OGYK", 4, 176566},
	{"NGIZ", 4, 176567},
	{"IZUH", 4, 176568},
	{"HOUF", 4, 176569},
	{"HLIZ", 4, 176570},
	{"GGHU", 4, 176571},
	{"FIPO", 4, 176572},
	{"EMMD", 4, 176573},
	{"DPFO", 4, 176574},
	{"DDUO", 4, 176575},
	{"BYGM", 4, 176576},
	{"BUDB", 4, 176577},
	{"LYRICD", 6, 176578},
	{"HASWELL", 7, 176579},
	{"WAVERUNNER", 10, 176580},
	{"ESSENES", 7, 176581},
	{"WALKERA", 7, 176582},
	{"SEFYDLIADAU", 11, 176583},
	{"TAURI", 5, 176584},
	{"ADRENA", 6, 176585},
	{"FLYERTALK", 9, 176586},
	{"PLUMPTON", 8, 176587},
	{"FESTOONED", 9, 176588},
	{"BURCHETT", 8, 176589},
	{"BAREST", 6, 176590},
	{"ETIOLOGICAL", 11, 176591},
	{"STEADFASTNESS", 13, 176592},
	{"SEBELIUS", 8, 176593},
	{"SAGADAHOC", 9, 176594},
	{"TOWNSLEY", 8, 176595},
	{"ENCELADUS", 9, 176596},
	{"CHUDACOFF", 9, 176597},
	{"CYTOLOGIC", 9, 176598},
	{"DWARFISM", 8, 176599},
	{"CCIR", 4, 176600},
	{"UNDERARMS", 9, 176601},
	{"ORGADOC", 7, 176602},
	{"FINANCIERO", 10, 176603},
	{"ARECA", 5, 176604},
	{"AQCESS", 6, 176605},
	{"SEEMAN", 6, 176606},
	{"MUMMIFICATION", 13, 176607},
	{"CHANTEL", 7, 176608},
	{"RPMI", 4, 176609},
	{"DESIGNPICS", 10, 176610},
	{"VLIW", 4, 176611},
	{"MCDERMID", 8, 176612},
	{"PASSBOOK", 8, 176613},
	{"KLYSTRON", 8, 176614},
	{"PMV", 3, 176615},
	{"PRIC", 4, 176616},
	{"IVONNE", 6, 176617},
	{"COLMA", 5, 176618},
	{"TALSORIAN", 9, 176619},
	{"ADAPTIVITY", 10, 176620},
	{"ECOUTER", 7, 176621},
	{"MURK", 4, 176622},
	{"DEMIGOD", 7, 176623},
	{"VASTERS", 7, 176624},
	{"ETIQUETAS", 9, 176625},
	{"DIDACTICS", 9, 176626},
	{"REESTABLISHING", 14, 176627},
	{"KEELS", 5, 176628},
	{"BYL", 3, 176629},
	{"SONDE", 5, 176630},
	{"KOHLBERG", 8, 176631},
	{"REINKE", 6, 176632},
	{"LAZENBY", 7, 176633},
	{"PECKS", 5, 176634},
	{"BLINKER", 7, 176635},
	{"NOELANI", 7, 176636},
	{"BOOG", 4, 176637},
	{"HULLO", 5, 176638},
	{"DIGRESSIONS", 11, 176639},
	{"LARTER", 6, 176640},
	{"PFDS", 4, 176641},
	{"BOWHUNTER", 9, 176642},
	{"DIOCLETIAN", 10, 176643},
	{"TANTALISING", 11, 176644},
	{"NDTV", 4, 176645},
	{"KAROLY", 6, 176646},
	{"BUTTERFAT", 9, 176647},
	{"SEARCHS", 7, 176648},
	{"POZA", 4, 176649},
	{"LINEE", 5, 176650},
	{"ZOVE", 4, 176651},
	{"YCHW", 4, 176652},
	{"WSEW", 4, 176653},
	{"WFEV", 4, 176654},
	{"UPEP", 4, 176655},
	{"UBIR", 4, 176656},
	{"UABS", 4, 176657},
	{"SGTD", 4, 176658},
	{"RPYR", 4, 176659},
	{"ROVC", 4, 176660},
	{"REZG", 4, 176661},
	{"PODU", 4, 176662},
	{"PAKL", 4, 176663},
	{"OVBU", 4, 176664},
	{"LTEJ", 4, 176665},
	{"LSYL", 4, 176666},
	{"LOSQ", 4, 176667},
	{"LCHW", 4, 176668},
	{"LAOL", 4, 176669},
	{"KMCK", 4, 176670},
	{"IXMU", 4, 176671},
	{"IMIY", 4, 176672},
	{"HMWH", 4, 176673},
	{"HLOY", 4, 176674},
	{"FIRV", 4, 176675},
	{"DLUL", 4, 176676},
	{"WITCHER", 7, 176677},
	{"GURANTEE", 8, 176678},
	{"FULK", 4, 176679},
	{"SOKOLOFF", 8, 176680},
	{"IFPI", 4, 176681},
	{"SPLM", 4, 176682},
	{"PUBBLICA", 8, 176683},
	{"PASSOS", 6, 176684},
	{"SOFOTEX", 7, 176685},
	{"SCHOOLIES", 9, 176686},
	{"IVSIZE", 6, 176687},
	{"FELLERS", 7, 176688},
	{"CHITWAN", 7, 176689},
	{"KUNI", 4, 176690},
	{"OPENZONE", 8, 176691},
	{"ACTINIDE", 8, 176692},
	{"VELOPED", 7, 176693},
	{"DEARDEN", 7, 176694},
	{"CILLA", 5, 176695},
	{"UNILIB", 6, 176696},
	{"AKERMAN", 7, 176697},
	{"SYKORA", 6, 176698},
	{"JAHNKE", 6, 176699},
	{"SCAMMING", 8, 176700},
	{"USEITHREADS", 11, 176701},
	{"MULATTA", 7, 176702},
	{"CHEMTRAILS", 10, 176703},
	{"BEGRUDGE", 8, 176704},
	{"MOONSPELL", 9, 176705},
	{"CARGOS", 6, 176706},
	{"RICAUD", 6, 176707},
	{"ACTIONED", 8, 176708},
	{"CINDEX", 6, 176709},
	{"WHINGING", 8, 176710},
	{"BEIER", 5, 176711},
	{"SEEDA", 5, 176712},
	{"XLIII", 5, 176713},
	{"NEOSEEK", 7, 176714},
	{"SALVES", 6, 176715},
	{"CRITS", 5, 176716},
	{"HYPING", 6, 176717},
	{"FATSO", 5, 176718},
	{"ARABIYA", 7, 176719},
	{"DOTTING", 7, 176720},
	{"CHLORATE", 8, 176721},
	{"UTCA", 4, 176722},
	{"COXSWAIN", 8, 176723},
	{"DEPILATION", 10, 176724},
	{"KOEHN", 5, 176725},
	{"BIOREGION", 9, 176726},
	{"SILBERSTEIN", 11, 176727},
	{"NOREAGA", 7, 176728},
	{"BESANT", 6, 176729},
	{"EATONWEB", 8, 176730},
	{"ANJELICA", 8, 176731},
	{"INVESTEE", 8, 176732},
	{"BARRIS", 6, 176733},
	{"SCHRIFTEN", 9, 176734},
	{"DINMORE", 7, 176735},
	{"SPATS", 5, 176736},
	{"PHONEX", 6, 176737},
	{"TEICH", 5, 176738},
	{"GARCINIA", 8, 176739},
	{"FANOUT", 6, 176740},
	{"AIRFRAMES", 9, 176741},
	{"TIKKI", 5, 176742},
	{"COUNSELLED", 10, 176743},
	{"LWORK", 5, 176744},
	{"SENTRIES", 8, 176745},
	{"TEXANA", 6, 176746},
	{"REPROACHES", 10, 176747},
	{"PIZZO", 5, 176748},
	{"ALTHOUGHT", 9, 176749},
	{"SALZBERG", 8, 176750},
	{"HILLE", 5, 176751},
	{"WARLEY", 6, 176752},
	{"BUGGIN", 6, 176753},
	{"BEMENT", 6, 176754},
	{"SPELTHORNE", 10, 176755},
	{"ROCESS", 6, 176756},
	{"CIAMPINO", 8, 176757},
	{"PEDIMENT", 8, 176758},
	{"KALINA", 6, 176759},
	{"HAYTI", 5, 176760},
	{"MITHRAS", 7, 176761},
	{"GIUDICE", 7, 176762},
	{"ARENAFAN", 8, 176763},
	{"ZEAU", 4, 176764},
	{"YLYO", 4, 176765},
	{"XWRI", 4, 176766},
	{"VADV", 4, 176767},
	{"URFM", 4, 176768},
	{"UOLD", 4, 176769},
	{"TWWE", 4, 176770},
	{"TPIX", 4, 176771},
	{"TMTV", 4, 176772},
	{"SBMW", 4, 176773},
	{"RLOH", 4, 176774},
	{"RKYC", 4, 176775},
	{"RDPM", 4, 176776},
	{"RBPE", 4, 176777},
	{"OBUK", 4, 176778},
	{"JWAL", 4, 176779},
	{"IDDN", 4, 176780},
	{"HYOP", 4, 176781},
	{"HMRE", 4, 176782},
	{"GSSW", 4, 176783},
	{"FXIA", 4, 176784},
	{"EZPI", 4, 176785},
	{"EMMM", 4, 176786},
	{"DDTE", 4, 176787},
	{"CUBU", 4, 176788},
	{"CKEH", 4, 176789},
	{"CCUB", 4, 176790},
	{"BYOA", 4, 176791},
	{"ATMG", 4, 176792},
	{"ANMF", 4, 176793},
	{"NDING", 5, 176794},
	{"PRAS", 4, 176795},
	{"GEEF", 4, 176796},
	{"CRIMMINS", 8, 176797},
	{"CASSIO", 6, 176798},
	{"SPEAKERCRAFT", 12, 176799},
	{"BERNADINO", 9, 176800},
	{"CTOBER", 6, 176801},
	{"BEEPERS", 7, 176802},
	{"KOLOR", 5, 176803},
	{"INTOXICANTS", 11, 176804},
	{"PROTESTOR", 9, 176805},
	{"CANDLELIGHTING", 14, 176806},
	{"FURNISS", 7, 176807},
	{"YIMOU", 5, 176808},
	{"DOCUSHARE", 9, 176809},
	{"PARNATE", 7, 176810},
	{"DEAMON", 6, 176811},
	{"ARKHANGELSK", 11, 176812},
	{"REMPEL", 6, 176813},
	{"MEINEM", 6, 176814},
	{"ORBAN", 5, 176815},
	{"MCGARVEY", 8, 176816},
	{"BALED", 5, 176817},
	{"WANNEER", 7, 176818},
	{"GRETAG", 6, 176819},
	{"TAKAPUNA", 8, 176820},
	{"BLOGOSCOPED", 11, 176821},
	{"TRINGA", 6, 176822},
	{"SIMULANT", 8, 176823},
	{"CUBESTOCK", 9, 176824},
	{"ASHWAGANDHA", 11, 176825},
	{"LESHER", 6, 176826},
	{"BALEFUL", 7, 176827},
	{"LMM", 3, 176828},
	{"ZENTRALBLATT", 12, 176829},
	{"SYLHET", 6, 176830},
	{"HAWG", 4, 176831},
	{"NOTATED", 7, 176832},
	{"CHAFER", 6, 176833},
	{"HARTFIELD", 9, 176834},
	{"VOLITIONAL", 10, 176835},
	{"SWIFTER", 7, 176836},
	{"AMPH", 4, 176837},
	{"KRAL", 4, 176838},
	{"HARDWARECENTRAL", 15, 176839},
	{"YANUKOVYCH", 10, 176840},
	{"AGOUTI", 6, 176841},
	{"TWINAX", 6, 176842},
	{"INFORMAZIONE", 12, 176843},
	{"DRUGGING", 8, 176844},
	{"NUKEES", 6, 176845},
	{"HISTOLYTICA", 11, 176846},
	{"MCCOVEY", 7, 176847},
	{"RELAXIN", 7, 176848},
	{"TIMOTHEUS", 9, 176849},
	{"FANTABULOUS", 11, 176850},
	{"PINARD", 6, 176851},
	{"FARMSTAYS", 9, 176852},
	{"STOLTZFUS", 9, 176853},
	{"GARDAI", 6, 176854},
	{"PRODUCTWIRE", 11, 176855},
	{"CUSTOMIZES", 10, 176856},
	{"HULP", 4, 176857},
	{"ENCRYPTOR", 9, 176858},
	{"RYANODINE", 9, 176859},
	{"RATHMINES", 9, 176860},
	{"LIGHTMAN", 8, 176861},
	{"PREIMPLANTATION", 15, 176862},
	{"FEARNLEY", 8, 176863},
	{"FAIRLADY", 8, 176864},
	{"BLUEST", 6, 176865},
	{"FESTOON", 7, 176866},
	{"DYCE", 4, 176867},
	{"MONOGATARI", 10, 176868},
	{"ALPHONSUS", 9, 176869},
	{"CLAWHAMMER", 10, 176870},
	{"PROFESSIONALIZATION", 19, 176871},
	{"MINISTRO", 8, 176872},
	{"ROCKRIDGE", 9, 176873},
	{"GELTEN", 6, 176874},
	{"CPST", 4, 176875},
	{"REDBOURN", 8, 176876},
	{"VIEC", 4, 176877},
	{"FARRIERS", 8, 176878},
	{"BUGREPORT", 9, 176879},
	{"RESEARC", 7, 176880},
	{"CALCOLO", 7, 176881},
	{"MIROIR", 6, 176882},
	{"AQUALOGIC", 9, 176883},
	{"YLTH", 4, 176884},
	{"YEFA", 4, 176885},
	{"YDPR", 4, 176886},
	{"YBMG", 4, 176887},
	{"XBYT", 4, 176888},
	{"WIRS", 4, 176889},
	{"WDYN", 4, 176890},
	{"UAGO", 4, 176891},
	{"TTPC", 4, 176892},
	{"SMGA", 4, 176893},
	{"RZIO", 4, 176894},
	{"RUZM", 4, 176895},
	{"RMGU", 4, 176896},
	{"OIRL", 4, 176897},
	{"NTVP", 4, 176898},
	{"NIZZ", 4, 176899},
	{"LYKR", 4, 176900},
	{"LTOQ", 4, 176901},
	{"LOUL", 4, 176902},
	{"LGAG", 4, 176903},
	{"KYIF", 4, 176904},
	{"KMAH", 4, 176905},
	{"KJES", 4, 176906},
	{"KAKH", 4, 176907},
	{"IZBO", 4, 176908},
	{"IPBL", 4, 176909},
	{"INVL", 4, 176910},
	{"INUZ", 4, 176911},
	{"HTMC", 4, 176912},
	{"HLYK", 4, 176913},
	{"HKUM", 4, 176914},
	{"GIFR", 4, 176915},
	{"FATK", 4, 176916},
	{"DOIC", 4, 176917},
	{"COGU", 4, 176918},
	{"BOCR", 4, 176919},
	{"MPLPOST", 7, 176920},
	{"MOUNTAINBIKE", 12, 176921},
	{"USELARGEFILES", 13, 176922},
	{"FARFLUNG", 8, 176923},
	{"DOLED", 5, 176924},
	{"NAMESECURE", 10, 176925},
	{"HAVIOR", 6, 176926},
	{"ESCOBEDO", 8, 176927},
	{"ROOMED", 6, 176928},
	{"BROOKLAND", 9, 176929},
	{"CONTABILIDAD", 12, 176930},
	{"ASSIGNEDTO", 10, 176931},
	{"CPCS", 4, 176932},
	{"XORO", 4, 176933},
	{"GLORIFIES", 9, 176934},
	{"YPD", 3, 176935},
	{"LISTES", 6, 176936},
	{"BOGEYMAN", 8, 176937},
	{"ALFREDSSON", 10, 176938},
	{"GOANTIQUES", 10, 176939},
	{"JAQUA", 5, 176940},
	{"THAROOR", 7, 176941},
	{"EVAR", 4, 176942},
	{"DUCKSNORTS", 10, 176943},
	{"HYDROXYPROLINE", 14, 176944},
	{"ALAR", 4, 176945},
	{"PROMESSE", 8, 176946},
	{"MECHANISED", 10, 176947},
	{"INSIDEOUT", 9, 176948},
	{"LACHAPELLE", 10, 176949},
	{"RUMORI", 6, 176950},
	{"JOLLEE", 6, 176951},
	{"WORKFARE", 8, 176952},
	{"UNBOSSED", 8, 176953},
	{"TONGARIRO", 9, 176954},
	{"PREPROCESS", 10, 176955},
	{"GUTTA", 5, 176956},
	{"APENAS", 6, 176957},
	{"KANAAN", 6, 176958},
	{"MUCHMUSIC", 9, 176959},
	{"BRANN", 5, 176960},
	{"FALA", 4, 176961},
	{"DECR", 4, 176962},
	{"GLOTTAL", 7, 176963},
	{"PLENA", 5, 176964},
	{"PAGP", 4, 176965},
	{"BIRKENSTOCKS", 12, 176966},
	{"WEARIN", 6, 176967},
	{"MOMENTOS", 8, 176968},
	{"BEHNKE", 6, 176969},
	{"MOSTRO", 6, 176970},
	{"INSPIRESTOCK", 12, 176971},
	{"DANUBIUS", 8, 176972},
	{"HILLOCK", 7, 176973},
	{"VASEY", 5, 176974},
	{"DICHLORIDE", 10, 176975},
	{"DEITCH", 6, 176976},
	{"BYNNAG", 6, 176977},
	{"ZARH", 4, 176978},
	{"YYAS", 4, 176979},
	{"VIFO", 4, 176980},
	{"VDID", 4, 176981},
	{"UYRI", 4, 176982},
	{"USSV", 4, 176983},
	{"RZWE", 4, 176984},
	{"RLAO", 4, 176985},
	{"RBSL", 4, 176986},
	{"PPYY", 4, 176987},
	{"PIFF", 4, 176988},
	{"OEYP", 4, 176989},
	{"NMUK", 4, 176990},
	{"LTDF", 4, 176991},
	{"KAAF", 4, 176992},
	{"HUAD", 4, 176993},
	{"HIFL", 4, 176994},
	{"GTMA", 4, 176995},
	{"EWGM", 4, 176996},
	{"EVVE", 4, 176997},
	{"DCIC", 4, 176998},
	{"APTM", 4, 176999},
	{"AICW", 4, 177000},
	{"IRRATIONALLY", 12, 177001},
	{"KRANNERT", 8, 177002},
	{"CADAVERIC", 9, 177003},
	{"GAGLIARDI", 9, 177004},
	{"UHAUL", 5, 177005},
	{"SUNGALE", 7, 177006},
	{"PREHEATING", 10, 177007},
	{"SPACESUIT", 9, 177008},
	{"FEARLESSNESS", 12, 177009},
	{"WILLETTS", 8, 177010},
	{"WYNNUM", 6, 177011},
	{"RNAV", 4, 177012},
	{"CRIBB", 5, 177013},
	{"JDICT", 5, 177014},
	{"FLUXBLOG", 8, 177015},
	{"SODERBERG", 9, 177016},
	{"QUEPOS", 6, 177017},
	{"PARUS", 5, 177018},
	{"LOMAN", 5, 177019},
	{"CHIPTUNING", 10, 177020},
	{"AHMANSON", 8, 177021},
	{"FRIENDY", 7, 177022},
	{"NEBEN", 5, 177023},
	{"PININFARINA", 11, 177024},
	{"GPROF", 5, 177025},
	{"HOLLYHOCK", 9, 177026},
	{"SPONSERS", 8, 177027},
	{"REALMENTE", 9, 177028},
	{"BYP", 3, 177029},
	{"CYNNAL", 6, 177030},
	{"HESKETT", 7, 177031},
	{"REVIE", 5, 177032},
	{"CORBELS", 7, 177033},
	{"BAEK", 4, 177034},
	{"FUSSFETISCH", 11, 177035},
	{"CAMERINO", 8, 177036},
	{"WAGGON", 6, 177037},
	{"KEEBLER", 7, 177038},
	{"FLEXNERI", 8, 177039},
	{"ALTAVOCES", 9, 177040},
	{"TOPCON", 6, 177041},
	{"RAPHAELITE", 10, 177042},
	{"CORDYCEPS", 9, 177043},
	{"MADILL", 6, 177044},
	{"PROPELLERHEADS", 14, 177045},
	{"NORBERTO", 8, 177046},
	{"GAGLIANO", 8, 177047},
	{"PHRF", 4, 177048},
	{"LUCIANNE", 8, 177049},
	{"INCAPACITATION", 14, 177050},
	{"PALMITIC", 8, 177051},
	{"JAIR", 4, 177052},
	{"MOSSO", 5, 177053},
	{"BAUMEISTER", 10, 177054},
	{"FLORAS", 6, 177055},
	{"ENTJUNGFERUNG", 13, 177056},
	{"CALLIS", 6, 177057},
	{"UNALTERABLE", 11, 177058},
	{"OLDTIMER", 8, 177059},
	{"DIGGA", 5, 177060},
	{"WINDSURFERS", 11, 177061},
	{"JETPORT", 7, 177062},
	{"BEELZEBUB", 9, 177063},
	{"HEALESVILLE", 11, 177064},
	{"ZTOW", 4, 177065},
	{"ZLIS", 4, 177066},
	{"XTOY", 4, 177067},
	{"WEBK", 4, 177068},
	{"VNER", 4, 177069},
	{"TGOG", 4, 177070},
	{"TDYE", 4, 177071},
	{"RZAG", 4, 177072},
	{"RBSD", 4, 177073},
	{"PYSU", 4, 177074},
	{"OCUN", 4, 177075},
	{"NERQ", 4, 177076},
	{"LTKI", 4, 177077},
	{"LOTQ", 4, 177078},
	{"KLEK", 4, 177079},
	{"KGLE", 4, 177080},
	{"KGAS", 4, 177081},
	{"HUBU", 4, 177082},
	{"HPOV", 4, 177083},
	{"HAYY", 4, 177084},
	{"GGFO", 4, 177085},
	{"FZAC", 4, 177086},
	{"FSGO", 4, 177087},
	{"FMTO", 4, 177088},
	{"EIKU", 4, 177089},
	{"CJON", 4, 177090},
	{"CEKU", 4, 177091},
	{"BMAL", 4, 177092},
	{"ANZJ", 4, 177093},
	{"AGBI", 4, 177094},
	{"ULTRAMIX", 8, 177095},
	{"SANDBLAST", 9, 177096},
	{"LCRA", 4, 177097},
	{"MINTURN", 7, 177098},
	{"XSONIC", 6, 177099},
	{"TECHNICALUSER", 13, 177100},
	{"AGRANDIR", 8, 177101},
	{"XPLANET", 7, 177102},
	{"PORKBUSTERS", 11, 177103},
	{"LONGTON", 7, 177104},
	{"TATHAM", 6, 177105},
	{"MAXIMISATION", 12, 177106},
	{"HIGHERS", 7, 177107},
	{"OUTDIR", 6, 177108},
	{"WINALL", 6, 177109},
	{"CSHRC", 5, 177110},
	{"DOGAN", 5, 177111},
	{"INEXPRESSIBLE", 13, 177112},
	{"TOROID", 6, 177113},
	{"CAMPIGLIO", 9, 177114},
	{"BAIRSTOW", 8, 177115},
	{"PIRATA", 6, 177116},
	{"HOUK", 4, 177117},
	{"AUTOMATICALY", 12, 177118},
	{"INDIOS", 6, 177119},
	{"EFFECTIVITY", 11, 177120},
	{"BAUMA", 5, 177121},
	{"SONATE", 6, 177122},
	{"OUSTS", 5, 177123},
	{"ECLIPSYS", 8, 177124},
	{"CHERISHING", 10, 177125},
	{"LIFECARE", 8, 177126},
	{"CONTENUTI", 9, 177127},
	{"INTERCOUNTRY", 12, 177128},
	{"FINNERTY", 8, 177129},
	{"MERCURIC", 8, 177130},
	{"PAPAVER", 7, 177131},
	{"ARCMAP", 6, 177132},
	{"ELOUISE", 7, 177133},
	{"CROONING", 8, 177134},
	{"KACZMAREK", 9, 177135},
	{"ASSASINATION", 12, 177136},
	{"GEOTOOLS", 8, 177137},
	{"FOZZY", 5, 177138},
	{"BORGE", 5, 177139},
	{"MSOP", 4, 177140},
	{"CAMERONS", 8, 177141},
	{"INRUSH", 6, 177142},
	{"BREF", 4, 177143},
	{"MENES", 5, 177144},
	{"KABELS", 6, 177145},
	{"COOKSHOP", 8, 177146},
	{"MYSTERIUM", 9, 177147},
	{"MSERVER", 7, 177148},
	{"TAMBO", 5, 177149},
	{"VIEWBOOK", 8, 177150},
	{"DECALOGUE", 9, 177151},
	{"TRANSDISCIPLINARY", 17, 177152},
	{"BOWSHER", 7, 177153},
	{"REMICK", 6, 177154},
	{"BREANNA", 7, 177155},
	{"INIZIALE", 8, 177156},
	{"LIVESEY", 7, 177157},
	{"TANKING", 7, 177158},
	{"ESPRESSIONE", 11, 177159},
	{"RIGO", 4, 177160},
	{"SNOWSHWRS", 9, 177161},
	{"WINDOWSMEDIA", 12, 177162},
	{"TENGAH", 6, 177163},
	{"ECCLESTONE", 10, 177164},
	{"GOTM", 4, 177165},
	{"AFTEREFFECTS", 12, 177166},
	{"RESPECTO", 8, 177167},
	{"ZHNY", 4, 177168},
	{"ZHAL", 4, 177169},
	{"YNNL", 4, 177170},
	{"WBYB", 4, 177171},
	{"VYSI", 4, 177172},
	{"VEIP", 4, 177173},
	{"UYOS", 4, 177174},
	{"UJIK", 4, 177175},
	{"TYNC", 4, 177176},
	{"SBUE", 4, 177177},
	{"RDYD", 4, 177178},
	{"NDWB", 4, 177179},
	{"NDRN", 4, 177180},
	{"MLOB", 4, 177181},
	{"LUGW", 4, 177182},
	{"LIKT", 4, 177183},
	{"LAUW", 4, 177184},
	{"KKYL", 4, 177185},
	{"GNCI", 4, 177186},
	{"EYDM", 4, 177187},
	{"ECWS", 4, 177188},
	{"AYNR", 4, 177189},
	{"AOPR", 4, 177190},
	{"UPENN", 5, 177191},
	{"WEATHERGOTH", 11, 177192},
	{"PURSLANE", 8, 177193},
	{"NACHES", 6, 177194},
	{"LYCURGUS", 8, 177195},
	{"SPONSERED", 9, 177196},
	{"ILUMIN", 6, 177197},
	{"BEIKS", 5, 177198},
	{"SOLANACEAE", 10, 177199},
	{"ALKALIS", 7, 177200},
	{"QUARRIED", 8, 177201},
	{"VATIONS", 7, 177202},
	{"OCIAL", 5, 177203},
	{"HAMDDEN", 7, 177204},
	{"PROBATED", 8, 177205},
	{"ENTRENCHMENT", 12, 177206},
	{"DISAVOW", 7, 177207},
	{"MELOY", 5, 177208},
	{"TIMBALES", 8, 177209},
	{"HOKIE", 5, 177210},
	{"ABORTIONISTS", 12, 177211},
	{"SUNWEAR", 7, 177212},
	{"SHELAGH", 7, 177213},
	{"UPINGTON", 8, 177214},
	{"SEGALL", 6, 177215},
	{"BALEEN", 6, 177216},
	{"ECKMAN", 6, 177217},
	{"MIDDELBURG", 10, 177218},
	{"TELENET", 7, 177219},
	{"PEALS", 5, 177220},
	{"DISSAPOINTMENT", 14, 177221},
	{"PANIS", 5, 177222},
	{"IAIDO", 5, 177223},
	{"GRIDFTP", 7, 177224},
	{"GLARINGLY", 9, 177225},
	{"CARLES", 6, 177226},
	{"PETTITTE", 8, 177227},
	{"FERRYING", 8, 177228},
	{"HEADEDNESS", 10, 177229},
	{"MARIETTE", 8, 177230},
	{"YAGOO", 5, 177231},
	{"POPHAM", 6, 177232},
	{"IDXML", 5, 177233},
	{"BACKSLIDING", 11, 177234},
	{"ENDRES", 6, 177235},
	{"METALLOCENE", 11, 177236},
	{"CRCS", 4, 177237},
	{"FENELON", 7, 177238},
	{"RESOURC", 7, 177239},
	{"ZIEHEN", 6, 177240},
	{"INVESTIMENTO", 12, 177241},
	{"HELICASES", 9, 177242},
	{"MAGNETORESISTANCE", 17, 177243},
	{"LOBULAR", 7, 177244},
	{"COPERNICAN", 10, 177245},
	{"WHISKING", 8, 177246},
	{"ACAR", 4, 177247},
	{"ULTRIK", 6, 177248},
	{"DEADHEAD", 8, 177249},
	{"INHALABLE", 9, 177250},
	{"BASSISTS", 8, 177251},
	{"WANTONLY", 8, 177252},
	{"FORTA", 5, 177253},
	{"PEMBRIDGE", 9, 177254},
	{"TUTANKHAMEN", 11, 177255},
	{"LFL", 3, 177256},
	{"MURAMATSU", 9, 177257},
	{"ARPEGE", 6, 177258},
	{"DRUGGISTS", 9, 177259},
	{"ANZOR", 5, 177260},
	{"JUMA", 4, 177261},
	{"HEADWORD", 8, 177262},
	{"HARPERCHILDRENS", 15, 177263},
	{"FREIZEITDAMEN", 13, 177264},
	{"VTAL", 4, 177265},
	{"UNSV", 4, 177266},
	{"TKAG", 4, 177267},
	{"RDIU", 4, 177268},
	{"PEZC", 4, 177269},
	{"OBAV", 4, 177270},
	{"LMUM", 4, 177271},
	{"LFOY", 4, 177272},
	{"LCWA", 4, 177273},
	{"LAOD", 4, 177274},
	{"KSOD", 4, 177275},
	{"JISU", 4, 177276},
	{"IPYE", 4, 177277},
	{"IEPP", 4, 177278},
	{"IAKU", 4, 177279},
	{"HYCI", 4, 177280},
	{"GVIG", 4, 177281},
	{"FPEM", 4, 177282},
	{"FOPA", 4, 177283},
	{"FICY", 4, 177284},
	{"FCNN", 4, 177285},
	{"EZGR", 4, 177286},
	{"EDYV", 4, 177287},
	{"DEOX", 4, 177288},
	{"AZYN", 4, 177289},
	{"AKNU", 4, 177290},
	{"ACCW", 4, 177291},
	{"ABEZ", 4, 177292},
	{"BARTELL", 7, 177293},
	{"NONVOTING", 9, 177294},
	{"KASBAH", 6, 177295},
	{"ADVENTU", 7, 177296},
	{"MORTGAG", 7, 177297},
	{"INCLUSIVITY", 11, 177298},
	{"HANDFULL", 8, 177299},
	{"CHINADAILY", 10, 177300},
	{"WELFORD", 7, 177301},
	{"LYRISC", 6, 177302},
	{"MARILYNN", 8, 177303},
	{"CWESTIYNAU", 10, 177304},
	{"CFMEU", 5, 177305},
	{"BCEL", 4, 177306},
	{"SEDIS", 5, 177307},
	{"FRIEDMANS", 9, 177308},
	{"BROCH", 5, 177309},
	{"VAILE", 5, 177310},
	{"ADFINDER", 8, 177311},
	{"VIVIENDA", 8, 177312},
	{"ONLLNE", 6, 177313},
	{"CRAIC", 5, 177314},
	{"BOLINGBROKE", 11, 177315},
	{"MERANO", 6, 177316},
	{"HYDROXYPROPYL", 13, 177317},
	{"KUHLMAN", 7, 177318},
	{"INSTRUMENTE", 11, 177319},
	{"ARENDS", 6, 177320},
	{"LIDCOMBE", 8, 177321},
	{"GGOOGLE", 7, 177322},
	{"BLUNDSTONE", 10, 177323},
	{"SPEIER", 6, 177324},
	{"TRANSAXLE", 9, 177325},
	{"NEUSEELAND", 10, 177326},
	{"TRANSURANIC", 11, 177327},
	{"SUNTEC", 6, 177328},
	{"SAMOVAR", 7, 177329},
	{"TONYS", 5, 177330},
	{"SUMPS", 5, 177331},
	{"WLF", 3, 177332},
	{"ZWEIFEL", 7, 177333},
	{"BOLDITALIC", 10, 177334},
	{"GOURMETS", 8, 177335},
	{"CAIFF", 5, 177336},
	{"UNSCALED", 8, 177337},
	{"DETAINER", 8, 177338},
	{"MOFA", 4, 177339},
	{"OPPRESSES", 9, 177340},
	{"USEMULTIPLICITY", 15, 177341},
	{"HERMA", 5, 177342},
	{"VGEX", 4, 177343},
	{"THUAN", 5, 177344},
	{"NEWAYS", 6, 177345},
	{"FAMES", 5, 177346},
	{"BUYIN", 5, 177347},
	{"TOUQUET", 7, 177348},
	{"BEZUIDENHOUT", 12, 177349},
	{"BERNADINE", 9, 177350},
	{"NONMONOTONIC", 12, 177351},
	{"KOMMANDER", 9, 177352},
	{"PATCHSET", 8, 177353},
	{"BEPPO", 5, 177354},
	{"ARGE", 4, 177355},
	{"WACHTWOORD", 10, 177356},
	{"ACMS", 4, 177357},
	{"GENK", 4, 177358},
	{"GEHENNA", 7, 177359},
	{"GLEB", 4, 177360},
	{"ASOKA", 5, 177361},
	{"BEHEADINGS", 10, 177362},
	{"AGENTES", 7, 177363},
	{"NOSTER", 6, 177364},
	{"NEVOW", 5, 177365},
	{"SULZBERGER", 10, 177366},
	{"SCHWANGERSCHAFT", 15, 177367},
	{"YDLA", 4, 177368},
	{"UGOG", 4, 177369},
	{"SDFO", 4, 177370},
	{"RFAY", 4, 177371},
	{"QIND", 4, 177372},
	{"PYYO", 4, 177373},
	{"PPIG", 4, 177374},
	{"PDER", 4, 177375},
	{"OMIV", 4, 177376},
	{"OABY", 4, 177377},
	{"NIDP", 4, 177378},
	{"LIMV", 4, 177379},
	{"JOEV", 4, 177380},
	{"JCHA", 4, 177381},
	{"IPTM", 4, 177382},
	{"INPD", 4, 177383},
	{"HNLY", 4, 177384},
	{"FZHA", 4, 177385},
	{"CLYH", 4, 177386},
	{"BYDC", 4, 177387},
	{"AFSF", 4, 177388},
	{"YORN", 4, 177389},
	{"PERIPHERALLY", 12, 177390},
	{"ESCHEWS", 7, 177391},
	{"SMILIESPLUGIN", 13, 177392},
	{"FUTURECOM", 9, 177393},
	{"FOOTSTEP", 8, 177394},
	{"BIOPHARM", 8, 177395},
	{"STEWING", 7, 177396},
	{"PCDD", 4, 177397},
	{"MIKRO", 5, 177398},
	{"VORES", 5, 177399},
	{"HETEROSTRUCTURES", 16, 177400},
	{"USELONGDOUBLE", 13, 177401},
	{"DEGREED", 7, 177402},
	{"SCHNEE", 6, 177403},
	{"BIDIR", 5, 177404},
	{"YASER", 5, 177405},
	{"ARTHAUS", 7, 177406},
	{"SUITEMEDIA", 10, 177407},
	{"THREADNEEDLE", 12, 177408},
	{"BEWICK", 6, 177409},
	{"LEVIT", 5, 177410},
	{"CHLAMYDOPHILA", 13, 177411},
	{"FRITTATAS", 9, 177412},
	{"LOXAHATCHEE", 11, 177413},
	{"MANUFACT", 8, 177414},
	{"VIEWMOL", 7, 177415},
	{"SWBT", 4, 177416},
	{"CULTUUR", 7, 177417},
	{"ACRIMONY", 8, 177418},
	{"MMIC", 4, 177419},
	{"HYPONATREMIA", 12, 177420},
	{"MALPAS", 6, 177421},
	{"BRISTLY", 7, 177422},
	{"RAAM", 4, 177423},
	{"LENSMASTER", 10, 177424},
	{"HERPETOLOGICAL", 14, 177425},
	{"SNRNP", 5, 177426},
	{"PERIODONTOLOGY", 14, 177427},
	{"CRAWFORDVILLE", 13, 177428},
	{"AUSSER", 6, 177429},
	{"AMJAD", 5, 177430},
	{"LOCKJAW", 7, 177431},
	{"IDDYNT", 6, 177432},
	{"UNDERACHIEVING", 14, 177433},
	{"LOGICACMG", 9, 177434},
	{"SALUS", 5, 177435},
	{"BUILDDIR", 8, 177436},
	{"TERMIN", 6, 177437},
	{"LIRR", 4, 177438},
	{"GIBNEY", 6, 177439},
	{"ENGADINE", 8, 177440},
	{"ULD", 3, 177441},
	{"DEMONIZED", 9, 177442},
	{"LOWRIE", 6, 177443},
	{"STARNET", 7, 177444},
	{"SOEVER", 6, 177445},
	{"ESLER", 5, 177446},
	{"NETHERTON", 9, 177447},
	{"KNOTWEED", 8, 177448},
	{"SOUNDBRIDGE", 11, 177449},
	{"TYPOLOGICAL", 11, 177450},
	{"SCHAKOWSKY", 10, 177451},
	{"CENTEREACH", 10, 177452},
	{"VIRTUS", 6, 177453},
	{"ROTRING", 7, 177454},
	{"HERAS", 5, 177455},
	{"DINNERTIME", 10, 177456},
	{"HOLLI", 5, 177457},
	{"CHITWOOD", 8, 177458},
	{"ACQUISTI", 8, 177459},
	{"FEATRON", 7, 177460},
	{"PVFS", 4, 177461},
	{"TRACINGS", 8, 177462},
	{"CDFS", 4, 177463},
	{"WHEATSHEAF", 10, 177464},
	{"COMPEN", 6, 177465},
	{"RUEFULLY", 8, 177466},
	{"LEVINAS", 7, 177467},
	{"FERRIE", 6, 177468},
	{"UNFAVORABLY", 11, 177469},
	{"INTEVA", 6, 177470},
	{"ROWSTATUS", 9, 177471},
	{"RACV", 4, 177472},
	{"YARA", 4, 177473},
	{"ZLOS", 4, 177474},
	{"ZCOR", 4, 177475},
	{"YRIM", 4, 177476},
	{"XMAJ", 4, 177477},
	{"XIUS", 4, 177478},
	{"WOJE", 4, 177479},
	{"WIIB", 4, 177480},
	{"WEYO", 4, 177481},
	{"SMOY", 4, 177482},
	{"SFCO", 4, 177483},
	{"RZHO", 4, 177484},
	{"RYEB", 4, 177485},
	{"PPEM", 4, 177486},
	{"PNOV", 4, 177487},
	{"PHDP", 4, 177488},
	{"PCSH", 4, 177489},
	{"OZYW", 4, 177490},
	{"OVIP", 4, 177491},
	{"OMCS", 4, 177492},
	{"OHUB", 4, 177493},
	{"MLBT", 4, 177494},
	{"MBAO", 4, 177495},
	{"LYSJ", 4, 177496},
	{"LCST", 4, 177497},
	{"KULK", 4, 177498},
	{"HOMK", 4, 177499},
	{"HBIK", 4, 177500},
	{"GCEA", 4, 177501},
	{"FSCL", 4, 177502},
	{"FILH", 4, 177503},
	{"EDUW", 4, 177504},
	{"EDFB", 4, 177505},
	{"DAPM", 4, 177506},
	{"CMYT", 4, 177507},
	{"AMMR", 4, 177508},
	{"ADOJ", 4, 177509},
	{"SLOTHFUL", 8, 177510},
	{"NVSIZE", 6, 177511},
	{"POSSESION", 9, 177512},
	{"OCULOMOTOR", 10, 177513},
	{"WEBBIE", 6, 177514},
	{"MIKULA", 6, 177515},
	{"MALENY", 6, 177516},
	{"HOPKIN", 6, 177517},
	{"BLANCHET", 8, 177518},
	{"GENCO", 5, 177519},
	{"HALLUCINOGEN", 12, 177520},
	{"ANYTHIN", 7, 177521},
	{"MUSTIQUE", 8, 177522},
	{"TOMFOOLERY", 10, 177523},
	{"PENTANE", 7, 177524},
	{"ROSCOFF", 7, 177525},
	{"BIBLIOG", 7, 177526},
	{"ALTERNATIV", 10, 177527},
	{"VARGO", 5, 177528},
	{"REICHL", 6, 177529},
	{"MUK", 3, 177530},
	{"DIEP", 4, 177531},
	{"CONURE", 6, 177532},
	{"PROPERTYNAME", 12, 177533},
	{"KOMPONENTEN", 11, 177534},
	{"CGCCA", 5, 177535},
	{"UNBELIEVEABLE", 13, 177536},
	{"SDAISA", 6, 177537},
	{"MCBURNEY", 8, 177538},
	{"LUMBY", 5, 177539},
	{"IVTYPE", 6, 177540},
	{"OUGH", 4, 177541},
	{"EXHORTS", 7, 177542},
	{"DUBSTEP", 7, 177543},
	{"MIEGO", 5, 177544},
	{"TABBER", 6, 177545},
	{"SHINOHARA", 9, 177546},
	{"RUTHLESSNESS", 12, 177547},
	{"SEDNA", 5, 177548},
	{"BWYD", 4, 177549},
	{"TEXREG", 6, 177550},
	{"SHAKESPEAR", 10, 177551},
	{"DECEDENTS", 9, 177552},
	{"ISOCITRATE", 10, 177553},
	{"JAYMES", 6, 177554},
	{"MONTEZ", 6, 177555},
	{"MOLOCH", 6, 177556},
	{"MEADOWVIEW", 10, 177557},
	{"USESOCKS", 8, 177558},
	{"ROBSTOWN", 8, 177559},
	{"VINYASA", 7, 177560},
	{"GETPID", 6, 177561},
	{"DRIBBLED", 8, 177562},
	{"BIGEYE", 6, 177563},
	{"MBLOG", 5, 177564},
	{"FULLBYPASSTEST", 14, 177565},
	{"EDCI", 4, 177566},
	{"EPIGRAM", 7, 177567},
	{"EBESTMATCH", 10, 177568},
	{"MUONLINE", 8, 177569},
	{"FORTNEY", 7, 177570},
	{"ANAGLYPH", 8, 177571},
	{"SIMKIN", 6, 177572},
	{"DIGITRA", 7, 177573},
	{"PULTENEY", 8, 177574},
	{"CXR", 3, 177575},
	{"ENGELSCHALL", 11, 177576},
	{"ASPNETMENU", 10, 177577},
	{"TURKIJE", 7, 177578},
	{"TAMINO", 6, 177579},
	{"STAPLEFORD", 10, 177580},
	{"KEUKA", 5, 177581},
	{"FURLA", 5, 177582},
	{"AWAMI", 5, 177583},
	{"WLEMB", 5, 177584},
	{"UNGLUED", 7, 177585},
	{"POMPADOUR", 9, 177586},
	{"PESCADOR", 8, 177587},
	{"FERIE", 5, 177588},
	{"PDAIR", 5, 177589},
	{"NVTYPE", 6, 177590},
	{"DESIGNINFO", 10, 177591},
	{"RAFUSE", 6, 177592},
	{"ANALISIS", 8, 177593},
	{"GERRYMANDERING", 14, 177594},
	{"WATERKANT", 9, 177595},
	{"STAUBACH", 8, 177596},
	{"WAFTED", 6, 177597},
	{"TEJON", 5, 177598},
	{"KEEPE", 5, 177599},
	{"EXTROVERTED", 11, 177600},
	{"MSLP", 4, 177601},
	{"BODIN", 5, 177602},
	{"EXPENDS", 7, 177603},
	{"DRAYCOTT", 8, 177604},
	{"CERNS", 5, 177605},
	{"YFUC", 4, 177606},
	{"XICE", 4, 177607},
	{"UBOY", 4, 177608},
	{"SLSQ", 4, 177609},
	{"SFOW", 4, 177610},
	{"SCBC", 4, 177611},
	{"RGPU", 4, 177612},
	{"POQU", 4, 177613},
	{"OLFV", 4, 177614},
	{"OGIU", 4, 177615},
	{"MUGL", 4, 177616},
	{"MDYI", 4, 177617},
	{"MCBU", 4, 177618},
	{"LPKI", 4, 177619},
	{"KAER", 4, 177620},
	{"ILKL", 4, 177621},
	{"IDAZ", 4, 177622},
	{"ICGY", 4, 177623},
	{"HLOD", 4, 177624},
	{"HIGR", 4, 177625},
	{"EDVR", 4, 177626},
	{"DOTM", 4, 177627},
	{"BFUN", 4, 177628},
	{"AQIB", 4, 177629},
	{"AFFJ", 4, 177630},
	{"AECK", 4, 177631},
	{"WASHINGTONVILLE", 15, 177632},
	{"GOLDE", 5, 177633},
	{"ALLSOPP", 7, 177634},
	{"SCHILLINGS", 10, 177635},
	{"HOTLYRICS", 9, 177636},
	{"DEHP", 4, 177637},
	{"UDIT", 4, 177638},
	{"TABELA", 6, 177639},
	{"PUCH", 4, 177640},
	{"IUNKNOWN", 8, 177641},
	{"NOTTOWAY", 8, 177642},
	{"HAVP", 4, 177643},
	{"BARDZO", 6, 177644},
	{"NCDOT", 5, 177645},
	{"HARDORE", 7, 177646},
	{"GONCALVES", 9, 177647},
	{"ONIINE", 6, 177648},
	{"ALOG", 4, 177649},
	{"WERTHER", 7, 177650},
	{"REASSURINGLY", 12, 177651},
	{"LAMS", 4, 177652},
	{"THWARTS", 7, 177653},
	{"BAULE", 5, 177654},
	{"AZARIAH", 7, 177655},
	{"MELATI", 6, 177656},
	{"BACKHOES", 8, 177657},
	{"QLIKVIEW", 8, 177658},
	{"UNISOG", 6, 177659},
	{"YWHOO", 5, 177660},
	{"SNARLS", 6, 177661},
	{"HAZLEWOOD", 9, 177662},
	{"PHENTAMINE", 10, 177663},
	{"GYNT", 4, 177664},
	{"PANAMSAT", 8, 177665},
	{"PISUM", 5, 177666},
	{"SCARP", 5, 177667},
	{"DHFS", 4, 177668},
	{"DELF", 4, 177669},
	{"SWAFFHAM", 8, 177670},
	{"CALABI", 6, 177671},
	{"EBULLETIN", 9, 177672},
	{"CHEONGSAM", 9, 177673},
	{"TYCOONS", 7, 177674},
	{"UDYOG", 5, 177675},
	{"STAATS", 6, 177676},
	{"NAKITA", 6, 177677},
	{"FULLING", 7, 177678},
	{"BOROS", 5, 177679},
	{"OTHERSIDE", 9, 177680},
	{"ZONTA", 5, 177681},
	{"BASTOGNE", 8, 177682},
	{"USHPIZIN", 8, 177683},
	{"PLEASENT", 8, 177684},
	{"SHERBOURNE", 10, 177685},
	{"DITHIOTHREITOL", 14, 177686},
	{"SUBSIDISING", 11, 177687},
	{"SHIJIAZHUANG", 12, 177688},
	{"NARNIAWEB", 9, 177689},
	{"BUNCHE", 6, 177690},
	{"PRECLUSION", 10, 177691},
	{"GAROTO", 6, 177692},
	{"KURO", 4, 177693},
	{"KATEGORIER", 10, 177694},
	{"JEDENFALLS", 10, 177695},
	{"POINSETT", 8, 177696},
	{"HELLION", 7, 177697},
	{"PERSPEC", 7, 177698},
	{"KHOSLA", 6, 177699},
	{"JAKI", 4, 177700},
	{"ABHORRED", 8, 177701},
	{"UNCALIBRATED", 12, 177702},
	{"CISPR", 5, 177703},
	{"APOIO", 5, 177704},
	{"LITHOS", 6, 177705},
	{"DITTMER", 7, 177706},
	{"TSTRING", 7, 177707},
	{"MIDCOAST", 8, 177708},
	{"KLOCK", 5, 177709},
	{"CAVY", 4, 177710},
	{"CMY", 3, 177711},
	{"YOSM", 4, 177712},
	{"WGUE", 4, 177713},
	{"WBIK", 4, 177714},
	{"UKIB", 4, 177715},
	{"UEKA", 4, 177716},
	{"OCAJ", 4, 177717},
	{"NOLW", 4, 177718},
	{"NACW", 4, 177719},
	{"MXIC", 4, 177720},
	{"LPEC", 4, 177721},
	{"HEZF", 4, 177722},
	{"GVIB", 4, 177723},
	{"GOPD", 4, 177724},
	{"FSYO", 4, 177725},
	{"EXYO", 4, 177726},
	{"ERRV", 4, 177727},
	{"EBAX", 4, 177728},
	{"DWOK", 4, 177729},
	{"DNYS", 4, 177730},
	{"CLAH", 4, 177731},
	{"APBI", 4, 177732},
	{"AAFW", 4, 177733},
	{"PIVOTED", 7, 177734},
	{"GROWNUP", 7, 177735},
	{"ZEIGT", 5, 177736},
	{"ALGE", 4, 177737},
	{"NECCESARY", 9, 177738},
	{"LUNGEN", 6, 177739},
	{"GLOBULINS", 9, 177740},
	{"BAROMTEC", 8, 177741},
	{"NITROPRUSSIDE", 13, 177742},
	{"SNAFFLE", 7, 177743},
	{"MISCIBLE", 8, 177744},
	{"DOWNPLAYING", 11, 177745},
	{"BEVILACQUA", 10, 177746},
	{"BELWITH", 7, 177747},
	{"MOLLIS", 6, 177748},
	{"INKLUSIVE", 9, 177749},
	{"CITADELS", 8, 177750},
	{"REINTRODUCING", 13, 177751},
	{"INTERGRATION", 12, 177752},
	{"DEMENTIEVA", 10, 177753},
	{"SPEKE", 5, 177754},
	{"IMMOBILIZE", 10, 177755},
	{"ESTRONE", 7, 177756},
	{"TESSERA", 7, 177757},
	{"SOLLTEN", 7, 177758},
	{"ROHINI", 6, 177759},
	{"SUPERMULTI", 10, 177760},
	{"MISLEADS", 8, 177761},
	{"GAMMAGE", 7, 177762},
	{"PHOTOBID", 8, 177763},
	{"HAICOM", 6, 177764},
	{"VULPES", 6, 177765},
	{"SVIDEO", 6, 177766},
	{"YAUOO", 5, 177767},
	{"BRISA", 5, 177768},
	{"UNCULTURED", 10, 177769},
	{"LIMAN", 5, 177770},
	{"ENDP", 4, 177771},
	{"CONQUISTADORS", 13, 177772},
	{"PAILLARD", 8, 177773},
	{"RIESIGE", 7, 177774},
	{"COIF", 4, 177775},
	{"PICKAWAY", 8, 177776},
	{"CAPTIVATES", 10, 177777},
	{"SOUNDSTORM", 10, 177778},
	{"MURCH", 5, 177779},
	{"CATALANA", 8, 177780},
	{"ERMANNO", 7, 177781},
	{"HORNBECK", 8, 177782},
	{"CINEMATOGRAPHIC", 15, 177783},
	{"SEQUESTER", 9, 177784},
	{"IBIZAN", 6, 177785},
	{"IMAMURA", 7, 177786},
	{"PLATTING", 8, 177787},
	{"NOWICKI", 7, 177788},
	{"JOBLINE", 7, 177789},
	{"DAHOMEY", 7, 177790},
	{"MOCPAGES", 8, 177791},
	{"GOREE", 5, 177792},
	{"SCHWINGER", 9, 177793},
	{"MOXY", 4, 177794},
	{"TESSIE", 6, 177795},
	{"LEBOMBO", 7, 177796},
	{"ANGLESEA", 8, 177797},
	{"WHATELY", 7, 177798},
	{"WEISSMANN", 9, 177799},
	{"ORTHOPTERA", 10, 177800},
	{"NROW", 4, 177801},
	{"FRONTIS", 7, 177802},
	{"BURSTYN", 7, 177803},
	{"CMNT", 4, 177804},
	{"REPOSSESS", 9, 177805},
	{"DECISIONMAKERS", 14, 177806},
	{"CONSTRICTING", 12, 177807},
	{"SEVIEWER", 8, 177808},
	{"CALORIFIC", 9, 177809},
	{"GOFFMAN", 7, 177810},
	{"CEIVA", 5, 177811},
	{"IADB", 4, 177812},
	{"DALLARA", 7, 177813},
	{"CDHS", 4, 177814},
	{"UPSTAGE", 7, 177815},
	{"HINDE", 5, 177816},
	{"COINTREAU", 9, 177817},
	{"MALTHOUSE", 9, 177818},
	{"FIBROCYSTIC", 11, 177819},
	{"DWIE", 4, 177820},
	{"STUPAK", 6, 177821},
	{"ESTROUS", 7, 177822},
	{"DENES", 5, 177823},
	{"XORD", 4, 177824},
	{"UDUP", 4, 177825},
	{"SPDE", 4, 177826},
	{"SAVU", 4, 177827},
	{"RSYF", 4, 177828},
	{"ROGD", 4, 177829},
	{"RGCI", 4, 177830},
	{"RCBE", 4, 177831},
	{"PUBM", 4, 177832},
	{"PEXH", 4, 177833},
	{"NNDP", 4, 177834},
	{"NKVO", 4, 177835},
	{"MMRA", 4, 177836},
	{"MAIW", 4, 177837},
	{"LAIF", 4, 177838},
	{"IXQU", 4, 177839},
	{"ILSJ", 4, 177840},
	{"IKDE", 4, 177841},
	{"HAUX", 4, 177842},
	{"HAGM", 4, 177843},
	{"FFIW", 4, 177844},
	{"EDNG", 4, 177845},
	{"BPIN", 4, 177846},
	{"AMPV", 4, 177847},
	{"OSTEOBLAST", 10, 177848},
	{"WORKETH", 7, 177849},
	{"THAXTON", 7, 177850},
	{"VOJTECH", 7, 177851},
	{"IONICS", 6, 177852},
	{"GEEKQUESTIONS", 13, 177853},
	{"CERVEZA", 7, 177854},
	{"YAKUTSK", 7, 177855},
	{"ELECTROSHOCK", 12, 177856},
	{"SINTESI", 7, 177857},
	{"MOVLW", 5, 177858},
	{"ALTECH", 6, 177859},
	{"PUNCTURING", 10, 177860},
	{"SHAKEUP", 7, 177861},
	{"MILW", 4, 177862},
	{"ZOETROPE", 8, 177863},
	{"TRANSESOPHAGEAL", 15, 177864},
	{"STOPGAP", 7, 177865},
	{"LANGLAUFING", 11, 177866},
	{"NIRMAL", 6, 177867},
	{"PHOSPHORESCENT", 14, 177868},
	{"DFAT", 4, 177869},
	{"LSEEKSIZE", 9, 177870},
	{"WHATWG", 6, 177871},
	{"BELGAUM", 7, 177872},
	{"ADENOCARCINOMAS", 15, 177873},
	{"VEJLE", 5, 177874},
	{"MAINES", 6, 177875},
	{"ELIG", 4, 177876},
	{"FOOTRESTS", 9, 177877},
	{"LILIANE", 7, 177878},
	{"VULPUTATE", 9, 177879},
	{"VERACHTERT", 10, 177880},
	{"SUBMODELS", 9, 177881},
	{"PICCIES", 7, 177882},
	{"KINDERSTRICH", 12, 177883},
	{"INCHOATE", 8, 177884},
	{"PETTIBONE", 9, 177885},
	{"SURTAX", 6, 177886},
	{"MANTI", 5, 177887},
	{"CULLEY", 6, 177888},
	{"EDAMAME", 7, 177889},
	{"BOURNS", 6, 177890},
	{"MUSHROOMING", 11, 177891},
	{"INCES", 5, 177892},
	{"BANDRA", 6, 177893},
	{"SHURIKEN", 8, 177894},
	{"POLYMERISATION", 14, 177895},
	{"INFL", 4, 177896},
	{"LUBBERS", 7, 177897},
	{"UNASHAMEDLY", 11, 177898},
	{"ORDBOK", 6, 177899},
	{"ANECHOIC", 8, 177900},
	{"MICRONESIAN", 11, 177901},
	{"WATERBIRD", 9, 177902},
	{"FOTOMODELL", 10, 177903},
	{"FAGUS", 5, 177904},
	{"BELLUNO", 7, 177905},
	{"BARRAMUNDI", 10, 177906},
	{"SPYROS", 6, 177907},
	{"FIRINGSQUAD", 11, 177908},
	{"CAFOD", 5, 177909},
	{"RELINK", 6, 177910},
	{"SCATTERPLOT", 11, 177911},
	{"SAUNTERED", 9, 177912},
	{"FOUNDLING", 9, 177913},
	{"POTVIN", 6, 177914},
	{"SPARLING", 8, 177915},
	{"WEIBEL", 6, 177916},
	{"NAKEDWOMEN", 10, 177917},
	{"HEIRARCHY", 9, 177918},
	{"RETRYING", 8, 177919},
	{"ILLIBERAL", 9, 177920},
	{"BREADSTICKS", 11, 177921},
	{"CRAFTMANSHIP", 12, 177922},
	{"VALEN", 5, 177923},
	{"EBOOKSTORE", 10, 177924},
	{"CYPHERS", 7, 177925},
	{"COLDEN", 6, 177926},
	{"DESERTING", 9, 177927},
	{"LENTO", 5, 177928},
	{"HOLTS", 5, 177929},
	{"STATIONER", 9, 177930},
	{"ZRAH", 4, 177931},
	{"YXII", 4, 177932},
	{"XLEF", 4, 177933},
	{"USDT", 4, 177934},
	{"TIFJ", 4, 177935},
	{"SJRW", 4, 177936},
	{"OWKO", 4, 177937},
	{"OTMR", 4, 177938},
	{"OMYY", 4, 177939},
	{"OMGH", 4, 177940},
	{"NLCE", 4, 177941},
	{"NGXM", 4, 177942},
	{"MAMH", 4, 177943},
	{"LPGI", 4, 177944},
	{"LOMP", 4, 177945},
	{"LIUT", 4, 177946},
	{"KOSD", 4, 177947},
	{"GYAK", 4, 177948},
	{"FKEP", 4, 177949},
	{"ESYP", 4, 177950},
	{"EPUK", 4, 177951},
	{"BEEU", 4, 177952},
	{"AKYT", 4, 177953},
	{"AGHM", 4, 177954},
	{"LATING", 6, 177955},
	{"NEWYEAR", 7, 177956},
	{"KEARSARGE", 9, 177957},
	{"ETHICISTS", 9, 177958},
	{"CEREBRO", 7, 177959},
	{"IMEC", 4, 177960},
	{"KNUD", 4, 177961},
	{"EPIL", 4, 177962},
	{"PERKASIE", 8, 177963},
	{"ALBINISM", 8, 177964},
	{"DOUCHEBAG", 9, 177965},
	{"MANDELBAUM", 10, 177966},
	{"KAUTZ", 5, 177967},
	{"PROBOT", 6, 177968},
	{"ONLOOKER", 8, 177969},
	{"FIREBRICK", 9, 177970},
	{"BEANUTILS", 9, 177971},
	{"YPARXEI", 7, 177972},
	{"DEATHLESS", 9, 177973},
	{"LINGUAPHONE", 11, 177974},
	{"PAEZ", 4, 177975},
	{"IMMERSES", 8, 177976},
	{"COLLEGIANS", 10, 177977},
	{"CARPATHIANS", 11, 177978},
	{"BUSSING", 7, 177979},
	{"MULTIPLEXOR", 11, 177980},
	{"CABL", 4, 177981},
	{"GARBANZO", 8, 177982},
	{"OCCA", 4, 177983},
	{"TRINKA", 6, 177984},
	{"LYRICE", 6, 177985},
	{"KOYO", 4, 177986},
	{"AWIPS", 5, 177987},
	{"GRAIG", 5, 177988},
	{"SONOGRAPHER", 11, 177989},
	{"TARSAL", 6, 177990},
	{"PUBLICAR", 8, 177991},
	{"VERVIEW", 7, 177992},
	{"CATALOGERS", 10, 177993},
	{"AGALACTIAE", 10, 177994},
	{"GENELYNX", 8, 177995},
	{"FACI", 4, 177996},
	{"PETRELS", 7, 177997},
	{"MENTING", 7, 177998},
	{"CHLOROFLUOROCARBONS", 19, 177999},
	{"RINGWORK", 8, 178000},
	{"ALBY", 4, 178001},
	{"ESEMPIO", 7, 178002},
	{"BLUEAIR", 7, 178003},
	{"KBUILD", 6, 178004},
	{"TABID", 5, 178005},
	{"PCWARE", 6, 178006},
	{"NUOC", 4, 178007},
	{"ZUSAMMENARBEIT", 14, 178008},
	{"OLFA", 4, 178009},
	{"CHOISISSEZ", 10, 178010},
	{"SWATHNAME", 9, 178011},
	{"WEBSIDESTORY", 12, 178012},
	{"EXISITING", 9, 178013},
	{"AFETY", 5, 178014},
	{"ARDFERN", 7, 178015},
	{"CERTIFIERS", 10, 178016},
	{"WIRLESS", 7, 178017},
	{"OURO", 4, 178018},
	{"LATTICEPOINT", 12, 178019},
	{"ARCHTEC", 7, 178020},
	{"DARNDEST", 8, 178021},
	{"ASCENTIS", 8, 178022},
	{"DINITRATE", 9, 178023},
	{"POPWATCH", 8, 178024},
	{"ASSURER", 7, 178025},
	{"AIRFLO", 6, 178026},
	{"FORAMS", 6, 178027},
	{"EISENMAN", 8, 178028},
	{"GORDEN", 6, 178029},
	{"RADIOMETRICCORRTABLE", 20, 178030},
	{"TYMES", 5, 178031},
	{"BEASLEYS", 8, 178032},
	{"ISENTROPIC", 10, 178033},
	{"COACTIVATOR", 11, 178034},
	{"LONGHOUSE", 9, 178035},
	{"HJELP", 5, 178036},
	{"AGEL", 4, 178037},
	{"TEKENINGEN", 10, 178038},
	{"OFTHIS", 6, 178039},
	{"RIDGEMONT", 9, 178040},
	{"BEHAVIORIST", 11, 178041},
	{"LIFTGATE", 8, 178042},
	{"WONTON", 6, 178043},
	{"REABSORPTION", 12, 178044},
	{"OASYS", 5, 178045},
	{"ZEJU", 4, 178046},
	{"XYSE", 4, 178047},
	{"WIGV", 4, 178048},
	{"WCEM", 4, 178049},
	{"VIXE", 4, 178050},
	{"VBEG", 4, 178051},
	{"UTDY", 4, 178052},
	{"TJOC", 4, 178053},
	{"THFC", 4, 178054},
	{"SUPK", 4, 178055},
	{"PMYF", 4, 178056},
	{"PKAR", 4, 178057},
	{"OLZE", 4, 178058},
	{"OJMA", 4, 178059},
	{"NPUZ", 4, 178060},
	{"NHLF", 4, 178061},
	{"MKON", 4, 178062},
	{"LLNC", 4, 178063},
	{"LLEZ", 4, 178064},
	{"KYSF", 4, 178065},
	{"KLID", 4, 178066},
	{"IEDZ", 4, 178067},
	{"ICUA", 4, 178068},
	{"GUMT", 4, 178069},
	{"GPUC", 4, 178070},
	{"FYCA", 4, 178071},
	{"FUKA", 4, 178072},
	{"EGKI", 4, 178073},
	{"EAFD", 4, 178074},
	{"DMSM", 4, 178075},
	{"BYEQ", 4, 178076},
	{"BOSR", 4, 178077},
	{"BIDG", 4, 178078},
	{"ALOZ", 4, 178079},
	{"AKVA", 4, 178080},
	{"AJKA", 4, 178081},
	{"CANADIANA", 9, 178082},
	{"OUTFRONT", 8, 178083},
	{"GHOSE", 5, 178084},
	{"BRERA", 5, 178085},
	{"BACKBOARDS", 10, 178086},
	{"SCANDINAVIANS", 13, 178087},
	{"MAROUBRA", 8, 178088},
	{"GOUDIE", 6, 178089},
	{"SALW", 4, 178090},
	{"BERRYMORE", 9, 178091},
	{"UNCOUPLED", 9, 178092},
	{"SELATAN", 7, 178093},
	{"EVERYTHINGHOME", 14, 178094},
	{"PREMIOS", 7, 178095},
	{"NEWLIN", 6, 178096},
	{"INTERLOCHEN", 11, 178097},
	{"LEGATE", 6, 178098},
	{"INFLORESCENCES", 14, 178099},
	{"COMPANYTYPE", 11, 178100},
	{"MORPHER", 7, 178101},
	{"HOTBIRD", 7, 178102},
	{"DEICING", 7, 178103},
	{"DISSUADED", 9, 178104},
	{"MALIAN", 6, 178105},
	{"FORMU", 5, 178106},
	{"CLASSIX", 7, 178107},
	{"MCKISSACK", 9, 178108},
	{"EROICA", 6, 178109},
	{"MIKAN", 5, 178110},
	{"ROUNDWOOD", 9, 178111},
	{"ONTACT", 6, 178112},
	{"QUATECH", 7, 178113},
	{"INSTALLPATCH", 12, 178114},
	{"SUBSCRIPTIONSSITES", 18, 178115},
	{"ROYALSTON", 9, 178116},
	{"WMK", 3, 178117},
	{"GPFS", 4, 178118},
	{"NEWSPAGE", 8, 178119},
	{"MOSUNNY", 7, 178120},
	{"GASTROENTEROLOGIST", 18, 178121},
	{"FOGELBERG", 9, 178122},
	{"PALED", 5, 178123},
	{"ASCRIBES", 8, 178124},
	{"SILYMARIN", 9, 178125},
	{"RINGLE", 6, 178126},
	{"BENEDICTUS", 10, 178127},
	{"CHINH", 5, 178128},
	{"MOOCH", 5, 178129},
	{"HORNSTR", 7, 178130},
	{"HEARTHS", 7, 178131},
	{"ENDY", 4, 178132},
	{"TANGLING", 8, 178133},
	{"FIRSTTIME", 9, 178134},
	{"TREADLE", 7, 178135},
	{"DRAMATIZE", 9, 178136},
	{"NIFOS", 5, 178137},
	{"FASL", 4, 178138},
	{"MSIC", 4, 178139},
	{"HISCOCK", 7, 178140},
	{"HEARTHSIDE", 10, 178141},
	{"ZYWALL", 6, 178142},
	{"APPAR", 5, 178143},
	{"RWM", 3, 178144},
	{"FSCANF", 6, 178145},
	{"OUTRAS", 6, 178146},
	{"VIDEOPROJECTOR", 14, 178147},
	{"OCLOCK", 6, 178148},
	{"HOWTH", 5, 178149},
	{"SUBVENTION", 10, 178150},
	{"LAUFER", 6, 178151},
	{"DONATOR", 7, 178152},
	{"DULLER", 6, 178153},
	{"DISPOSITIVOS", 12, 178154},
	{"GAPINGVOID", 10, 178155},
	{"FEMINISED", 9, 178156},
	{"TEILHARD", 8, 178157},
	{"ARLY", 4, 178158},
	{"DISCOVERERS", 11, 178159},
	{"DBCC", 4, 178160},
	{"BEIJO", 5, 178161},
	{"PAGS", 4, 178162},
	{"BENEVENTO", 9, 178163},
	{"MECHATRONIC", 11, 178164},
	{"GATEAU", 6, 178165},
	{"SAWBRIDGEWORTH", 14, 178166},
	{"RAKEBACK", 8, 178167},
	{"TRABANT", 7, 178168},
	{"STRAWBS", 7, 178169},
	{"SIGHTEDNESS", 11, 178170},
	{"FURLED", 6, 178171},
	{"YSRS", 4, 178172},
	{"YPUC", 4, 178173},
	{"YEUN", 4, 178174},
	{"XIED", 4, 178175},
	{"WMEC", 4, 178176},
	{"WAJU", 4, 178177},
	{"VPOW", 4, 178178},
	{"URDH", 4, 178179},
	{"UGEJ", 4, 178180},
	{"TKLI", 4, 178181},
	{"SWOF", 4, 178182},
	{"SPYM", 4, 178183},
	{"REWQ", 4, 178184},
	{"OJED", 4, 178185},
	{"NKUC", 4, 178186},
	{"MAHC", 4, 178187},
	{"LZMA", 4, 178188},
	{"LAAW", 4, 178189},
	{"IKBA", 4, 178190},
	{"IDYP", 4, 178191},
	{"IAUD", 4, 178192},
	{"HGAZ", 4, 178193},
	{"GOBT", 4, 178194},
	{"GIGL", 4, 178195},
	{"DOLR", 4, 178196},
	{"DKUB", 4, 178197},
	{"COBP", 4, 178198},
	{"CAKA", 4, 178199},
	{"AXGR", 4, 178200},
	{"LUDWIGSHAFEN", 12, 178201},
	{"ALKI", 4, 178202},
	{"STUPIDER", 8, 178203},
	{"JOUNI", 5, 178204},
	{"CHIAROSCURO", 11, 178205},
	{"DENKEN", 6, 178206},
	{"CAMINOS", 7, 178207},
	{"DSQUARED", 8, 178208},
	{"BLAUVELT", 8, 178209},
	{"CARINO", 6, 178210},
	{"USERLIST", 8, 178211},
	{"EURAX", 5, 178212},
	{"DROPOFF", 7, 178213},
	{"LEAVENED", 8, 178214},
	{"FICKT", 5, 178215},
	{"DTSEARCH", 8, 178216},
	{"PARTMAN", 7, 178217},
	{"MAGNON", 6, 178218},
	{"DIMOCK", 6, 178219},
	{"COGGESHALL", 10, 178220},
	{"TOCOPHERYL", 10, 178221},
	{"ALTERN", 6, 178222},
	{"SPARXX", 6, 178223},
	{"RASHMI", 6, 178224},
	{"ESDRAS", 6, 178225},
	{"SONNENSTUDIOCAM", 15, 178226},
	{"OBSERVATIONTIME", 15, 178227},
	{"GADIS", 5, 178228},
	{"UTILIZAR", 8, 178229},
	{"GIMMICKY", 8, 178230},
	{"AMMANFORD", 9, 178231},
	{"CLAVES", 6, 178232},
	{"CARACOL", 7, 178233},
	{"TYPIFY", 6, 178234},
	{"ARTGAZEBO", 9, 178235},
	{"PROPULSIVE", 10, 178236},
	{"SHELLIE", 7, 178237},
	{"WRITIN", 6, 178238},
	{"FURLAN", 6, 178239},
	{"IDLED", 5, 178240},
	{"TROF", 4, 178241},
	{"NOBODIES", 8, 178242},
	{"PRECONDITIONED", 14, 178243},
	{"BELLICOSE", 9, 178244},
	{"ANTEQUERA", 9, 178245},
	{"VILLAGGIO", 9, 178246},
	{"SCLK", 4, 178247},
	{"HYPOGONADISM", 12, 178248},
	{"CRYPTOGRAM", 10, 178249},
	{"PXL", 3, 178250},
	{"GELERT", 6, 178251},
	{"REDBANK", 7, 178252},
	{"MCQUADE", 7, 178253},
	{"STRRCHR", 7, 178254},
	{"GOOGLECOM", 9, 178255},
	{"BOOTER", 6, 178256},
	{"LYRICSFIND", 10, 178257},
	{"FERRUGINOUS", 11, 178258},
	{"ETISALAT", 8, 178259},
	{"GANZEN", 6, 178260},
	{"EXAR", 4, 178261},
	{"STANDPIPE", 9, 178262},
	{"TUYEN", 5, 178263},
	{"BOTTOMLINEPRICE", 15, 178264},
	{"PHASEOUT", 8, 178265},
	{"YMWNEUD", 7, 178266},
	{"TORMOD", 6, 178267},
	{"MUFFLE", 6, 178268},
	{"YACHATS", 7, 178269},
	{"EVEYONE", 7, 178270},
	{"BTLS", 4, 178271},
	{"CONTENTSLINE", 12, 178272},
	{"SATELLITEVELOCITY", 17, 178273},
	{"NEWSMEN", 7, 178274},
	{"DOUT", 4, 178275},
	{"EKTELON", 7, 178276},
	{"SIGHTVECTOR", 11, 178277},
	{"COMMISSARIAT", 12, 178278},
	{"SUNCOR", 6, 178279},
	{"SCENELINENUMBER", 15, 178280},
	{"MACGOWAN", 8, 178281},
	{"ATTITUDERATE", 12, 178282},
	{"ATTITUDEANGLE", 13, 178283},
	{"WINDSHIRTS", 10, 178284},
	{"NARGS", 5, 178285},
	{"QUSH", 4, 178286},
	{"PARFITT", 7, 178287},
	{"NONSECTARIAN", 12, 178288},
	{"DBWORLD", 7, 178289},
	{"SEELE", 5, 178290},
	{"EXFREUNDIN", 10, 178291},
	{"MESTER", 6, 178292},
	{"VERIDATA", 8, 178293},
	{"MBQ", 3, 178294},
	{"AMINOACYL", 9, 178295},
	{"BRANDIE", 7, 178296},
	{"YMSH", 4, 178297},
	{"YKAU", 4, 178298},
	{"YCYB", 4, 178299},
	{"UOUG", 4, 178300},
	{"TVGA", 4, 178301},
	{"THGB", 4, 178302},
	{"TAPF", 4, 178303},
	{"RHPR", 4, 178304},
	{"RGSD", 4, 178305},
	{"RAGY", 4, 178306},
	{"QURE", 4, 178307},
	{"PYWR", 4, 178308},
	{"NZJO", 4, 178309},
	{"NDHB", 4, 178310},
	{"LLUA", 4, 178311},
	{"LLPP", 4, 178312},
	{"LIZT", 4, 178313},
	{"KYJO", 4, 178314},
	{"KYAD", 4, 178315},
	{"KWAD", 4, 178316},
	{"KUYT", 4, 178317},
	{"JOBJ", 4, 178318},
	{"GYED", 4, 178319},
	{"FOXG", 4, 178320},
	{"EZPO", 4, 178321},
	{"ELGH", 4, 178322},
	{"DUOH", 4, 178323},
	{"DOPS", 4, 178324},
	{"DIRU", 4, 178325},
	{"CAMF", 4, 178326},
	{"BUMY", 4, 178327},
	{"AROX", 4, 178328},
	{"ALPP", 4, 178329},
	{"TURCK", 5, 178330},
	{"CHAMPIONNAT", 11, 178331},
	{"ROHMER", 6, 178332},
	{"SPRECHER", 8, 178333},
	{"MORTIIS", 7, 178334},
	{"INACTIVATING", 12, 178335},
	{"ABYDOS", 6, 178336},
	{"VERNONIA", 8, 178337},
	{"TERADYNE", 8, 178338},
	{"VINIFERA", 8, 178339},
	{"SATELLITEPOSITION", 17, 178340},
	{"FIDDLY", 6, 178341},
	{"MEGALOMANIAC", 12, 178342},
	{"DKVM", 4, 178343},
	{"SLAUGHTERS", 10, 178344},
	{"LYBRAND", 7, 178345},
	{"TITRATED", 8, 178346},
	{"LHRH", 4, 178347},
	{"MULTIWAY", 8, 178348},
	{"LYFORD", 6, 178349},
	{"JABIRU", 6, 178350},
	{"PAPUANS", 7, 178351},
	{"CORNFIELDS", 10, 178352},
	{"INTEGO", 6, 178353},
	{"EBBING", 6, 178354},
	{"AMINOGLYCOSIDES", 15, 178355},
	{"CONTEMPORANEA", 13, 178356},
	{"MADSON", 6, 178357},
	{"MOMEN", 5, 178358},
	{"MEDIASTINUM", 11, 178359},
	{"NOISIER", 7, 178360},
	{"EPAY", 4, 178361},
	{"TVSPY", 5, 178362},
	{"TIPPLE", 6, 178363},
	{"TOUCHTONE", 9, 178364},
	{"EVELINA", 7, 178365},
	{"DITTRICH", 8, 178366},
	{"ABSCISSA", 8, 178367},
	{"LOURENCO", 8, 178368},
	{"FRECKLE", 7, 178369},
	{"BCAST", 5, 178370},
	{"ALLERGIST", 9, 178371},
	{"BRITENY", 7, 178372},
	{"SRVCS", 5, 178373},
	{"GRANDOE", 7, 178374},
	{"ACCY", 4, 178375},
	{"REPOSSESSIONS", 13, 178376},
	{"AKAMU", 5, 178377},
	{"ENTAL", 5, 178378},
	{"GRUMP", 5, 178379},
	{"YIPPIE", 6, 178380},
	{"ELOAN", 5, 178381},
	{"WAITAKI", 7, 178382},
	{"QUERO", 5, 178383},
	{"FABRIKNEU", 9, 178384},
	{"MAILLING", 8, 178385},
	{"TANSY", 5, 178386},
	{"RESTA", 5, 178387},
	{"MEDIACENTRE", 11, 178388},
	{"WIRA", 4, 178389},
	{"MONOLOG", 7, 178390},
	{"CEVA", 4, 178391},
	{"JINDABYNE", 9, 178392},
	{"JANV", 4, 178393},
	{"BINCIMAP", 8, 178394},
	{"TADCASTER", 9, 178395},
	{"SOFEMININE", 10, 178396},
	{"MONAHANS", 8, 178397},
	{"WMR", 3, 178398},
	{"PROTOTYPED", 10, 178399},
	{"PERCEPTUALLY", 12, 178400},
	{"PORTENTS", 8, 178401},
	{"FORCEFIELD", 10, 178402},
	{"NASHOBA", 7, 178403},
	{"LEFTMARGIN", 10, 178404},
	{"CEDURES", 7, 178405},
	{"ACHINGLY", 8, 178406},
	{"VENETIANS", 9, 178407},
	{"DXLD", 4, 178408},
	{"UNNERVED", 8, 178409},
	{"SPYMAC", 6, 178410},
	{"MAOR", 4, 178411},
	{"MAUSTON", 7, 178412},
	{"DEMAIN", 6, 178413},
	{"ZIMO", 4, 178414},
	{"ZFRE", 4, 178415},
	{"UABI", 4, 178416},
	{"RMKN", 4, 178417},
	{"RLSK", 4, 178418},
	{"ONRP", 4, 178419},
	{"OLYV", 4, 178420},
	{"NROX", 4, 178421},
	{"JICO", 4, 178422},
	{"GUIZ", 4, 178423},
	{"GBIP", 4, 178424},
	{"FXIS", 4, 178425},
	{"FLWH", 4, 178426},
	{"FIMB", 4, 178427},
	{"EJUK", 4, 178428},
	{"DUNJ", 4, 178429},
	{"DEGH", 4, 178430},
	{"BHAB", 4, 178431},
	{"AUKI", 4, 178432},
	{"AFOW", 4, 178433},
	{"AEGU", 4, 178434},
	{"MONOFOON", 8, 178435},
	{"PARTICIPLES", 11, 178436},
	{"PAINTABLE", 9, 178437},
	{"HOTMAILCOM", 10, 178438},
	{"XFR", 3, 178439},
	{"VERAS", 5, 178440},
	{"DIENE", 5, 178441},
	{"CLEARENCE", 9, 178442},
	{"DOLES", 5, 178443},
	{"HARMLESSLY", 10, 178444},
	{"RELEASEEDITLOCKCHECKBOX", 23, 178445},
	{"GALLWCH", 7, 178446},
	{"FANNO", 5, 178447},
	{"DEHART", 6, 178448},
	{"WXSTRING", 8, 178449},
	{"GIZZARD", 7, 178450},
	{"CONGRUENCY", 10, 178451},
	{"MORRILTON", 9, 178452},
	{"NONWHITE", 8, 178453},
	{"ACTIVERECORD", 12, 178454},
	{"PURTY", 5, 178455},
	{"SCAPULAR", 8, 178456},
	{"POSSESSORS", 10, 178457},
	{"MEADOWBANK", 10, 178458},
	{"PERCOLATING", 11, 178459},
	{"HYPERGRAPH", 10, 178460},
	{"KRISTIANSEN", 11, 178461},
	{"MEPHISTOPHELES", 14, 178462},
	{"PEAKTALK", 8, 178463},
	{"FIKE", 4, 178464},
	{"LODGINGHOTELS", 13, 178465},
	{"LIBREVILLE", 10, 178466},
	{"EQUISYS", 7, 178467},
	{"PEVONIA", 7, 178468},
	{"FLAB", 4, 178469},
	{"WAHMS", 5, 178470},
	{"OLUG", 4, 178471},
	{"OUZO", 4, 178472},
	{"TITLEBAR", 8, 178473},
	{"NEVILL", 6, 178474},
	{"VEREINIGUNG", 11, 178475},
	{"TRUECOLOR", 9, 178476},
	{"FUERTES", 7, 178477},
	{"FELKER", 6, 178478},
	{"PROCLIVITY", 10, 178479},
	{"ABBAYE", 6, 178480},
	{"HADAR", 5, 178481},
	{"ATHINA", 6, 178482},
	{"WATERLILY", 9, 178483},
	{"TABLELESS", 9, 178484},
	{"VALA", 4, 178485},
	{"RHENIUM", 7, 178486},
	{"CHAPERONIN", 10, 178487},
	{"POULTNEY", 8, 178488},
	{"POLOGNE", 7, 178489},
	{"JMJ", 3, 178490},
	{"ESTHERVILLE", 11, 178491},
	{"EFTSL", 5, 178492},
	{"SPACEBALLS", 10, 178493},
	{"IMPLICA", 7, 178494},
	{"RIMMEL", 6, 178495},
	{"HALACHIC", 8, 178496},
	{"MICROTECHNOLOGY", 15, 178497},
	{"MEDC", 4, 178498},
	{"AMPOULES", 8, 178499},
	{"MISIC", 5, 178500},
	{"YOSHIKO", 7, 178501},
	{"KUCK", 4, 178502},
	{"MACCHINA", 8, 178503},
	{"KENWORTHY", 9, 178504},
	{"GIELEN", 6, 178505},
	{"FORTES", 6, 178506},
	{"FAIRLAND", 8, 178507},
	{"ISOUND", 6, 178508},
	{"MASTROIANNI", 11, 178509},
	{"PHYLOGENIES", 11, 178510},
	{"CREATIS", 7, 178511},
	{"XWINDOWS", 8, 178512},
	{"VANELI", 6, 178513},
	{"LIVELINESS", 10, 178514},
	{"EASTPOINTE", 10, 178515},
	{"BEGLEITUNG", 10, 178516},
	{"DUGALD", 6, 178517},
	{"DALEN", 5, 178518},
	{"XLEW", 4, 178519},
	{"WNSJ", 4, 178520},
	{"VAIK", 4, 178521},
	{"UOGO", 4, 178522},
	{"UJAS", 4, 178523},
	{"PTMU", 4, 178524},
	{"OUGT", 4, 178525},
	{"NGMG", 4, 178526},
	{"MPGI", 4, 178527},
	{"LIXC", 4, 178528},
	{"KCUP", 4, 178529},
	{"JIDI", 4, 178530},
	{"JAVK", 4, 178531},
	{"IPKA", 4, 178532},
	{"IPGL", 4, 178533},
	{"IKIG", 4, 178534},
	{"IDAQ", 4, 178535},
	{"IBOF", 4, 178536},
	{"HUDG", 4, 178537},
	{"GNDR", 4, 178538},
	{"GIDW", 4, 178539},
	{"EXOL", 4, 178540},
	{"EVPO", 4, 178541},
	{"EPEQ", 4, 178542},
	{"ELJI", 4, 178543},
	{"DOMK", 4, 178544},
	{"BTUN", 4, 178545},
	{"BPUB", 4, 178546},
	{"BEZO", 4, 178547},
	{"AIPL", 4, 178548},
	{"FUJIKURA", 8, 178549},
	{"FREINDLY", 8, 178550},
	{"SNOWSUIT", 8, 178551},
	{"UUENCODE", 8, 178552},
	{"HOLIDAYING", 10, 178553},
	{"DEVELOPM", 8, 178554},
	{"MEDICARERX", 10, 178555},
	{"ARCOTEL", 7, 178556},
	{"ESSAIS", 6, 178557},
	{"LYRICX", 6, 178558},
	{"KIRUNA", 6, 178559},
	{"GODSON", 6, 178560},
	{"GIBSONIA", 8, 178561},
	{"PASSA", 5, 178562},
	{"DOWNFIELD", 9, 178563},
	{"BROODMARE", 9, 178564},
	{"ZONATION", 8, 178565},
	{"NORMALY", 7, 178566},
	{"YPF", 3, 178567},
	{"DROGBA", 6, 178568},
	{"CORREOS", 7, 178569},
	{"BOOCH", 5, 178570},
	{"MAARIV", 6, 178571},
	{"PEUR", 4, 178572},
	{"LECTRIC", 7, 178573},
	{"GEEG", 4, 178574},
	{"CONSERVER", 9, 178575},
	{"COLLECTIO", 9, 178576},
	{"GITARRE", 7, 178577},
	{"ADJECTIVAL", 10, 178578},
	{"WARNES", 6, 178579},
	{"RATNA", 5, 178580},
	{"CONTRAVENING", 12, 178581},
	{"BEMOANING", 9, 178582},
	{"FECKLESS", 8, 178583},
	{"CRYSTALLISATION", 15, 178584},
	{"VEHICULE", 8, 178585},
	{"PHYSIQUES", 9, 178586},
	{"CYBEVASION", 10, 178587},
	{"LAMPING", 7, 178588},
	{"EBENSBURG", 9, 178589},
	{"ARDIS", 5, 178590},
	{"TUBEROSE", 8, 178591},
	{"BLAYDON", 7, 178592},
	{"STEREOPHONIC", 12, 178593},
	{"KAMATH", 6, 178594},
	{"XAXIS", 5, 178595},
	{"COMMUTATIVITY", 13, 178596},
	{"LALANNE", 7, 178597},
	{"BAMPTON", 7, 178598},
	{"SKYWELL", 7, 178599},
	{"PLAF", 4, 178600},
	{"HOEDOWN", 7, 178601},
	{"HAMBONE", 7, 178602},
	{"SHERER", 6, 178603},
	{"DUFFER", 6, 178604},
	{"MOTHRA", 6, 178605},
	{"MAKGADIKGADI", 12, 178606},
	{"SLAVIA", 6, 178607},
	{"BIPED", 5, 178608},
	{"REGELING", 8, 178609},
	{"MASSACHUSETTES", 14, 178610},
	{"QPM", 3, 178611},
	{"TOREAD", 6, 178612},
	{"NDIM", 4, 178613},
	{"MUSIAL", 6, 178614},
	{"ASSELIN", 7, 178615},
	{"MARCELL", 7, 178616},
	{"ADDEWIDION", 10, 178617},
	{"WGP", 3, 178618},
	{"ORMISTON", 8, 178619},
	{"SKIWEAR", 7, 178620},
	{"ASTRONOMIA", 10, 178621},
	{"JOSETTE", 7, 178622},
	{"ALAJUELA", 8, 178623},
	{"HOLMFIRTH", 9, 178624},
	{"RIOR", 4, 178625},
	{"SHAHIN", 6, 178626},
	{"HOTELYEAR", 9, 178627},
	{"CASTANETS", 9, 178628},
	{"LIKEMINDED", 10, 178629},
	{"DGK", 3, 178630},
	{"UKAT", 4, 178631},
	{"PALING", 6, 178632},
	{"ARTSPACE", 8, 178633},
	{"TTPP", 4, 178634},
	{"HOHENHEIM", 9, 178635},
	{"DECKCHAIR", 9, 178636},
	{"DAZZLES", 7, 178637},
	{"LAITHWAITES", 11, 178638},
	{"CYNLLUNIAU", 10, 178639},
	{"UNGLAZED", 8, 178640},
	{"LLG", 3, 178641},
	{"KENTVILLE", 9, 178642},
	{"MEMEBERS", 8, 178643},
	{"EMULSIFIED", 10, 178644},
	{"ZIRK", 4, 178645},
	{"YZHA", 4, 178646},
	{"YNUD", 4, 178647},
	{"WLAL", 4, 178648},
	{"WESD", 4, 178649},
	{"USEZ", 4, 178650},
	{"UPSV", 4, 178651},
	{"UENM", 4, 178652},
	{"UAPE", 4, 178653},
	{"RAFP", 4, 178654},
	{"OOCU", 4, 178655},
	{"OGAK", 4, 178656},
	{"OBUO", 4, 178657},
	{"NILK", 4, 178658},
	{"NGYP", 4, 178659},
	{"LSMC", 4, 178660},
	{"IFSM", 4, 178661},
	{"HWEK", 4, 178662},
	{"FXIN", 4, 178663},
	{"EKRZ", 4, 178664},
	{"EBEZ", 4, 178665},
	{"DWAH", 4, 178666},
	{"DDBR", 4, 178667},
	{"DEUR", 4, 178668},
	{"CATALDO", 7, 178669},
	{"CAROLINIAN", 10, 178670},
	{"HELFER", 6, 178671},
	{"VESTI", 5, 178672},
	{"ACKLAND", 7, 178673},
	{"PHILES", 6, 178674},
	{"JOEM", 4, 178675},
	{"HUGHEY", 6, 178676},
	{"RODRIGUE", 8, 178677},
	{"REQUIR", 6, 178678},
	{"BISHER", 6, 178679},
	{"NSFNET", 6, 178680},
	{"NIGHTSHIRT", 10, 178681},
	{"OSPEDALE", 8, 178682},
	{"BELLEROSE", 9, 178683},
	{"PRESTA", 6, 178684},
	{"HIJRA", 5, 178685},
	{"FUNICULAR", 9, 178686},
	{"CEDURE", 6, 178687},
	{"DIVERTICULUM", 12, 178688},
	{"SUCCESSIVO", 10, 178689},
	{"SOLIDUS", 7, 178690},
	{"LINKOPING", 9, 178691},
	{"HYSTEROSCOPY", 12, 178692},
	{"FANTASMA", 8, 178693},
	{"CADFAEL", 7, 178694},
	{"CBQ", 3, 178695},
	{"ACHEIVED", 8, 178696},
	{"PERNICE", 7, 178697},
	{"RABELAIS", 8, 178698},
	{"SCHWESTER", 9, 178699},
	{"KAMIN", 5, 178700},
	{"PRGF", 4, 178701},
	{"FONTSET", 7, 178702},
	{"SIXSIXONE", 9, 178703},
	{"GAURD", 5, 178704},
	{"CRANKSHAFTS", 11, 178705},
	{"ANIMENATION", 11, 178706},
	{"STATIONING", 10, 178707},
	{"KAPIOLANI", 9, 178708},
	{"NARANJA", 7, 178709},
	{"VIACCESS", 8, 178710},
	{"KEARSLEY", 8, 178711},
	{"MEDULLOBLASTOMA", 15, 178712},
	{"VCDIMAGER", 9, 178713},
	{"STABIL", 6, 178714},
	{"MUSICNOTES", 10, 178715},
	{"AUTOCRAT", 8, 178716},
	{"THYMOMA", 7, 178717},
	{"SHOULDERING", 11, 178718},
	{"QUADRAT", 7, 178719},
	{"CINNAMINSON", 11, 178720},
	{"ZAPIRO", 6, 178721},
	{"TICHY", 5, 178722},
	{"CLAPBOARD", 9, 178723},
	{"URICH", 5, 178724},
	{"BAYAMON", 7, 178725},
	{"SATTAR", 6, 178726},
	{"CELLULAIRE", 10, 178727},
	{"BALLSY", 6, 178728},
	{"PROGETTI", 8, 178729},
	{"YOUG", 4, 178730},
	{"KYMCO", 5, 178731},
	{"HOVEL", 5, 178732},
	{"NATIONALES", 10, 178733},
	{"OMNITECH", 8, 178734},
	{"WRITEFILE", 9, 178735},
	{"MESERVE", 7, 178736},
	{"GAULS", 5, 178737},
	{"WHEDONESQUE", 11, 178738},
	{"KARNAL", 6, 178739},
	{"GRUVER", 6, 178740},
	{"EXUPERY", 7, 178741},
	{"CONFORME", 8, 178742},
	{"REUSS", 5, 178743},
	{"LOGEC", 5, 178744},
	{"FLASHKIT", 8, 178745},
	{"CHNG", 4, 178746},
	{"TWIKISKINS", 10, 178747},
	{"DEHUMANIZING", 12, 178748},
	{"CHETAN", 6, 178749},
	{"YIDR", 4, 178750},
	{"XMOS", 4, 178751},
	{"XLIA", 4, 178752},
	{"WAIP", 4, 178753},
	{"VROD", 4, 178754},
	{"TRUV", 4, 178755},
	{"SKRY", 4, 178756},
	{"RPBU", 4, 178757},
	{"RJUB", 4, 178758},
	{"QIPR", 4, 178759},
	{"NZOC", 4, 178760},
	{"NKRY", 4, 178761},
	{"MSTM", 4, 178762},
	{"KIUS", 4, 178763},
	{"INCJ", 4, 178764},
	{"HUDU", 4, 178765},
	{"GGYF", 4, 178766},
	{"FDAG", 4, 178767},
	{"EVPR", 4, 178768},
	{"BNGO", 4, 178769},
	{"AGUB", 4, 178770},
	{"GABRIELI", 8, 178771},
	{"CERRADO", 7, 178772},
	{"NEOLOGISMS", 10, 178773},
	{"BRIQUETTES", 10, 178774},
	{"HONNEUR", 7, 178775},
	{"BARITE", 6, 178776},
	{"MYDATA", 6, 178777},
	{"HOLDOUT", 7, 178778},
	{"AMARANTHUS", 10, 178779},
	{"DEVINN", 6, 178780},
	{"SETEMBRO", 8, 178781},
	{"MICROGLOBULIN", 13, 178782},
	{"MORANDI", 7, 178783},
	{"POZZO", 5, 178784},
	{"LAUGHIN", 7, 178785},
	{"CYANOSIS", 8, 178786},
	{"FLAMEPROOF", 10, 178787},
	{"CAERNARFONSHIRE", 15, 178788},
	{"RISERVA", 7, 178789},
	{"EINGEBEN", 8, 178790},
	{"MUNCHER", 7, 178791},
	{"DOROURKE", 8, 178792},
	{"KURTZMAN", 8, 178793},
	{"INDIVIDUALIZATION", 17, 178794},
	{"BISCHOF", 7, 178795},
	{"GIADA", 5, 178796},
	{"LUKACS", 6, 178797},
	{"BHUJ", 4, 178798},
	{"DALAT", 5, 178799},
	{"ALEKSEI", 7, 178800},
	{"JUNOS", 5, 178801},
	{"VWR", 3, 178802},
	{"NICOLETTA", 9, 178803},
	{"SUBMILLIMETER", 13, 178804},
	{"SPEARING", 8, 178805},
	{"BUDDHAHOOD", 10, 178806},
	{"CLEGHORN", 8, 178807},
	{"FOURSEASONS", 11, 178808},
	{"FAMOTIDINE", 10, 178809},
	{"MODD", 4, 178810},
	{"PERADON", 7, 178811},
	{"ANGOLO", 6, 178812},
	{"GRACKLE", 7, 178813},
	{"DOVID", 5, 178814},
	{"SCREAMERS", 9, 178815},
	{"UPGRADATION", 11, 178816},
	{"KCTS", 4, 178817},
	{"DIEET", 5, 178818},
	{"TAKANO", 6, 178819},
	{"INCITES", 7, 178820},
	{"LGR", 3, 178821},
	{"FULLFILL", 8, 178822},
	{"LENZEN", 6, 178823},
	{"STIRRINGS", 9, 178824},
	{"STRINDBERG", 10, 178825},
	{"INCONEL", 7, 178826},
	{"DAYE", 4, 178827},
	{"ACTUALMENTE", 11, 178828},
	{"PHOTOSPHERIC", 12, 178829},
	{"JUVENIL", 7, 178830},
	{"HELNWEIN", 8, 178831},
	{"GANNET", 6, 178832},
	{"GAMEPLAN", 8, 178833},
	{"COPEPOD", 7, 178834},
	{"ELISKA", 6, 178835},
	{"FECTIVE", 7, 178836},
	{"WINTERSON", 9, 178837},
	{"DARWINIA", 8, 178838},
	{"FLORANISTA", 10, 178839},
	{"GLUCONEOGENESIS", 15, 178840},
	{"OVERDRAWN", 9, 178841},
	{"BERGKAMP", 8, 178842},
	{"RETENTIONS", 10, 178843},
	{"PIPEDREAM", 9, 178844},
	{"ALEWIFE", 7, 178845},
	{"SDGALLERY", 9, 178846},
	{"ZIWI", 4, 178847},
	{"ZILD", 4, 178848},
	{"YOOR", 4, 178849},
	{"YMWI", 4, 178850},
	{"XEXT", 4, 178851},
	{"WWME", 4, 178852},
	{"WPUP", 4, 178853},
	{"UJER", 4, 178854},
	{"UEEQ", 4, 178855},
	{"SYOP", 4, 178856},
	{"RBPA", 4, 178857},
	{"RBMI", 4, 178858},
	{"PHAK", 4, 178859},
	{"ORFY", 4, 178860},
	{"NOUD", 4, 178861},
	{"KIDY", 4, 178862},
	{"IDIJ", 4, 178863},
	{"GGOP", 4, 178864},
	{"FWPO", 4, 178865},
	{"FVIV", 4, 178866},
	{"FTTY", 4, 178867},
	{"FEMY", 4, 178868},
	{"EJUT", 4, 178869},
	{"DKUW", 4, 178870},
	{"DEVW", 4, 178871},
	{"BYOD", 4, 178872},
	{"BSJU", 4, 178873},
	{"AJYA", 4, 178874},
	{"DECIDER", 7, 178875},
	{"LUSITANIA", 9, 178876},
	{"RUSTLED", 7, 178877},
	{"FLEDERMAUS", 10, 178878},
	{"UNQUENCHABLE", 12, 178879},
	{"FALLERS", 7, 178880},
	{"STUBBED", 7, 178881},
	{"STAVUDINE", 9, 178882},
	{"MUKHOPADHYAY", 12, 178883},
	{"BBF", 3, 178884},
	{"INSTRUMENTOS", 12, 178885},
	{"KOOLANCE", 8, 178886},
	{"FORESEEING", 10, 178887},
	{"FABRICANTE", 10, 178888},
	{"PASTORIUS", 9, 178889},
	{"FULCHER", 7, 178890},
	{"DISULPHIDE", 10, 178891},
	{"STEPMOM", 7, 178892},
	{"TRANSF", 6, 178893},
	{"INDOLENCE", 9, 178894},
	{"REENA", 5, 178895},
	{"COMEDIENNE", 10, 178896},
	{"MENDE", 5, 178897},
	{"PROFUNDITY", 10, 178898},
	{"FISHTAIL", 8, 178899},
	{"SPECTEC", 7, 178900},
	{"GOLIGHTLY", 9, 178901},
	{"KALBA", 5, 178902},
	{"NUSSLE", 6, 178903},
	{"SCHAFFHAUSEN", 12, 178904},
	{"PSPICE", 6, 178905},
	{"FIXERS", 6, 178906},
	{"CONTUSION", 9, 178907},
	{"UNDERRUN", 8, 178908},
	{"LAWE", 4, 178909},
	{"FRAPS", 5, 178910},
	{"DINSTALL", 8, 178911},
	{"COMMINGLING", 11, 178912},
	{"NDCC", 4, 178913},
	{"DRAX", 4, 178914},
	{"CLON", 4, 178915},
	{"ALTANA", 6, 178916},
	{"PARU", 4, 178917},
	{"STEINKE", 7, 178918},
	{"ALESSA", 6, 178919},
	{"ALYS", 4, 178920},
	{"LANIGAN", 7, 178921},
	{"AMICK", 5, 178922},
	{"VOSTRO", 6, 178923},
	{"BURTONSVILLE", 12, 178924},
	{"QCC", 3, 178925},
	{"EARMARKING", 10, 178926},
	{"FETOPROTEIN", 11, 178927},
	{"CHARLEMONT", 10, 178928},
	{"MOCKUMENTARY", 12, 178929},
	{"LYNDALE", 7, 178930},
	{"TURGID", 6, 178931},
	{"NICMOS", 6, 178932},
	{"DEFEN", 5, 178933},
	{"EXIGENCY", 8, 178934},
	{"SUPERSUCKERS", 12, 178935},
	{"CONJURATION", 11, 178936},
	{"CLUBHEAD", 8, 178937},
	{"BWG", 3, 178938},
	{"SONDRE", 6, 178939},
	{"PENETRACION", 11, 178940},
	{"DAREDEVILS", 10, 178941},
	{"MUCHLY", 6, 178942},
	{"GRACEY", 6, 178943},
	{"WINHELP", 7, 178944},
	{"HAGGAR", 6, 178945},
	{"CELEX", 5, 178946},
	{"RELEARN", 7, 178947},
	{"NARF", 4, 178948},
	{"NEXIA", 5, 178949},
	{"EXIGE", 5, 178950},
	{"PEBBLED", 7, 178951},
	{"LRF", 3, 178952},
	{"IRCA", 4, 178953},
	{"TOFF", 4, 178954},
	{"FINDEST", 7, 178955},
	{"LTRICS", 6, 178956},
	{"INSERTER", 8, 178957},
	{"PARMAR", 6, 178958},
	{"NECESARIO", 9, 178959},
	{"DIOPHANTINE", 11, 178960},
	{"WANES", 5, 178961},
	{"TUVOK", 5, 178962},
	{"ZSAW", 4, 178963},
	{"ZIPI", 4, 178964},
	{"YNRO", 4, 178965},
	{"YDFI", 4, 178966},
	{"XSWA", 4, 178967},
	{"VSUN", 4, 178968},
	{"VBOB", 4, 178969},
	{"UMKE", 4, 178970},
	{"THDC", 4, 178971},
	{"RDRJ", 4, 178972},
	{"RBMO", 4, 178973},
	{"PYCR", 4, 178974},
	{"PNIG", 4, 178975},
	{"PATV", 4, 178976},
	{"OCHV", 4, 178977},
	{"OAMR", 4, 178978},
	{"NUKT", 4, 178979},
	{"NMEP", 4, 178980},
	{"NEXB", 4, 178981},
	{"MYIR", 4, 178982},
	{"KURY", 4, 178983},
	{"JROB", 4, 178984},
	{"JEBE", 4, 178985},
	{"IJAL", 4, 178986},
	{"DQIN", 4, 178987},
	{"AZDE", 4, 178988},
	{"AUXD", 4, 178989},
	{"AKVE", 4, 178990},
	{"INTERNALIZING", 13, 178991},
	{"STUNK", 5, 178992},
	{"REINED", 6, 178993},
	{"ACETYLCYSTEINE", 14, 178994},
	{"PRELOADING", 10, 178995},
	{"FAUNS", 5, 178996},
	{"VIVARIUM", 8, 178997},
	{"MOTEURS", 7, 178998},
	{"DETLEV", 6, 178999},
	{"AUGENWEIDE", 10, 179000},
	{"XMODEM", 6, 179001},
	{"GRENDON", 7, 179002},
	{"UFJ", 3, 179003},
	{"PREND", 5, 179004},
	{"JULHO", 5, 179005},
	{"INTERLINEAR", 11, 179006},
	{"REREGISTRATION", 14, 179007},
	{"EDITORA", 7, 179008},
	{"DIGGITY", 7, 179009},
	{"CASMIR", 6, 179010},
	{"MAYLINE", 7, 179011},
	{"DARDANELLE", 10, 179012},
	{"TBLOG", 5, 179013},
	{"PAKURANGA", 9, 179014},
	{"TAGG", 4, 179015},
	{"UNENVIABLE", 10, 179016},
	{"GENAU", 5, 179017},
	{"SAOSIN", 6, 179018},
	{"RADIONICS", 9, 179019},
	{"TSVANGIRAI", 10, 179020},
	{"DORFF", 5, 179021},
	{"ARCHAEOPTERYX", 13, 179022},
	{"VICINI", 6, 179023},
	{"MYSQLDUMP", 9, 179024},
	{"LESHAN", 6, 179025},
	{"REINALDO", 8, 179026},
	{"VAIR", 4, 179027},
	{"TECHENCLAVE", 11, 179028},
	{"MICROLINK", 9, 179029},
	{"REAY", 4, 179030},
	{"BKW", 3, 179031},
	{"OBSCENELY", 9, 179032},
	{"ARGENTEUIL", 10, 179033},
	{"VARRO", 5, 179034},
	{"GULICK", 6, 179035},
	{"GREVILLEA", 9, 179036},
	{"FUMIGATUS", 9, 179037},
	{"BIOCOMPATIBILITY", 16, 179038},
	{"PERMEATING", 10, 179039},
	{"WARRANTEES", 10, 179040},
	{"ZYAIR", 5, 179041},
	{"HYRUM", 5, 179042},
	{"CHOSING", 7, 179043},
	{"GARAY", 5, 179044},
	{"REISSUANCE", 10, 179045},
	{"LVLUG", 5, 179046},
	{"MARVA", 5, 179047},
	{"ANTINUCLEAR", 11, 179048},
	{"DRING", 5, 179049},
	{"THERAPUTIC", 10, 179050},
	{"UNPACKAGED", 10, 179051},
	{"UNFEELING", 9, 179052},
	{"MICROSCOPICAL", 13, 179053},
	{"COOING", 6, 179054},
	{"PAIVA", 5, 179055},
	{"ILGA", 4, 179056},
	{"CAVELL", 6, 179057},
	{"ROUSSOS", 7, 179058},
	{"EBAYCOM", 7, 179059},
	{"OPENCDK", 7, 179060},
	{"NEUROIMAGE", 10, 179061},
	{"RONY", 4, 179062},
	{"POSTNEWSWEEK", 12, 179063},
	{"RICORDI", 7, 179064},
	{"VERANTWORTLICH", 14, 179065},
	{"PIETERSEN", 9, 179066},
	{"LDY", 3, 179067},
	{"DUMBELLS", 8, 179068},
	{"CHORALWIKI", 10, 179069},
	{"BLINC", 5, 179070},
	{"EQUIPMEN", 8, 179071},
	{"ABENTEUER", 9, 179072},
	{"BISHOPRIC", 9, 179073},
	{"CZM", 3, 179074},
	{"STARCHILD", 9, 179075},
	{"SALYER", 6, 179076},
	{"DICHOTOMIES", 11, 179077},
	{"ESPOIR", 6, 179078},
	{"DINGMAN", 7, 179079},
	{"MACOUPIN", 8, 179080},
	{"ZAMU", 4, 179081},
	{"YSPY", 4, 179082},
	{"YDRJ", 4, 179083},
	{"YDAC", 4, 179084},
	{"XTJO", 4, 179085},
	{"VTHR", 4, 179086},
	{"TKAD", 4, 179087},
	{"TJAW", 4, 179088},
	{"PSSW", 4, 179089},
	{"PPSD", 4, 179090},
	{"PAVN", 4, 179091},
	{"ONKP", 4, 179092},
	{"OBMU", 4, 179093},
	{"NDCJ", 4, 179094},
	{"LZEN", 4, 179095},
	{"LOKW", 4, 179096},
	{"LCCO", 4, 179097},
	{"KIFL", 4, 179098},
	{"IZTU", 4, 179099},
	{"IXJO", 4, 179100},
	{"HROV", 4, 179101},
	{"HDCO", 4, 179102},
	{"GHOD", 4, 179103},
	{"FDOP", 4, 179104},
	{"CACQ", 4, 179105},
	{"ACUO", 4, 179106},
	{"ACOZ", 4, 179107},
	{"ABYV", 4, 179108},
	{"AUFLAGE", 7, 179109},
	{"LFD", 3, 179110},
	{"FLEXFIT", 7, 179111},
	{"MAZZER", 6, 179112},
	{"MARXIAN", 7, 179113},
	{"RHODEN", 6, 179114},
	{"REGURGITATE", 11, 179115},
	{"PRINTSHOP", 9, 179116},
	{"LENSER", 6, 179117},
	{"CEECS", 5, 179118},
	{"KAPTON", 6, 179119},
	{"HORLOGES", 8, 179120},
	{"TIMETRAVEL", 10, 179121},
	{"SEVEREST", 8, 179122},
	{"MUSLC", 5, 179123},
	{"LESSE", 5, 179124},
	{"METATAGS", 8, 179125},
	{"RACHELS", 7, 179126},
	{"CANIBUS", 7, 179127},
	{"CIRILLO", 7, 179128},
	{"DECHRAU", 7, 179129},
	{"DAIMNATION", 10, 179130},
	{"BACKGEMMON", 10, 179131},
	{"MISSI", 5, 179132},
	{"IMMUNODIFFUSION", 15, 179133},
	{"BLWYDDYN", 8, 179134},
	{"SKALLER", 7, 179135},
	{"NYMPHETAMINE", 12, 179136},
	{"APPLEINSIDER", 12, 179137},
	{"NCGS", 4, 179138},
	{"CUBIS", 5, 179139},
	{"CATATONIA", 9, 179140},
	{"OLIGOPEPTIDE", 12, 179141},
	{"NUMERIQUE", 9, 179142},
	{"ZMV", 3, 179143},
	{"ZLX", 3, 179144},
	{"ZJM", 3, 179145},
	{"ZFK", 3, 179146},
	{"XQY", 3, 179147},
	{"XQB", 3, 179148},
	{"XCQ", 3, 179149},
	{"XCK", 3, 179150},
	{"WPZ", 3, 179151},
	{"QDJ", 3, 179152},
	{"QCJ", 3, 179153},
	{"MQQ", 3, 179154},
	{"JXM", 3, 179155},
	{"BXY", 3, 179156},
	{"BURPEE", 6, 179157},
	{"ULLI", 4, 179158},
	{"QUINOLONES", 10, 179159},
	{"TOBLER", 6, 179160},
	{"SIMBEL", 6, 179161},
	{"PROGRESSBAR", 11, 179162},
	{"JELLE", 5, 179163},
	{"POLITCAL", 8, 179164},
	{"RESETPASSWORD", 13, 179165},
	{"PODNOVA", 7, 179166},
	{"UNSPEC", 6, 179167},
	{"GETLOCATION", 11, 179168},
	{"NUAL", 4, 179169},
	{"KUBLER", 6, 179170},
	{"NISKAYUNA", 9, 179171},
	{"BEAUTIFYING", 11, 179172},
	{"SPACEDTOPIC", 11, 179173},
	{"EVALUABLE", 9, 179174},
	{"GENERELT", 8, 179175},
	{"PETTITT", 7, 179176},
	{"TETRADECANOYLPHORBOL", 20, 179177},
	{"MEDICATING", 10, 179178},
	{"CHEKOV", 6, 179179},
	{"SEAGER", 6, 179180},
	{"GLISTENED", 9, 179181},
	{"VILNA", 5, 179182},
	{"CYCL", 4, 179183},
	{"BLANT", 5, 179184},
	{"AUTOBOTS", 8, 179185},
	{"CMK", 3, 179186},
	{"MUSCLEMEN", 9, 179187},
	{"YPSERV", 6, 179188},
	{"OPENMAP", 7, 179189},
	{"KYRICS", 6, 179190},
	{"ENCROACHED", 10, 179191},
	{"EINSTEINS", 9, 179192},
	{"CORRIENTE", 9, 179193},
	{"ARTICLENAME", 11, 179194},
	{"SCHLAGE", 7, 179195},
	{"HYDROMORPHONE", 13, 179196},
	{"HOTLINKING", 10, 179197},
	{"ESCHMEYER", 9, 179198},
	{"AREQ", 4, 179199},
	{"TRANSPORATION", 13, 179200},
	{"IGAD", 4, 179201},
	{"NIEDERAU", 8, 179202},
	{"EURODICT", 8, 179203},
	{"AMBANI", 6, 179204},
	{"PULSER", 6, 179205},
	{"GROOTE", 6, 179206},
	{"DIOUF", 5, 179207},
	{"WATKINSVILLE", 12, 179208},
	{"SUPPLENESS", 10, 179209},
	{"MOJE", 4, 179210},
	{"COMPRESSIONAL", 13, 179211},
	{"WINDRIVERS", 10, 179212},
	{"NOUAKCHOTT", 10, 179213},
	{"BANKSY", 6, 179214},
	{"IRASCIBLE", 9, 179215},
	{"ZZRE", 4, 179216},
	{"XBOT", 4, 179217},
	{"VETM", 4, 179218},
	{"TIKU", 4, 179219},
	{"SCZE", 4, 179220},
	{"RIWR", 4, 179221},
	{"QHAD", 4, 179222},
	{"POWC", 4, 179223},
	{"OFYS", 4, 179224},
	{"NZLI", 4, 179225},
	{"MRFL", 4, 179226},
	{"LKVA", 4, 179227},
	{"KUWH", 4, 179228},
	{"HNPL", 4, 179229},
	{"GSNU", 4, 179230},
	{"GEEY", 4, 179231},
	{"FHUA", 4, 179232},
	{"EZSR", 4, 179233},
	{"EWOD", 4, 179234},
	{"EVYF", 4, 179235},
	{"DNCO", 4, 179236},
	{"BDOU", 4, 179237},
	{"AVUN", 4, 179238},
	{"CRUMPLE", 7, 179239},
	{"STAVROPOL", 9, 179240},
	{"SESKA", 5, 179241},
	{"LECLAIRE", 8, 179242},
	{"WARDA", 5, 179243},
	{"NSAPI", 5, 179244},
	{"MELDS", 5, 179245},
	{"DEFAULTERS", 10, 179246},
	{"LEELOO", 6, 179247},
	{"FEIG", 4, 179248},
	{"ERICKSEN", 8, 179249},
	{"MUSICMOBS", 9, 179250},
	{"KLEINBERG", 9, 179251},
	{"REPRIMANDS", 10, 179252},
	{"MESSINGER", 9, 179253},
	{"VERIUNI", 7, 179254},
	{"MONCKS", 6, 179255},
	{"INITSCRIPT", 10, 179256},
	{"FEELERS", 7, 179257},
	{"VARROA", 6, 179258},
	{"CROSSCOUNTRY", 12, 179259},
	{"AUTOVIEW", 8, 179260},
	{"RAYNES", 6, 179261},
	{"HASKOVO", 7, 179262},
	{"EIGENES", 7, 179263},
	{"CHOOSY", 6, 179264},
	{"GEILO", 5, 179265},
	{"MASERU", 6, 179266},
	{"SURECOM", 7, 179267},
	{"MURRAYS", 7, 179268},
	{"SCAMBIO", 7, 179269},
	{"CPTR", 4, 179270},
	{"FEMALEFIRST", 11, 179271},
	{"WELLCRAFT", 9, 179272},
	{"ZOBEL", 5, 179273},
	{"JERU", 4, 179274},
	{"ESKRIDGE", 8, 179275},
	{"TAKATA", 6, 179276},
	{"JACKKNIFE", 9, 179277},
	{"MORINI", 6, 179278},
	{"CANUTE", 6, 179279},
	{"HOESCHEN", 8, 179280},
	{"CORDONED", 8, 179281},
	{"SYNOLOGY", 8, 179282},
	{"IWAMOTO", 7, 179283},
	{"VIBRAM", 6, 179284},
	{"WARRINGAH", 9, 179285},
	{"COLOCATED", 9, 179286},
	{"WINOGRAD", 8, 179287},
	{"PWEBSTATS", 9, 179288},
	{"PALLADINO", 9, 179289},
	{"AUGMENTATIONS", 13, 179290},
	{"FRACTIONBOX", 11, 179291},
	{"EDITTEXT", 8, 179292},
	{"LALI", 4, 179293},
	{"SOFTHEON", 8, 179294},
	{"SNOWDROP", 8, 179295},
	{"BIRDWATCHERS", 12, 179296},
	{"DISPOSIBLE", 10, 179297},
	{"DISENROLLMENT", 13, 179298},
	{"VIBRATED", 8, 179299},
	{"CHROMATOGRAM", 12, 179300},
	{"HAMILTONIANS", 12, 179301},
	{"INTERLOPER", 10, 179302},
	{"CREATIVELABS", 12, 179303},
	{"TINNEY", 6, 179304},
	{"TALAT", 5, 179305},
	{"DENUDED", 7, 179306},
	{"BUTLINS", 7, 179307},
	{"REVIVALIST", 10, 179308},
	{"RENDRE", 6, 179309},
	{"FOYT", 4, 179310},
	{"ZORTIC", 6, 179311},
	{"CHANDAN", 7, 179312},
	{"DUNDRUM", 7, 179313},
	{"YOICHI", 6, 179314},
	{"MURPHYSBORO", 11, 179315},
	{"SMUDGED", 7, 179316},
	{"BALART", 6, 179317},
	{"DOWNSLOPE", 9, 179318},
	{"RUDDERS", 7, 179319},
	{"ROADWORK", 8, 179320},
	{"NONCORE", 7, 179321},
	{"LAMBASTED", 9, 179322},
	{"XLABEL", 6, 179323},
	{"SUBJUGATE", 9, 179324},
	{"ISADORE", 7, 179325},
	{"ZYON", 4, 179326},
	{"ZYLO", 4, 179327},
	{"VDEA", 4, 179328},
	{"TOVL", 4, 179329},
	{"SGTP", 4, 179330},
	{"ONWC", 4, 179331},
	{"OLTK", 4, 179332},
	{"NZFI", 4, 179333},
	{"NJOD", 4, 179334},
	{"MUKI", 4, 179335},
	{"MCTH", 4, 179336},
	{"MCTE", 4, 179337},
	{"LVAH", 4, 179338},
	{"LKCR", 4, 179339},
	{"KRAZ", 4, 179340},
	{"IOLC", 4, 179341},
	{"HPAM", 4, 179342},
	{"HKOB", 4, 179343},
	{"FMAZ", 4, 179344},
	{"FLWA", 4, 179345},
	{"FGOP", 4, 179346},
	{"BSRI", 4, 179347},
	{"BCFA", 4, 179348},
	{"AVOG", 4, 179349},
	{"ATRK", 4, 179350},
	{"ANZF", 4, 179351},
	{"AMHZ", 4, 179352},
	{"THEMUZICMAN", 11, 179353},
	{"SEMINARIAN", 10, 179354},
	{"MONEE", 5, 179355},
	{"PLAISANCE", 9, 179356},
	{"PERKED", 6, 179357},
	{"OSMENT", 6, 179358},
	{"YLRICS", 6, 179359},
	{"GOZANDO", 7, 179360},
	{"METEOMAR", 8, 179361},
	{"STELE", 5, 179362},
	{"EZEQUIEL", 8, 179363},
	{"GAZETTES", 8, 179364},
	{"SPORTBIKES", 10, 179365},
	{"ASSHAT", 6, 179366},
	{"SOMOGYI", 7, 179367},
	{"LAMPLIGHTER", 11, 179368},
	{"COMMISSAIRE", 11, 179369},
	{"MURALITHARAN", 12, 179370},
	{"JAPONAIS", 8, 179371},
	{"OLIVEROS", 8, 179372},
	{"BERATE", 6, 179373},
	{"HALLEN", 6, 179374},
	{"DERED", 5, 179375},
	{"SEIDL", 5, 179376},
	{"TAUSCHER", 8, 179377},
	{"ROCHEN", 6, 179378},
	{"WHITECAPS", 9, 179379},
	{"TARGETNAMESPACE", 15, 179380},
	{"SMEATON", 7, 179381},
	{"NEWSEUM", 7, 179382},
	{"ENTERP", 6, 179383},
	{"UNDERVOTES", 10, 179384},
	{"FOXTON", 6, 179385},
	{"GLOWSTICKS", 10, 179386},
	{"VENERE", 6, 179387},
	{"TACTICIAN", 9, 179388},
	{"PENDED", 6, 179389},
	{"MILLICAN", 8, 179390},
	{"MEDTECH", 7, 179391},
	{"DRECK", 5, 179392},
	{"HISTOPLASMOSIS", 14, 179393},
	{"BIKKEMBERGS", 11, 179394},
	{"NOWATA", 6, 179395},
	{"LURICS", 6, 179396},
	{"GULDEN", 6, 179397},
	{"NEWSNOW", 7, 179398},
	{"MATSHITA", 8, 179399},
	{"NATURALEZA", 10, 179400},
	{"SAPPHICEROTICA", 14, 179401},
	{"HAVERTOWN", 9, 179402},
	{"FUKK", 4, 179403},
	{"RENZ", 4, 179404},
	{"STEGNER", 7, 179405},
	{"SOFFITS", 7, 179406},
	{"NIYAZOV", 7, 179407},
	{"ANDROLOGY", 9, 179408},
	{"DEEPDENE", 8, 179409},
	{"STARRDUST", 9, 179410},
	{"COLLIERIES", 10, 179411},
	{"AJUMP", 5, 179412},
	{"STOKESLEY", 9, 179413},
	{"CARTERVILLE", 11, 179414},
	{"SPLINTERING", 11, 179415},
	{"MENGER", 6, 179416},
	{"TENROX", 6, 179417},
	{"NIOBE", 5, 179418},
	{"LEBOEUF", 7, 179419},
	{"RESCHKE", 7, 179420},
	{"HERBALISER", 10, 179421},
	{"GACH", 4, 179422},
	{"PLAATJES", 8, 179423},
	{"INCORPOREAL", 11, 179424},
	{"RENFE", 5, 179425},
	{"SHENOY", 6, 179426},
	{"KLCC", 4, 179427},
	{"EXUVIANCE", 9, 179428},
	{"CHOLELITHIASIS", 14, 179429},
	{"ORDERLIES", 9, 179430},
	{"CDEBCONF", 8, 179431},
	{"EHIME", 5, 179432},
	{"PASSORD", 7, 179433},
	{"EBELING", 7, 179434},
	{"LYRUCS", 6, 179435},
	{"INIVA", 5, 179436},
	{"THRUSHES", 8, 179437},
	{"HEMSIDA", 7, 179438},
	{"JAKMA", 5, 179439},
	{"COMLAW", 6, 179440},
	{"DURAFIRM", 8, 179441},
	{"ZEFE", 4, 179442},
	{"YTVC", 4, 179443},
	{"YKWA", 4, 179444},
	{"YIPL", 4, 179445},
	{"YCHL", 4, 179446},
	{"WIGM", 4, 179447},
	{"VKIN", 4, 179448},
	{"UTZH", 4, 179449},
	{"UTOY", 4, 179450},
	{"UEDY", 4, 179451},
	{"TRIJ", 4, 179452},
	{"SZAL", 4, 179453},
	{"KLOB", 4, 179454},
	{"IRHY", 4, 179455},
	{"GYOG", 4, 179456},
	{"FVOD", 4, 179457},
	{"FEBD", 4, 179458},
	{"EPTQ", 4, 179459},
	{"DCUI", 4, 179460},
	{"CKIO", 4, 179461},
	{"BOUV", 4, 179462},
	{"ATZM", 4, 179463},
	{"ANCF", 4, 179464},
	{"GGP", 3, 179465},
	{"TENDRING", 8, 179466},
	{"RHYMEFEST", 9, 179467},
	{"LMETZGER", 8, 179468},
	{"SMARTJOY", 8, 179469},
	{"GADS", 4, 179470},
	{"TITMOUSE", 8, 179471},
	{"RANDALLSTOWN", 12, 179472},
	{"DIENT", 5, 179473},
	{"RAZAK", 5, 179474},
	{"SMARTVIEW", 9, 179475},
	{"MEDIAKIT", 8, 179476},
	{"CQR", 3, 179477},
	{"LINNELL", 7, 179478},
	{"HADEETH", 7, 179479},
	{"PLASTICIZERS", 12, 179480},
	{"INJECTABLES", 11, 179481},
	{"KLITSCHKO", 9, 179482},
	{"HURTIN", 6, 179483},
	{"CYMBELINE", 9, 179484},
	{"XMLNODEPTR", 10, 179485},
	{"SATSANG", 7, 179486},
	{"FERRIED", 7, 179487},
	{"SEANCES", 7, 179488},
	{"CHERMSIDE", 9, 179489},
	{"MICRONIX", 8, 179490},
	{"IMITZ", 5, 179491},
	{"WRIGGLING", 9, 179492},
	{"DAPSONE", 7, 179493},
	{"BWAY", 4, 179494},
	{"SAGITTA", 7, 179495},
	{"JACOBO", 6, 179496},
	{"PETERSSON", 9, 179497},
	{"RIBOSYLATION", 12, 179498},
	{"GLOBS", 5, 179499},
	{"MOULDY", 6, 179500},
	{"GRAINE", 6, 179501},
	{"AMANT", 5, 179502},
	{"SOFTIE", 6, 179503},
	{"XCARET", 6, 179504},
	{"EARTHWALK", 9, 179505},
	{"FAOIN", 5, 179506},
	{"SUBPACKAGES", 11, 179507},
	{"NONPERFORMING", 13, 179508},
	{"KENLEY", 6, 179509},
	{"REINSERT", 8, 179510},
	{"TORING", 6, 179511},
	{"IASTED", 6, 179512},
	{"FRUITED", 7, 179513},
	{"BRAZELTON", 9, 179514},
	{"FREELOADER", 10, 179515},
	{"UDDIN", 5, 179516},
	{"SEGUNDOS", 8, 179517},
	{"PATHOM", 6, 179518},
	{"MCCAY", 5, 179519},
	{"GADDAFI", 7, 179520},
	{"FISC", 4, 179521},
	{"ORIHUELA", 8, 179522},
	{"MOVIEMAKER", 10, 179523},
	{"VINCCI", 6, 179524},
	{"FAMILYSEARCH", 12, 179525},
	{"MEREST", 6, 179526},
	{"ROESCH", 6, 179527},
	{"KOOKAI", 6, 179528},
	{"WORDES", 6, 179529},
	{"POSTINI", 7, 179530},
	{"TELECLASS", 9, 179531},
	{"HYSTERSISTERS", 13, 179532},
	{"UNASHAMED", 9, 179533},
	{"SWITCHBOX", 9, 179534},
	{"CABRI", 5, 179535},
	{"DISMANTLEMENT", 13, 179536},
	{"CHUMPS", 6, 179537},
	{"APMD", 4, 179538},
	{"ANNEAUX", 7, 179539},
	{"QUANSON", 7, 179540},
	{"RAWAT", 5, 179541},
	{"UBERPLAY", 8, 179542},
	{"PERPENDICULARLY", 15, 179543},
	{"DOWNWARDLY", 10, 179544},
	{"WINNOV", 6, 179545},
	{"CASTILLE", 8, 179546},
	{"GENICULATE", 10, 179547},
	{"GROWIN", 6, 179548},
	{"ZOCA", 4, 179549},
	{"WWNO", 4, 179550},
	{"WWMO", 4, 179551},
	{"WPAU", 4, 179552},
	{"WIYA", 4, 179553},
	{"VSEV", 4, 179554},
	{"VLEV", 4, 179555},
	{"UPLT", 4, 179556},
	{"UKTE", 4, 179557},
	{"TZUN", 4, 179558},
	{"SAPW", 4, 179559},
	{"PBLI", 4, 179560},
	{"OXYI", 4, 179561},
	{"OMKY", 4, 179562},
	{"NUXP", 4, 179563},
	{"NDRK", 4, 179564},
	{"NAMK", 4, 179565},
	{"MOLN", 4, 179566},
	{"MEKR", 4, 179567},
	{"MAHJ", 4, 179568},
	{"LKUS", 4, 179569},
	{"LFEC", 4, 179570},
	{"KHUT", 4, 179571},
	{"KFLU", 4, 179572},
	{"JELA", 4, 179573},
	{"IXDR", 4, 179574},
	{"IPOM", 4, 179575},
	{"IDGM", 4, 179576},
	{"HBUM", 4, 179577},
	{"GNGU", 4, 179578},
	{"GLYJ", 4, 179579},
	{"EUKN", 4, 179580},
	{"EFOD", 4, 179581},
	{"CGIA", 4, 179582},
	{"BUGR", 4, 179583},
	{"BCMO", 4, 179584},
	{"AVSB", 4, 179585},
	{"APTB", 4, 179586},
	{"MANNAN", 6, 179587},
	{"GUNNEDAH", 8, 179588},
	{"TEATIME", 7, 179589},
	{"FAVORITA", 8, 179590},
	{"TRUETT", 6, 179591},
	{"PSCW", 4, 179592},
	{"SISWATI", 7, 179593},
	{"EETTDD", 6, 179594},
	{"SUPERIMPOSE", 11, 179595},
	{"KATZE", 5, 179596},
	{"FAIRDALE", 8, 179597},
	{"NASTRAN", 7, 179598},
	{"CZARS", 5, 179599},
	{"STAINER", 7, 179600},
	{"EXPOUNDING", 10, 179601},
	{"OSUNA", 5, 179602},
	{"HAFTUNG", 7, 179603},
	{"BANTING", 7, 179604},
	{"WOODENWARE", 10, 179605},
	{"PUSHOVER", 8, 179606},
	{"NUTZEN", 6, 179607},
	{"BROADMAN", 8, 179608},
	{"RETHANS", 7, 179609},
	{"PACKABLE", 8, 179610},
	{"HELICONIA", 9, 179611},
	{"SYSTEMID", 8, 179612},
	{"PPRREETTOORRIIAA", 16, 179613},
	{"EXCOM", 5, 179614},
	{"NONINDIGENOUS", 13, 179615},
	{"GESTERN", 7, 179616},
	{"BREATHY", 7, 179617},
	{"LYONNE", 6, 179618},
	{"SWADDLING", 9, 179619},
	{"STUDIEREN", 9, 179620},
	{"BENIGHTED", 9, 179621},
	{"MULARKEY", 8, 179622},
	{"TITLEY", 6, 179623},
	{"TYPESETTER", 10, 179624},
	{"AVOYELLES", 9, 179625},
	{"ARTIESTEN", 9, 179626},
	{"WEMYSS", 6, 179627},
	{"LYNLEY", 6, 179628},
	{"ZALEWSKI", 8, 179629},
	{"FRIGGING", 8, 179630},
	{"SWASHBUCKLERS", 13, 179631},
	{"INDIANTOWN", 10, 179632},
	{"ANATOLI", 7, 179633},
	{"BENJA", 5, 179634},
	{"LUBED", 5, 179635},
	{"MAPLESTORY", 10, 179636},
	{"TERISTICS", 9, 179637},
	{"UNLOCKABLES", 11, 179638},
	{"HYSTERIC", 8, 179639},
	{"MUTASE", 6, 179640},
	{"TELECARE", 8, 179641},
	{"TREKKED", 7, 179642},
	{"ROBESPIERRE", 11, 179643},
	{"TILLBAKA", 8, 179644},
	{"REDWAY", 6, 179645},
	{"MCDANIELS", 9, 179646},
	{"GOBIND", 6, 179647},
	{"ADREF", 5, 179648},
	{"INTELLICHOICE", 13, 179649},
	{"UNITAR", 6, 179650},
	{"CMUCL", 5, 179651},
	{"PASHTUN", 7, 179652},
	{"UNINSULATED", 11, 179653},
	{"ACPA", 4, 179654},
	{"ADMINISTRADOR", 13, 179655},
	{"PRIVITY", 7, 179656},
	{"MUNDA", 5, 179657},
	{"LUNGING", 7, 179658},
	{"CLAST", 5, 179659},
	{"ZGET", 4, 179660},
	{"YHOV", 4, 179661},
	{"YFIO", 4, 179662},
	{"XNER", 4, 179663},
	{"ULIL", 4, 179664},
	{"SYVE", 4, 179665},
	{"SSYG", 4, 179666},
	{"SRMA", 4, 179667},
	{"RORZ", 4, 179668},
	{"RKMD", 4, 179669},
	{"RJED", 4, 179670},
	{"NXXI", 4, 179671},
	{"LWEP", 4, 179672},
	{"LSTJ", 4, 179673},
	{"LIUW", 4, 179674},
	{"JRAL", 4, 179675},
	{"IBRU", 4, 179676},
	{"HOGD", 4, 179677},
	{"FMCL", 4, 179678},
	{"FKOM", 4, 179679},
	{"ELKT", 4, 179680},
	{"EFKA", 4, 179681},
	{"EDWW", 4, 179682},
	{"DZAI", 4, 179683},
	{"CEYU", 4, 179684},
	{"CCUN", 4, 179685},
	{"BCTW", 4, 179686},
	{"AWAX", 4, 179687},
	{"EXULTATION", 10, 179688},
	{"AMIDON", 6, 179689},
	{"FAND", 4, 179690},
	{"ASCIIDOC", 8, 179691},
	{"IOPUS", 5, 179692},
	{"BLANKE", 6, 179693},
	{"MCCS", 4, 179694},
	{"WRECKLESS", 9, 179695},
	{"SELFSAME", 8, 179696},
	{"SWIKI", 5, 179697},
	{"NAKEDGIRLS", 10, 179698},
	{"OVERCOATS", 9, 179699},
	{"INTERDISCIPLINARITY", 19, 179700},
	{"GLAUCOUS", 8, 179701},
	{"CALVINISTS", 10, 179702},
	{"RESPONS", 7, 179703},
	{"PLESSEY", 7, 179704},
	{"BESTA", 5, 179705},
	{"KERGUELEN", 9, 179706},
	{"DEBIANDOC", 9, 179707},
	{"JIGGING", 7, 179708},
	{"TECHJOBS", 8, 179709},
	{"PUMMELED", 8, 179710},
	{"DIRECTCONNECT", 13, 179711},
	{"TUSSIN", 6, 179712},
	{"MILLWRIGHT", 10, 179713},
	{"JAVI", 4, 179714},
	{"GROVEL", 6, 179715},
	{"SOBERLY", 7, 179716},
	{"MGSA", 4, 179717},
	{"THERFORE", 8, 179718},
	{"MEMMOVE", 7, 179719},
	{"MOVIETIME", 9, 179720},
	{"GREYSTOKE", 9, 179721},
	{"PREIFATRWYDD", 12, 179722},
	{"KAGI", 4, 179723},
	{"VESTRON", 7, 179724},
	{"NYCBUG", 6, 179725},
	{"SYSOPS", 6, 179726},
	{"COSMA", 5, 179727},
	{"WLAD", 4, 179728},
	{"BERGQUIST", 9, 179729},
	{"EDICAL", 6, 179730},
	{"TOPCODER", 8, 179731},
	{"ERGOMETER", 9, 179732},
	{"BRINDA", 6, 179733},
	{"OCCUPATIONALLY", 14, 179734},
	{"MADRIGALS", 9, 179735},
	{"KLATT", 5, 179736},
	{"ECAR", 4, 179737},
	{"CHALKER", 7, 179738},
	{"CERVO", 5, 179739},
	{"SUPERSPEEDWAY", 13, 179740},
	{"EVOLVER", 7, 179741},
	{"ANTISEPTICS", 11, 179742},
	{"UNCOMPROMISED", 13, 179743},
	{"IMPERFECTA", 10, 179744},
	{"DSDNA", 5, 179745},
	{"BASENOTES", 9, 179746},
	{"MANUFACTURABILITY", 17, 179747},
	{"UJENA", 5, 179748},
	{"XPLOD", 5, 179749},
	{"SCANLINE", 8, 179750},
	{"MELLEM", 6, 179751},
	{"BGB", 3, 179752},
	{"LYRICC", 6, 179753},
	{"KINGSTONE", 9, 179754},
	{"ADELSTEIN", 9, 179755},
	{"KAFFEINE", 8, 179756},
	{"SOLEX", 5, 179757},
	{"RICHBURG", 8, 179758},
	{"BYELAWS", 7, 179759},
	{"XINGTONE", 8, 179760},
	{"SIZEAPPEAL", 10, 179761},
	{"GAYEST", 6, 179762},
	{"REDIT", 5, 179763},
	{"JARK", 4, 179764},
	{"PROFFESSIONAL", 13, 179765},
	{"KURAMA", 6, 179766},
	{"KNOBBY", 6, 179767},
	{"PAWAR", 5, 179768},
	{"BREWHOUSE", 9, 179769},
	{"GUARDIANSHIPS", 13, 179770},
	{"ZIOR", 4, 179771},
	{"YNBO", 4, 179772},
	{"WGOR", 4, 179773},
	{"RKYI", 4, 179774},
	{"ORUW", 4, 179775},
	{"NURN", 4, 179776},
	{"NJIW", 4, 179777},
	{"MAVR", 4, 179778},
	{"IRUD", 4, 179779},
	{"IGLY", 4, 179780},
	{"GKOS", 4, 179781},
	{"FWEV", 4, 179782},
	{"EMEQ", 4, 179783},
	{"DNCS", 4, 179784},
	{"CTVN", 4, 179785},
	{"BPSP", 4, 179786},
	{"CURMUDGEONLY", 12, 179787},
	{"PRINTZ", 6, 179788},
	{"XINERAMA", 8, 179789},
	{"HALLADAY", 8, 179790},
	{"BLUEY", 5, 179791},
	{"TORAL", 5, 179792},
	{"STRUTT", 6, 179793},
	{"NEBR", 4, 179794},
	{"ACTUALIDAD", 10, 179795},
	{"HEINEN", 6, 179796},
	{"FIZZING", 7, 179797},
	{"EETIMES", 7, 179798},
	{"ZIDA", 4, 179799},
	{"MONOPHONIQUES", 13, 179800},
	{"BULTACO", 7, 179801},
	{"LEORA", 5, 179802},
	{"JEWEILIGEN", 10, 179803},
	{"ADJACENCIES", 11, 179804},
	{"FOODNATION", 10, 179805},
	{"SUPERIEURE", 10, 179806},
	{"PLATTEN", 7, 179807},
	{"SCHMALTZ", 8, 179808},
	{"FETID", 5, 179809},
	{"NEXEN", 5, 179810},
	{"HILLYER", 7, 179811},
	{"BOATMEN", 7, 179812},
	{"MANDS", 5, 179813},
	{"BAYLES", 6, 179814},
	{"SABIE", 5, 179815},
	{"BALOCH", 6, 179816},
	{"TIFFANYS", 8, 179817},
	{"ENDOSOMES", 9, 179818},
	{"GIGAPOP", 7, 179819},
	{"MENCODER", 8, 179820},
	{"SEBOLD", 6, 179821},
	{"CCMS", 4, 179822},
	{"VESPASIAN", 9, 179823},
	{"TONGANOXIE", 10, 179824},
	{"SINGLENESS", 10, 179825},
	{"ARAYA", 5, 179826},
	{"YOGESH", 6, 179827},
	{"SCORCHER", 8, 179828},
	{"PRUFROCK", 8, 179829},
	{"TROUNCED", 8, 179830},
	{"FENICE", 6, 179831},
	{"PRESIDENCIES", 12, 179832},
	{"TOYSRUS", 7, 179833},
	{"KEBLE", 5, 179834},
	{"XBR", 3, 179835},
	{"NETBUYER", 8, 179836},
	{"KAPUT", 5, 179837},
	{"TAILSPIN", 8, 179838},
	{"STANOZOLOL", 10, 179839},
	{"KETTE", 5, 179840},
	{"SILLIEST", 8, 179841},
	{"COMPOSABLE", 10, 179842},
	{"DOLLARD", 7, 179843},
	{"BLACKFACE", 9, 179844},
	{"CUCKOOS", 7, 179845},
	{"VALUTATO", 8, 179846},
	{"BEDALE", 6, 179847},
	{"SCARBROUGH", 10, 179848},
	{"LYRIXS", 6, 179849},
	{"MEWES", 5, 179850},
	{"TURANDOT", 8, 179851},
	{"INDEFINITENESS", 14, 179852},
	{"SOTALOL", 7, 179853},
	{"LYRIVS", 6, 179854},
	{"BUSHWICK", 8, 179855},
	{"WINDSOCK", 8, 179856},
	{"HAIBLE", 6, 179857},
	{"PBUF", 4, 179858},
	{"REVEIW", 6, 179859},
	{"YEARNINGS", 9, 179860},
	{"EMVACIC", 7, 179861},
	{"YAKS", 4, 179862},
	{"HYDRIC", 6, 179863},
	{"WERBACH", 7, 179864},
	{"MARSTELLER", 10, 179865},
	{"DPHIL", 5, 179866},
	{"XMODS", 5, 179867},
	{"BYWATER", 7, 179868},
	{"BERRIGAN", 8, 179869},
	{"ZYOR", 4, 179870},
	{"ZELC", 4, 179871},
	{"YBYY", 4, 179872},
	{"XJON", 4, 179873},
	{"WOGL", 4, 179874},
	{"VOWO", 4, 179875},
	{"VLAC", 4, 179876},
	{"UZEI", 4, 179877},
	{"URLB", 4, 179878},
	{"SDAK", 4, 179879},
	{"RMRG", 4, 179880},
	{"PSKY", 4, 179881},
	{"MDWA", 4, 179882},
	{"MAHB", 4, 179883},
	{"LMIM", 4, 179884},
	{"LLMS", 4, 179885},
	{"KYFL", 4, 179886},
	{"KUSB", 4, 179887},
	{"KTIR", 4, 179888},
	{"ISYU", 4, 179889},
	{"IRYR", 4, 179890},
	{"EKEB", 4, 179891},
	{"EBOJ", 4, 179892},
	{"DPEM", 4, 179893},
	{"DMTH", 4, 179894},
	{"AUOR", 4, 179895},
	{"IGINLA", 6, 179896},
	{"ICONYOUR", 8, 179897},
	{"VALOREBOOKS", 11, 179898},
	{"DODAJ", 5, 179899},
	{"KONQ", 4, 179900},
	{"JOUEURS", 7, 179901},
	{"DEPENDENTLY", 11, 179902},
	{"TECNICHE", 8, 179903},
	{"CHRISTMASES", 11, 179904},
	{"KENNISON", 8, 179905},
	{"REMISE", 6, 179906},
	{"BALUCHISTAN", 11, 179907},
	{"TOMAN", 5, 179908},
	{"SISSETON", 8, 179909},
	{"FEEHAN", 6, 179910},
	{"SZASZ", 5, 179911},
	{"SKUA", 4, 179912},
	{"UNQUIET", 7, 179913},
	{"SOLECTRON", 9, 179914},
	{"EINZIGE", 7, 179915},
	{"JRP", 3, 179916},
	{"VERSTECKTE", 10, 179917},
	{"RADIC", 5, 179918},
	{"CLOCKWARE", 9, 179919},
	{"HERBAGE", 7, 179920},
	{"CHUUK", 5, 179921},
	{"BORISOV", 7, 179922},
	{"ENLOE", 5, 179923},
	{"APTER", 5, 179924},
	{"FLUOROSIS", 9, 179925},
	{"AVIARIES", 8, 179926},
	{"EVERBODY", 8, 179927},
	{"ADDUCE", 6, 179928},
	{"TWADDLE", 7, 179929},
	{"ECONOMIQUES", 11, 179930},
	{"BVG", 3, 179931},
	{"ELITR", 5, 179932},
	{"TACHOMETERS", 11, 179933},
	{"DAVIDA", 6, 179934},
	{"MARONEY", 7, 179935},
	{"RUNNINGS", 8, 179936},
	{"HELPSCREEN", 10, 179937},
	{"CLASIC", 6, 179938},
	{"ARQUIVOS", 8, 179939},
	{"DQPSK", 5, 179940},
	{"LYROCS", 6, 179941},
	{"DANZEL", 6, 179942},
	{"SUBPROBLEMS", 11, 179943},
	{"VINK", 4, 179944},
	{"MITSU", 5, 179945},
	{"BATTLECRUISER", 13, 179946},
	{"GONOCOCCAL", 10, 179947},
	{"OGGETTO", 7, 179948},
	{"FORFAITS", 8, 179949},
	{"SUMED", 5, 179950},
	{"SHILLINGTON", 11, 179951},
	{"RANIERI", 7, 179952},
	{"DSCR", 4, 179953},
	{"BOOSH", 5, 179954},
	{"LAMBERTS", 8, 179955},
	{"UNITARIANS", 10, 179956},
	{"ICDE", 4, 179957},
	{"APOTHEKE", 8, 179958},
	{"SNIFFIN", 7, 179959},
	{"JMG", 3, 179960},
	{"TRANSPOR", 8, 179961},
	{"UNUTTERABLE", 11, 179962},
	{"PLYOMETRICS", 11, 179963},
	{"MITTERRAND", 10, 179964},
	{"EXOTO", 5, 179965},
	{"MEMANTINE", 9, 179966},
	{"SCRIBING", 8, 179967},
	{"CERO", 4, 179968},
	{"CAUCHO", 6, 179969},
	{"ELLERMAN", 8, 179970},
	{"ROTTNEST", 8, 179971},
	{"AMEDA", 5, 179972},
	{"PLOYER", 6, 179973},
	{"OUTSHINE", 8, 179974},
	{"TRANSFOR", 8, 179975},
	{"YMMA", 4, 179976},
	{"WNMD", 4, 179977},
	{"UKLE", 4, 179978},
	{"RTKR", 4, 179979},
	{"ROTY", 4, 179980},
	{"PYOT", 4, 179981},
	{"PNAR", 4, 179982},
	{"OLMF", 4, 179983},
	{"OJOW", 4, 179984},
	{"NKKA", 4, 179985},
	{"NCBU", 4, 179986},
	{"MPAO", 4, 179987},
	{"MEKH", 4, 179988},
	{"LGUT", 4, 179989},
	{"LFOE", 4, 179990},
	{"KOCT", 4, 179991},
	{"IUPA", 4, 179992},
	{"HJOK", 4, 179993},
	{"HEKV", 4, 179994},
	{"FZAR", 4, 179995},
	{"DTHL", 4, 179996},
	{"BACR", 4, 179997},
	{"ASPD", 4, 179998},
	{"LYEICS", 6, 179999},
	{"MAHIDOL", 7, 180000},
	{"KLG", 3, 180001},
	{"TRANSURETHRAL", 13, 180002},
	{"PROSERPINE", 10, 180003},
	{"BLUECHILLIES", 12, 180004},
	{"ASSTD", 5, 180005},
	{"MOBILINK", 8, 180006},
	{"UHLSPORT", 8, 180007},
	{"CHATTOOGA", 9, 180008},
	{"PARISIANS", 9, 180009},
	{"CAPITO", 6, 180010},
	{"BUMPIN", 6, 180011},
	{"GYROSCOPES", 10, 180012},
	{"DIARRHOEAL", 10, 180013},
	{"STELLT", 6, 180014},
	{"TETRAHEDRA", 10, 180015},
	{"PATRONIZED", 10, 180016},
	{"MULLANEY", 8, 180017},
	{"IODIZED", 7, 180018},
	{"KARLS", 5, 180019},
	{"STEDFAST", 8, 180020},
	{"LIBWMF", 6, 180021},
	{"KAILA", 5, 180022},
	{"CAPSIZE", 7, 180023},
	{"MINISTERIE", 10, 180024},
	{"LYRICW", 6, 180025},
	{"GUNUNG", 6, 180026},
	{"ALDUS", 5, 180027},
	{"POMMES", 6, 180028},
	{"SUPERCHIPS", 10, 180029},
	{"PESCATORE", 9, 180030},
	{"INELEGANT", 9, 180031},
	{"CLAMBERED", 9, 180032},
	{"DUGAS", 5, 180033},
	{"HISTRIONIC", 10, 180034},
	{"LYFICS", 6, 180035},
	{"SUBSISTS", 8, 180036},
	{"RUNTIMEEXCEPTION", 16, 180037},
	{"IPFWADM", 7, 180038},
	{"MONONITRATE", 11, 180039},
	{"MONOGR", 6, 180040},
	{"LHRICS", 6, 180041},
	{"GONADOTROPINS", 13, 180042},
	{"GOODERS", 7, 180043},
	{"NATING", 6, 180044},
	{"WORLWIDE", 8, 180045},
	{"CORRECTORS", 10, 180046},
	{"QEMATA", 6, 180047},
	{"NEUROREPORT", 11, 180048},
	{"LYRKCS", 6, 180049},
	{"XERT", 4, 180050},
	{"BAGLE", 5, 180051},
	{"OWNERSHIPS", 10, 180052},
	{"EMBEDED", 7, 180053},
	{"CDBS", 4, 180054},
	{"SUCKLE", 6, 180055},
	{"GLUCOCONTROL", 12, 180056},
	{"CARNEIRO", 8, 180057},
	{"INTARSIA", 8, 180058},
	{"HEROQUEST", 9, 180059},
	{"DXTHREADS", 9, 180060},
	{"TSKB", 4, 180061},
	{"POPPET", 6, 180062},
	{"CHARTPLOTTERS", 13, 180063},
	{"LYRIFS", 6, 180064},
	{"LGRICS", 6, 180065},
	{"MILLNER", 7, 180066},
	{"LYRJCS", 6, 180067},
	{"ANDREU", 6, 180068},
	{"KINGFISHERS", 11, 180069},
	{"VIMES", 5, 180070},
	{"BOURASSA", 8, 180071},
	{"OYRICS", 6, 180072},
	{"FACIALLY", 8, 180073},
	{"COMAND", 6, 180074},
	{"VEEP", 4, 180075},
	{"ZEIM", 4, 180076},
	{"YLWI", 4, 180077},
	{"SXCO", 4, 180078},
	{"RZAH", 4, 180079},
	{"RYUL", 4, 180080},
	{"RAXS", 4, 180081},
	{"RAOW", 4, 180082},
	{"PORV", 4, 180083},
	{"PMDO", 4, 180084},
	{"OCTD", 4, 180085},
	{"NYOD", 4, 180086},
	{"MYKO", 4, 180087},
	{"KURR", 4, 180088},
	{"KMST", 4, 180089},
	{"JRWI", 4, 180090},
	{"JIGO", 4, 180091},
	{"HSGL", 4, 180092},
	{"HMSM", 4, 180093},
	{"GMWH", 4, 180094},
	{"GEDQ", 4, 180095},
	{"EMND", 4, 180096},
	{"DKRY", 4, 180097},
	{"DGBA", 4, 180098},
	{"BURF", 4, 180099},
	{"BMOS", 4, 180100},
	{"SOLICITUD", 9, 180101},
	{"POPPYCOCK", 9, 180102},
	{"OPENDARWIN", 10, 180103},
	{"MISAPPROPRIATED", 15, 180104},
	{"HMPH", 4, 180105},
	{"WORMHOLES", 9, 180106},
	{"POSTCONDITION", 13, 180107},
	{"EXLEY", 5, 180108},
	{"ZAHLEN", 6, 180109},
	{"DEGENERATING", 12, 180110},
	{"LYSISTRATA", 10, 180111},
	{"LABORAL", 7, 180112},
	{"COFINANCING", 11, 180113},
	{"ADULTCHAT", 9, 180114},
	{"ERSONAL", 7, 180115},
	{"PREDRAG", 7, 180116},
	{"SIRC", 4, 180117},
	{"RECOMMANDE", 10, 180118},
	{"NEBULAR", 7, 180119},
	{"SUBKEYS", 7, 180120},
	{"NOKIAS", 6, 180121},
	{"GEISEL", 6, 180122},
	{"IOLANI", 6, 180123},
	{"CJB", 3, 180124},
	{"CAVI", 4, 180125},
	{"WELBY", 5, 180126},
	{"SERGIUS", 7, 180127},
	{"ROSAMUNDE", 9, 180128},
	{"DOANLOAD", 8, 180129},
	{"ARKWRIGHT", 9, 180130},
	{"TACITURN", 8, 180131},
	{"SWAYS", 5, 180132},
	{"INYOKERN", 8, 180133},
	{"BACKPORTED", 10, 180134},
	{"CYBERMEN", 8, 180135},
	{"ISRCTN", 6, 180136},
	{"HSLDA", 5, 180137},
	{"ENUMERABLE", 10, 180138},
	{"DELACOUR", 8, 180139},
	{"TOSHIRO", 7, 180140},
	{"ACROREAD", 8, 180141},
	{"CHEEZ", 5, 180142},
	{"USWITCH", 7, 180143},
	{"GRATA", 5, 180144},
	{"BERATED", 7, 180145},
	{"TRANSLOCASE", 11, 180146},
	{"ARKIVE", 6, 180147},
	{"NEWYEARS", 8, 180148},
	{"MONON", 5, 180149},
	{"BALTER", 6, 180150},
	{"VIDEOMAKER", 10, 180151},
	{"KAYENTA", 7, 180152},
	{"CKIN", 4, 180153},
	{"GOODER", 6, 180154},
	{"COLYER", 6, 180155},
	{"APACHEHANDLER", 13, 180156},
	{"SUNRACE", 7, 180157},
	{"NANOCOMPOSITE", 13, 180158},
	{"HAEMODIALYSIS", 13, 180159},
	{"VIRTANEN", 8, 180160},
	{"GREASING", 8, 180161},
	{"DSKELCFGFILE", 12, 180162},
	{"SINDS", 5, 180163},
	{"MOUSEMAT", 8, 180164},
	{"FUGE", 4, 180165},
	{"ECACHL", 6, 180166},
	{"QTLS", 4, 180167},
	{"SERTOLI", 7, 180168},
	{"PYRICS", 6, 180169},
	{"EUTROPHIC", 9, 180170},
	{"DLIDO", 5, 180171},
	{"TORCHIERES", 10, 180172},
	{"BRISTLED", 8, 180173},
	{"MILANI", 6, 180174},
	{"CSCC", 4, 180175},
	{"UNLEARN", 7, 180176},
	{"KARRIE", 6, 180177},
	{"DAJE", 4, 180178},
	{"CASTINE", 7, 180179},
	{"UNEDIG", 6, 180180},
	{"LATVIJA", 7, 180181},
	{"FLECKED", 7, 180182},
	{"CCPR", 4, 180183},
	{"DOOZY", 5, 180184},
	{"LATERALITY", 10, 180185},
	{"SUPERPOSED", 10, 180186},
	{"SIROLIMUS", 9, 180187},
	{"PICOULT", 7, 180188},
	{"SERAFIN", 7, 180189},
	{"PREPLANNING", 11, 180190},
	{"AELOD", 5, 180191},
	{"COVERI", 6, 180192},
	{"ASTROPHYSICIST", 14, 180193},
	{"NEWSWORLD", 9, 180194},
	{"REDESIGNATING", 13, 180195},
	{"SABBATHS", 8, 180196},
	{"ALRC", 4, 180197},
	{"SARUM", 5, 180198},
	{"MUSTERING", 9, 180199},
	{"ZURR", 4, 180200},
	{"VYNA", 4, 180201},
	{"URLT", 4, 180202},
	{"UEEP", 4, 180203},
	{"SXME", 4, 180204},
	{"SAUP", 4, 180205},
	{"PVIR", 4, 180206},
	{"PNRA", 4, 180207},
	{"ORFB", 4, 180208},
	{"NPIM", 4, 180209},
	{"MVAS", 4, 180210},
	{"MUGI", 4, 180211},
	{"LOPG", 4, 180212},
	{"ILUM", 4, 180213},
	{"HFEV", 4, 180214},
	{"GSTB", 4, 180215},
	{"FLMA", 4, 180216},
	{"ERKD", 4, 180217},
	{"EMRN", 4, 180218},
	{"EBMI", 4, 180219},
	{"DIXA", 4, 180220},
	{"BFLO", 4, 180221},
	{"AZCO", 4, 180222},
	{"MATADORS", 8, 180223},
	{"EUROCLEAR", 9, 180224},
	{"CASELAW", 7, 180225},
	{"HIROTA", 6, 180226},
	{"CELEBERTY", 9, 180227},
	{"CLOWNFISH", 9, 180228},
	{"ALLEMANDE", 9, 180229},
	{"SOPHY", 5, 180230},
	{"ASHGROVE", 8, 180231},
	{"YKK", 3, 180232},
	{"TCCC", 4, 180233},
	{"ENDONUCLEASES", 13, 180234},
	{"CURTIZ", 6, 180235},
	{"PARAMARIBO", 10, 180236},
	{"LUNDH", 5, 180237},
	{"MURWILLUMBAH", 12, 180238},
	{"FOBUS", 5, 180239},
	{"BETROTHAL", 9, 180240},
	{"BENTGEAR", 8, 180241},
	{"ANNETT", 6, 180242},
	{"TRESTLES", 8, 180243},
	{"KERNIGHAN", 9, 180244},
	{"ORAZIO", 6, 180245},
	{"BARRIENTOS", 10, 180246},
	{"SKEWS", 5, 180247},
	{"MOWERY", 6, 180248},
	{"GONDRY", 6, 180249},
	{"ROTHE", 5, 180250},
	{"DAMRON", 6, 180251},
	{"ROGRAMS", 7, 180252},
	{"BACCARA", 7, 180253},
	{"SIMCHAT", 7, 180254},
	{"NIPPY", 5, 180255},
	{"USCCB", 5, 180256},
	{"DELGADOS", 8, 180257},
	{"DADI", 4, 180258},
	{"BIOANALYTICAL", 13, 180259},
	{"WELTS", 5, 180260},
	{"MATAR", 5, 180261},
	{"KALETRA", 7, 180262},
	{"INTRUDES", 8, 180263},
	{"HACKBARTH", 9, 180264},
	{"GANESAN", 7, 180265},
	{"FERRIGNO", 8, 180266},
	{"ELWIN", 5, 180267},
	{"SPLIFF", 6, 180268},
	{"RINDS", 5, 180269},
	{"ELEMENTOS", 9, 180270},
	{"ADLT", 4, 180271},
	{"BLUEDOG", 7, 180272},
	{"GREENEST", 8, 180273},
	{"PYRIMIDINES", 11, 180274},
	{"YOUT", 4, 180275},
	{"HOSEASONS", 9, 180276},
	{"PIMPPA", 6, 180277},
	{"FASTFOOD", 8, 180278},
	{"UNIVERSITETET", 13, 180279},
	{"DSCH", 4, 180280},
	{"DOCKABLE", 8, 180281},
	{"PANDAN", 6, 180282},
	{"NICOLLE", 7, 180283},
	{"FOISTED", 7, 180284},
	{"SUSKIND", 7, 180285},
	{"CYTOSCAPE", 9, 180286},
	{"KALISH", 6, 180287},
	{"MKR", 3, 180288},
	{"LOLLAPALOOZA", 12, 180289},
	{"HOROSCOPO", 9, 180290},
	{"PANAJI", 6, 180291},
	{"MUNCHKINS", 9, 180292},
	{"ORDINALS", 8, 180293},
	{"BOORISH", 7, 180294},
	{"PEOPIE", 6, 180295},
	{"EIGHTHS", 7, 180296},
	{"OVERBAY", 7, 180297},
	{"REGLAS", 6, 180298},
	{"ONESTOP", 7, 180299},
	{"MUTEXES", 7, 180300},
	{"UNIC", 4, 180301},
	{"SHIPSTON", 8, 180302},
	{"ISRP", 4, 180303},
	{"CRAMPON", 7, 180304},
	{"AKICA", 5, 180305},
	{"XLIBRIS", 7, 180306},
	{"JIRO", 4, 180307},
	{"PACKETCABLE", 11, 180308},
	{"TABACCO", 7, 180309},
	{"GLACIOLOGY", 10, 180310},
	{"NIKES", 5, 180311},
	{"DCMA", 4, 180312},
	{"SAVOIA", 6, 180313},
	{"ZIGI", 4, 180314},
	{"YNLA", 4, 180315},
	{"YIFB", 4, 180316},
	{"WILP", 4, 180317},
	{"VROB", 4, 180318},
	{"TVPA", 4, 180319},
	{"SBNR", 4, 180320},
	{"PYSC", 4, 180321},
	{"PCAB", 4, 180322},
	{"OSLD", 4, 180323},
	{"NYOM", 4, 180324},
	{"NGOZ", 4, 180325},
	{"NCZA", 4, 180326},
	{"LLDW", 4, 180327},
	{"LFVO", 4, 180328},
	{"JDDR", 4, 180329},
	{"HYYE", 4, 180330},
	{"GAUM", 4, 180331},
	{"FOLG", 4, 180332},
	{"ENCM", 4, 180333},
	{"EAGM", 4, 180334},
	{"DMRJ", 4, 180335},
	{"DCMO", 4, 180336},
	{"BVIA", 4, 180337},
	{"BRSQ", 4, 180338},
	{"AQDE", 4, 180339},
	{"AJIW", 4, 180340},
	{"RENEWCOMMAND", 12, 180341},
	{"MILLPOND", 8, 180342},
	{"ALTENBURG", 9, 180343},
	{"AUDIOLAB", 8, 180344},
	{"WHITETAILS", 10, 180345},
	{"SQUIGGLE", 8, 180346},
	{"MISSOULIAN", 10, 180347},
	{"CHANTEUSE", 9, 180348},
	{"SPETTACOLI", 10, 180349},
	{"RURALES", 7, 180350},
	{"DETALII", 7, 180351},
	{"AIRSHOWS", 8, 180352},
	{"GULLIBILITY", 11, 180353},
	{"GOODLOOKING", 11, 180354},
	{"GERNOT", 6, 180355},
	{"WETUMPKA", 8, 180356},
	{"REDAZIONE", 9, 180357},
	{"KELD", 4, 180358},
	{"VANMARK", 7, 180359},
	{"PISTURES", 8, 180360},
	{"CATBACK", 7, 180361},
	{"ROUGHED", 7, 180362},
	{"VASOTEC", 7, 180363},
	{"MERCIE", 6, 180364},
	{"VIKES", 5, 180365},
	{"PERFUM", 6, 180366},
	{"YAFFE", 5, 180367},
	{"DIYA", 4, 180368},
	{"BLCK", 4, 180369},
	{"BRAHE", 5, 180370},
	{"QUESTE", 6, 180371},
	{"IMPRESORAS", 10, 180372},
	{"ILLES", 5, 180373},
	{"WOODCREST", 9, 180374},
	{"WATERBOY", 8, 180375},
	{"SILSBEE", 7, 180376},
	{"KOPER", 5, 180377},
	{"ALTAN", 5, 180378},
	{"AEROMEDICAL", 11, 180379},
	{"DEVOIR", 6, 180380},
	{"BLACKBEARS", 10, 180381},
	{"HUNDE", 5, 180382},
	{"PANHARD", 7, 180383},
	{"RCTC", 4, 180384},
	{"DFAIT", 5, 180385},
	{"BARIS", 5, 180386},
	{"COAG", 4, 180387},
	{"SIMPLEXML", 9, 180388},
	{"TAMM", 4, 180389},
	{"GONDWANA", 8, 180390},
	{"DLLIMPORT", 9, 180391},
	{"ISTRY", 5, 180392},
	{"ENTIREWEB", 9, 180393},
	{"CORDIA", 6, 180394},
	{"BLOGHARBOR", 10, 180395},
	{"NUDEPICTURES", 12, 180396},
	{"NANOFABRICATION", 15, 180397},
	{"KARAKAS", 7, 180398},
	{"ADJOINED", 8, 180399},
	{"INTERVEN", 8, 180400},
	{"WATERSKI", 8, 180401},
	{"TANAKH", 6, 180402},
	{"MOULT", 5, 180403},
	{"TESSELLATION", 12, 180404},
	{"SOUMIS", 6, 180405},
	{"FREESCI", 7, 180406},
	{"AUTOLEADS", 9, 180407},
	{"WIDEMAN", 7, 180408},
	{"NAMATH", 6, 180409},
	{"ALLAKHAZAM", 10, 180410},
	{"PURCELLVILLE", 12, 180411},
	{"GYULA", 5, 180412},
	{"SEBASTIANO", 10, 180413},
	{"KONTA", 5, 180414},
	{"HOTPLATE", 8, 180415},
	{"REDID", 5, 180416},
	{"AFTERSALES", 10, 180417},
	{"TOYNE", 5, 180418},
	{"GOODISON", 8, 180419},
	{"POLYOL", 6, 180420},
	{"HOTCOPPER", 9, 180421},
	{"AUGUE", 5, 180422},
	{"PIRE", 4, 180423},
	{"ARTZ", 4, 180424},
	{"GETPARAMETER", 12, 180425},
	{"BARMY", 5, 180426},
	{"HANWELL", 7, 180427},
	{"CAVALLINI", 9, 180428},
	{"FOURDOCS", 8, 180429},
	{"COMPLEMENTARITIES", 17, 180430},
	{"VILEST", 6, 180431},
	{"SOMTIMES", 8, 180432},
	{"SEVAN", 5, 180433},
	{"INDOLES", 7, 180434},
	{"EXAFS", 5, 180435},
	{"AORIST", 6, 180436},
	{"GOTTHARD", 8, 180437},
	{"LUKASAURUS", 10, 180438},
	{"DOTADAS", 7, 180439},
	{"ANIMIST", 7, 180440},
	{"VPTH", 4, 180441},
	{"VILV", 4, 180442},
	{"ULSN", 4, 180443},
	{"UARG", 4, 180444},
	{"SUPJ", 4, 180445},
	{"RITK", 4, 180446},
	{"PHEG", 4, 180447},
	{"OXOU", 4, 180448},
	{"NLOL", 4, 180449},
	{"NKZA", 4, 180450},
	{"MCDI", 4, 180451},
	{"LYCM", 4, 180452},
	{"LWAH", 4, 180453},
	{"KJOR", 4, 180454},
	{"KFOX", 4, 180455},
	{"IAZW", 4, 180456},
	{"GROR", 4, 180457},
	{"GNYA", 4, 180458},
	{"GGYR", 4, 180459},
	{"EZZE", 4, 180460},
	{"EMIY", 4, 180461},
	{"EGOY", 4, 180462},
	{"EBWE", 4, 180463},
	{"DZOM", 4, 180464},
	{"CABT", 4, 180465},
	{"AWIY", 4, 180466},
	{"ATRB", 4, 180467},
	{"ARFC", 4, 180468},
	{"AQID", 4, 180469},
	{"AFAW", 4, 180470},
	{"MICROTITER", 10, 180471},
	{"JONASSON", 8, 180472},
	{"FEMARA", 6, 180473},
	{"BATTLER", 7, 180474},
	{"VASSALS", 7, 180475},
	{"JGR", 3, 180476},
	{"CONGOS", 6, 180477},
	{"SICAMOUS", 8, 180478},
	{"SAFESURF", 8, 180479},
	{"BEYBLADES", 9, 180480},
	{"KRAM", 4, 180481},
	{"TRANX", 5, 180482},
	{"OKOBOJI", 7, 180483},
	{"THROTTLED", 9, 180484},
	{"PANTEX", 6, 180485},
	{"TIPPERS", 7, 180486},
	{"SCIFIT", 6, 180487},
	{"SAVILL", 6, 180488},
	{"BRASILIENSIS", 12, 180489},
	{"KELLIHER", 8, 180490},
	{"NONTERMINAL", 11, 180491},
	{"KALAUPAPA", 9, 180492},
	{"GENTIUM", 7, 180493},
	{"VULNIFICUS", 10, 180494},
	{"SOPRANI", 7, 180495},
	{"MOOLENAAR", 9, 180496},
	{"INFORMAT", 8, 180497},
	{"EGALE", 5, 180498},
	{"BUTYRIC", 7, 180499},
	{"SHAYE", 5, 180500},
	{"BULIMIC", 7, 180501},
	{"RIDGER", 6, 180502},
	{"SPIRITO", 7, 180503},
	{"REZENSENTIN", 11, 180504},
	{"OCTANOL", 7, 180505},
	{"KEURIG", 6, 180506},
	{"PEPOLE", 6, 180507},
	{"SANDYLION", 9, 180508},
	{"WOMAD", 5, 180509},
	{"FRID", 4, 180510},
	{"TRANING", 7, 180511},
	{"OESTRADIOL", 10, 180512},
	{"KYR", 3, 180513},
	{"DUNWICH", 7, 180514},
	{"CINTRE", 6, 180515},
	{"CHGSET", 6, 180516},
	{"TARAWERA", 8, 180517},
	{"CABAS", 5, 180518},
	{"CAMFROG", 7, 180519},
	{"ENGLEHART", 9, 180520},
	{"BOCAS", 5, 180521},
	{"LASHKAR", 7, 180522},
	{"EBID", 4, 180523},
	{"DOURIF", 6, 180524},
	{"TRENTBASIN", 10, 180525},
	{"MPLAB", 5, 180526},
	{"GIBLIN", 6, 180527},
	{"FONDER", 6, 180528},
	{"MEDOC", 5, 180529},
	{"CMBS", 4, 180530},
	{"INSULATES", 9, 180531},
	{"TAGOH", 5, 180532},
	{"MOTLES", 6, 180533},
	{"LAMBCHOP", 8, 180534},
	{"ENTRANCING", 10, 180535},
	{"WILLAPA", 7, 180536},
	{"BLAKEWAY", 8, 180537},
	{"UNPUBL", 6, 180538},
	{"MENINGEAL", 9, 180539},
	{"MELANCHOLIA", 11, 180540},
	{"WUGGAWOO", 8, 180541},
	{"SHAMPOOING", 10, 180542},
	{"SEEBEYOND", 9, 180543},
	{"VIOLON", 6, 180544},
	{"VESTER", 6, 180545},
	{"NAMC", 4, 180546},
	{"GEGENLICHTBLENDE", 16, 180547},
	{"LITESTEP", 8, 180548},
	{"AMAPI", 5, 180549},
	{"SWARAJ", 6, 180550},
	{"TAIYUAN", 7, 180551},
	{"WATCOM", 6, 180552},
	{"MOLDER", 6, 180553},
	{"FUDENDO", 7, 180554},
	{"ZEFAL", 5, 180555},
	{"DUNNY", 5, 180556},
	{"CAPPUCINO", 9, 180557},
	{"YSNY", 4, 180558},
	{"XOSM", 4, 180559},
	{"ULUK", 4, 180560},
	{"PMSP", 4, 180561},
	{"OCZE", 4, 180562},
	{"NKAJ", 4, 180563},
	{"MEYR", 4, 180564},
	{"LRAJ", 4, 180565},
	{"KLUK", 4, 180566},
	{"HUAG", 4, 180567},
	{"HNGU", 4, 180568},
	{"EUWS", 4, 180569},
	{"EKCY", 4, 180570},
	{"EECW", 4, 180571},
	{"DKOP", 4, 180572},
	{"CSFL", 4, 180573},
	{"BYTV", 4, 180574},
	{"BCBO", 4, 180575},
	{"BARJ", 4, 180576},
	{"BAEX", 4, 180577},
	{"AWKB", 4, 180578},
	{"APYM", 4, 180579},
	{"DOWNOLAD", 8, 180580},
	{"UNLEY", 5, 180581},
	{"PERLLIBS", 8, 180582},
	{"CHROMINANCE", 11, 180583},
	{"PILOTHOUSE", 10, 180584},
	{"NAKUSP", 6, 180585},
	{"HOGESCHOOL", 10, 180586},
	{"BOYKINS", 7, 180587},
	{"AVAILIABLE", 10, 180588},
	{"VALIA", 5, 180589},
	{"VISUALISED", 10, 180590},
	{"HANAU", 5, 180591},
	{"SEAGRAVE", 8, 180592},
	{"CHADWELL", 8, 180593},
	{"THORNWOOD", 9, 180594},
	{"DRAGULA", 7, 180595},
	{"UNCED", 5, 180596},
	{"JORDY", 5, 180597},
	{"CABOTINE", 8, 180598},
	{"NUNZIO", 6, 180599},
	{"ROGAR", 5, 180600},
	{"MEXIQUE", 7, 180601},
	{"ELOPE", 5, 180602},
	{"DIENES", 6, 180603},
	{"STIBO", 5, 180604},
	{"PRINTCAP", 8, 180605},
	{"BIGMACHINES", 11, 180606},
	{"GINKO", 5, 180607},
	{"OCELLATUS", 9, 180608},
	{"MINIBOX", 7, 180609},
	{"MICROINJECTION", 14, 180610},
	{"OGURA", 5, 180611},
	{"EXPEN", 5, 180612},
	{"SURVIVALIST", 11, 180613},
	{"SNOWPARK", 8, 180614},
	{"SCRIABIN", 8, 180615},
	{"MARITZ", 6, 180616},
	{"RESCH", 5, 180617},
	{"PMAC", 4, 180618},
	{"GASOL", 5, 180619},
	{"NEHMEN", 6, 180620},
	{"DIGITALS", 8, 180621},
	{"APERTO", 6, 180622},
	{"OLDSKOOL", 8, 180623},
	{"CFK", 3, 180624},
	{"ONETHUMB", 8, 180625},
	{"STUDENTBOOKWORLD", 16, 180626},
	{"WAILUA", 6, 180627},
	{"NARASIMHA", 9, 180628},
	{"MOVWF", 5, 180629},
	{"ZCZC", 4, 180630},
	{"INFOCHOICE", 10, 180631},
	{"CHOLESTYRAMINE", 14, 180632},
	{"CYHOEDDI", 8, 180633},
	{"WEBBE", 5, 180634},
	{"RAMIFICATION", 12, 180635},
	{"SUNSATION", 9, 180636},
	{"ELLUSIONZ", 9, 180637},
	{"WELSHMAN", 8, 180638},
	{"CREMATORIA", 10, 180639},
	{"MICRODIALYSIS", 13, 180640},
	{"GRODNO", 6, 180641},
	{"NANCHANG", 8, 180642},
	{"ABDUCTEES", 9, 180643},
	{"POIANA", 6, 180644},
	{"TELECLASSES", 11, 180645},
	{"VLIEGER", 7, 180646},
	{"RABAUL", 6, 180647},
	{"AYCOCK", 6, 180648},
	{"IHEALTHTREE", 11, 180649},
	{"BEGUILED", 8, 180650},
	{"SALMOND", 7, 180651},
	{"DONATI", 6, 180652},
	{"CRATED", 6, 180653},
	{"MAALOX", 6, 180654},
	{"CHENOPODIUM", 11, 180655},
	{"BESOINS", 7, 180656},
	{"CRIMPERS", 8, 180657},
	{"BEHM", 4, 180658},
	{"MONIZ", 5, 180659},
	{"DIGIGUIDE", 9, 180660},
	{"YSTG", 4, 180661},
	{"YMEB", 4, 180662},
	{"YLOM", 4, 180663},
	{"YJOL", 4, 180664},
	{"WNIR", 4, 180665},
	{"TLLP", 4, 180666},
	{"RKOK", 4, 180667},
	{"RAJM", 4, 180668},
	{"NDXR", 4, 180669},
	{"MPMC", 4, 180670},
	{"LKTI", 4, 180671},
	{"LIDJ", 4, 180672},
	{"KOCI", 4, 180673},
	{"KAYD", 4, 180674},
	{"JPRI", 4, 180675},
	{"ISYP", 4, 180676},
	{"HTUC", 4, 180677},
	{"HGWE", 4, 180678},
	{"GNUG", 4, 180679},
	{"FGAD", 4, 180680},
	{"EDRW", 4, 180681},
	{"EDDD", 4, 180682},
	{"EBUP", 4, 180683},
	{"DYEC", 4, 180684},
	{"CRIK", 4, 180685},
	{"CHOJ", 4, 180686},
	{"BNMA", 4, 180687},
	{"BBII", 4, 180688},
	{"AOBJ", 4, 180689},
	{"AAUB", 4, 180690},
	{"KIMIKO", 6, 180691},
	{"LENSDEKSEL", 10, 180692},
	{"PRIVATISE", 9, 180693},
	{"AZEEM", 5, 180694},
	{"AGCAS", 5, 180695},
	{"ROLLERGIRLS", 11, 180696},
	{"REHIRE", 6, 180697},
	{"HYDROFLUORIC", 12, 180698},
	{"IDOC", 4, 180699},
	{"VIOLETTA", 8, 180700},
	{"AUTHENTICWATCHES", 16, 180701},
	{"HANNAY", 6, 180702},
	{"PHOTOBLOGGING", 13, 180703},
	{"UNREPRESENTATIVE", 16, 180704},
	{"BLUESCOPE", 9, 180705},
	{"KERATINOCYTE", 12, 180706},
	{"KASLO", 5, 180707},
	{"GYNAECOLOGIST", 13, 180708},
	{"FILMIKI", 7, 180709},
	{"ARRESTOR", 8, 180710},
	{"FAIREY", 6, 180711},
	{"YEZDK", 5, 180712},
	{"STILLEN", 7, 180713},
	{"EVERTS", 6, 180714},
	{"CERRILLOS", 9, 180715},
	{"ACOVEA", 6, 180716},
	{"COUNTERFEITERS", 14, 180717},
	{"MANELE", 6, 180718},
	{"EDITA", 5, 180719},
	{"KFM", 3, 180720},
	{"SWINFORD", 8, 180721},
	{"SINEW", 5, 180722},
	{"TOPLAYER", 8, 180723},
	{"PUBLICATIES", 11, 180724},
	{"CISCOE", 6, 180725},
	{"WRITEWORDS", 10, 180726},
	{"MORDANT", 7, 180727},
	{"MERICA", 6, 180728},
	{"INCOTERMS", 9, 180729},
	{"OVERBOUGHT", 10, 180730},
	{"SADDUCEES", 9, 180731},
	{"BULAN", 5, 180732},
	{"ERWINIA", 7, 180733},
	{"YZERMAN", 7, 180734},
	{"OGYSTAL", 7, 180735},
	{"MPACT", 5, 180736},
	{"TWIKISITETOOLS", 14, 180737},
	{"HAECKEL", 7, 180738},
	{"CULTUREL", 8, 180739},
	{"INTIMUS", 7, 180740},
	{"ROCKETEER", 9, 180741},
	{"BORDO", 5, 180742},
	{"RAMIREZI", 8, 180743},
	{"MICROCONTENT", 12, 180744},
	{"CLOTILDE", 8, 180745},
	{"TORTURER", 8, 180746},
	{"INGOLSTADT", 10, 180747},
	{"POKA", 4, 180748},
	{"NOTER", 5, 180749},
	{"REISNER", 7, 180750},
	{"CARNIE", 6, 180751},
	{"DROUOT", 6, 180752},
	{"AUKE", 4, 180753},
	{"TAEGAN", 6, 180754},
	{"PRESCRITION", 11, 180755},
	{"CORRELATIONAL", 13, 180756},
	{"JAQUELINE", 9, 180757},
	{"DURATEC", 7, 180758},
	{"SLAPPER", 7, 180759},
	{"SOMNOLENCE", 10, 180760},
	{"LIPSEY", 6, 180761},
	{"CURVATURES", 10, 180762},
	{"COMMANDEERED", 12, 180763},
	{"CONNIFF", 7, 180764},
	{"CERTAINTEED", 11, 180765},
	{"ASCRIBING", 9, 180766},
	{"MDY", 3, 180767},
	{"ZZWA", 4, 180768},
	{"ZYLI", 4, 180769},
	{"WRZB", 4, 180770},
	{"VUIT", 4, 180771},
	{"TYFC", 4, 180772},
	{"TRZE", 4, 180773},
	{"SCYR", 4, 180774},
	{"SAKM", 4, 180775},
	{"RTVC", 4, 180776},
	{"PYSI", 4, 180777},
	{"PHAU", 4, 180778},
	{"NAPG", 4, 180779},
	{"MSUH", 4, 180780},
	{"MEXS", 4, 180781},
	{"KIEX", 4, 180782},
	{"IWAC", 4, 180783},
	{"ILJI", 4, 180784},
	{"HMIM", 4, 180785},
	{"HHUD", 4, 180786},
	{"EUED", 4, 180787},
	{"ERVR", 4, 180788},
	{"EBUH", 4, 180789},
	{"DGYN", 4, 180790},
	{"AURD", 4, 180791},
	{"ARZS", 4, 180792},
	{"AADJ", 4, 180793},
	{"TAKUYA", 6, 180794},
	{"IRREPARABLY", 11, 180795},
	{"FAUNTLEROY", 10, 180796},
	{"ZAHL", 4, 180797},
	{"MINNICH", 7, 180798},
	{"MCOM", 4, 180799},
	{"SHIRRED", 7, 180800},
	{"SIGNPOSTING", 11, 180801},
	{"IMPROVMENT", 10, 180802},
	{"PUKEKOHE", 8, 180803},
	{"WALTHALL", 8, 180804},
	{"ENERGIZERS", 10, 180805},
	{"RUSSA", 5, 180806},
	{"CATHI", 5, 180807},
	{"SETTITLE", 8, 180808},
	{"CMHS", 4, 180809},
	{"UPLINKS", 7, 180810},
	{"SPEAKMAN", 8, 180811},
	{"JNCC", 4, 180812},
	{"HETEROZYGOTES", 13, 180813},
	{"FUJIMI", 6, 180814},
	{"CONVAIR", 7, 180815},
	{"GEOCOMMUNITY", 12, 180816},
	{"MORGENTHAU", 10, 180817},
	{"DIAGONALIZATION", 15, 180818},
	{"QUEENE", 6, 180819},
	{"SUTTONS", 7, 180820},
	{"SWAYNE", 6, 180821},
	{"SOULWAX", 7, 180822},
	{"TOIMPROVE", 9, 180823},
	{"MORRISEY", 8, 180824},
	{"JORDAAN", 7, 180825},
	{"SWEETING", 8, 180826},
	{"HOMENS", 6, 180827},
	{"HOCHSCHILD", 10, 180828},
	{"OMPUTER", 7, 180829},
	{"ACQUISTION", 10, 180830},
	{"PARATURE", 8, 180831},
	{"DONTNOTIFY", 10, 180832},
	{"EDGERS", 6, 180833},
	{"RETREIVE", 8, 180834},
	{"MAPEX", 5, 180835},
	{"ACEST", 5, 180836},
	{"ADAIRSVILLE", 11, 180837},
	{"UPCOMMING", 9, 180838},
	{"MORIRE", 6, 180839},
	{"COMPTER", 7, 180840},
	{"MINMAX", 6, 180841},
	{"LUCKIER", 7, 180842},
	{"HESSEL", 6, 180843},
	{"PARTYWARE", 9, 180844},
	{"CAPLIN", 6, 180845},
	{"WREDE", 5, 180846},
	{"SEISMOGRAPH", 11, 180847},
	{"ZUNCH", 5, 180848},
	{"DIATOMIC", 8, 180849},
	{"INAUGURATING", 12, 180850},
	{"TOVEY", 5, 180851},
	{"KNOPP", 5, 180852},
	{"BROWSES", 7, 180853},
	{"GERMANICUS", 10, 180854},
	{"GAZETTEERS", 10, 180855},
	{"ITAMAR", 6, 180856},
	{"DECLENSION", 10, 180857},
	{"SHERMER", 7, 180858},
	{"DLOG", 4, 180859},
	{"ROMANSH", 7, 180860},
	{"PINSTRIPED", 10, 180861},
	{"DUNIA", 5, 180862},
	{"TROSSACHS", 9, 180863},
	{"NEGATIVED", 9, 180864},
	{"LATINOAMERICANA", 15, 180865},
	{"EXPEDITES", 9, 180866},
	{"BALZER", 6, 180867},
	{"CLAYMATION", 10, 180868},
	{"ANIMAIS", 7, 180869},
	{"STANDPOINTS", 11, 180870},
	{"YPEY", 4, 180871},
	{"YFRY", 4, 180872},
	{"WAOR", 4, 180873},
	{"VOCH", 4, 180874},
	{"UWAH", 4, 180875},
	{"UPAJ", 4, 180876},
	{"UIWI", 4, 180877},
	{"TVPL", 4, 180878},
	{"SMEK", 4, 180879},
	{"SEGB", 4, 180880},
	{"RWIP", 4, 180881},
	{"RUIC", 4, 180882},
	{"PSLU", 4, 180883},
	{"PEGW", 4, 180884},
	{"OZAB", 4, 180885},
	{"MGOB", 4, 180886},
	{"IUMJ", 4, 180887},
	{"ICUI", 4, 180888},
	{"IBHU", 4, 180889},
	{"FRYW", 4, 180890},
	{"FFIJ", 4, 180891},
	{"EWUT", 4, 180892},
	{"DUMD", 4, 180893},
	{"DDAA", 4, 180894},
	{"CDYE", 4, 180895},
	{"CCIH", 4, 180896},
	{"BAHM", 4, 180897},
	{"AVLE", 4, 180898},
	{"AFRY", 4, 180899},
	{"AEMM", 4, 180900},
	{"CARNABY", 7, 180901},
	{"CCVERSION", 9, 180902},
	{"ORYZAE", 6, 180903},
	{"HEIRENS", 7, 180904},
	{"ANTERO", 6, 180905},
	{"UNGULATES", 9, 180906},
	{"EXPED", 5, 180907},
	{"WALSTON", 7, 180908},
	{"VARDA", 5, 180909},
	{"VAWA", 4, 180910},
	{"SWINGLINE", 9, 180911},
	{"SURAJ", 5, 180912},
	{"ODDNESS", 7, 180913},
	{"CLEATOR", 7, 180914},
	{"GRANITZ", 7, 180915},
	{"COMBINATOR", 10, 180916},
	{"LVR", 3, 180917},
	{"DORMOUSE", 8, 180918},
	{"ATLC", 4, 180919},
	{"SMIDGEN", 7, 180920},
	{"WWWGOOGLE", 9, 180921},
	{"FIRMAN", 6, 180922},
	{"SEGNI", 5, 180923},
	{"WATERBOYS", 9, 180924},
	{"GAMESVILLE", 10, 180925},
	{"CASEPACK", 8, 180926},
	{"FAWNS", 5, 180927},
	{"BRIAND", 6, 180928},
	{"TOUPPER", 7, 180929},
	{"MILNOR", 6, 180930},
	{"BROMELIAD", 9, 180931},
	{"GEOTIFF", 7, 180932},
	{"AMMENDMENT", 10, 180933},
	{"BUNION", 6, 180934},
	{"WAID", 4, 180935},
	{"VELLEMAN", 8, 180936},
	{"RIGSBY", 6, 180937},
	{"GREENSLADE", 10, 180938},
	{"GORIN", 5, 180939},
	{"SHATIN", 6, 180940},
	{"CLICKHERETOFIND", 15, 180941},
	{"STRUKTUR", 8, 180942},
	{"SNOBBISH", 8, 180943},
	{"MOXLEY", 6, 180944},
	{"FOUNDSTONE", 10, 180945},
	{"SFCC", 4, 180946},
	{"KIDSWEAR", 8, 180947},
	{"SALVAPANTALLAS", 14, 180948},
	{"MICHELA", 7, 180949},
	{"FUNNELING", 9, 180950},
	{"SPAGO", 5, 180951},
	{"SCHREIER", 8, 180952},
	{"YELLOWHEAD", 10, 180953},
	{"ANIXTER", 7, 180954},
	{"BELLISSIMO", 10, 180955},
	{"ACWA", 4, 180956},
	{"NURPP", 5, 180957},
	{"SETTEES", 7, 180958},
	{"MORPHOS", 7, 180959},
	{"FLEDGING", 8, 180960},
	{"PUSAT", 5, 180961},
	{"FERNTREE", 8, 180962},
	{"OSNABRUECK", 10, 180963},
	{"DAMARIS", 7, 180964},
	{"SCRAPWORKS", 10, 180965},
	{"PROPERTYFINDER", 14, 180966},
	{"ANODYNE", 7, 180967},
	{"SAMANA", 6, 180968},
	{"SANCTIFYING", 11, 180969},
	{"CULTIC", 6, 180970},
	{"DAGS", 4, 180971},
	{"COLORATI", 8, 180972},
	{"TOSCANINI", 9, 180973},
	{"PHONEANALOGWIRELESS", 19, 180974},
	{"EUROTRASH", 9, 180975},
	{"ASCOTT", 6, 180976},
	{"RUSTENBURG", 10, 180977},
	{"WOODHALL", 8, 180978},
	{"MOUSEDOWN", 9, 180979},
	{"BESTELLUNG", 10, 180980},
	{"POYDRAS", 7, 180981},
	{"LENSCRAFTERS", 12, 180982},
	{"WHOLEMEAL", 9, 180983},
	{"TAPEWARE", 8, 180984},
	{"CLIQUER", 7, 180985},
	{"FLEXON", 6, 180986},
	{"POMPEU", 6, 180987},
	{"CARDIOLOGIA", 11, 180988},
	{"MERCHANTABLE", 12, 180989},
	{"NAVAIR", 6, 180990},
	{"MARYPORT", 8, 180991},
	{"LUJO", 4, 180992},
	{"DEARIE", 6, 180993},
	{"REWORDED", 8, 180994},
	{"CARNOSINE", 9, 180995},
	{"VERUM", 5, 180996},
	{"FOOTSTONE", 9, 180997},
	{"ZYGI", 4, 180998},
	{"VYTE", 4, 180999},
	{"UMBM", 4, 181000},
	{"UHRA", 4, 181001},
	{"UAYO", 4, 181002},
	{"SYAG", 4, 181003},
	{"RYZA", 4, 181004},
	{"RYNW", 4, 181005},
	{"RROZ", 4, 181006},
	{"RDAO", 4, 181007},
	{"PMAB", 4, 181008},
	{"PIOF", 4, 181009},
	{"OBFE", 4, 181010},
	{"NCKN", 4, 181011},
	{"MRJU", 4, 181012},
	{"MIBR", 4, 181013},
	{"MBAE", 4, 181014},
	{"LSHD", 4, 181015},
	{"KHRE", 4, 181016},
	{"HJAV", 4, 181017},
	{"GOKL", 4, 181018},
	{"GISQ", 4, 181019},
	{"FTIK", 4, 181020},
	{"FRYD", 4, 181021},
	{"ESVU", 4, 181022},
	{"EPJU", 4, 181023},
	{"ENZL", 4, 181024},
	{"DTMO", 4, 181025},
	{"DRVI", 4, 181026},
	{"DILF", 4, 181027},
	{"DGIM", 4, 181028},
	{"DDRW", 4, 181029},
	{"BULF", 4, 181030},
	{"ATYD", 4, 181031},
	{"ACSD", 4, 181032},
	{"AABL", 4, 181033},
	{"JBD", 3, 181034},
	{"LEAFGREEN", 9, 181035},
	{"FUNCIONES", 9, 181036},
	{"WEATHERALOUD", 12, 181037},
	{"CKED", 4, 181038},
	{"DEADTIME", 8, 181039},
	{"INTENTIA", 8, 181040},
	{"GEOLOCATION", 11, 181041},
	{"FRIENDSEARCH", 12, 181042},
	{"IGHTS", 5, 181043},
	{"GASTROPODS", 10, 181044},
	{"BARSKY", 6, 181045},
	{"VOLLER", 6, 181046},
	{"SUNNINGDALE", 11, 181047},
	{"ABAQUS", 6, 181048},
	{"BUGMENOT", 8, 181049},
	{"COSTANTINO", 10, 181050},
	{"HILGER", 6, 181051},
	{"TTASETITEMOFF", 13, 181052},
	{"NAHUATL", 7, 181053},
	{"COAD", 4, 181054},
	{"ROSEGARDEN", 10, 181055},
	{"HOLLIDAYSBURG", 13, 181056},
	{"HOMEWORKERS", 11, 181057},
	{"SKERRITT", 8, 181058},
	{"SHORTIES", 8, 181059},
	{"KARHU", 5, 181060},
	{"BCTF", 4, 181061},
	{"NONLETHAL", 9, 181062},
	{"DALYAN", 6, 181063},
	{"YAHOOGROUP", 10, 181064},
	{"TARIFFA", 7, 181065},
	{"DIDDL", 5, 181066},
	{"PLATINAX", 8, 181067},
	{"COMEUPPANCE", 11, 181068},
	{"UMHS", 4, 181069},
	{"GCCOSANDVERS", 12, 181070},
	{"DESKOP", 6, 181071},
	{"WILKO", 5, 181072},
	{"SRTM", 4, 181073},
	{"SUNDAES", 7, 181074},
	{"LEQUEL", 6, 181075},
	{"ELINE", 5, 181076},
	{"ECHELLE", 7, 181077},
	{"IPMS", 4, 181078},
	{"TUALLY", 6, 181079},
	{"EMBEDDEDNESS", 12, 181080},
	{"AXXIS", 5, 181081},
	{"ENIGMAS", 7, 181082},
	{"RAMEKINS", 8, 181083},
	{"DONAVAN", 7, 181084},
	{"TERNI", 5, 181085},
	{"CLOP", 4, 181086},
	{"KINDE", 5, 181087},
	{"DOYEN", 5, 181088},
	{"BEZOEK", 6, 181089},
	{"OSTERIA", 7, 181090},
	{"EISENSTADT", 10, 181091},
	{"SIUTE", 5, 181092},
	{"RESCAN", 6, 181093},
	{"KRISTOFER", 9, 181094},
	{"HAYASHIZAKI", 11, 181095},
	{"WEYER", 5, 181096},
	{"EFFIN", 5, 181097},
	{"TORANO", 6, 181098},
	{"OPSEC", 5, 181099},
	{"WILSONART", 9, 181100},
	{"PARCIALMENTE", 12, 181101},
	{"FARGE", 5, 181102},
	{"HOCKESSIN", 9, 181103},
	{"SADIPSCING", 10, 181104},
	{"PORTDIR", 7, 181105},
	{"NRSC", 4, 181106},
	{"KIEVIT", 6, 181107},
	{"PEARMAN", 7, 181108},
	{"DHOSTKEYSFILE", 13, 181109},
	{"PHLOG", 5, 181110},
	{"ICPC", 4, 181111},
	{"FRENZAL", 7, 181112},
	{"LYRISS", 6, 181113},
	{"IRENAISSANCE", 12, 181114},
	{"HAZELDEN", 8, 181115},
	{"UNFAILINGLY", 11, 181116},
	{"HUMORED", 7, 181117},
	{"AMILY", 5, 181118},
	{"TILBAKE", 7, 181119},
	{"HOTELA", 6, 181120},
	{"ZCOL", 4, 181121},
	{"ZAMP", 4, 181122},
	{"VBAS", 4, 181123},
	{"VAKU", 4, 181124},
	{"UUSA", 4, 181125},
	{"UPJE", 4, 181126},
	{"UMYT", 4, 181127},
	{"UGMI", 4, 181128},
	{"UAWK", 4, 181129},
	{"RGSR", 4, 181130},
	{"PHOD", 4, 181131},
	{"NILD", 4, 181132},
	{"MUOZ", 4, 181133},
	{"LLWY", 4, 181134},
	{"LLND", 4, 181135},
	{"HMYK", 4, 181136},
	{"HMSR", 4, 181137},
	{"EIUC", 4, 181138},
	{"ECYM", 4, 181139},
	{"CYTU", 4, 181140},
	{"CKYK", 4, 181141},
	{"BUZA", 4, 181142},
	{"BUBE", 4, 181143},
	{"BBIR", 4, 181144},
	{"AERL", 4, 181145},
	{"EXPLOITERS", 10, 181146},
	{"NONUMY", 6, 181147},
	{"JOKINEN", 7, 181148},
	{"HEXOKINASE", 10, 181149},
	{"FUNCOM", 6, 181150},
	{"SCARLETTE", 9, 181151},
	{"SFWMD", 5, 181152},
	{"SABBATICALS", 11, 181153},
	{"MENDATIONS", 10, 181154},
	{"VOWELL", 6, 181155},
	{"SECRETES", 8, 181156},
	{"TRATED", 6, 181157},
	{"HONIARA", 7, 181158},
	{"SCAPPOOSE", 9, 181159},
	{"BEFALLS", 7, 181160},
	{"ENDLICH", 7, 181161},
	{"OPENWRT", 7, 181162},
	{"GANES", 5, 181163},
	{"CONSTRUCTIONIST", 15, 181164},
	{"ESCARGOT", 8, 181165},
	{"MULLENS", 7, 181166},
	{"TARPLEY", 7, 181167},
	{"NOWONSALE", 9, 181168},
	{"VALUEWEB", 8, 181169},
	{"DISBARRED", 9, 181170},
	{"HHMM", 4, 181171},
	{"ASKSAM", 6, 181172},
	{"XECUTIVE", 8, 181173},
	{"STELCO", 6, 181174},
	{"LIONMAN", 7, 181175},
	{"GLF", 3, 181176},
	{"MONTO", 5, 181177},
	{"GILE", 4, 181178},
	{"FGR", 3, 181179},
	{"EXEMPLIFYING", 12, 181180},
	{"HODEL", 5, 181181},
	{"TRASTUZUMAB", 11, 181182},
	{"MELDED", 6, 181183},
	{"PLCTURES", 8, 181184},
	{"OPOY", 4, 181185},
	{"GEUM", 4, 181186},
	{"VACU", 4, 181187},
	{"WIVE", 4, 181188},
	{"JIMK", 4, 181189},
	{"PRIMEROS", 8, 181190},
	{"SLUGNET", 7, 181191},
	{"POSSESSORY", 10, 181192},
	{"PLAMEN", 6, 181193},
	{"NOHIPER", 7, 181194},
	{"JPD", 3, 181195},
	{"PRAMOD", 6, 181196},
	{"MACAFEE", 7, 181197},
	{"CHERE", 5, 181198},
	{"ADEV", 4, 181199},
	{"PHILBERT", 8, 181200},
	{"HANTAI", 6, 181201},
	{"WOLKY", 5, 181202},
	{"RHUM", 4, 181203},
	{"RIOWORKS", 8, 181204},
	{"CLASEN", 6, 181205},
	{"BIRDWATCH", 9, 181206},
	{"FUSSED", 6, 181207},
	{"CLICIWCH", 8, 181208},
	{"FINNY", 5, 181209},
	{"FENLAND", 7, 181210},
	{"ANABAPTISTS", 11, 181211},
	{"HYPEROPIA", 9, 181212},
	{"YODEL", 5, 181213},
	{"IZQUIERDO", 9, 181214},
	{"PXZZ", 4, 181215},
	{"HANDSWORTH", 10, 181216},
	{"BROMPHENIRAMINE", 15, 181217},
	{"ARTCYCLOPEDIA", 13, 181218},
	{"LONGBOTTOM", 10, 181219},
	{"PINHOLES", 8, 181220},
	{"ENIAC", 5, 181221},
	{"XLIV", 4, 181222},
	{"LALALA", 6, 181223},
	{"FERROVIE", 8, 181224},
	{"DUBNER", 6, 181225},
	{"RINOA", 5, 181226},
	{"ORTHOSIS", 8, 181227},
	{"TERBUTALINE", 11, 181228},
	{"ZOSC", 4, 181229},
	{"YKOU", 4, 181230},
	{"YHYB", 4, 181231},
	{"XAMW", 4, 181232},
	{"VFIN", 4, 181233},
	{"UEXE", 4, 181234},
	{"TTMY", 4, 181235},
	{"TMSP", 4, 181236},
	{"SHUV", 4, 181237},
	{"PYAG", 4, 181238},
	{"OWIB", 4, 181239},
	{"MROR", 4, 181240},
	{"MDWE", 4, 181241},
	{"LRUT", 4, 181242},
	{"KYSB", 4, 181243},
	{"KIGU", 4, 181244},
	{"KAEM", 4, 181245},
	{"IMIB", 4, 181246},
	{"GRUO", 4, 181247},
	{"EPCV", 4, 181248},
	{"EGFE", 4, 181249},
	{"CUWA", 4, 181250},
	{"BNWA", 4, 181251},
	{"BETP", 4, 181252},
	{"ATWM", 4, 181253},
	{"AKYL", 4, 181254},
	{"IRDETO", 6, 181255},
	{"USSITE", 6, 181256},
	{"LIGETI", 6, 181257},
	{"JAZZERCISE", 10, 181258},
	{"POLACCO", 7, 181259},
	{"GODAVARI", 8, 181260},
	{"AEROSPATIALE", 12, 181261},
	{"DISEMBARKED", 11, 181262},
	{"COUNTDOWNS", 10, 181263},
	{"LEONARDTOWN", 11, 181264},
	{"CHICAGOIST", 10, 181265},
	{"TROVATO", 7, 181266},
	{"GLEANING", 8, 181267},
	{"ESTORES", 7, 181268},
	{"POTOS", 5, 181269},
	{"CACHEABLE", 9, 181270},
	{"BURGUNDIAN", 10, 181271},
	{"RESYNCHRONIZATION", 17, 181272},
	{"CENTICORE", 9, 181273},
	{"WITTNER", 7, 181274},
	{"VANDAAG", 7, 181275},
	{"NDEBELE", 7, 181276},
	{"UPDATABLE", 9, 181277},
	{"RAJAGOPAL", 9, 181278},
	{"ANNIES", 6, 181279},
	{"NEWSREAL", 8, 181280},
	{"MPOREI", 6, 181281},
	{"MASSRECIPES", 11, 181282},
	{"CAFF", 4, 181283},
	{"LOGICIAN", 8, 181284},
	{"TELLES", 6, 181285},
	{"PROUTY", 6, 181286},
	{"HALLSTROM", 9, 181287},
	{"KEDCOM", 6, 181288},
	{"FUTA", 4, 181289},
	{"KANSANS", 7, 181290},
	{"DINMONT", 7, 181291},
	{"TOEPLITZ", 8, 181292},
	{"TRANSNET", 8, 181293},
	{"HURRIYAT", 8, 181294},
	{"ULTRAMODERN", 11, 181295},
	{"EDRYCH", 6, 181296},
	{"PENTE", 5, 181297},
	{"HUBERTUS", 8, 181298},
	{"SZMIDT", 6, 181299},
	{"CHERY", 5, 181300},
	{"MEDIABOOK", 9, 181301},
	{"VERSAUTE", 8, 181302},
	{"VENGENCE", 8, 181303},
	{"MONTECITORIO", 12, 181304},
	{"BUONGIORNO", 10, 181305},
	{"THUMPED", 7, 181306},
	{"MULTISTEP", 9, 181307},
	{"SUPERBE", 7, 181308},
	{"NECCESSARILY", 12, 181309},
	{"LRV", 3, 181310},
	{"CONJECTURAL", 11, 181311},
	{"WEBDIRECTORY", 12, 181312},
	{"DOCOSAHEXAENOIC", 15, 181313},
	{"REMANUFACTURE", 13, 181314},
	{"MOTOROLLA", 9, 181315},
	{"FLAVOPROTEIN", 12, 181316},
	{"BOLDING", 7, 181317},
	{"RUMINATION", 10, 181318},
	{"STOLT", 5, 181319},
	{"CLARETT", 7, 181320},
	{"CASTANEA", 8, 181321},
	{"AUSCULTATION", 12, 181322},
	{"TOCOPHEROLS", 11, 181323},
	{"MOVIESONLINE", 12, 181324},
	{"BLACKMAILING", 12, 181325},
	{"WTZR", 4, 181326},
	{"WIGGUM", 6, 181327},
	{"XAKANAXA", 8, 181328},
	{"STATERS", 7, 181329},
	{"WHITTLESEY", 10, 181330},
	{"TUMUT", 5, 181331},
	{"ADELL", 5, 181332},
	{"VADO", 4, 181333},
	{"ECURITY", 7, 181334},
	{"ARCLIGHT", 8, 181335},
	{"BUOI", 4, 181336},
	{"SCRIPTER", 8, 181337},
	{"CYMBIDIUM", 9, 181338},
	{"UNDERSOLD", 9, 181339},
	{"YVAM", 4, 181340},
	{"YPIK", 4, 181341},
	{"WMYM", 4, 181342},
	{"UIME", 4, 181343},
	{"TOWU", 4, 181344},
	{"SROR", 4, 181345},
	{"RPEM", 4, 181346},
	{"RPAB", 4, 181347},
	{"RBLV", 4, 181348},
	{"RAJY", 4, 181349},
	{"POLP", 4, 181350},
	{"OIPU", 4, 181351},
	{"OGDP", 4, 181352},
	{"OFRT", 4, 181353},
	{"OBSJ", 4, 181354},
	{"OBKA", 4, 181355},
	{"OBJU", 4, 181356},
	{"MRPU", 4, 181357},
	{"HCAF", 4, 181358},
	{"GMUM", 4, 181359},
	{"GHJI", 4, 181360},
	{"FOGR", 4, 181361},
	{"FCYR", 4, 181362},
	{"EZCR", 4, 181363},
	{"EPPT", 4, 181364},
	{"DPGA", 4, 181365},
	{"DMIZ", 4, 181366},
	{"CJIH", 4, 181367},
	{"BDET", 4, 181368},
	{"AYJI", 4, 181369},
	{"AECU", 4, 181370},
	{"EXPRE", 5, 181371},
	{"MAPSITE", 7, 181372},
	{"TOOTHPASTES", 11, 181373},
	{"KUEHNE", 6, 181374},
	{"ESTRATEGY", 9, 181375},
	{"HYDROSPHERE", 11, 181376},
	{"AMBERG", 6, 181377},
	{"AVANTGUILD", 10, 181378},
	{"ORGANISMES", 10, 181379},
	{"LAZZARO", 7, 181380},
	{"DOCTER", 6, 181381},
	{"MASCULINITIES", 13, 181382},
	{"DDATBLYGU", 9, 181383},
	{"HOMETEAM", 8, 181384},
	{"LANNON", 6, 181385},
	{"LPV", 3, 181386},
	{"ONDANSETRON", 11, 181387},
	{"WASSENAAR", 9, 181388},
	{"ULMUS", 5, 181389},
	{"KUPFER", 6, 181390},
	{"RATIONALS", 9, 181391},
	{"BAUDER", 6, 181392},
	{"HAMAX", 5, 181393},
	{"WONDIR", 6, 181394},
	{"TETRACYCLINES", 13, 181395},
	{"NEUSS", 5, 181396},
	{"FASD", 4, 181397},
	{"ASTARTE", 7, 181398},
	{"GINGIVALIS", 10, 181399},
	{"MISOGYNIST", 10, 181400},
	{"JAMUL", 5, 181401},
	{"BOFFINS", 7, 181402},
	{"EVITAR", 6, 181403},
	{"HORNSTRASSE", 11, 181404},
	{"FPROFILE", 8, 181405},
	{"TERNAL", 6, 181406},
	{"ALTENBERG", 9, 181407},
	{"GIGAGOLF", 8, 181408},
	{"DINEEN", 6, 181409},
	{"SPIFF", 5, 181410},
	{"CIBO", 4, 181411},
	{"PIETA", 5, 181412},
	{"SAYEED", 6, 181413},
	{"OPENLINUX", 9, 181414},
	{"FAMILIARISATION", 15, 181415},
	{"DYSREGULATION", 13, 181416},
	{"MILITARES", 9, 181417},
	{"AUSLANDER", 9, 181418},
	{"FALR", 4, 181419},
	{"EMEKA", 5, 181420},
	{"BUZZES", 6, 181421},
	{"FANPRO", 6, 181422},
	{"TENDANCE", 8, 181423},
	{"RADMIN", 6, 181424},
	{"HOVEN", 5, 181425},
	{"BWIA", 4, 181426},
	{"BLACKSHEEP", 10, 181427},
	{"SOPAC", 5, 181428},
	{"MAGGY", 5, 181429},
	{"IDLERS", 6, 181430},
	{"CHALKBOARDS", 11, 181431},
	{"PHAGOCYTES", 10, 181432},
	{"PASQUA", 6, 181433},
	{"NYSDOT", 6, 181434},
	{"MAHADEVAN", 9, 181435},
	{"NORWEGIANITY", 12, 181436},
	{"EIGENTLICH", 10, 181437},
	{"LAVEAUX", 7, 181438},
	{"NOARLUNGA", 9, 181439},
	{"UCMJ", 4, 181440},
	{"DELMAS", 6, 181441},
	{"NVARCHAR", 8, 181442},
	{"ALBRITTON", 9, 181443},
	{"XLOG", 4, 181444},
	{"QUINTUPLE", 9, 181445},
	{"MILLIMAN", 8, 181446},
	{"WALLKILL", 8, 181447},
	{"SEIMENS", 7, 181448},
	{"MEYDA", 5, 181449},
	{"LIBRAR", 6, 181450},
	{"SEMMES", 6, 181451},
	{"QUADROPHENIA", 12, 181452},
	{"CLICKERS", 8, 181453},
	{"REPURPOSING", 11, 181454},
	{"PSYCHOBIOLOGY", 13, 181455},
	{"ZAYA", 4, 181456},
	{"YCZE", 4, 181457},
	{"WWGR", 4, 181458},
	{"VTOF", 4, 181459},
	{"VLAA", 4, 181460},
	{"UDTA", 4, 181461},
	{"UAQU", 4, 181462},
	{"SULR", 4, 181463},
	{"SOKU", 4, 181464},
	{"SMBR", 4, 181465},
	{"SLEZ", 4, 181466},
	{"SGTC", 4, 181467},
	{"RHUE", 4, 181468},
	{"RCSH", 4, 181469},
	{"NDLC", 4, 181470},
	{"LGAO", 4, 181471},
	{"KVIO", 4, 181472},
	{"JABW", 4, 181473},
	{"HWEF", 4, 181474},
	{"HUMD", 4, 181475},
	{"GMSP", 4, 181476},
	{"FMEY", 4, 181477},
	{"FLSM", 4, 181478},
	{"FLSB", 4, 181479},
	{"DMHZ", 4, 181480},
	{"DIRW", 4, 181481},
	{"CEYP", 4, 181482},
	{"BBAI", 4, 181483},
	{"GUIDI", 5, 181484},
	{"MIWA", 4, 181485},
	{"BAGI", 4, 181486},
	{"HOUNDING", 8, 181487},
	{"DAUNTE", 6, 181488},
	{"WINFIXER", 8, 181489},
	{"DATASTORM", 9, 181490},
	{"VANEK", 5, 181491},
	{"REGURGITATED", 12, 181492},
	{"DONEPEZIL", 9, 181493},
	{"HIPATH", 6, 181494},
	{"SAVOLA", 6, 181495},
	{"BIPASHA", 7, 181496},
	{"SHRUBBY", 7, 181497},
	{"COMPARTMENTALIZED", 17, 181498},
	{"VITEBSK", 7, 181499},
	{"RUSSISCH", 8, 181500},
	{"HOBBICO", 7, 181501},
	{"AFTERDAWN", 9, 181502},
	{"SPHR", 4, 181503},
	{"HECLA", 5, 181504},
	{"YUMMI", 5, 181505},
	{"NEWTONVILLE", 11, 181506},
	{"ESPERIENZA", 10, 181507},
	{"DREES", 5, 181508},
	{"RACEMIC", 7, 181509},
	{"CONTORTIONS", 11, 181510},
	{"REPETITIVELY", 12, 181511},
	{"TAUNUS", 6, 181512},
	{"CUSTOME", 7, 181513},
	{"DENYLE", 6, 181514},
	{"DAVYDENKO", 9, 181515},
	{"ADMINISTRATEUR", 14, 181516},
	{"CROSSSEARCH", 11, 181517},
	{"COMPULSORILY", 12, 181518},
	{"TURVEY", 6, 181519},
	{"SLOWPITCH", 9, 181520},
	{"PACKHORSE", 9, 181521},
	{"APPORTIONING", 12, 181522},
	{"RECOMENDATION", 13, 181523},
	{"ANDINA", 6, 181524},
	{"UTILIZA", 7, 181525},
	{"CAIRNGORMS", 10, 181526},
	{"BURRIED", 7, 181527},
	{"JDL", 3, 181528},
	{"ARSONIST", 8, 181529},
	{"GETRAGENE", 9, 181530},
	{"COFI", 4, 181531},
	{"KOBES", 5, 181532},
	{"ULRIC", 5, 181533},
	{"DROSERA", 7, 181534},
	{"HYSCIENCE", 9, 181535},
	{"BOESDAL", 7, 181536},
	{"PROVERS", 7, 181537},
	{"EFFUSIVE", 8, 181538},
	{"KARAMAZOV", 9, 181539},
	{"GODDEN", 6, 181540},
	{"HEILIG", 6, 181541},
	{"RAMBLA", 6, 181542},
	{"BAUMBACH", 8, 181543},
	{"LENNAR", 6, 181544},
	{"FLIMS", 5, 181545},
	{"FREETECH", 8, 181546},
	{"CENTAUREA", 9, 181547},
	{"SAPSUCKER", 9, 181548},
	{"CLOISTERED", 10, 181549},
	{"VSOP", 4, 181550},
	{"BIOLABS", 7, 181551},
	{"REDOUBLED", 9, 181552},
	{"IBRA", 4, 181553},
	{"WEISSE", 6, 181554},
	{"CHORISTERS", 10, 181555},
	{"YEAREND", 7, 181556},
	{"CLIMAXED", 8, 181557},
	{"BOSOMS", 6, 181558},
	{"VICTORIANA", 10, 181559},
	{"MURDO", 5, 181560},
	{"SANDELL", 7, 181561},
	{"LEMASS", 6, 181562},
	{"PAWPRINT", 8, 181563},
	{"OTOLITH", 7, 181564},
	{"OANDA", 5, 181565},
	{"DUTIABLE", 8, 181566},
	{"DORMA", 5, 181567},
	{"CUBICAL", 7, 181568},
	{"OPAQUES", 7, 181569},
	{"KOVU", 4, 181570},
	{"FLAPPED", 7, 181571},
	{"LAMINGTON", 9, 181572},
	{"MABLETON", 8, 181573},
	{"VERLAINE", 8, 181574},
	{"CPGNUKE", 7, 181575},
	{"CANDIAN", 7, 181576},
	{"KIEM", 4, 181577},
	{"VISUALIZADOR", 12, 181578},
	{"CONTEXTE", 8, 181579},
	{"MANKIN", 6, 181580},
	{"ADENOVIRUSES", 12, 181581},
	{"KONDOME", 7, 181582},
	{"ALRLINES", 8, 181583},
	{"GALLINA", 7, 181584},
	{"ERRORMESSAGE", 12, 181585},
	{"SUPERNUMERARY", 13, 181586},
	{"BLOGOMETER", 10, 181587},
	{"YOUZ", 4, 181588},
	{"WIDN", 4, 181589},
	{"VMUS", 4, 181590},
	{"UIFO", 4, 181591},
	{"TMBA", 4, 181592},
	{"THLL", 4, 181593},
	{"RYIG", 4, 181594},
	{"RVEV", 4, 181595},
	{"RIAY", 4, 181596},
	{"PYPO", 4, 181597},
	{"PHIF", 4, 181598},
	{"NDIQ", 4, 181599},
	{"NAUF", 4, 181600},
	{"MRAU", 4, 181601},
	{"LUWI", 4, 181602},
	{"LEUV", 4, 181603},
	{"IGDU", 4, 181604},
	{"HTYY", 4, 181605},
	{"FYSH", 4, 181606},
	{"DTCH", 4, 181607},
	{"AQUEDUCTS", 9, 181608},
	{"JOFFREY", 7, 181609},
	{"PHOTOSENSITIVITY", 16, 181610},
	{"IMPRESSIONEN", 12, 181611},
	{"THEMS", 5, 181612},
	{"MINERA", 6, 181613},
	{"REPROBATE", 9, 181614},
	{"DAPI", 4, 181615},
	{"PEYRONIE", 8, 181616},
	{"ONLIME", 6, 181617},
	{"EDMAN", 5, 181618},
	{"IDABEL", 6, 181619},
	{"DESPUES", 7, 181620},
	{"WRG", 3, 181621},
	{"KAZUKI", 6, 181622},
	{"GACY", 4, 181623},
	{"NYHAN", 5, 181624},
	{"CUBBIES", 7, 181625},
	{"NVCC", 4, 181626},
	{"INDISCRETIONS", 13, 181627},
	{"RIPER", 5, 181628},
	{"PHOTOLIBRARY", 12, 181629},
	{"HYPERMARKETS", 12, 181630},
	{"MCLEMORE", 8, 181631},
	{"GHANI", 5, 181632},
	{"LODEN", 5, 181633},
	{"CCPS", 4, 181634},
	{"ATLANTICO", 9, 181635},
	{"BOURN", 5, 181636},
	{"BIAXIAL", 7, 181637},
	{"STENHOLM", 8, 181638},
	{"SAMUELSSON", 10, 181639},
	{"LYGICS", 6, 181640},
	{"DRCT", 4, 181641},
	{"PERCIEVE", 8, 181642},
	{"MOTORBOOKS", 10, 181643},
	{"BUGID", 5, 181644},
	{"RUNDFUNK", 8, 181645},
	{"NEUROENDOCRINOLOGY", 18, 181646},
	{"INDUSTRIALE", 11, 181647},
	{"DUNA", 4, 181648},
	{"EPALS", 5, 181649},
	{"CHEMOMETRICS", 12, 181650},
	{"ORCI", 4, 181651},
	{"SOBIG", 5, 181652},
	{"KHALILI", 7, 181653},
	{"HARDRIVE", 8, 181654},
	{"RAGAZZE", 7, 181655},
	{"LONELIEST", 9, 181656},
	{"EXTENTECH", 9, 181657},
	{"CDTI", 4, 181658},
	{"MURRUMBIDGEE", 12, 181659},
	{"ROCKWOOL", 8, 181660},
	{"SJOSTROM", 8, 181661},
	{"RESPUESTAS", 10, 181662},
	{"INTERNETNEWS", 12, 181663},
	{"SCULPIN", 7, 181664},
	{"HOKUSAI", 7, 181665},
	{"ZOOMABLE", 8, 181666},
	{"FORSOOK", 7, 181667},
	{"SHINAWATRA", 10, 181668},
	{"HITTITES", 8, 181669},
	{"BALIK", 5, 181670},
	{"DUPLICITOUS", 11, 181671},
	{"LORRE", 5, 181672},
	{"LJRICS", 6, 181673},
	{"PROCOLLAGEN", 11, 181674},
	{"EXPLETIVES", 10, 181675},
	{"CRFH", 4, 181676},
	{"IRTC", 4, 181677},
	{"FLINTLOCK", 9, 181678},
	{"CHAINSETS", 9, 181679},
	{"ARROWCOMPANY", 12, 181680},
	{"ACHENBACH", 9, 181681},
	{"MYCNN", 5, 181682},
	{"WICKENS", 7, 181683},
	{"INFOSPORTS", 10, 181684},
	{"TATLER", 6, 181685},
	{"DIGGINS", 7, 181686},
	{"TRANFER", 7, 181687},
	{"MARRAIGE", 8, 181688},
	{"OSTELLO", 7, 181689},
	{"CORREC", 6, 181690},
	{"FORX", 4, 181691},
	{"ESSENT", 6, 181692},
	{"ALLOTED", 7, 181693},
	{"ZMOS", 4, 181694},
	{"YPUZ", 4, 181695},
	{"XOUR", 4, 181696},
	{"XFUL", 4, 181697},
	{"XASV", 4, 181698},
	{"WOKO", 4, 181699},
	{"VYFL", 4, 181700},
	{"VRUS", 4, 181701},
	{"VITW", 4, 181702},
	{"UBIG", 4, 181703},
	{"TLUB", 4, 181704},
	{"TJPM", 4, 181705},
	{"STVL", 4, 181706},
	{"SQKM", 4, 181707},
	{"SMUF", 4, 181708},
	{"RVIZ", 4, 181709},
	{"RRDA", 4, 181710},
	{"OXYB", 4, 181711},
	{"MCYC", 4, 181712},
	{"LNWI", 4, 181713},
	{"LMGA", 4, 181714},
	{"LIZW", 4, 181715},
	{"LAKT", 4, 181716},
	{"KHZA", 4, 181717},
	{"JUGU", 4, 181718},
	{"IKSW", 4, 181719},
	{"HGYM", 4, 181720},
	{"GGCA", 4, 181721},
	{"FDWA", 4, 181722},
	{"EXDU", 4, 181723},
	{"EGIP", 4, 181724},
	{"EDHM", 4, 181725},
	{"DMOG", 4, 181726},
	{"DJHA", 4, 181727},
	{"CYCI", 4, 181728},
	{"CMOF", 4, 181729},
	{"BNRE", 4, 181730},
	{"BIZO", 4, 181731},
	{"BCPO", 4, 181732},
	{"BAMU", 4, 181733},
	{"VACTION", 7, 181734},
	{"CHLOROPHENYL", 12, 181735},
	{"UALR", 4, 181736},
	{"CISSY", 5, 181737},
	{"PREEMPTS", 8, 181738},
	{"SKYHAWKS", 8, 181739},
	{"FINNO", 5, 181740},
	{"ADVANTEST", 9, 181741},
	{"LINSE", 5, 181742},
	{"NIMANTICS", 9, 181743},
	{"HARTSDALE", 9, 181744},
	{"TWINROOM", 8, 181745},
	{"SHORTSTORIES", 12, 181746},
	{"NAEEM", 5, 181747},
	{"EQIP", 4, 181748},
	{"ELEMENTNAME", 11, 181749},
	{"DATACABLE", 9, 181750},
	{"PRELATES", 8, 181751},
	{"MADRON", 6, 181752},
	{"MOONE", 5, 181753},
	{"CATACOMB", 8, 181754},
	{"AVIREX", 6, 181755},
	{"NYALA", 5, 181756},
	{"JUMPSUITS", 9, 181757},
	{"ATONAL", 6, 181758},
	{"MULBERRYTECH", 12, 181759},
	{"LYRICQ", 6, 181760},
	{"LOSTWITHIEL", 11, 181761},
	{"DECANOATE", 9, 181762},
	{"SKYWORKS", 8, 181763},
	{"DURELL", 6, 181764},
	{"PLOIDY", 6, 181765},
	{"GOSSEN", 6, 181766},
	{"REGALI", 6, 181767},
	{"KEYFRAMES", 9, 181768},
	{"HOSPEDAGEM", 10, 181769},
	{"BLUECHART", 9, 181770},
	{"LEKMAN", 6, 181771},
	{"HKEY", 4, 181772},
	{"AUDA", 4, 181773},
	{"MICROGEOPHAGUS", 14, 181774},
	{"THERMS", 6, 181775},
	{"BLUEJAYS", 8, 181776},
	{"FRICATIVE", 9, 181777},
	{"GETX", 4, 181778},
	{"TELEPLAY", 8, 181779},
	{"GTALK", 5, 181780},
	{"CAPITATED", 9, 181781},
	{"UNSEREM", 7, 181782},
	{"ISOTHERMS", 9, 181783},
	{"ARFER", 5, 181784},
	{"HEXAFLUORIDE", 12, 181785},
	{"ENSIGNS", 7, 181786},
	{"ANTERIORLY", 10, 181787},
	{"ALMON", 5, 181788},
	{"WEKALIST", 8, 181789},
	{"PSEUDOMALLEI", 12, 181790},
	{"GNMA", 4, 181791},
	{"BERSON", 6, 181792},
	{"CELLULASE", 9, 181793},
	{"UNPREDICTABLY", 13, 181794},
	{"UNICENT", 7, 181795},
	{"LANTUS", 6, 181796},
	{"POTTAWATTAMIE", 13, 181797},
	{"RAHMEN", 6, 181798},
	{"HELLOGOODBYE", 12, 181799},
	{"HYDROLOGIST", 11, 181800},
	{"PARADORES", 9, 181801},
	{"LOWEL", 5, 181802},
	{"VASSALLO", 8, 181803},
	{"WORCHESTER", 10, 181804},
	{"UMTATA", 6, 181805},
	{"MURRAYFIELD", 11, 181806},
	{"CCMIXTER", 8, 181807},
	{"MARIAS", 6, 181808},
	{"APOP", 4, 181809},
	{"NATUREWORKS", 11, 181810},
	{"SANDAG", 6, 181811},
	{"GPW", 3, 181812},
	{"DIACHRONIC", 10, 181813},
	{"SAUVE", 5, 181814},
	{"STORYTIMES", 10, 181815},
	{"CATTAILS", 8, 181816},
	{"CATOLICA", 8, 181817},
	{"NAZARIO", 7, 181818},
	{"KOLHAPUR", 8, 181819},
	{"YRHI", 4, 181820},
	{"YIFR", 4, 181821},
	{"WMOL", 4, 181822},
	{"VCHI", 4, 181823},
	{"UYTA", 4, 181824},
	{"UPTY", 4, 181825},
	{"SYAK", 4, 181826},
	{"SMYK", 4, 181827},
	{"RUPN", 4, 181828},
	{"RKRS", 4, 181829},
	{"RHPA", 4, 181830},
	{"PPOA", 4, 181831},
	{"PDAI", 4, 181832},
	{"MRVI", 4, 181833},
	{"MPVA", 4, 181834},
	{"MNBC", 4, 181835},
	{"LTEW", 4, 181836},
	{"KIPU", 4, 181837},
	{"JENR", 4, 181838},
	{"IODK", 4, 181839},
	{"GTUM", 4, 181840},
	{"FYME", 4, 181841},
	{"FROI", 4, 181842},
	{"FNOF", 4, 181843},
	{"FEDN", 4, 181844},
	{"DEFC", 4, 181845},
	{"CVOC", 4, 181846},
	{"CEIK", 4, 181847},
	{"BYMM", 4, 181848},
	{"BEMC", 4, 181849},
	{"IFBB", 4, 181850},
	{"CEFOTAXIME", 10, 181851},
	{"PINKSTON", 8, 181852},
	{"KAUFFMANN", 9, 181853},
	{"COMSEC", 6, 181854},
	{"HOSTGATOR", 9, 181855},
	{"HANDTIED", 8, 181856},
	{"REPEALER", 8, 181857},
	{"CLUBLAND", 8, 181858},
	{"AVELLINO", 8, 181859},
	{"CPANTS", 6, 181860},
	{"SPENDTHRIFT", 11, 181861},
	{"DORNER", 6, 181862},
	{"MOWITZ", 6, 181863},
	{"IMIDAZOLES", 10, 181864},
	{"SCOGGINS", 8, 181865},
	{"MYFILE", 6, 181866},
	{"PONSA", 5, 181867},
	{"LEVITAN", 7, 181868},
	{"ANTIPODES", 9, 181869},
	{"MEADWESTVACO", 12, 181870},
	{"HEIDENREICH", 11, 181871},
	{"NEUVILLE", 8, 181872},
	{"JSERV", 5, 181873},
	{"SETLOCATION", 11, 181874},
	{"CHERS", 5, 181875},
	{"ABCDEF", 6, 181876},
	{"PASV", 4, 181877},
	{"DARL", 4, 181878},
	{"CLLPART", 7, 181879},
	{"FRAMESDIRECT", 12, 181880},
	{"ZAGS", 4, 181881},
	{"PARTIJEN", 8, 181882},
	{"DAGAN", 5, 181883},
	{"ALIZA", 5, 181884},
	{"MYRICS", 6, 181885},
	{"PLESE", 5, 181886},
	{"AIRIINES", 8, 181887},
	{"XBRITE", 6, 181888},
	{"MIDEM", 5, 181889},
	{"FORTI", 5, 181890},
	{"DAIYOO", 6, 181891},
	{"ATTAP", 5, 181892},
	{"ISHED", 5, 181893},
	{"HADAC", 5, 181894},
	{"KIESLING", 8, 181895},
	{"AMAZOBOOK", 9, 181896},
	{"CELLARING", 9, 181897},
	{"NEIGHBORHOODSCOUT", 17, 181898},
	{"ELLROY", 6, 181899},
	{"RELIGIONISTS", 12, 181900},
	{"LULC", 4, 181901},
	{"HOTPANTS", 8, 181902},
	{"BAMFIELD", 8, 181903},
	{"TUOTE", 5, 181904},
	{"DATELESS", 8, 181905},
	{"WELLMARK", 8, 181906},
	{"EDUCATIVOS", 10, 181907},
	{"SILKROAD", 8, 181908},
	{"ARMARI", 6, 181909},
	{"LIMPET", 6, 181910},
	{"EUROMAN", 7, 181911},
	{"KELI", 4, 181912},
	{"CULTURELLE", 10, 181913},
	{"BAHL", 4, 181914},
	{"GREETLNG", 8, 181915},
	{"GALBREATH", 9, 181916},
	{"NUNNALLY", 8, 181917},
	{"DELEWARE", 8, 181918},
	{"DYSTOCIA", 8, 181919},
	{"ELLICE", 6, 181920},
	{"COSTILLA", 8, 181921},
	{"PRESSMANIA", 10, 181922},
	{"ODJFS", 5, 181923},
	{"ASCC", 4, 181924},
	{"PARTER", 6, 181925},
	{"HILDESHEIM", 10, 181926},
	{"CONTRIBUTERS", 12, 181927},
	{"VIRTUALIZED", 11, 181928},
	{"AREACODE", 8, 181929},
	{"CIIPART", 7, 181930},
	{"XONIX", 5, 181931},
	{"SCLENCE", 7, 181932},
	{"NORMALIZES", 10, 181933},
	{"FORNECEDORES", 12, 181934},
	{"BEREUTER", 8, 181935},
	{"KORESH", 6, 181936},
	{"MCCREEVY", 8, 181937},
	{"GROSSEST", 8, 181938},
	{"ALIQUIP", 7, 181939},
	{"LYWICS", 6, 181940},
	{"FANCONI", 7, 181941},
	{"ZIPF", 4, 181942},
	{"VOLCAN", 6, 181943},
	{"DOWNIOAD", 8, 181944},
	{"ANTENAS", 7, 181945},
	{"SHANTIES", 8, 181946},
	{"IPGRI", 5, 181947},
	{"HANDWORK", 8, 181948},
	{"TOYOTAS", 7, 181949},
	{"MONTESINOS", 10, 181950},
	{"ZROC", 4, 181951},
	{"ZMER", 4, 181952},
	{"ZLIT", 4, 181953},
	{"YKEW", 4, 181954},
	{"WFUE", 4, 181955},
	{"UPOB", 4, 181956},
	{"UINU", 4, 181957},
	{"UDAO", 4, 181958},
	{"TTFU", 4, 181959},
	{"SDBI", 4, 181960},
	{"RLME", 4, 181961},
	{"QIPE", 4, 181962},
	{"PHUL", 4, 181963},
	{"ODSQ", 4, 181964},
	{"NFOP", 4, 181965},
	{"NEXM", 4, 181966},
	{"MNAD", 4, 181967},
	{"LFOA", 4, 181968},
	{"KIPC", 4, 181969},
	{"IZDE", 4, 181970},
	{"IWIC", 4, 181971},
	{"HEVD", 4, 181972},
	{"GYEC", 4, 181973},
	{"FJUI", 4, 181974},
	{"ESKP", 4, 181975},
	{"ERFM", 4, 181976},
	{"ELEQ", 4, 181977},
	{"DTAJ", 4, 181978},
	{"DRHP", 4, 181979},
	{"CYJA", 4, 181980},
	{"AZLA", 4, 181981},
	{"GROUN", 5, 181982},
	{"HTMLDOC", 7, 181983},
	{"KEYGENERATOR", 12, 181984},
	{"RADIOMETRICALLY", 15, 181985},
	{"FIUME", 5, 181986},
	{"DOWNIOADS", 9, 181987},
	{"ENSMM", 5, 181988},
	{"CANTODICT", 9, 181989},
	{"RODOPI", 6, 181990},
	{"VALUSOFT", 8, 181991},
	{"ARROWFILINGS", 12, 181992},
	{"WOJCIK", 6, 181993},
	{"MONOMIALS", 9, 181994},
	{"MSRC", 4, 181995},
	{"POACH", 5, 181996},
	{"ARRSEPEDIA", 10, 181997},
	{"PNHANG", 6, 181998},
	{"PLOUGHS", 7, 181999},
	{"TORONADO", 8, 182000},
	{"IFILL", 5, 182001},
	{"ABRE", 4, 182002},
	{"VELARO", 6, 182003},
	{"SDATA", 5, 182004},
	{"DATABSE", 7, 182005},
	{"PROSCENIUM", 10, 182006},
	{"EMOTIONLESS", 11, 182007},
	{"SUPERPAVE", 9, 182008},
	{"MSOFT", 5, 182009},
	{"LASHINGS", 8, 182010},
	{"CEPHALOSPORIN", 13, 182011},
	{"NOEMI", 5, 182012},
	{"TELEXON", 7, 182013},
	{"RESTATES", 8, 182014},
	{"CONFIGFILE", 10, 182015},
	{"SCRIPTY", 7, 182016},
	{"STORLES", 7, 182017},
	{"MIZU", 4, 182018},
	{"MODRONE", 7, 182019},
	{"BATEN", 5, 182020},
	{"DEVASP", 6, 182021},
	{"GODWARD", 7, 182022},
	{"PHARMACARE", 10, 182023},
	{"INMAC", 5, 182024},
	{"WASHAKIE", 8, 182025},
	{"ASAKUSA", 7, 182026},
	{"ARUTZ", 5, 182027},
	{"PORTEOUS", 8, 182028},
	{"MONCRIEF", 8, 182029},
	{"ADVERTEREN", 10, 182030},
	{"PAPERCLIPS", 10, 182031},
	{"EDGECOMB", 8, 182032},
	{"JOXER", 5, 182033},
	{"TABEL", 5, 182034},
	{"TELESIS", 7, 182035},
	{"CHROOTED", 8, 182036},
	{"SUBCRITICAL", 11, 182037},
	{"KINKOS", 6, 182038},
	{"DIRECCION", 9, 182039},
	{"PROVENA", 7, 182040},
	{"WILLD", 5, 182041},
	{"LOUE", 4, 182042},
	{"CANTABILE", 9, 182043},
	{"ADDRES", 6, 182044},
	{"PERSECUTORS", 11, 182045},
	{"LOCHNER", 7, 182046},
	{"AVERRED", 7, 182047},
	{"KRISTOFFER", 10, 182048},
	{"EILDON", 6, 182049},
	{"GRUE", 4, 182050},
	{"THANDIE", 7, 182051},
	{"CWPC", 4, 182052},
	{"FFVII", 5, 182053},
	{"EARTHA", 6, 182054},
	{"SAAMI", 5, 182055},
	{"THYROGLOBULIN", 13, 182056},
	{"SCANNELL", 8, 182057},
	{"CBRN", 4, 182058},
	{"NABJ", 4, 182059},
	{"LANOIS", 6, 182060},
	{"MONETT", 6, 182061},
	{"ZSPR", 4, 182062},
	{"ZARM", 4, 182063},
	{"USDS", 4, 182064},
	{"UCYI", 4, 182065},
	{"TTYY", 4, 182066},
	{"SZYN", 4, 182067},
	{"SFYH", 4, 182068},
	{"RYUJ", 4, 182069},
	{"ROZC", 4, 182070},
	{"PPIM", 4, 182071},
	{"OVPM", 4, 182072},
	{"LLOX", 4, 182073},
	{"LELF", 4, 182074},
	{"KFLY", 4, 182075},
	{"JHAD", 4, 182076},
	{"JABT", 4, 182077},
	{"ILGH", 4, 182078},
	{"GVED", 4, 182079},
	{"GSVO", 4, 182080},
	{"EMYY", 4, 182081},
	{"DPMP", 4, 182082},
	{"CKKY", 4, 182083},
	{"GIFTBASKETS", 11, 182084},
	{"BOSWELLIA", 9, 182085},
	{"BEAUTYREST", 10, 182086},
	{"POLYTECH", 8, 182087},
	{"KETOGLUTARATE", 13, 182088},
	{"ENABLEVAL", 9, 182089},
	{"TITOLI", 6, 182090},
	{"COMPOSTER", 9, 182091},
	{"MICELI", 6, 182092},
	{"GETTIME", 7, 182093},
	{"CHAVO", 5, 182094},
	{"CLEMMER", 7, 182095},
	{"MOCKSVILLE", 10, 182096},
	{"BANKOFAMERICA", 13, 182097},
	{"WINPROXY", 8, 182098},
	{"KRUX", 4, 182099},
	{"WHITBURN", 8, 182100},
	{"TARINA", 6, 182101},
	{"MOROVIA", 7, 182102},
	{"MERT", 4, 182103},
	{"LAMAI", 5, 182104},
	{"FRANCAISES", 10, 182105},
	{"REGGE", 5, 182106},
	{"HOWSER", 6, 182107},
	{"TRUCS", 5, 182108},
	{"HOCKER", 6, 182109},
	{"NORLAND", 7, 182110},
	{"BOSC", 4, 182111},
	{"TURBOCAD", 8, 182112},
	{"THAMESLINK", 10, 182113},
	{"GASWORKS", 8, 182114},
	{"AGROCHEMICAL", 12, 182115},
	{"TARKOVSKY", 9, 182116},
	{"SELFLESSLY", 10, 182117},
	{"PIROXICAM", 9, 182118},
	{"WILLIFORD", 9, 182119},
	{"SUESSES", 7, 182120},
	{"PAND", 4, 182121},
	{"DATRIX", 6, 182122},
	{"ACTUALIZE", 9, 182123},
	{"SIKU", 4, 182124},
	{"VALUELESS", 9, 182125},
	{"SNIFFLES", 8, 182126},
	{"FOURNISSEURS", 12, 182127},
	{"JAMC", 4, 182128},
	{"IMPERCEPTIBLY", 13, 182129},
	{"REPLI", 5, 182130},
	{"PERCOLATE", 9, 182131},
	{"ENCUENTRE", 9, 182132},
	{"LIBMNG", 6, 182133},
	{"BOVINA", 6, 182134},
	{"BURCHFIELD", 10, 182135},
	{"BERKEL", 6, 182136},
	{"CEIVE", 5, 182137},
	{"TWIXT", 5, 182138},
	{"REVETMENT", 9, 182139},
	{"PARKPLATZEROTIK", 15, 182140},
	{"WIELDER", 7, 182141},
	{"STILLING", 8, 182142},
	{"PENLEY", 6, 182143},
	{"WEISGERBER", 10, 182144},
	{"YOUMANS", 7, 182145},
	{"VALLY", 5, 182146},
	{"LINUXPPC", 8, 182147},
	{"SUBJETIVA", 9, 182148},
	{"IRSHAD", 6, 182149},
	{"TAKEOFFS", 8, 182150},
	{"JAREN", 5, 182151},
	{"CARTUCCE", 8, 182152},
	{"TRENDIEST", 9, 182153},
	{"FTELL", 5, 182154},
	{"HERSONISSOS", 11, 182155},
	{"NXIST", 5, 182156},
	{"COMMERCIALES", 12, 182157},
	{"UDEN", 4, 182158},
	{"KAAL", 4, 182159},
	{"MICROLENSING", 12, 182160},
	{"FALFURRIAS", 10, 182161},
	{"SPORTHILL", 9, 182162},
	{"ORDENAR", 7, 182163},
	{"BANDAS", 6, 182164},
	{"SCIRYL", 6, 182165},
	{"LIBATK", 6, 182166},
	{"YZAM", 4, 182167},
	{"YAIL", 4, 182168},
	{"WIIP", 4, 182169},
	{"VOMO", 4, 182170},
	{"UGOE", 4, 182171},
	{"THRC", 4, 182172},
	{"MYYA", 4, 182173},
	{"MIFN", 4, 182174},
	{"MBPL", 4, 182175},
	{"JRMA", 4, 182176},
	{"JMAL", 4, 182177},
	{"GMSS", 4, 182178},
	{"FYPA", 4, 182179},
	{"FIGL", 4, 182180},
	{"EPCW", 4, 182181},
	{"DMRI", 4, 182182},
	{"CMTH", 4, 182183},
	{"SPORTSCASTER", 12, 182184},
	{"MALAHAT", 7, 182185},
	{"PHENTOLAMINE", 12, 182186},
	{"ADOBO", 5, 182187},
	{"MANDE", 5, 182188},
	{"CREVASSE", 8, 182189},
	{"ERLY", 4, 182190},
	{"DRUITT", 6, 182191},
	{"CARDA", 5, 182192},
	{"HASTENS", 7, 182193},
	{"MOVECENTER", 10, 182194},
	{"PANAVISION", 10, 182195},
	{"CHILMARK", 8, 182196},
	{"METROPOINT", 10, 182197},
	{"BUNKERWORLD", 11, 182198},
	{"PHOTOCELL", 9, 182199},
	{"BIOELEMENTS", 11, 182200},
	{"PAGEPRINTER", 11, 182201},
	{"CHATING", 7, 182202},
	{"REAMERS", 7, 182203},
	{"BHAGWAN", 7, 182204},
	{"PARLAMENTO", 10, 182205},
	{"MANAGINGWEBS", 12, 182206},
	{"HUIZEN", 6, 182207},
	{"APPENDIXFILESYSTEM", 18, 182208},
	{"SHELFWEAR", 9, 182209},
	{"DAVANTAGE", 9, 182210},
	{"PREEN", 5, 182211},
	{"YOSHIOKA", 8, 182212},
	{"BRILLIANCY", 10, 182213},
	{"TEXASUSA", 8, 182214},
	{"VOLUNTARISM", 11, 182215},
	{"SIMIC", 5, 182216},
	{"BALKINIZATION", 13, 182217},
	{"TASCA", 5, 182218},
	{"MIKAMI", 6, 182219},
	{"VHOST", 5, 182220},
	{"CONVERTION", 10, 182221},
	{"MONOCLINIC", 10, 182222},
	{"GUSHES", 6, 182223},
	{"MARECHAL", 8, 182224},
	{"MEMBERCENTER", 12, 182225},
	{"GRIZ", 4, 182226},
	{"EMTEK", 5, 182227},
	{"NECCESARILY", 11, 182228},
	{"IMCA", 4, 182229},
	{"SCHWABE", 7, 182230},
	{"PIANTE", 6, 182231},
	{"SURER", 5, 182232},
	{"COALE", 5, 182233},
	{"EQUESTRIANS", 11, 182234},
	{"AGENCES", 7, 182235},
	{"APPTS", 5, 182236},
	{"REIGER", 6, 182237},
	{"TACC", 4, 182238},
	{"CROPPIN", 7, 182239},
	{"CARDX", 5, 182240},
	{"NELSEN", 6, 182241},
	{"FRAE", 4, 182242},
	{"BEVELS", 6, 182243},
	{"KATONA", 6, 182244},
	{"BIORESEARCH", 11, 182245},
	{"TERBINAFINE", 11, 182246},
	{"AAPM", 4, 182247},
	{"TRAITOROUS", 10, 182248},
	{"LINKWARE", 8, 182249},
	{"GORAU", 5, 182250},
	{"HACEN", 5, 182251},
	{"BURRA", 5, 182252},
	{"LEVITE", 6, 182253},
	{"INTERLOGIC", 10, 182254},
	{"VIRAGE", 6, 182255},
	{"VIRA", 4, 182256},
	{"NASLUND", 7, 182257},
	{"MISSOURIANS", 11, 182258},
	{"CHKDSK", 6, 182259},
	{"ZDP", 3, 182260},
	{"AMERICAIN", 9, 182261},
	{"VEILSIDE", 8, 182262},
	{"SANDLOT", 7, 182263},
	{"EIRMOD", 6, 182264},
	{"QUIETING", 8, 182265},
	{"COMPUTADORES", 12, 182266},
	{"TETRALOGY", 9, 182267},
	{"ZYMO", 4, 182268},
	{"ZYAL", 4, 182269},
	{"WWMI", 4, 182270},
	{"WEXL", 4, 182271},
	{"UXST", 4, 182272},
	{"UTOZ", 4, 182273},
	{"UIMM", 4, 182274},
	{"TYKO", 4, 182275},
	{"SROF", 4, 182276},
	{"RRWI", 4, 182277},
	{"RIZM", 4, 182278},
	{"RBWE", 4, 182279},
	{"RBHO", 4, 182280},
	{"PUPE", 4, 182281},
	{"PBAG", 4, 182282},
	{"ONXW", 4, 182283},
	{"OFWC", 4, 182284},
	{"NJIU", 4, 182285},
	{"MRTS", 4, 182286},
	{"LMSY", 4, 182287},
	{"IDYM", 4, 182288},
	{"ICZI", 4, 182289},
	{"GLAO", 4, 182290},
	{"GFEI", 4, 182291},
	{"FUPC", 4, 182292},
	{"FKLE", 4, 182293},
	{"EWPS", 4, 182294},
	{"ERVC", 4, 182295},
	{"DHTM", 4, 182296},
	{"DHOK", 4, 182297},
	{"BPPL", 4, 182298},
	{"AMML", 4, 182299},
	{"AICG", 4, 182300},
	{"MAPLESOFT", 9, 182301},
	{"EFILE", 5, 182302},
	{"WELLSBURG", 9, 182303},
	{"CANDOUR", 7, 182304},
	{"LABELWRITER", 11, 182305},
	{"JUKI", 4, 182306},
	{"PACIFIED", 8, 182307},
	{"LAZING", 6, 182308},
	{"LUTYENS", 7, 182309},
	{"NEWSTANDARD", 11, 182310},
	{"PENETRANT", 9, 182311},
	{"POLLENS", 7, 182312},
	{"MWMT", 4, 182313},
	{"HALEDON", 7, 182314},
	{"HDSL", 4, 182315},
	{"LELLIPOP", 8, 182316},
	{"BRAUNSTEIN", 10, 182317},
	{"CTSNET", 6, 182318},
	{"HIAWASSEE", 9, 182319},
	{"MIKMOD", 6, 182320},
	{"ENSLEY", 6, 182321},
	{"TWIDDLE", 7, 182322},
	{"CONTEXTUALIZED", 14, 182323},
	{"ANTONIS", 7, 182324},
	{"BRIGIT", 6, 182325},
	{"QUETIAPINE", 10, 182326},
	{"POLYOLEFINS", 11, 182327},
	{"DACK", 4, 182328},
	{"WOODEND", 7, 182329},
	{"MOLS", 4, 182330},
	{"JOBLESSNESS", 11, 182331},
	{"STENY", 5, 182332},
	{"INDUSTRIEL", 10, 182333},
	{"PPPL", 4, 182334},
	{"CARBONARA", 9, 182335},
	{"BELTRE", 6, 182336},
	{"HUDGENS", 7, 182337},
	{"GREENHORN", 9, 182338},
	{"GPAS", 4, 182339},
	{"BLOGFATHER", 10, 182340},
	{"SPECTROGRAM", 11, 182341},
	{"PHARCYDE", 8, 182342},
	{"MEXIKO", 6, 182343},
	{"DUNKLEY", 7, 182344},
	{"DKP", 3, 182345},
	{"FAMILES", 7, 182346},
	{"ELIASSON", 8, 182347},
	{"LISTAR", 6, 182348},
	{"BOROWITZ", 8, 182349},
	{"DRIN", 4, 182350},
	{"HIGHLIFE", 8, 182351},
	{"ROADBED", 7, 182352},
	{"GUISBOROUGH", 11, 182353},
	{"POSTIONS", 8, 182354},
	{"PERLEY", 6, 182355},
	{"OVERLOCKER", 10, 182356},
	{"KABOODLE", 8, 182357},
	{"PHYTOMER", 8, 182358},
	{"HOMEABOUTCONTACT", 16, 182359},
	{"GOLDENS", 7, 182360},
	{"RAWKUS", 6, 182361},
	{"CHATTISGARH", 11, 182362},
	{"APERTURA", 8, 182363},
	{"ILAM", 4, 182364},
	{"MULHERN", 7, 182365},
	{"GORED", 5, 182366},
	{"MLU", 3, 182367},
	{"SPAETH", 6, 182368},
	{"REMUNERATIVE", 12, 182369},
	{"ETYPE", 5, 182370},
	{"FIREY", 5, 182371},
	{"OLIGOS", 6, 182372},
	{"ACDA", 4, 182373},
	{"SRIMAD", 6, 182374},
	{"PULIDO", 6, 182375},
	{"PHARMAC", 7, 182376},
	{"VHFCONTESTING", 13, 182377},
	{"XYLENES", 7, 182378},
	{"INTRICACY", 9, 182379},
	{"CLIBPDF", 7, 182380},
	{"KOZA", 4, 182381},
	{"HUNTIN", 6, 182382},
	{"FINANZIAMENTO", 13, 182383},
	{"MATFER", 6, 182384},
	{"HOSTETTLER", 10, 182385},
	{"CORALIE", 7, 182386},
	{"DOWNLOSD", 8, 182387},
	{"PENDULOUS", 9, 182388},
	{"ZODE", 4, 182389},
	{"YMYN", 4, 182390},
	{"YLSI", 4, 182391},
	{"XALA", 4, 182392},
	{"WFOX", 4, 182393},
	{"VCEN", 4, 182394},
	{"UILS", 4, 182395},
	{"SZIG", 4, 182396},
	{"SYTU", 4, 182397},
	{"RHUC", 4, 182398},
	{"NGGP", 4, 182399},
	{"MUNH", 4, 182400},
	{"LUNW", 4, 182401},
	{"LNWH", 4, 182402},
	{"LEWC", 4, 182403},
	{"JRFO", 4, 182404},
	{"IRZO", 4, 182405},
	{"IKCA", 4, 182406},
	{"GYNY", 4, 182407},
	{"GEAY", 4, 182408},
	{"EUMU", 4, 182409},
	{"EAVR", 4, 182410},
	{"BSTV", 4, 182411},
	{"AJIC", 4, 182412},
	{"AHLG", 4, 182413},
	{"ABGR", 4, 182414},
	{"MAGNIFICIENT", 12, 182415},
	{"KORNGOLD", 8, 182416},
	{"KARTHIKEYAN", 11, 182417},
	{"TIONING", 7, 182418},
	{"TENGU", 5, 182419},
	{"HOMAIL", 6, 182420},
	{"DISEQC", 6, 182421},
	{"SHADWELL", 8, 182422},
	{"MONEYMAKING", 11, 182423},
	{"MOURNER", 7, 182424},
	{"AMIL", 4, 182425},
	{"MINGEL", 6, 182426},
	{"GASTRECTOMY", 11, 182427},
	{"SUPERHEATED", 11, 182428},
	{"MULLICA", 7, 182429},
	{"QUESTED", 7, 182430},
	{"MANZELLA", 8, 182431},
	{"PANJANG", 7, 182432},
	{"ENFOLD", 6, 182433},
	{"WIRST", 5, 182434},
	{"TROUBADOURS", 11, 182435},
	{"SUPERIORES", 10, 182436},
	{"DAVITS", 6, 182437},
	{"BRITH", 5, 182438},
	{"COUNTOMAT", 9, 182439},
	{"BIOPHOTONICS", 12, 182440},
	{"TRICOR", 6, 182441},
	{"BROADFORD", 9, 182442},
	{"AMOURS", 6, 182443},
	{"REENTERED", 9, 182444},
	{"PAUPERS", 7, 182445},
	{"ABADDON", 7, 182446},
	{"JUTSU", 5, 182447},
	{"ACEP", 4, 182448},
	{"SOUNDDIVER", 10, 182449},
	{"PASIFIKA", 8, 182450},
	{"INTERTAINMENT", 13, 182451},
	{"DROPED", 6, 182452},
	{"SLOCATE", 7, 182453},
	{"ASBL", 4, 182454},
	{"OVERREACTING", 12, 182455},
	{"METHYLTRANSFERASES", 18, 182456},
	{"BUSHMEAT", 8, 182457},
	{"RUZICKA", 7, 182458},
	{"MUGELLO", 7, 182459},
	{"DJBDNS", 6, 182460},
	{"WALLE", 5, 182461},
	{"PLAYMAKERS", 10, 182462},
	{"PICTUERES", 9, 182463},
	{"SETCOOKIE", 9, 182464},
	{"BLUDGEON", 8, 182465},
	{"WELLED", 6, 182466},
	{"BIOLAWYER", 9, 182467},
	{"BRAULT", 6, 182468},
	{"OTOMO", 5, 182469},
	{"NATURAE", 7, 182470},
	{"KRATZ", 5, 182471},
	{"WEETABIX", 8, 182472},
	{"ALPI", 4, 182473},
	{"SUBCRIPTIONS", 12, 182474},
	{"YANTIS", 6, 182475},
	{"LLANDEILO", 9, 182476},
	{"BACKSTABBING", 12, 182477},
	{"CLYRO", 5, 182478},
	{"INCONSIDERABLE", 14, 182479},
	{"DEROGATIONS", 11, 182480},
	{"BRICKLAYING", 11, 182481},
	{"HALPER", 6, 182482},
	{"ABOBA", 5, 182483},
	{"LIRYCS", 6, 182484},
	{"STATICE", 7, 182485},
	{"COTYLEDONS", 10, 182486},
	{"TITANATE", 8, 182487},
	{"LOSIN", 5, 182488},
	{"FORG", 4, 182489},
	{"CACKLE", 6, 182490},
	{"WISTER", 6, 182491},
	{"LIAB", 4, 182492},
	{"KRAGEN", 6, 182493},
	{"BELUISTER", 9, 182494},
	{"SALLOW", 6, 182495},
	{"RANNOCH", 7, 182496},
	{"COZAD", 5, 182497},
	{"RSPA", 4, 182498},
	{"LIEVEN", 6, 182499},
	{"ALLMUSIC", 8, 182500},
	{"VTKALGORITHM", 12, 182501},
	{"VIEWTOPIC", 9, 182502},
	{"BAMBERGER", 9, 182503},
	{"PANIPAT", 7, 182504},
	{"SANCHES", 7, 182505},
	{"INTERPOKER", 10, 182506},
	{"BOTEL", 5, 182507},
	{"DIWNLOAD", 8, 182508},
	{"PALAPA", 6, 182509},
	{"HIDDINK", 7, 182510},
	{"SECR", 4, 182511},
	{"QUINDI", 6, 182512},
	{"WONDERFULBUYS", 13, 182513},
	{"FUKKING", 7, 182514},
	{"CLARKCONNECT", 12, 182515},
	{"CANDA", 5, 182516},
	{"ACTIVESHIELD", 12, 182517},
	{"YEPT", 4, 182518},
	{"VIEQ", 4, 182519},
	{"USKW", 4, 182520},
	{"UGDO", 4, 182521},
	{"TIPC", 4, 182522},
	{"REVH", 4, 182523},
	{"QABA", 4, 182524},
	{"OLFN", 4, 182525},
	{"NDKC", 4, 182526},
	{"MRGU", 4, 182527},
	{"MIXD", 4, 182528},
	{"LMTU", 4, 182529},
	{"LDTV", 4, 182530},
	{"LACD", 4, 182531},
	{"KSSK", 4, 182532},
	{"KOVH", 4, 182533},
	{"GSSY", 4, 182534},
	{"FGMS", 4, 182535},
	{"ETVF", 4, 182536},
	{"EMML", 4, 182537},
	{"EKIV", 4, 182538},
	{"BPAI", 4, 182539},
	{"AXFA", 4, 182540},
	{"ADUW", 4, 182541},
	{"STRP", 4, 182542},
	{"POLYTETRAFLUOROETHYLENE", 23, 182543},
	{"LOVITT", 6, 182544},
	{"ARIANNOL", 8, 182545},
	{"PAVO", 4, 182546},
	{"MURTON", 6, 182547},
	{"UNGREASED", 9, 182548},
	{"THIOSULFATE", 11, 182549},
	{"GEMAAKT", 7, 182550},
	{"CAMPANELLI", 10, 182551},
	{"AMZN", 4, 182552},
	{"MONTAGNES", 9, 182553},
	{"MARQ", 4, 182554},
	{"REFORMATORY", 11, 182555},
	{"SUBRECIPIENT", 12, 182556},
	{"PROTID", 6, 182557},
	{"DURRETT", 7, 182558},
	{"TADAO", 5, 182559},
	{"MACLELLAN", 9, 182560},
	{"NETDEV", 6, 182561},
	{"LONGFIELD", 9, 182562},
	{"DEMEURE", 7, 182563},
	{"SOLLER", 6, 182564},
	{"PSTYLE", 6, 182565},
	{"NAAKT", 5, 182566},
	{"FILMWORKS", 9, 182567},
	{"POOLR", 5, 182568},
	{"SHEBOP", 6, 182569},
	{"ADMINSTRATIVE", 13, 182570},
	{"RUGMAN", 6, 182571},
	{"OSTENTATION", 11, 182572},
	{"OPROFILE", 8, 182573},
	{"EVERONE", 7, 182574},
	{"WORTHEN", 7, 182575},
	{"KITTENCAL", 9, 182576},
	{"MAESTEG", 7, 182577},
	{"NARASIMHAN", 10, 182578},
	{"TETRAHYMENA", 11, 182579},
	{"QUTB", 4, 182580},
	{"OVERBY", 6, 182581},
	{"NINGUNA", 7, 182582},
	{"STRADLIN", 8, 182583},
	{"ZANDVOORT", 9, 182584},
	{"PLIP", 4, 182585},
	{"CHERISHES", 9, 182586},
	{"SNOWSTORMS", 10, 182587},
	{"RIHGA", 5, 182588},
	{"PINEL", 5, 182589},
	{"LINGUINI", 8, 182590},
	{"TWINN", 5, 182591},
	{"EXSLT", 5, 182592},
	{"BOBB", 4, 182593},
	{"RAMSDELL", 8, 182594},
	{"BUSE", 4, 182595},
	{"STODGY", 6, 182596},
	{"APLICADA", 8, 182597},
	{"UAHOO", 5, 182598},
	{"CURITY", 6, 182599},
	{"EDMEE", 5, 182600},
	{"BOOKEND", 7, 182601},
	{"TEXTIL", 6, 182602},
	{"ANECDOTALLY", 11, 182603},
	{"BOUR", 4, 182604},
	{"SHIPOWNER", 9, 182605},
	{"LINCOLNS", 8, 182606},
	{"SOUPER", 6, 182607},
	{"ENTICEMENT", 10, 182608},
	{"TIMECLOCK", 9, 182609},
	{"UNDERWHELMING", 13, 182610},
	{"EFRON", 5, 182611},
	{"PARITIES", 8, 182612},
	{"AFFIANT", 7, 182613},
	{"NEOLIBERTARIAN", 14, 182614},
	{"YANC", 4, 182615},
	{"MELFORT", 7, 182616},
	{"CURRAGH", 7, 182617},
	{"PARTITIONMAGIC", 14, 182618},
	{"ELCHE", 5, 182619},
	{"GLOSSAR", 7, 182620},
	{"WRATHFUL", 8, 182621},
	{"JEICHORN", 8, 182622},
	{"BOLTER", 6, 182623},
	{"TIMEKILLER", 10, 182624},
	{"FACOM", 5, 182625},
	{"DRSCHEME", 8, 182626},
	{"ONLINESEATS", 11, 182627},
	{"IGUASSU", 7, 182628},
	{"PLATTSMOUTH", 11, 182629},
	{"ROSNEFT", 7, 182630},
	{"JTAPI", 5, 182631},
	{"SILISTRA", 8, 182632},
	{"ZILP", 4, 182633},
	{"YUCO", 4, 182634},
	{"YCEF", 4, 182635},
	{"YAMD", 4, 182636},
	{"TTUG", 4, 182637},
	{"TOYR", 4, 182638},
	{"TEYR", 4, 182639},
	{"SSKR", 4, 182640},
	{"SPUF", 4, 182641},
	{"SKFL", 4, 182642},
	{"PTHF", 4, 182643},
	{"POLC", 4, 182644},
	{"PODB", 4, 182645},
	{"MPHH", 4, 182646},
	{"MOML", 4, 182647},
	{"LZSA", 4, 182648},
	{"KHKH", 4, 182649},
	{"JRRT", 4, 182650},
	{"GOVG", 4, 182651},
	{"GAMC", 4, 182652},
	{"EAZZ", 4, 182653},
	{"DECN", 4, 182654},
	{"CHOX", 4, 182655},
	{"BSMU", 4, 182656},
	{"BIVE", 4, 182657},
	{"AQSP", 4, 182658},
	{"AKYR", 4, 182659},
	{"THUIS", 5, 182660},
	{"NETCARE", 7, 182661},
	{"EGBERTS", 7, 182662},
	{"VASOCONSTRICTOR", 15, 182663},
	{"NOGUEIRA", 8, 182664},
	{"BIOEQUIVALENCE", 14, 182665},
	{"MEFLOQUINE", 10, 182666},
	{"DRACONIS", 8, 182667},
	{"SHADOWKNIGHT", 12, 182668},
	{"RSPAN", 5, 182669},
	{"RADEMACHER", 10, 182670},
	{"SEKONDA", 7, 182671},
	{"REDLION", 7, 182672},
	{"POLAMALU", 8, 182673},
	{"AEROMONAS", 9, 182674},
	{"VARON", 5, 182675},
	{"PARTOOK", 7, 182676},
	{"INVIDUNT", 8, 182677},
	{"SIBNEFT", 7, 182678},
	{"OKOLONA", 7, 182679},
	{"DIDDLY", 6, 182680},
	{"CHIETI", 6, 182681},
	{"SULFONYLUREA", 12, 182682},
	{"MURES", 5, 182683},
	{"HLUHLUWE", 8, 182684},
	{"JOAD", 4, 182685},
	{"CLARINETIST", 11, 182686},
	{"VISSIM", 6, 182687},
	{"LEGANZA", 7, 182688},
	{"DOZERS", 6, 182689},
	{"FEDERICA", 8, 182690},
	{"TRANSMONDE", 10, 182691},
	{"TULSI", 5, 182692},
	{"GUTKNECHT", 9, 182693},
	{"MNSCU", 5, 182694},
	{"VISITEUROPE", 11, 182695},
	{"MEDIDA", 6, 182696},
	{"BURSWOOD", 8, 182697},
	{"PHYLIP", 6, 182698},
	{"PEOPE", 5, 182699},
	{"OFICINAS", 8, 182700},
	{"BAMBANG", 7, 182701},
	{"TRACKPAD", 8, 182702},
	{"BROSS", 5, 182703},
	{"SHAPESHIFTERS", 13, 182704},
	{"PHAZE", 5, 182705},
	{"JJJJ", 4, 182706},
	{"CLAVIA", 6, 182707},
	{"PONOMAREW", 9, 182708},
	{"GAHOO", 5, 182709},
	{"SLAVING", 7, 182710},
	{"MUKAI", 5, 182711},
	{"KNEEPADS", 8, 182712},
	{"PARISE", 6, 182713},
	{"MCKINSTRY", 9, 182714},
	{"NEOGENE", 7, 182715},
	{"PENGE", 5, 182716},
	{"LYOTARD", 7, 182717},
	{"KUPER", 5, 182718},
	{"ONCIDIUM", 8, 182719},
	{"GOLDSBOROUGH", 12, 182720},
	{"DIARMUID", 8, 182721},
	{"GANDIA", 6, 182722},
	{"TURBOMACHINERY", 14, 182723},
	{"SCHEISSE", 8, 182724},
	{"MANAHAWKIN", 10, 182725},
	{"KORCULA", 7, 182726},
	{"FAMILIARS", 9, 182727},
	{"VARLA", 5, 182728},
	{"OJIBWAY", 7, 182729},
	{"SARSGAARD", 9, 182730},
	{"OVERESTIMATES", 13, 182731},
	{"GLOCKENSPIEL", 12, 182732},
	{"EDAM", 4, 182733},
	{"KIDLINK", 7, 182734},
	{"SINGSTAR", 8, 182735},
	{"EMBALLAGE", 9, 182736},
	{"ELLMAU", 6, 182737},
	{"ISOENZYME", 9, 182738},
	{"BODYKIT", 7, 182739},
	{"PEGASYS", 7, 182740},
	{"RAWCLIFFE", 9, 182741},
	{"COLLEDGE", 8, 182742},
	{"GRAMICCI", 8, 182743},
	{"MAGINON", 7, 182744},
	{"BLACKEN", 7, 182745},
	{"ZORG", 4, 182746},
	{"POSSIBLES", 9, 182747},
	{"MARILEE", 7, 182748},
	{"WETHERILL", 9, 182749},
	{"INTENSIONAL", 11, 182750},
	{"YUSW", 4, 182751},
	{"YIFU", 4, 182752},
	{"WEFR", 4, 182753},
	{"VIIW", 4, 182754},
	{"UOBR", 4, 182755},
	{"UDUD", 4, 182756},
	{"TUCI", 4, 182757},
	{"TLLG", 4, 182758},
	{"SAGP", 4, 182759},
	{"RUSY", 4, 182760},
	{"RRDE", 4, 182761},
	{"OUIG", 4, 182762},
	{"NWYC", 4, 182763},
	{"NREX", 4, 182764},
	{"MIBM", 4, 182765},
	{"LZHA", 4, 182766},
	{"LAEC", 4, 182767},
	{"KYKI", 4, 182768},
	{"KUCO", 4, 182769},
	{"HSFL", 4, 182770},
	{"HEZM", 4, 182771},
	{"GTHV", 4, 182772},
	{"ELUO", 4, 182773},
	{"ECDW", 4, 182774},
	{"DUWH", 4, 182775},
	{"DGYA", 4, 182776},
	{"BOED", 4, 182777},
	{"AQAM", 4, 182778},
	{"AMKR", 4, 182779},
	{"AJIL", 4, 182780},
	{"ABAV", 4, 182781},
	{"ALAIHI", 6, 182782},
	{"MIDERN", 6, 182783},
	{"BIELLA", 6, 182784},
	{"JUSTA", 5, 182785},
	{"GFD", 3, 182786},
	{"CONGREGANTS", 11, 182787},
	{"COBIA", 5, 182788},
	{"CALDAS", 6, 182789},
	{"QUICKOFFICE", 11, 182790},
	{"KONTROL", 7, 182791},
	{"OUTP", 4, 182792},
	{"KAKTUZ", 6, 182793},
	{"ARTICLEE", 8, 182794},
	{"ISOTHIOCYANATE", 14, 182795},
	{"QUOTPOJKVAN", 11, 182796},
	{"CLUBQUOTA", 9, 182797},
	{"MONIN", 5, 182798},
	{"FASTRACK", 8, 182799},
	{"SCHMUTZ", 7, 182800},
	{"VANNES", 6, 182801},
	{"GUES", 4, 182802},
	{"DEFLECTS", 8, 182803},
	{"KENIA", 5, 182804},
	{"LINKCHECK", 9, 182805},
	{"PALAS", 5, 182806},
	{"LEADDISCOVERY", 13, 182807},
	{"KLEREN", 6, 182808},
	{"EMPREX", 6, 182809},
	{"TRAVELEX", 8, 182810},
	{"PHILOMENA", 9, 182811},
	{"DATATRAVELER", 12, 182812},
	{"SUBLIMATED", 10, 182813},
	{"BORRELLI", 8, 182814},
	{"ANNEXATIONS", 11, 182815},
	{"JUNKETS", 7, 182816},
	{"ADDE", 4, 182817},
	{"SCHEMER", 7, 182818},
	{"LIKA", 4, 182819},
	{"DTMLFILE", 8, 182820},
	{"MAGTRON", 7, 182821},
	{"MALEDOM", 7, 182822},
	{"RENDERLISTPLUGIN", 16, 182823},
	{"CABLELABS", 9, 182824},
	{"SPELLCASTER", 11, 182825},
	{"OGBUJI", 6, 182826},
	{"STANDIFORD", 10, 182827},
	{"GOODBULBS", 9, 182828},
	{"BBV", 3, 182829},
	{"KDEPRINT", 8, 182830},
	{"CLARETS", 7, 182831},
	{"REBBI", 5, 182832},
	{"TRANSCRIPTIONISTS", 17, 182833},
	{"BOOTCD", 6, 182834},
	{"COULIS", 6, 182835},
	{"EXTENXLS", 8, 182836},
	{"ROZINN", 6, 182837},
	{"SORCEROR", 8, 182838},
	{"NORVELL", 7, 182839},
	{"MENUCONFIG", 10, 182840},
	{"MIDDLEWICH", 10, 182841},
	{"ACTUELLEMENT", 12, 182842},
	{"NEWSWISE", 8, 182843},
	{"POWDERFINGER", 12, 182844},
	{"BOXJAM", 6, 182845},
	{"RLF", 3, 182846},
	{"UCSPI", 5, 182847},
	{"MIHALY", 6, 182848},
	{"RODDING", 7, 182849},
	{"SRCS", 4, 182850},
	{"HAMBLE", 6, 182851},
	{"FERRON", 6, 182852},
	{"DEINER", 6, 182853},
	{"CAMERADIGITAL", 13, 182854},
	{"SNOWSHACK", 9, 182855},
	{"NUSRAT", 6, 182856},
	{"JETP", 4, 182857},
	{"LAVON", 5, 182858},
	{"WOLFCAMERA", 10, 182859},
	{"NOUBA", 5, 182860},
	{"WRITHE", 6, 182861},
	{"COCKEREL", 8, 182862},
	{"YMSI", 4, 182863},
	{"XVIA", 4, 182864},
	{"XUSS", 4, 182865},
	{"WWBR", 4, 182866},
	{"WIMU", 4, 182867},
	{"URRH", 4, 182868},
	{"UOID", 4, 182869},
	{"ULJE", 4, 182870},
	{"SGUB", 4, 182871},
	{"RYUI", 4, 182872},
	{"RSZO", 4, 182873},
	{"RPCR", 4, 182874},
	{"PILK", 4, 182875},
	{"ORHD", 4, 182876},
	{"ORGG", 4, 182877},
	{"NKEB", 4, 182878},
	{"MHWI", 4, 182879},
	{"LYIK", 4, 182880},
	{"JGRE", 4, 182881},
	{"HEVB", 4, 182882},
	{"GYFE", 4, 182883},
	{"EUXW", 4, 182884},
	{"ELZI", 4, 182885},
	{"BYBB", 4, 182886},
	{"BUAL", 4, 182887},
	{"BQUI", 4, 182888},
	{"AFCT", 4, 182889},
	{"ABCU", 4, 182890},
	{"OCCIDENTALE", 11, 182891},
	{"LINKSTATION", 11, 182892},
	{"LEFKADA", 7, 182893},
	{"BLAKEMAN", 8, 182894},
	{"AZALIS", 6, 182895},
	{"VLASOV", 6, 182896},
	{"DUMAIS", 6, 182897},
	{"PURELL", 6, 182898},
	{"GABELLI", 7, 182899},
	{"BLACKLEY", 8, 182900},
	{"USPAP", 5, 182901},
	{"KEUNG", 5, 182902},
	{"HERMOSAS", 8, 182903},
	{"WIWA", 4, 182904},
	{"MIZAR", 5, 182905},
	{"CALDERWOOD", 10, 182906},
	{"SITENAVIGATION", 14, 182907},
	{"GEORDI", 6, 182908},
	{"LOPRESSOR", 9, 182909},
	{"LIVIO", 5, 182910},
	{"KDHE", 4, 182911},
	{"SIANG", 5, 182912},
	{"PATCHLEVEL", 10, 182913},
	{"SPECTRUMS", 9, 182914},
	{"CEEC", 4, 182915},
	{"SYDICATION", 10, 182916},
	{"MUMMERS", 7, 182917},
	{"LEBRA", 5, 182918},
	{"CANANIAN", 8, 182919},
	{"TRETORN", 7, 182920},
	{"FRIENDLESS", 10, 182921},
	{"PROBOSCIS", 9, 182922},
	{"ANALTEENS", 9, 182923},
	{"WHOLEHEARTED", 12, 182924},
	{"GONDA", 5, 182925},
	{"UNDERLINGS", 10, 182926},
	{"MAHASKA", 7, 182927},
	{"VALIC", 5, 182928},
	{"INKLINGS", 8, 182929},
	{"FITFUL", 6, 182930},
	{"FACTFILES", 9, 182931},
	{"UNSTRESSED", 10, 182932},
	{"ESTRUCTURA", 10, 182933},
	{"WINPCAP", 7, 182934},
	{"GENUINEINTEL", 12, 182935},
	{"ANALTEEN", 8, 182936},
	{"DETAILSART", 10, 182937},
	{"BEVER", 5, 182938},
	{"USSC", 4, 182939},
	{"STORR", 5, 182940},
	{"CAUTIONING", 10, 182941},
	{"SPINONE", 7, 182942},
	{"SICUT", 5, 182943},
	{"KRYCEK", 6, 182944},
	{"GRBS", 4, 182945},
	{"FHSU", 4, 182946},
	{"CONSULTAR", 9, 182947},
	{"GENII", 5, 182948},
	{"EVANT", 5, 182949},
	{"PARKPLATZTREFFS", 15, 182950},
	{"MASAYA", 6, 182951},
	{"REFRACTORS", 10, 182952},
	{"TRANSLATUM", 10, 182953},
	{"CASHION", 7, 182954},
	{"SPORTSBLOGS", 11, 182955},
	{"INTRUST", 7, 182956},
	{"OVERPASSES", 10, 182957},
	{"BASKETWEAVE", 11, 182958},
	{"ILLI", 4, 182959},
	{"ENGER", 5, 182960},
	{"AWDURDODAU", 10, 182961},
	{"ASPALLIANCE", 11, 182962},
	{"EARMUFFS", 8, 182963},
	{"ANDEREM", 7, 182964},
	{"ALEXUS", 6, 182965},
	{"KRISPIES", 8, 182966},
	{"DISHONOURED", 11, 182967},
	{"JINJA", 5, 182968},
	{"ALIMENTAZIONE", 13, 182969},
	{"AUSTLII", 7, 182970},
	{"UNQUESTIONING", 13, 182971},
	{"SCHIPPER", 8, 182972},
	{"ZVW", 3, 182973},
	{"ZPX", 3, 182974},
	{"XQV", 3, 182975},
	{"XQC", 3, 182976},
	{"XKK", 3, 182977},
	{"XJG", 3, 182978},
	{"WQQ", 3, 182979},
	{"RQK", 3, 182980},
	{"QXY", 3, 182981},
	{"QXM", 3, 182982},
	{"QMX", 3, 182983},
	{"MXQ", 3, 182984},
	{"LWQ", 3, 182985},
	{"LQZ", 3, 182986},
	{"JZL", 3, 182987},
	{"JYG", 3, 182988},
	{"JXF", 3, 182989},
	{"GXZ", 3, 182990},
	{"GJZ", 3, 182991},
	{"BWJ", 3, 182992},
	{"BRQ", 3, 182993},
	{"TERAI", 5, 182994},
	{"TOHRU", 5, 182995},
	{"FORGOTTON", 9, 182996},
	{"BOTTOMLAND", 10, 182997},
	{"NEUBAUTEN", 9, 182998},
	{"DENSION", 7, 182999},
	{"MEZCO", 5, 183000},
	{"AQUATINT", 8, 183001},
	{"MIDSOUTH", 8, 183002},
	{"DESULTORY", 9, 183003},
	{"ESSBASE", 7, 183004},
	{"AVEX", 4, 183005},
	{"ZEBI", 4, 183006},
	{"YEOV", 4, 183007},
	{"XGOT", 4, 183008},
	{"XASJ", 4, 183009},
	{"WWOL", 4, 183010},
	{"WFUT", 4, 183011},
	{"TMOZ", 4, 183012},
	{"TIDC", 4, 183013},
	{"SYER", 4, 183014},
	{"RRUF", 4, 183015},
	{"RLMI", 4, 183016},
	{"PSUT", 4, 183017},
	{"PNIK", 4, 183018},
	{"NNUG", 4, 183019},
	{"MEEY", 4, 183020},
	{"LKFI", 4, 183021},
	{"KTYL", 4, 183022},
	{"IGEP", 4, 183023},
	{"HWIM", 4, 183024},
	{"FCFI", 4, 183025},
	{"FCDE", 4, 183026},
	{"EDLP", 4, 183027},
	{"CFEN", 4, 183028},
	{"AEPR", 4, 183029},
	{"FABRIQUE", 8, 183030},
	{"DISJUNCT", 8, 183031},
	{"PILKEY", 6, 183032},
	{"ELIMI", 5, 183033},
	{"EDAYS", 5, 183034},
	{"EPIFANES", 8, 183035},
	{"VITOR", 5, 183036},
	{"FINC", 4, 183037},
	{"CHEDI", 5, 183038},
	{"COUTO", 5, 183039},
	{"SHAREEF", 7, 183040},
	{"GSTRING", 7, 183041},
	{"CRAMLINGTON", 11, 183042},
	{"VEROMAX", 7, 183043},
	{"PEDDIE", 6, 183044},
	{"SMARTLINK", 9, 183045},
	{"XCC", 3, 183046},
	{"PROBALLY", 8, 183047},
	{"CIENFUEGOS", 10, 183048},
	{"JANACEK", 7, 183049},
	{"INTERLATA", 9, 183050},
	{"ANTEATERS", 9, 183051},
	{"MMBASE", 6, 183052},
	{"PITIFULLY", 9, 183053},
	{"LINDEBERG", 9, 183054},
	{"CRESCENTS", 9, 183055},
	{"ESCUDOS", 7, 183056},
	{"BENCHEXCHANGE", 13, 183057},
	{"MCLS", 4, 183058},
	{"BALLYNAHINCH", 12, 183059},
	{"HOLMER", 6, 183060},
	{"FOTOMODELLE", 11, 183061},
	{"CONFISCATING", 12, 183062},
	{"RIZLA", 5, 183063},
	{"MENACINGLY", 10, 183064},
	{"USYD", 4, 183065},
	{"SPAMD", 5, 183066},
	{"MAXXTRO", 7, 183067},
	{"AMBIGUOUSLY", 11, 183068},
	{"AUCTIVA", 7, 183069},
	{"TORCHING", 8, 183070},
	{"REVELING", 8, 183071},
	{"EMMELINE", 8, 183072},
	{"WITHE", 5, 183073},
	{"SEJM", 4, 183074},
	{"SHIKAI", 6, 183075},
	{"LETIZIA", 7, 183076},
	{"DENDY", 5, 183077},
	{"BLAKESLEY", 9, 183078},
	{"GEOREFERENCED", 13, 183079},
	{"KINNAIRD", 8, 183080},
	{"BEERSHEBA", 9, 183081},
	{"ATOMICA", 7, 183082},
	{"FRANCHOT", 8, 183083},
	{"KIRKCUDBRIGHT", 13, 183084},
	{"ALAMEIN", 7, 183085},
	{"LINKEN", 6, 183086},
	{"INITIALIZERS", 12, 183087},
	{"IPODSTORE", 9, 183088},
	{"GLINDA", 6, 183089},
	{"JCW", 3, 183090},
	{"FINANC", 6, 183091},
	{"HENDRERIT", 9, 183092},
	{"MORBIHAN", 8, 183093},
	{"SEASICKNESS", 11, 183094},
	{"UCRL", 4, 183095},
	{"NIDAL", 5, 183096},
	{"KUEN", 4, 183097},
	{"DISINCLINED", 11, 183098},
	{"LACKEYS", 7, 183099},
	{"STADIO", 6, 183100},
	{"EWOKS", 5, 183101},
	{"BOMBONIERE", 10, 183102},
	{"HOKKIEN", 7, 183103},
	{"KENDER", 6, 183104},
	{"KOVAL", 5, 183105},
	{"DARKHORSE", 9, 183106},
	{"GRONDAHL", 8, 183107},
	{"MISSLES", 7, 183108},
	{"CONTEX", 6, 183109},
	{"FACILISIS", 9, 183110},
	{"SPEELGOED", 9, 183111},
	{"MONEL", 5, 183112},
	{"CODICIL", 7, 183113},
	{"ANTUNES", 7, 183114},
	{"ZEPS", 4, 183115},
	{"YUKY", 4, 183116},
	{"YTEB", 4, 183117},
	{"YMAE", 4, 183118},
	{"WWFR", 4, 183119},
	{"WKSE", 4, 183120},
	{"WKIR", 4, 183121},
	{"VSBU", 4, 183122},
	{"UTZP", 4, 183123},
	{"UHUA", 4, 183124},
	{"TUOF", 4, 183125},
	{"TIZZ", 4, 183126},
	{"RGTA", 4, 183127},
	{"NUXM", 4, 183128},
	{"NODG", 4, 183129},
	{"JUTO", 4, 183130},
	{"IZEX", 4, 183131},
	{"INZR", 4, 183132},
	{"IJEK", 4, 183133},
	{"GRYN", 4, 183134},
	{"DZHU", 4, 183135},
	{"CMPO", 4, 183136},
	{"CAOU", 4, 183137},
	{"BYKL", 4, 183138},
	{"BTDE", 4, 183139},
	{"PURINES", 7, 183140},
	{"SCREVEN", 7, 183141},
	{"PIEZ", 4, 183142},
	{"FLOODWATER", 10, 183143},
	{"LONGYEARBYEN", 12, 183144},
	{"HANNUM", 6, 183145},
	{"DARIUSZ", 7, 183146},
	{"CEFUROXIME", 10, 183147},
	{"PUERILE", 7, 183148},
	{"DIEL", 4, 183149},
	{"GILLI", 5, 183150},
	{"DGB", 3, 183151},
	{"ANUP", 4, 183152},
	{"PHARMACOPEIA", 12, 183153},
	{"KLEBER", 6, 183154},
	{"SPOFFORD", 8, 183155},
	{"ELECTRONICAL", 12, 183156},
	{"ANIVERSARIO", 11, 183157},
	{"NEERAJ", 6, 183158},
	{"JESMOND", 7, 183159},
	{"NOOKSACK", 8, 183160},
	{"MILHARES", 8, 183161},
	{"EDITORIALLY", 11, 183162},
	{"BZFLAG", 6, 183163},
	{"BERKELEYDB", 10, 183164},
	{"JOURNAUX", 8, 183165},
	{"SUSTIVA", 7, 183166},
	{"QUANNUM", 7, 183167},
	{"KERKYRA", 7, 183168},
	{"KREG", 4, 183169},
	{"AMBULATION", 10, 183170},
	{"MAYRA", 5, 183171},
	{"OJSC", 4, 183172},
	{"EMPHA", 5, 183173},
	{"TETRAHYDRO", 10, 183174},
	{"BECLOMETHASONE", 14, 183175},
	{"BREATHWORK", 10, 183176},
	{"THINKVISION", 11, 183177},
	{"IMPROVER", 8, 183178},
	{"WORTHLESSNESS", 13, 183179},
	{"ABSYNTHE", 8, 183180},
	{"VERMICELLI", 10, 183181},
	{"SPLC", 4, 183182},
	{"GASTINEAU", 9, 183183},
	{"LACTO", 5, 183184},
	{"GEOMVIEW", 8, 183185},
	{"XMODMAP", 7, 183186},
	{"KAYSAR", 6, 183187},
	{"SOUDERTON", 9, 183188},
	{"ECONOPUNDIT", 11, 183189},
	{"DEVOLVING", 9, 183190},
	{"CASILLAS", 8, 183191},
	{"OBLATION", 8, 183192},
	{"MAESTROS", 8, 183193},
	{"WESTERNIZED", 11, 183194},
	{"RIEFENSTAHL", 11, 183195},
	{"TORC", 4, 183196},
	{"FRANZISKA", 9, 183197},
	{"ENOLASE", 7, 183198},
	{"ROTAN", 5, 183199},
	{"CINET", 5, 183200},
	{"CARACALLA", 9, 183201},
	{"YOMI", 4, 183202},
	{"CRONBACH", 8, 183203},
	{"HYGYRCHEDD", 10, 183204},
	{"ATLMULTIMEDIA", 13, 183205},
	{"NECROLOGY", 9, 183206},
	{"LANDOR", 6, 183207},
	{"COVERLETS", 9, 183208},
	{"PYTZ", 4, 183209},
	{"SNOTEL", 6, 183210},
	{"OVERCONFIDENCE", 14, 183211},
	{"STROBL", 6, 183212},
	{"EXECUTORY", 9, 183213},
	{"HAFELE", 6, 183214},
	{"COMUNICATION", 12, 183215},
	{"DOHILITE", 8, 183216},
	{"FIRSTLINE", 9, 183217},
	{"PARTOUZE", 8, 183218},
	{"COMBUST", 7, 183219},
	{"GEIGY", 5, 183220},
	{"CIVILIZING", 10, 183221},
	{"COMMUNIQUES", 11, 183222},
	{"LENHART", 7, 183223},
	{"BUSHMILLS", 9, 183224},
	{"SAMER", 5, 183225},
	{"ASCLEPIAS", 9, 183226},
	{"KENEALLY", 8, 183227},
	{"SHUMEN", 6, 183228},
	{"CONSEILLER", 10, 183229},
	{"STOCKYARD", 9, 183230},
	{"NEWSMAIL", 8, 183231},
	{"ZYSK", 4, 183232},
	{"ZKRI", 4, 183233},
	{"ZBUL", 4, 183234},
	{"YSAX", 4, 183235},
	{"YEGR", 4, 183236},
	{"WMEW", 4, 183237},
	{"UEXA", 4, 183238},
	{"UDCL", 4, 183239},
	{"TTBY", 4, 183240},
	{"TMWA", 4, 183241},
	{"TFAY", 4, 183242},
	{"SORZ", 4, 183243},
	{"SBDE", 4, 183244},
	{"RPCL", 4, 183245},
	{"RLHI", 4, 183246},
	{"RDZE", 4, 183247},
	{"PIMC", 4, 183248},
	{"ONCV", 4, 183249},
	{"NYCY", 4, 183250},
	{"NDJC", 4, 183251},
	{"MNSC", 4, 183252},
	{"LZEL", 4, 183253},
	{"LMEB", 4, 183254},
	{"LFOB", 4, 183255},
	{"HSYL", 4, 183256},
	{"HGIG", 4, 183257},
	{"GPTH", 4, 183258},
	{"FCDS", 4, 183259},
	{"DMPG", 4, 183260},
	{"DLBF", 4, 183261},
	{"DJUP", 4, 183262},
	{"DFTH", 4, 183263},
	{"DDRH", 4, 183264},
	{"BTOV", 4, 183265},
	{"CORNEILLE", 9, 183266},
	{"TROPHOBLAST", 11, 183267},
	{"TOOLROOM", 8, 183268},
	{"STILLBIRTHS", 11, 183269},
	{"ALFONZO", 7, 183270},
	{"TRIPOS", 6, 183271},
	{"SIUTES", 6, 183272},
	{"MISSPENT", 8, 183273},
	{"DOTFILE", 7, 183274},
	{"MULTIPLET", 9, 183275},
	{"MERKEN", 6, 183276},
	{"HOFSTEDE", 8, 183277},
	{"PIROUETTE", 9, 183278},
	{"MPEP", 4, 183279},
	{"BATALLA", 7, 183280},
	{"ARAVIND", 7, 183281},
	{"DAMMING", 7, 183282},
	{"TOMASI", 6, 183283},
	{"IMMUNIX", 7, 183284},
	{"HOOPA", 5, 183285},
	{"EWOSS", 5, 183286},
	{"BAGASSE", 7, 183287},
	{"ECPC", 4, 183288},
	{"DORP", 4, 183289},
	{"UNSCHOOLING", 11, 183290},
	{"HUNTINGTONS", 11, 183291},
	{"BOYE", 4, 183292},
	{"GUISEPPE", 8, 183293},
	{"PALAVER", 7, 183294},
	{"KAPOR", 5, 183295},
	{"MEGACO", 6, 183296},
	{"GORGIAS", 7, 183297},
	{"OFFICEDEPOT", 11, 183298},
	{"BALALAIKA", 9, 183299},
	{"GEOSTROPHIC", 11, 183300},
	{"DUCTLESS", 8, 183301},
	{"APPIA", 5, 183302},
	{"NEXTSTAT", 8, 183303},
	{"BRANDIS", 7, 183304},
	{"TALKBACKS", 9, 183305},
	{"BOUSQUET", 8, 183306},
	{"BIKO", 4, 183307},
	{"LIBPTHREAD", 10, 183308},
	{"APOSTOLOS", 9, 183309},
	{"ABBIGLIAMENTO", 13, 183310},
	{"STOREWIDE", 9, 183311},
	{"ORADELL", 7, 183312},
	{"ROLETA", 6, 183313},
	{"GIACOMETTI", 10, 183314},
	{"LISTERIOSIS", 11, 183315},
	{"NORTHFLEET", 10, 183316},
	{"ANTIAIRCRAFT", 12, 183317},
	{"NAMBUCCA", 8, 183318},
	{"TSMF", 4, 183319},
	{"FTTP", 4, 183320},
	{"FRMPROFILE", 10, 183321},
	{"SBRT", 4, 183322},
	{"DINGLEY", 7, 183323},
	{"DRYDOCK", 7, 183324},
	{"CARWERKS", 8, 183325},
	{"BUDEJOVICE", 10, 183326},
	{"YARNELL", 7, 183327},
	{"EMPLEOS", 7, 183328},
	{"TRIBU", 5, 183329},
	{"INORGANICS", 10, 183330},
	{"FOLLO", 5, 183331},
	{"GRANDSTANDS", 11, 183332},
	{"GRND", 4, 183333},
	{"MAILCAP", 7, 183334},
	{"UNVARNISHED", 11, 183335},
	{"LOAEL", 5, 183336},
	{"OVERRAN", 7, 183337},
	{"SPYKER", 6, 183338},
	{"RUSHWORTH", 9, 183339},
	{"HOTMAL", 6, 183340},
	{"EACUTE", 6, 183341},
	{"ACDBTRACE", 9, 183342},
	{"HAMIL", 5, 183343},
	{"FRQ", 3, 183344},
	{"FOLIES", 6, 183345},
	{"TOPICNAME", 9, 183346},
	{"DONK", 4, 183347},
	{"THIAZIDE", 8, 183348},
	{"WRETCHES", 8, 183349},
	{"POTSDAMER", 9, 183350},
	{"NCBUY", 5, 183351},
	{"INADVERTANTLY", 13, 183352},
	{"ROCKNROCKS", 10, 183353},
	{"MISHKIN", 7, 183354},
	{"BOLLAND", 7, 183355},
	{"PENNSIC", 7, 183356},
	{"IBOGAINE", 8, 183357},
	{"HIDEN", 5, 183358},
	{"SCIONLIFE", 9, 183359},
	{"PINGPONG", 8, 183360},
	{"MATSUBARA", 9, 183361},
	{"BALDRICK", 8, 183362},
	{"KUNZEL", 6, 183363},
	{"WICKMAN", 7, 183364},
	{"SHAHAR", 6, 183365},
	{"AKONG", 5, 183366},
	{"PAGEPAGE", 8, 183367},
	{"SDRS", 4, 183368},
	{"NCBAT", 5, 183369},
	{"ASPECTRATIOFIXED", 16, 183370},
	{"DEVSEL", 6, 183371},
	{"ZZPI", 4, 183372},
	{"UYMI", 4, 183373},
	{"UTCY", 4, 183374},
	{"UBCI", 4, 183375},
	{"SYXI", 4, 183376},
	{"RXIN", 4, 183377},
	{"ROKN", 4, 183378},
	{"RMJA", 4, 183379},
	{"RAJR", 4, 183380},
	{"PATJ", 4, 183381},
	{"NYMT", 4, 183382},
	{"NMBE", 4, 183383},
	{"MRKH", 4, 183384},
	{"MAOB", 4, 183385},
	{"JINJ", 4, 183386},
	{"IXOV", 4, 183387},
	{"IGTW", 4, 183388},
	{"HOBG", 4, 183389},
	{"GSYA", 4, 183390},
	{"FKRO", 4, 183391},
	{"FCDI", 4, 183392},
	{"CUDI", 4, 183393},
	{"CBYC", 4, 183394},
	{"APIW", 4, 183395},
	{"CAVUTO", 6, 183396},
	{"SOCIALITES", 10, 183397},
	{"NONSUCH", 7, 183398},
	{"CLINGY", 6, 183399},
	{"BLUSHER", 7, 183400},
	{"SCHIFRIN", 8, 183401},
	{"KYLES", 5, 183402},
	{"MARANT", 6, 183403},
	{"SALCEDO", 7, 183404},
	{"DYSPHORIC", 9, 183405},
	{"FNAC", 4, 183406},
	{"KATELLA", 7, 183407},
	{"INDEPENDANTLY", 13, 183408},
	{"BRUK", 4, 183409},
	{"IFILE", 5, 183410},
	{"ORMS", 4, 183411},
	{"WHEATS", 6, 183412},
	{"VTKOBJECTBASE", 13, 183413},
	{"HOARSELY", 8, 183414},
	{"FUMIGANT", 8, 183415},
	{"MARISKA", 7, 183416},
	{"BONHOMME", 8, 183417},
	{"PROMARK", 7, 183418},
	{"PICTRES", 7, 183419},
	{"OPPURTUNITIES", 13, 183420},
	{"CHIKA", 5, 183421},
	{"BUIE", 4, 183422},
	{"PROSOCIAL", 9, 183423},
	{"MORANT", 6, 183424},
	{"IGLS", 4, 183425},
	{"HELLENISM", 9, 183426},
	{"EGGSHELLS", 9, 183427},
	{"LLANGEFNI", 9, 183428},
	{"IMPA", 4, 183429},
	{"FCK", 3, 183430},
	{"BEKAERT", 7, 183431},
	{"OBJECTIFICATION", 15, 183432},
	{"MEDITERRANEA", 12, 183433},
	{"INTOWN", 6, 183434},
	{"NOWPUBLIC", 9, 183435},
	{"MARGENTA", 8, 183436},
	{"STATECRAFT", 10, 183437},
	{"KIYA", 4, 183438},
	{"SHITING", 7, 183439},
	{"WOODMONT", 8, 183440},
	{"REEM", 4, 183441},
	{"CROTHERS", 8, 183442},
	{"LIGHTCURVE", 10, 183443},
	{"REVTEX", 6, 183444},
	{"URBANMALL", 9, 183445},
	{"SYNTHETICALLY", 13, 183446},
	{"PARKWAYS", 8, 183447},
	{"MALVINA", 7, 183448},
	{"COGNIGEN", 8, 183449},
	{"FLUORESCENS", 11, 183450},
	{"BERLING", 7, 183451},
	{"XECUTER", 7, 183452},
	{"REIMAN", 6, 183453},
	{"PWAT", 4, 183454},
	{"POSESSION", 9, 183455},
	{"AFER", 4, 183456},
	{"MASHAD", 6, 183457},
	{"KUVASZ", 6, 183458},
	{"FALLINGWATER", 12, 183459},
	{"MEDPUNDIT", 9, 183460},
	{"CAPN", 4, 183461},
	{"THUMBSCREWS", 11, 183462},
	{"STANDARDBRED", 12, 183463},
	{"PANEER", 6, 183464},
	{"BULLDOZING", 10, 183465},
	{"TRACH", 5, 183466},
	{"WOOZY", 5, 183467},
	{"UNDERCROFT", 10, 183468},
	{"SYNAESTHESIA", 12, 183469},
	{"WDNR", 4, 183470},
	{"ECKARD", 6, 183471},
	{"CONTIGO", 7, 183472},
	{"GFAP", 4, 183473},
	{"STCC", 4, 183474},
	{"PANGBOURNE", 10, 183475},
	{"FAMILIEN", 8, 183476},
	{"CRAIS", 5, 183477},
	{"RHODOS", 6, 183478},
	{"POWAKADDY", 9, 183479},
	{"PCCHIPS", 7, 183480},
	{"KALLEN", 6, 183481},
	{"KOSCIUSZKO", 10, 183482},
	{"NATIONAUX", 9, 183483},
	{"VORHERIGE", 9, 183484},
	{"SKILES", 6, 183485},
	{"PLETCHER", 8, 183486},
	{"KEANEY", 6, 183487},
	{"YTUI", 4, 183488},
	{"YLOL", 4, 183489},
	{"UVOL", 4, 183490},
	{"UKMI", 4, 183491},
	{"UKAG", 4, 183492},
	{"SYSW", 4, 183493},
	{"SVAP", 4, 183494},
	{"PPBE", 4, 183495},
	{"PIBE", 4, 183496},
	{"OXGE", 4, 183497},
	{"LLUB", 4, 183498},
	{"IXDU", 4, 183499},
	{"IBSC", 4, 183500},
	{"HIYU", 4, 183501},
	{"HABW", 4, 183502},
	{"FSRO", 4, 183503},
	{"EDFS", 4, 183504},
	{"CBSM", 4, 183505},
	{"AVOM", 4, 183506},
	{"NAUSEAM", 7, 183507},
	{"LANGILLE", 8, 183508},
	{"MPEGTV", 6, 183509},
	{"AKTIONEN", 8, 183510},
	{"ANDROMACHE", 10, 183511},
	{"PROPIA", 6, 183512},
	{"BARCELONE", 9, 183513},
	{"FIORINAL", 8, 183514},
	{"BROWNSBORO", 10, 183515},
	{"TERRANE", 7, 183516},
	{"CENTLY", 6, 183517},
	{"INNLINK", 7, 183518},
	{"PATTINSON", 9, 183519},
	{"FISHINGMAGIC", 12, 183520},
	{"APARNA", 6, 183521},
	{"NOINDENT", 8, 183522},
	{"EARTHSAVE", 9, 183523},
	{"TAGNET", 6, 183524},
	{"RIBCAGE", 7, 183525},
	{"FLOUT", 5, 183526},
	{"DACULA", 6, 183527},
	{"YORU", 4, 183528},
	{"FATTI", 5, 183529},
	{"DASILVA", 7, 183530},
	{"CKHH", 4, 183531},
	{"MANDAR", 6, 183532},
	{"COGNITIONS", 10, 183533},
	{"QUOTOF", 6, 183534},
	{"STUDIOUSLY", 10, 183535},
	{"BORMIO", 6, 183536},
	{"VIBERT", 6, 183537},
	{"KABOB", 5, 183538},
	{"DOWNLOADD", 9, 183539},
	{"DEFEATIST", 9, 183540},
	{"CROSSBRED", 9, 183541},
	{"BODYCRAFT", 9, 183542},
	{"HOFFMEISTER", 11, 183543},
	{"FCPS", 4, 183544},
	{"PAWE", 4, 183545},
	{"ENCINA", 6, 183546},
	{"BURGES", 6, 183547},
	{"REVELED", 7, 183548},
	{"DODECAHEDRON", 12, 183549},
	{"GREBES", 6, 183550},
	{"MOQTADA", 7, 183551},
	{"HADAD", 5, 183552},
	{"CYFLEOEDD", 9, 183553},
	{"WHEATBELT", 9, 183554},
	{"AYDEN", 5, 183555},
	{"MADEA", 5, 183556},
	{"DYLAI", 5, 183557},
	{"COLLOQUIALLY", 12, 183558},
	{"LAMARCHE", 8, 183559},
	{"SUBLICENSEES", 12, 183560},
	{"UNINFORMATIVE", 13, 183561},
	{"RIVERBELLE", 10, 183562},
	{"LEZLEY", 6, 183563},
	{"FUNTION", 7, 183564},
	{"SWEDESBORO", 10, 183565},
	{"ICOMOS", 6, 183566},
	{"PROHORMONES", 11, 183567},
	{"SUNDRIED", 8, 183568},
	{"DETECTABILITY", 13, 183569},
	{"PESKIN", 6, 183570},
	{"PRIMAX", 6, 183571},
	{"LECK", 4, 183572},
	{"MISCONFIGURED", 13, 183573},
	{"FONZ", 4, 183574},
	{"CONFOUNDS", 9, 183575},
	{"LIPARI", 6, 183576},
	{"DYNACORD", 8, 183577},
	{"ORDERSTATUS", 11, 183578},
	{"LAIRS", 5, 183579},
	{"STANDAARD", 9, 183580},
	{"KASANE", 6, 183581},
	{"BIONUTRITIONAL", 14, 183582},
	{"VATED", 5, 183583},
	{"SANCHAR", 7, 183584},
	{"HOSTNUKE", 8, 183585},
	{"MAGMATISM", 9, 183586},
	{"BIOREACTORS", 11, 183587},
	{"ARNAZ", 5, 183588},
	{"SERIGRAPHS", 10, 183589},
	{"WATCHUNG", 8, 183590},
	{"PDVSA", 5, 183591},
	{"MUSCHIES", 8, 183592},
	{"BAILA", 5, 183593},
	{"ATHEY", 5, 183594},
	{"REGIONALISATION", 15, 183595},
	{"WENDE", 5, 183596},
	{"COWPARADE", 9, 183597},
	{"POWERCORE", 9, 183598},
	{"LALITA", 6, 183599},
	{"STARPHOENIX", 11, 183600},
	{"MUHSIN", 6, 183601},
	{"ZZYW", 4, 183602},
	{"YTHD", 4, 183603},
	{"YIRV", 4, 183604},
	{"XSID", 4, 183605},
	{"WVET", 4, 183606},
	{"TTFL", 4, 183607},
	{"TSCD", 4, 183608},
	{"THGY", 4, 183609},
	{"SBEK", 4, 183610},
	{"PLYY", 4, 183611},
	{"OMND", 4, 183612},
	{"OIBL", 4, 183613},
	{"NYUE", 4, 183614},
	{"NEKW", 4, 183615},
	{"MMSW", 4, 183616},
	{"KITK", 4, 183617},
	{"ICIG", 4, 183618},
	{"GNUD", 4, 183619},
	{"FOMI", 4, 183620},
	{"FIAD", 4, 183621},
	{"FFYR", 4, 183622},
	{"ENYG", 4, 183623},
	{"EFGA", 4, 183624},
	{"DEML", 4, 183625},
	{"CHSJ", 4, 183626},
	{"ASJR", 4, 183627},
	{"RESURFACES", 10, 183628},
	{"TRAVELLODGE", 11, 183629},
	{"AMMANN", 6, 183630},
	{"VOLENDAM", 8, 183631},
	{"MESOWEST", 8, 183632},
	{"DISSCUSSION", 11, 183633},
	{"LEIERKASTEN", 11, 183634},
	{"SWINDELL", 8, 183635},
	{"PUBLICIS", 8, 183636},
	{"BRANDNAMES", 10, 183637},
	{"SHERRATT", 8, 183638},
	{"KEEPALL", 7, 183639},
	{"BEETON", 6, 183640},
	{"CONCIERTOS", 10, 183641},
	{"GADO", 4, 183642},
	{"MUNDEN", 6, 183643},
	{"ASMLINKAGE", 10, 183644},
	{"REALPRODUCER", 12, 183645},
	{"NONMETRO", 8, 183646},
	{"MEARES", 6, 183647},
	{"MAXSON", 6, 183648},
	{"KNAPWEED", 8, 183649},
	{"SAHIL", 5, 183650},
	{"MATEN", 5, 183651},
	{"MACROPHYTES", 11, 183652},
	{"VILJOEN", 7, 183653},
	{"DARTINGTON", 10, 183654},
	{"LIETUVIU", 8, 183655},
	{"VDW", 3, 183656},
	{"SALTMAN", 7, 183657},
	{"CIRISME", 7, 183658},
	{"TURISTICHE", 10, 183659},
	{"ASSUNTO", 7, 183660},
	{"PROE", 4, 183661},
	{"PITIABLE", 8, 183662},
	{"FERENGI", 7, 183663},
	{"MENORAHS", 8, 183664},
	{"KONTAKTMARKT", 12, 183665},
	{"HYLA", 4, 183666},
	{"MILLIPEDE", 9, 183667},
	{"GRILLER", 7, 183668},
	{"QUOTBOYFRIENDQUOT", 17, 183669},
	{"HOMERUNS", 8, 183670},
	{"GLPK", 4, 183671},
	{"ROXANNA", 7, 183672},
	{"RESIDENZ", 8, 183673},
	{"PLAINWELL", 9, 183674},
	{"FERRITES", 8, 183675},
	{"GASTRONOMIE", 11, 183676},
	{"SUMMERHOUSES", 12, 183677},
	{"FETED", 5, 183678},
	{"SANDSTROM", 9, 183679},
	{"NETSTUMBLER", 11, 183680},
	{"DATIONS", 7, 183681},
	{"GABBRO", 6, 183682},
	{"OVERY", 5, 183683},
	{"NEWITTS", 7, 183684},
	{"BETRAYERS", 9, 183685},
	{"SILVERSPECK", 11, 183686},
	{"BUDLEIGH", 8, 183687},
	{"URING", 5, 183688},
	{"COILOVER", 8, 183689},
	{"HAIRPIECE", 9, 183690},
	{"NECKBAND", 8, 183691},
	{"LEGLESS", 7, 183692},
	{"FORU", 4, 183693},
	{"LUNDE", 5, 183694},
	{"MPERIA", 6, 183695},
	{"NGAYON", 6, 183696},
	{"CORRALEJO", 9, 183697},
	{"SCHOLTEN", 8, 183698},
	{"ECTED", 5, 183699},
	{"IMPLODED", 8, 183700},
	{"COUNTRIE", 8, 183701},
	{"VIOUSLY", 7, 183702},
	{"KITAKYUSHU", 10, 183703},
	{"SUBMANIFOLD", 11, 183704},
	{"FINNMARK", 8, 183705},
	{"APPLEBEES", 9, 183706},
	{"LITTERMAID", 10, 183707},
	{"FAUNE", 5, 183708},
	{"BIRRELL", 7, 183709},
	{"RESULTATS", 9, 183710},
	{"REITERATION", 11, 183711},
	{"OCBC", 4, 183712},
	{"PLAQUEMINE", 10, 183713},
	{"JDSU", 4, 183714},
	{"SYMBOLE", 7, 183715},
	{"MOUNTFORD", 9, 183716},
	{"BPU", 3, 183717},
	{"UNREVIEWED", 10, 183718},
	{"KALAN", 5, 183719},
	{"VLIE", 4, 183720},
	{"UZZF", 4, 183721},
	{"UTSV", 4, 183722},
	{"TKOP", 4, 183723},
	{"SKFI", 4, 183724},
	{"SFAY", 4, 183725},
	{"SEUC", 4, 183726},
	{"RKSQ", 4, 183727},
	{"RDMR", 4, 183728},
	{"PWIR", 4, 183729},
	{"PUDG", 4, 183730},
	{"PIGW", 4, 183731},
	{"OVLI", 4, 183732},
	{"NAYW", 4, 183733},
	{"MLDO", 4, 183734},
	{"LSTF", 4, 183735},
	{"LPAA", 4, 183736},
	{"LLCD", 4, 183737},
	{"KSYN", 4, 183738},
	{"ITMD", 4, 183739},
	{"HRHY", 4, 183740},
	{"HEKF", 4, 183741},
	{"FDEW", 4, 183742},
	{"ETMB", 4, 183743},
	{"EBPS", 4, 183744},
	{"DPWI", 4, 183745},
	{"CCOG", 4, 183746},
	{"ALBB", 4, 183747},
	{"MORTICE", 7, 183748},
	{"NZHERALD", 8, 183749},
	{"LIETUVA", 7, 183750},
	{"VISANT", 6, 183751},
	{"GUREVICH", 8, 183752},
	{"ALERTE", 6, 183753},
	{"VAPORIZE", 8, 183754},
	{"DIISOCYANATE", 12, 183755},
	{"ALIMENTS", 8, 183756},
	{"TRAMORE", 7, 183757},
	{"KNOOP", 5, 183758},
	{"INSURANCEWIDE", 13, 183759},
	{"KILMARTIN", 9, 183760},
	{"CORSAIRS", 8, 183761},
	{"CHROMOPHORE", 11, 183762},
	{"STUTTERED", 9, 183763},
	{"SICKELS", 7, 183764},
	{"MAGICISO", 8, 183765},
	{"FOOTBEDS", 8, 183766},
	{"REMS", 4, 183767},
	{"DUGWAY", 6, 183768},
	{"ANOOP", 5, 183769},
	{"CHOLANGITIS", 11, 183770},
	{"INTROD", 6, 183771},
	{"VERBEEK", 7, 183772},
	{"REIFF", 5, 183773},
	{"INDISCREET", 10, 183774},
	{"SHOELACE", 8, 183775},
	{"NAMAH", 5, 183776},
	{"FONTHAUS", 8, 183777},
	{"BICKLE", 6, 183778},
	{"BELLOC", 6, 183779},
	{"DUELLING", 8, 183780},
	{"BAIK", 4, 183781},
	{"PLAX", 4, 183782},
	{"TWRA", 4, 183783},
	{"SHOWTUNES", 9, 183784},
	{"PEDANTRY", 8, 183785},
	{"BRONCHOSPASM", 12, 183786},
	{"BOSCASTLE", 9, 183787},
	{"BACC", 4, 183788},
	{"ALVERNO", 7, 183789},
	{"SANTAYANA", 9, 183790},
	{"LUMS", 4, 183791},
	{"STARMAKER", 9, 183792},
	{"HOTMALI", 7, 183793},
	{"BOLDCHATPLUS", 12, 183794},
	{"SPORTO", 6, 183795},
	{"RAMESSES", 8, 183796},
	{"LUGGED", 6, 183797},
	{"BITMASK", 7, 183798},
	{"SINDEE", 6, 183799},
	{"VALARIE", 7, 183800},
	{"SCARAMOUCHE", 11, 183801},
	{"DEADLANDS", 9, 183802},
	{"RETINAS", 7, 183803},
	{"KOHM", 4, 183804},
	{"MAXTON", 6, 183805},
	{"DEBILITATED", 11, 183806},
	{"CLARIA", 6, 183807},
	{"ROOTBEER", 8, 183808},
	{"WORLDMARK", 9, 183809},
	{"UPSR", 4, 183810},
	{"MANGERE", 7, 183811},
	{"MYDVD", 5, 183812},
	{"LAUS", 4, 183813},
	{"LACHMAN", 7, 183814},
	{"DIZZLE", 6, 183815},
	{"MOTONEURONS", 11, 183816},
	{"PHILANTHROPIES", 14, 183817},
	{"MARINATING", 10, 183818},
	{"DUQUETTE", 8, 183819},
	{"NAVES", 5, 183820},
	{"BANCAIRE", 8, 183821},
	{"ZELIG", 5, 183822},
	{"TIPPEE", 6, 183823},
	{"QUADRIPLEGIA", 12, 183824},
	{"WEBWARPER", 9, 183825},
	{"UNDERREPORTING", 14, 183826},
	{"UNOBTAINABLE", 12, 183827},
	{"RUSSELLS", 8, 183828},
	{"MARJ", 4, 183829},
	{"ALIF", 4, 183830},
	{"JONKER", 6, 183831},
	{"IMAGIC", 6, 183832},
	{"ASKPASS", 7, 183833},
	{"MAZAK", 5, 183834},
	{"CAJAS", 5, 183835},
	{"SEEMLESS", 8, 183836},
	{"REACTIONARIES", 13, 183837},
	{"FRUITYLOOPS", 11, 183838},
	{"BLAZON", 6, 183839},
	{"RSLOGIX", 7, 183840},
	{"HERBA", 5, 183841},
	{"CHEIF", 5, 183842},
	{"ZPIA", 4, 183843},
	{"ZASK", 4, 183844},
	{"WSSY", 4, 183845},
	{"WDLE", 4, 183846},
	{"UFCA", 4, 183847},
	{"TYUA", 4, 183848},
	{"TUWH", 4, 183849},
	{"RVIP", 4, 183850},
	{"RKIO", 4, 183851},
	{"RGAE", 4, 183852},
	{"PIOC", 4, 183853},
	{"PFIF", 4, 183854},
	{"OUKS", 4, 183855},
	{"OBYK", 4, 183856},
	{"NIDY", 4, 183857},
	{"NGDH", 4, 183858},
	{"NAGM", 4, 183859},
	{"MTHC", 4, 183860},
	{"MSUA", 4, 183861},
	{"MRIP", 4, 183862},
	{"LWIE", 4, 183863},
	{"LUNB", 4, 183864},
	{"KOSR", 4, 183865},
	{"IFAK", 4, 183866},
	{"FZOR", 4, 183867},
	{"FBYW", 4, 183868},
	{"DOCB", 4, 183869},
	{"DMOF", 4, 183870},
	{"DJAU", 4, 183871},
	{"COOG", 4, 183872},
	{"CEYM", 4, 183873},
	{"BHOJ", 4, 183874},
	{"AEBY", 4, 183875},
	{"IMPLIEDLY", 9, 183876},
	{"UNSHARP", 7, 183877},
	{"CONSETETUR", 10, 183878},
	{"BACKDATED", 9, 183879},
	{"TRABALHOS", 9, 183880},
	{"TICIPANTS", 9, 183881},
	{"GEOMETRICS", 10, 183882},
	{"COMPLEXE", 8, 183883},
	{"MICROPROSE", 10, 183884},
	{"DONAGHY", 7, 183885},
	{"GARS", 4, 183886},
	{"CORRINA", 7, 183887},
	{"LAIDLEY", 7, 183888},
	{"IPRINT", 6, 183889},
	{"SITEFINDER", 10, 183890},
	{"BEATNUTS", 8, 183891},
	{"PRAN", 4, 183892},
	{"HEWES", 5, 183893},
	{"NETBEUI", 7, 183894},
	{"MAXIMILLIAN", 11, 183895},
	{"AIRCOOLED", 9, 183896},
	{"CHRISBREEN", 10, 183897},
	{"PASTORALE", 9, 183898},
	{"RESETTLE", 8, 183899},
	{"HELIPAD", 7, 183900},
	{"AURO", 4, 183901},
	{"SOLUTIA", 7, 183902},
	{"ECALLCHINA", 10, 183903},
	{"TERMINED", 8, 183904},
	{"RUTKOWSKI", 9, 183905},
	{"IMPACTION", 9, 183906},
	{"IMAGESHACK", 10, 183907},
	{"SMILER", 6, 183908},
	{"IPOX", 4, 183909},
	{"BACKPROPAGATION", 15, 183910},
	{"ZAPATOS", 7, 183911},
	{"LASKO", 5, 183912},
	{"KONICAMINOLTA", 13, 183913},
	{"WHSMITHS", 8, 183914},
	{"LOOSENESS", 9, 183915},
	{"JEWELRIES", 9, 183916},
	{"VELG", 4, 183917},
	{"HREOC", 5, 183918},
	{"IDRIVE", 6, 183919},
	{"APPENDECTOMY", 12, 183920},
	{"VOLUMIZING", 10, 183921},
	{"CANBE", 5, 183922},
	{"LAMOTTE", 7, 183923},
	{"BIRGITTA", 8, 183924},
	{"SERVERAL", 8, 183925},
	{"NEGLECTFUL", 10, 183926},
	{"LEPTOSPIRA", 10, 183927},
	{"ACBEE", 5, 183928},
	{"DVDPLANET", 9, 183929},
	{"YAHOOCOM", 8, 183930},
	{"MELK", 4, 183931},
	{"SUBNETTING", 10, 183932},
	{"NEWPAPER", 8, 183933},
	{"ACETAZOLAMIDE", 13, 183934},
	{"KENKYU", 6, 183935},
	{"QAPP", 4, 183936},
	{"MARTIUS", 7, 183937},
	{"HPIJS", 5, 183938},
	{"BRASCO", 6, 183939},
	{"RADIOED", 7, 183940},
	{"CETUS", 5, 183941},
	{"REVERSIBLY", 10, 183942},
	{"PHENTERINE", 10, 183943},
	{"LISHING", 7, 183944},
	{"HASSON", 6, 183945},
	{"CORINE", 6, 183946},
	{"BILK", 4, 183947},
	{"DIGIMAC", 7, 183948},
	{"SWAGELOK", 8, 183949},
	{"GAMLA", 5, 183950},
	{"MARPOL", 6, 183951},
	{"BITSET", 6, 183952},
	{"JAHOO", 5, 183953},
	{"ARCHINECT", 9, 183954},
	{"ADAC", 4, 183955},
	{"SPORANOX", 8, 183956},
	{"DEMENTIAS", 9, 183957},
	{"SAWASDEE", 8, 183958},
	{"KXAN", 4, 183959},
	{"SOURCEOECD", 10, 183960},
	{"PILLAGED", 8, 183961},
	{"MEMORIALIZED", 12, 183962},
	{"FINCK", 5, 183963},
	{"ZEILE", 5, 183964},
	{"VOCES", 5, 183965},
	{"RIKSBANK", 8, 183966},
	{"PROEDRO", 7, 183967},
	{"YPEK", 4, 183968},
	{"YNCT", 4, 183969},
	{"YLAE", 4, 183970},
	{"YKSA", 4, 183971},
	{"YEVW", 4, 183972},
	{"YDBR", 4, 183973},
	{"WWGO", 4, 183974},
	{"UZWA", 4, 183975},
	{"UYMY", 4, 183976},
	{"STMM", 4, 183977},
	{"SMUK", 4, 183978},
	{"SGAF", 4, 183979},
	{"RNYC", 4, 183980},
	{"RLGO", 4, 183981},
	{"PHAY", 4, 183982},
	{"OOPG", 4, 183983},
	{"OJCI", 4, 183984},
	{"OFDB", 4, 183985},
	{"NDJS", 4, 183986},
	{"MUKU", 4, 183987},
	{"MRAA", 4, 183988},
	{"KOUZ", 4, 183989},
	{"KMMA", 4, 183990},
	{"JAHM", 4, 183991},
	{"IMMR", 4, 183992},
	{"HRCA", 4, 183993},
	{"GKUN", 4, 183994},
	{"FWAX", 4, 183995},
	{"ESGC", 4, 183996},
	{"DILT", 4, 183997},
	{"CCEM", 4, 183998},
	{"APUF", 4, 183999},
	{"AKUE", 4, 184000},
	{"AGSG", 4, 184001},
	{"BROMUS", 6, 184002},
	{"ADRENALS", 8, 184003},
	{"YULEE", 5, 184004},
	{"CHAG", 4, 184005},
	{"STRATFOR", 8, 184006},
	{"HOOFT", 5, 184007},
	{"DEMDACO", 7, 184008},
	{"WANSBECK", 8, 184009},
	{"VISABLE", 7, 184010},
	{"SUNSCAPE", 8, 184011},
	{"RAHTZ", 5, 184012},
	{"ZAVENTEM", 8, 184013},
	{"RESEARCHBUZZ", 12, 184014},
	{"REASONINGS", 10, 184015},
	{"DENOTATIONAL", 12, 184016},
	{"ARNOLDO", 7, 184017},
	{"DODDRIDGE", 9, 184018},
	{"MARLEAU", 7, 184019},
	{"DRAWBAR", 7, 184020},
	{"AUMANN", 6, 184021},
	{"WEBVIEWER", 9, 184022},
	{"PRONSTARS", 9, 184023},
	{"CCSR", 4, 184024},
	{"CHALKING", 8, 184025},
	{"CANARIO", 7, 184026},
	{"WITKIN", 6, 184027},
	{"SUMEA", 5, 184028},
	{"VESTIDO", 7, 184029},
	{"FIREBIRDS", 9, 184030},
	{"EPAC", 4, 184031},
	{"TELEVISE", 8, 184032},
	{"SPEECHWRITER", 12, 184033},
	{"BECKUM", 6, 184034},
	{"ALIQUYAM", 8, 184035},
	{"APPORTIONMENTS", 14, 184036},
	{"NOCERA", 6, 184037},
	{"HEMIPLEGIA", 10, 184038},
	{"UUC", 3, 184039},
	{"DYSPRAXIA", 9, 184040},
	{"FSLUG", 5, 184041},
	{"ADAUGA", 6, 184042},
	{"GUIMARAES", 9, 184043},
	{"AGARICUS", 8, 184044},
	{"VORONIN", 7, 184045},
	{"RANGANATHAN", 11, 184046},
	{"INDIALANTIC", 11, 184047},
	{"HOMINIS", 7, 184048},
	{"AGATHE", 6, 184049},
	{"CONTRAVENTIONS", 14, 184050},
	{"GLORFINDEL", 10, 184051},
	{"COULTERVILLE", 12, 184052},
	{"WEIERSTRASS", 11, 184053},
	{"ILLIAM", 6, 184054},
	{"PATRY", 5, 184055},
	{"CONNECTGEAR", 11, 184056},
	{"CLOSEDIR", 8, 184057},
	{"COMIXPEDIA", 10, 184058},
	{"JAMAICANS", 9, 184059},
	{"PANICLE", 7, 184060},
	{"ENFACE", 6, 184061},
	{"YAHOOTRAVEL", 11, 184062},
	{"SUBSIDIZES", 10, 184063},
	{"MOUT", 4, 184064},
	{"LIBWNCK", 7, 184065},
	{"NIEMAND", 7, 184066},
	{"WEDEL", 5, 184067},
	{"TELIC", 5, 184068},
	{"CLARUS", 6, 184069},
	{"SUSHIL", 6, 184070},
	{"ELIDA", 5, 184071},
	{"CEMA", 4, 184072},
	{"OLOTELS", 7, 184073},
	{"PROCHLOROCOCCUS", 15, 184074},
	{"COLBEE", 6, 184075},
	{"KONZERT", 7, 184076},
	{"GREYFRIARS", 10, 184077},
	{"FIRETRUCK", 9, 184078},
	{"UMPTEENTH", 9, 184079},
	{"MEETINGHOUSE", 12, 184080},
	{"CREWSAVER", 9, 184081},
	{"MARAD", 5, 184082},
	{"GOLDWASSER", 10, 184083},
	{"PUNTED", 6, 184084},
	{"SPAMFIGHTER", 11, 184085},
	{"FUNCIONAMIENTO", 14, 184086},
	{"PARANASAL", 9, 184087},
	{"DSGN", 4, 184088},
	{"AZZURRA", 7, 184089},
	{"ZMOU", 4, 184090},
	{"WWNA", 4, 184091},
	{"WDHE", 4, 184092},
	{"VSBA", 4, 184093},
	{"TMDE", 4, 184094},
	{"TFOG", 4, 184095},
	{"TFEU", 4, 184096},
	{"SULC", 4, 184097},
	{"SPPI", 4, 184098},
	{"RRFO", 4, 184099},
	{"RNUD", 4, 184100},
	{"PUNN", 4, 184101},
	{"ORJR", 4, 184102},
	{"LAXC", 4, 184103},
	{"KULD", 4, 184104},
	{"KOWT", 4, 184105},
	{"HIVR", 4, 184106},
	{"HIBL", 4, 184107},
	{"HAKW", 4, 184108},
	{"GPUZ", 4, 184109},
	{"GLUX", 4, 184110},
	{"FCCI", 4, 184111},
	{"EPWR", 4, 184112},
	{"ECCF", 4, 184113},
	{"DMMO", 4, 184114},
	{"BYAZ", 4, 184115},
	{"BBYV", 4, 184116},
	{"ARRM", 4, 184117},
	{"WORTHILY", 8, 184118},
	{"ROTELLA", 7, 184119},
	{"OUTSHOT", 7, 184120},
	{"ATHLETICALLY", 12, 184121},
	{"PALMISANO", 9, 184122},
	{"RODDA", 5, 184123},
	{"INTERACTIVIST", 13, 184124},
	{"BADBOY", 6, 184125},
	{"PROBENECID", 10, 184126},
	{"ASSAYING", 8, 184127},
	{"HERTSMERE", 9, 184128},
	{"GAMESERVER", 10, 184129},
	{"OEHLBACH", 8, 184130},
	{"SEPTET", 6, 184131},
	{"GOOFBALL", 8, 184132},
	{"EHLERT", 6, 184133},
	{"REVERSO", 7, 184134},
	{"CSICOP", 6, 184135},
	{"CARPOOLS", 8, 184136},
	{"PASSY", 5, 184137},
	{"HANNER", 6, 184138},
	{"VERFAHREN", 9, 184139},
	{"REPLICANT", 9, 184140},
	{"KNICKER", 7, 184141},
	{"BANDHAVGARH", 11, 184142},
	{"CHLO", 4, 184143},
	{"INSOMUCH", 8, 184144},
	{"EXPENSIVELY", 11, 184145},
	{"ANNEKE", 6, 184146},
	{"SALIVATION", 10, 184147},
	{"GIBRALTER", 9, 184148},
	{"PTAC", 4, 184149},
	{"MSID", 4, 184150},
	{"DRUCE", 5, 184151},
	{"SHAMWARI", 8, 184152},
	{"CCPD", 4, 184153},
	{"BURCHILL", 8, 184154},
	{"MACROMOLECULE", 13, 184155},
	{"EROCAM", 6, 184156},
	{"BECKERMAN", 9, 184157},
	{"MESENCHYME", 10, 184158},
	{"LIFECIRCLE", 10, 184159},
	{"KHALILZAD", 9, 184160},
	{"MICROPLANE", 10, 184161},
	{"ONLINES", 7, 184162},
	{"INTERCALATED", 12, 184163},
	{"FASTFAME", 8, 184164},
	{"MORINDA", 7, 184165},
	{"XCF", 3, 184166},
	{"MULTICULTURALIST", 16, 184167},
	{"CRADA", 5, 184168},
	{"BMU", 3, 184169},
	{"REDDRAGONLADY", 13, 184170},
	{"AMAYAUSERS", 10, 184171},
	{"XPOSED", 6, 184172},
	{"PRALINES", 8, 184173},
	{"MOTLE", 5, 184174},
	{"AXWORTHY", 8, 184175},
	{"YANUK", 5, 184176},
	{"SUPPLEX", 7, 184177},
	{"SCRUPLE", 7, 184178},
	{"FABA", 4, 184179},
	{"KRONECKER", 9, 184180},
	{"ASCONA", 6, 184181},
	{"SCOM", 4, 184182},
	{"SWAINSBORO", 10, 184183},
	{"FEXCEPTIONS", 11, 184184},
	{"UNCHARGED", 9, 184185},
	{"NEUROTOXINS", 11, 184186},
	{"LANGRIDGE", 9, 184187},
	{"YAKTRAX", 7, 184188},
	{"NAKEDWOMAN", 10, 184189},
	{"LPGS", 4, 184190},
	{"TUNNELL", 7, 184191},
	{"IFEQ", 4, 184192},
	{"HANKINSON", 9, 184193},
	{"HAMMURABI", 9, 184194},
	{"WORKMATES", 9, 184195},
	{"TECHOLOGY", 9, 184196},
	{"STEADIED", 8, 184197},
	{"ORMONDE", 7, 184198},
	{"GEORGIOU", 8, 184199},
	{"BRIBIE", 6, 184200},
	{"APPELS", 6, 184201},
	{"REALIZZAZIONE", 13, 184202},
	{"MCCOURY", 7, 184203},
	{"BOOZY", 5, 184204},
	{"USACOPS", 7, 184205},
	{"PHOTOPRODUCTION", 15, 184206},
	{"DEVELOPERSDEX", 13, 184207},
	{"PANRIX", 6, 184208},
	{"PETERLEE", 8, 184209},
	{"HORSEBIT", 8, 184210},
	{"NIPLE", 5, 184211},
	{"DRCNET", 6, 184212},
	{"TUSSAUD", 7, 184213},
	{"UNHERALDED", 10, 184214},
	{"COGNEX", 6, 184215},
	{"ASYM", 4, 184216},
	{"MATERIALISED", 12, 184217},
	{"CURNOW", 6, 184218},
	{"IMPOSTO", 7, 184219},
	{"COOLIE", 6, 184220},
	{"ORDEALS", 7, 184221},
	{"KOTAK", 5, 184222},
	{"DELLER", 6, 184223},
	{"DBPOWERAMP", 10, 184224},
	{"BVD", 3, 184225},
	{"MINERALOGIST", 12, 184226},
	{"HONEYED", 7, 184227},
	{"ZHIM", 4, 184228},
	{"YUUS", 4, 184229},
	{"XPOP", 4, 184230},
	{"WMYC", 4, 184231},
	{"VOYF", 4, 184232},
	{"TCYS", 4, 184233},
	{"SDLI", 4, 184234},
	{"RJAT", 4, 184235},
	{"RGCL", 4, 184236},
	{"QDOE", 4, 184237},
	{"PEZF", 4, 184238},
	{"OXSW", 4, 184239},
	{"OVBR", 4, 184240},
	{"OSMY", 4, 184241},
	{"ONRB", 4, 184242},
	{"OEDF", 4, 184243},
	{"MBSQ", 4, 184244},
	{"JLEA", 4, 184245},
	{"GUTL", 4, 184246},
	{"GSLT", 4, 184247},
	{"FYGR", 4, 184248},
	{"ENYD", 4, 184249},
	{"EDVP", 4, 184250},
	{"DRKO", 4, 184251},
	{"CIEW", 4, 184252},
	{"AFEZ", 4, 184253},
	{"BISQUICK", 8, 184254},
	{"AUSTRONESIAN", 12, 184255},
	{"NETIZENS", 8, 184256},
	{"STACKTRACE", 10, 184257},
	{"TIQUE", 5, 184258},
	{"RECOILED", 8, 184259},
	{"ENTEROVIRUS", 11, 184260},
	{"TRIMESTERS", 10, 184261},
	{"VASCONCELOS", 11, 184262},
	{"PHARAONIC", 9, 184263},
	{"COMMUNALISM", 11, 184264},
	{"FRANKOMA", 8, 184265},
	{"ZYGMUNT", 7, 184266},
	{"OTMAIL", 6, 184267},
	{"COMPRENDRE", 10, 184268},
	{"KVK", 3, 184269},
	{"LAMBOURNE", 9, 184270},
	{"PANETTA", 7, 184271},
	{"FITNESSEQUIPMENT", 16, 184272},
	{"FARHAT", 6, 184273},
	{"BODDINGTON", 10, 184274},
	{"CANCELATION", 11, 184275},
	{"AOIFE", 5, 184276},
	{"PENTEX", 6, 184277},
	{"TASKLIST", 8, 184278},
	{"BENZOIN", 7, 184279},
	{"LAPB", 4, 184280},
	{"DISLIKING", 9, 184281},
	{"METTER", 6, 184282},
	{"LISTOWNERS", 10, 184283},
	{"BOERSMA", 7, 184284},
	{"JADETEX", 7, 184285},
	{"ETHICON", 7, 184286},
	{"SCHWAG", 6, 184287},
	{"HISTORISCHE", 11, 184288},
	{"SWFSHAPE", 8, 184289},
	{"CHARACTERIS", 11, 184290},
	{"KUTTNER", 7, 184291},
	{"KONFERENZ", 9, 184292},
	{"KAWAMOTO", 8, 184293},
	{"INTERRUPTER", 11, 184294},
	{"CONECTION", 9, 184295},
	{"HTMAIL", 6, 184296},
	{"FIBREBOARD", 10, 184297},
	{"REZENSIONEN", 11, 184298},
	{"VLUCHTEN", 8, 184299},
	{"PHYSICSWEB", 10, 184300},
	{"INFURIATE", 9, 184301},
	{"BASTARDLY", 9, 184302},
	{"HONCHOS", 7, 184303},
	{"HYDROGRAPHS", 11, 184304},
	{"GROMOV", 6, 184305},
	{"RDY", 3, 184306},
	{"HOTAIL", 6, 184307},
	{"ARMHOLES", 8, 184308},
	{"SCIFAN", 6, 184309},
	{"DILUTES", 7, 184310},
	{"URLTRENDS", 9, 184311},
	{"NAVIGAZIONE", 11, 184312},
	{"DIONYSOS", 8, 184313},
	{"BIOMOL", 6, 184314},
	{"STATMENTS", 9, 184315},
	{"KREPS", 5, 184316},
	{"SHAMA", 5, 184317},
	{"RACOR", 5, 184318},
	{"MYFIRSTPLUGIN", 13, 184319},
	{"CHINKS", 6, 184320},
	{"UNRIPE", 6, 184321},
	{"FEEDSTUFFS", 10, 184322},
	{"MONCEAU", 7, 184323},
	{"DAEJEON", 7, 184324},
	{"RELYON", 6, 184325},
	{"PMCS", 4, 184326},
	{"HYPERPIGMENTATION", 17, 184327},
	{"VORHERIGES", 10, 184328},
	{"TOFRANIL", 8, 184329},
	{"THROATY", 7, 184330},
	{"KOUNTRY", 7, 184331},
	{"CERTIF", 6, 184332},
	{"SHIPMATE", 8, 184333},
	{"PLOTINUS", 8, 184334},
	{"MANAGEM", 7, 184335},
	{"OCCLUSIONS", 10, 184336},
	{"MINIDISCS", 9, 184337},
	{"RADIOGRAPHER", 12, 184338},
	{"COMPARTMENTALIZATION", 20, 184339},
	{"ORATORIOS", 9, 184340},
	{"IMPLODING", 9, 184341},
	{"VIRIAL", 6, 184342},
	{"TIANNA", 6, 184343},
	{"CONVULSED", 9, 184344},
	{"FORSEE", 6, 184345},
	{"MENORES", 7, 184346},
	{"HEIMAN", 6, 184347},
	{"ORTHORHOMBIC", 12, 184348},
	{"KARD", 4, 184349},
	{"ZSDE", 4, 184350},
	{"ZIGO", 4, 184351},
	{"YSUZ", 4, 184352},
	{"YDEX", 4, 184353},
	{"WOSK", 4, 184354},
	{"UXCI", 4, 184355},
	{"TOLV", 4, 184356},
	{"SPYP", 4, 184357},
	{"SCLY", 4, 184358},
	{"RGFE", 4, 184359},
	{"PLCO", 4, 184360},
	{"OVBI", 4, 184361},
	{"NDTL", 4, 184362},
	{"MLIL", 4, 184363},
	{"LVEU", 4, 184364},
	{"LAXL", 4, 184365},
	{"KKIW", 4, 184366},
	{"KIRW", 4, 184367},
	{"HPOM", 4, 184368},
	{"HGOU", 4, 184369},
	{"GMSO", 4, 184370},
	{"DDTI", 4, 184371},
	{"DCFR", 4, 184372},
	{"BOSF", 4, 184373},
	{"ALNB", 4, 184374},
	{"POWERNOTE", 9, 184375},
	{"PILOCARPINE", 11, 184376},
	{"KRYTEN", 6, 184377},
	{"CARBIDES", 8, 184378},
	{"TSUKASA", 7, 184379},
	{"SORIES", 6, 184380},
	{"REACTIE", 7, 184381},
	{"SILVERSIDE", 10, 184382},
	{"GETTYS", 6, 184383},
	{"SCOURS", 6, 184384},
	{"MOONING", 7, 184385},
	{"KLOS", 4, 184386},
	{"ESOURCE", 7, 184387},
	{"BLOEDDRUK", 9, 184388},
	{"SPANNERCAMS", 11, 184389},
	{"RESETTABLE", 10, 184390},
	{"GWYDION", 7, 184391},
	{"ARTBOOK", 7, 184392},
	{"OUTRIGGERS", 10, 184393},
	{"DMAS", 4, 184394},
	{"WILENSKY", 8, 184395},
	{"BIGINTEGER", 10, 184396},
	{"BELSIZE", 7, 184397},
	{"DETECTIO", 8, 184398},
	{"CRYOPRESERVED", 13, 184399},
	{"GAMEWYRD", 8, 184400},
	{"HAENGETITTEN", 12, 184401},
	{"SECULARIST", 10, 184402},
	{"CRAIK", 5, 184403},
	{"UFW", 3, 184404},
	{"OSIJEK", 6, 184405},
	{"ERASTUS", 7, 184406},
	{"EDUCATIONCOLLEGES", 17, 184407},
	{"ADFA", 4, 184408},
	{"INQUIRYTRADE", 12, 184409},
	{"AGGRESIVE", 9, 184410},
	{"MARMON", 6, 184411},
	{"PENTACLES", 9, 184412},
	{"ALLGOOD", 7, 184413},
	{"ONSTREAM", 8, 184414},
	{"SKYSCAPE", 8, 184415},
	{"FAWLEY", 6, 184416},
	{"SEAGOING", 8, 184417},
	{"TENTANG", 7, 184418},
	{"SAKU", 4, 184419},
	{"NOTDEF", 6, 184420},
	{"CRISPNESS", 9, 184421},
	{"JORM", 4, 184422},
	{"MORING", 6, 184423},
	{"JEWISHNESS", 10, 184424},
	{"AIRBORN", 7, 184425},
	{"POLYMORPHA", 10, 184426},
	{"LENGTHENS", 9, 184427},
	{"FASTPASS", 8, 184428},
	{"DEFERMENTS", 10, 184429},
	{"CHUEN", 5, 184430},
	{"DHEKELIA", 8, 184431},
	{"PREDATING", 9, 184432},
	{"MCLACHLIN", 9, 184433},
	{"CLEANNESS", 9, 184434},
	{"VALIS", 5, 184435},
	{"UNMOLESTED", 10, 184436},
	{"HYPERTEC", 8, 184437},
	{"BYDGOSZCZ", 9, 184438},
	{"MAYTALS", 7, 184439},
	{"DXCC", 4, 184440},
	{"WERA", 4, 184441},
	{"RHDB", 4, 184442},
	{"SALECARES", 9, 184443},
	{"SOHAIL", 6, 184444},
	{"MICROWORKZ", 10, 184445},
	{"DIFFERANT", 9, 184446},
	{"INSISTENTLY", 11, 184447},
	{"UNCER", 5, 184448},
	{"DENSEST", 7, 184449},
	{"BUCKSPORT", 9, 184450},
	{"TITCHMARSH", 10, 184451},
	{"MORENCI", 7, 184452},
	{"PATCHETT", 8, 184453},
	{"BODYPAINT", 9, 184454},
	{"KITTED", 6, 184455},
	{"ENGLISHLANGUAGE", 15, 184456},
	{"PREFETCHABLE", 12, 184457},
	{"BROWNSON", 8, 184458},
	{"NATURTITTEN", 11, 184459},
	{"VANDERGRIFT", 11, 184460},
	{"TETRACHLOROETHYLENE", 19, 184461},
	{"MATTAWA", 7, 184462},
	{"WARRAGUL", 8, 184463},
	{"STITUTE", 7, 184464},
	{"HYPERDRIVE", 10, 184465},
	{"ADJOIN", 6, 184466},
	{"GBD", 3, 184467},
	{"TILINGS", 7, 184468},
	{"ALOUETTE", 8, 184469},
	{"UPANISHAD", 9, 184470},
	{"ANGULO", 6, 184471},
	{"CECS", 4, 184472},
	{"SONGZ", 5, 184473},
	{"YOGR", 4, 184474},
	{"XIPR", 4, 184475},
	{"WSCY", 4, 184476},
	{"UTRB", 4, 184477},
	{"ULGH", 4, 184478},
	{"TAXU", 4, 184479},
	{"SKYJ", 4, 184480},
	{"RVEK", 4, 184481},
	{"PPAV", 4, 184482},
	{"PIFH", 4, 184483},
	{"NSJR", 4, 184484},
	{"NEXW", 4, 184485},
	{"MPAV", 4, 184486},
	{"LAAV", 4, 184487},
	{"KBLE", 4, 184488},
	{"IMUC", 4, 184489},
	{"IICL", 4, 184490},
	{"HZWI", 4, 184491},
	{"GYAV", 4, 184492},
	{"GEBH", 4, 184493},
	{"FWIM", 4, 184494},
	{"DOLN", 4, 184495},
	{"DHRI", 4, 184496},
	{"DAIZ", 4, 184497},
	{"BDIE", 4, 184498},
	{"AUSV", 4, 184499},
	{"PRODUKTINFO", 11, 184500},
	{"AARGH", 5, 184501},
	{"TRADECRAFT", 10, 184502},
	{"HYDROXYMETHYL", 13, 184503},
	{"GAUMONT", 7, 184504},
	{"FORDING", 7, 184505},
	{"TECHSUPPORT", 11, 184506},
	{"MANJU", 5, 184507},
	{"STOWERS", 7, 184508},
	{"ECHEN", 5, 184509},
	{"NIRAJ", 5, 184510},
	{"BREGENZ", 7, 184511},
	{"WOUL", 4, 184512},
	{"RIBE", 4, 184513},
	{"PRETECH", 7, 184514},
	{"REICHARDT", 9, 184515},
	{"WBBM", 4, 184516},
	{"ETTING", 6, 184517},
	{"AUTOLEARN", 9, 184518},
	{"SONODE", 6, 184519},
	{"SILVERPLATTER", 13, 184520},
	{"ORCHIDACEAE", 11, 184521},
	{"DESTE", 5, 184522},
	{"LINU", 4, 184523},
	{"DISPERSANT", 10, 184524},
	{"ICALSHARE", 9, 184525},
	{"NIGHTVISION", 11, 184526},
	{"THERMAREST", 10, 184527},
	{"ANALENTJUNGFERUNG", 17, 184528},
	{"MURRELET", 8, 184529},
	{"SPRUILL", 7, 184530},
	{"KLETT", 5, 184531},
	{"SCHINDLERS", 10, 184532},
	{"PAPILIO", 7, 184533},
	{"RHEUMATOLOGIST", 14, 184534},
	{"SEMPERVIRENS", 12, 184535},
	{"LEPPER", 6, 184536},
	{"HEALTHCAST", 10, 184537},
	{"CRONIC", 6, 184538},
	{"KUNKLE", 6, 184539},
	{"IAUC", 4, 184540},
	{"GLASSINE", 8, 184541},
	{"NIKOLIC", 7, 184542},
	{"LINIE", 5, 184543},
	{"KEWPIE", 6, 184544},
	{"PROGNOSTICATIONS", 16, 184545},
	{"PHEDRE", 6, 184546},
	{"ROCKHOPPER", 10, 184547},
	{"OSMOLALITY", 10, 184548},
	{"AGNELLO", 7, 184549},
	{"MACRONUTRIENTS", 14, 184550},
	{"GELINAS", 7, 184551},
	{"NETPOND", 7, 184552},
	{"COSEWIC", 7, 184553},
	{"LYND", 4, 184554},
	{"MATURIN", 7, 184555},
	{"CARDC", 5, 184556},
	{"DOUGALL", 7, 184557},
	{"TELEGRAPHS", 10, 184558},
	{"CALDERONE", 9, 184559},
	{"LORIKEET", 8, 184560},
	{"KAFIR", 5, 184561},
	{"XERIC", 5, 184562},
	{"CHEMOATTRACTANT", 15, 184563},
	{"REALIGNING", 10, 184564},
	{"EMMER", 5, 184565},
	{"DESHMUKH", 8, 184566},
	{"MAKSUTOV", 8, 184567},
	{"JIGGLING", 8, 184568},
	{"ADLUT", 5, 184569},
	{"SEIDLER", 7, 184570},
	{"MOTUEKA", 7, 184571},
	{"GBK", 3, 184572},
	{"MIRRODIN", 8, 184573},
	{"ANNUEL", 6, 184574},
	{"SEEBURG", 7, 184575},
	{"SETTIMANA", 9, 184576},
	{"HOTMIL", 6, 184577},
	{"YELLOWLEGS", 10, 184578},
	{"KIRKBRIDE", 9, 184579},
	{"COVERTS", 7, 184580},
	{"TRANSGRESSORS", 13, 184581},
	{"REVEIWS", 7, 184582},
	{"DIYTOOLS", 8, 184583},
	{"AMANN", 5, 184584},
	{"KDEBINDINGS", 11, 184585},
	{"CONDITON", 8, 184586},
	{"BEREZOVSKY", 10, 184587},
	{"SEEKABLE", 8, 184588},
	{"OSMOSE", 6, 184589},
	{"KNEX", 4, 184590},
	{"RAMDAC", 6, 184591},
	{"WINICK", 6, 184592},
	{"PCMS", 4, 184593},
	{"PEPCO", 5, 184594},
	{"CLEWS", 5, 184595},
	{"GEONET", 6, 184596},
	{"SPIR", 4, 184597},
	{"PENNSVILLE", 10, 184598},
	{"REDOLENT", 8, 184599},
	{"DEPENDALL", 9, 184600},
	{"CROSSWINDS", 10, 184601},
	{"DUPLEXING", 9, 184602},
	{"ZZSI", 4, 184603},
	{"ZZII", 4, 184604},
	{"WNMC", 4, 184605},
	{"WDAW", 4, 184606},
	{"VOVI", 4, 184607},
	{"URUJ", 4, 184608},
	{"UKFR", 4, 184609},
	{"UJIB", 4, 184610},
	{"TCUA", 4, 184611},
	{"SUOU", 4, 184612},
	{"RFSH", 4, 184613},
	{"RBCC", 4, 184614},
	{"PBUC", 4, 184615},
	{"PBOD", 4, 184616},
	{"PAER", 4, 184617},
	{"OYFE", 4, 184618},
	{"OKOY", 4, 184619},
	{"MMSO", 4, 184620},
	{"MCFE", 4, 184621},
	{"LUXT", 4, 184622},
	{"IDOX", 4, 184623},
	{"ICKZ", 4, 184624},
	{"IADW", 4, 184625},
	{"HOVD", 4, 184626},
	{"GYFL", 4, 184627},
	{"GMUG", 4, 184628},
	{"FLBU", 4, 184629},
	{"ERHR", 4, 184630},
	{"DDGA", 4, 184631},
	{"CPCO", 4, 184632},
	{"BTFI", 4, 184633},
	{"BEYL", 4, 184634},
	{"BBRU", 4, 184635},
	{"BBOO", 4, 184636},
	{"ALNF", 4, 184637},
	{"MATURO", 6, 184638},
	{"IMPUDENCE", 9, 184639},
	{"BIMMERFEST", 10, 184640},
	{"TOMORROWLAND", 12, 184641},
	{"HOCKS", 5, 184642},
	{"WATERAID", 8, 184643},
	{"GUTTMACHER", 10, 184644},
	{"FANPAGE", 7, 184645},
	{"ACUTALLY", 8, 184646},
	{"RETD", 4, 184647},
	{"LIPSKY", 6, 184648},
	{"DYADS", 5, 184649},
	{"MEDICIN", 7, 184650},
	{"MAKSIM", 6, 184651},
	{"MENCAP", 6, 184652},
	{"PATCHEN", 7, 184653},
	{"PARTNERSQUOT", 12, 184654},
	{"VALLS", 5, 184655},
	{"SECURICOR", 9, 184656},
	{"REPRESSES", 9, 184657},
	{"LIVESHOWS", 9, 184658},
	{"ROVERBOOK", 9, 184659},
	{"GUNSMITHS", 9, 184660},
	{"TYNEDALE", 8, 184661},
	{"SUGANO", 6, 184662},
	{"RITZCAMERA", 10, 184663},
	{"SPORTSBYBROOKS", 14, 184664},
	{"SCHLADMING", 10, 184665},
	{"WITHOU", 6, 184666},
	{"AUTAUGA", 7, 184667},
	{"FOALED", 6, 184668},
	{"PISCO", 5, 184669},
	{"EBROADCAST", 10, 184670},
	{"SUBSPECIALTIES", 14, 184671},
	{"STEILACOOM", 10, 184672},
	{"MARICULTURE", 11, 184673},
	{"CARLS", 5, 184674},
	{"XORP", 4, 184675},
	{"AUTOCOMMIT", 10, 184676},
	{"MORGANVILLE", 11, 184677},
	{"ANANIAS", 7, 184678},
	{"TRONA", 5, 184679},
	{"VIED", 4, 184680},
	{"LIBGNUTLS", 9, 184681},
	{"PCDI", 4, 184682},
	{"VANAF", 5, 184683},
	{"TERATOMA", 8, 184684},
	{"HOTEST", 6, 184685},
	{"MACROBIOTICS", 12, 184686},
	{"ICQS", 4, 184687},
	{"EASTFIELD", 9, 184688},
	{"AZZAM", 5, 184689},
	{"DEVTRACK", 8, 184690},
	{"ATTENDENCE", 10, 184691},
	{"ALLINGTON", 9, 184692},
	{"STEINFELD", 9, 184693},
	{"NONECONOMIC", 11, 184694},
	{"GENERALIZABLE", 13, 184695},
	{"FINDERSCOPE", 11, 184696},
	{"DAYDREAMER", 10, 184697},
	{"IVANO", 5, 184698},
	{"EULOGIES", 8, 184699},
	{"BLUERIDGE", 9, 184700},
	{"KMR", 3, 184701},
	{"WUZZADEM", 8, 184702},
	{"UNDERSHIRTS", 11, 184703},
	{"GEMBIRD", 7, 184704},
	{"STOCH", 5, 184705},
	{"HAEGER", 6, 184706},
	{"RESEALED", 8, 184707},
	{"WHATEVS", 7, 184708},
	{"WEAKLING", 8, 184709},
	{"MISANTHROPIC", 12, 184710},
	{"MARCOT", 6, 184711},
	{"FYING", 5, 184712},
	{"CRAPPER", 7, 184713},
	{"KARANA", 6, 184714},
	{"IGOUMENITSA", 11, 184715},
	{"DMAN", 4, 184716},
	{"ANVILS", 6, 184717},
	{"PELADOS", 7, 184718},
	{"GMPI", 4, 184719},
	{"ARCHTOP", 7, 184720},
	{"YLABEL", 6, 184721},
	{"HADJI", 5, 184722},
	{"AUTODETECT", 10, 184723},
	{"FRIAS", 5, 184724},
	{"ZMIS", 4, 184725},
	{"YAZE", 4, 184726},
	{"SYBL", 4, 184727},
	{"SCYP", 4, 184728},
	{"RPTU", 4, 184729},
	{"REDX", 4, 184730},
	{"NROR", 4, 184731},
	{"MOAP", 4, 184732},
	{"LSSQ", 4, 184733},
	{"LPEI", 4, 184734},
	{"JAZI", 4, 184735},
	{"ILIY", 4, 184736},
	{"HIGL", 4, 184737},
	{"GRER", 4, 184738},
	{"FEAU", 4, 184739},
	{"ERJD", 4, 184740},
	{"EDML", 4, 184741},
	{"DUMU", 4, 184742},
	{"DDRG", 4, 184743},
	{"CYKE", 4, 184744},
	{"BVID", 4, 184745},
	{"AMUZ", 4, 184746},
	{"SPLASHBACKS", 11, 184747},
	{"PTEX", 4, 184748},
	{"HEIDFELD", 8, 184749},
	{"BEATPORT", 8, 184750},
	{"AKHENATEN", 9, 184751},
	{"KOYUKUK", 7, 184752},
	{"WOJTEK", 6, 184753},
	{"SUBWATERSHED", 12, 184754},
	{"SATHORN", 7, 184755},
	{"DINGBAT", 7, 184756},
	{"VISAR", 5, 184757},
	{"VIDEOGIOCHI", 11, 184758},
	{"FAUSTINA", 8, 184759},
	{"MIKUNI", 6, 184760},
	{"WERELDWIJD", 10, 184761},
	{"MAPQUES", 7, 184762},
	{"GRIEFS", 6, 184763},
	{"NIHILO", 6, 184764},
	{"TECHNOLAND", 10, 184765},
	{"OVERNMENT", 9, 184766},
	{"ELEMENTALIST", 12, 184767},
	{"SURTEES", 7, 184768},
	{"ROULEAU", 7, 184769},
	{"COSTIN", 6, 184770},
	{"INNOVACE", 8, 184771},
	{"MICHELOB", 8, 184772},
	{"MACMANUS", 8, 184773},
	{"YOKED", 5, 184774},
	{"STEEPLES", 8, 184775},
	{"CCDF", 4, 184776},
	{"RIBOT", 5, 184777},
	{"BULLIT", 6, 184778},
	{"TROPHOBLASTIC", 13, 184779},
	{"NANHAI", 6, 184780},
	{"FREEMASONARY", 12, 184781},
	{"CIMENTO", 7, 184782},
	{"USERDICT", 8, 184783},
	{"STEWARTSTOWN", 12, 184784},
	{"PRISS", 5, 184785},
	{"RRG", 3, 184786},
	{"SAKHAROV", 8, 184787},
	{"OVERDOSING", 10, 184788},
	{"SHADI", 5, 184789},
	{"NIDRR", 5, 184790},
	{"EURESCOM", 8, 184791},
	{"CLUSTERLIST", 11, 184792},
	{"ADVERTENCIA", 11, 184793},
	{"TAISEN", 6, 184794},
	{"PREPARA", 7, 184795},
	{"VERGENCE", 8, 184796},
	{"ICPS", 4, 184797},
	{"SAUDIA", 6, 184798},
	{"REDBALLOON", 10, 184799},
	{"USSD", 4, 184800},
	{"ASSISTENTE", 10, 184801},
	{"TARES", 5, 184802},
	{"DISQUALIFICATIONS", 17, 184803},
	{"SCHUCK", 6, 184804},
	{"BOOHER", 6, 184805},
	{"ATTACHEMENT", 11, 184806},
	{"SMRT", 4, 184807},
	{"UNDESCRIBED", 11, 184808},
	{"NASTASSJA", 9, 184809},
	{"ARAK", 4, 184810},
	{"MATHISON", 8, 184811},
	{"LACHES", 6, 184812},
	{"CYZICUS", 7, 184813},
	{"HRVOJE", 6, 184814},
	{"DOMENY", 6, 184815},
	{"DDV", 3, 184816},
	{"DEMERGER", 8, 184817},
	{"PARKPLATZTREFF", 14, 184818},
	{"MOYLES", 6, 184819},
	{"COLLATERALS", 11, 184820},
	{"BRENTANO", 8, 184821},
	{"TREMULOUS", 9, 184822},
	{"PFLCI", 5, 184823},
	{"UPPERCLASSMEN", 13, 184824},
	{"SINKHOLES", 9, 184825},
	{"KANHA", 5, 184826},
	{"HOSTELLERIE", 11, 184827},
	{"MARKNET", 7, 184828},
	{"BRIMLEY", 7, 184829},
	{"FUNTASTIC", 9, 184830},
	{"ALLOCATIVE", 10, 184831},
	{"FOVEA", 5, 184832},
	{"ECFA", 4, 184833},
	{"DONTNOTIFYCHECKBOX", 18, 184834},
	{"XLG", 3, 184835},
	{"TYTU", 4, 184836},
	{"SQLOBJECT", 9, 184837},
	{"HITEKER", 7, 184838},
	{"GARST", 5, 184839},
	{"DETTO", 5, 184840},
	{"ANAHUAC", 7, 184841},
	{"GAUDENS", 7, 184842},
	{"HOMEOMORPHISM", 13, 184843},
	{"MENARCHE", 8, 184844},
	{"BASSETERRE", 10, 184845},
	{"ONCHANGE", 8, 184846},
	{"ZDIE", 4, 184847},
	{"YSOK", 4, 184848},
	{"YPIZ", 4, 184849},
	{"YBLV", 4, 184850},
	{"WLAF", 4, 184851},
	{"VSGO", 4, 184852},
	{"VBRA", 4, 184853},
	{"UDYJ", 4, 184854},
	{"UDGA", 4, 184855},
	{"TWOZ", 4, 184856},
	{"TOYP", 4, 184857},
	{"TMRF", 4, 184858},
	{"PJUD", 4, 184859},
	{"OYAQ", 4, 184860},
	{"NOXL", 4, 184861},
	{"MPQU", 4, 184862},
	{"MBUM", 4, 184863},
	{"LAOC", 4, 184864},
	{"IXAG", 4, 184865},
	{"IPPW", 4, 184866},
	{"EBLY", 4, 184867},
	{"DMYJ", 4, 184868},
	{"CWID", 4, 184869},
	{"COIG", 4, 184870},
	{"CFUE", 4, 184871},
	{"BMHA", 4, 184872},
	{"BIMI", 4, 184873},
	{"WHINGE", 6, 184874},
	{"TOTTERING", 9, 184875},
	{"IMMO", 4, 184876},
	{"LRDP", 4, 184877},
	{"FUSERS", 6, 184878},
	{"MECS", 4, 184879},
	{"BEDRM", 5, 184880},
	{"CHILDMINDING", 12, 184881},
	{"CHRONWATCH", 10, 184882},
	{"MMFF", 4, 184883},
	{"QUALS", 5, 184884},
	{"FICKMASCHINE", 12, 184885},
	{"GROSSEN", 7, 184886},
	{"ALBERTINA", 9, 184887},
	{"LOWVILLE", 8, 184888},
	{"GOOFED", 6, 184889},
	{"ASYMPTOTE", 9, 184890},
	{"CARMAKER", 8, 184891},
	{"SANDEFJORD", 10, 184892},
	{"CALDICOTT", 9, 184893},
	{"DIBENZO", 7, 184894},
	{"MRGREEN", 7, 184895},
	{"LANDHOLDING", 11, 184896},
	{"AQUENT", 6, 184897},
	{"SCALPS", 6, 184898},
	{"DESPAIRED", 9, 184899},
	{"QUAILS", 6, 184900},
	{"ODESA", 5, 184901},
	{"KIMORA", 6, 184902},
	{"JANU", 4, 184903},
	{"SATIATED", 8, 184904},
	{"RHODRI", 6, 184905},
	{"COALDALE", 8, 184906},
	{"LOCALISM", 8, 184907},
	{"LEFTIE", 6, 184908},
	{"GRAVITATED", 10, 184909},
	{"CAMECO", 6, 184910},
	{"CODESHARE", 9, 184911},
	{"SWILLING", 8, 184912},
	{"RECENTE", 7, 184913},
	{"AUTODC", 6, 184914},
	{"USDI", 4, 184915},
	{"UCU", 3, 184916},
	{"BUDOKAN", 7, 184917},
	{"SCLERA", 6, 184918},
	{"CYPERUS", 7, 184919},
	{"JAVAGAMES", 9, 184920},
	{"DATAWEEK", 8, 184921},
	{"ZENDER", 6, 184922},
	{"BATSFORD", 8, 184923},
	{"RECAPPING", 9, 184924},
	{"PLUPART", 7, 184925},
	{"PHOTOREFRACTIVE", 15, 184926},
	{"STERI", 5, 184927},
	{"MORTLAKE", 8, 184928},
	{"INTRALATA", 9, 184929},
	{"WINDSURFER", 10, 184930},
	{"FRER", 4, 184931},
	{"ANNONYMOUS", 10, 184932},
	{"STARTUPJOURNAL", 14, 184933},
	{"NECKER", 6, 184934},
	{"NOMADE", 6, 184935},
	{"FINANZAS", 8, 184936},
	{"DUMOULIN", 8, 184937},
	{"NCID", 4, 184938},
	{"FICKBILD", 8, 184939},
	{"SLUGGISHNESS", 12, 184940},
	{"KLEINWORT", 9, 184941},
	{"SAUMUR", 6, 184942},
	{"RUDELFICKEN", 11, 184943},
	{"VINEY", 5, 184944},
	{"EMBARRASING", 11, 184945},
	{"OZEKI", 5, 184946},
	{"PRINCIPAUX", 10, 184947},
	{"TOOBIN", 6, 184948},
	{"POINTSHOP", 9, 184949},
	{"PREEMIES", 8, 184950},
	{"CROSSGCC", 8, 184951},
	{"SWAFFORD", 8, 184952},
	{"WEVO", 4, 184953},
	{"MOBLIE", 6, 184954},
	{"KUKUI", 5, 184955},
	{"CODLING", 7, 184956},
	{"LIGHTNINGS", 10, 184957},
	{"TANGOS", 6, 184958},
	{"REPENTING", 9, 184959},
	{"GBAZIN", 6, 184960},
	{"SHOPPIN", 7, 184961},
	{"LIVESQUOT", 9, 184962},
	{"GRANDFATHERING", 14, 184963},
	{"STANISLAS", 9, 184964},
	{"BERKELY", 7, 184965},
	{"SUBCHRONIC", 10, 184966},
	{"CASTO", 5, 184967},
	{"ZGAV", 4, 184968},
	{"WWNE", 4, 184969},
	{"URGJ", 4, 184970},
	{"RKIP", 4, 184971},
	{"PPEE", 4, 184972},
	{"OVOP", 4, 184973},
	{"ORLB", 4, 184974},
	{"OLLK", 4, 184975},
	{"OLKG", 4, 184976},
	{"OFJP", 4, 184977},
	{"OARF", 4, 184978},
	{"NDCG", 4, 184979},
	{"MBEB", 4, 184980},
	{"LITJ", 4, 184981},
	{"KMBE", 4, 184982},
	{"IEKU", 4, 184983},
	{"HELJ", 4, 184984},
	{"GHYB", 4, 184985},
	{"FYSP", 4, 184986},
	{"FBYF", 4, 184987},
	{"FAXH", 4, 184988},
	{"EEUB", 4, 184989},
	{"ECDT", 4, 184990},
	{"DIOQ", 4, 184991},
	{"DAKK", 4, 184992},
	{"CZSA", 4, 184993},
	{"CNAU", 4, 184994},
	{"CAAV", 4, 184995},
	{"BYOH", 4, 184996},
	{"BMWM", 4, 184997},
	{"BIAV", 4, 184998},
	{"ASLL", 4, 184999},
	{"BUONARROTI", 10, 185000},
	{"MISAWA", 6, 185001},
	{"SEARCHBAR", 9, 185002},
	{"VISU", 4, 185003},
	{"NECKSTRAP", 9, 185004},
	{"MASAKO", 6, 185005},
	{"NAVIS", 5, 185006},
	{"KNEED", 5, 185007},
	{"COSMOGONY", 9, 185008},
	{"YERINGTON", 9, 185009},
	{"GANSBAAI", 8, 185010},
	{"SOULDIERS", 9, 185011},
	{"PRODUCTIE", 9, 185012},
	{"JUPITERS", 8, 185013},
	{"INVULNERABILITY", 15, 185014},
	{"YERUSHALAYIM", 12, 185015},
	{"KILLINGSWORTH", 13, 185016},
	{"COLANGELO", 9, 185017},
	{"SOWAH", 5, 185018},
	{"GROUPWORK", 9, 185019},
	{"UNDERWHELMED", 12, 185020},
	{"VIDEAL", 6, 185021},
	{"PESSOAS", 7, 185022},
	{"ADSNOTE", 7, 185023},
	{"MANLINESS", 9, 185024},
	{"CHURCHMEN", 9, 185025},
	{"TEXTUALLY", 9, 185026},
	{"LILIACEAE", 9, 185027},
	{"EASPORTS", 8, 185028},
	{"TRAINABLE", 9, 185029},
	{"THEATREORGANS", 13, 185030},
	{"BANKABLE", 8, 185031},
	{"MAUMELLE", 8, 185032},
	{"BREDE", 5, 185033},
	{"PEACHEY", 7, 185034},
	{"PARTHIAN", 8, 185035},
	{"TVER", 4, 185036},
	{"PROTSIM", 7, 185037},
	{"HECKLING", 8, 185038},
	{"SODDING", 7, 185039},
	{"SUBMODEL", 8, 185040},
	{"DEODORIZERS", 11, 185041},
	{"REVOLUTIONIZES", 14, 185042},
	{"KNOWEN", 6, 185043},
	{"POMPEO", 6, 185044},
	{"SITEID", 6, 185045},
	{"PAKEHA", 6, 185046},
	{"CLASSID", 7, 185047},
	{"BINCHY", 6, 185048},
	{"MASTERSOFT", 10, 185049},
	{"LABERGE", 7, 185050},
	{"BRAUCHE", 7, 185051},
	{"PHENOLICS", 9, 185052},
	{"LYNXOS", 6, 185053},
	{"CAPABILITES", 11, 185054},
	{"REPORTINGTM", 11, 185055},
	{"POCKLINGTON", 11, 185056},
	{"DETRACTING", 10, 185057},
	{"CHIRPED", 7, 185058},
	{"LUGOD", 5, 185059},
	{"TECHNOLOGIC", 11, 185060},
	{"SYNERGETIC", 10, 185061},
	{"MAMMOGRAPHIC", 12, 185062},
	{"FACTA", 5, 185063},
	{"BASSON", 6, 185064},
	{"HARBERT", 7, 185065},
	{"ZOID", 4, 185066},
	{"FAUCI", 5, 185067},
	{"RISOUL", 6, 185068},
	{"REAUTHORIZED", 12, 185069},
	{"CYANOACRYLATE", 13, 185070},
	{"ARTLINE", 7, 185071},
	{"LEXICALLY", 9, 185072},
	{"KOHSUKE", 7, 185073},
	{"TOWNSCAPE", 9, 185074},
	{"HIMSELFE", 8, 185075},
	{"STEFF", 5, 185076},
	{"HUMPERS", 7, 185077},
	{"CROSSPOSTED", 11, 185078},
	{"CHRISTOU", 8, 185079},
	{"PROTGI", 6, 185080},
	{"DERISIVE", 8, 185081},
	{"IMBIBED", 7, 185082},
	{"HANOVERIAN", 10, 185083},
	{"SAMMA", 5, 185084},
	{"SUBDREAMER", 10, 185085},
	{"ACCELRYS", 8, 185086},
	{"MADRES", 6, 185087},
	{"INTERAKT", 8, 185088},
	{"SERIVCE", 7, 185089},
	{"IDEMA", 5, 185090},
	{"ZINM", 4, 185091},
	{"ZEIF", 4, 185092},
	{"YENP", 4, 185093},
	{"XDER", 4, 185094},
	{"WWMY", 4, 185095},
	{"WACQ", 4, 185096},
	{"VSBO", 4, 185097},
	{"VOBO", 4, 185098},
	{"VNIC", 4, 185099},
	{"VLEA", 4, 185100},
	{"UMTW", 4, 185101},
	{"UGEK", 4, 185102},
	{"UEEC", 4, 185103},
	{"TPDF", 4, 185104},
	{"THCP", 4, 185105},
	{"TCPU", 4, 185106},
	{"RAQE", 4, 185107},
	{"PWRO", 4, 185108},
	{"PIOR", 4, 185109},
	{"PEWT", 4, 185110},
	{"ONZU", 4, 185111},
	{"OFJR", 4, 185112},
	{"MUPL", 4, 185113},
	{"MCSO", 4, 185114},
	{"MBGR", 4, 185115},
	{"LJAY", 4, 185116},
	{"IFUT", 4, 185117},
	{"GSYR", 4, 185118},
	{"GIML", 4, 185119},
	{"GEEU", 4, 185120},
	{"FYEN", 4, 185121},
	{"FYAD", 4, 185122},
	{"FRDR", 4, 185123},
	{"EZOU", 4, 185124},
	{"ESGP", 4, 185125},
	{"DNOQ", 4, 185126},
	{"BEIP", 4, 185127},
	{"ATZK", 4, 185128},
	{"AMMT", 4, 185129},
	{"AFGR", 4, 185130},
	{"PHOTOLINKS", 10, 185131},
	{"CARRANZA", 8, 185132},
	{"WARTON", 6, 185133},
	{"ALESSANDRIA", 11, 185134},
	{"CLINICO", 7, 185135},
	{"DUNKLIN", 7, 185136},
	{"CODIFYING", 9, 185137},
	{"REUTHER", 7, 185138},
	{"EQUIPAGE", 8, 185139},
	{"LIGHTOBJECT", 11, 185140},
	{"ITYPE", 5, 185141},
	{"CARNAUBA", 8, 185142},
	{"WABISABI", 8, 185143},
	{"ODEM", 4, 185144},
	{"KONDOR", 6, 185145},
	{"BRATTLE", 7, 185146},
	{"NETRAM", 6, 185147},
	{"WARATAHS", 8, 185148},
	{"NIGHTGOWNS", 10, 185149},
	{"CARGA", 5, 185150},
	{"ABKHAZ", 6, 185151},
	{"DAWNA", 5, 185152},
	{"BAILIWICK", 9, 185153},
	{"ABENCLOSING", 11, 185154},
	{"SPCK", 4, 185155},
	{"VISTOS", 6, 185156},
	{"BUSHELL", 7, 185157},
	{"WUORNOS", 7, 185158},
	{"COSTES", 6, 185159},
	{"FORESTAL", 8, 185160},
	{"PROPHESYING", 11, 185161},
	{"EMBOSSERS", 9, 185162},
	{"ICQMAIL", 7, 185163},
	{"SAVAGED", 7, 185164},
	{"TARNG", 5, 185165},
	{"ZHURNAL", 7, 185166},
	{"NICEBLOGERS", 11, 185167},
	{"MORODER", 7, 185168},
	{"DAIKIN", 6, 185169},
	{"NEROVISION", 10, 185170},
	{"ANGELJOLIE", 10, 185171},
	{"SLITHERING", 10, 185172},
	{"ABODES", 6, 185173},
	{"ULATIONS", 8, 185174},
	{"TAMARISK", 8, 185175},
	{"STACIA", 6, 185176},
	{"KARYOTYPING", 11, 185177},
	{"DATERS", 6, 185178},
	{"KRING", 5, 185179},
	{"GEOCHRONOLOGY", 13, 185180},
	{"SPOUTED", 7, 185181},
	{"DNAME", 5, 185182},
	{"CAMBIE", 6, 185183},
	{"LETHEM", 6, 185184},
	{"JEEPSTER", 8, 185185},
	{"FUTUREMATE", 10, 185186},
	{"SOCIOECONOMICALLY", 17, 185187},
	{"CLANGING", 8, 185188},
	{"CINEMATICS", 10, 185189},
	{"ASIATIN", 7, 185190},
	{"BATISTE", 7, 185191},
	{"OVERVOTES", 9, 185192},
	{"ABBASI", 6, 185193},
	{"ASSESSEE", 8, 185194},
	{"VISIONNER", 9, 185195},
	{"RLX", 3, 185196},
	{"INGEGNERIA", 10, 185197},
	{"BERIT", 5, 185198},
	{"DETMER", 6, 185199},
	{"BOOMTOWNS", 9, 185200},
	{"HUNTON", 6, 185201},
	{"XENOBIOTICS", 11, 185202},
	{"GUANIDINE", 9, 185203},
	{"BILLNO", 6, 185204},
	{"STRAUSBERG", 10, 185205},
	{"IONIZERS", 8, 185206},
	{"SANKARA", 7, 185207},
	{"ECEMBER", 7, 185208},
	{"AGPGART", 7, 185209},
	{"AMERICIUM", 9, 185210},
	{"TRICKETT", 8, 185211},
	{"ARCHEAN", 7, 185212},
	{"ADLS", 4, 185213},
	{"JESSEE", 6, 185214},
	{"HOLTSVILLE", 10, 185215},
	{"GARON", 5, 185216},
	{"BASTIAT", 7, 185217},
	{"UNCONTROVERSIAL", 15, 185218},
	{"POYNTON", 7, 185219},
	{"NAVISTAR", 8, 185220},
	{"INSURGENCIES", 12, 185221},
	{"SUBCOMPONENTS", 13, 185222},
	{"PRESSEMITTEILUNGEN", 18, 185223},
	{"RUMBLERS", 8, 185224},
	{"HUMBUL", 6, 185225},
	{"MACULATA", 8, 185226},
	{"KADDISH", 7, 185227},
	{"ZISU", 4, 185228},
	{"XVAR", 4, 185229},
	{"XQUA", 4, 185230},
	{"XPIX", 4, 185231},
	{"XMLS", 4, 185232},
	{"XFRI", 4, 185233},
	{"UMPV", 4, 185234},
	{"TYLC", 4, 185235},
	{"TEGM", 4, 185236},
	{"TECD", 4, 185237},
	{"TDUF", 4, 185238},
	{"SRSU", 4, 185239},
	{"SKUB", 4, 185240},
	{"RZYB", 4, 185241},
	{"RZEE", 4, 185242},
	{"RSPT", 4, 185243},
	{"RBPR", 4, 185244},
	{"RBAF", 4, 185245},
	{"PFAV", 4, 185246},
	{"OEDC", 4, 185247},
	{"MOBW", 4, 185248},
	{"MJOY", 4, 185249},
	{"MEMV", 4, 185250},
	{"KORJ", 4, 185251},
	{"KIJO", 4, 185252},
	{"IDZO", 4, 185253},
	{"GCAI", 4, 185254},
	{"FOIB", 4, 185255},
	{"FMYV", 4, 185256},
	{"FENU", 4, 185257},
	{"EPLC", 4, 185258},
	{"EGCR", 4, 185259},
	{"CKIG", 4, 185260},
	{"ATRM", 4, 185261},
	{"CALLANAN", 8, 185262},
	{"SUPERMATE", 9, 185263},
	{"GODMAN", 6, 185264},
	{"ACCESORY", 8, 185265},
	{"SKANDINAVISK", 12, 185266},
	{"KREUTZ", 6, 185267},
	{"SYLVATICA", 9, 185268},
	{"BIMA", 4, 185269},
	{"MOORER", 6, 185270},
	{"KAELIN", 6, 185271},
	{"BENNION", 7, 185272},
	{"RITZCARLTON", 11, 185273},
	{"SHABU", 5, 185274},
	{"INSTIKI", 7, 185275},
	{"FILMI", 5, 185276},
	{"SWYDDOG", 7, 185277},
	{"HELDERBERG", 10, 185278},
	{"FEENSTRA", 8, 185279},
	{"COMPUMEDICS", 11, 185280},
	{"UPCOUNTRY", 9, 185281},
	{"TELECOURSE", 10, 185282},
	{"HYADES", 6, 185283},
	{"SEARCHWIKI", 10, 185284},
	{"OSASUNA", 7, 185285},
	{"RESTEASY", 8, 185286},
	{"REALMUSIC", 9, 185287},
	{"BENIHANA", 8, 185288},
	{"TANGAS", 6, 185289},
	{"CLYBURN", 7, 185290},
	{"LAVERTY", 7, 185291},
	{"SLIMSERVER", 10, 185292},
	{"HERMIE", 6, 185293},
	{"DIACETATE", 9, 185294},
	{"CERNING", 7, 185295},
	{"MENARA", 6, 185296},
	{"SAUSSURE", 8, 185297},
	{"HOMEO", 5, 185298},
	{"WINDPIPE", 8, 185299},
	{"TEMBER", 6, 185300},
	{"OLENA", 5, 185301},
	{"ESPAGNOLE", 9, 185302},
	{"MYPAGE", 6, 185303},
	{"HINTERGLEMM", 11, 185304},
	{"NOTEHOLDERS", 11, 185305},
	{"VERONESE", 8, 185306},
	{"GUILTLESS", 9, 185307},
	{"CITYNOTE", 8, 185308},
	{"CASEIRAS", 8, 185309},
	{"NAAMAN", 6, 185310},
	{"DODA", 4, 185311},
	{"SPLISH", 6, 185312},
	{"SOLUBILIZATION", 14, 185313},
	{"SIMLA", 5, 185314},
	{"QUICKSEEK", 9, 185315},
	{"LATTNER", 7, 185316},
	{"WITHHOLDINGS", 12, 185317},
	{"SHERRARD", 8, 185318},
	{"REDAKTION", 9, 185319},
	{"DISPONIBILI", 11, 185320},
	{"BURNINGS", 8, 185321},
	{"PSYCHOPHYSIOLOGICAL", 19, 185322},
	{"CARACTERE", 9, 185323},
	{"RESAMPLED", 9, 185324},
	{"INTERCOSTAL", 11, 185325},
	{"WAFFLING", 8, 185326},
	{"SMOK", 4, 185327},
	{"KONISHI", 7, 185328},
	{"CONFLATION", 10, 185329},
	{"ESTABA", 6, 185330},
	{"DISTRESSES", 10, 185331},
	{"LIBMUDFLAP", 10, 185332},
	{"KIRYAT", 6, 185333},
	{"BIOSILK", 7, 185334},
	{"THUM", 4, 185335},
	{"TINYSEQ", 7, 185336},
	{"POLSCE", 6, 185337},
	{"PAIDMEMBERS", 11, 185338},
	{"RETAKEN", 7, 185339},
	{"BRUCKER", 7, 185340},
	{"HARNER", 6, 185341},
	{"BIONDA", 6, 185342},
	{"SEMIPARAMETRIC", 14, 185343},
	{"HEERE", 5, 185344},
	{"ERDRICH", 7, 185345},
	{"ZAMI", 4, 185346},
	{"PRICETRACKER", 12, 185347},
	{"CHWARAEON", 9, 185348},
	{"GORITHM", 7, 185349},
	{"PERCIFORMES", 11, 185350},
	{"ASESU", 5, 185351},
	{"YWAX", 4, 185352},
	{"XRAI", 4, 185353},
	{"XASK", 4, 185354},
	{"WMIK", 4, 185355},
	{"USDP", 4, 185356},
	{"UENB", 4, 185357},
	{"UEEG", 4, 185358},
	{"TEXU", 4, 185359},
	{"SDRD", 4, 185360},
	{"PAMC", 4, 185361},
	{"OVMO", 4, 185362},
	{"OELZ", 4, 185363},
	{"OACY", 4, 185364},
	{"NPIX", 4, 185365},
	{"MYEO", 4, 185366},
	{"LUKU", 4, 185367},
	{"LAQS", 4, 185368},
	{"KHLE", 4, 185369},
	{"HLGO", 4, 185370},
	{"GOXY", 4, 185371},
	{"GAEX", 4, 185372},
	{"FFSK", 4, 185373},
	{"EWLL", 4, 185374},
	{"EUAR", 4, 185375},
	{"ESLP", 4, 185376},
	{"EKBL", 4, 185377},
	{"DVEA", 4, 185378},
	{"CIRV", 4, 185379},
	{"CGES", 4, 185380},
	{"CDDV", 4, 185381},
	{"BRIV", 4, 185382},
	{"AFLT", 4, 185383},
	{"USAREUR", 7, 185384},
	{"GOUR", 4, 185385},
	{"GARNISHEE", 9, 185386},
	{"TIONSHIPS", 9, 185387},
	{"BRASSIERE", 9, 185388},
	{"TRANSMUTE", 9, 185389},
	{"RIGNEY", 6, 185390},
	{"HORSERADAR", 10, 185391},
	{"FMVSS", 5, 185392},
	{"INTERMINGLING", 13, 185393},
	{"FOUNDERED", 9, 185394},
	{"NATIONA", 7, 185395},
	{"AUSTENITIC", 10, 185396},
	{"TRANSFRONTIER", 13, 185397},
	{"SWYDD", 5, 185398},
	{"INTERCONNECTOR", 14, 185399},
	{"HALLUCINATORY", 13, 185400},
	{"LONGSHOREMEN", 12, 185401},
	{"CHRISTIANO", 10, 185402},
	{"ARATA", 5, 185403},
	{"MANION", 6, 185404},
	{"MANDAT", 6, 185405},
	{"KNOSSOS", 7, 185406},
	{"DEVILISHLY", 10, 185407},
	{"TELEPHONICS", 11, 185408},
	{"MENORRHAGIA", 11, 185409},
	{"DUROMETER", 9, 185410},
	{"FIREWATER", 9, 185411},
	{"DBEST", 5, 185412},
	{"BEZIERS", 7, 185413},
	{"WIELE", 5, 185414},
	{"PENICILLAMINE", 13, 185415},
	{"TRAVELLODGES", 12, 185416},
	{"SECCIONES", 9, 185417},
	{"SKOGLUND", 8, 185418},
	{"GUYON", 5, 185419},
	{"TATTOOISTS", 10, 185420},
	{"STEGALL", 7, 185421},
	{"NSESSION", 8, 185422},
	{"REDCLOUDS", 9, 185423},
	{"AMUCK", 5, 185424},
	{"ALGAAS", 6, 185425},
	{"YOUGHAL", 7, 185426},
	{"DCV", 3, 185427},
	{"NEWPOINT", 8, 185428},
	{"AFRIKANER", 9, 185429},
	{"CPRS", 4, 185430},
	{"VERSAUT", 7, 185431},
	{"SANTANGELO", 10, 185432},
	{"FRMVCARD", 8, 185433},
	{"BHAGWATI", 8, 185434},
	{"HEREND", 6, 185435},
	{"SOBIE", 5, 185436},
	{"AQUILEGIA", 9, 185437},
	{"WORTMAN", 7, 185438},
	{"FCG", 3, 185439},
	{"DIGSETTE", 8, 185440},
	{"ACTMEMORY", 9, 185441},
	{"ABPOINTS", 8, 185442},
	{"YELLOWCAKE", 10, 185443},
	{"IZEQCOM", 7, 185444},
	{"GAYMEN", 6, 185445},
	{"INTERNETSTOCKBLOG", 17, 185446},
	{"NEDD", 4, 185447},
	{"BARAKAT", 7, 185448},
	{"BLINDE", 6, 185449},
	{"FRNT", 4, 185450},
	{"INSTITUTIONALISATION", 20, 185451},
	{"ICRF", 4, 185452},
	{"HOUSEBOUND", 10, 185453},
	{"DANGEROUSNESS", 13, 185454},
	{"DISPENSATIONS", 13, 185455},
	{"SILENE", 6, 185456},
	{"ASSUR", 5, 185457},
	{"ATTACHMATE", 10, 185458},
	{"STRAITJACKET", 12, 185459},
	{"LACNIC", 6, 185460},
	{"FEEDRSS", 7, 185461},
	{"STRADIVARIUS", 12, 185462},
	{"BOLTZ", 5, 185463},
	{"BOKMAAL", 7, 185464},
	{"RADECSYS", 8, 185465},
	{"IRRETRIEVABLY", 13, 185466},
	{"TVNEWSER", 8, 185467},
	{"CAUT", 4, 185468},
	{"HAAGEN", 6, 185469},
	{"CAMARGUE", 8, 185470},
	{"QUATE", 5, 185471},
	{"KINARD", 6, 185472},
	{"FEILER", 6, 185473},
	{"ISHAQ", 5, 185474},
	{"VUB", 3, 185475},
	{"SCHOLA", 6, 185476},
	{"PASARAN", 7, 185477},
	{"WHOAMI", 6, 185478},
	{"ZUHO", 4, 185479},
	{"ZOCO", 4, 185480},
	{"YDDI", 4, 185481},
	{"WEYB", 4, 185482},
	{"VWON", 4, 185483},
	{"VTOM", 4, 185484},
	{"VPOL", 4, 185485},
	{"UZAR", 4, 185486},
	{"UXFR", 4, 185487},
	{"UPIR", 4, 185488},
	{"ULOD", 4, 185489},
	{"TVSB", 4, 185490},
	{"TKAW", 4, 185491},
	{"SOLG", 4, 185492},
	{"SLCO", 4, 185493},
	{"RSRH", 4, 185494},
	{"ONMB", 4, 185495},
	{"MPMJ", 4, 185496},
	{"MLCO", 4, 185497},
	{"MIFU", 4, 185498},
	{"LLOJ", 4, 185499},
	{"KGBA", 4, 185500},
	{"GMYV", 4, 185501},
	{"FDYS", 4, 185502},
	{"FAYR", 4, 185503},
	{"EAYU", 4, 185504},
	{"DRPG", 4, 185505},
	{"DOUK", 4, 185506},
	{"DCNE", 4, 185507},
	{"VOICECON", 8, 185508},
	{"MCCAFFERY", 9, 185509},
	{"MEDIAPOST", 9, 185510},
	{"BLON", 4, 185511},
	{"THRALLS", 7, 185512},
	{"WARRENDALE", 10, 185513},
	{"NARRE", 5, 185514},
	{"SPEIRS", 6, 185515},
	{"JULIANE", 7, 185516},
	{"JOZSEF", 6, 185517},
	{"SPORTSFAN", 9, 185518},
	{"SLEEPINN", 8, 185519},
	{"DRQ", 3, 185520},
	{"CHUMBAWAMBA", 11, 185521},
	{"BOOGA", 5, 185522},
	{"ALESSANDRINI", 12, 185523},
	{"ELIMINAR", 8, 185524},
	{"PHRENOLOGY", 10, 185525},
	{"FICKKONTAKT", 11, 185526},
	{"ALTAS", 5, 185527},
	{"OVERABUNDANCE", 13, 185528},
	{"KRASNER", 7, 185529},
	{"PROSHOW", 7, 185530},
	{"RSCOE", 5, 185531},
	{"HONFLEUR", 8, 185532},
	{"LEXALERT", 8, 185533},
	{"KILLALL", 7, 185534},
	{"PUBBLICITARI", 12, 185535},
	{"CALVERLEY", 9, 185536},
	{"TAMBA", 5, 185537},
	{"COOKES", 6, 185538},
	{"ROMPERS", 7, 185539},
	{"NCCA", 4, 185540},
	{"HAZLETT", 7, 185541},
	{"SHRNA", 5, 185542},
	{"SCDMA", 5, 185543},
	{"CRISE", 5, 185544},
	{"RYBCZYNSKI", 10, 185545},
	{"ELEZIONI", 8, 185546},
	{"CHURCHS", 7, 185547},
	{"CONNIVANCE", 10, 185548},
	{"ABARTH", 6, 185549},
	{"TIZZY", 5, 185550},
	{"PENLAND", 7, 185551},
	{"INVISO", 6, 185552},
	{"BOTTOMING", 9, 185553},
	{"ROBBINSDALE", 11, 185554},
	{"KYTE", 4, 185555},
	{"AYOUB", 5, 185556},
	{"ANTAEUS", 7, 185557},
	{"RECHARGEABLES", 13, 185558},
	{"LOWEN", 5, 185559},
	{"DEFUNIAK", 8, 185560},
	{"OUTGREW", 7, 185561},
	{"OACUTE", 6, 185562},
	{"EDTION", 6, 185563},
	{"VANCLEAVE", 9, 185564},
	{"CERNLIB", 7, 185565},
	{"SENTENTIAL", 10, 185566},
	{"HOLFORD", 7, 185567},
	{"XCB", 3, 185568},
	{"PROVIDENCIA", 11, 185569},
	{"TIRADES", 7, 185570},
	{"MISCREANT", 9, 185571},
	{"BLACKBOARDS", 11, 185572},
	{"STUDIER", 7, 185573},
	{"ORIGINATORID", 12, 185574},
	{"BITTEREST", 9, 185575},
	{"BIKEZ", 5, 185576},
	{"SCRAPBOOKERS", 12, 185577},
	{"ADRI", 4, 185578},
	{"TYSKLAND", 8, 185579},
	{"RADOME", 6, 185580},
	{"NUCLEO", 6, 185581},
	{"CLAC", 4, 185582},
	{"UTTERBACK", 9, 185583},
	{"TROLLER", 7, 185584},
	{"LIEV", 4, 185585},
	{"KMG", 3, 185586},
	{"CHATSCHLAMPEN", 13, 185587},
	{"FREEPIC", 7, 185588},
	{"COMESA", 6, 185589},
	{"BULLZ", 5, 185590},
	{"NEWSBRIEFS", 10, 185591},
	{"INTERNEES", 9, 185592},
	{"BOTANIKA", 8, 185593},
	{"KIZER", 5, 185594},
	{"ADIPOCYTE", 9, 185595},
	{"PARODI", 6, 185596},
	{"ARRESTER", 8, 185597},
	{"STORYBOARDING", 13, 185598},
	{"LLUNIAU", 7, 185599},
	{"PRIMAKOV", 8, 185600},
	{"AIDWATCH", 8, 185601},
	{"UZB", 3, 185602},
	{"NONAKA", 6, 185603},
	{"IOVATE", 6, 185604},
	{"CHICOT", 6, 185605},
	{"ZUND", 4, 185606},
	{"ZUMO", 4, 185607},
	{"YWOK", 4, 185608},
	{"XULT", 4, 185609},
	{"WNAK", 4, 185610},
	{"UTEZ", 4, 185611},
	{"UKHU", 4, 185612},
	{"RPGR", 4, 185613},
	{"ROSJ", 4, 185614},
	{"RLUB", 4, 185615},
	{"RDTT", 4, 185616},
	{"NLUF", 4, 185617},
	{"LMDU", 4, 185618},
	{"LEKL", 4, 185619},
	{"LCIM", 4, 185620},
	{"KRAE", 4, 185621},
	{"IZBE", 4, 185622},
	{"IAKB", 4, 185623},
	{"HUFO", 4, 185624},
	{"GNRU", 4, 185625},
	{"FSPH", 4, 185626},
	{"FPSI", 4, 185627},
	{"FOVI", 4, 185628},
	{"EZVI", 4, 185629},
	{"EZDR", 4, 185630},
	{"EJRO", 4, 185631},
	{"EDTF", 4, 185632},
	{"APJO", 4, 185633},
	{"SUBMANDIBULAR", 13, 185634},
	{"LILLINGTON", 10, 185635},
	{"WESTHILL", 8, 185636},
	{"THIRTYSOMETHING", 15, 185637},
	{"SOFFRONT", 8, 185638},
	{"NUTRO", 5, 185639},
	{"BELLACH", 7, 185640},
	{"INSDSEQ", 7, 185641},
	{"NEWSBOARD", 9, 185642},
	{"FRASES", 6, 185643},
	{"GOOLD", 5, 185644},
	{"PARY", 4, 185645},
	{"VERIFICA", 8, 185646},
	{"POULSON", 7, 185647},
	{"FORSCHUNGSGEMEINSCHAFT", 22, 185648},
	{"SPIRITUALISTS", 13, 185649},
	{"GRX", 3, 185650},
	{"ARPAD", 5, 185651},
	{"ZIONS", 5, 185652},
	{"BELIZEAN", 8, 185653},
	{"KEMPTVILLE", 10, 185654},
	{"OPENSRS", 7, 185655},
	{"LUMET", 5, 185656},
	{"IGBP", 4, 185657},
	{"SHATTERPROOF", 12, 185658},
	{"LDCT", 4, 185659},
	{"HAMSA", 5, 185660},
	{"PHORNO", 6, 185661},
	{"UNCERTAINLY", 11, 185662},
	{"WELLBORN", 8, 185663},
	{"MYNEGAI", 7, 185664},
	{"ITOJUN", 6, 185665},
	{"DALLOZ", 6, 185666},
	{"RESENTING", 9, 185667},
	{"MAICO", 5, 185668},
	{"RECRYSTALLIZATION", 17, 185669},
	{"ROBINETTE", 9, 185670},
	{"SELLABLE", 8, 185671},
	{"PAWLOWSKI", 9, 185672},
	{"RANDOMY", 7, 185673},
	{"MCCONKEY", 8, 185674},
	{"KINGDOME", 8, 185675},
	{"WMM", 3, 185676},
	{"DDNS", 4, 185677},
	{"PEELE", 5, 185678},
	{"GEBRUIKERS", 10, 185679},
	{"ENDOTHERMIC", 11, 185680},
	{"PYC", 3, 185681},
	{"FAMILIARLY", 10, 185682},
	{"VOUGHT", 6, 185683},
	{"REVIENS", 7, 185684},
	{"EVITAMINS", 9, 185685},
	{"ALTOSANTA", 9, 185686},
	{"MENHADEN", 8, 185687},
	{"TOURNY", 6, 185688},
	{"MISIDENTIFIED", 13, 185689},
	{"JBJ", 3, 185690},
	{"OLYMPOS", 7, 185691},
	{"ROWSET", 6, 185692},
	{"CHELLY", 6, 185693},
	{"MULTIVIEW", 9, 185694},
	{"FLYTECH", 7, 185695},
	{"WILFREDO", 8, 185696},
	{"WAZIRISTAN", 10, 185697},
	{"SCOWLING", 8, 185698},
	{"CAROLAN", 7, 185699},
	{"AECL", 4, 185700},
	{"XGETTEXT", 8, 185701},
	{"WOCE", 4, 185702},
	{"VELOCIDAD", 9, 185703},
	{"MAHR", 4, 185704},
	{"FPSO", 4, 185705},
	{"CONSULTE", 8, 185706},
	{"REFRACTOMETERS", 14, 185707},
	{"MOUSSAKA", 8, 185708},
	{"POSAL", 5, 185709},
	{"GENTA", 5, 185710},
	{"SUFIS", 5, 185711},
	{"FILDES", 6, 185712},
	{"CNNCOM", 6, 185713},
	{"MANAR", 5, 185714},
	{"EXPLO", 5, 185715},
	{"UDIG", 4, 185716},
	{"INSTALLA", 8, 185717},
	{"LUGANSK", 7, 185718},
	{"LUKALIST", 8, 185719},
	{"PARMENIDES", 10, 185720},
	{"KENTS", 5, 185721},
	{"INTERWIKIS", 10, 185722},
	{"BCOPY", 5, 185723},
	{"BACKOUT", 7, 185724},
	{"MERCYME", 7, 185725},
	{"DISPOSITIVO", 11, 185726},
	{"DEMOCRAZIA", 10, 185727},
	{"LATEEF", 6, 185728},
	{"SWAGGERING", 10, 185729},
	{"COMMERCIALISED", 14, 185730},
	{"OADBY", 5, 185731},
	{"KBB", 3, 185732},
	{"JUSTME", 6, 185733},
	{"CLASSEN", 7, 185734},
	{"TEMPORARIES", 11, 185735},
	{"NOUWEN", 6, 185736},
	{"INTRADERMAL", 11, 185737},
	{"CHEVYS", 6, 185738},
	{"HUGHESVILLE", 11, 185739},
	{"DCACHE", 6, 185740},
	{"ZAMM", 4, 185741},
	{"YTEP", 4, 185742},
	{"VSSU", 4, 185743},
	{"UIGG", 4, 185744},
	{"TSLL", 4, 185745},
	{"TIDG", 4, 185746},
	{"RUEJ", 4, 185747},
	{"ROUZ", 4, 185748},
	{"ROTL", 4, 185749},
	{"RLBY", 4, 185750},
	{"RBAJ", 4, 185751},
	{"POSL", 4, 185752},
	{"PAPN", 4, 185753},
	{"MTPL", 4, 185754},
	{"MOUC", 4, 185755},
	{"LPMU", 4, 185756},
	{"LEYQ", 4, 185757},
	{"KNDA", 4, 185758},
	{"GEYB", 4, 185759},
	{"GCEM", 4, 185760},
	{"CSVA", 4, 185761},
	{"COZZ", 4, 185762},
	{"UPSLOPE", 7, 185763},
	{"INTERPRETA", 10, 185764},
	{"DATAEXPERT", 10, 185765},
	{"WIKIWIKIWEB", 11, 185766},
	{"TRANTER", 7, 185767},
	{"NLCS", 4, 185768},
	{"LOCKRIDGE", 9, 185769},
	{"DEGREASERS", 10, 185770},
	{"WILAYAH", 7, 185771},
	{"BULLE", 5, 185772},
	{"ALMSHOUSE", 9, 185773},
	{"ORMEROD", 7, 185774},
	{"BAYMOUNT", 8, 185775},
	{"GRANDLY", 7, 185776},
	{"BIOTECHNOLOGIE", 14, 185777},
	{"PODSHOW", 7, 185778},
	{"ENVER", 5, 185779},
	{"CAPELLO", 7, 185780},
	{"KROM", 4, 185781},
	{"MWAVE", 5, 185782},
	{"MUGUET", 6, 185783},
	{"KEYSYM", 6, 185784},
	{"TSHIPLEY", 8, 185785},
	{"OLBAS", 5, 185786},
	{"FRADIN", 6, 185787},
	{"DERING", 6, 185788},
	{"AMISHA", 6, 185789},
	{"PQRST", 5, 185790},
	{"MULTIHOMED", 10, 185791},
	{"CLUUID", 6, 185792},
	{"TRACO", 5, 185793},
	{"PROJE", 5, 185794},
	{"JOCKO", 5, 185795},
	{"PUBLICANS", 9, 185796},
	{"MCILROY", 7, 185797},
	{"MATHSOFT", 8, 185798},
	{"VICON", 5, 185799},
	{"GRACIOUSNESS", 12, 185800},
	{"FICTIVE", 7, 185801},
	{"DHEC", 4, 185802},
	{"ORCL", 4, 185803},
	{"MICROFLUIDICS", 13, 185804},
	{"TWPU", 4, 185805},
	{"PAXMAN", 6, 185806},
	{"LIGUORI", 7, 185807},
	{"DBCS", 4, 185808},
	{"CYBURBIA", 8, 185809},
	{"WELLSLEY", 8, 185810},
	{"CHECKOUTCHECKOUT", 16, 185811},
	{"BIRTHMARK", 9, 185812},
	{"STIVERS", 7, 185813},
	{"ERLEWINE", 8, 185814},
	{"ELABORATIONS", 12, 185815},
	{"CLICKSMART", 10, 185816},
	{"SAINZ", 5, 185817},
	{"QUOTNO", 6, 185818},
	{"FORESHADOW", 10, 185819},
	{"FLASHINGS", 9, 185820},
	{"VITIATE", 7, 185821},
	{"INTERAKTIV", 10, 185822},
	{"FOOTLIGHTS", 10, 185823},
	{"OFFICESCAN", 10, 185824},
	{"SMARTING", 8, 185825},
	{"VALCO", 5, 185826},
	{"MYSONGBOOK", 10, 185827},
	{"ASHDOD", 6, 185828},
	{"TEXTBASE", 8, 185829},
	{"PUEDA", 5, 185830},
	{"MIETEN", 6, 185831},
	{"JURGENSEN", 9, 185832},
	{"SORB", 4, 185833},
	{"CITRULLINE", 10, 185834},
	{"ROYS", 4, 185835},
	{"BOUNCIN", 7, 185836},
	{"TOWNPLACE", 9, 185837},
	{"SURGERYPLASTIC", 14, 185838},
	{"HATREDS", 7, 185839},
	{"CUPRA", 5, 185840},
	{"NOHSC", 5, 185841},
	{"WELLESLY", 8, 185842},
	{"TIMMERMANS", 10, 185843},
	{"PURULENT", 8, 185844},
	{"KOSKIE", 6, 185845},
	{"MARYELLEN", 9, 185846},
	{"BUCHS", 5, 185847},
	{"FICKPARTY", 9, 185848},
	{"STEELMAKING", 11, 185849},
	{"MURNAU", 6, 185850},
	{"DECAPODA", 8, 185851},
	{"UPDATEABLE", 10, 185852},
	{"PROSTACYCLIN", 12, 185853},
	{"FRANCIOSA", 9, 185854},
	{"EFECTS", 6, 185855},
	{"CINEMOCRACY", 11, 185856},
	{"HEINLE", 6, 185857},
	{"MERCERIZED", 10, 185858},
	{"EVALUEZONE", 10, 185859},
	{"YYAT", 4, 185860},
	{"YMSO", 4, 185861},
	{"YENM", 4, 185862},
	{"YCIG", 4, 185863},
	{"YARW", 4, 185864},
	{"XTVS", 4, 185865},
	{"UYAO", 4, 185866},
	{"UWOM", 4, 185867},
	{"UIFA", 4, 185868},
	{"UGPL", 4, 185869},
	{"TYAY", 4, 185870},
	{"RVSA", 4, 185871},
	{"PYED", 4, 185872},
	{"PVIL", 4, 185873},
	{"OLPP", 4, 185874},
	{"OFVR", 4, 185875},
	{"NPRY", 4, 185876},
	{"LKPE", 4, 185877},
	{"KOLY", 4, 185878},
	{"KIZA", 4, 185879},
	{"IBUM", 4, 185880},
	{"FMFT", 4, 185881},
	{"EXFL", 4, 185882},
	{"DPAO", 4, 185883},
	{"DMMI", 4, 185884},
	{"DDTR", 4, 185885},
	{"AKHC", 4, 185886},
	{"SENTANCE", 8, 185887},
	{"GHASSAN", 7, 185888},
	{"IMPERIL", 7, 185889},
	{"ANYURI", 6, 185890},
	{"MELONENTITTEN", 13, 185891},
	{"SALAMIS", 7, 185892},
	{"ANALFOTZE", 9, 185893},
	{"KACH", 4, 185894},
	{"HUTSCHENREUTHER", 15, 185895},
	{"SUPPLIE", 7, 185896},
	{"SADONA", 6, 185897},
	{"HURSON", 6, 185898},
	{"ZWEITE", 6, 185899},
	{"APAQ", 4, 185900},
	{"NOVOFLEX", 8, 185901},
	{"CENSER", 6, 185902},
	{"PROBLE", 6, 185903},
	{"NONINCOME", 9, 185904},
	{"COLLEGUES", 9, 185905},
	{"ENSRN", 5, 185906},
	{"AMAMOS", 6, 185907},
	{"MAGNANI", 7, 185908},
	{"DHARAM", 6, 185909},
	{"FRIARY", 6, 185910},
	{"BUTESHIRE", 9, 185911},
	{"LILYPIE", 7, 185912},
	{"METAMUCIL", 9, 185913},
	{"CYBERNETMAN", 11, 185914},
	{"CLASIFICADOS", 12, 185915},
	{"SURFEIT", 7, 185916},
	{"CARLLTON", 8, 185917},
	{"ASPRO", 5, 185918},
	{"SISSEL", 6, 185919},
	{"SCHNELLER", 9, 185920},
	{"OBEISANCE", 9, 185921},
	{"MOTTLE", 6, 185922},
	{"MAGMAS", 6, 185923},
	{"PDATE", 5, 185924},
	{"MABUHAY", 7, 185925},
	{"PDPS", 4, 185926},
	{"FORMATTERS", 10, 185927},
	{"WACKED", 6, 185928},
	{"RICHA", 5, 185929},
	{"BUHAY", 5, 185930},
	{"SAHAR", 5, 185931},
	{"WASALLAM", 8, 185932},
	{"RODEWAYINN", 10, 185933},
	{"FRITES", 6, 185934},
	{"CRITCHLEY", 9, 185935},
	{"WHELP", 5, 185936},
	{"BAROCLINIC", 10, 185937},
	{"DOUCHES", 7, 185938},
	{"EMANAGER", 8, 185939},
	{"FANTAISIE", 9, 185940},
	{"AFPC", 4, 185941},
	{"USUMACINTA", 10, 185942},
	{"PCDJ", 4, 185943},
	{"FORMEDNESS", 10, 185944},
	{"REEMS", 5, 185945},
	{"ERINA", 5, 185946},
	{"BETUS", 5, 185947},
	{"TOUCHSTAR", 9, 185948},
	{"IPMA", 4, 185949},
	{"GIBBARD", 7, 185950},
	{"ADOM", 4, 185951},
	{"BAYADA", 6, 185952},
	{"ENSIGHT", 7, 185953},
	{"RAPHE", 5, 185954},
	{"OHLSSON", 7, 185955},
	{"EQUINES", 7, 185956},
	{"LVDT", 4, 185957},
	{"HACKMASTER", 10, 185958},
	{"MONNAIE", 7, 185959},
	{"LIBMOWITZ", 9, 185960},
	{"BERNSEN", 7, 185961},
	{"GAPERS", 6, 185962},
	{"HIJRAH", 6, 185963},
	{"STIJN", 5, 185964},
	{"SUSILO", 6, 185965},
	{"PRIMERICA", 9, 185966},
	{"SIMAP", 5, 185967},
	{"IGNOMINIOUS", 11, 185968},
	{"ENTSCHIEDEN", 11, 185969},
	{"AVASTIN", 7, 185970},
	{"YLX", 3, 185971},
	{"UNFAMILIARITY", 13, 185972},
	{"AREVA", 5, 185973},
	{"SHAGWELL", 8, 185974},
	{"KOTZ", 4, 185975},
	{"RATMAN", 6, 185976},
	{"ACTUALES", 8, 185977},
	{"WXPP", 4, 185978},
	{"YBCO", 4, 185979},
	{"KYBERNHSHS", 10, 185980},
	{"MUROIDEA", 8, 185981},
	{"FANGIRL", 7, 185982},
	{"TKIP", 4, 185983},
	{"REFUTATIONS", 11, 185984},
	{"GOLFGOLF", 8, 185985},
	{"FATMA", 5, 185986},
	{"SRINATH", 7, 185987},
	{"UNITEDSTATES", 12, 185988},
	{"SULKING", 7, 185989},
	{"LINODE", 6, 185990},
	{"BAKUNIN", 7, 185991},
	{"KUNSTREPRODUKTIONEN", 19, 185992},
	{"KREUTZER", 8, 185993},
	{"MUIC", 4, 185994},
	{"MANTO", 5, 185995},
	{"ZREM", 4, 185996},
	{"YUNJ", 4, 185997},
	{"YOAR", 4, 185998},
	{"WRAH", 4, 185999},
	{"VPFO", 4, 186000},
	{"SDRR", 4, 186001},
	{"SCDO", 4, 186002},
	{"PYAC", 4, 186003},
	{"PBUD", 4, 186004},
	{"MONQ", 4, 186005},
	{"KYEX", 4, 186006},
	{"ISYR", 4, 186007},
	{"IRTZ", 4, 186008},
	{"IGCE", 4, 186009},
	{"HUTB", 4, 186010},
	{"EPCG", 4, 186011},
	{"EDRG", 4, 186012},
	{"EAZL", 4, 186013},
	{"DRTI", 4, 186014},
	{"BWED", 4, 186015},
	{"BGOT", 4, 186016},
	{"BCPA", 4, 186017},
	{"ADUF", 4, 186018},
	{"KEENEST", 7, 186019},
	{"DEIST", 5, 186020},
	{"COSMECEUTICALS", 14, 186021},
	{"BANDURA", 7, 186022},
	{"SMOOTHS", 7, 186023},
	{"BHAM", 4, 186024},
	{"PRATA", 5, 186025},
	{"DIEBACK", 7, 186026},
	{"DETENTE", 7, 186027},
	{"BELPRE", 6, 186028},
	{"WWWMSN", 6, 186029},
	{"GEEKINESS", 9, 186030},
	{"NIBBLER", 7, 186031},
	{"ROOFLINE", 8, 186032},
	{"UNGAINLY", 8, 186033},
	{"DARSTELLUNG", 11, 186034},
	{"MOHER", 5, 186035},
	{"ELECTRONICSCONSULTING", 21, 186036},
	{"AKASH", 5, 186037},
	{"LAFOLLETTE", 10, 186038},
	{"NEXTVISION", 10, 186039},
	{"KRANKY", 6, 186040},
	{"INTERENT", 8, 186041},
	{"CEDA", 4, 186042},
	{"AMERINN", 7, 186043},
	{"TILLICH", 7, 186044},
	{"CAYLUS", 6, 186045},
	{"AMERICAINN", 10, 186046},
	{"BAILES", 6, 186047},
	{"SENTECH", 7, 186048},
	{"SPEARE", 6, 186049},
	{"ORKIDEA", 7, 186050},
	{"FLUKA", 5, 186051},
	{"EXPONENTIALS", 12, 186052},
	{"VASOMOTOR", 9, 186053},
	{"COALFIELDS", 10, 186054},
	{"TRATIONS", 8, 186055},
	{"LUCCHINO", 8, 186056},
	{"DOVETAILS", 9, 186057},
	{"BIOTOPES", 8, 186058},
	{"MIMESIS", 7, 186059},
	{"TEMAT", 5, 186060},
	{"MENUIRES", 8, 186061},
	{"DENKER", 6, 186062},
	{"EVEY", 4, 186063},
	{"SPRINGHILLSUITES", 16, 186064},
	{"DIHYDRATE", 9, 186065},
	{"WELESLEY", 8, 186066},
	{"AEDPA", 5, 186067},
	{"HANDSPUN", 8, 186068},
	{"BAUBLE", 6, 186069},
	{"SKYY", 4, 186070},
	{"TIFOSI", 6, 186071},
	{"BELIEVABILITY", 13, 186072},
	{"UPOC", 4, 186073},
	{"HYDROGENASE", 11, 186074},
	{"XMLBLASTER", 10, 186075},
	{"CIRCLET", 7, 186076},
	{"VOIVODSHIP", 10, 186077},
	{"FIRSTCHAR", 9, 186078},
	{"BLUTJUNG", 8, 186079},
	{"TOLAN", 5, 186080},
	{"CAPPERS", 7, 186081},
	{"BLOGISTAN", 9, 186082},
	{"WHEREAFTER", 10, 186083},
	{"QUR", 3, 186084},
	{"JONZE", 5, 186085},
	{"OLLIVER", 7, 186086},
	{"DIMITRE", 7, 186087},
	{"BIOTERROR", 9, 186088},
	{"POZZI", 5, 186089},
	{"OXALIS", 6, 186090},
	{"BARBY", 5, 186091},
	{"EURONE", 6, 186092},
	{"CARBORUNDUM", 11, 186093},
	{"LOTTSO", 6, 186094},
	{"PLAGIARIST", 10, 186095},
	{"COML", 4, 186096},
	{"DOKIE", 5, 186097},
	{"REGIMENTED", 10, 186098},
	{"JCOKOS", 6, 186099},
	{"PIOTROWSKI", 10, 186100},
	{"IFAW", 4, 186101},
	{"DELPY", 5, 186102},
	{"MUDRA", 5, 186103},
	{"BLAEST", 6, 186104},
	{"USAHOTELS", 9, 186105},
	{"ATIMA", 5, 186106},
	{"WEBDEVELOPER", 12, 186107},
	{"TRAST", 5, 186108},
	{"JLAB", 4, 186109},
	{"WELSLEY", 7, 186110},
	{"ROCKTON", 7, 186111},
	{"LEXARMEDIA", 10, 186112},
	{"UNIONFS", 7, 186113},
	{"SEAWORTHY", 9, 186114},
	{"REVERSABLE", 10, 186115},
	{"TRELOAR", 7, 186116},
	{"CHRYS", 5, 186117},
	{"YYAC", 4, 186118},
	{"XSAC", 4, 186119},
	{"XPIC", 4, 186120},
	{"WWWY", 4, 186121},
	{"VEXA", 4, 186122},
	{"VEIV", 4, 186123},
	{"TZAB", 4, 186124},
	{"TSYB", 4, 186125},
	{"TRWA", 4, 186126},
	{"TEXF", 4, 186127},
	{"SPYN", 4, 186128},
	{"SKLY", 4, 186129},
	{"RNTB", 4, 186130},
	{"RENQ", 4, 186131},
	{"RDOX", 4, 186132},
	{"PODF", 4, 186133},
	{"OVUS", 4, 186134},
	{"OOLZ", 4, 186135},
	{"OCIC", 4, 186136},
	{"OBJA", 4, 186137},
	{"NCDR", 4, 186138},
	{"MPDR", 4, 186139},
	{"MEYW", 4, 186140},
	{"LOCQ", 4, 186141},
	{"KEZU", 4, 186142},
	{"JZEF", 4, 186143},
	{"JCAN", 4, 186144},
	{"IDSQ", 4, 186145},
	{"HKAB", 4, 186146},
	{"GOPG", 4, 186147},
	{"GEUT", 4, 186148},
	{"GAML", 4, 186149},
	{"FMYY", 4, 186150},
	{"EUKL", 4, 186151},
	{"EOGU", 4, 186152},
	{"EKSJ", 4, 186153},
	{"CYNU", 4, 186154},
	{"CCDE", 4, 186155},
	{"COMPANYKIDS", 11, 186156},
	{"ALENTEJO", 8, 186157},
	{"RAVINIA", 7, 186158},
	{"ROUSES", 6, 186159},
	{"DAMOCLES", 8, 186160},
	{"POSIE", 5, 186161},
	{"BEFFEN", 6, 186162},
	{"JANAK", 5, 186163},
	{"VALEMOUNT", 9, 186164},
	{"WORDMAP", 7, 186165},
	{"DENIGRATING", 11, 186166},
	{"SNAKED", 6, 186167},
	{"INTERCHANGABLE", 14, 186168},
	{"DORMIR", 6, 186169},
	{"MODOG", 5, 186170},
	{"CONSOLATIONS", 12, 186171},
	{"DARKS", 5, 186172},
	{"CISAPRIDE", 9, 186173},
	{"WEBMANAGER", 10, 186174},
	{"WEEMEE", 6, 186175},
	{"ZEILENGA", 8, 186176},
	{"ARENARIA", 8, 186177},
	{"PAZZA", 5, 186178},
	{"UPMANN", 6, 186179},
	{"JEZABEL", 7, 186180},
	{"DOWLNOAD", 8, 186181},
	{"EMBOSSER", 8, 186182},
	{"WHORLS", 6, 186183},
	{"ELEKTRISCHE", 11, 186184},
	{"ANISEED", 7, 186185},
	{"FACTUM", 6, 186186},
	{"WOVENS", 6, 186187},
	{"SPYHUNTER", 9, 186188},
	{"WOOLACOMBE", 10, 186189},
	{"SANITIZATION", 12, 186190},
	{"FULKS", 5, 186191},
	{"ENSLAVING", 9, 186192},
	{"ANALCAMS", 8, 186193},
	{"JENGA", 5, 186194},
	{"CATTON", 6, 186195},
	{"CYMUNED", 7, 186196},
	{"MEDES", 5, 186197},
	{"KOLLAR", 6, 186198},
	{"BEXTOR", 6, 186199},
	{"DOCMAN", 6, 186200},
	{"WAAAAY", 6, 186201},
	{"SPELLCRAFT", 10, 186202},
	{"OPTIONALITY", 11, 186203},
	{"HESPERUS", 8, 186204},
	{"COLLATES", 8, 186205},
	{"FANTAIL", 7, 186206},
	{"DEALE", 5, 186207},
	{"RAFAT", 5, 186208},
	{"KESTON", 6, 186209},
	{"GATLINBERG", 10, 186210},
	{"PMTS", 4, 186211},
	{"HARBINGERS", 10, 186212},
	{"SHALBE", 6, 186213},
	{"ODOROUS", 7, 186214},
	{"RUDRAKSHA", 9, 186215},
	{"ADVISORAMA", 10, 186216},
	{"ACETABULAR", 10, 186217},
	{"MELPHALAN", 9, 186218},
	{"ELEVATIONAL", 11, 186219},
	{"NALCO", 5, 186220},
	{"INDEFINABLE", 11, 186221},
	{"CODINGS", 7, 186222},
	{"ITALIENISCH", 11, 186223},
	{"BABYWEAR", 8, 186224},
	{"CASILLA", 7, 186225},
	{"HILLTOPS", 8, 186226},
	{"CAISSON", 7, 186227},
	{"MIXMAG", 6, 186228},
	{"IBOX", 4, 186229},
	{"EMBELLISHING", 12, 186230},
	{"CEDILLA", 7, 186231},
	{"QUB", 3, 186232},
	{"BAMBAATAA", 9, 186233},
	{"ARRIS", 5, 186234},
	{"TIGRES", 6, 186235},
	{"ANTISPYWAR", 10, 186236},
	{"USHOTELS", 8, 186237},
	{"GALATASARAY", 11, 186238},
	{"WINDLE", 6, 186239},
	{"PHISON", 6, 186240},
	{"TCAP", 4, 186241},
	{"SUBURBANLODGE", 13, 186242},
	{"PISSE", 5, 186243},
	{"LUOMA", 5, 186244},
	{"USHOTEL", 7, 186245},
	{"USAHOTEL", 8, 186246},
	{"FAITS", 5, 186247},
	{"LIMNOL", 6, 186248},
	{"KENNE", 5, 186249},
	{"INFINITIVES", 11, 186250},
	{"BOLDATA", 7, 186251},
	{"LINDL", 5, 186252},
	{"PARTIZAN", 8, 186253},
	{"GRIJS", 5, 186254},
	{"CATKORE", 7, 186255},
	{"IRONICAL", 8, 186256},
	{"VEGEMITE", 8, 186257},
	{"CCCT", 4, 186258},
	{"TAVIRA", 6, 186259},
	{"INKBLOT", 7, 186260},
	{"HUMAYUN", 7, 186261},
	{"APPROVABLE", 10, 186262},
	{"HICOLOR", 7, 186263},
	{"BUZZIN", 6, 186264},
	{"SYMPATHIZED", 11, 186265},
	{"INARA", 5, 186266},
	{"SUBGOALS", 8, 186267},
	{"BUMST", 5, 186268},
	{"ZYWO", 4, 186269},
	{"ZASU", 4, 186270},
	{"YWOW", 4, 186271},
	{"XSRE", 4, 186272},
	{"XKID", 4, 186273},
	{"WLPA", 4, 186274},
	{"WLDE", 4, 186275},
	{"TVRI", 4, 186276},
	{"TICZ", 4, 186277},
	{"TBYZ", 4, 186278},
	{"REIZ", 4, 186279},
	{"RBBE", 4, 186280},
	{"PTTW", 4, 186281},
	{"OZUM", 4, 186282},
	{"ORRM", 4, 186283},
	{"NDWT", 4, 186284},
	{"MSIW", 4, 186285},
	{"MHOC", 4, 186286},
	{"LUSJ", 4, 186287},
	{"LCAK", 4, 186288},
	{"INZB", 4, 186289},
	{"IFDU", 4, 186290},
	{"HYFL", 4, 186291},
	{"HUPG", 4, 186292},
	{"HUMT", 4, 186293},
	{"EYLY", 4, 186294},
	{"CLEX", 4, 186295},
	{"CHNB", 4, 186296},
	{"BQUE", 4, 186297},
	{"GRV", 3, 186298},
	{"VOLCANICS", 9, 186299},
	{"AQUILLA", 7, 186300},
	{"UNCULTIVATED", 12, 186301},
	{"PYON", 4, 186302},
	{"FIBS", 4, 186303},
	{"CLOYING", 7, 186304},
	{"FUNCTIONARY", 11, 186305},
	{"PAPHIOPEDILUM", 13, 186306},
	{"PHOTOANALOG", 11, 186307},
	{"STURGE", 6, 186308},
	{"APHC", 4, 186309},
	{"YEHUDI", 6, 186310},
	{"BLUEBEARD", 9, 186311},
	{"KAMAOLE", 7, 186312},
	{"HOUSSE", 6, 186313},
	{"RAJI", 4, 186314},
	{"EAGAIN", 6, 186315},
	{"KILLAZ", 6, 186316},
	{"SHEPERD", 7, 186317},
	{"TUDORS", 6, 186318},
	{"DRIESSEN", 8, 186319},
	{"RENSBURG", 8, 186320},
	{"OMAFICK", 7, 186321},
	{"HEADSCARVES", 11, 186322},
	{"NAFD", 4, 186323},
	{"SUPPOSITIONS", 12, 186324},
	{"BATTERERS", 9, 186325},
	{"TUMBNAILS", 9, 186326},
	{"SUPRGLU", 7, 186327},
	{"JEHOSHAPHAT", 11, 186328},
	{"ILLUMINAZIONE", 13, 186329},
	{"WCAR", 4, 186330},
	{"RENOVATORS", 10, 186331},
	{"PLUSHIES", 8, 186332},
	{"RISCOS", 6, 186333},
	{"PRERUNNER", 9, 186334},
	{"BANGLADESHIS", 12, 186335},
	{"INTERMESH", 9, 186336},
	{"ENDESA", 6, 186337},
	{"CHEVAUX", 7, 186338},
	{"PROTECTANTS", 11, 186339},
	{"ELEGIES", 7, 186340},
	{"SRBIJA", 6, 186341},
	{"BEATLELINKS", 11, 186342},
	{"EXPLODER", 8, 186343},
	{"BALLYCLARE", 10, 186344},
	{"INCARNATED", 10, 186345},
	{"GARGLING", 8, 186346},
	{"KOHONEN", 7, 186347},
	{"FILEINFO", 8, 186348},
	{"GIMENEZ", 7, 186349},
	{"NERODE", 6, 186350},
	{"SPECIC", 6, 186351},
	{"FRANKTON", 8, 186352},
	{"BRIDGFORD", 9, 186353},
	{"SQUIGGLY", 8, 186354},
	{"KRAHN", 5, 186355},
	{"RAGHAV", 6, 186356},
	{"KALANCHOE", 9, 186357},
	{"SEDGEWICK", 9, 186358},
	{"GERON", 5, 186359},
	{"KAMILLE", 7, 186360},
	{"TYPELIB", 7, 186361},
	{"CAROLINGIAN", 11, 186362},
	{"LEGCO", 5, 186363},
	{"FINL", 4, 186364},
	{"UNREVISED", 9, 186365},
	{"PNTXTA", 6, 186366},
	{"HENDERSHOT", 10, 186367},
	{"HCPS", 4, 186368},
	{"CONFS", 5, 186369},
	{"NADESICO", 8, 186370},
	{"OEFENINGEN", 10, 186371},
	{"EVELYNE", 7, 186372},
	{"ZKID", 4, 186373},
	{"ZBEL", 4, 186374},
	{"YNOK", 4, 186375},
	{"XEME", 4, 186376},
	{"VFRA", 4, 186377},
	{"VARH", 4, 186378},
	{"UNOK", 4, 186379},
	{"ULNU", 4, 186380},
	{"UAFE", 4, 186381},
	{"SUVO", 4, 186382},
	{"ROXM", 4, 186383},
	{"NKOZ", 4, 186384},
	{"MUPM", 4, 186385},
	{"MRAF", 4, 186386},
	{"LTJE", 4, 186387},
	{"LIIB", 4, 186388},
	{"KURB", 4, 186389},
	{"KPUS", 4, 186390},
	{"KAHM", 4, 186391},
	{"HYQU", 4, 186392},
	{"GWEG", 4, 186393},
	{"GRHE", 4, 186394},
	{"GAXI", 4, 186395},
	{"FOBO", 4, 186396},
	{"CWRE", 4, 186397},
	{"CGYM", 4, 186398},
	{"CDWH", 4, 186399},
	{"BSIF", 4, 186400},
	{"BNDE", 4, 186401},
	{"BMWC", 4, 186402},
	{"BBEH", 4, 186403},
	{"AXAV", 4, 186404},
	{"ASPF", 4, 186405},
	{"AGYU", 4, 186406},
	{"TAVEL", 5, 186407},
	{"BRAZEAU", 7, 186408},
	{"BAATHISTS", 9, 186409},
	{"GEMPLER", 7, 186410},
	{"CROMOLYN", 8, 186411},
	{"DIVISIBILITY", 12, 186412},
	{"SONARTEC", 8, 186413},
	{"SKREV", 5, 186414},
	{"ZSERVER", 7, 186415},
	{"HORNBEAM", 8, 186416},
	{"CORROBORATES", 12, 186417},
	{"VIDAS", 5, 186418},
	{"PREVEZA", 7, 186419},
	{"PAULK", 5, 186420},
	{"FIBRATION", 9, 186421},
	{"PAIGN", 5, 186422},
	{"SANJA", 5, 186423},
	{"IMAGESTATION", 12, 186424},
	{"CARBINES", 8, 186425},
	{"SSCRA", 5, 186426},
	{"FICKPARTYS", 10, 186427},
	{"DATONG", 6, 186428},
	{"BRISSON", 7, 186429},
	{"GIJS", 4, 186430},
	{"SIGMATEL", 8, 186431},
	{"DESENHOS", 8, 186432},
	{"AUSTRAILIAN", 11, 186433},
	{"MATRESSES", 9, 186434},
	{"FTYPE", 5, 186435},
	{"ROLLERBLADES", 12, 186436},
	{"LANDFILLED", 10, 186437},
	{"SUBCOMPONENT", 12, 186438},
	{"KAVIAREROTIK", 12, 186439},
	{"EPORTS", 6, 186440},
	{"FOAD", 4, 186441},
	{"EROSIONAL", 9, 186442},
	{"STUTSMAN", 8, 186443},
	{"STARHOTELS", 10, 186444},
	{"AGETEC", 6, 186445},
	{"ZENIA", 5, 186446},
	{"HUESCA", 6, 186447},
	{"ESCENTUAL", 9, 186448},
	{"RJM", 3, 186449},
	{"COUPERIN", 8, 186450},
	{"SIENTO", 6, 186451},
	{"MUTTERJAGD", 10, 186452},
	{"KAKAR", 5, 186453},
	{"BRATTY", 6, 186454},
	{"VAJDA", 5, 186455},
	{"RICHT", 5, 186456},
	{"KAFFIR", 6, 186457},
	{"DOYON", 5, 186458},
	{"CARBONITE", 9, 186459},
	{"MONSTERSCHWAENZE", 16, 186460},
	{"POPPNETT", 8, 186461},
	{"DIETHYLSTILBESTROL", 18, 186462},
	{"AGEC", 4, 186463},
	{"CHATLUDER", 9, 186464},
	{"LIVELIER", 8, 186465},
	{"HTTPSERVLETRESPONSE", 19, 186466},
	{"KILA", 4, 186467},
	{"BOYT", 4, 186468},
	{"GERVASE", 7, 186469},
	{"RUBYFORGE", 9, 186470},
	{"UNID", 4, 186471},
	{"CHESLER", 7, 186472},
	{"HYDROXIDES", 10, 186473},
	{"WITTON", 6, 186474},
	{"MIRAMONTE", 9, 186475},
	{"OVERWINTER", 10, 186476},
	{"RJC", 3, 186477},
	{"CALIBERS", 8, 186478},
	{"SEASHORES", 9, 186479},
	{"TRAUMTITTEN", 11, 186480},
	{"PRIMALITY", 9, 186481},
	{"MAEVA", 5, 186482},
	{"NAZTECH", 7, 186483},
	{"HANDBOEK", 8, 186484},
	{"SAWICKY", 7, 186485},
	{"THINKCYCLE", 10, 186486},
	{"MCTIERNAN", 9, 186487},
	{"LIBATA", 6, 186488},
	{"CORRIGENDA", 10, 186489},
	{"PHOTOSOLVE", 10, 186490},
	{"GRENADIERS", 10, 186491},
	{"ANALVIDEOS", 10, 186492},
	{"UEMATSU", 7, 186493},
	{"THOUSANDTHS", 11, 186494},
	{"DENIGRATION", 11, 186495},
	{"BRUIT", 5, 186496},
	{"WORLDHOTELS", 11, 186497},
	{"ACACIAS", 7, 186498},
	{"ZTOB", 4, 186499},
	{"YPMO", 4, 186500},
	{"XICP", 4, 186501},
	{"WOLC", 4, 186502},
	{"VADH", 4, 186503},
	{"UVOI", 4, 186504},
	{"TTUF", 4, 186505},
	{"TDRJ", 4, 186506},
	{"TBUE", 4, 186507},
	{"SVUI", 4, 186508},
	{"RLNO", 4, 186509},
	{"PONX", 4, 186510},
	{"PMYT", 4, 186511},
	{"NPMI", 4, 186512},
	{"NKYU", 4, 186513},
	{"NKEF", 4, 186514},
	{"MNAZ", 4, 186515},
	{"MFOI", 4, 186516},
	{"KOER", 4, 186517},
	{"JOUB", 4, 186518},
	{"IRUA", 4, 186519},
	{"HLDR", 4, 186520},
	{"HABF", 4, 186521},
	{"GBYV", 4, 186522},
	{"FSYT", 4, 186523},
	{"DUOB", 4, 186524},
	{"DRFE", 4, 186525},
	{"CSTW", 4, 186526},
	{"PARTONS", 7, 186527},
	{"MONDAINE", 8, 186528},
	{"MEDECINS", 8, 186529},
	{"MULTIPLAY", 9, 186530},
	{"LIBRERIA", 8, 186531},
	{"TURNHOUT", 8, 186532},
	{"PERFORMANCING", 13, 186533},
	{"QUADE", 5, 186534},
	{"CUEVA", 5, 186535},
	{"BERCOW", 6, 186536},
	{"MAGNANIMITY", 11, 186537},
	{"BRKFST", 6, 186538},
	{"BOPS", 4, 186539},
	{"SUMISAS", 7, 186540},
	{"CAPERNAUM", 9, 186541},
	{"WHITTLESEA", 10, 186542},
	{"ALECK", 5, 186543},
	{"LEUKOPENIA", 10, 186544},
	{"REGRESSING", 10, 186545},
	{"PROPIO", 6, 186546},
	{"HARDTRANCE", 10, 186547},
	{"MONSTERSCHWANZ", 14, 186548},
	{"PASC", 4, 186549},
	{"NATTER", 6, 186550},
	{"SELES", 5, 186551},
	{"WAUSEON", 7, 186552},
	{"MIRTAZAPINE", 11, 186553},
	{"IDOLIZE", 7, 186554},
	{"FIESOLE", 7, 186555},
	{"DRAMMEN", 7, 186556},
	{"COZZI", 5, 186557},
	{"PALESTRA", 8, 186558},
	{"WEBBASED", 8, 186559},
	{"HUPPERT", 7, 186560},
	{"SOUTHWING", 9, 186561},
	{"BENTZ", 5, 186562},
	{"VOMS", 4, 186563},
	{"GLOMERULUS", 10, 186564},
	{"KALDOR", 6, 186565},
	{"CATRINA", 7, 186566},
	{"WEEKLEY", 7, 186567},
	{"NIAMS", 5, 186568},
	{"FRONTCOURT", 10, 186569},
	{"SLOVINSKI", 9, 186570},
	{"LIBGTOP", 7, 186571},
	{"CUU", 3, 186572},
	{"EALY", 4, 186573},
	{"FINUTE", 6, 186574},
	{"WZDFTPD", 7, 186575},
	{"MASOUD", 6, 186576},
	{"WAKARUSA", 8, 186577},
	{"TRICKLES", 8, 186578},
	{"MANDARINE", 9, 186579},
	{"OMWS", 4, 186580},
	{"RISBOROUGH", 10, 186581},
	{"MYOTONIC", 8, 186582},
	{"SAMARIUM", 8, 186583},
	{"HYPERSTUDIO", 11, 186584},
	{"DEMAN", 5, 186585},
	{"BANDAID", 7, 186586},
	{"WOMENSUITS", 10, 186587},
	{"DEEZ", 4, 186588},
	{"UNEX", 4, 186589},
	{"RETICULATA", 10, 186590},
	{"GORTEX", 6, 186591},
	{"RACO", 4, 186592},
	{"OPENUI", 6, 186593},
	{"ICBL", 4, 186594},
	{"LEVL", 4, 186595},
	{"KREMS", 5, 186596},
	{"INSTYTUT", 8, 186597},
	{"HEERLEN", 7, 186598},
	{"SSUES", 5, 186599},
	{"TENNECO", 7, 186600},
	{"REHIRED", 7, 186601},
	{"BONFIELD", 8, 186602},
	{"UGZ", 3, 186603},
	{"ESEMINAR", 8, 186604},
	{"MICROMV", 7, 186605},
	{"DORFMEISTER", 11, 186606},
	{"GALLOPS", 7, 186607},
	{"MATCHBOOKS", 10, 186608},
	{"BIZNETDAILY", 11, 186609},
	{"HIGHMORE", 8, 186610},
	{"BYZANTINES", 10, 186611},
	{"SPORTSTICKER", 12, 186612},
	{"NETBANK", 7, 186613},
	{"THUILE", 6, 186614},
	{"FABRI", 5, 186615},
	{"DISAMBIGUATE", 12, 186616},
	{"RIUM", 4, 186617},
	{"OUTSOURCES", 10, 186618},
	{"COMPENDIA", 9, 186619},
	{"CUNO", 4, 186620},
	{"MISCELLANIA", 11, 186621},
	{"YURL", 4, 186622},
	{"XLED", 4, 186623},
	{"WUNF", 4, 186624},
	{"WOJC", 4, 186625},
	{"WKSN", 4, 186626},
	{"WBYH", 4, 186627},
	{"VSVI", 4, 186628},
	{"VAKO", 4, 186629},
	{"USZA", 4, 186630},
	{"TZGI", 4, 186631},
	{"SHYF", 4, 186632},
	{"RZES", 4, 186633},
	{"PYAP", 4, 186634},
	{"NSGY", 4, 186635},
	{"NPLI", 4, 186636},
	{"NDJD", 4, 186637},
	{"NCLY", 4, 186638},
	{"MPMW", 4, 186639},
	{"LMAE", 4, 186640},
	{"LFMY", 4, 186641},
	{"KWRE", 4, 186642},
	{"KPOE", 4, 186643},
	{"KJEW", 4, 186644},
	{"JPRO", 4, 186645},
	{"IRYQ", 4, 186646},
	{"IMKH", 4, 186647},
	{"IKLO", 4, 186648},
	{"HUEW", 4, 186649},
	{"HMWI", 4, 186650},
	{"HEJB", 4, 186651},
	{"FSTD", 4, 186652},
	{"FMAA", 4, 186653},
	{"FGWY", 4, 186654},
	{"EPKA", 4, 186655},
	{"DRIH", 4, 186656},
	{"DIRH", 4, 186657},
	{"BEHY", 4, 186658},
	{"BCUR", 4, 186659},
	{"MEMEBER", 7, 186660},
	{"EORTC", 5, 186661},
	{"BHEL", 4, 186662},
	{"MATCHINGS", 9, 186663},
	{"LIBGAL", 6, 186664},
	{"GENX", 4, 186665},
	{"DRIPPERS", 8, 186666},
	{"NEWEY", 5, 186667},
	{"MAGPIERSS", 9, 186668},
	{"RETAKING", 8, 186669},
	{"RETAILED", 8, 186670},
	{"KLINGELTOENE", 12, 186671},
	{"FEDERA", 6, 186672},
	{"ATLAN", 5, 186673},
	{"POUTY", 5, 186674},
	{"SAWAI", 5, 186675},
	{"OMAFICKEN", 9, 186676},
	{"STOTTS", 6, 186677},
	{"LUMBOSACRAL", 11, 186678},
	{"PHOTOMINT", 9, 186679},
	{"HOLLOWELL", 9, 186680},
	{"LASERDISCS", 10, 186681},
	{"COREGEN", 7, 186682},
	{"MAVI", 4, 186683},
	{"DEXTEROUS", 9, 186684},
	{"OVIDIU", 6, 186685},
	{"GIRTON", 6, 186686},
	{"CONNAISSANCES", 13, 186687},
	{"ELOG", 4, 186688},
	{"MUSCHICAM", 9, 186689},
	{"MAIMING", 7, 186690},
	{"DSPP", 4, 186691},
	{"ACCQUISITIONS", 13, 186692},
	{"MEMBRI", 6, 186693},
	{"SHEFFORD", 8, 186694},
	{"RESENTATION", 11, 186695},
	{"INSCRIVEZ", 9, 186696},
	{"NORMATIVA", 9, 186697},
	{"CHOCS", 5, 186698},
	{"BIOPRODUCTS", 11, 186699},
	{"BATHER", 6, 186700},
	{"ANNUALREPORT", 12, 186701},
	{"RESPONSABILE", 12, 186702},
	{"ETHIER", 6, 186703},
	{"MAURIN", 6, 186704},
	{"OFDA", 4, 186705},
	{"LOEHR", 5, 186706},
	{"FAIENCE", 7, 186707},
	{"VEENSTRA", 8, 186708},
	{"SONNEL", 6, 186709},
	{"VELOP", 5, 186710},
	{"ILJA", 4, 186711},
	{"GROCE", 5, 186712},
	{"GCALCTOOL", 9, 186713},
	{"CHANTI", 6, 186714},
	{"GREENTOWN", 9, 186715},
	{"TELECHECK", 9, 186716},
	{"ARONOFF", 7, 186717},
	{"ROZA", 4, 186718},
	{"BEAUTE", 6, 186719},
	{"BEAMFORMING", 11, 186720},
	{"ANTITHROMBOTIC", 14, 186721},
	{"LIBHTML", 7, 186722},
	{"KILBORN", 7, 186723},
	{"AURELIEN", 8, 186724},
	{"REXAM", 5, 186725},
	{"EMERICK", 7, 186726},
	{"DISSES", 6, 186727},
	{"CEIR", 4, 186728},
	{"SHACHAR", 7, 186729},
	{"SEROPOSITIVITY", 14, 186730},
	{"GROUNDSKEEPER", 13, 186731},
	{"BOPM", 4, 186732},
	{"INNOVATES", 9, 186733},
	{"YOJI", 4, 186734},
	{"TRIGGS", 6, 186735},
	{"ANTHROPOMETRY", 13, 186736},
	{"INCHON", 6, 186737},
	{"FEASTERVILLE", 12, 186738},
	{"TOLDJAH", 7, 186739},
	{"MRY", 3, 186740},
	{"AHWAHNEE", 8, 186741},
	{"ROTATIONALLY", 12, 186742},
	{"BLAY", 4, 186743},
	{"MASAHIKO", 8, 186744},
	{"FEMOSHOPPING", 12, 186745},
	{"ANTIPIXEL", 9, 186746},
	{"SPEZIALNUTTEN", 13, 186747},
	{"SHIUR", 5, 186748},
	{"MONSTERPIMMEL", 13, 186749},
	{"XMAIL", 5, 186750},
	{"AVANCES", 7, 186751},
	{"NICHENET", 8, 186752},
	{"GENEL", 5, 186753},
	{"REMARRIES", 9, 186754},
	{"ESCON", 5, 186755},
	{"COPYEDITING", 11, 186756},
	{"UMANSKY", 7, 186757},
	{"CHROMOGENIC", 11, 186758},
	{"VASILE", 6, 186759},
	{"ZAPL", 4, 186760},
	{"XPUB", 4, 186761},
	{"WMYT", 4, 186762},
	{"VOFO", 4, 186763},
	{"UARN", 4, 186764},
	{"TVSF", 4, 186765},
	{"TUYV", 4, 186766},
	{"TMIZ", 4, 186767},
	{"TMCF", 4, 186768},
	{"RUZB", 4, 186769},
	{"RKOX", 4, 186770},
	{"RJEL", 4, 186771},
	{"PYTI", 4, 186772},
	{"PPMO", 4, 186773},
	{"PHTR", 4, 186774},
	{"PHGR", 4, 186775},
	{"PAZA", 4, 186776},
	{"MZAN", 4, 186777},
	{"MNSU", 4, 186778},
	{"LIGG", 4, 186779},
	{"LCZY", 4, 186780},
	{"LCEI", 4, 186781},
	{"LBCA", 4, 186782},
	{"KWAZ", 4, 186783},
	{"KGON", 4, 186784},
	{"KCOT", 4, 186785},
	{"JIBI", 4, 186786},
	{"FLEL", 4, 186787},
	{"FCTE", 4, 186788},
	{"EYDF", 4, 186789},
	{"EFDU", 4, 186790},
	{"EFAQ", 4, 186791},
	{"DEKR", 4, 186792},
	{"CRYM", 4, 186793},
	{"BYOX", 4, 186794},
	{"BGOB", 4, 186795},
	{"BGAI", 4, 186796},
	{"VIGNES", 6, 186797},
	{"PHILLIPSON", 10, 186798},
	{"NAMITA", 6, 186799},
	{"KOBUS", 5, 186800},
	{"HARTSELLE", 9, 186801},
	{"MISINTERPRETATIONS", 18, 186802},
	{"ANTHEMIC", 8, 186803},
	{"MARTTI", 6, 186804},
	{"PHENOTHIAZINES", 14, 186805},
	{"BASTED", 6, 186806},
	{"TRILEPTAL", 9, 186807},
	{"LOMBORG", 7, 186808},
	{"VPRINTF", 7, 186809},
	{"PROTISTS", 8, 186810},
	{"OLDTOWN", 7, 186811},
	{"CAMERAWORK", 10, 186812},
	{"MOBILI", 6, 186813},
	{"METABOLICALLY", 13, 186814},
	{"MODERNES", 8, 186815},
	{"PLAYPENS", 8, 186816},
	{"MANDIE", 6, 186817},
	{"SALG", 4, 186818},
	{"RESTRINGIR", 10, 186819},
	{"NMRA", 4, 186820},
	{"PHYSORGFORUM", 12, 186821},
	{"MELNIK", 6, 186822},
	{"ZABRISKIE", 9, 186823},
	{"REPLIESRE", 9, 186824},
	{"NFRC", 4, 186825},
	{"HENZE", 5, 186826},
	{"XUPITER", 7, 186827},
	{"LONGUEVILLE", 11, 186828},
	{"CCTLDS", 6, 186829},
	{"GUNBROKER", 9, 186830},
	{"BELLPORT", 8, 186831},
	{"UNDIGNIFIED", 11, 186832},
	{"CABAZON", 7, 186833},
	{"REAPPLIED", 9, 186834},
	{"EXTREEM", 7, 186835},
	{"SGPP", 4, 186836},
	{"MANNO", 5, 186837},
	{"KATALIN", 7, 186838},
	{"ULTRASONE", 9, 186839},
	{"CZARNECKI", 9, 186840},
	{"TIFFS", 5, 186841},
	{"MCCARROLL", 9, 186842},
	{"CORONEL", 7, 186843},
	{"REICHELT", 8, 186844},
	{"PSILOCYBIN", 10, 186845},
	{"SKYDIVER", 8, 186846},
	{"WILDENHUES", 10, 186847},
	{"OVERFILL", 8, 186848},
	{"STESSO", 6, 186849},
	{"PNFORUMS", 8, 186850},
	{"SUPERBALL", 9, 186851},
	{"MAULING", 7, 186852},
	{"CONFAB", 6, 186853},
	{"CARKIT", 6, 186854},
	{"LOGINFO", 7, 186855},
	{"HOCHMAN", 7, 186856},
	{"SYLVER", 6, 186857},
	{"NORVILLE", 8, 186858},
	{"MULLA", 5, 186859},
	{"CLEAROUT", 8, 186860},
	{"SDSDH", 5, 186861},
	{"CONOCIMIENTO", 12, 186862},
	{"NUMBERLINE", 10, 186863},
	{"NETQUOTE", 8, 186864},
	{"FCW", 3, 186865},
	{"FAVELA", 6, 186866},
	{"GEMELLI", 7, 186867},
	{"MANNATECH", 9, 186868},
	{"ASSENTOR", 8, 186869},
	{"WEBCASTERS", 10, 186870},
	{"DEMUTUALIZATION", 15, 186871},
	{"SKYBLUE", 7, 186872},
	{"ICTF", 4, 186873},
	{"ROPERTY", 7, 186874},
	{"NOFRAMES", 8, 186875},
	{"BERTI", 5, 186876},
	{"WEANLING", 8, 186877},
	{"RASTAFARIAN", 11, 186878},
	{"QUINOLONE", 9, 186879},
	{"BALDER", 6, 186880},
	{"KAINATE", 7, 186881},
	{"CAPPA", 5, 186882},
	{"RESTRIC", 7, 186883},
	{"ADVIWARE", 8, 186884},
	{"SYND", 4, 186885},
	{"MOROCCANS", 9, 186886},
	{"PRICIER", 7, 186887},
	{"DIOGELWCH", 9, 186888},
	{"DEFIN", 5, 186889},
	{"RICCIO", 6, 186890},
	{"MPIOPEROS", 9, 186891},
	{"NEVON", 5, 186892},
	{"MORD", 4, 186893},
	{"ILOKANO", 7, 186894},
	{"FREENX", 6, 186895},
	{"ZARQ", 4, 186896},
	{"WCYC", 4, 186897},
	{"VREV", 4, 186898},
	{"VGRE", 4, 186899},
	{"UNNC", 4, 186900},
	{"UCFS", 4, 186901},
	{"UBYW", 4, 186902},
	{"TKOD", 4, 186903},
	{"TKOC", 4, 186904},
	{"TAKM", 4, 186905},
	{"SYUR", 4, 186906},
	{"RKNJ", 4, 186907},
	{"RGBY", 4, 186908},
	{"REKV", 4, 186909},
	{"QIMI", 4, 186910},
	{"OXGO", 4, 186911},
	{"OUAU", 4, 186912},
	{"ONKG", 4, 186913},
	{"OFUZ", 4, 186914},
	{"MZOR", 4, 186915},
	{"MPHM", 4, 186916},
	{"MAMR", 4, 186917},
	{"LUZZ", 4, 186918},
	{"LTEP", 4, 186919},
	{"LRYP", 4, 186920},
	{"LOXA", 4, 186921},
	{"LOCW", 4, 186922},
	{"LMVI", 4, 186923},
	{"KOZI", 4, 186924},
	{"HAGP", 4, 186925},
	{"GBRY", 4, 186926},
	{"ERWS", 4, 186927},
	{"EDRR", 4, 186928},
	{"DCDR", 4, 186929},
	{"QADIR", 5, 186930},
	{"LANCEOLATA", 10, 186931},
	{"KENNEDALE", 9, 186932},
	{"ENDEAR", 6, 186933},
	{"NEWCON", 6, 186934},
	{"CLASSIS", 7, 186935},
	{"CARRYFORWARDS", 13, 186936},
	{"KINSER", 6, 186937},
	{"OTENET", 6, 186938},
	{"KOBI", 4, 186939},
	{"CUPP", 4, 186940},
	{"INCENT", 6, 186941},
	{"EFFIGIES", 8, 186942},
	{"CEPTS", 5, 186943},
	{"WETHERELL", 9, 186944},
	{"RUNOUT", 6, 186945},
	{"CREEPED", 7, 186946},
	{"DPRINTK", 7, 186947},
	{"YOUNGBLOODZ", 11, 186948},
	{"DYFODOL", 7, 186949},
	{"AUSLAND", 7, 186950},
	{"SKOOG", 5, 186951},
	{"FOLGE", 5, 186952},
	{"COUNTERSIGNED", 13, 186953},
	{"COMTROL", 7, 186954},
	{"SEKOLAH", 7, 186955},
	{"HEPTANE", 7, 186956},
	{"COCKOLD", 7, 186957},
	{"PROJECTIONIST", 13, 186958},
	{"NECKAR", 6, 186959},
	{"LAKSHMAN", 8, 186960},
	{"MURDA", 5, 186961},
	{"JETIX", 5, 186962},
	{"COUNTERACTED", 12, 186963},
	{"MACHIDA", 7, 186964},
	{"BOWTIES", 7, 186965},
	{"THEMEPARK", 9, 186966},
	{"OFFE", 4, 186967},
	{"PRIMEAU", 7, 186968},
	{"ANEUPLOIDY", 10, 186969},
	{"AUTOGENERATED", 13, 186970},
	{"RENDA", 5, 186971},
	{"NEGATIVLAND", 11, 186972},
	{"DIRRTY", 6, 186973},
	{"ACAC", 4, 186974},
	{"BIOTERRORIST", 12, 186975},
	{"INCULATE", 8, 186976},
	{"PRELOADER", 9, 186977},
	{"LIFESONG", 8, 186978},
	{"PORCARO", 7, 186979},
	{"LATIGO", 6, 186980},
	{"SUPERCOMM", 9, 186981},
	{"METR", 4, 186982},
	{"CARBUNCLE", 9, 186983},
	{"PLANKING", 8, 186984},
	{"ITOOLS", 6, 186985},
	{"STEPSISTER", 10, 186986},
	{"GLASSON", 7, 186987},
	{"PREGNACY", 8, 186988},
	{"BINFORD", 7, 186989},
	{"BLOCKHOUSE", 10, 186990},
	{"KIMEL", 5, 186991},
	{"SMARTRIDGE", 10, 186992},
	{"SARKIS", 6, 186993},
	{"VOLD", 4, 186994},
	{"PROCESSEUR", 10, 186995},
	{"BATTE", 5, 186996},
	{"ACPC", 4, 186997},
	{"URABON", 6, 186998},
	{"JMK", 3, 186999},
	{"GRIMLEY", 7, 187000},
	{"TRICOLOUR", 9, 187001},
	{"COPIAR", 6, 187002},
	{"BALAK", 5, 187003},
	{"PLOYS", 5, 187004},
	{"GRUPPENFICK", 11, 187005},
	{"CAIG", 4, 187006},
	{"SERVICEORDER", 12, 187007},
	{"REPOT", 5, 187008},
	{"SUBASSEMBLY", 11, 187009},
	{"SKYTEAM", 7, 187010},
	{"PALLIDA", 7, 187011},
	{"WHITEFRIARS", 11, 187012},
	{"MACSENSE", 8, 187013},
	{"LILIUOKALANI", 12, 187014},
	{"GRAPHIRE", 8, 187015},
	{"RENSET", 6, 187016},
	{"TELEMEDIA", 9, 187017},
	{"LIBGL", 5, 187018},
	{"AIRFOILS", 8, 187019},
	{"LNBACCESSORY", 12, 187020},
	{"RAEFORD", 7, 187021},
	{"GAIRLOCH", 8, 187022},
	{"AUTOFARM", 8, 187023},
	{"NETVOX", 6, 187024},
	{"ZTOM", 4, 187025},
	{"ZILR", 4, 187026},
	{"YFAY", 4, 187027},
	{"XPOA", 4, 187028},
	{"XIEW", 4, 187029},
	{"WOWY", 4, 187030},
	{"UCST", 4, 187031},
	{"TDRB", 4, 187032},
	{"RUTR", 4, 187033},
	{"PUPR", 4, 187034},
	{"PBRU", 4, 187035},
	{"OPMB", 4, 187036},
	{"NUMG", 4, 187037},
	{"NGFC", 4, 187038},
	{"LPSN", 4, 187039},
	{"LPIX", 4, 187040},
	{"LMII", 4, 187041},
	{"LKBR", 4, 187042},
	{"LIXD", 4, 187043},
	{"KHYB", 4, 187044},
	{"KAYR", 4, 187045},
	{"JDIS", 4, 187046},
	{"FSKU", 4, 187047},
	{"EULL", 4, 187048},
	{"EKEG", 4, 187049},
	{"EIJD", 4, 187050},
	{"EAUK", 4, 187051},
	{"DUDO", 4, 187052},
	{"DLUO", 4, 187053},
	{"CKRH", 4, 187054},
	{"BROR", 4, 187055},
	{"ATCD", 4, 187056},
	{"ABIY", 4, 187057},
	{"ABBH", 4, 187058},
	{"SHEEPDOGS", 9, 187059},
	{"AGPS", 4, 187060},
	{"THEAD", 5, 187061},
	{"IMPAX", 5, 187062},
	{"FLOREY", 6, 187063},
	{"DEDUCTABLE", 10, 187064},
	{"HENRYS", 6, 187065},
	{"CILIP", 5, 187066},
	{"SHLIB", 5, 187067},
	{"EGOISTE", 7, 187068},
	{"IMPEACHING", 10, 187069},
	{"LALANDE", 7, 187070},
	{"RHAGFYR", 7, 187071},
	{"FERGS", 5, 187072},
	{"ESCITALOPRAM", 12, 187073},
	{"UMG", 3, 187074},
	{"ROTTER", 6, 187075},
	{"DISCORDIA", 9, 187076},
	{"CONFIANCE", 9, 187077},
	{"IHOME", 5, 187078},
	{"HONOURARY", 9, 187079},
	{"INOCENCIA", 9, 187080},
	{"VERTICALRESPONSE", 16, 187081},
	{"GARLICK", 7, 187082},
	{"MLX", 3, 187083},
	{"URBANITY", 8, 187084},
	{"SPANNERFOTOS", 12, 187085},
	{"GWELLA", 6, 187086},
	{"FURUHASHI", 9, 187087},
	{"OVERSHADOWS", 11, 187088},
	{"ASPRS", 5, 187089},
	{"MONFORT", 7, 187090},
	{"SOUNDPOINT", 10, 187091},
	{"ETHERBOOT", 9, 187092},
	{"STONEMASONS", 11, 187093},
	{"PARKROYAL", 9, 187094},
	{"LECHEROUS", 9, 187095},
	{"PETERBURG", 9, 187096},
	{"LATKES", 6, 187097},
	{"CCCA", 4, 187098},
	{"BEECROFT", 8, 187099},
	{"VUNG", 4, 187100},
	{"BRYNN", 5, 187101},
	{"OSTEOCLAST", 10, 187102},
	{"FROGNET", 7, 187103},
	{"BREAKCORE", 9, 187104},
	{"MCJ", 3, 187105},
	{"ROLA", 4, 187106},
	{"PCUSA", 5, 187107},
	{"LAWGIVER", 8, 187108},
	{"FREHLEY", 7, 187109},
	{"OCAP", 4, 187110},
	{"SJOERD", 6, 187111},
	{"SPIEGELAU", 9, 187112},
	{"PERSPIRANT", 10, 187113},
	{"PRIVILEGING", 11, 187114},
	{"BIGGIES", 7, 187115},
	{"MAGLOIRE", 8, 187116},
	{"RAZORBLADE", 10, 187117},
	{"WORKSOURCE", 10, 187118},
	{"CAMHS", 5, 187119},
	{"TOTTER", 6, 187120},
	{"PHOTOBIOLOGY", 12, 187121},
	{"RUMPLED", 7, 187122},
	{"METEOS", 6, 187123},
	{"HUNCHES", 7, 187124},
	{"IEXPLORER", 9, 187125},
	{"TORIN", 5, 187126},
	{"FALCONBRIDGE", 12, 187127},
	{"RAHALL", 6, 187128},
	{"QOTW", 4, 187129},
	{"PUTTANE", 7, 187130},
	{"CONCUSSIONS", 11, 187131},
	{"BASRAH", 6, 187132},
	{"TELECOMUNICACIONES", 18, 187133},
	{"TALWIN", 6, 187134},
	{"IDEAZON", 7, 187135},
	{"PENALISE", 8, 187136},
	{"PASSIONFRUIT", 12, 187137},
	{"TEMAN", 5, 187138},
	{"PENALIZES", 9, 187139},
	{"MIRLE", 5, 187140},
	{"LANYON", 6, 187141},
	{"HEATPIPE", 8, 187142},
	{"BIOASTRO", 8, 187143},
	{"BRONCHIECTASIS", 14, 187144},
	{"SCALDED", 7, 187145},
	{"OPENLAB", 7, 187146},
	{"MEOLA", 5, 187147},
	{"BLIGHTY", 7, 187148},
	{"RIESS", 5, 187149},
	{"IMPORTATIONS", 12, 187150},
	{"FLOM", 4, 187151},
	{"TREMENTINA", 10, 187152},
	{"LIBESKIND", 9, 187153},
	{"DEPORTEES", 9, 187154},
	{"COUTSOUKIS", 10, 187155},
	{"JAZZMAN", 7, 187156},
	{"FINISAR", 7, 187157},
	{"STAUBER", 7, 187158},
	{"TIMECARD", 8, 187159},
	{"RIBULOSE", 8, 187160},
	{"MICROMUSE", 9, 187161},
	{"KARTIK", 6, 187162},
	{"RADM", 4, 187163},
	{"SQUEAKER", 8, 187164},
	{"SATPRINTS", 9, 187165},
	{"PFGE", 4, 187166},
	{"LEVU", 4, 187167},
	{"ROCS", 4, 187168},
	{"PROUDFOOT", 9, 187169},
	{"OMELETTES", 9, 187170},
	{"WINNICK", 7, 187171},
	{"ZEQU", 4, 187172},
	{"UJRA", 4, 187173},
	{"SPCI", 4, 187174},
	{"RVST", 4, 187175},
	{"RECB", 4, 187176},
	{"RBAE", 4, 187177},
	{"PCOC", 4, 187178},
	{"MYIF", 4, 187179},
	{"LUCL", 4, 187180},
	{"KYPU", 4, 187181},
	{"KLYY", 4, 187182},
	{"IVLI", 4, 187183},
	{"IUDI", 4, 187184},
	{"IJME", 4, 187185},
	{"IBEK", 4, 187186},
	{"GYML", 4, 187187},
	{"FLUZ", 4, 187188},
	{"EZJO", 4, 187189},
	{"ELHC", 4, 187190},
	{"DTUG", 4, 187191},
	{"DGNA", 4, 187192},
	{"DFCO", 4, 187193},
	{"DCBU", 4, 187194},
	{"CPOO", 4, 187195},
	{"SNOWBOUND", 9, 187196},
	{"MEDEVAC", 7, 187197},
	{"LUOYANG", 7, 187198},
	{"CARTOONY", 8, 187199},
	{"UMLS", 4, 187200},
	{"FLAMIN", 6, 187201},
	{"DOMANDE", 7, 187202},
	{"PARTOF", 6, 187203},
	{"PARTIESQUOT", 11, 187204},
	{"BIKEWAYS", 8, 187205},
	{"SITECREATORS", 12, 187206},
	{"JIANGMEN", 8, 187207},
	{"GOBOLINUX", 9, 187208},
	{"FRONTERAS", 9, 187209},
	{"MONTESANO", 9, 187210},
	{"CONFIDES", 8, 187211},
	{"PLEASINGLY", 10, 187212},
	{"PEDUNCLE", 8, 187213},
	{"BOLI", 4, 187214},
	{"AFROCENTRIC", 11, 187215},
	{"BOTAN", 5, 187216},
	{"PERSIS", 6, 187217},
	{"HAMSTRUNG", 9, 187218},
	{"PORTSIDE", 8, 187219},
	{"BRYOPHYTES", 10, 187220},
	{"HOROSKOP", 8, 187221},
	{"FIORANO", 7, 187222},
	{"PRINTVERSION", 12, 187223},
	{"WILHITE", 7, 187224},
	{"SERENADES", 9, 187225},
	{"SMID", 4, 187226},
	{"REALISATIONS", 12, 187227},
	{"DOWNLIGHT", 9, 187228},
	{"FAITHPOINT", 10, 187229},
	{"PLAYLOUDER", 10, 187230},
	{"ZUX", 3, 187231},
	{"ZJJ", 3, 187232},
	{"ZFZ", 3, 187233},
	{"XKV", 3, 187234},
	{"VZP", 3, 187235},
	{"UVX", 3, 187236},
	{"QWP", 3, 187237},
	{"QQF", 3, 187238},
	{"QKR", 3, 187239},
	{"PWX", 3, 187240},
	{"KZV", 3, 187241},
	{"GWQ", 3, 187242},
	{"CQQ", 3, 187243},
	{"BGZ", 3, 187244},
	{"LAUGHINGLY", 10, 187245},
	{"BRICKWORKS", 10, 187246},
	{"OCONUS", 6, 187247},
	{"GANANOQUE", 9, 187248},
	{"IPOWER", 6, 187249},
	{"FUNTIME", 7, 187250},
	{"TUBINGEN", 8, 187251},
	{"SPIKER", 6, 187252},
	{"SAREX", 5, 187253},
	{"MEGABIOTICS", 11, 187254},
	{"BOOMKAT", 7, 187255},
	{"STREICHER", 9, 187256},
	{"ICASA", 5, 187257},
	{"PREFACES", 8, 187258},
	{"INCRE", 5, 187259},
	{"LLANDOVERY", 10, 187260},
	{"DOLPHY", 6, 187261},
	{"COGHILL", 7, 187262},
	{"WALLACEBURG", 11, 187263},
	{"LIVEHELP", 8, 187264},
	{"HOLMQUIST", 9, 187265},
	{"QAWWALI", 7, 187266},
	{"EARLOBE", 7, 187267},
	{"BUSYBODIES", 10, 187268},
	{"WITCHED", 7, 187269},
	{"CAID", 4, 187270},
	{"EASTERNERS", 10, 187271},
	{"PACKAGINGS", 10, 187272},
	{"EPTEMBER", 8, 187273},
	{"TITTENFICKEN", 12, 187274},
	{"FEASIBLY", 8, 187275},
	{"LEVBID", 6, 187276},
	{"BOLS", 4, 187277},
	{"KADUNA", 6, 187278},
	{"EDIFY", 5, 187279},
	{"SCHMOE", 6, 187280},
	{"DOCKAGE", 7, 187281},
	{"TRAVELSOUND", 11, 187282},
	{"SURVIVALINK", 11, 187283},
	{"ECONOMICI", 9, 187284},
	{"FARQUHARSON", 11, 187285},
	{"DUIN", 4, 187286},
	{"POLYOLS", 7, 187287},
	{"IMAGINI", 7, 187288},
	{"TENUE", 5, 187289},
	{"KAOLINITE", 9, 187290},
	{"IDOLATERS", 9, 187291},
	{"IMPERMISSIBLY", 13, 187292},
	{"NOTHINGFACE", 11, 187293},
	{"WEITERLESEN", 11, 187294},
	{"CHALCEDON", 9, 187295},
	{"MBIA", 4, 187296},
	{"WUMPSCUT", 8, 187297},
	{"KRYDDKAKA", 9, 187298},
	{"PIKER", 5, 187299},
	{"EGENIX", 6, 187300},
	{"SPRAT", 5, 187301},
	{"SEDUCER", 7, 187302},
	{"OBJCOPY", 7, 187303},
	{"PRYDAIN", 7, 187304},
	{"TABLESPACES", 11, 187305},
	{"SSDAN", 5, 187306},
	{"LYRIX", 5, 187307},
	{"ASKJEEVE", 8, 187308},
	{"YMUH", 4, 187309},
	{"XERE", 4, 187310},
	{"WACU", 4, 187311},
	{"UKHT", 4, 187312},
	{"UBTP", 4, 187313},
	{"UANX", 4, 187314},
	{"TZFR", 4, 187315},
	{"SUMR", 4, 187316},
	{"SSUK", 4, 187317},
	{"SKBR", 4, 187318},
	{"RPAO", 4, 187319},
	{"RBSR", 4, 187320},
	{"NSPC", 4, 187321},
	{"MHUL", 4, 187322},
	{"MHIP", 4, 187323},
	{"MCEV", 4, 187324},
	{"LNGO", 4, 187325},
	{"KUSD", 4, 187326},
	{"KRAH", 4, 187327},
	{"IMBH", 4, 187328},
	{"HYGU", 4, 187329},
	{"HWYA", 4, 187330},
	{"HPMI", 4, 187331},
	{"GYOP", 4, 187332},
	{"GYGU", 4, 187333},
	{"GPRU", 4, 187334},
	{"GIWE", 4, 187335},
	{"EZPU", 4, 187336},
	{"DZES", 4, 187337},
	{"DKUS", 4, 187338},
	{"DKMW", 4, 187339},
	{"CPTH", 4, 187340},
	{"AYDY", 4, 187341},
	{"AXYC", 4, 187342},
	{"LOPERS", 6, 187343},
	{"DUMMER", 6, 187344},
	{"FICKMAUS", 8, 187345},
	{"VIDEOREDO", 9, 187346},
	{"KLEZMATICS", 10, 187347},
	{"SPORTSWEB", 9, 187348},
	{"COMERCIALES", 11, 187349},
	{"YOSHIMI", 7, 187350},
	{"FAMAGUSTA", 9, 187351},
	{"ROTARACT", 8, 187352},
	{"MASQUERADES", 11, 187353},
	{"STROUSTRUP", 10, 187354},
	{"SEALYHAM", 8, 187355},
	{"TRANSM", 6, 187356},
	{"MYWAY", 5, 187357},
	{"SEVERINO", 8, 187358},
	{"CHANS", 5, 187359},
	{"MACPLAY", 7, 187360},
	{"JONNIE", 6, 187361},
	{"BRAESIDE", 8, 187362},
	{"TULLOW", 6, 187363},
	{"TEENNUTTEN", 10, 187364},
	{"PRICY", 5, 187365},
	{"CUTTIN", 6, 187366},
	{"REPA", 4, 187367},
	{"FICKDATE", 8, 187368},
	{"ATTARD", 6, 187369},
	{"MUMOL", 5, 187370},
	{"LIGHTHEADED", 11, 187371},
	{"IMPELLERS", 9, 187372},
	{"PROJECTRECENT", 13, 187373},
	{"WANNER", 6, 187374},
	{"BOOTFICK", 8, 187375},
	{"VINGE", 5, 187376},
	{"SEVERO", 6, 187377},
	{"DITECH", 6, 187378},
	{"HAIRE", 5, 187379},
	{"HLINE", 5, 187380},
	{"CIUTAT", 6, 187381},
	{"TROYA", 5, 187382},
	{"MELLA", 5, 187383},
	{"ENMIC", 5, 187384},
	{"BARBOURVILLE", 12, 187385},
	{"TENACIOUSLY", 11, 187386},
	{"SHAWNIGAN", 9, 187387},
	{"SAMIA", 5, 187388},
	{"NAMESPACEURI", 12, 187389},
	{"ROOTSTOCKS", 10, 187390},
	{"FEKKAI", 6, 187391},
	{"INSCRIT", 7, 187392},
	{"MAXLINE", 7, 187393},
	{"GEOCACHES", 9, 187394},
	{"HORWATH", 7, 187395},
	{"FUNCS", 5, 187396},
	{"ASSUMABLE", 9, 187397},
	{"MARRING", 7, 187398},
	{"IFTHE", 5, 187399},
	{"GARRITAN", 8, 187400},
	{"MOONBEAMS", 9, 187401},
	{"CARVAJAL", 8, 187402},
	{"MATZO", 5, 187403},
	{"INCULCATED", 10, 187404},
	{"GARIN", 5, 187405},
	{"PETRAS", 6, 187406},
	{"MANDERS", 7, 187407},
	{"SCRE", 4, 187408},
	{"MONATE", 6, 187409},
	{"EXCITONS", 8, 187410},
	{"IZAAK", 5, 187411},
	{"ESFAHAN", 7, 187412},
	{"ELINI", 5, 187413},
	{"TRADEEASY", 9, 187414},
	{"NONDEPOSITORY", 13, 187415},
	{"MUNDT", 5, 187416},
	{"SNAVELY", 7, 187417},
	{"NETSUPPORT", 10, 187418},
	{"DONAHOE", 7, 187419},
	{"KOZMIX", 6, 187420},
	{"CEREBUS", 7, 187421},
	{"BACKFILE", 8, 187422},
	{"REMOV", 5, 187423},
	{"QUADRILLION", 11, 187424},
	{"LIBE", 4, 187425},
	{"BALLISTA", 8, 187426},
	{"HOODLUMS", 8, 187427},
	{"DYESTUFFS", 9, 187428},
	{"HEMORRHAGING", 12, 187429},
	{"ELKINGTON", 9, 187430},
	{"FUNGIBLE", 8, 187431},
	{"OGASAWARA", 9, 187432},
	{"CTCP", 4, 187433},
	{"VERSCHIEDENE", 12, 187434},
	{"GICLEES", 7, 187435},
	{"POLLER", 6, 187436},
	{"DBPSK", 5, 187437},
	{"WORSHAM", 7, 187438},
	{"SUMATERA", 8, 187439},
	{"ALTIERI", 7, 187440},
	{"CONSUM", 6, 187441},
	{"WOHIN", 5, 187442},
	{"STALAG", 6, 187443},
	{"PHYSIKALISCHE", 13, 187444},
	{"MEDNET", 6, 187445},
	{"BOCCONI", 7, 187446},
	{"GVRP", 4, 187447},
	{"FINELINE", 8, 187448},
	{"DEMISED", 7, 187449},
	{"HUISMAN", 7, 187450},
	{"MANTENO", 7, 187451},
	{"STIEFELFETISCH", 14, 187452},
	{"LILE", 4, 187453},
	{"JALIL", 5, 187454},
	{"WINKELS", 7, 187455},
	{"ZUMW", 4, 187456},
	{"ZGUI", 4, 187457},
	{"YIRS", 4, 187458},
	{"XRAD", 4, 187459},
	{"URDJ", 4, 187460},
	{"UOOR", 4, 187461},
	{"UMEJ", 4, 187462},
	{"TUKH", 4, 187463},
	{"TCCH", 4, 187464},
	{"RUPK", 4, 187465},
	{"RPSG", 4, 187466},
	{"RCKI", 4, 187467},
	{"QICO", 4, 187468},
	{"OBKN", 4, 187469},
	{"NHYM", 4, 187470},
	{"MHEK", 4, 187471},
	{"LOER", 4, 187472},
	{"LGOC", 4, 187473},
	{"KUTU", 4, 187474},
	{"KAUK", 4, 187475},
	{"IKOY", 4, 187476},
	{"IGOG", 4, 187477},
	{"FYUS", 4, 187478},
	{"ERQA", 4, 187479},
	{"ERLP", 4, 187480},
	{"EFSG", 4, 187481},
	{"DRJU", 4, 187482},
	{"CHZA", 4, 187483},
	{"AYRT", 4, 187484},
	{"AWKD", 4, 187485},
	{"APTD", 4, 187486},
	{"AKYP", 4, 187487},
	{"AKJO", 4, 187488},
	{"AKGE", 4, 187489},
	{"KILRUSH", 7, 187490},
	{"GEHRKE", 6, 187491},
	{"SERVICEMIX", 10, 187492},
	{"JRG", 3, 187493},
	{"VEXTREC", 7, 187494},
	{"TIDELANDS", 9, 187495},
	{"SAPWOOD", 7, 187496},
	{"MENUDO", 6, 187497},
	{"NEWVILLE", 8, 187498},
	{"LIMONENE", 8, 187499},
	{"INSERTABLE", 10, 187500},
	{"GDESKLETS", 9, 187501},
	{"RONDELLE", 8, 187502},
	{"YIGAL", 5, 187503},
	{"SUPRESS", 7, 187504},
	{"BORAH", 5, 187505},
	{"ASIATEENS", 9, 187506},
	{"PITCHFORD", 9, 187507},
	{"MULTITOOLS", 10, 187508},
	{"MEULEN", 6, 187509},
	{"PHLX", 4, 187510},
	{"UNMONITORED", 11, 187511},
	{"APARICIO", 8, 187512},
	{"IMPACTO", 7, 187513},
	{"CEDU", 4, 187514},
	{"ESSENTIEL", 9, 187515},
	{"COBEN", 5, 187516},
	{"DEMAR", 5, 187517},
	{"RPGHOST", 7, 187518},
	{"MUSEUMSKUNST", 12, 187519},
	{"GENERALL", 8, 187520},
	{"PUMPERS", 7, 187521},
	{"QUINNE", 6, 187522},
	{"TURBOESPRIT", 11, 187523},
	{"THURMONT", 8, 187524},
	{"PRISMACOLOR", 11, 187525},
	{"CROESO", 6, 187526},
	{"NUREG", 5, 187527},
	{"CHIK", 4, 187528},
	{"ULTRAFLEX", 9, 187529},
	{"SAMUT", 5, 187530},
	{"FITING", 6, 187531},
	{"SLIPPIN", 7, 187532},
	{"SCANTRON", 8, 187533},
	{"REPOSED", 7, 187534},
	{"MANADO", 6, 187535},
	{"ATTILIO", 7, 187536},
	{"GIFTWAREHOUSE", 13, 187537},
	{"SACCHI", 6, 187538},
	{"COLDITZ", 7, 187539},
	{"VINTEN", 6, 187540},
	{"BISNIS", 6, 187541},
	{"CSUF", 4, 187542},
	{"INCORPO", 7, 187543},
	{"UDUPI", 5, 187544},
	{"KINGLET", 7, 187545},
	{"KEYCORP", 7, 187546},
	{"HONEYD", 6, 187547},
	{"SUBSITES", 8, 187548},
	{"SPERMADUSCHE", 12, 187549},
	{"KINETOCHORE", 11, 187550},
	{"CICERONE", 8, 187551},
	{"JOSHPET", 7, 187552},
	{"ASPESI", 6, 187553},
	{"MUSTACHES", 9, 187554},
	{"DERATING", 8, 187555},
	{"UTPA", 4, 187556},
	{"GEMLIGHT", 8, 187557},
	{"SECRETARYS", 10, 187558},
	{"GOSSAGE", 7, 187559},
	{"TRIFLUOROMETHYL", 15, 187560},
	{"HASARD", 6, 187561},
	{"COMMUNICATIE", 12, 187562},
	{"PUGWASH", 7, 187563},
	{"MINAKO", 6, 187564},
	{"FSIGNED", 7, 187565},
	{"MICROENVIRONMENT", 16, 187566},
	{"LEDDY", 5, 187567},
	{"TELALASKA", 9, 187568},
	{"BOOKPLATES", 10, 187569},
	{"UNALASKA", 8, 187570},
	{"FICKORGIEN", 10, 187571},
	{"FFLFFL", 6, 187572},
	{"MILDEST", 7, 187573},
	{"MASTED", 6, 187574},
	{"MGJ", 3, 187575},
	{"SUBHUMAN", 8, 187576},
	{"CHRONOGRAPHS", 12, 187577},
	{"PBDES", 5, 187578},
	{"BJU", 3, 187579},
	{"UNDERCLASSMEN", 13, 187580},
	{"TREW", 4, 187581},
	{"DISPO", 5, 187582},
	{"YEVG", 4, 187583},
	{"YESQ", 4, 187584},
	{"WPOE", 4, 187585},
	{"WLOD", 4, 187586},
	{"WENY", 4, 187587},
	{"VYGR", 4, 187588},
	{"SHYR", 4, 187589},
	{"SAXL", 4, 187590},
	{"PCSE", 4, 187591},
	{"PAAD", 4, 187592},
	{"OUTX", 4, 187593},
	{"OUDK", 4, 187594},
	{"OLKU", 4, 187595},
	{"KEDZ", 4, 187596},
	{"IBUK", 4, 187597},
	{"HSBL", 4, 187598},
	{"FYPE", 4, 187599},
	{"FUTS", 4, 187600},
	{"EDTD", 4, 187601},
	{"DDRL", 4, 187602},
	{"BYMT", 4, 187603},
	{"BYCM", 4, 187604},
	{"BEYM", 4, 187605},
	{"OUTLAWZ", 7, 187606},
	{"LAVALIFE", 8, 187607},
	{"PORTIMAO", 8, 187608},
	{"RESTLESSLY", 10, 187609},
	{"IPGN", 4, 187610},
	{"GREENYES", 8, 187611},
	{"USELESSNESS", 11, 187612},
	{"CRANIO", 6, 187613},
	{"BONBON", 6, 187614},
	{"MYCOSES", 7, 187615},
	{"ZVENTS", 6, 187616},
	{"LDK", 3, 187617},
	{"LEZEN", 5, 187618},
	{"DOVETAILED", 10, 187619},
	{"BORCHARDT", 9, 187620},
	{"WMETH", 5, 187621},
	{"ERWACHSENE", 10, 187622},
	{"CATIONAL", 8, 187623},
	{"PUKED", 5, 187624},
	{"PEDDLED", 7, 187625},
	{"NEWIDIADAU", 10, 187626},
	{"EXTERNER", 8, 187627},
	{"DISTRIBUTERS", 12, 187628},
	{"CROME", 5, 187629},
	{"UNGROUNDED", 10, 187630},
	{"PHILIPINO", 9, 187631},
	{"EARFUL", 6, 187632},
	{"MUZIKA", 6, 187633},
	{"OAKEN", 5, 187634},
	{"MAPPIN", 6, 187635},
	{"MALKA", 5, 187636},
	{"CLEMENCE", 8, 187637},
	{"TEENMOESE", 9, 187638},
	{"GEOLAB", 6, 187639},
	{"FALLOWFIELD", 11, 187640},
	{"ESTRAZIONE", 10, 187641},
	{"SIXX", 4, 187642},
	{"VALENTIA", 8, 187643},
	{"MOVIEMAKING", 11, 187644},
	{"LAUGHABLY", 9, 187645},
	{"KNEECAP", 7, 187646},
	{"FOLHA", 5, 187647},
	{"FICKSPALTE", 10, 187648},
	{"CIPRIANO", 8, 187649},
	{"PAOK", 4, 187650},
	{"ENFERMEDAD", 10, 187651},
	{"CALCIFICATIONS", 14, 187652},
	{"ATELIERS", 8, 187653},
	{"IMMUNIZING", 10, 187654},
	{"CAMION", 6, 187655},
	{"SUGARLESS", 9, 187656},
	{"AUTOMATISCH", 11, 187657},
	{"HAUGH", 5, 187658},
	{"ENDROIT", 7, 187659},
	{"HOMETHE", 7, 187660},
	{"SNIFFLE", 7, 187661},
	{"TEENIEFICK", 10, 187662},
	{"JUNHO", 5, 187663},
	{"TALLASSEE", 9, 187664},
	{"CONTESTATION", 12, 187665},
	{"SONGMEANINGS", 12, 187666},
	{"LISTENIN", 8, 187667},
	{"AGRITOURISM", 11, 187668},
	{"JEFFREE", 7, 187669},
	{"HANDBILLS", 9, 187670},
	{"FOGEY", 5, 187671},
	{"CHATWIN", 7, 187672},
	{"CENTRELINE", 10, 187673},
	{"TOMMEE", 6, 187674},
	{"SICSTUS", 7, 187675},
	{"GETC", 4, 187676},
	{"CATAMOUNT", 9, 187677},
	{"ARRANGMENTS", 11, 187678},
	{"ENTICES", 7, 187679},
	{"EDITAR", 6, 187680},
	{"MULTIGENE", 9, 187681},
	{"MAPSEND", 7, 187682},
	{"SLUSHY", 6, 187683},
	{"MARILY", 6, 187684},
	{"BRESSLER", 8, 187685},
	{"NURIT", 5, 187686},
	{"THANJAVUR", 9, 187687},
	{"RECCE", 5, 187688},
	{"HARLOTS", 7, 187689},
	{"FAHAD", 5, 187690},
	{"CONDUITE", 8, 187691},
	{"AFRI", 4, 187692},
	{"SCAPEGOATING", 12, 187693},
	{"LIVI", 4, 187694},
	{"MASKER", 6, 187695},
	{"UNITLESS", 8, 187696},
	{"SYNTAXIN", 8, 187697},
	{"GUARALDI", 8, 187698},
	{"TRIPPERS", 8, 187699},
	{"NSLDS", 5, 187700},
	{"TWEEKS", 6, 187701},
	{"PICTOGRAPHS", 11, 187702},
	{"MYPROGS", 7, 187703},
	{"MINDPRINT", 9, 187704},
	{"FILENO", 6, 187705},
	{"SESSUM", 6, 187706},
	{"ROUGES", 6, 187707},
	{"HUMOURS", 7, 187708},
	{"DUSCHCAM", 8, 187709},
	{"BACKCOVER", 9, 187710},
	{"SPARKLEHORSE", 12, 187711},
	{"NATURALISED", 11, 187712},
	{"EINLOGGEN", 9, 187713},
	{"STAWELL", 7, 187714},
	{"REDON", 5, 187715},
	{"UYGUR", 5, 187716},
	{"HASSALL", 7, 187717},
	{"FREENUDE", 8, 187718},
	{"CSAC", 4, 187719},
	{"BIBLIOTHEQUE", 12, 187720},
	{"TRACHEOTOMY", 11, 187721},
	{"JALEN", 5, 187722},
	{"GLIPIZIDE", 9, 187723},
	{"PICTURESOF", 10, 187724},
	{"DEROSE", 6, 187725},
	{"ZEBL", 4, 187726},
	{"ZAIW", 4, 187727},
	{"YYAL", 4, 187728},
	{"YWEO", 4, 187729},
	{"YKMA", 4, 187730},
	{"YDPA", 4, 187731},
	{"XBOW", 4, 187732},
	{"WMYP", 4, 187733},
	{"WJIM", 4, 187734},
	{"VUEA", 4, 187735},
	{"UBEU", 4, 187736},
	{"UAFF", 4, 187737},
	{"TYCY", 4, 187738},
	{"ROOU", 4, 187739},
	{"RGCE", 4, 187740},
	{"PUPL", 4, 187741},
	{"PMTR", 4, 187742},
	{"PHWO", 4, 187743},
	{"OUZH", 4, 187744},
	{"OLUA", 4, 187745},
	{"NGUW", 4, 187746},
	{"MNLY", 4, 187747},
	{"MIXP", 4, 187748},
	{"MEYI", 4, 187749},
	{"KUNN", 4, 187750},
	{"KERZ", 4, 187751},
	{"HGAD", 4, 187752},
	{"GOIC", 4, 187753},
	{"GIDT", 4, 187754},
	{"FHMS", 4, 187755},
	{"ERVP", 4, 187756},
	{"EJOP", 4, 187757},
	{"DEOQ", 4, 187758},
	{"DAEC", 4, 187759},
	{"CKKU", 4, 187760},
	{"CGRU", 4, 187761},
	{"BCNO", 4, 187762},
	{"VLV", 3, 187763},
	{"MINIATUR", 8, 187764},
	{"VITICULTURAL", 12, 187765},
	{"GULATI", 6, 187766},
	{"CHAMFER", 7, 187767},
	{"MOKELUMNE", 9, 187768},
	{"DUXUSER", 7, 187769},
	{"CBZ", 3, 187770},
	{"ANALIZED", 8, 187771},
	{"TROWER", 6, 187772},
	{"ALESTRON", 8, 187773},
	{"LABE", 4, 187774},
	{"REHASHING", 9, 187775},
	{"LINKDOMAIN", 10, 187776},
	{"REPLENISHES", 11, 187777},
	{"HUMAIN", 6, 187778},
	{"APPLECROSS", 10, 187779},
	{"MELODIJAS", 9, 187780},
	{"ANFRAGE", 7, 187781},
	{"WYD", 3, 187782},
	{"KAPERS", 6, 187783},
	{"KARUP", 5, 187784},
	{"GAUR", 4, 187785},
	{"DATABANKS", 9, 187786},
	{"APSLEY", 6, 187787},
	{"ACHME", 5, 187788},
	{"WEBUSER", 7, 187789},
	{"SANDLES", 7, 187790},
	{"KRATOS", 6, 187791},
	{"AMTRADE", 7, 187792},
	{"CENTAURUS", 9, 187793},
	{"COLORMODE", 9, 187794},
	{"BROLIN", 6, 187795},
	{"AGAMA", 5, 187796},
	{"WADDING", 7, 187797},
	{"GRIECO", 6, 187798},
	{"THERRIEN", 8, 187799},
	{"SPYSWEEPER", 10, 187800},
	{"PSRC", 4, 187801},
	{"POLGAR", 6, 187802},
	{"DUNNVILLE", 9, 187803},
	{"SPEEDERS", 8, 187804},
	{"REDRAWS", 7, 187805},
	{"METACOGNITION", 13, 187806},
	{"INADVISABLE", 11, 187807},
	{"SUHR", 4, 187808},
	{"HISPANA", 7, 187809},
	{"VIVATAR", 7, 187810},
	{"QUIC", 4, 187811},
	{"CSFBL", 5, 187812},
	{"VOLTAIC", 7, 187813},
	{"SECON", 5, 187814},
	{"KITTIN", 6, 187815},
	{"GAMSE", 5, 187816},
	{"GALLAZ", 6, 187817},
	{"DERRIERE", 8, 187818},
	{"SPETTACOLO", 10, 187819},
	{"KELLYVILLE", 10, 187820},
	{"SUFFRAGETTE", 11, 187821},
	{"FRENI", 5, 187822},
	{"PALATABILITY", 12, 187823},
	{"MEGAPHONES", 10, 187824},
	{"PASQUAL", 7, 187825},
	{"CHOCOHOLIC", 10, 187826},
	{"CODICES", 7, 187827},
	{"BEECRYPT", 8, 187828},
	{"AUSTAD", 6, 187829},
	{"CONSUMERWATCH", 13, 187830},
	{"RMAGIC", 6, 187831},
	{"ALINGHI", 7, 187832},
	{"STRECH", 6, 187833},
	{"COTABATO", 8, 187834},
	{"NETDOCTOR", 9, 187835},
	{"TIMEBOMB", 8, 187836},
	{"PILOTES", 7, 187837},
	{"LINKLIST", 8, 187838},
	{"FATCAT", 6, 187839},
	{"ESTERIFIED", 10, 187840},
	{"CIFOR", 5, 187841},
	{"XLVIII", 6, 187842},
	{"DAIMYO", 6, 187843},
	{"RUEBEN", 6, 187844},
	{"DYNES", 5, 187845},
	{"CENSUSSCOPE", 11, 187846},
	{"FLOT", 4, 187847},
	{"CUDGEL", 6, 187848},
	{"AURAIT", 6, 187849},
	{"SMARTADS", 8, 187850},
	{"MYNIX", 5, 187851},
	{"GMELIN", 6, 187852},
	{"TRISOL", 6, 187853},
	{"TARHEEL", 7, 187854},
	{"EPMD", 4, 187855},
	{"STANDAR", 7, 187856},
	{"MARASCHINO", 10, 187857},
	{"DAVIDSEN", 8, 187858},
	{"AODV", 4, 187859},
	{"ZGRE", 4, 187860},
	{"ZFIE", 4, 187861},
	{"YCUE", 4, 187862},
	{"XSDE", 4, 187863},
	{"WROY", 4, 187864},
	{"TVAF", 4, 187865},
	{"TNUD", 4, 187866},
	{"SPPT", 4, 187867},
	{"SDBA", 4, 187868},
	{"RKRY", 4, 187869},
	{"PLIQ", 4, 187870},
	{"PIGH", 4, 187871},
	{"OZLE", 4, 187872},
	{"NYCS", 4, 187873},
	{"IFOP", 4, 187874},
	{"GTYR", 4, 187875},
	{"GAAM", 4, 187876},
	{"EYPM", 4, 187877},
	{"EUXI", 4, 187878},
	{"ECDM", 4, 187879},
	{"EBOZ", 4, 187880},
	{"DJOG", 4, 187881},
	{"TRAFFICKER", 10, 187882},
	{"MIDKIFF", 7, 187883},
	{"WKY", 3, 187884},
	{"CHEAPEN", 7, 187885},
	{"HYGROSCOPIC", 11, 187886},
	{"HAGANS", 6, 187887},
	{"QUASIMODO", 9, 187888},
	{"MULTIFARIOUS", 12, 187889},
	{"RUNNETH", 7, 187890},
	{"BITMAPPED", 9, 187891},
	{"IGNATZ", 6, 187892},
	{"FUSSEROTIK", 10, 187893},
	{"SONGSTRESS", 10, 187894},
	{"ESPEJO", 6, 187895},
	{"KRACK", 5, 187896},
	{"DUNAS", 5, 187897},
	{"MABON", 5, 187898},
	{"ELEMIS", 6, 187899},
	{"BEHARI", 6, 187900},
	{"ZEMBLA", 6, 187901},
	{"XAWTV", 5, 187902},
	{"TEENSCHLAMPEN", 13, 187903},
	{"PEPPYWEAR", 9, 187904},
	{"GREIFSWALD", 10, 187905},
	{"BRECKNOCKSHIRE", 14, 187906},
	{"SELKET", 6, 187907},
	{"KAWABATA", 8, 187908},
	{"FICKVOTZE", 9, 187909},
	{"WOBBLES", 7, 187910},
	{"EATONTON", 8, 187911},
	{"DECLS", 5, 187912},
	{"MCGREAL", 7, 187913},
	{"BLOUD", 5, 187914},
	{"MAISONETTES", 11, 187915},
	{"BIRTHPARENTS", 12, 187916},
	{"SHAKYAMUNI", 10, 187917},
	{"MANSI", 5, 187918},
	{"RHIAN", 5, 187919},
	{"LLEGAR", 6, 187920},
	{"LICHTMAN", 8, 187921},
	{"GGLD", 4, 187922},
	{"LANCZOS", 7, 187923},
	{"JMAX", 4, 187924},
	{"FICKLUDER", 9, 187925},
	{"CENTURIA", 8, 187926},
	{"PHOTOGUIDE", 10, 187927},
	{"HITPARADE", 9, 187928},
	{"PATED", 5, 187929},
	{"PCIUTILS", 8, 187930},
	{"CATING", 6, 187931},
	{"APPE", 4, 187932},
	{"QUICKPRO", 8, 187933},
	{"COUNTR", 6, 187934},
	{"ABHORS", 6, 187935},
	{"HOMAS", 5, 187936},
	{"FREEL", 5, 187937},
	{"EROTIKSUCHMASCHINE", 18, 187938},
	{"BARCALDINE", 10, 187939},
	{"LEHTONEN", 8, 187940},
	{"GUCKERT", 7, 187941},
	{"SCHLAMPENCAMS", 13, 187942},
	{"FICKORGIE", 9, 187943},
	{"WORLDSPAN", 9, 187944},
	{"MYSITE", 6, 187945},
	{"SONOGRAPHIC", 11, 187946},
	{"BESKRIVELSE", 11, 187947},
	{"TRIPSO", 6, 187948},
	{"COMPANIA", 8, 187949},
	{"CETIS", 5, 187950},
	{"TEENSCHLAMPE", 12, 187951},
	{"GAURANTEED", 10, 187952},
	{"FILEPRO", 7, 187953},
	{"MINARETS", 8, 187954},
	{"BRANDWEEK", 9, 187955},
	{"BENTLEIGH", 9, 187956},
	{"RECOMPUTE", 9, 187957},
	{"PUNKIN", 6, 187958},
	{"BUSHEHR", 7, 187959},
	{"VIEWPERF", 8, 187960},
	{"POURERS", 7, 187961},
	{"TRAUMAERSCHE", 12, 187962},
	{"SANDANSKI", 9, 187963},
	{"WRACK", 5, 187964},
	{"PECHTCHANSKI", 12, 187965},
	{"KDEWEBDEV", 9, 187966},
	{"GOLDTHWAITE", 11, 187967},
	{"PARKPLATZTREFFEN", 16, 187968},
	{"FICKDATES", 9, 187969},
	{"ELDERWEB", 8, 187970},
	{"CORTEO", 6, 187971},
	{"ABGESPPRITZT", 12, 187972},
	{"REDHAIRED", 9, 187973},
	{"GUATTARI", 8, 187974},
	{"COMT", 4, 187975},
	{"EKIOSK", 6, 187976},
	{"NIGHTJAR", 8, 187977},
	{"DAIICHI", 7, 187978},
	{"INTERFUSE", 9, 187979},
	{"SEPERATES", 9, 187980},
	{"DOGON", 5, 187981},
	{"MENDS", 5, 187982},
	{"LYMM", 4, 187983},
	{"LIVESTATE", 9, 187984},
	{"ANSCHEISSEN", 11, 187985},
	{"EALES", 5, 187986},
	{"MEMUP", 5, 187987},
	{"LUBOS", 5, 187988},
	{"SKIPPERED", 9, 187989},
	{"YSGT", 4, 187990},
	{"YMRO", 4, 187991},
	{"YJRW", 4, 187992},
	{"YIPE", 4, 187993},
	{"UKSL", 4, 187994},
	{"SKAJ", 4, 187995},
	{"RPMR", 4, 187996},
	{"ROZS", 4, 187997},
	{"RLCL", 4, 187998},
	{"REHL", 4, 187999},
	{"NGGT", 4, 188000},
	{"MMUD", 4, 188001},
	{"LPUZ", 4, 188002},
	{"LEZC", 4, 188003},
	{"JUVA", 4, 188004},
	{"JOWE", 4, 188005},
	{"JIAL", 4, 188006},
	{"IKHR", 4, 188007},
	{"IDFS", 4, 188008},
	{"GRBI", 4, 188009},
	{"GOLB", 4, 188010},
	{"GFUM", 4, 188011},
	{"FGAE", 4, 188012},
	{"FEGL", 4, 188013},
	{"ELFQ", 4, 188014},
	{"ECGO", 4, 188015},
	{"DAGM", 4, 188016},
	{"CDEE", 4, 188017},
	{"BYGH", 4, 188018},
	{"AKPI", 4, 188019},
	{"AJKU", 4, 188020},
	{"BENDEL", 6, 188021},
	{"NGENIUS", 7, 188022},
	{"LAMPADE", 7, 188023},
	{"TOBER", 5, 188024},
	{"FORMEL", 6, 188025},
	{"CHIROPODISTS", 12, 188026},
	{"SCCM", 4, 188027},
	{"PUTSCH", 6, 188028},
	{"DATAPOINT", 9, 188029},
	{"BREAKBEATS", 10, 188030},
	{"BLEIBEN", 7, 188031},
	{"VIVIDNESS", 9, 188032},
	{"BEDTIMECOMFORT", 14, 188033},
	{"MODELLISTA", 10, 188034},
	{"ENDCOLOR", 8, 188035},
	{"RESUM", 5, 188036},
	{"MYAPP", 5, 188037},
	{"GEYSERVILLE", 11, 188038},
	{"YATELEY", 7, 188039},
	{"PANORAMICS", 10, 188040},
	{"FLAGRANTLY", 10, 188041},
	{"SANDERSVILLE", 12, 188042},
	{"RESPONSIVITY", 12, 188043},
	{"RECAPTURING", 11, 188044},
	{"GOLYGU", 6, 188045},
	{"BORBA", 5, 188046},
	{"PANICULATA", 10, 188047},
	{"MOLYBDATE", 9, 188048},
	{"MUSICWEB", 8, 188049},
	{"OPMANAGER", 9, 188050},
	{"MANICURISTS", 11, 188051},
	{"GVSU", 4, 188052},
	{"FUMIO", 5, 188053},
	{"CORPORATIST", 11, 188054},
	{"REPRICING", 9, 188055},
	{"PELLY", 5, 188056},
	{"MICQ", 4, 188057},
	{"CDTE", 4, 188058},
	{"BUZZSAW", 7, 188059},
	{"SPRINGWATER", 11, 188060},
	{"BEATITUDE", 9, 188061},
	{"DGF", 3, 188062},
	{"WOOLIES", 7, 188063},
	{"ROELAND", 7, 188064},
	{"BELLMAWR", 8, 188065},
	{"HUSBANDMAN", 10, 188066},
	{"DOGO", 4, 188067},
	{"GENEPOOL", 8, 188068},
	{"CLIENTID", 8, 188069},
	{"PROCUREUR", 9, 188070},
	{"RUMEX", 5, 188071},
	{"DAYTEK", 6, 188072},
	{"AXELSSON", 8, 188073},
	{"PSKOV", 5, 188074},
	{"STUK", 4, 188075},
	{"IRCSERVICES", 11, 188076},
	{"BUMPKIN", 7, 188077},
	{"BCCA", 4, 188078},
	{"LEMURIA", 7, 188079},
	{"PARTIN", 6, 188080},
	{"DOULEUR", 7, 188081},
	{"AYAD", 4, 188082},
	{"NEESGRID", 8, 188083},
	{"MEGAPLEX", 8, 188084},
	{"BATELEUR", 8, 188085},
	{"REDTRAM", 7, 188086},
	{"CALDB", 5, 188087},
	{"VAILLANCOURT", 12, 188088},
	{"MABY", 4, 188089},
	{"BLEACHES", 8, 188090},
	{"RETROREFLECTIVE", 15, 188091},
	{"PCURRENTBOX", 11, 188092},
	{"INSIDEPOOL", 10, 188093},
	{"NURIA", 5, 188094},
	{"MANZO", 5, 188095},
	{"DXC", 3, 188096},
	{"CHEEZY", 6, 188097},
	{"HEADE", 5, 188098},
	{"EXPATRIATION", 12, 188099},
	{"LENOBLE", 7, 188100},
	{"TOWNSQUARE", 10, 188101},
	{"FLEXIRENT", 9, 188102},
	{"GETBOUNDS", 9, 188103},
	{"ASKEY", 5, 188104},
	{"PURGATORIO", 10, 188105},
	{"MELODICA", 8, 188106},
	{"HEAVES", 6, 188107},
	{"RONDEBOSCH", 10, 188108},
	{"CPATCH", 6, 188109},
	{"SCIENTIFICS", 11, 188110},
	{"PEERY", 5, 188111},
	{"BUSKERS", 7, 188112},
	{"BLAIKIE", 7, 188113},
	{"ROUPAS", 6, 188114},
	{"BLOGMAD", 7, 188115},
	{"KOSG", 4, 188116},
	{"IMAGEQUEST", 10, 188117},
	{"MILCHTITTEN", 11, 188118},
	{"ELECOM", 6, 188119},
	{"MALOOF", 6, 188120},
	{"NEDRA", 5, 188121},
	{"BOOTNOTES", 9, 188122},
	{"SOULMATCH", 9, 188123},
	{"CONSCRIPTED", 11, 188124},
	{"CDRDAO", 6, 188125},
	{"DKW", 3, 188126},
	{"ZOVS", 4, 188127},
	{"ZILY", 4, 188128},
	{"YMRH", 4, 188129},
	{"VJIM", 4, 188130},
	{"VAMS", 4, 188131},
	{"USRH", 4, 188132},
	{"UDGO", 4, 188133},
	{"TDEX", 4, 188134},
	{"RUTW", 4, 188135},
	{"RAQL", 4, 188136},
	{"PJAS", 4, 188137},
	{"OZZE", 4, 188138},
	{"MLYG", 4, 188139},
	{"MBSR", 4, 188140},
	{"LTVC", 4, 188141},
	{"LRAU", 4, 188142},
	{"LIKL", 4, 188143},
	{"KJAP", 4, 188144},
	{"GUPV", 4, 188145},
	{"GOAV", 4, 188146},
	{"GMEU", 4, 188147},
	{"FMRC", 4, 188148},
	{"FFYL", 4, 188149},
	{"EVMO", 4, 188150},
	{"EDHD", 4, 188151},
	{"DKAK", 4, 188152},
	{"DKAC", 4, 188153},
	{"CTVT", 4, 188154},
	{"CISX", 4, 188155},
	{"CENF", 4, 188156},
	{"AQIW", 4, 188157},
	{"APVA", 4, 188158},
	{"AGRT", 4, 188159},
	{"ACUZ", 4, 188160},
	{"SOFFITEL", 8, 188161},
	{"STOUDEMIRE", 10, 188162},
	{"GREENLAW", 8, 188163},
	{"CARBOLITE", 9, 188164},
	{"WEITZEL", 7, 188165},
	{"WEARSIDE", 8, 188166},
	{"OVERNIGHTER", 11, 188167},
	{"LAUBACH", 7, 188168},
	{"PROFESSIONALE", 13, 188169},
	{"CHIKLIS", 7, 188170},
	{"BRAMMER", 7, 188171},
	{"ANALFOTZEN", 10, 188172},
	{"TEENEROTIK", 10, 188173},
	{"SGRENA", 6, 188174},
	{"MUIRFIELD", 9, 188175},
	{"EISELE", 6, 188176},
	{"DEUTSCHLANDS", 12, 188177},
	{"DAZS", 4, 188178},
	{"XLVII", 5, 188179},
	{"UNRESECTABLE", 12, 188180},
	{"AUCTIONTAMER", 12, 188181},
	{"WAGONLIT", 8, 188182},
	{"BULKLEY", 7, 188183},
	{"COMMITTEEMAN", 12, 188184},
	{"CONTURA", 7, 188185},
	{"BRACLET", 7, 188186},
	{"SAFED", 5, 188187},
	{"PEWEE", 5, 188188},
	{"PAGA", 4, 188189},
	{"CACCIA", 6, 188190},
	{"ARITA", 5, 188191},
	{"NEUROSCIENTIST", 14, 188192},
	{"NARRABEEN", 9, 188193},
	{"BROSES", 6, 188194},
	{"SCHRAGER", 8, 188195},
	{"BLACKCAT", 8, 188196},
	{"ROTIC", 5, 188197},
	{"OLANG", 5, 188198},
	{"GANGTOK", 7, 188199},
	{"TOMICA", 6, 188200},
	{"CHUBU", 5, 188201},
	{"RRSPS", 5, 188202},
	{"FICKVOTZEN", 10, 188203},
	{"RENEGED", 7, 188204},
	{"ATHLONXP", 8, 188205},
	{"KLEINANZEIGEN", 13, 188206},
	{"VLOER", 5, 188207},
	{"FRIERSON", 8, 188208},
	{"CGRP", 4, 188209},
	{"AMED", 4, 188210},
	{"TRANSPOWER", 10, 188211},
	{"BOWLBY", 6, 188212},
	{"BENZINA", 7, 188213},
	{"POSTAROO", 8, 188214},
	{"PREDICAMENTS", 12, 188215},
	{"OLTL", 4, 188216},
	{"NEWBS", 5, 188217},
	{"SEABASS", 7, 188218},
	{"FICKAUTO", 8, 188219},
	{"COPPING", 7, 188220},
	{"CODESET", 7, 188221},
	{"JAJA", 4, 188222},
	{"IDEALISED", 9, 188223},
	{"DESIRAE", 7, 188224},
	{"INSTITUTT", 9, 188225},
	{"VOLOS", 5, 188226},
	{"PASSI", 5, 188227},
	{"NLIB", 4, 188228},
	{"TSUDA", 5, 188229},
	{"CYTHERA", 7, 188230},
	{"MUTILATIONS", 11, 188231},
	{"KEYLOCK", 7, 188232},
	{"MICROCIRCUIT", 12, 188233},
	{"KVOA", 4, 188234},
	{"ERIELACK", 8, 188235},
	{"UNTRUTHFUL", 10, 188236},
	{"MANNERISM", 9, 188237},
	{"PHYL", 4, 188238},
	{"UALBANY", 7, 188239},
	{"SEQUOIAS", 8, 188240},
	{"PFIESTERIA", 10, 188241},
	{"CRINOLINE", 9, 188242},
	{"XLENT", 5, 188243},
	{"NUSBAUM", 7, 188244},
	{"KANDIYOHI", 9, 188245},
	{"STATISM", 7, 188246},
	{"NELDA", 5, 188247},
	{"UNCCD", 5, 188248},
	{"RISON", 5, 188249},
	{"CANTUEL", 7, 188250},
	{"SOWNLOAD", 8, 188251},
	{"SUBALTERN", 9, 188252},
	{"SPORTCOATS", 10, 188253},
	{"PRONK", 5, 188254},
	{"SIGNALMAN", 9, 188255},
	{"YEKATERINBURG", 13, 188256},
	{"LOSMANDY", 8, 188257},
	{"IFAP", 4, 188258},
	{"KOVALCHUK", 9, 188259},
	{"FINCEN", 6, 188260},
	{"ICAEW", 5, 188261},
	{"GLAESER", 7, 188262},
	{"ENGELBRECHT", 11, 188263},
	{"ACCESSIBLITY", 12, 188264},
	{"LEGITIMIZING", 12, 188265},
	{"VALIE", 5, 188266},
	{"TROVARE", 7, 188267},
	{"TOONTOWN", 8, 188268},
	{"BLAHS", 5, 188269},
	{"TOPICALS", 8, 188270},
	{"BALAS", 5, 188271},
	{"APPUI", 5, 188272},
	{"ALTEGEILEWEIBER", 15, 188273},
	{"LAURUS", 6, 188274},
	{"ACTUALIZED", 10, 188275},
	{"REHEATED", 8, 188276},
	{"KAVIAREROTIKS", 13, 188277},
	{"YMBE", 4, 188278},
	{"YELB", 4, 188279},
	{"YCOY", 4, 188280},
	{"WROW", 4, 188281},
	{"WKMA", 4, 188282},
	{"VRER", 4, 188283},
	{"VHAL", 4, 188284},
	{"VDOR", 4, 188285},
	{"UXER", 4, 188286},
	{"UTCD", 4, 188287},
	{"USSJ", 4, 188288},
	{"UMKN", 4, 188289},
	{"ULUO", 4, 188290},
	{"UFRI", 4, 188291},
	{"UDDU", 4, 188292},
	{"UCAD", 4, 188293},
	{"UBOM", 4, 188294},
	{"TPIU", 4, 188295},
	{"RMRK", 4, 188296},
	{"RBJA", 4, 188297},
	{"PEOB", 4, 188298},
	{"OYOP", 4, 188299},
	{"OFRC", 4, 188300},
	{"NCPL", 4, 188301},
	{"NBIZ", 4, 188302},
	{"LKSK", 4, 188303},
	{"IPTL", 4, 188304},
	{"HNBY", 4, 188305},
	{"DBAZ", 4, 188306},
	{"CTUT", 4, 188307},
	{"CKKR", 4, 188308},
	{"CHZE", 4, 188309},
	{"AXEW", 4, 188310},
	{"TYGON", 5, 188311},
	{"PUMPKINHEAD", 11, 188312},
	{"TATTOONOW", 9, 188313},
	{"POLYMATH", 8, 188314},
	{"JAMIA", 5, 188315},
	{"COMPTEUR", 8, 188316},
	{"BHARATA", 7, 188317},
	{"INTERDIGITAL", 12, 188318},
	{"FLAGPOINT", 9, 188319},
	{"IMPO", 4, 188320},
	{"FICKCAM", 7, 188321},
	{"HOORN", 5, 188322},
	{"DORJE", 5, 188323},
	{"NEUTRALISE", 10, 188324},
	{"BIXLER", 6, 188325},
	{"SRAC", 4, 188326},
	{"LALIBERTE", 9, 188327},
	{"POLARIMETRIC", 12, 188328},
	{"LONGINGLY", 9, 188329},
	{"TRENDED", 7, 188330},
	{"GRML", 4, 188331},
	{"SNOOPS", 6, 188332},
	{"KLMNO", 5, 188333},
	{"RAGG", 4, 188334},
	{"EPISCOPATE", 10, 188335},
	{"OXALIPLATIN", 11, 188336},
	{"NUCLEOSOMES", 11, 188337},
	{"MIDGUT", 6, 188338},
	{"SWIPL", 5, 188339},
	{"MODRR", 5, 188340},
	{"SIDELIGHTS", 10, 188341},
	{"FLUOROPOLYMER", 13, 188342},
	{"VIEWCOM", 7, 188343},
	{"NPPA", 4, 188344},
	{"MOONY", 5, 188345},
	{"LEGIONARY", 9, 188346},
	{"FHLB", 4, 188347},
	{"CROGHAN", 7, 188348},
	{"CDFI", 4, 188349},
	{"SUPERLATTICE", 12, 188350},
	{"HARRISONS", 9, 188351},
	{"BACKPORTS", 9, 188352},
	{"MORANO", 6, 188353},
	{"MKB", 3, 188354},
	{"GRWPIAU", 7, 188355},
	{"IFOLDER", 7, 188356},
	{"APUD", 4, 188357},
	{"YFC", 3, 188358},
	{"SYNTHESISER", 11, 188359},
	{"IMODIUM", 7, 188360},
	{"ARQUITECTOS", 11, 188361},
	{"SEMEL", 5, 188362},
	{"NEWSNEWS", 8, 188363},
	{"COLECO", 6, 188364},
	{"BERKUS", 6, 188365},
	{"INTONED", 7, 188366},
	{"TELECHARGERTELECHARGER", 22, 188367},
	{"COSLA", 5, 188368},
	{"MESSAGEWALL", 11, 188369},
	{"MEDIEVIL", 8, 188370},
	{"RANNEY", 6, 188371},
	{"TECHNOGRAPHICS", 14, 188372},
	{"BANDES", 6, 188373},
	{"ROSEATE", 7, 188374},
	{"FORMALISATION", 13, 188375},
	{"ARTICLEEMAIL", 12, 188376},
	{"BAITFISH", 8, 188377},
	{"FRIMLEY", 7, 188378},
	{"EXERC", 5, 188379},
	{"PHARMACOVIGILANCE", 17, 188380},
	{"MOKO", 4, 188381},
	{"CPUINFO", 7, 188382},
	{"TALENTLESS", 10, 188383},
	{"SPIKELETS", 9, 188384},
	{"SCFM", 4, 188385},
	{"BODYDIE", 7, 188386},
	{"ORCHIS", 6, 188387},
	{"MULHALL", 7, 188388},
	{"PLUGING", 7, 188389},
	{"FERMIN", 6, 188390},
	{"ACHITEC", 7, 188391},
	{"MIDD", 4, 188392},
	{"RUFFIANS", 8, 188393},
	{"PHETNERMINE", 11, 188394},
	{"FLEXCAR", 7, 188395},
	{"GUARINI", 7, 188396},
	{"YOSHIMOTO", 9, 188397},
	{"SERVIR", 6, 188398},
	{"BLANCAS", 7, 188399},
	{"ICSID", 5, 188400},
	{"BONDY", 5, 188401},
	{"ISHIBASHI", 9, 188402},
	{"CONTRALTO", 9, 188403},
	{"LUCKYTECH", 9, 188404},
	{"ORPEN", 5, 188405},
	{"MYCENAE", 7, 188406},
	{"TERUEL", 6, 188407},
	{"BALLYHOO", 8, 188408},
	{"SEQNO", 5, 188409},
	{"EXELIB", 6, 188410},
	{"DESOLDERING", 11, 188411},
	{"UMFRAGEN", 8, 188412},
	{"TENAX", 5, 188413},
	{"ADSURL", 6, 188414},
	{"ZZYB", 4, 188415},
	{"ZSFA", 4, 188416},
	{"YUUZ", 4, 188417},
	{"XICH", 4, 188418},
	{"XDIE", 4, 188419},
	{"UIZT", 4, 188420},
	{"UIKE", 4, 188421},
	{"UDEZ", 4, 188422},
	{"TECP", 4, 188423},
	{"PTUC", 4, 188424},
	{"PIPR", 4, 188425},
	{"OYBL", 4, 188426},
	{"ORXB", 4, 188427},
	{"OMNB", 4, 188428},
	{"OJPM", 4, 188429},
	{"OICD", 4, 188430},
	{"OFUI", 4, 188431},
	{"NZYA", 4, 188432},
	{"NUNQ", 4, 188433},
	{"NDJJ", 4, 188434},
	{"MPDT", 4, 188435},
	{"LAUI", 4, 188436},
	{"IMUK", 4, 188437},
	{"ICAZ", 4, 188438},
	{"HLEU", 4, 188439},
	{"HGUT", 4, 188440},
	{"HGMA", 4, 188441},
	{"GBAM", 4, 188442},
	{"FVEC", 4, 188443},
	{"EACP", 4, 188444},
	{"DYIL", 4, 188445},
	{"DNIR", 4, 188446},
	{"DMSS", 4, 188447},
	{"COYE", 4, 188448},
	{"AGHZ", 4, 188449},
	{"PARACELSUS", 10, 188450},
	{"HARDISON", 8, 188451},
	{"ELECTROVAYA", 11, 188452},
	{"HYDR", 4, 188453},
	{"INTERTELESCOPEOFFSET", 20, 188454},
	{"QUILTY", 6, 188455},
	{"OPENNTF", 7, 188456},
	{"POWERMATIC", 10, 188457},
	{"WLSE", 4, 188458},
	{"AGRICULTURALLY", 14, 188459},
	{"LODESTONE", 9, 188460},
	{"TIJDENS", 7, 188461},
	{"QUINTAL", 7, 188462},
	{"PROLE", 5, 188463},
	{"SATANS", 6, 188464},
	{"FRANTIX", 7, 188465},
	{"PANMURE", 7, 188466},
	{"EWEBTRICITY", 11, 188467},
	{"KLART", 5, 188468},
	{"SYBERCOM", 8, 188469},
	{"SONNENBERG", 10, 188470},
	{"ECONLOG", 7, 188471},
	{"APERION", 7, 188472},
	{"SCALETTA", 8, 188473},
	{"TRONIX", 6, 188474},
	{"TORTUGUERO", 10, 188475},
	{"LAURANCE", 8, 188476},
	{"PAZZO", 5, 188477},
	{"GLOMERULI", 9, 188478},
	{"CHAMBON", 7, 188479},
	{"LIBAUDIOFILE", 12, 188480},
	{"ATCHLEY", 7, 188481},
	{"RACS", 4, 188482},
	{"GROO", 4, 188483},
	{"HILLTOPPERS", 11, 188484},
	{"NEUR", 4, 188485},
	{"CHICANOS", 8, 188486},
	{"LEFTS", 5, 188487},
	{"TENTER", 6, 188488},
	{"MONOTONES", 9, 188489},
	{"MYNA", 4, 188490},
	{"KASSIE", 6, 188491},
	{"BIGDECIMAL", 10, 188492},
	{"GECOS", 5, 188493},
	{"TRANSTERRESTRIAL", 16, 188494},
	{"FERNEY", 6, 188495},
	{"DISTT", 5, 188496},
	{"ELIVE", 5, 188497},
	{"VEBA", 4, 188498},
	{"SUBDIALS", 8, 188499},
	{"RUES", 4, 188500},
	{"XPLORETECH", 10, 188501},
	{"TWEEDEN", 7, 188502},
	{"STOUDAMIRE", 10, 188503},
	{"GOLFGUIDE", 9, 188504},
	{"PUFA", 4, 188505},
	{"OCCLUDING", 9, 188506},
	{"ENSHRINE", 8, 188507},
	{"SUPERIA", 7, 188508},
	{"BIOLOGIQUE", 10, 188509},
	{"METES", 5, 188510},
	{"ZMAX", 4, 188511},
	{"SPYSHERIFF", 10, 188512},
	{"LINDATA", 7, 188513},
	{"GEITNER", 7, 188514},
	{"TIMESPEC", 8, 188515},
	{"STRASSENHUREN", 13, 188516},
	{"LASTER", 6, 188517},
	{"HOAGY", 5, 188518},
	{"RUDELFICK", 9, 188519},
	{"EXPLOR", 6, 188520},
	{"MONOPOLIZATION", 14, 188521},
	{"ASHKELON", 8, 188522},
	{"ERGS", 4, 188523},
	{"BUCKIE", 6, 188524},
	{"DURYEA", 6, 188525},
	{"ADEOS", 5, 188526},
	{"SIHANOUK", 8, 188527},
	{"SUPERGRACE", 10, 188528},
	{"FABBRI", 6, 188529},
	{"DITROPAN", 8, 188530},
	{"AWEIGH", 6, 188531},
	{"SMBPASSWD", 9, 188532},
	{"QUOIN", 5, 188533},
	{"RIGAS", 5, 188534},
	{"SUGE", 4, 188535},
	{"FIBROSARCOMA", 12, 188536},
	{"QUINS", 5, 188537},
	{"KAUSHAL", 7, 188538},
	{"MINELLI", 7, 188539},
	{"GUARAN", 6, 188540},
	{"UMAINE", 6, 188541},
	{"HAGLUND", 7, 188542},
	{"UNCONVERTED", 11, 188543},
	{"TOPSELLER", 9, 188544},
	{"RABIT", 5, 188545},
	{"INVOKER", 7, 188546},
	{"FGHIJ", 5, 188547},
	{"DIASPORAS", 9, 188548},
	{"VALDEMAR", 8, 188549},
	{"TERMIOS", 7, 188550},
	{"DARLEEN", 7, 188551},
	{"BOOKWORLD", 9, 188552},
	{"AUFEMININ", 9, 188553},
	{"ZZTR", 4, 188554},
	{"YNLE", 4, 188555},
	{"YLSM", 4, 188556},
	{"XTBR", 4, 188557},
	{"WLPR", 4, 188558},
	{"URKL", 4, 188559},
	{"UJAA", 4, 188560},
	{"THZU", 4, 188561},
	{"TBCA", 4, 188562},
	{"SYUG", 4, 188563},
	{"STRZ", 4, 188564},
	{"STPG", 4, 188565},
	{"SLYQ", 4, 188566},
	{"RYMS", 4, 188567},
	{"RQAW", 4, 188568},
	{"RCMO", 4, 188569},
	{"PRMA", 4, 188570},
	{"PMAJ", 4, 188571},
	{"OULJ", 4, 188572},
	{"OPAZ", 4, 188573},
	{"OKUC", 4, 188574},
	{"NPGA", 4, 188575},
	{"MRZA", 4, 188576},
	{"MCVI", 4, 188577},
	{"LOCY", 4, 188578},
	{"LLLC", 4, 188579},
	{"JDUK", 4, 188580},
	{"IQAL", 4, 188581},
	{"ILGL", 4, 188582},
	{"HWIG", 4, 188583},
	{"HEZL", 4, 188584},
	{"FFYP", 4, 188585},
	{"EUIG", 4, 188586},
	{"DCDE", 4, 188587},
	{"CBYM", 4, 188588},
	{"ACYK", 4, 188589},
	{"FREMDFICKEN", 11, 188590},
	{"COVANCE", 7, 188591},
	{"CASETTE", 7, 188592},
	{"CURTLY", 6, 188593},
	{"WMII", 4, 188594},
	{"MARTINGALES", 11, 188595},
	{"HUPP", 4, 188596},
	{"RESUSCITATED", 12, 188597},
	{"ORZO", 4, 188598},
	{"PATTERNSKIN", 11, 188599},
	{"URLAUBSFICK", 11, 188600},
	{"MDIST", 5, 188601},
	{"DOORKNOBS", 9, 188602},
	{"HAENGETITTENS", 13, 188603},
	{"ATTABOY", 7, 188604},
	{"TRAUMARSCH", 10, 188605},
	{"DALLOWAY", 8, 188606},
	{"LAYIN", 5, 188607},
	{"PUTAIN", 6, 188608},
	{"POLUTION", 8, 188609},
	{"BAUMGARDNER", 11, 188610},
	{"YANGSHUO", 8, 188611},
	{"DYSPLASTIC", 10, 188612},
	{"SUBCODE", 7, 188613},
	{"HOMERTON", 8, 188614},
	{"WAVEFUNCTIONS", 13, 188615},
	{"SHEUNG", 6, 188616},
	{"EXEMPLES", 8, 188617},
	{"CERITA", 6, 188618},
	{"INFERMIERE", 10, 188619},
	{"DIAGON", 6, 188620},
	{"PHILODENDRON", 12, 188621},
	{"SATURNA", 7, 188622},
	{"CONFIDANTE", 10, 188623},
	{"VISUALBASIC", 11, 188624},
	{"MILANTE", 7, 188625},
	{"ENSPT", 5, 188626},
	{"AIRBOX", 6, 188627},
	{"RASHLY", 6, 188628},
	{"JACETECH", 8, 188629},
	{"VARDI", 5, 188630},
	{"NAVIGANT", 8, 188631},
	{"LONGVILLE", 9, 188632},
	{"CHIHIRO", 7, 188633},
	{"AMENT", 5, 188634},
	{"LEERING", 7, 188635},
	{"COLOMBIE", 8, 188636},
	{"WANITA", 6, 188637},
	{"SIENCE", 6, 188638},
	{"FRONTIN", 7, 188639},
	{"ROPERS", 6, 188640},
	{"KEPHART", 7, 188641},
	{"ACROLEIN", 8, 188642},
	{"BOMAN", 5, 188643},
	{"SOUDAN", 6, 188644},
	{"QSTRINGLIST", 11, 188645},
	{"QUEERTY", 7, 188646},
	{"ECLAIR", 6, 188647},
	{"CLEARINGS", 9, 188648},
	{"FAMILIARIZING", 13, 188649},
	{"HYALURONAN", 10, 188650},
	{"EXCLUDETOPIC", 12, 188651},
	{"SPER", 4, 188652},
	{"PMTCT", 5, 188653},
	{"PHPECLIPSE", 10, 188654},
	{"LANSDOWN", 8, 188655},
	{"ULTRON", 6, 188656},
	{"SPYWARESTRIKE", 13, 188657},
	{"SAVIOURS", 8, 188658},
	{"MODBURY", 7, 188659},
	{"SONGKHLA", 8, 188660},
	{"TAXOTERE", 8, 188661},
	{"SIDETRACK", 9, 188662},
	{"DONWLOADS", 9, 188663},
	{"MULTISENSORY", 12, 188664},
	{"PLEASANTRIES", 12, 188665},
	{"DIBBS", 5, 188666},
	{"HYPERKALEMIA", 12, 188667},
	{"TOTALI", 6, 188668},
	{"LOUER", 5, 188669},
	{"UOMINI", 6, 188670},
	{"ATONING", 7, 188671},
	{"ATHENEE", 7, 188672},
	{"WADDY", 5, 188673},
	{"MUCINOUS", 8, 188674},
	{"LNXH", 4, 188675},
	{"CONTOL", 6, 188676},
	{"SYLLABICATION", 13, 188677},
	{"CONSORZIO", 9, 188678},
	{"KLD", 3, 188679},
	{"FAVOUTITE", 9, 188680},
	{"ANGUSTICLAVIUS", 14, 188681},
	{"RAMY", 4, 188682},
	{"TRANSYLVANIAN", 13, 188683},
	{"POTENTIOMETRIC", 14, 188684},
	{"METOHIJA", 8, 188685},
	{"ULTRASEEK", 9, 188686},
	{"RUGG", 4, 188687},
	{"MOUSEUP", 7, 188688},
	{"CODEPENDENCY", 12, 188689},
	{"VIARAMA", 7, 188690},
	{"SCHOOLEY", 8, 188691},
	{"EBRILL", 6, 188692},
	{"PUPAL", 5, 188693},
	{"OCEANOGRAPHER", 13, 188694},
	{"LORCH", 5, 188695},
	{"BLINKBITS", 9, 188696},
	{"TMCC", 4, 188697},
	{"MAAG", 4, 188698},
	{"PLAZE", 5, 188699},
	{"INSINUATED", 10, 188700},
	{"YYOS", 4, 188701},
	{"YDNO", 4, 188702},
	{"XERF", 4, 188703},
	{"XBAU", 4, 188704},
	{"WNUT", 4, 188705},
	{"WHEK", 4, 188706},
	{"USOX", 4, 188707},
	{"ULKF", 4, 188708},
	{"UKTR", 4, 188709},
	{"UJAT", 4, 188710},
	{"UDAU", 4, 188711},
	{"TUEB", 4, 188712},
	{"SPYB", 4, 188713},
	{"SKYU", 4, 188714},
	{"RYNT", 4, 188715},
	{"RMKA", 4, 188716},
	{"RMIH", 4, 188717},
	{"RCKH", 4, 188718},
	{"OVBA", 4, 188719},
	{"OFTK", 4, 188720},
	{"NUOR", 4, 188721},
	{"NUNJ", 4, 188722},
	{"NJWA", 4, 188723},
	{"NAFP", 4, 188724},
	{"MTUC", 4, 188725},
	{"MJIN", 4, 188726},
	{"LJAK", 4, 188727},
	{"LFSS", 4, 188728},
	{"KDUT", 4, 188729},
	{"INBP", 4, 188730},
	{"GHEQ", 4, 188731},
	{"FDUL", 4, 188732},
	{"EXJO", 4, 188733},
	{"ETUX", 4, 188734},
	{"DAAW", 4, 188735},
	{"BLEX", 4, 188736},
	{"YESTER", 6, 188737},
	{"MANGIARE", 8, 188738},
	{"GOODHART", 8, 188739},
	{"PILEATED", 8, 188740},
	{"PAGENT", 6, 188741},
	{"RANDOMS", 7, 188742},
	{"KETER", 5, 188743},
	{"GCW", 3, 188744},
	{"FARHI", 5, 188745},
	{"ETHNICS", 7, 188746},
	{"SYLACAUGA", 9, 188747},
	{"GIARDIASIS", 10, 188748},
	{"DAOLNWOD", 8, 188749},
	{"RECIPIENCY", 10, 188750},
	{"MARYVALE", 8, 188751},
	{"XLVI", 4, 188752},
	{"VRD", 3, 188753},
	{"JKD", 3, 188754},
	{"KCTCS", 5, 188755},
	{"WALLHANGING", 11, 188756},
	{"ROUGHNECK", 9, 188757},
	{"COVERGIRL", 9, 188758},
	{"TRABAJAR", 8, 188759},
	{"QUICKPLACE", 10, 188760},
	{"WARBLE", 6, 188761},
	{"COOCHIE", 7, 188762},
	{"SKYS", 4, 188763},
	{"COUNTERACTS", 11, 188764},
	{"NORMALISE", 9, 188765},
	{"SCHEPERS", 8, 188766},
	{"ASSPARADE", 9, 188767},
	{"PRODIGIES", 9, 188768},
	{"ATLIN", 5, 188769},
	{"RIZZUTO", 7, 188770},
	{"NONGAME", 7, 188771},
	{"NEOCORTICAL", 11, 188772},
	{"FSYNC", 5, 188773},
	{"BHUTANI", 7, 188774},
	{"ANTINORI", 8, 188775},
	{"SEDUCTRESS", 10, 188776},
	{"BALNEARIO", 9, 188777},
	{"LICHTER", 7, 188778},
	{"HERBES", 6, 188779},
	{"CLEMENCEAU", 10, 188780},
	{"PODUNK", 6, 188781},
	{"GETHOSTBYADDR", 13, 188782},
	{"BITPASS", 7, 188783},
	{"GALSTON", 7, 188784},
	{"JANNEMAN", 8, 188785},
	{"TURRELL", 7, 188786},
	{"MOISTURISERS", 12, 188787},
	{"SUBEXPRESSION", 13, 188788},
	{"PHRYGIA", 7, 188789},
	{"MEHER", 5, 188790},
	{"ATMOB", 5, 188791},
	{"TEENTITTEN", 10, 188792},
	{"PENASCO", 7, 188793},
	{"AMRAM", 5, 188794},
	{"STENZEL", 7, 188795},
	{"PERKAL", 6, 188796},
	{"PORRAS", 6, 188797},
	{"KIVIO", 5, 188798},
	{"DENKTAS", 7, 188799},
	{"CCTOOLS", 7, 188800},
	{"ADMD", 4, 188801},
	{"OVERIGE", 7, 188802},
	{"FORDLIAN", 8, 188803},
	{"FICKTREFFEN", 11, 188804},
	{"CLAVICHORD", 10, 188805},
	{"XMML", 4, 188806},
	{"SAYWHAT", 7, 188807},
	{"IRISHBLOGS", 10, 188808},
	{"ZWEMBADEN", 9, 188809},
	{"KASHGAR", 7, 188810},
	{"DARDANELLES", 11, 188811},
	{"BERRETT", 7, 188812},
	{"EMESIS", 6, 188813},
	{"BASSETLAW", 9, 188814},
	{"TURISTICA", 9, 188815},
	{"HOTTUB", 6, 188816},
	{"FAMILIARIZED", 12, 188817},
	{"FIVB", 4, 188818},
	{"CYCKI", 5, 188819},
	{"RADIOBUTTON", 11, 188820},
	{"KADATCO", 7, 188821},
	{"CAPSSA", 6, 188822},
	{"CORBAN", 6, 188823},
	{"ANADA", 5, 188824},
	{"TEENMUSCHI", 10, 188825},
	{"AUTOCOMPUTER", 12, 188826},
	{"MEGACHIP", 8, 188827},
	{"INTERETHNIC", 11, 188828},
	{"FREETHINKERS", 12, 188829},
	{"SOCKLINER", 9, 188830},
	{"KGV", 3, 188831},
	{"INTERSPIRE", 10, 188832},
	{"AVAL", 4, 188833},
	{"CHALON", 6, 188834},
	{"COLLEGETEENS", 12, 188835},
	{"EDIZIONE", 8, 188836},
	{"DREAMSICLES", 11, 188837},
	{"DATACENTERS", 11, 188838},
	{"BALWYN", 6, 188839},
	{"VOLUPTUA", 8, 188840},
	{"PARTSELECT", 10, 188841},
	{"AGATES", 6, 188842},
	{"TOMOS", 5, 188843},
	{"APROCOM", 7, 188844},
	{"TECNOLOGIE", 10, 188845},
	{"TEAMWEAR", 8, 188846},
	{"ROOTWORM", 8, 188847},
	{"FFMM", 4, 188848},
	{"FEKETE", 6, 188849},
	{"MCKIERNAN", 9, 188850},
	{"BAPHOMET", 8, 188851},
	{"SHERBURN", 8, 188852},
	{"OTELLO", 6, 188853},
	{"INVENTARIO", 10, 188854},
	{"REKINDLING", 10, 188855},
	{"RADIOGRAPHERS", 13, 188856},
	{"COLONIALIST", 11, 188857},
	{"SAWTELL", 7, 188858},
	{"NIKAO", 5, 188859},
	{"LITHOSPHERIC", 12, 188860},
	{"CROTCHES", 8, 188861},
	{"ORGANISATIONEN", 14, 188862},
	{"KQKQ", 4, 188863},
	{"COSMOPOLITANISM", 15, 188864},
	{"COCCO", 5, 188865},
	{"UNIPROCESSOR", 12, 188866},
	{"SUCCESSIONS", 11, 188867},
	{"ANDESITE", 8, 188868},
	{"CEPTION", 7, 188869},
	{"BUSYNESS", 8, 188870},
	{"ZNOR", 4, 188871},
	{"WLWE", 4, 188872},
	{"WATY", 4, 188873},
	{"WAOF", 4, 188874},
	{"UUPA", 4, 188875},
	{"URHY", 4, 188876},
	{"UGRU", 4, 188877},
	{"UADU", 4, 188878},
	{"TKYO", 4, 188879},
	{"TJEL", 4, 188880},
	{"TIPM", 4, 188881},
	{"TAUQ", 4, 188882},
	{"SPMW", 4, 188883},
	{"RMVO", 4, 188884},
	{"RLGE", 4, 188885},
	{"RDZA", 4, 188886},
	{"RCWE", 4, 188887},
	{"OHBU", 4, 188888},
	{"LSTV", 4, 188889},
	{"LPUE", 4, 188890},
	{"KOLC", 4, 188891},
	{"IOCD", 4, 188892},
	{"HDVD", 4, 188893},
	{"GDUP", 4, 188894},
	{"ERUY", 4, 188895},
	{"DJST", 4, 188896},
	{"DDMU", 4, 188897},
	{"AZIK", 4, 188898},
	{"AUPU", 4, 188899},
	{"ADCY", 4, 188900},
	{"MYLEENE", 7, 188901},
	{"COLINA", 6, 188902},
	{"CENET", 5, 188903},
	{"FOXWORTH", 8, 188904},
	{"SWAYZAK", 7, 188905},
	{"JOINDATA", 8, 188906},
	{"BILLIONTH", 9, 188907},
	{"UCFV", 4, 188908},
	{"WANLESS", 7, 188909},
	{"PLAATJE", 7, 188910},
	{"NASSAR", 6, 188911},
	{"SOCCEROOS", 9, 188912},
	{"BYRUM", 5, 188913},
	{"LUSTLOCH", 8, 188914},
	{"NEWSBLASTER", 11, 188915},
	{"URGENCE", 7, 188916},
	{"INHERITORS", 10, 188917},
	{"EAGAR", 5, 188918},
	{"NONRENEWABLE", 12, 188919},
	{"PERLIN", 6, 188920},
	{"BARBATO", 7, 188921},
	{"RANONG", 6, 188922},
	{"GOLEMS", 6, 188923},
	{"CONDENSOR", 9, 188924},
	{"PLASTI", 6, 188925},
	{"MOYNAHAN", 8, 188926},
	{"MIDDLEPORT", 10, 188927},
	{"BROCKHAMPTON", 12, 188928},
	{"CASHIN", 6, 188929},
	{"FAKIR", 5, 188930},
	{"ESCONDIDA", 9, 188931},
	{"DEBKA", 5, 188932},
	{"PHARMACOLOGICALLY", 17, 188933},
	{"YLW", 3, 188934},
	{"FAVORIETEN", 10, 188935},
	{"ALTESCHLAMPEN", 13, 188936},
	{"METHYLDOPA", 10, 188937},
	{"SPIDERWORKS", 11, 188938},
	{"HAUREX", 6, 188939},
	{"MYLA", 4, 188940},
	{"ASIATEENIES", 11, 188941},
	{"JOINFORD", 8, 188942},
	{"SREB", 4, 188943},
	{"SPENNYMOOR", 10, 188944},
	{"ENDODERM", 8, 188945},
	{"SUBSTATE", 8, 188946},
	{"CRADOCK", 7, 188947},
	{"FUGUTECH", 8, 188948},
	{"FREMDFICK", 9, 188949},
	{"RASHTRIYA", 9, 188950},
	{"MONOLITHS", 9, 188951},
	{"DEVASTATINGLY", 13, 188952},
	{"CONDER", 6, 188953},
	{"NEILY", 5, 188954},
	{"LAPPIN", 6, 188955},
	{"FENECH", 6, 188956},
	{"STRASSENHURE", 12, 188957},
	{"CAREENING", 9, 188958},
	{"KOONCE", 6, 188959},
	{"GALLIMARD", 9, 188960},
	{"DIVINITIES", 10, 188961},
	{"ZIPLABS", 7, 188962},
	{"SNOWSHOW", 8, 188963},
	{"RELIGIO", 7, 188964},
	{"NIKHEF", 6, 188965},
	{"LIBDBI", 6, 188966},
	{"GALLES", 6, 188967},
	{"THERMOSETTING", 13, 188968},
	{"MEDIFAST", 8, 188969},
	{"SERVICII", 8, 188970},
	{"OSTRACISM", 9, 188971},
	{"ZENDA", 5, 188972},
	{"PHILLIPA", 8, 188973},
	{"TESTDRIVE", 9, 188974},
	{"JOMO", 4, 188975},
	{"UNEM", 4, 188976},
	{"HIGHMEM", 7, 188977},
	{"KINGERY", 7, 188978},
	{"JAMICOM", 7, 188979},
	{"NKRUMAH", 7, 188980},
	{"GOODACRE", 8, 188981},
	{"RIPPIN", 6, 188982},
	{"MAGASINS", 8, 188983},
	{"HOOKWORM", 8, 188984},
	{"FREEWARES", 9, 188985},
	{"REDCARDS", 8, 188986},
	{"LOTTER", 6, 188987},
	{"BOSSI", 5, 188988},
	{"MALATESTA", 9, 188989},
	{"KETOGENIC", 9, 188990},
	{"PAICE", 5, 188991},
	{"IMHOTEP", 7, 188992},
	{"SPARQL", 6, 188993},
	{"NOTETAKING", 10, 188994},
	{"EMAILJOKE", 9, 188995},
	{"BIENNIA", 7, 188996},
	{"CREEN", 5, 188997},
	{"PLANTAGO", 8, 188998},
	{"AKAELAE", 7, 188999},
	{"OLMEC", 5, 189000},
	{"COLLETS", 7, 189001},
	{"CARDIOVERSION", 13, 189002},
	{"WOOTON", 6, 189003},
	{"SLINGBACKS", 10, 189004},
	{"GRANA", 5, 189005},
	{"GOGGINS", 7, 189006},
	{"BUTTRESSES", 10, 189007},
	{"GRAVITATING", 11, 189008},
	{"ZKYS", 4, 189009},
	{"ZEPU", 4, 189010},
	{"ZASL", 4, 189011},
	{"YFEV", 4, 189012},
	{"YDSO", 4, 189013},
	{"YAGH", 4, 189014},
	{"VSRA", 4, 189015},
	{"UTUC", 4, 189016},
	{"UKNA", 4, 189017},
	{"UBMU", 4, 189018},
	{"UAUT", 4, 189019},
	{"TMOW", 4, 189020},
	{"RLTD", 4, 189021},
	{"REXF", 4, 189022},
	{"RCSU", 4, 189023},
	{"OVGA", 4, 189024},
	{"NSRD", 4, 189025},
	{"MIHU", 4, 189026},
	{"LOYN", 4, 189027},
	{"KHOB", 4, 189028},
	{"HTCY", 4, 189029},
	{"GEPS", 4, 189030},
	{"GEHY", 4, 189031},
	{"EPPM", 4, 189032},
	{"DDFL", 4, 189033},
	{"BOWG", 4, 189034},
	{"BCUS", 4, 189035},
	{"BBCL", 4, 189036},
	{"AYCY", 4, 189037},
	{"AOZU", 4, 189038},
	{"AGTR", 4, 189039},
	{"ACVA", 4, 189040},
	{"AVELOX", 6, 189041},
	{"LIRICS", 6, 189042},
	{"FDEE", 4, 189043},
	{"UCG", 3, 189044},
	{"DROVERS", 7, 189045},
	{"FXPANSION", 9, 189046},
	{"PHUC", 4, 189047},
	{"PARHELIA", 8, 189048},
	{"MICROBREWERIES", 14, 189049},
	{"HUMBUCKERS", 10, 189050},
	{"ATMOSPHERICS", 12, 189051},
	{"AMSDEN", 6, 189052},
	{"ADMS", 4, 189053},
	{"KRIM", 4, 189054},
	{"AUDET", 5, 189055},
	{"OBELISKS", 8, 189056},
	{"AVAPRO", 6, 189057},
	{"GAITS", 5, 189058},
	{"DVDIRECT", 8, 189059},
	{"CANDYE", 6, 189060},
	{"SPHERIC", 7, 189061},
	{"VIERGE", 6, 189062},
	{"STERRETT", 8, 189063},
	{"RABBANI", 7, 189064},
	{"PRESSOR", 7, 189065},
	{"SYDNI", 5, 189066},
	{"STFX", 4, 189067},
	{"PARTICIPER", 10, 189068},
	{"LORDSBURG", 9, 189069},
	{"ELGOOG", 6, 189070},
	{"CONTRATOS", 9, 189071},
	{"TENNILLE", 8, 189072},
	{"DOREY", 5, 189073},
	{"DOGGEREL", 8, 189074},
	{"ADITIONAL", 9, 189075},
	{"MISCALCULATED", 13, 189076},
	{"IMPREGNATE", 10, 189077},
	{"EMACSEN", 7, 189078},
	{"AEREI", 5, 189079},
	{"VESTN", 5, 189080},
	{"LSTAT", 5, 189081},
	{"PRECONFERENCE", 13, 189082},
	{"KLINGELT", 8, 189083},
	{"ANANTH", 6, 189084},
	{"FISHTANK", 8, 189085},
	{"GETCLASSNAME", 12, 189086},
	{"WOODMEN", 7, 189087},
	{"EXISTENCES", 10, 189088},
	{"BUCHWALD", 8, 189089},
	{"NETRITION", 9, 189090},
	{"OPDATERET", 9, 189091},
	{"MINITITTEN", 10, 189092},
	{"HEMLINE", 7, 189093},
	{"MILAGROS", 8, 189094},
	{"ALENTOURS", 9, 189095},
	{"FREF", 4, 189096},
	{"ELLENVILLE", 10, 189097},
	{"MASTRUBATING", 12, 189098},
	{"EMOLLIENTS", 10, 189099},
	{"AMPLES", 6, 189100},
	{"HISTIOCYTOSIS", 13, 189101},
	{"BABYLONE", 8, 189102},
	{"ACCOMIDATION", 12, 189103},
	{"THORLEY", 7, 189104},
	{"PENODOL", 7, 189105},
	{"WADLER", 6, 189106},
	{"PONR", 4, 189107},
	{"PICKSTOP", 8, 189108},
	{"LEYBURN", 7, 189109},
	{"WYSONG", 6, 189110},
	{"INTERTRIBAL", 11, 189111},
	{"HUUR", 4, 189112},
	{"ACCORDI", 7, 189113},
	{"SHEOL", 5, 189114},
	{"LSMOD", 5, 189115},
	{"AVINASH", 7, 189116},
	{"OVRAL", 5, 189117},
	{"TERFEL", 6, 189118},
	{"NEUENSCHWANDER", 14, 189119},
	{"CROSTINI", 8, 189120},
	{"BRUNDTLAND", 10, 189121},
	{"TROM", 4, 189122},
	{"TSGL", 4, 189123},
	{"NUTRAMAX", 8, 189124},
	{"INVERARAY", 9, 189125},
	{"GUADEC", 6, 189126},
	{"FAVORITAS", 9, 189127},
	{"SUBTRACTIONS", 12, 189128},
	{"RELNOTES", 8, 189129},
	{"DIGIBOX", 7, 189130},
	{"VIETA", 5, 189131},
	{"VERLINDEN", 9, 189132},
	{"NONHAZARDOUS", 12, 189133},
	{"NORPRO", 6, 189134},
	{"DCNR", 4, 189135},
	{"KRISJAN", 7, 189136},
	{"DANYCH", 6, 189137},
	{"UNABOMBER", 9, 189138},
	{"IVAX", 4, 189139},
	{"PAULINO", 7, 189140},
	{"COMMENTSPAMMING", 15, 189141},
	{"IACC", 4, 189142},
	{"GAUDIN", 6, 189143},
	{"FOCS", 4, 189144},
	{"HILAL", 5, 189145},
	{"ATHRAWON", 8, 189146},
	{"MENDACITY", 9, 189147},
	{"REVITALIZES", 11, 189148},
	{"JAPANS", 6, 189149},
	{"HOWERTON", 8, 189150},
	{"CARDROOMS", 9, 189151},
	{"SPROTT", 6, 189152},
	{"OBERGURGL", 9, 189153},
	{"TWEEDDALE", 9, 189154},
	{"TEENORGIE", 9, 189155},
	{"EPOETIN", 7, 189156},
	{"BULVERDE", 8, 189157},
	{"KUTCH", 5, 189158},
	{"RANDERS", 7, 189159},
	{"NISHIYAMA", 9, 189160},
	{"NEOPHYTES", 9, 189161},
	{"LOONIE", 6, 189162},
	{"ZOFS", 4, 189163},
	{"ZLAS", 4, 189164},
	{"WNRS", 4, 189165},
	{"VMIK", 4, 189166},
	{"UKLI", 4, 189167},
	{"RVTH", 4, 189168},
	{"OYVI", 4, 189169},
	{"NYUL", 4, 189170},
	{"NGDJ", 4, 189171},
	{"NDVR", 4, 189172},
	{"LUSQ", 4, 189173},
	{"IMSJ", 4, 189174},
	{"HDDI", 4, 189175},
	{"FMSI", 4, 189176},
	{"FDWI", 4, 189177},
	{"FCEB", 4, 189178},
	{"ESFC", 4, 189179},
	{"DGHE", 4, 189180},
	{"DDEK", 4, 189181},
	{"TAUCHEN", 7, 189182},
	{"FARRE", 5, 189183},
	{"MORB", 4, 189184},
	{"VOGON", 5, 189185},
	{"DADAR", 5, 189186},
	{"MODICON", 7, 189187},
	{"MISD", 4, 189188},
	{"LIBGNOMEMM", 10, 189189},
	{"FINALES", 7, 189190},
	{"DEFENSOR", 8, 189191},
	{"BUCKRAM", 7, 189192},
	{"ACCESSORIESPARTS", 16, 189193},
	{"PUBERTAL", 8, 189194},
	{"RUNEBERG", 8, 189195},
	{"SPAMMY", 6, 189196},
	{"REDIRECTIONS", 12, 189197},
	{"MCCALLA", 7, 189198},
	{"LAMMERMOOR", 10, 189199},
	{"COLLODION", 9, 189200},
	{"DDRESS", 6, 189201},
	{"TARDIF", 6, 189202},
	{"EXTRAVAGANTLY", 13, 189203},
	{"SIGKILL", 7, 189204},
	{"GRAE", 4, 189205},
	{"BALASUBRAMANIAN", 15, 189206},
	{"LIASE", 5, 189207},
	{"CERP", 4, 189208},
	{"INTERACTI", 9, 189209},
	{"SUBCLASSOF", 10, 189210},
	{"SHOULDE", 7, 189211},
	{"BITTLE", 6, 189212},
	{"TAMIR", 5, 189213},
	{"SOARER", 6, 189214},
	{"MJY", 3, 189215},
	{"GYMKHANA", 8, 189216},
	{"ABORTIONIST", 11, 189217},
	{"CATHOLICITY", 11, 189218},
	{"APSC", 4, 189219},
	{"MATICS", 6, 189220},
	{"BUSKER", 6, 189221},
	{"HAUPTMANN", 9, 189222},
	{"BONNEAU", 7, 189223},
	{"GODOLPHIN", 9, 189224},
	{"XRLQ", 4, 189225},
	{"EGCG", 4, 189226},
	{"DISTALLY", 8, 189227},
	{"BYREF", 5, 189228},
	{"FLEXONET", 8, 189229},
	{"BUILDED", 7, 189230},
	{"HOJAS", 5, 189231},
	{"MCIS", 4, 189232},
	{"OVERSHOT", 8, 189233},
	{"HAUGE", 5, 189234},
	{"THYMIDYLATE", 11, 189235},
	{"LACTATES", 8, 189236},
	{"TIBBITTS", 8, 189237},
	{"DICIONARY", 9, 189238},
	{"SAMICK", 6, 189239},
	{"ROADIES", 7, 189240},
	{"DOTNETBB", 8, 189241},
	{"CIPHERING", 9, 189242},
	{"VOLLE", 5, 189243},
	{"ACROS", 5, 189244},
	{"SLENDERTONE", 11, 189245},
	{"SUMMERDALE", 10, 189246},
	{"NOBORU", 6, 189247},
	{"NEOCRON", 7, 189248},
	{"IMMINENTLY", 10, 189249},
	{"PUNKBUSTER", 10, 189250},
	{"PELEE", 5, 189251},
	{"HYDROMETEOROLOGICAL", 19, 189252},
	{"WINDELERZIEHUNG", 15, 189253},
	{"FERRAGO", 7, 189254},
	{"MEECH", 5, 189255},
	{"LENKER", 6, 189256},
	{"PADDINGTONS", 11, 189257},
	{"GRADI", 5, 189258},
	{"PARSHAT", 7, 189259},
	{"JOURDAIN", 8, 189260},
	{"TAKAFUMI", 8, 189261},
	{"FMOC", 4, 189262},
	{"PRANIC", 6, 189263},
	{"NOBUNAGA", 8, 189264},
	{"SLANDERED", 9, 189265},
	{"STARCOM", 7, 189266},
	{"DEVL", 4, 189267},
	{"ADAPTO", 6, 189268},
	{"GMDSS", 5, 189269},
	{"DIHYDROFOLATE", 13, 189270},
	{"HEADWIND", 8, 189271},
	{"GRABLE", 6, 189272},
	{"CEDRO", 5, 189273},
	{"RORKE", 5, 189274},
	{"MURRIN", 6, 189275},
	{"TERATOGENICITY", 14, 189276},
	{"BOULAY", 6, 189277},
	{"ZZOP", 4, 189278},
	{"YDSH", 4, 189279},
	{"YAUB", 4, 189280},
	{"VYEX", 4, 189281},
	{"VTOD", 4, 189282},
	{"VIZC", 4, 189283},
	{"UVOO", 4, 189284},
	{"UVAA", 4, 189285},
	{"UKUT", 4, 189286},
	{"SRDB", 4, 189287},
	{"SMLB", 4, 189288},
	{"SAUW", 4, 189289},
	{"ROBK", 4, 189290},
	{"MUSN", 4, 189291},
	{"MTUL", 4, 189292},
	{"LRYE", 4, 189293},
	{"LEIU", 4, 189294},
	{"GUTM", 4, 189295},
	{"GLIZ", 4, 189296},
	{"FUCO", 4, 189297},
	{"FRWA", 4, 189298},
	{"FRIU", 4, 189299},
	{"EPJE", 4, 189300},
	{"DOMJ", 4, 189301},
	{"DCUE", 4, 189302},
	{"CYVA", 4, 189303},
	{"AVOF", 4, 189304},
	{"CAKER", 5, 189305},
	{"KUNSTHALLE", 10, 189306},
	{"ODDPARENTS", 10, 189307},
	{"ELECCIONES", 10, 189308},
	{"DEMAGOGUES", 10, 189309},
	{"PREL", 4, 189310},
	{"MURDOC", 6, 189311},
	{"SOPRON", 6, 189312},
	{"GREENFIELDS", 11, 189313},
	{"TADIC", 5, 189314},
	{"UKRAIN", 6, 189315},
	{"INATION", 7, 189316},
	{"INTEGRIS", 8, 189317},
	{"BEENS", 5, 189318},
	{"ANAESTH", 7, 189319},
	{"ROEDERER", 8, 189320},
	{"DOWTY", 5, 189321},
	{"CEPHAS", 6, 189322},
	{"BANTAMWEIGHT", 12, 189323},
	{"DIURESIS", 8, 189324},
	{"QESSALONIKH", 11, 189325},
	{"MBSQREG", 7, 189326},
	{"NAKID", 5, 189327},
	{"SEPTAGE", 7, 189328},
	{"PARAMECIUM", 10, 189329},
	{"MORRUS", 6, 189330},
	{"HUSSEINI", 8, 189331},
	{"UPLIFTMENT", 10, 189332},
	{"MAROTTA", 7, 189333},
	{"CADDEN", 6, 189334},
	{"VELARDE", 7, 189335},
	{"TANTRIX", 7, 189336},
	{"PTSUNNY", 7, 189337},
	{"HARPUR", 6, 189338},
	{"LAMBADA", 7, 189339},
	{"BARLEYLANDS", 11, 189340},
	{"SOLIPSISM", 9, 189341},
	{"SEAGO", 5, 189342},
	{"KONKA", 5, 189343},
	{"METROPOLISES", 12, 189344},
	{"MCTAVISH", 8, 189345},
	{"COTR", 4, 189346},
	{"CAPTIAN", 7, 189347},
	{"BONNYRIGG", 9, 189348},
	{"LANDICE", 7, 189349},
	{"FLIGHTY", 7, 189350},
	{"MORICE", 6, 189351},
	{"CORPSMAN", 8, 189352},
	{"ERMS", 4, 189353},
	{"REMINI", 6, 189354},
	{"TENENS", 6, 189355},
	{"SORELLE", 7, 189356},
	{"ANSTRUTHER", 10, 189357},
	{"HEPATOL", 7, 189358},
	{"OPPOSER", 7, 189359},
	{"NEOHIOPAL", 9, 189360},
	{"BARTONELLA", 10, 189361},
	{"INCORP", 6, 189362},
	{"VANGUARDS", 9, 189363},
	{"CLUBPLANET", 10, 189364},
	{"ROILING", 7, 189365},
	{"ICTIONARY", 9, 189366},
	{"WINDBLOWN", 9, 189367},
	{"MAJORETTE", 9, 189368},
	{"BEHINDS", 7, 189369},
	{"SUPERVISORIAL", 13, 189370},
	{"CRAF", 4, 189371},
	{"ABIZAID", 7, 189372},
	{"POTENTIATE", 10, 189373},
	{"PARTICULARIZED", 14, 189374},
	{"LITHOLOGIC", 10, 189375},
	{"GAINSVILLE", 10, 189376},
	{"EJUS", 4, 189377},
	{"USDAW", 5, 189378},
	{"PFLUG", 5, 189379},
	{"PROCAINAMIDE", 12, 189380},
	{"GEEBAS", 6, 189381},
	{"GARRIS", 6, 189382},
	{"AURARIA", 7, 189383},
	{"NEUTRALLY", 9, 189384},
	{"SLIDESHOWPLUGIN", 15, 189385},
	{"MALM", 4, 189386},
	{"HAWSERS", 7, 189387},
	{"CARPOOLED", 9, 189388},
	{"INFOTGP", 7, 189389},
	{"DICTS", 5, 189390},
	{"FOOTBOARDS", 10, 189391},
	{"PHILANDER", 9, 189392},
	{"NYLONSCHLAMPEN", 14, 189393},
	{"GOVERNATOR", 10, 189394},
	{"CALLINGTON", 10, 189395},
	{"SUSSER", 6, 189396},
	{"ZRIN", 4, 189397},
	{"ZALT", 4, 189398},
	{"YRAE", 4, 189399},
	{"VWAD", 4, 189400},
	{"VODO", 4, 189401},
	{"TQWE", 4, 189402},
	{"TOVR", 4, 189403},
	{"SMMU", 4, 189404},
	{"SIDM", 4, 189405},
	{"RSTX", 4, 189406},
	{"RNQI", 4, 189407},
	{"RLOE", 4, 189408},
	{"RHUI", 4, 189409},
	{"PYJA", 4, 189410},
	{"OFNP", 4, 189411},
	{"OEYR", 4, 189412},
	{"NZWI", 4, 189413},
	{"NZSC", 4, 189414},
	{"NVYA", 4, 189415},
	{"NCOK", 4, 189416},
	{"MYPS", 4, 189417},
	{"MLTH", 4, 189418},
	{"MLAH", 4, 189419},
	{"MITJ", 4, 189420},
	{"LIJE", 4, 189421},
	{"KCYP", 4, 189422},
	{"IXGE", 4, 189423},
	{"IPEU", 4, 189424},
	{"IEUD", 4, 189425},
	{"GTCH", 4, 189426},
	{"GGBE", 4, 189427},
	{"FVIK", 4, 189428},
	{"DOSV", 4, 189429},
	{"DHUI", 4, 189430},
	{"DGWO", 4, 189431},
	{"BITK", 4, 189432},
	{"BGOE", 4, 189433},
	{"BEMR", 4, 189434},
	{"BELJ", 4, 189435},
	{"ARBB", 4, 189436},
	{"ABOP", 4, 189437},
	{"TABLEDANCE", 10, 189438},
	{"TBUFFER", 7, 189439},
	{"DESTABILIZED", 12, 189440},
	{"PAGOS", 5, 189441},
	{"KOKI", 4, 189442},
	{"HOLSINGER", 9, 189443},
	{"STUDENTI", 8, 189444},
	{"VEALE", 5, 189445},
	{"GARNISHING", 10, 189446},
	{"WERNICKE", 8, 189447},
	{"SPITFIRES", 9, 189448},
	{"ALITA", 5, 189449},
	{"PUTERS", 6, 189450},
	{"PIETTE", 6, 189451},
	{"GABLED", 6, 189452},
	{"VICTIMISED", 10, 189453},
	{"MPAC", 4, 189454},
	{"LOPINAVIR", 9, 189455},
	{"GNUENTERPRISE", 13, 189456},
	{"ACHIVE", 6, 189457},
	{"MCCONE", 6, 189458},
	{"INSANIQUARIUM", 13, 189459},
	{"MINCEMEAT", 9, 189460},
	{"LPFM", 4, 189461},
	{"CONVIENT", 8, 189462},
	{"LANDI", 5, 189463},
	{"UBIQUITOUSLY", 12, 189464},
	{"SCHOONOVER", 10, 189465},
	{"MARANDA", 7, 189466},
	{"ASMAIL", 6, 189467},
	{"AMPTHILL", 8, 189468},
	{"TETHERING", 9, 189469},
	{"MUSICOLOGIST", 12, 189470},
	{"GALLAWAY", 8, 189471},
	{"CEPHALOPOD", 10, 189472},
	{"LAWRY", 5, 189473},
	{"REEDSPORT", 9, 189474},
	{"BARTOLOME", 9, 189475},
	{"UNTARRING", 9, 189476},
	{"POSTBANK", 8, 189477},
	{"CRCA", 4, 189478},
	{"LEEW", 4, 189479},
	{"JIGGA", 5, 189480},
	{"MAJIK", 5, 189481},
	{"PAPAGO", 6, 189482},
	{"THESSALONICA", 12, 189483},
	{"SETID", 5, 189484},
	{"RECORDNOW", 9, 189485},
	{"OURT", 4, 189486},
	{"TIBOOK", 6, 189487},
	{"BASKETBALLNCAA", 14, 189488},
	{"BAGNEWS", 7, 189489},
	{"ELIB", 4, 189490},
	{"AVNERY", 6, 189491},
	{"TEIGNBRIDGE", 11, 189492},
	{"LOOKIE", 6, 189493},
	{"GIATI", 5, 189494},
	{"FERRERA", 7, 189495},
	{"ENRAGE", 6, 189496},
	{"POLLOI", 6, 189497},
	{"DEPENDANCE", 10, 189498},
	{"TESTAVERDE", 10, 189499},
	{"CONVIO", 6, 189500},
	{"SUPRAVENTRICULAR", 16, 189501},
	{"YOSHITOSHI", 10, 189502},
	{"TOGAF", 5, 189503},
	{"AYLER", 5, 189504},
	{"LLOYDMINSER", 11, 189505},
	{"LINGCOD", 7, 189506},
	{"ICONA", 5, 189507},
	{"ZUKERMAN", 8, 189508},
	{"SNUFFY", 6, 189509},
	{"RUBER", 5, 189510},
	{"MULTIROOM", 9, 189511},
	{"MAINTENACE", 10, 189512},
	{"CURRULE", 7, 189513},
	{"ISTRICT", 7, 189514},
	{"DANKA", 5, 189515},
	{"VIRTUALHOST", 11, 189516},
	{"FORRIGE", 7, 189517},
	{"TIMESAVER", 9, 189518},
	{"LIBACE", 6, 189519},
	{"EROTIKA", 7, 189520},
	{"HOPIN", 5, 189521},
	{"SHOVELER", 8, 189522},
	{"REINERT", 7, 189523},
	{"OZDIP", 5, 189524},
	{"DOWNLODS", 8, 189525},
	{"CBAT", 4, 189526},
	{"STARKER", 7, 189527},
	{"HODGDON", 7, 189528},
	{"HOTETUR", 7, 189529},
	{"GOLL", 4, 189530},
	{"BARONI", 6, 189531},
	{"WALESA", 6, 189532},
	{"CHIRPY", 6, 189533},
	{"TRUX", 4, 189534},
	{"TELEPORTER", 10, 189535},
	{"REDUCTASES", 10, 189536},
	{"POLONIUM", 8, 189537},
	{"FLACH", 5, 189538},
	{"SANDWICHFICK", 12, 189539},
	{"HAWAIIN", 7, 189540},
	{"MACNAUGHTON", 11, 189541},
	{"INFORMATON", 10, 189542},
	{"CORUNDUM", 8, 189543},
	{"REENLISTMENT", 12, 189544},
	{"GAMECENTER", 10, 189545},
	{"FRANKA", 6, 189546},
	{"ARCOR", 5, 189547},
	{"ISPF", 4, 189548},
	{"AMPLIFICATIONS", 14, 189549},
	{"BRONZEAGE", 9, 189550},
	{"YMEP", 4, 189551},
	{"WLSB", 4, 189552},
	{"WLBA", 4, 189553},
	{"VDOE", 4, 189554},
	{"UTZM", 4, 189555},
	{"UDAV", 4, 189556},
	{"TSDW", 4, 189557},
	{"TCTR", 4, 189558},
	{"TCDR", 4, 189559},
	{"STVR", 4, 189560},
	{"SKEX", 4, 189561},
	{"RPFE", 4, 189562},
	{"REKY", 4, 189563},
	{"PMBY", 4, 189564},
	{"PETK", 4, 189565},
	{"OICR", 4, 189566},
	{"NDKB", 4, 189567},
	{"MBDR", 4, 189568},
	{"KIBI", 4, 189569},
	{"KHLO", 4, 189570},
	{"HBIC", 4, 189571},
	{"FUDA", 4, 189572},
	{"FILB", 4, 189573},
	{"EVSF", 4, 189574},
	{"ENWU", 4, 189575},
	{"EKUC", 4, 189576},
	{"DJMA", 4, 189577},
	{"COLQ", 4, 189578},
	{"BPAL", 4, 189579},
	{"BLIU", 4, 189580},
	{"BJAC", 4, 189581},
	{"BOGARD", 6, 189582},
	{"RAPSON", 6, 189583},
	{"UNICEL", 6, 189584},
	{"TALINUX", 7, 189585},
	{"SINEWS", 6, 189586},
	{"FLEMINGS", 8, 189587},
	{"DINKA", 5, 189588},
	{"LEUKOTRIENES", 12, 189589},
	{"ROBACK", 6, 189590},
	{"EROTICI", 7, 189591},
	{"MASP", 4, 189592},
	{"XMLSEC", 6, 189593},
	{"PROMOONLY", 9, 189594},
	{"DETACHES", 8, 189595},
	{"TRILBY", 6, 189596},
	{"EXPERIMEN", 9, 189597},
	{"CHIRPS", 6, 189598},
	{"STUDIOLINE", 10, 189599},
	{"ARCAT", 5, 189600},
	{"ASHKENAZY", 9, 189601},
	{"TUTIONS", 7, 189602},
	{"GLANZ", 5, 189603},
	{"WALLAROO", 8, 189604},
	{"SCHAPIRO", 8, 189605},
	{"VIMS", 4, 189606},
	{"LODIS", 5, 189607},
	{"GAYTWINKS", 9, 189608},
	{"HASHMI", 6, 189609},
	{"PHOTOEUPHORIA", 13, 189610},
	{"KIRKINTILLOCH", 13, 189611},
	{"INTERCHANGING", 13, 189612},
	{"ASTRAKHAN", 9, 189613},
	{"IREANN", 6, 189614},
	{"GLYCAN", 6, 189615},
	{"STIER", 5, 189616},
	{"LAGES", 5, 189617},
	{"SERJEANT", 8, 189618},
	{"ECHINODERMS", 11, 189619},
	{"ARVES", 5, 189620},
	{"VIROQUA", 7, 189621},
	{"PASTRYWIZ", 9, 189622},
	{"KOMONDOR", 8, 189623},
	{"RITENOUR", 8, 189624},
	{"LOANPAYDAY", 10, 189625},
	{"SUMMERTOWN", 10, 189626},
	{"HELLMANN", 8, 189627},
	{"REALVIZ", 7, 189628},
	{"LOMOGRAPHY", 10, 189629},
	{"FATALISTIC", 10, 189630},
	{"COURVOISIER", 11, 189631},
	{"LOADEDHUMOR", 11, 189632},
	{"DECUBITUS", 9, 189633},
	{"STDDEV", 6, 189634},
	{"HIRUNDO", 7, 189635},
	{"DUDU", 4, 189636},
	{"SHADRACH", 8, 189637},
	{"RDESKTOP", 8, 189638},
	{"EFFE", 4, 189639},
	{"SOUCE", 5, 189640},
	{"VLOGGING", 8, 189641},
	{"SDFCHECKER", 10, 189642},
	{"PEELERS", 7, 189643},
	{"VALENCIANNAILS", 14, 189644},
	{"LAMEST", 6, 189645},
	{"INPLACE", 7, 189646},
	{"MONOGRAPHIC", 11, 189647},
	{"DEXTERRA", 8, 189648},
	{"PITTORE", 7, 189649},
	{"WWSLOG", 6, 189650},
	{"LSRS", 4, 189651},
	{"BLATHERING", 10, 189652},
	{"VERBALIZE", 9, 189653},
	{"SHALLOWNESS", 11, 189654},
	{"GTAP", 4, 189655},
	{"VIAGGIA", 7, 189656},
	{"OLEY", 4, 189657},
	{"RUMINAL", 7, 189658},
	{"ILKKA", 5, 189659},
	{"BIOONE", 6, 189660},
	{"KAIF", 4, 189661},
	{"BVRP", 4, 189662},
	{"FLEURVILLE", 10, 189663},
	{"AVCE", 4, 189664},
	{"CAMER", 5, 189665},
	{"ABHINAV", 7, 189666},
	{"ENDOCYTIC", 9, 189667},
	{"NIGRO", 5, 189668},
	{"MZSCHEME", 8, 189669},
	{"INTERCESSORY", 12, 189670},
	{"GRAPHABLE", 9, 189671},
	{"BOUNDRIES", 9, 189672},
	{"ZSLA", 4, 189673},
	{"ZORW", 4, 189674},
	{"ZIEP", 4, 189675},
	{"YTSU", 4, 189676},
	{"XLIE", 4, 189677},
	{"WEBG", 4, 189678},
	{"VNAR", 4, 189679},
	{"URFP", 4, 189680},
	{"TSPP", 4, 189681},
	{"TOKC", 4, 189682},
	{"TLUL", 4, 189683},
	{"TGMS", 4, 189684},
	{"SKUC", 4, 189685},
	{"SEJP", 4, 189686},
	{"RZAT", 4, 189687},
	{"RUAI", 4, 189688},
	{"OFKB", 4, 189689},
	{"MTVT", 4, 189690},
	{"MNEZ", 4, 189691},
	{"LAPY", 4, 189692},
	{"JINM", 4, 189693},
	{"HEJF", 4, 189694},
	{"GHOG", 4, 189695},
	{"EDWU", 4, 189696},
	{"DEIB", 4, 189697},
	{"DECJ", 4, 189698},
	{"DDDA", 4, 189699},
	{"CCTE", 4, 189700},
	{"BYEO", 4, 189701},
	{"BIJE", 4, 189702},
	{"AYMS", 4, 189703},
	{"AXIR", 4, 189704},
	{"LEVITATING", 10, 189705},
	{"LABLES", 6, 189706},
	{"TRATE", 5, 189707},
	{"LYSERGIC", 8, 189708},
	{"RENAULTSPORT", 12, 189709},
	{"JAVASCRIPTCORE", 14, 189710},
	{"ENSNARED", 8, 189711},
	{"BEREN", 5, 189712},
	{"LOYALLY", 7, 189713},
	{"ESCHOLARSHIP", 12, 189714},
	{"WATERBROOK", 10, 189715},
	{"SNEEZED", 7, 189716},
	{"DISCONTINUES", 12, 189717},
	{"NITRA", 5, 189718},
	{"REDSKIN", 7, 189719},
	{"FUTUREPUNDIT", 12, 189720},
	{"STONEFLIES", 10, 189721},
	{"SHROOM", 6, 189722},
	{"NAESB", 5, 189723},
	{"DPWNLOAD", 8, 189724},
	{"MUSHROOMED", 10, 189725},
	{"IMPRESSA", 8, 189726},
	{"YIXING", 6, 189727},
	{"TOBYHANNA", 9, 189728},
	{"MAZARIN", 7, 189729},
	{"SEIDENBERG", 10, 189730},
	{"CUTLET", 6, 189731},
	{"PAAVO", 5, 189732},
	{"GUIDESTAR", 9, 189733},
	{"NOONTIME", 8, 189734},
	{"TEKTRO", 6, 189735},
	{"VORDERMAN", 9, 189736},
	{"JENNISON", 8, 189737},
	{"UNAC", 4, 189738},
	{"RISKINESS", 9, 189739},
	{"PHLEBOTOMIST", 12, 189740},
	{"QUOTECREDIT", 11, 189741},
	{"LANOXIN", 7, 189742},
	{"ACADEM", 6, 189743},
	{"HAZES", 5, 189744},
	{"YEAP", 4, 189745},
	{"PROCYON", 7, 189746},
	{"MICREL", 6, 189747},
	{"PROMYELOCYTIC", 13, 189748},
	{"FROGPAD", 7, 189749},
	{"GRYPHONS", 8, 189750},
	{"TARGETDOG", 9, 189751},
	{"PNFORUM", 7, 189752},
	{"BWANA", 5, 189753},
	{"ALBIA", 5, 189754},
	{"TEKSTEN", 7, 189755},
	{"PASSIVATED", 10, 189756},
	{"TIFICATION", 10, 189757},
	{"DARKLING", 8, 189758},
	{"XPANDAX", 7, 189759},
	{"RECIRCULATED", 12, 189760},
	{"PHASERS", 7, 189761},
	{"LOSANGELES", 10, 189762},
	{"REDUCTIO", 8, 189763},
	{"LIPOMA", 6, 189764},
	{"SUPPORTABILITY", 14, 189765},
	{"SUBSERVIENCE", 12, 189766},
	{"CRACKERJACK", 11, 189767},
	{"OCCURANCES", 10, 189768},
	{"NIGHTINGALES", 12, 189769},
	{"AIZAWA", 6, 189770},
	{"MENSYS", 6, 189771},
	{"STROMNESS", 9, 189772},
	{"VLIST", 5, 189773},
	{"EXTREMCHAT", 10, 189774},
	{"EXECVE", 6, 189775},
	{"TIRITH", 6, 189776},
	{"DEALCAM", 7, 189777},
	{"BRAGAS", 6, 189778},
	{"MALENE", 6, 189779},
	{"ZHONGWEN", 8, 189780},
	{"GAPED", 5, 189781},
	{"PILCH", 5, 189782},
	{"PARDUS", 6, 189783},
	{"LATINTEEN", 9, 189784},
	{"BEINN", 5, 189785},
	{"SUBDUING", 8, 189786},
	{"FUMENTO", 7, 189787},
	{"REWIRED", 7, 189788},
	{"APOPLEXY", 8, 189789},
	{"ICASSP", 6, 189790},
	{"TERRITOIRES", 11, 189791},
	{"DALLAIRE", 8, 189792},
	{"KAMAS", 5, 189793},
	{"ARABY", 5, 189794},
	{"LLOBREGAT", 9, 189795},
	{"THERIOT", 7, 189796},
	{"DEINONYCHUS", 11, 189797},
	{"MULVIHILL", 9, 189798},
	{"MEXBOROUGH", 10, 189799},
	{"DANNO", 5, 189800},
	{"YLUG", 4, 189801},
	{"WVOC", 4, 189802},
	{"WEOV", 4, 189803},
	{"URMY", 4, 189804},
	{"SHJR", 4, 189805},
	{"RKYB", 4, 189806},
	{"QCON", 4, 189807},
	{"OUMN", 4, 189808},
	{"OLTY", 4, 189809},
	{"OKCI", 4, 189810},
	{"NPMO", 4, 189811},
	{"MBPA", 4, 189812},
	{"LTZB", 4, 189813},
	{"LEIZ", 4, 189814},
	{"KKRI", 4, 189815},
	{"ILUK", 4, 189816},
	{"HTMR", 4, 189817},
	{"GIBU", 4, 189818},
	{"FRBI", 4, 189819},
	{"FMRO", 4, 189820},
	{"EYIC", 4, 189821},
	{"ELMM", 4, 189822},
	{"DOWV", 4, 189823},
	{"DKMH", 4, 189824},
	{"CIZA", 4, 189825},
	{"CIJA", 4, 189826},
	{"ALCC", 4, 189827},
	{"AHYM", 4, 189828},
	{"AFCL", 4, 189829},
	{"TEALE", 5, 189830},
	{"VOIDABLE", 8, 189831},
	{"ORDBOKSOEK", 10, 189832},
	{"GORDANO", 7, 189833},
	{"MORAIS", 6, 189834},
	{"MARIBYRNONG", 11, 189835},
	{"ATTACHFILESIZELIMIT", 19, 189836},
	{"HANAFIN", 7, 189837},
	{"UNEXERCISED", 11, 189838},
	{"RECTION", 7, 189839},
	{"HORNSTEIN", 9, 189840},
	{"DESAPARECIDOS", 13, 189841},
	{"SPLITTED", 8, 189842},
	{"POORHOUSE", 9, 189843},
	{"TOWNSON", 7, 189844},
	{"DECISIVENESS", 12, 189845},
	{"AMLWCH", 6, 189846},
	{"LINDQVIST", 9, 189847},
	{"NIKITIN", 7, 189848},
	{"STEEVES", 7, 189849},
	{"PHOTIC", 6, 189850},
	{"KIKKA", 5, 189851},
	{"SAMOKOV", 7, 189852},
	{"BACKTRACKED", 11, 189853},
	{"GSPOT", 5, 189854},
	{"MULLIKEN", 8, 189855},
	{"LLANRWST", 8, 189856},
	{"CHIRICO", 7, 189857},
	{"MANTRIC", 7, 189858},
	{"AURAVITA", 8, 189859},
	{"HILLTOPERS", 10, 189860},
	{"QKINDEX", 7, 189861},
	{"REINTEGRATE", 11, 189862},
	{"MAJORANA", 8, 189863},
	{"FOLKSONG", 8, 189864},
	{"ASPECTOS", 8, 189865},
	{"HYDREF", 6, 189866},
	{"SYNCHED", 7, 189867},
	{"PREVIEWER", 9, 189868},
	{"XENOBIOTIC", 10, 189869},
	{"TOPDIR", 6, 189870},
	{"GOTY", 4, 189871},
	{"CEAP", 4, 189872},
	{"RIFFIC", 6, 189873},
	{"LIFEJACKET", 10, 189874},
	{"JROCKIT", 7, 189875},
	{"FUGUES", 6, 189876},
	{"KIRCHER", 7, 189877},
	{"BIONCA", 6, 189878},
	{"IMERYS", 6, 189879},
	{"GOTTESMAN", 9, 189880},
	{"BORGNINE", 8, 189881},
	{"SINTEF", 6, 189882},
	{"DONGARRA", 8, 189883},
	{"SEAWOLF", 7, 189884},
	{"LETTERMEN", 9, 189885},
	{"INFLECTIONAL", 12, 189886},
	{"BRITTAN", 7, 189887},
	{"ZCM", 3, 189888},
	{"KIRUNDI", 7, 189889},
	{"CORNO", 5, 189890},
	{"SUCCINIC", 8, 189891},
	{"OFCCP", 5, 189892},
	{"CYANOBACTERIAL", 14, 189893},
	{"FOOTWARE", 8, 189894},
	{"KRAK", 4, 189895},
	{"DEPOE", 5, 189896},
	{"STONEWASH", 9, 189897},
	{"SCHECK", 6, 189898},
	{"UMPTEEN", 7, 189899},
	{"DANAZOL", 7, 189900},
	{"AUTOBID", 7, 189901},
	{"SIVAKUMAR", 9, 189902},
	{"INDEXABLE", 9, 189903},
	{"ANTHON", 6, 189904},
	{"SLANTS", 6, 189905},
	{"EPILEPTICUS", 11, 189906},
	{"MASATOSHI", 9, 189907},
	{"CYBERGUARD", 10, 189908},
	{"MISTI", 5, 189909},
	{"GAMEQUESTDIRECT", 15, 189910},
	{"USDE", 4, 189911},
	{"STORMRIDER", 10, 189912},
	{"SUNBEAMS", 8, 189913},
	{"HASSLED", 7, 189914},
	{"TINGLY", 6, 189915},
	{"SELFHOOD", 8, 189916},
	{"TEKLOGIX", 8, 189917},
	{"WKB", 3, 189918},
	{"LOGN", 4, 189919},
	{"ALLAIN", 6, 189920},
	{"BUFFON", 6, 189921},
	{"TOPHAM", 6, 189922},
	{"TECHNIBOND", 10, 189923},
	{"SUBSCRIPTBOX", 12, 189924},
	{"CHANGESETS", 10, 189925},
	{"CCBC", 4, 189926},
	{"FAHNEN", 6, 189927},
	{"SKERRY", 6, 189928},
	{"STEINBERGER", 11, 189929},
	{"AUTHORITIE", 10, 189930},
	{"TELLINGLY", 9, 189931},
	{"STONERS", 7, 189932},
	{"SCHILL", 6, 189933},
	{"HETFIELD", 8, 189934},
	{"ENTREVISTA", 10, 189935},
	{"ZIAU", 4, 189936},
	{"ZACT", 4, 189937},
	{"YSKR", 4, 189938},
	{"YNGI", 4, 189939},
	{"VLET", 4, 189940},
	{"VACK", 4, 189941},
	{"TYKR", 4, 189942},
	{"SKUT", 4, 189943},
	{"RLOK", 4, 189944},
	{"RIZH", 4, 189945},
	{"RIFK", 4, 189946},
	{"RAIV", 4, 189947},
	{"PUPC", 4, 189948},
	{"OVOG", 4, 189949},
	{"OUGP", 4, 189950},
	{"MYRS", 4, 189951},
	{"KVEL", 4, 189952},
	{"IZME", 4, 189953},
	{"GNPU", 4, 189954},
	{"FMOG", 4, 189955},
	{"FIMW", 4, 189956},
	{"ENPD", 4, 189957},
	{"DMYU", 4, 189958},
	{"DJIE", 4, 189959},
	{"DICY", 4, 189960},
	{"DHEX", 4, 189961},
	{"DDMC", 4, 189962},
	{"CYEF", 4, 189963},
	{"CAYT", 4, 189964},
	{"ARBW", 4, 189965},
	{"JUNKED", 6, 189966},
	{"SILVE", 5, 189967},
	{"BRIGAND", 7, 189968},
	{"BEUTLER", 7, 189969},
	{"OVERHYPED", 9, 189970},
	{"KENTARO", 7, 189971},
	{"JAHRHUNDERT", 11, 189972},
	{"CHASMS", 6, 189973},
	{"GAMECOM", 7, 189974},
	{"BRUNERO", 7, 189975},
	{"BALLADINS", 9, 189976},
	{"PANNY", 5, 189977},
	{"LUQUE", 5, 189978},
	{"NOZOMI", 6, 189979},
	{"LEATHE", 6, 189980},
	{"SHUMATE", 7, 189981},
	{"SEIMAS", 6, 189982},
	{"MIENET", 6, 189983},
	{"TIMEY", 5, 189984},
	{"POLYXMASS", 9, 189985},
	{"CASSAR", 6, 189986},
	{"SPURNS", 6, 189987},
	{"GIFFEN", 6, 189988},
	{"SOUNDBYTES", 10, 189989},
	{"NORILSK", 7, 189990},
	{"VEGLIFE", 7, 189991},
	{"WEBTOPICVIEWTEMPLATE", 20, 189992},
	{"JOBHUNTERS", 10, 189993},
	{"HORD", 4, 189994},
	{"STAINTON", 8, 189995},
	{"AQUISTO", 7, 189996},
	{"TANTRAMASSAGEN", 14, 189997},
	{"OUTERLIMITS", 11, 189998},
	{"SILENTS", 7, 189999},
	{"JEALOUSIES", 10, 190000},
	{"DOWBLOAD", 8, 190001},
	{"DEDO", 4, 190002},
	{"PAESTUM", 7, 190003},
	{"ICQHACKERS", 10, 190004},
	{"DITTIES", 7, 190005},
	{"CHROMAFFIN", 10, 190006},
	{"NEWSCOM", 7, 190007},
	{"NEFAZODONE", 10, 190008},
	{"PMBOK", 5, 190009},
	{"GIONS", 5, 190010},
	{"FOOTPRINTING", 12, 190011},
	{"DECAMP", 6, 190012},
	{"ABIOGENESIS", 11, 190013},
	{"TYLENE", 6, 190014},
	{"PANED", 5, 190015},
	{"OMARI", 5, 190016},
	{"BELCHFIRE", 9, 190017},
	{"KLOSTERMAN", 10, 190018},
	{"CCMA", 4, 190019},
	{"QUANH", 5, 190020},
	{"COMUNICACIONES", 14, 190021},
	{"BEKMAN", 6, 190022},
	{"POUILLY", 7, 190023},
	{"EUONYMUS", 8, 190024},
	{"SUMVISION", 9, 190025},
	{"STARGAZERS", 10, 190026},
	{"RUNCIMAN", 8, 190027},
	{"GRAMENE", 7, 190028},
	{"KAMARA", 6, 190029},
	{"COMPOSANTS", 10, 190030},
	{"PNFLASHGAMES", 12, 190031},
	{"PLAKA", 5, 190032},
	{"BROIN", 5, 190033},
	{"APPLIX", 6, 190034},
	{"YUJIN", 5, 190035},
	{"NORPLANT", 8, 190036},
	{"TRATA", 5, 190037},
	{"XPRT", 4, 190038},
	{"NCAAS", 5, 190039},
	{"DIGNITARY", 9, 190040},
	{"FABIANA", 7, 190041},
	{"WISES", 5, 190042},
	{"SAMENVATTING", 12, 190043},
	{"SPERMINE", 8, 190044},
	{"BEARTOOTH", 9, 190045},
	{"KIBLER", 6, 190046},
	{"FREDTALK", 8, 190047},
	{"MANNIE", 6, 190048},
	{"FLORENCIA", 9, 190049},
	{"UNITHOLDER", 10, 190050},
	{"ILLINIOS", 8, 190051},
	{"INMOBILIARIA", 12, 190052},
	{"UNIVESITY", 9, 190053},
	{"NAQVI", 5, 190054},
	{"ENSCE", 5, 190055},
	{"WEBCONTROLS", 11, 190056},
	{"MELVYL", 6, 190057},
	{"LHMU", 4, 190058},
	{"HURR", 4, 190059},
	{"KEIFER", 6, 190060},
	{"SCHOLAE", 7, 190061},
	{"HLRZ", 4, 190062},
	{"ENSDM", 5, 190063},
	{"WENCHES", 7, 190064},
	{"ZWEL", 4, 190065},
	{"ZEEM", 4, 190066},
	{"YOOF", 4, 190067},
	{"XMLF", 4, 190068},
	{"WDAD", 4, 190069},
	{"UGAH", 4, 190070},
	{"TMGM", 4, 190071},
	{"SYFY", 4, 190072},
	{"RLTR", 4, 190073},
	{"OMPP", 4, 190074},
	{"OLTG", 4, 190075},
	{"OJAL", 4, 190076},
	{"NZOP", 4, 190077},
	{"NFAW", 4, 190078},
	{"MKES", 4, 190079},
	{"MCTA", 4, 190080},
	{"LRCA", 4, 190081},
	{"LKTE", 4, 190082},
	{"KOIZ", 4, 190083},
	{"KNOD", 4, 190084},
	{"JSTR", 4, 190085},
	{"IUMK", 4, 190086},
	{"ISYW", 4, 190087},
	{"IBDI", 4, 190088},
	{"HEVV", 4, 190089},
	{"GACD", 4, 190090},
	{"FMRE", 4, 190091},
	{"ECIU", 4, 190092},
	{"DEZP", 4, 190093},
	{"AMMB", 4, 190094},
	{"OBZOR", 5, 190095},
	{"EVARTS", 6, 190096},
	{"BALLANTINES", 11, 190097},
	{"LYDNEY", 6, 190098},
	{"MAILLARD", 8, 190099},
	{"SMIRNIOTOPOULOS", 15, 190100},
	{"GALITSIN", 8, 190101},
	{"JTEXTFIELD", 10, 190102},
	{"SABANA", 6, 190103},
	{"TEKAPO", 6, 190104},
	{"SWRI", 4, 190105},
	{"SUPEREGO", 8, 190106},
	{"GARSIDE", 7, 190107},
	{"SCHAAP", 6, 190108},
	{"PMTOOLS", 7, 190109},
	{"GEOGHAN", 7, 190110},
	{"CORRIENTES", 10, 190111},
	{"GESICHT", 7, 190112},
	{"FOWNLOAD", 8, 190113},
	{"TENSEI", 6, 190114},
	{"KRAJINA", 7, 190115},
	{"IMPROBABILITY", 13, 190116},
	{"ONTWIKKELING", 12, 190117},
	{"SWATHES", 7, 190118},
	{"COPORATE", 8, 190119},
	{"ADAMI", 5, 190120},
	{"TIPSTERS", 8, 190121},
	{"PERISHABLES", 11, 190122},
	{"DISPLAYER", 9, 190123},
	{"APPWORX", 7, 190124},
	{"SHREWDLY", 8, 190125},
	{"NORTEK", 6, 190126},
	{"WOLFEN", 6, 190127},
	{"PROVOCATIVELY", 13, 190128},
	{"SNEERS", 6, 190129},
	{"CLARITAS", 8, 190130},
	{"LOCHER", 6, 190131},
	{"RESIDENTAL", 10, 190132},
	{"CRIMPS", 6, 190133},
	{"STARTTLS", 8, 190134},
	{"SUWON", 5, 190135},
	{"BLOSSER", 7, 190136},
	{"RENMARK", 7, 190137},
	{"LATHYRUS", 8, 190138},
	{"EPILOG", 6, 190139},
	{"TANJONG", 7, 190140},
	{"THUMBUP", 7, 190141},
	{"BLOODHOUNDS", 11, 190142},
	{"VOCATIONALLY", 12, 190143},
	{"PROVENTIL", 9, 190144},
	{"MEED", 4, 190145},
	{"DURCHSCHNITTLICHE", 17, 190146},
	{"UNMADE", 6, 190147},
	{"CASION", 6, 190148},
	{"MEDITERRANEUM", 13, 190149},
	{"CYFARFOD", 8, 190150},
	{"RESTOCKS", 8, 190151},
	{"TORREON", 7, 190152},
	{"KARASTAN", 8, 190153},
	{"BETWSC", 6, 190154},
	{"UNDRAINED", 9, 190155},
	{"SANTIAM", 7, 190156},
	{"DIMINUER", 8, 190157},
	{"AQUESTA", 7, 190158},
	{"TIFIC", 5, 190159},
	{"MARMI", 5, 190160},
	{"TINUED", 6, 190161},
	{"GEILETITTEN", 11, 190162},
	{"TIOMAN", 6, 190163},
	{"VPLS", 4, 190164},
	{"MARCHAL", 7, 190165},
	{"MIMA", 4, 190166},
	{"BRANCHEN", 8, 190167},
	{"EVYAPAR", 7, 190168},
	{"LOWY", 4, 190169},
	{"IMPISH", 6, 190170},
	{"EYEWALL", 7, 190171},
	{"CRECHES", 7, 190172},
	{"MENACED", 7, 190173},
	{"BARVE", 5, 190174},
	{"INTERV", 6, 190175},
	{"VIRGINICA", 9, 190176},
	{"PROSHOP", 7, 190177},
	{"FLOUTING", 8, 190178},
	{"TEDY", 4, 190179},
	{"BADAN", 5, 190180},
	{"VCAT", 4, 190181},
	{"VAQUERO", 7, 190182},
	{"SENESCHAL", 9, 190183},
	{"MEASURERS", 9, 190184},
	{"MALOY", 5, 190185},
	{"ELSMERE", 7, 190186},
	{"APSFILTER", 9, 190187},
	{"TROUGHTON", 9, 190188},
	{"OVALE", 5, 190189},
	{"FRANCISVILLE", 12, 190190},
	{"RUDRA", 5, 190191},
	{"NONPOLAR", 8, 190192},
	{"CHESSMEN", 8, 190193},
	{"ZSFI", 4, 190194},
	{"XYST", 4, 190195},
	{"XMLD", 4, 190196},
	{"VJAM", 4, 190197},
	{"VIIC", 4, 190198},
	{"VAKH", 4, 190199},
	{"UKGE", 4, 190200},
	{"UBLU", 4, 190201},
	{"UAIM", 4, 190202},
	{"TOCZ", 4, 190203},
	{"RUIK", 4, 190204},
	{"RDOK", 4, 190205},
	{"PBEY", 4, 190206},
	{"OUDJ", 4, 190207},
	{"ONWU", 4, 190208},
	{"OLZS", 4, 190209},
	{"OBSY", 4, 190210},
	{"NZBU", 4, 190211},
	{"MYEF", 4, 190212},
	{"MLSA", 4, 190213},
	{"LMNA", 4, 190214},
	{"KRIO", 4, 190215},
	{"KBRY", 4, 190216},
	{"IPSQ", 4, 190217},
	{"HUSY", 4, 190218},
	{"GUAV", 4, 190219},
	{"GPOC", 4, 190220},
	{"GOYD", 4, 190221},
	{"GIUN", 4, 190222},
	{"GGBO", 4, 190223},
	{"FMEB", 4, 190224},
	{"FIUS", 4, 190225},
	{"EXEV", 4, 190226},
	{"EEUF", 4, 190227},
	{"BLAA", 4, 190228},
	{"TETRODOTOXIN", 12, 190229},
	{"EISENTRAUT", 10, 190230},
	{"ARABBA", 6, 190231},
	{"DEAFENED", 8, 190232},
	{"REDIRIS", 7, 190233},
	{"STANCHION", 9, 190234},
	{"ERGOTAMINE", 10, 190235},
	{"CLIMATISATION", 13, 190236},
	{"AMOD", 4, 190237},
	{"RECOMBINE", 9, 190238},
	{"MACR", 4, 190239},
	{"MULTIGENERATIONAL", 17, 190240},
	{"MCCULLEY", 8, 190241},
	{"BOOKSDESKTOPS", 13, 190242},
	{"HOOTING", 7, 190243},
	{"FIELDEN", 7, 190244},
	{"MANWL", 5, 190245},
	{"WEBNET", 6, 190246},
	{"ENANTHATE", 9, 190247},
	{"ANARCHA", 7, 190248},
	{"RUBRIQUE", 8, 190249},
	{"KIRWIN", 6, 190250},
	{"CLUNK", 5, 190251},
	{"FUTEBOL", 7, 190252},
	{"DESCANT", 7, 190253},
	{"MORAVEC", 7, 190254},
	{"BETHEA", 6, 190255},
	{"APRILAIRE", 9, 190256},
	{"BURROUGH", 8, 190257},
	{"GOTTEX", 6, 190258},
	{"TUNKHANNOCK", 11, 190259},
	{"AFFENPINSCHER", 13, 190260},
	{"MINTAGE", 7, 190261},
	{"COROLLARIES", 11, 190262},
	{"JBIC", 4, 190263},
	{"TEENREPORT", 10, 190264},
	{"PLATINIUM", 9, 190265},
	{"CYRENE", 6, 190266},
	{"CLIVAR", 6, 190267},
	{"DOWNLODA", 8, 190268},
	{"OSUOSL", 6, 190269},
	{"FCPA", 4, 190270},
	{"MONTELL", 7, 190271},
	{"HORMS", 5, 190272},
	{"SMARTWEED", 9, 190273},
	{"MUZZLELOADING", 13, 190274},
	{"UPTREND", 7, 190275},
	{"SLOGGING", 8, 190276},
	{"WAHAB", 5, 190277},
	{"HISTLX", 6, 190278},
	{"CRBO", 4, 190279},
	{"PIAZZALE", 8, 190280},
	{"DYSTHYMIA", 9, 190281},
	{"KARSH", 5, 190282},
	{"GILFILLAN", 9, 190283},
	{"HELIOSPHERIC", 12, 190284},
	{"DEJECTION", 9, 190285},
	{"BERNARDSVILLE", 13, 190286},
	{"KIANG", 5, 190287},
	{"WONDERFALLS", 11, 190288},
	{"BMWRACER", 8, 190289},
	{"MIZELL", 6, 190290},
	{"MEIRELLES", 9, 190291},
	{"EXCEPTIONALISM", 14, 190292},
	{"ARMSTEAD", 8, 190293},
	{"PARALLELIZING", 13, 190294},
	{"SUBCOMMANDS", 11, 190295},
	{"PSYCHOGENIC", 11, 190296},
	{"EXTREMEFITNESS", 14, 190297},
	{"POLOKWANE", 9, 190298},
	{"GINEI", 5, 190299},
	{"MERROW", 6, 190300},
	{"COBAR", 5, 190301},
	{"DOMETIC", 7, 190302},
	{"DISTRACTOR", 10, 190303},
	{"OLIGOMERIZATION", 15, 190304},
	{"PERIGORD", 8, 190305},
	{"DORDOGNESHIREQUOT", 17, 190306},
	{"ROORKEE", 7, 190307},
	{"YOLANDE", 7, 190308},
	{"VIRSYN", 6, 190309},
	{"FITTIPALDI", 10, 190310},
	{"CHEWER", 6, 190311},
	{"LIFFE", 5, 190312},
	{"HUMPHRYS", 8, 190313},
	{"ECONOMIZE", 9, 190314},
	{"SCHERMERHORN", 12, 190315},
	{"LEVOXYL", 7, 190316},
	{"WANDEL", 6, 190317},
	{"EDUCATIONK", 10, 190318},
	{"DISSECTS", 8, 190319},
	{"AMELIORATING", 12, 190320},
	{"BIOMIMETIC", 10, 190321},
	{"UMMA", 4, 190322},
	{"TATTLER", 7, 190323},
	{"RITUALLY", 8, 190324},
	{"BRUNELLESCHI", 12, 190325},
	{"GAMEE", 5, 190326},
	{"FLXSCALE", 8, 190327},
	{"MMIS", 4, 190328},
	{"GREENSIDE", 9, 190329},
	{"FAYED", 5, 190330},
	{"AIDMATES", 8, 190331},
	{"SUBMODE", 7, 190332},
	{"AIRCO", 5, 190333},
	{"XVAN", 4, 190334},
	{"XABA", 4, 190335},
	{"WSIR", 4, 190336},
	{"WDCA", 4, 190337},
	{"UHID", 4, 190338},
	{"RUDU", 4, 190339},
	{"ROXS", 4, 190340},
	{"RCPA", 4, 190341},
	{"RBBA", 4, 190342},
	{"PRZE", 4, 190343},
	{"PPYU", 4, 190344},
	{"PETY", 4, 190345},
	{"MREJ", 4, 190346},
	{"MPVI", 4, 190347},
	{"LYUL", 4, 190348},
	{"LTZF", 4, 190349},
	{"LKDU", 4, 190350},
	{"LBBC", 4, 190351},
	{"JEWW", 4, 190352},
	{"JARU", 4, 190353},
	{"IZFO", 4, 190354},
	{"ISLL", 4, 190355},
	{"ILTJ", 4, 190356},
	{"GECY", 4, 190357},
	{"FSUE", 4, 190358},
	{"FKEA", 4, 190359},
	{"ENKV", 4, 190360},
	{"DOGK", 4, 190361},
	{"BNAR", 4, 190362},
	{"BMOU", 4, 190363},
	{"SULFITES", 8, 190364},
	{"PHOTLINK", 8, 190365},
	{"PHOTIRMS", 8, 190366},
	{"PHOTINST", 8, 190367},
	{"MAGZEROP", 8, 190368},
	{"FGROUPNO", 8, 190369},
	{"ASTINST", 7, 190370},
	{"PROPHETESS", 10, 190371},
	{"MENINGES", 8, 190372},
	{"SCHNELLES", 9, 190373},
	{"HATCHETS", 8, 190374},
	{"BOFA", 4, 190375},
	{"PAVOL", 5, 190376},
	{"PICTIRES", 8, 190377},
	{"NCJRS", 5, 190378},
	{"IDREF", 5, 190379},
	{"DESKTOPBSD", 10, 190380},
	{"GHRELIN", 7, 190381},
	{"EUROTALK", 8, 190382},
	{"CARBONIZED", 10, 190383},
	{"MATTIA", 6, 190384},
	{"DEMIR", 5, 190385},
	{"TMAC", 4, 190386},
	{"ENVIROMAPPER", 12, 190387},
	{"CRAFTSBURY", 10, 190388},
	{"AMERICANOS", 10, 190389},
	{"MAKIKO", 6, 190390},
	{"HAKKINEN", 8, 190391},
	{"FACKED", 6, 190392},
	{"WUERTTEMBERG", 12, 190393},
	{"FICKTREFF", 9, 190394},
	{"DOQNLOAD", 8, 190395},
	{"JAVACC", 6, 190396},
	{"FEIERN", 6, 190397},
	{"WACHTEL", 7, 190398},
	{"KATANGA", 7, 190399},
	{"KALLA", 5, 190400},
	{"PBMS", 4, 190401},
	{"MIDDLES", 7, 190402},
	{"WITZ", 4, 190403},
	{"DISTENSION", 10, 190404},
	{"LIBGSF", 6, 190405},
	{"SPOONFULS", 9, 190406},
	{"CARREIRA", 8, 190407},
	{"UNTEN", 5, 190408},
	{"ODWNLOAD", 8, 190409},
	{"ELEMEN", 6, 190410},
	{"APODACA", 7, 190411},
	{"DYME", 4, 190412},
	{"VANDREAD", 8, 190413},
	{"NLRA", 4, 190414},
	{"EBENE", 5, 190415},
	{"BUSSMANN", 8, 190416},
	{"ACQUISTA", 8, 190417},
	{"RIFLING", 7, 190418},
	{"LALL", 4, 190419},
	{"FUNEREAL", 8, 190420},
	{"STALLARD", 8, 190421},
	{"THUMBDRIVE", 10, 190422},
	{"EMMETSBURG", 10, 190423},
	{"BLABY", 5, 190424},
	{"REGULARY", 8, 190425},
	{"KATICH", 6, 190426},
	{"SEAPLANES", 9, 190427},
	{"LYM", 3, 190428},
	{"DNSMASQ", 7, 190429},
	{"CONSERVATORIUM", 14, 190430},
	{"NECESITO", 8, 190431},
	{"FLORIANOPOLIS", 13, 190432},
	{"TRIPLEXES", 9, 190433},
	{"PLATONISM", 9, 190434},
	{"RAMPLING", 8, 190435},
	{"PAWNSHOP", 8, 190436},
	{"ACOMDATA", 8, 190437},
	{"WRESTED", 7, 190438},
	{"SOUTHRIDGE", 10, 190439},
	{"RADARPLUS", 9, 190440},
	{"NAGAOKA", 7, 190441},
	{"ENDF", 4, 190442},
	{"GALLERIS", 8, 190443},
	{"BOSAL", 5, 190444},
	{"FQPA", 4, 190445},
	{"VOLKSBLAD", 9, 190446},
	{"DEPOIS", 6, 190447},
	{"WORLDWIND", 9, 190448},
	{"DECEIVES", 8, 190449},
	{"PLAINT", 6, 190450},
	{"FIGHE", 5, 190451},
	{"MEDHUNTERS", 10, 190452},
	{"ILEOSTOMY", 9, 190453},
	{"JOELY", 5, 190454},
	{"WASHU", 5, 190455},
	{"ULTRACOMPACT", 12, 190456},
	{"ECLIPSEZONE", 11, 190457},
	{"BAKAR", 5, 190458},
	{"MALAMUD", 7, 190459},
	{"LEGENDE", 7, 190460},
	{"AUDRAIN", 7, 190461},
	{"TIEBACKS", 8, 190462},
	{"CODEBREAKER", 11, 190463},
	{"SUBA", 4, 190464},
	{"ROUBINI", 7, 190465},
	{"GOFORTH", 7, 190466},
	{"EUROINVESTOR", 12, 190467},
	{"DUGUID", 6, 190468},
	{"PPLE", 4, 190469},
	{"MINIBLOGS", 9, 190470},
	{"TELEFONOS", 9, 190471},
	{"HOVLAND", 7, 190472},
	{"IMPERIO", 7, 190473},
	{"HUMORLESS", 9, 190474},
	{"HOTCAKES", 8, 190475},
	{"HENDEL", 6, 190476},
	{"ONDREJ", 6, 190477},
	{"PREDIC", 6, 190478},
	{"STEMPEL", 7, 190479},
	{"SLOTT", 5, 190480},
	{"ACPO", 4, 190481},
	{"ZACE", 4, 190482},
	{"WPUS", 4, 190483},
	{"WLCA", 4, 190484},
	{"WJOE", 4, 190485},
	{"WCOW", 4, 190486},
	{"USDW", 4, 190487},
	{"UIMB", 4, 190488},
	{"TRDS", 4, 190489},
	{"TMMO", 4, 190490},
	{"SUJA", 4, 190491},
	{"RROX", 4, 190492},
	{"RDNY", 4, 190493},
	{"PDUN", 4, 190494},
	{"NNCU", 4, 190495},
	{"NGFT", 4, 190496},
	{"NDDD", 4, 190497},
	{"MPPU", 4, 190498},
	{"MNSP", 4, 190499},
	{"MNBA", 4, 190500},
	{"JBAN", 4, 190501},
	{"IKPR", 4, 190502},
	{"HODY", 4, 190503},
	{"HGEM", 4, 190504},
	{"HAYG", 4, 190505},
	{"GOUC", 4, 190506},
	{"FONY", 4, 190507},
	{"FKUM", 4, 190508},
	{"FIFH", 4, 190509},
	{"FARJ", 4, 190510},
	{"EWCY", 4, 190511},
	{"ESBP", 4, 190512},
	{"EGUG", 4, 190513},
	{"EFPL", 4, 190514},
	{"DLTH", 4, 190515},
	{"DGOC", 4, 190516},
	{"DCME", 4, 190517},
	{"CABW", 4, 190518},
	{"BAIU", 4, 190519},
	{"CAUDLE", 6, 190520},
	{"CARECODE", 8, 190521},
	{"SABERMETRICS", 12, 190522},
	{"DEMESNE", 7, 190523},
	{"HAUGESUND", 9, 190524},
	{"HELGENBERGER", 12, 190525},
	{"WINGTIP", 7, 190526},
	{"DOWNKOAD", 8, 190527},
	{"QRY", 3, 190528},
	{"TRUGREEN", 8, 190529},
	{"MYTAXFREE", 9, 190530},
	{"FAAP", 4, 190531},
	{"BRINY", 5, 190532},
	{"PROGAMMING", 10, 190533},
	{"POLLAN", 6, 190534},
	{"SARISKA", 7, 190535},
	{"DRISKILL", 8, 190536},
	{"NIMBLY", 6, 190537},
	{"EBRUARY", 7, 190538},
	{"NEHALEM", 7, 190539},
	{"ABHAY", 5, 190540},
	{"WINDIES", 7, 190541},
	{"ACCTON", 6, 190542},
	{"PRAWA", 5, 190543},
	{"PTRBOX", 6, 190544},
	{"GREENBURG", 9, 190545},
	{"ROTHROCK", 8, 190546},
	{"NAVIGATEUR", 10, 190547},
	{"MANGIONE", 8, 190548},
	{"CSAR", 4, 190549},
	{"BABINGTON", 9, 190550},
	{"SEQHOUND", 8, 190551},
	{"KERSHNER", 8, 190552},
	{"UNIF", 4, 190553},
	{"NUPHA", 5, 190554},
	{"DEFAMING", 8, 190555},
	{"FRIZZLED", 8, 190556},
	{"EDEALS", 6, 190557},
	{"JUNGES", 6, 190558},
	{"HYPOXANTHINE", 12, 190559},
	{"CYBERSQUATTING", 14, 190560},
	{"GPAC", 4, 190561},
	{"HAACK", 5, 190562},
	{"PROMESSI", 8, 190563},
	{"MONTANARI", 9, 190564},
	{"SUPPED", 6, 190565},
	{"PLAYGRO", 7, 190566},
	{"JUSTONEMINUTE", 13, 190567},
	{"CALUMNY", 7, 190568},
	{"POLARIMETER", 11, 190569},
	{"LAVS", 4, 190570},
	{"CORFIELD", 8, 190571},
	{"SIGISMUND", 9, 190572},
	{"LISTMOTOR", 9, 190573},
	{"IRONSIDES", 9, 190574},
	{"MANAGEENGINE", 12, 190575},
	{"HERRN", 5, 190576},
	{"GOSSYPIUM", 9, 190577},
	{"ANTWONE", 7, 190578},
	{"VERGER", 6, 190579},
	{"PARAGLIDER", 10, 190580},
	{"FUNSTON", 7, 190581},
	{"LUCKETT", 7, 190582},
	{"ABAKUS", 6, 190583},
	{"AACR", 4, 190584},
	{"DATANG", 6, 190585},
	{"BROADLANDS", 10, 190586},
	{"PUBLICFAQ", 9, 190587},
	{"PSDA", 4, 190588},
	{"PROGID", 6, 190589},
	{"PERIPLUS", 8, 190590},
	{"DELVARE", 7, 190591},
	{"BINYAMIN", 8, 190592},
	{"AROCLOR", 7, 190593},
	{"ANALYS", 6, 190594},
	{"WYTHENSHAWE", 11, 190595},
	{"UNIDADES", 8, 190596},
	{"ENTERPRISEDB", 12, 190597},
	{"NDMP", 4, 190598},
	{"HOTPICS", 7, 190599},
	{"GETDESCRIPTION", 14, 190600},
	{"MALFUNCTIONED", 13, 190601},
	{"DUBBEL", 6, 190602},
	{"MBUS", 4, 190603},
	{"ANGLICKY", 8, 190604},
	{"SIMONIS", 7, 190605},
	{"SPECICATION", 11, 190606},
	{"DULUX", 5, 190607},
	{"FORDFORUMS", 10, 190608},
	{"LUDICROUSLY", 11, 190609},
	{"WALSENBURG", 10, 190610},
	{"HUXTABLE", 8, 190611},
	{"ROSIERE", 7, 190612},
	{"GENSET", 6, 190613},
	{"BENBOW", 6, 190614},
	{"TRACKWAY", 8, 190615},
	{"LINDSLEY", 8, 190616},
	{"YAYOO", 5, 190617},
	{"PYNCIAU", 7, 190618},
	{"POSTCONVICTION", 14, 190619},
	{"BIODATA", 7, 190620},
	{"LOCHGILPHEAD", 12, 190621},
	{"DEVIS", 5, 190622},
	{"FILIBUSTERING", 13, 190623},
	{"JEROLD", 6, 190624},
	{"BUKAN", 5, 190625},
	{"WARCHILD", 8, 190626},
	{"ZTAL", 4, 190627},
	{"ZLEC", 4, 190628},
	{"XVIR", 4, 190629},
	{"VYPL", 4, 190630},
	{"UYPA", 4, 190631},
	{"UAMM", 4, 190632},
	{"TCHQ", 4, 190633},
	{"SFGA", 4, 190634},
	{"RUEK", 4, 190635},
	{"RUBH", 4, 190636},
	{"RKKU", 4, 190637},
	{"RFSU", 4, 190638},
	{"RFEV", 4, 190639},
	{"REUA", 4, 190640},
	{"PWEC", 4, 190641},
	{"PPSU", 4, 190642},
	{"MROP", 4, 190643},
	{"MPUE", 4, 190644},
	{"LPOM", 4, 190645},
	{"KKIK", 4, 190646},
	{"INWC", 4, 190647},
	{"IGIG", 4, 190648},
	{"GFON", 4, 190649},
	{"FLSO", 4, 190650},
	{"DKOE", 4, 190651},
	{"DHBO", 4, 190652},
	{"BEYD", 4, 190653},
	{"BBOF", 4, 190654},
	{"AMMW", 4, 190655},
	{"AAFL", 4, 190656},
	{"ENFER", 5, 190657},
	{"YYTEXT", 6, 190658},
	{"SUDINI", 6, 190659},
	{"TAGZANIA", 8, 190660},
	{"MOLECULARGASTRONOMY", 19, 190661},
	{"RUGGERO", 7, 190662},
	{"GAULOISES", 9, 190663},
	{"CLAI", 4, 190664},
	{"PORTEND", 7, 190665},
	{"NEWSAGENCY", 10, 190666},
	{"APRIORI", 7, 190667},
	{"FUZZI", 5, 190668},
	{"CALERO", 6, 190669},
	{"AUTOGENOUS", 10, 190670},
	{"PAVLINA", 7, 190671},
	{"GENEONTOLOGY", 12, 190672},
	{"TYPECODE", 8, 190673},
	{"TRANSFERWARE", 12, 190674},
	{"TELEPRESENCE", 12, 190675},
	{"ROLEMASTER", 10, 190676},
	{"HANDES", 6, 190677},
	{"SWIFFER", 7, 190678},
	{"LEWELLEN", 8, 190679},
	{"REVES", 5, 190680},
	{"MOLINARO", 8, 190681},
	{"MERCS", 5, 190682},
	{"KILDEE", 6, 190683},
	{"BANGUI", 6, 190684},
	{"TENTING", 7, 190685},
	{"MULLARD", 7, 190686},
	{"STOFFEL", 7, 190687},
	{"AYRIO", 5, 190688},
	{"KURIHARA", 8, 190689},
	{"CYBERAGENT", 10, 190690},
	{"COOKOFF", 7, 190691},
	{"JAYANTI", 7, 190692},
	{"BALAMORY", 8, 190693},
	{"AMADEO", 6, 190694},
	{"PATASKALA", 9, 190695},
	{"FOLGERS", 7, 190696},
	{"SPATTERED", 9, 190697},
	{"DUMITRU", 7, 190698},
	{"COULOIR", 7, 190699},
	{"PACBELL", 7, 190700},
	{"HOLOENZYME", 10, 190701},
	{"ERSHIP", 6, 190702},
	{"AMALEK", 6, 190703},
	{"BUTNER", 6, 190704},
	{"TPBS", 4, 190705},
	{"PVIEWSEL", 8, 190706},
	{"IPEXPERT", 8, 190707},
	{"LUNAIRE", 7, 190708},
	{"DEEPWOODS", 9, 190709},
	{"SMILLIE", 7, 190710},
	{"BLOODSTAINED", 12, 190711},
	{"MULTISEARCH", 11, 190712},
	{"MUSWELLBROOK", 12, 190713},
	{"MONCURE", 7, 190714},
	{"ACCSTATION", 10, 190715},
	{"TORANA", 6, 190716},
	{"STRAGGLING", 10, 190717},
	{"SOLDIERCITY", 11, 190718},
	{"KERKORIAN", 9, 190719},
	{"HAMBONES", 8, 190720},
	{"SHROFF", 6, 190721},
	{"PONTIFICIA", 10, 190722},
	{"HENNINGSEN", 10, 190723},
	{"YAPPING", 7, 190724},
	{"PFCS", 4, 190725},
	{"COCHON", 6, 190726},
	{"CHRISTIA", 8, 190727},
	{"PGG", 3, 190728},
	{"COZYING", 7, 190729},
	{"BERTHE", 6, 190730},
	{"GOLDREICH", 9, 190731},
	{"RITTMAN", 7, 190732},
	{"CESK", 4, 190733},
	{"RIESIGEMUSCHI", 13, 190734},
	{"KRITA", 5, 190735},
	{"UNIVAC", 6, 190736},
	{"UNFIXED", 7, 190737},
	{"PBJ", 3, 190738},
	{"BBOY", 4, 190739},
	{"PEMS", 4, 190740},
	{"VAUDE", 5, 190741},
	{"AYREON", 6, 190742},
	{"MINISTORE", 9, 190743},
	{"HARRIETTE", 9, 190744},
	{"BADGLEY", 7, 190745},
	{"DEATHWISH", 9, 190746},
	{"MAILHOST", 8, 190747},
	{"CWMNI", 5, 190748},
	{"ACERO", 5, 190749},
	{"MATAS", 5, 190750},
	{"PENDULA", 7, 190751},
	{"EIJK", 4, 190752},
	{"DUCKIES", 7, 190753},
	{"OVERLAIN", 8, 190754},
	{"MULGA", 5, 190755},
	{"SVSU", 4, 190756},
	{"TULBAGH", 7, 190757},
	{"DEWIS", 5, 190758},
	{"TMOVINGIMAGE", 12, 190759},
	{"NATWAR", 6, 190760},
	{"EUROMED", 7, 190761},
	{"ANALYSEN", 8, 190762},
	{"WORDCOUNT", 9, 190763},
	{"RADICE", 6, 190764},
	{"FRAMLINGHAM", 11, 190765},
	{"KURGAN", 6, 190766},
	{"BLINKX", 6, 190767},
	{"ACADIANS", 8, 190768},
	{"ZAJA", 4, 190769},
	{"WWLA", 4, 190770},
	{"WIGL", 4, 190771},
	{"VSUS", 4, 190772},
	{"VOYC", 4, 190773},
	{"VJER", 4, 190774},
	{"UACL", 4, 190775},
	{"TSRB", 4, 190776},
	{"TMLC", 4, 190777},
	{"SKSK", 4, 190778},
	{"SFUG", 4, 190779},
	{"RNSQ", 4, 190780},
	{"RDRC", 4, 190781},
	{"RABJ", 4, 190782},
	{"PHVA", 4, 190783},
	{"OXKI", 4, 190784},
	{"OLMP", 4, 190785},
	{"OJUI", 4, 190786},
	{"NWOW", 4, 190787},
	{"NMRK", 4, 190788},
	{"NGDS", 4, 190789},
	{"MGOU", 4, 190790},
	{"MBIF", 4, 190791},
	{"KUGE", 4, 190792},
	{"JUGH", 4, 190793},
	{"IMBD", 4, 190794},
	{"IFVA", 4, 190795},
	{"GUYU", 4, 190796},
	{"GDIT", 4, 190797},
	{"FJIA", 4, 190798},
	{"EVAV", 4, 190799},
	{"ESLB", 4, 190800},
	{"EHRW", 4, 190801},
	{"DZUR", 4, 190802},
	{"DKOK", 4, 190803},
	{"DDJA", 4, 190804},
	{"CEVS", 4, 190805},
	{"BTSB", 4, 190806},
	{"BTOK", 4, 190807},
	{"BSKY", 4, 190808},
	{"AKUO", 4, 190809},
	{"ACGO", 4, 190810},
	{"ABJU", 4, 190811},
	{"AALV", 4, 190812},
	{"TENJHO", 6, 190813},
	{"BISHOPVILLE", 11, 190814},
	{"IMMUNISATIONS", 13, 190815},
	{"FRENZ", 5, 190816},
	{"FANSUBS", 7, 190817},
	{"BENTGRASS", 9, 190818},
	{"SUPPLIMENTS", 11, 190819},
	{"AGENCJA", 7, 190820},
	{"VROMAN", 6, 190821},
	{"MADOKA", 6, 190822},
	{"MINIPORT", 8, 190823},
	{"KISUMU", 6, 190824},
	{"AGNITUM", 7, 190825},
	{"NAMAQUALAND", 11, 190826},
	{"AUTOMATI", 8, 190827},
	{"HYTRIN", 6, 190828},
	{"WINCOR", 6, 190829},
	{"STARFOX", 7, 190830},
	{"STRASS", 6, 190831},
	{"PROVIDEO", 8, 190832},
	{"GRUMET", 6, 190833},
	{"DELAHAYE", 8, 190834},
	{"COMPSCI", 7, 190835},
	{"DRESSUP", 7, 190836},
	{"DISASSOCIATE", 12, 190837},
	{"UCTV", 4, 190838},
	{"FIJIANS", 7, 190839},
	{"COMTESSE", 8, 190840},
	{"KYAN", 4, 190841},
	{"DESATURASE", 10, 190842},
	{"PREMERGUIDE", 11, 190843},
	{"HILLA", 5, 190844},
	{"STERILISED", 10, 190845},
	{"HERMLE", 6, 190846},
	{"INTRAMEDULLARY", 14, 190847},
	{"DOWHLOAD", 8, 190848},
	{"SCHLITZ", 7, 190849},
	{"RALLIART", 8, 190850},
	{"GIRLSHUNTINGGIRLS", 17, 190851},
	{"MICONAZOLE", 10, 190852},
	{"ANABOL", 6, 190853},
	{"HOTORNOT", 8, 190854},
	{"HARTL", 5, 190855},
	{"DIFFERENTIATORS", 15, 190856},
	{"ICASE", 5, 190857},
	{"MIDA", 4, 190858},
	{"GETAFE", 6, 190859},
	{"NIGHTLIGHTS", 11, 190860},
	{"DERMATOMYOSITIS", 15, 190861},
	{"SCRIBAL", 7, 190862},
	{"ROXBOROUGH", 10, 190863},
	{"HYDROMETER", 10, 190864},
	{"DIREITO", 7, 190865},
	{"SUBLINE", 7, 190866},
	{"JOHNIE", 6, 190867},
	{"STRIPEY", 7, 190868},
	{"CADDICK", 7, 190869},
	{"NELMS", 5, 190870},
	{"WAMPANOAG", 9, 190871},
	{"POLLINI", 7, 190872},
	{"NAPL", 4, 190873},
	{"CATCHUP", 7, 190874},
	{"ACBL", 4, 190875},
	{"WPIX", 4, 190876},
	{"TEXIS", 5, 190877},
	{"WASHI", 5, 190878},
	{"ANGELINI", 8, 190879},
	{"CRAFTWORK", 9, 190880},
	{"SLINGSHOTS", 10, 190881},
	{"PICOS", 5, 190882},
	{"NTWK", 4, 190883},
	{"CHICANERY", 9, 190884},
	{"DLINUX", 6, 190885},
	{"MAKAH", 5, 190886},
	{"INFOINFO", 8, 190887},
	{"ELSTRUCTSCHEMA", 14, 190888},
	{"ANTWAN", 6, 190889},
	{"JAILERS", 7, 190890},
	{"VOLLBUSIG", 9, 190891},
	{"GRUNEWALD", 9, 190892},
	{"JOBLINK", 7, 190893},
	{"CHAUD", 5, 190894},
	{"SUBVENTIONS", 11, 190895},
	{"SELLERSBURG", 11, 190896},
	{"ROOSTS", 6, 190897},
	{"COUNTERSPIN", 11, 190898},
	{"SAMMON", 6, 190899},
	{"AFTRA", 5, 190900},
	{"CARDUELIS", 9, 190901},
	{"LEGI", 4, 190902},
	{"JEUNET", 6, 190903},
	{"SANDCASTLES", 11, 190904},
	{"DISASTROUSLY", 12, 190905},
	{"SANKARAN", 8, 190906},
	{"REKA", 4, 190907},
	{"AIRFORM", 7, 190908},
	{"STEMMONS", 8, 190909},
	{"PSYTRANCE", 9, 190910},
	{"COWNLOAD", 8, 190911},
	{"ZITTING", 7, 190912},
	{"TERRITORIO", 10, 190913},
	{"HPOJ", 4, 190914},
	{"CATTELL", 7, 190915},
	{"POLITICHE", 9, 190916},
	{"ZQUI", 4, 190917},
	{"YROX", 4, 190918},
	{"YPOA", 4, 190919},
	{"XDRA", 4, 190920},
	{"WTWE", 4, 190921},
	{"VTOP", 4, 190922},
	{"UOVO", 4, 190923},
	{"UDJO", 4, 190924},
	{"TYPP", 4, 190925},
	{"TVOF", 4, 190926},
	{"TRMA", 4, 190927},
	{"TKMO", 4, 190928},
	{"SOPW", 4, 190929},
	{"SKDU", 4, 190930},
	{"RAGQ", 4, 190931},
	{"OIDY", 4, 190932},
	{"NPYO", 4, 190933},
	{"NMRD", 4, 190934},
	{"LOLT", 4, 190935},
	{"LOEC", 4, 190936},
	{"LGOG", 4, 190937},
	{"LERZ", 4, 190938},
	{"IRSJ", 4, 190939},
	{"HUTR", 4, 190940},
	{"HLYJ", 4, 190941},
	{"FYLO", 4, 190942},
	{"FMWH", 4, 190943},
	{"FAYY", 4, 190944},
	{"EJEM", 4, 190945},
	{"EDEZ", 4, 190946},
	{"DRSL", 4, 190947},
	{"DBAE", 4, 190948},
	{"ALNY", 4, 190949},
	{"ARCHWEEK", 8, 190950},
	{"GENELOC", 7, 190951},
	{"GANGLIOSIDE", 11, 190952},
	{"NEWMEDIA", 8, 190953},
	{"GASQUET", 7, 190954},
	{"ESCB", 4, 190955},
	{"EDELSON", 7, 190956},
	{"TURNSTONE", 9, 190957},
	{"LAZARTIGUE", 10, 190958},
	{"BUNKERING", 9, 190959},
	{"BAZIN", 5, 190960},
	{"ZABA", 4, 190961},
	{"BMRB", 4, 190962},
	{"ARANGO", 6, 190963},
	{"RPV", 3, 190964},
	{"PLUSTEK", 7, 190965},
	{"MILLAIS", 7, 190966},
	{"DSTV", 4, 190967},
	{"ENTEROCOLITICA", 14, 190968},
	{"WENSLEYDALE", 11, 190969},
	{"TYPEMAP", 7, 190970},
	{"HEMATOXYLIN", 11, 190971},
	{"CALLOUTS", 8, 190972},
	{"MYGEDVIEW", 9, 190973},
	{"INTIMATIONS", 11, 190974},
	{"PRONSTAR", 8, 190975},
	{"ARZT", 4, 190976},
	{"HAGEMAN", 7, 190977},
	{"DLIDOS", 6, 190978},
	{"ASMODEE", 7, 190979},
	{"WANTIRNA", 8, 190980},
	{"QUONSET", 7, 190981},
	{"HOMEBIZ", 7, 190982},
	{"ESECURITY", 9, 190983},
	{"XLIX", 4, 190984},
	{"SOFTCOPY", 8, 190985},
	{"KALEU", 5, 190986},
	{"FORMAMIDE", 9, 190987},
	{"EXPLICATE", 9, 190988},
	{"ACQUISITIVE", 11, 190989},
	{"BOFFIN", 6, 190990},
	{"MABLETHORPE", 11, 190991},
	{"TICKNOR", 7, 190992},
	{"URGH", 4, 190993},
	{"SDNP", 4, 190994},
	{"PICATINNY", 9, 190995},
	{"SCHNELLE", 8, 190996},
	{"DAGO", 4, 190997},
	{"PRESSGANG", 9, 190998},
	{"JEWELRYTV", 9, 190999},
	{"EHOWS", 5, 191000},
	{"FACINATING", 10, 191001},
	{"LABURNUM", 8, 191002},
	{"ACLAND", 6, 191003},
	{"RICHIESTE", 9, 191004},
	{"FREEDUC", 7, 191005},
	{"HETERODOX", 9, 191006},
	{"BRONCS", 6, 191007},
	{"BUNRATTY", 8, 191008},
	{"PLESSY", 6, 191009},
	{"MORFORD", 7, 191010},
	{"FERMENTER", 9, 191011},
	{"PATC", 4, 191012},
	{"KEYBANK", 7, 191013},
	{"PHONOGRAPHIC", 12, 191014},
	{"MANQUE", 6, 191015},
	{"MACUNGIE", 8, 191016},
	{"TROJANHUNTER", 12, 191017},
	{"TRACKLISTINGS", 13, 191018},
	{"JENEANE", 7, 191019},
	{"KLAWOCK", 7, 191020},
	{"TENANCE", 7, 191021},
	{"CADOURI", 7, 191022},
	{"GENOCIDES", 9, 191023},
	{"PIPEDA", 6, 191024},
	{"MAFFEI", 6, 191025},
	{"ANGLOS", 6, 191026},
	{"PAPERMATE", 9, 191027},
	{"COMUNICACION", 12, 191028},
	{"RPLAY", 5, 191029},
	{"MEAUX", 5, 191030},
	{"CORBYN", 6, 191031},
	{"BARBECUING", 10, 191032},
	{"ACCOMMODATIVE", 13, 191033},
	{"STAIRLIFTS", 10, 191034},
	{"MOOSEJAWOUTPOST", 15, 191035},
	{"BRIDGEWAY", 9, 191036},
	{"LAWMEME", 7, 191037},
	{"STALACTITES", 11, 191038},
	{"FLASHFXP", 8, 191039},
	{"DYSTROPHIES", 11, 191040},
	{"WESTERMANN", 10, 191041},
	{"MIMOSAS", 7, 191042},
	{"HENGER", 6, 191043},
	{"PUSHROD", 7, 191044},
	{"PORTATILI", 9, 191045},
	{"MARGARETA", 9, 191046},
	{"EVENED", 6, 191047},
	{"NIZAM", 5, 191048},
	{"DATAMINING", 10, 191049},
	{"CEVICHE", 7, 191050},
	{"KUNM", 4, 191051},
	{"CHITINASE", 9, 191052},
	{"DAIKON", 6, 191053},
	{"CAMEROONIAN", 11, 191054},
	{"CODFISH", 7, 191055},
	{"ALEXIE", 6, 191056},
	{"SCRUTON", 7, 191057},
	{"LUMUMBA", 7, 191058},
	{"TESTBEDS", 8, 191059},
	{"ROUTINGS", 8, 191060},
	{"DUBBLE", 6, 191061},
	{"YWEU", 4, 191062},
	{"WREY", 4, 191063},
	{"VDAL", 4, 191064},
	{"USPT", 4, 191065},
	{"RPMP", 4, 191066},
	{"RAQN", 4, 191067},
	{"PTSG", 4, 191068},
	{"POWY", 4, 191069},
	{"PMYP", 4, 191070},
	{"PEIP", 4, 191071},
	{"OXYW", 4, 191072},
	{"ORIJ", 4, 191073},
	{"OGCR", 4, 191074},
	{"NVOU", 4, 191075},
	{"NLWI", 4, 191076},
	{"MBPE", 4, 191077},
	{"LPIZ", 4, 191078},
	{"LOUK", 4, 191079},
	{"LEUG", 4, 191080},
	{"LBWI", 4, 191081},
	{"KYDU", 4, 191082},
	{"KOKP", 4, 191083},
	{"JIMZ", 4, 191084},
	{"FXEN", 4, 191085},
	{"FKRE", 4, 191086},
	{"EUDT", 4, 191087},
	{"EJOW", 4, 191088},
	{"DVAP", 4, 191089},
	{"DRNI", 4, 191090},
	{"DPEI", 4, 191091},
	{"CAOB", 4, 191092},
	{"BBSL", 4, 191093},
	{"AFFK", 4, 191094},
	{"AFAG", 4, 191095},
	{"PEPI", 4, 191096},
	{"MATAMATA", 8, 191097},
	{"HERGER", 6, 191098},
	{"LIFSHITZ", 8, 191099},
	{"HORSEFEATHERS", 13, 191100},
	{"XOXOXO", 6, 191101},
	{"DELK", 4, 191102},
	{"FRIBERG", 7, 191103},
	{"PURRFECT", 8, 191104},
	{"UKM", 3, 191105},
	{"FLEXNET", 7, 191106},
	{"DOUBLESPEAK", 11, 191107},
	{"CAGEY", 5, 191108},
	{"SHARIFF", 7, 191109},
	{"RCSL", 4, 191110},
	{"ELBURN", 6, 191111},
	{"CALCULATER", 10, 191112},
	{"MINDEDLY", 8, 191113},
	{"BOYSSTUFF", 9, 191114},
	{"MIDNYTE", 7, 191115},
	{"ROSEWILL", 8, 191116},
	{"SALTBURN", 8, 191117},
	{"SENTING", 7, 191118},
	{"DOWNLOZD", 8, 191119},
	{"DEBILITY", 8, 191120},
	{"BOHDAN", 6, 191121},
	{"IMPROPRIETIES", 13, 191122},
	{"MALANG", 6, 191123},
	{"MAGNIFICO", 9, 191124},
	{"SHIRKING", 8, 191125},
	{"SHAPEFILES", 10, 191126},
	{"RUSTLERS", 8, 191127},
	{"KOOKA", 5, 191128},
	{"DEMAS", 5, 191129},
	{"VMIKLOS", 7, 191130},
	{"TOWNEND", 7, 191131},
	{"MOGENS", 6, 191132},
	{"AUTEUIL", 7, 191133},
	{"MECER", 5, 191134},
	{"ZAKEN", 5, 191135},
	{"NEWALL", 6, 191136},
	{"PROPRIOCEPTIVE", 14, 191137},
	{"ETTERS", 6, 191138},
	{"SPORTFISH", 9, 191139},
	{"DURIN", 5, 191140},
	{"IMIPENEM", 8, 191141},
	{"SUPERLIGHT", 10, 191142},
	{"PARNALL", 7, 191143},
	{"DAITO", 5, 191144},
	{"INDOCHINE", 9, 191145},
	{"LAURITZEN", 9, 191146},
	{"UPSELL", 6, 191147},
	{"POLICOSANOL", 11, 191148},
	{"LISTP", 5, 191149},
	{"DOSNLOAD", 8, 191150},
	{"DAVIDIAN", 8, 191151},
	{"ALOES", 5, 191152},
	{"ZEUTHEN", 7, 191153},
	{"GYMRU", 5, 191154},
	{"FRIGHTENERS", 11, 191155},
	{"OVERREACT", 9, 191156},
	{"CRAPPED", 7, 191157},
	{"PIAVE", 5, 191158},
	{"GROWLER", 7, 191159},
	{"FORMBOX", 7, 191160},
	{"COMPARI", 7, 191161},
	{"SALTERTON", 9, 191162},
	{"CIRSIUM", 7, 191163},
	{"ERLAND", 6, 191164},
	{"BLAWGS", 6, 191165},
	{"FASSETT", 7, 191166},
	{"NSDICTIONARY", 12, 191167},
	{"NASEEM", 6, 191168},
	{"GASTROSTOMY", 11, 191169},
	{"UKERNA", 6, 191170},
	{"MAGHRIB", 7, 191171},
	{"TROTMAN", 7, 191172},
	{"AMENHOTEP", 9, 191173},
	{"RIAU", 4, 191174},
	{"PREVX", 5, 191175},
	{"FRELINGHUYSEN", 13, 191176},
	{"DHAMMAPADA", 10, 191177},
	{"SOUTHERLAND", 11, 191178},
	{"ENGSC", 5, 191179},
	{"RTYPE", 5, 191180},
	{"OBLITERATING", 12, 191181},
	{"JUDEAN", 6, 191182},
	{"HURDY", 5, 191183},
	{"TROMP", 5, 191184},
	{"KAZUHIKO", 8, 191185},
	{"VICTUALS", 8, 191186},
	{"KATER", 5, 191187},
	{"CERTO", 5, 191188},
	{"ARCHAEON", 8, 191189},
	{"DULLY", 5, 191190},
	{"CANNISTER", 9, 191191},
	{"KNHC", 4, 191192},
	{"BRACHA", 6, 191193},
	{"JASWANT", 7, 191194},
	{"INTEGR", 6, 191195},
	{"DOLING", 6, 191196},
	{"DEALRAM", 7, 191197},
	{"RDIST", 5, 191198},
	{"HOLCIM", 6, 191199},
	{"AFZAL", 5, 191200},
	{"VIDEONOW", 8, 191201},
	{"LEONORE", 7, 191202},
	{"GRAVEUR", 7, 191203},
	{"EASYDECK", 8, 191204},
	{"VIVIER", 6, 191205},
	{"DMAX", 4, 191206},
	{"DEFINITIVES", 11, 191207},
	{"DOWNPOAD", 8, 191208},
	{"CARADON", 7, 191209},
	{"BIOCHIMIE", 9, 191210},
	{"SHOGO", 5, 191211},
	{"LOUS", 4, 191212},
	{"BAHRAM", 6, 191213},
	{"MAMMALOGY", 9, 191214},
	{"KISLEV", 6, 191215},
	{"CHIAMATA", 8, 191216},
	{"WEBTENDER", 9, 191217},
	{"WODA", 4, 191218},
	{"ZSTU", 4, 191219},
	{"ZMAK", 4, 191220},
	{"ZLOW", 4, 191221},
	{"UONM", 4, 191222},
	{"UDPE", 4, 191223},
	{"TZOM", 4, 191224},
	{"THDV", 4, 191225},
	{"RVAZ", 4, 191226},
	{"RPCU", 4, 191227},
	{"PUGL", 4, 191228},
	{"PPPO", 4, 191229},
	{"PDEG", 4, 191230},
	{"OEVW", 4, 191231},
	{"NIXG", 4, 191232},
	{"MTBA", 4, 191233},
	{"LBOE", 4, 191234},
	{"KJOK", 4, 191235},
	{"IRND", 4, 191236},
	{"HUPL", 4, 191237},
	{"HKRO", 4, 191238},
	{"HIRB", 4, 191239},
	{"GEIP", 4, 191240},
	{"GBAO", 4, 191241},
	{"GAAB", 4, 191242},
	{"FLFI", 4, 191243},
	{"FDUD", 4, 191244},
	{"EIGB", 4, 191245},
	{"DSOJ", 4, 191246},
	{"DFCA", 4, 191247},
	{"DDYJ", 4, 191248},
	{"DAKB", 4, 191249},
	{"AXCL", 4, 191250},
	{"AVSD", 4, 191251},
	{"STRG", 4, 191252},
	{"EXALTING", 8, 191253},
	{"ACHEWOOD", 8, 191254},
	{"NETSKY", 6, 191255},
	{"LAMPKIN", 7, 191256},
	{"WOLFMOTHER", 10, 191257},
	{"TWITS", 5, 191258},
	{"TEXTEDIT", 8, 191259},
	{"GEDPAGE", 7, 191260},
	{"FLOGGER", 7, 191261},
	{"RITCH", 5, 191262},
	{"SPECTRASONICS", 13, 191263},
	{"GRANTOWN", 8, 191264},
	{"BIGLER", 6, 191265},
	{"AMCA", 4, 191266},
	{"MAPLELEAF", 9, 191267},
	{"LCY", 3, 191268},
	{"EVERCOOL", 8, 191269},
	{"WEEPY", 5, 191270},
	{"JLM", 3, 191271},
	{"SWCH", 4, 191272},
	{"DIMITRIE", 8, 191273},
	{"TAILGATES", 9, 191274},
	{"TULLIO", 6, 191275},
	{"TRIALLING", 9, 191276},
	{"PERDANA", 7, 191277},
	{"TISSERAND", 9, 191278},
	{"TOURNAI", 7, 191279},
	{"VERBUM", 6, 191280},
	{"TETRAD", 6, 191281},
	{"THERMOHALINE", 12, 191282},
	{"MADR", 4, 191283},
	{"PHONELINE", 9, 191284},
	{"VISTED", 6, 191285},
	{"MPOS", 4, 191286},
	{"GOALCENTRIX", 11, 191287},
	{"COXETER", 7, 191288},
	{"SHORTHORN", 9, 191289},
	{"HELMED", 6, 191290},
	{"PREMO", 5, 191291},
	{"KERBS", 5, 191292},
	{"MARITZA", 7, 191293},
	{"CHIDE", 5, 191294},
	{"SAANICHTON", 10, 191295},
	{"CELLI", 5, 191296},
	{"TAKENAKA", 8, 191297},
	{"SUBPROBLEM", 10, 191298},
	{"ATOPY", 5, 191299},
	{"SENTHIL", 7, 191300},
	{"LOBDELL", 7, 191301},
	{"SKOKI", 5, 191302},
	{"ERMAN", 5, 191303},
	{"ASPHODEL", 8, 191304},
	{"TELLIER", 7, 191305},
	{"INHIBIN", 7, 191306},
	{"ENGHRAIFFT", 10, 191307},
	{"PRESTEIGNE", 10, 191308},
	{"LEONIA", 6, 191309},
	{"SHERRINGTON", 11, 191310},
	{"DLWNLOAD", 8, 191311},
	{"ECKERSLEY", 9, 191312},
	{"JOHNNIC", 7, 191313},
	{"MINUTIA", 7, 191314},
	{"LIKELIHOODS", 11, 191315},
	{"ENTRAP", 6, 191316},
	{"WOOLARD", 7, 191317},
	{"NACC", 4, 191318},
	{"ARBORISTS", 9, 191319},
	{"TRANSFUSED", 10, 191320},
	{"MAIKO", 5, 191321},
	{"CARDQ", 5, 191322},
	{"QUALSIASI", 9, 191323},
	{"SOTWARE", 7, 191324},
	{"AURATUS", 7, 191325},
	{"CRONUS", 6, 191326},
	{"CLUBTEST", 8, 191327},
	{"TRANSMISSIVE", 12, 191328},
	{"WARGO", 5, 191329},
	{"HEPTATHLON", 10, 191330},
	{"DMANET", 6, 191331},
	{"INDIGNITIES", 11, 191332},
	{"ARMO", 4, 191333},
	{"PAWAN", 5, 191334},
	{"NOMBREUX", 8, 191335},
	{"FROGGIE", 7, 191336},
	{"MASSET", 6, 191337},
	{"SPELLBORN", 9, 191338},
	{"FORSCHNER", 9, 191339},
	{"RHYMED", 6, 191340},
	{"LARES", 5, 191341},
	{"RICKARDS", 8, 191342},
	{"WHIRLS", 6, 191343},
	{"WRAITHS", 7, 191344},
	{"PALLE", 5, 191345},
	{"COMPASSIONATELY", 15, 191346},
	{"HUSSAR", 6, 191347},
	{"BARTHEL", 7, 191348},
	{"BEURETTE", 8, 191349},
	{"SCOW", 4, 191350},
	{"CHILDREARING", 12, 191351},
	{"ZELDERS", 7, 191352},
	{"EJERCICIO", 9, 191353},
	{"CHEAPSEATS", 10, 191354},
	{"GOODLING", 8, 191355},
	{"STONEVILLE", 10, 191356},
	{"PROTONATED", 10, 191357},
	{"MYALL", 5, 191358},
	{"MIMIX", 5, 191359},
	{"STOBART", 7, 191360},
	{"FESTPLATTE", 10, 191361},
	{"XAXI", 4, 191362},
	{"WREE", 4, 191363},
	{"VULE", 4, 191364},
	{"VSCE", 4, 191365},
	{"USBF", 4, 191366},
	{"RIPY", 4, 191367},
	{"RGSK", 4, 191368},
	{"REMH", 4, 191369},
	{"QBAN", 4, 191370},
	{"PMLE", 4, 191371},
	{"PANV", 4, 191372},
	{"OJOL", 4, 191373},
	{"OGOK", 4, 191374},
	{"OFOY", 4, 191375},
	{"NZOG", 4, 191376},
	{"NYUC", 4, 191377},
	{"NUXH", 4, 191378},
	{"NOMC", 4, 191379},
	{"NHWY", 4, 191380},
	{"MOYS", 4, 191381},
	{"LRIK", 4, 191382},
	{"LAKL", 4, 191383},
	{"ISPD", 4, 191384},
	{"HUCY", 4, 191385},
	{"HGAP", 4, 191386},
	{"GADY", 4, 191387},
	{"GABC", 4, 191388},
	{"EUEL", 4, 191389},
	{"EDTM", 4, 191390},
	{"ECJA", 4, 191391},
	{"CYEM", 4, 191392},
	{"CSUL", 4, 191393},
	{"CGUF", 4, 191394},
	{"BDAM", 4, 191395},
	{"AXDA", 4, 191396},
	{"AVAY", 4, 191397},
	{"ARNK", 4, 191398},
	{"SYSSTAT", 7, 191399},
	{"COROLLE", 7, 191400},
	{"DURGIN", 6, 191401},
	{"PEATLAND", 8, 191402},
	{"HEINKEL", 7, 191403},
	{"MAPABOUT", 8, 191404},
	{"RETURNERS", 9, 191405},
	{"JUXTAPOSE", 9, 191406},
	{"AVALOS", 6, 191407},
	{"DIALLER", 7, 191408},
	{"WILTRADE", 8, 191409},
	{"GRACIN", 6, 191410},
	{"ADVERTORIAL", 11, 191411},
	{"SITEINDEX", 9, 191412},
	{"LAMPA", 5, 191413},
	{"GOOGLS", 6, 191414},
	{"BAAQMD", 6, 191415},
	{"SQUIGGLES", 9, 191416},
	{"FUNCIONA", 8, 191417},
	{"ARSONISTS", 9, 191418},
	{"HDCAM", 5, 191419},
	{"DOWNLOQD", 8, 191420},
	{"BIOGRAPHIC", 10, 191421},
	{"DEPREDATION", 11, 191422},
	{"FREEREPUBLIC", 12, 191423},
	{"FOOLIN", 6, 191424},
	{"VETTA", 5, 191425},
	{"READSOFT", 8, 191426},
	{"OREIRO", 6, 191427},
	{"SFWA", 4, 191428},
	{"DOWJLOAD", 8, 191429},
	{"SUREMENT", 8, 191430},
	{"EDITI", 5, 191431},
	{"NYAL", 4, 191432},
	{"SUPERBOAT", 9, 191433},
	{"PHILMONT", 8, 191434},
	{"KOUR", 4, 191435},
	{"VOORBEELD", 9, 191436},
	{"SPCS", 4, 191437},
	{"CSNAME", 6, 191438},
	{"VINATIERI", 9, 191439},
	{"NOVILLO", 7, 191440},
	{"ITEMIZATION", 11, 191441},
	{"EINTR", 5, 191442},
	{"BLIG", 4, 191443},
	{"BJORKMAN", 8, 191444},
	{"TAXIDERMIST", 11, 191445},
	{"GOOGKE", 6, 191446},
	{"FRANTI", 6, 191447},
	{"INSIGNIAS", 9, 191448},
	{"BEIDE", 5, 191449},
	{"JAPANSE", 7, 191450},
	{"CAPLET", 6, 191451},
	{"BOOTLEGGERS", 11, 191452},
	{"XOWNLOAD", 8, 191453},
	{"MAGNY", 5, 191454},
	{"HYNEK", 5, 191455},
	{"WICIPEDIA", 9, 191456},
	{"KINGSMILL", 9, 191457},
	{"ICAHN", 5, 191458},
	{"EXCITMENT", 9, 191459},
	{"PRACY", 5, 191460},
	{"DOWNOOAD", 8, 191461},
	{"HARBORD", 7, 191462},
	{"SUMY", 4, 191463},
	{"OUTSTRIPPING", 12, 191464},
	{"EXTENDEDROMAN", 13, 191465},
	{"AMAZONITE", 9, 191466},
	{"WISKUNDE", 8, 191467},
	{"HONORA", 6, 191468},
	{"UPCLOSE", 7, 191469},
	{"KOOLATRON", 9, 191470},
	{"ERSTAD", 6, 191471},
	{"ONCLUSION", 9, 191472},
	{"DOMAINKEYS", 10, 191473},
	{"ENOYL", 5, 191474},
	{"PETAWAWA", 8, 191475},
	{"GLABRATA", 8, 191476},
	{"OVERBROAD", 9, 191477},
	{"CATIMINI", 8, 191478},
	{"RUANDA", 6, 191479},
	{"GUILDENSTERN", 12, 191480},
	{"PLANTANSWERS", 12, 191481},
	{"STANCHIONS", 10, 191482},
	{"MAYB", 4, 191483},
	{"DROPDOWNLIST", 12, 191484},
	{"WEEBL", 5, 191485},
	{"INFINIUM", 8, 191486},
	{"DOMMAGES", 8, 191487},
	{"ALFANI", 6, 191488},
	{"TAPLIN", 6, 191489},
	{"PYBLOSXOM", 9, 191490},
	{"PHASIC", 6, 191491},
	{"YABOO", 5, 191492},
	{"UPPERPARTS", 10, 191493},
	{"PALLIDUS", 8, 191494},
	{"ZTOG", 4, 191495},
	{"WDFA", 4, 191496},
	{"TZFE", 4, 191497},
	{"SNDB", 4, 191498},
	{"ROPZ", 4, 191499},
	{"ROOQ", 4, 191500},
	{"RIPJ", 4, 191501},
	{"RBMW", 4, 191502},
	{"MRJE", 4, 191503},
	{"MDSA", 4, 191504},
	{"MDIL", 4, 191505},
	{"MAEW", 4, 191506},
	{"IRTJ", 4, 191507},
	{"HEXY", 4, 191508},
	{"HECJ", 4, 191509},
	{"GOYN", 4, 191510},
	{"GNID", 4, 191511},
	{"FWIK", 4, 191512},
	{"FAOF", 4, 191513},
	{"FAIK", 4, 191514},
	{"EXYB", 4, 191515},
	{"EJUX", 4, 191516},
	{"EEUD", 4, 191517},
	{"DASZ", 4, 191518},
	{"CKAE", 4, 191519},
	{"CGIF", 4, 191520},
	{"CDOO", 4, 191521},
	{"GALLIGAN", 8, 191522},
	{"APPENDER", 8, 191523},
	{"AGAM", 4, 191524},
	{"CAPTAN", 6, 191525},
	{"ANTIPERSPIRANT", 14, 191526},
	{"MIGNONNE", 8, 191527},
	{"EOWNLOAD", 8, 191528},
	{"EYSENCK", 7, 191529},
	{"BOUDEWIJN", 9, 191530},
	{"SYMBOLPRINT", 11, 191531},
	{"DREAMGEAR", 9, 191532},
	{"TOLOWER", 7, 191533},
	{"REALESTATEJOURNAL", 17, 191534},
	{"OUTSTATE", 8, 191535},
	{"JOUETS", 6, 191536},
	{"ROOTY", 5, 191537},
	{"MATCHABELLI", 11, 191538},
	{"DEPLETES", 8, 191539},
	{"ORGASAMS", 8, 191540},
	{"SYSINSTALL", 10, 191541},
	{"GREENSTAR", 9, 191542},
	{"LEBENSLAUF", 10, 191543},
	{"GOOLEY", 6, 191544},
	{"GEORGIEV", 8, 191545},
	{"DAUNORUBICIN", 12, 191546},
	{"REMORSEFUL", 10, 191547},
	{"LANTAU", 6, 191548},
	{"GEISER", 6, 191549},
	{"EQUIPM", 6, 191550},
	{"VDU", 3, 191551},
	{"STRAIGHTENS", 11, 191552},
	{"KERMODE", 7, 191553},
	{"TAVERNAS", 8, 191554},
	{"ROBERGE", 7, 191555},
	{"IRADIO", 6, 191556},
	{"CARTAGO", 7, 191557},
	{"GILDE", 5, 191558},
	{"GALANTAMINE", 11, 191559},
	{"DEVANE", 6, 191560},
	{"REALER", 6, 191561},
	{"APTIVA", 6, 191562},
	{"NCLUG", 5, 191563},
	{"AVENAL", 6, 191564},
	{"CATSUITS", 8, 191565},
	{"UPPINGHAM", 9, 191566},
	{"SAYURI", 6, 191567},
	{"PEFC", 4, 191568},
	{"LIMINE", 6, 191569},
	{"FRAGRANCENET", 12, 191570},
	{"PCITURES", 8, 191571},
	{"GRDC", 4, 191572},
	{"GOLDMANN", 8, 191573},
	{"CAMPUSI", 7, 191574},
	{"KRISHAN", 7, 191575},
	{"FOURMS", 6, 191576},
	{"GLADEWATER", 10, 191577},
	{"CHANGELOGS", 10, 191578},
	{"MMMF", 4, 191579},
	{"NERANG", 6, 191580},
	{"WREAKS", 6, 191581},
	{"LINEFEED", 8, 191582},
	{"PESHTIGO", 8, 191583},
	{"LYSA", 4, 191584},
	{"EDWORTHYS", 9, 191585},
	{"TRADITIONALISM", 14, 191586},
	{"BEKI", 4, 191587},
	{"NUTBAR", 6, 191588},
	{"JOBFINDER", 9, 191589},
	{"MOZILA", 6, 191590},
	{"KEENTOONS", 9, 191591},
	{"GENTIVA", 7, 191592},
	{"ROQUES", 6, 191593},
	{"ROCKHARD", 8, 191594},
	{"OBSTINATELY", 11, 191595},
	{"HARASSER", 8, 191596},
	{"POLLUTES", 8, 191597},
	{"FILESYS", 7, 191598},
	{"CHASEN", 6, 191599},
	{"BANDITO", 7, 191600},
	{"KADENA", 6, 191601},
	{"LACOCK", 6, 191602},
	{"GUG", 3, 191603},
	{"VERZE", 5, 191604},
	{"TEKKY", 5, 191605},
	{"INCERTAE", 8, 191606},
	{"MICHAE", 6, 191607},
	{"JFIF", 4, 191608},
	{"TIZIANA", 7, 191609},
	{"VELI", 4, 191610},
	{"HISTORICA", 9, 191611},
	{"LRRD", 4, 191612},
	{"THINKFILM", 9, 191613},
	{"PRESCALER", 9, 191614},
	{"VIRTUALTOURIST", 14, 191615},
	{"NUDEWOMAN", 9, 191616},
	{"ESTACADA", 8, 191617},
	{"XWRAS", 5, 191618},
	{"BALCONNET", 9, 191619},
	{"OYUN", 4, 191620},
	{"FLEXLM", 6, 191621},
	{"SKIRMISHER", 10, 191622},
	{"FOOTAGES", 8, 191623},
	{"JOYBOOK", 7, 191624},
	{"STRAIGHTNESS", 12, 191625},
	{"GLEICK", 6, 191626},
	{"NAROOMA", 7, 191627},
	{"MACISAAC", 8, 191628},
	{"BAKULA", 6, 191629},
	{"ZASM", 4, 191630},
	{"YDLE", 4, 191631},
	{"VYHO", 4, 191632},
	{"SIMJ", 4, 191633},
	{"RULU", 4, 191634},
	{"ROZN", 4, 191635},
	{"PKAT", 4, 191636},
	{"ONLP", 4, 191637},
	{"NDLG", 4, 191638},
	{"MVEL", 4, 191639},
	{"MREH", 4, 191640},
	{"MPTD", 4, 191641},
	{"LKPU", 4, 191642},
	{"LIIW", 4, 191643},
	{"LFAA", 4, 191644},
	{"JAZM", 4, 191645},
	{"GGPO", 4, 191646},
	{"GAEU", 4, 191647},
	{"FYBO", 4, 191648},
	{"DUKS", 4, 191649},
	{"DTDI", 4, 191650},
	{"DTBE", 4, 191651},
	{"DOOZ", 4, 191652},
	{"CJAP", 4, 191653},
	{"CEKH", 4, 191654},
	{"AAFU", 4, 191655},
	{"NOHEADER", 8, 191656},
	{"VERSANDFERTIG", 13, 191657},
	{"HUIZHOU", 7, 191658},
	{"OCEANIS", 7, 191659},
	{"MIDPLANE", 8, 191660},
	{"IMPORTA", 7, 191661},
	{"CROSSLINK", 9, 191662},
	{"FAIRUZ", 6, 191663},
	{"QUIKLINK", 8, 191664},
	{"PESTE", 5, 191665},
	{"OGAME", 5, 191666},
	{"HASHEMITE", 9, 191667},
	{"JISM", 4, 191668},
	{"DMEL", 4, 191669},
	{"BASEPEAK", 8, 191670},
	{"AGGRANDIZEMENT", 14, 191671},
	{"WOLL", 4, 191672},
	{"SEVERINA", 8, 191673},
	{"ORIENTA", 7, 191674},
	{"SECORD", 6, 191675},
	{"KLRU", 4, 191676},
	{"SABENA", 6, 191677},
	{"RIVKA", 5, 191678},
	{"CHISWELL", 8, 191679},
	{"RIESENPIMMEL", 12, 191680},
	{"CABA", 4, 191681},
	{"LOFTED", 6, 191682},
	{"COUDERSPORT", 11, 191683},
	{"VDF", 3, 191684},
	{"TOIVONEN", 8, 191685},
	{"TINYS", 5, 191686},
	{"SUBDISCIPLINE", 13, 191687},
	{"INTHEMIX", 8, 191688},
	{"MICHAIL", 7, 191689},
	{"DITZY", 5, 191690},
	{"OFFENSIVES", 10, 191691},
	{"FOUGNER", 7, 191692},
	{"FRIENDSEND", 10, 191693},
	{"DESEASE", 7, 191694},
	{"COLLECTIVITY", 12, 191695},
	{"EXPLAINABLE", 11, 191696},
	{"WAREING", 7, 191697},
	{"THEODEN", 7, 191698},
	{"JOTTED", 6, 191699},
	{"BLACKROX", 8, 191700},
	{"FRUTIGER", 8, 191701},
	{"RIEDL", 5, 191702},
	{"PANTANO", 7, 191703},
	{"LOGISTIQUE", 10, 191704},
	{"ACESSO", 6, 191705},
	{"KARY", 4, 191706},
	{"HARTSHORN", 9, 191707},
	{"RIBISI", 6, 191708},
	{"SIRNAS", 6, 191709},
	{"QCM", 3, 191710},
	{"METACLASS", 9, 191711},
	{"GROUPTHINK", 10, 191712},
	{"SWANWICK", 8, 191713},
	{"PERRYTON", 8, 191714},
	{"INTELLITOUCH", 12, 191715},
	{"GPOGLE", 6, 191716},
	{"TANSEY", 6, 191717},
	{"FACILTIES", 9, 191718},
	{"IMPERMANENT", 11, 191719},
	{"UNPOPULARITY", 12, 191720},
	{"DELUDING", 8, 191721},
	{"IMCI", 4, 191722},
	{"ASBOS", 5, 191723},
	{"BOILEAU", 7, 191724},
	{"GISLE", 5, 191725},
	{"DEPARMENT", 9, 191726},
	{"BURNINGBIRD", 11, 191727},
	{"OVERDOSED", 9, 191728},
	{"MARTINVILLE", 11, 191729},
	{"CHARTA", 6, 191730},
	{"DUERST", 6, 191731},
	{"AGGLUTININ", 10, 191732},
	{"ROYALISTS", 9, 191733},
	{"LAVINGTON", 9, 191734},
	{"EXUBERA", 7, 191735},
	{"DKWNLOAD", 8, 191736},
	{"WRATTEN", 7, 191737},
	{"TWEEDEHANDS", 11, 191738},
	{"CANVASSERS", 10, 191739},
	{"WEEDEN", 6, 191740},
	{"PALATINAE", 9, 191741},
	{"NINGALOO", 8, 191742},
	{"MONALISA", 8, 191743},
	{"JYUTPING", 8, 191744},
	{"DONKIN", 6, 191745},
	{"MILIND", 6, 191746},
	{"SWEETCORN", 9, 191747},
	{"SEJOUR", 6, 191748},
	{"IVISION", 7, 191749},
	{"STANTIAL", 8, 191750},
	{"ACTINIDES", 9, 191751},
	{"RAGAMUFFIN", 10, 191752},
	{"PARAFORMALDEHYDE", 16, 191753},
	{"KANNA", 5, 191754},
	{"JECTED", 6, 191755},
	{"ZOUAVE", 6, 191756},
	{"KHULNA", 6, 191757},
	{"ANDRAE", 6, 191758},
	{"PIDFILE", 7, 191759},
	{"MUSTS", 5, 191760},
	{"KERRYMAN", 8, 191761},
	{"SPEKTOR", 7, 191762},
	{"AQUOLINA", 8, 191763},
	{"TABUS", 5, 191764},
	{"UNFREE", 6, 191765},
	{"NCCLS", 5, 191766},
	{"LACHEN", 6, 191767},
	{"AIRLINS", 7, 191768},
	{"HENNES", 6, 191769},
	{"MALEV", 5, 191770},
	{"ZOOBA", 5, 191771},
	{"WEATHERHOST", 11, 191772},
	{"GOTV", 4, 191773},
	{"ZOLT", 4, 191774},
	{"YJOC", 4, 191775},
	{"YDYE", 4, 191776},
	{"XSQU", 4, 191777},
	{"WVIN", 4, 191778},
	{"SYNG", 4, 191779},
	{"SWEY", 4, 191780},
	{"SECG", 4, 191781},
	{"SCSF", 4, 191782},
	{"RTZF", 4, 191783},
	{"PMEX", 4, 191784},
	{"NTVF", 4, 191785},
	{"NEZM", 4, 191786},
	{"KSMR", 4, 191787},
	{"KEIJ", 4, 191788},
	{"JWIT", 4, 191789},
	{"IBAM", 4, 191790},
	{"GMOH", 4, 191791},
	{"GBMO", 4, 191792},
	{"EMNU", 4, 191793},
	{"EIFJ", 4, 191794},
	{"CMOB", 4, 191795},
	{"CLAE", 4, 191796},
	{"APTP", 4, 191797},
	{"PUGSLEY", 7, 191798},
	{"OMBUDS", 6, 191799},
	{"METROFASHION", 12, 191800},
	{"HAMBLY", 6, 191801},
	{"DIOXANE", 7, 191802},
	{"CHIROPODY", 9, 191803},
	{"ROUGHSHOD", 9, 191804},
	{"KANAN", 5, 191805},
	{"DOCUCOLOR", 9, 191806},
	{"RAIMONDI", 8, 191807},
	{"LTCOL", 5, 191808},
	{"ROSEBERRY", 9, 191809},
	{"MYPROFILE", 9, 191810},
	{"JURAN", 5, 191811},
	{"RACLETTE", 8, 191812},
	{"VIJVER", 6, 191813},
	{"NODIG", 5, 191814},
	{"SAVALAS", 7, 191815},
	{"LEONETTO", 8, 191816},
	{"MASCO", 5, 191817},
	{"RAZZAQ", 6, 191818},
	{"KEMPSTON", 8, 191819},
	{"SHARANSKY", 9, 191820},
	{"MINDBLOWING", 11, 191821},
	{"LONERS", 6, 191822},
	{"KNEALE", 6, 191823},
	{"FRANCISCUS", 10, 191824},
	{"CLUSAZ", 6, 191825},
	{"SAYETH", 6, 191826},
	{"HETERODYNE", 10, 191827},
	{"EGGED", 5, 191828},
	{"BRAME", 5, 191829},
	{"WETTERLING", 10, 191830},
	{"YAHOOGAMES", 10, 191831},
	{"TAMARI", 6, 191832},
	{"CHAUSSURE", 9, 191833},
	{"HARLE", 5, 191834},
	{"DUPY", 4, 191835},
	{"CRUISESONLY", 11, 191836},
	{"LONDONIST", 9, 191837},
	{"MONACA", 6, 191838},
	{"BILTON", 6, 191839},
	{"KOKUSAI", 7, 191840},
	{"INTEGRALE", 9, 191841},
	{"GOOMBA", 6, 191842},
	{"PANNEL", 6, 191843},
	{"ILIFF", 5, 191844},
	{"MMSD", 4, 191845},
	{"ABERTAWE", 8, 191846},
	{"HUMBROL", 7, 191847},
	{"SHORTHAUL", 9, 191848},
	{"FLATLANDS", 9, 191849},
	{"EUROPESTANSTED", 14, 191850},
	{"LIBEROUTER", 10, 191851},
	{"GIOGLE", 6, 191852},
	{"LUTS", 4, 191853},
	{"CRUELEST", 8, 191854},
	{"PROGRAMMS", 9, 191855},
	{"MUNZ", 4, 191856},
	{"LAMO", 4, 191857},
	{"ONCOLOGIC", 9, 191858},
	{"MLMMJ", 5, 191859},
	{"LISTINGTYPE", 11, 191860},
	{"DIMETHYLAMINO", 13, 191861},
	{"VGF", 3, 191862},
	{"ACHAEANS", 8, 191863},
	{"NTRP", 4, 191864},
	{"GILCHREST", 9, 191865},
	{"CRAVAT", 6, 191866},
	{"GASTOWN", 7, 191867},
	{"DEJAIRC", 7, 191868},
	{"FARRUKH", 7, 191869},
	{"BILLUND", 7, 191870},
	{"REGLAMENTO", 10, 191871},
	{"NEWVAL", 6, 191872},
	{"COREN", 5, 191873},
	{"CAULDRONS", 9, 191874},
	{"ZVP", 3, 191875},
	{"ZKV", 3, 191876},
	{"ZBK", 3, 191877},
	{"XZZ", 3, 191878},
	{"XZJ", 3, 191879},
	{"XJZ", 3, 191880},
	{"XJL", 3, 191881},
	{"XJK", 3, 191882},
	{"VJK", 3, 191883},
	{"QYU", 3, 191884},
	{"QYB", 3, 191885},
	{"QWQ", 3, 191886},
	{"QWC", 3, 191887},
	{"QPQ", 3, 191888},
	{"QLJ", 3, 191889},
	{"LXZ", 3, 191890},
	{"FXZ", 3, 191891},
	{"CQK", 3, 191892},
	{"KHALAF", 6, 191893},
	{"DOWMLOADS", 9, 191894},
	{"VISER", 5, 191895},
	{"NTUC", 4, 191896},
	{"HAUPTBAHNHOF", 12, 191897},
	{"HYMNALS", 7, 191898},
	{"ZEITNER", 7, 191899},
	{"WAPENS", 6, 191900},
	{"DIVIDUAL", 8, 191901},
	{"ISPECIES", 8, 191902},
	{"GENUG", 5, 191903},
	{"EFORMS", 6, 191904},
	{"DECCACOLOUR", 11, 191905},
	{"CAZAL", 5, 191906},
	{"TIROLE", 6, 191907},
	{"PHOTODETECTOR", 13, 191908},
	{"BEDNAR", 6, 191909},
	{"MARTIKA", 7, 191910},
	{"MARCON", 6, 191911},
	{"ERFAHRENE", 9, 191912},
	{"MARD", 4, 191913},
	{"TOPIARIES", 9, 191914},
	{"PICKPOCKETS", 11, 191915},
	{"PINIONS", 7, 191916},
	{"OPPINION", 8, 191917},
	{"BORDERWIDTH", 11, 191918},
	{"ZYSE", 4, 191919},
	{"ZNAV", 4, 191920},
	{"ZKIS", 4, 191921},
	{"YPHD", 4, 191922},
	{"WTIP", 4, 191923},
	{"SYSM", 4, 191924},
	{"SSQM", 4, 191925},
	{"SJOG", 4, 191926},
	{"RZEC", 4, 191927},
	{"RNDY", 4, 191928},
	{"QIWA", 4, 191929},
	{"PIAK", 4, 191930},
	{"OVRA", 4, 191931},
	{"ORCF", 4, 191932},
	{"NPEY", 4, 191933},
	{"NIJM", 4, 191934},
	{"LTHV", 4, 191935},
	{"LIMJ", 4, 191936},
	{"KOTL", 4, 191937},
	{"JSPI", 4, 191938},
	{"JIYA", 4, 191939},
	{"GUYK", 4, 191940},
	{"GMCE", 4, 191941},
	{"FIGT", 4, 191942},
	{"FCES", 4, 191943},
	{"ENLR", 4, 191944},
	{"DUIC", 4, 191945},
	{"DRUW", 4, 191946},
	{"DAGP", 4, 191947},
	{"CHUF", 4, 191948},
	{"CHRH", 4, 191949},
	{"BFRI", 4, 191950},
	{"AWEF", 4, 191951},
	{"ACVI", 4, 191952},
	{"ABCM", 4, 191953},
	{"HANDPRINT", 9, 191954},
	{"ARTHUS", 6, 191955},
	{"RAZVAN", 6, 191956},
	{"BOREHAM", 7, 191957},
	{"QUALQUER", 8, 191958},
	{"PUTC", 4, 191959},
	{"DAMANSARA", 9, 191960},
	{"JORD", 4, 191961},
	{"MCCURTAIN", 9, 191962},
	{"LOLOL", 5, 191963},
	{"RICKSHAWS", 9, 191964},
	{"NONRENEWAL", 10, 191965},
	{"SNITCHIN", 8, 191966},
	{"CULI", 4, 191967},
	{"XPLODE", 6, 191968},
	{"CEBUANO", 7, 191969},
	{"MINDRE", 6, 191970},
	{"GRIFONI", 7, 191971},
	{"MASONVILLE", 10, 191972},
	{"HYDROGENS", 9, 191973},
	{"KATAUSKAS", 9, 191974},
	{"GAINST", 6, 191975},
	{"SKINNERS", 8, 191976},
	{"PAWCATUCK", 9, 191977},
	{"LEHRMAN", 7, 191978},
	{"PASP", 4, 191979},
	{"IMMIGRAZIONE", 12, 191980},
	{"CHEMTREC", 8, 191981},
	{"LIONBRIDGE", 10, 191982},
	{"OVERSTEPPED", 11, 191983},
	{"MOOLAH", 6, 191984},
	{"HENTERMINE", 10, 191985},
	{"PRAETOR", 7, 191986},
	{"TOMENTOSA", 9, 191987},
	{"DROPBEAR", 8, 191988},
	{"TECHLINK", 8, 191989},
	{"FINGERLING", 10, 191990},
	{"EUROBANK", 8, 191991},
	{"DICKINS", 7, 191992},
	{"ALYSHA", 6, 191993},
	{"HAFNIUM", 7, 191994},
	{"GAMEFINDER", 10, 191995},
	{"LAKEY", 5, 191996},
	{"KUFFNER", 7, 191997},
	{"HEREINABOVE", 11, 191998},
	{"TENSING", 7, 191999},
	{"REIJO", 5, 192000},
	{"REFURBISHMENTS", 14, 192001},
	{"ALIM", 4, 192002},
	{"SLUGGY", 6, 192003},
	{"KITCHING", 8, 192004},
	{"ROWNLOAD", 8, 192005},
	{"EBULLIENT", 9, 192006},
	{"TWIKIFAQ", 8, 192007},
	{"ORMANDY", 7, 192008},
	{"DOMBROWSKI", 10, 192009},
	{"TREMAIN", 7, 192010},
	{"GOOGOE", 6, 192011},
	{"DELORIE", 7, 192012},
	{"TROPISM", 7, 192013},
	{"PAVONE", 6, 192014},
	{"SANDHYA", 7, 192015},
	{"RAICHLE", 7, 192016},
	{"ELIXIRS", 7, 192017},
	{"ECIENT", 6, 192018},
	{"SYNNOVE", 7, 192019},
	{"STORMERS", 8, 192020},
	{"RHOME", 5, 192021},
	{"PROPHETHOOD", 11, 192022},
	{"ENDDATE", 7, 192023},
	{"BAZZA", 5, 192024},
	{"NUTTENKONTAKT", 13, 192025},
	{"CAMELLIAS", 9, 192026},
	{"PANTENE", 7, 192027},
	{"MUREX", 5, 192028},
	{"CYCHWYN", 7, 192029},
	{"SCHOOLBOOKS", 11, 192030},
	{"HATTERSLEY", 10, 192031},
	{"PECHE", 5, 192032},
	{"NEUILLY", 7, 192033},
	{"WALTMAN", 7, 192034},
	{"THERMIONIC", 10, 192035},
	{"MANAN", 5, 192036},
	{"WROBEL", 6, 192037},
	{"UNTIMED", 7, 192038},
	{"SHIMANE", 7, 192039},
	{"EVENTHANDLER", 12, 192040},
	{"PAYAL", 5, 192041},
	{"MALLOCH", 7, 192042},
	{"BONANNO", 7, 192043},
	{"AVANZADO", 8, 192044},
	{"FUMA", 4, 192045},
	{"CARATULAS", 9, 192046},
	{"EINSATZ", 7, 192047},
	{"ALLEPPEY", 8, 192048},
	{"SUNBURNT", 8, 192049},
	{"NAINITAL", 8, 192050},
	{"COMPENDEX", 9, 192051},
	{"DISTVERSION", 11, 192052},
	{"COSGRAVE", 8, 192053},
	{"GALLACTICA", 10, 192054},
	{"FIBRECULTURE", 12, 192055},
	{"SUPERFICIE", 10, 192056},
	{"EXUDED", 6, 192057},
	{"LAFON", 5, 192058},
	{"DINOFLAGELLATES", 15, 192059},
	{"SEBALD", 6, 192060},
	{"YEHUDAH", 7, 192061},
	{"SHANTUNG", 8, 192062},
	{"MUGGLENET", 9, 192063},
	{"GENIC", 5, 192064},
	{"ASHUTOSH", 8, 192065},
	{"OVERBOOKED", 10, 192066},
	{"CAVEOLIN", 8, 192067},
	{"VORMETRIC", 9, 192068},
	{"XVEN", 4, 192069},
	{"XSMO", 4, 192070},
	{"WREB", 4, 192071},
	{"TWWI", 4, 192072},
	{"RSNC", 4, 192073},
	{"PTHD", 4, 192074},
	{"PDFO", 4, 192075},
	{"PAIC", 4, 192076},
	{"OYTW", 4, 192077},
	{"OXAM", 4, 192078},
	{"OHLM", 4, 192079},
	{"NYEG", 4, 192080},
	{"NWOK", 4, 192081},
	{"NDWC", 4, 192082},
	{"NBAZ", 4, 192083},
	{"MWAD", 4, 192084},
	{"MBME", 4, 192085},
	{"LYIO", 4, 192086},
	{"LYBD", 4, 192087},
	{"LBTO", 4, 192088},
	{"KZAC", 4, 192089},
	{"KMYM", 4, 192090},
	{"HIDW", 4, 192091},
	{"FPAH", 4, 192092},
	{"FMCN", 4, 192093},
	{"ETUK", 4, 192094},
	{"ERHD", 4, 192095},
	{"EPPB", 4, 192096},
	{"ELJR", 4, 192097},
	{"DYAO", 4, 192098},
	{"DTEB", 4, 192099},
	{"DERX", 4, 192100},
	{"AWRU", 4, 192101},
	{"GLENNVILLE", 10, 192102},
	{"NUKING", 6, 192103},
	{"TELRAD", 6, 192104},
	{"GROTESQUELY", 11, 192105},
	{"BETTERMAN", 9, 192106},
	{"METIN", 5, 192107},
	{"GITLIN", 6, 192108},
	{"PREOPERATIVELY", 14, 192109},
	{"UWIC", 4, 192110},
	{"CODICI", 6, 192111},
	{"PHRAGMITES", 10, 192112},
	{"SCOUNT", 6, 192113},
	{"DEVHELP", 7, 192114},
	{"EMINTS", 6, 192115},
	{"SPHEROIDAL", 10, 192116},
	{"RAJINDER", 8, 192117},
	{"PAMINTUAN", 9, 192118},
	{"CARDURA", 7, 192119},
	{"ELENIAK", 7, 192120},
	{"CROON", 5, 192121},
	{"SWELLINGS", 9, 192122},
	{"RADIOMETRY", 10, 192123},
	{"RACHA", 5, 192124},
	{"PENTECOSTALS", 12, 192125},
	{"ONLINEONLINE", 12, 192126},
	{"PLANTINGA", 9, 192127},
	{"KERMA", 5, 192128},
	{"EBONYNUDE", 9, 192129},
	{"BERRIDGE", 8, 192130},
	{"THIOUREA", 8, 192131},
	{"MUSICXPC", 8, 192132},
	{"BACKSCATTERED", 13, 192133},
	{"THIORIDAZINE", 12, 192134},
	{"LENSED", 6, 192135},
	{"TIPTOP", 6, 192136},
	{"MOWN", 4, 192137},
	{"LEANNI", 6, 192138},
	{"OLEUM", 5, 192139},
	{"TEENSY", 6, 192140},
	{"VAGRANTS", 8, 192141},
	{"VACATIONER", 10, 192142},
	{"STARSHINE", 9, 192143},
	{"BUDDA", 5, 192144},
	{"ACETO", 5, 192145},
	{"ROSELAWN", 8, 192146},
	{"PRONATURA", 9, 192147},
	{"COBERTURA", 9, 192148},
	{"EISENACH", 8, 192149},
	{"TESTUN", 6, 192150},
	{"HYDRIDES", 8, 192151},
	{"SOGNO", 5, 192152},
	{"NEMATODA", 8, 192153},
	{"FILLIP", 6, 192154},
	{"VELINGRAD", 9, 192155},
	{"FBOX", 4, 192156},
	{"ELED", 4, 192157},
	{"WITBANK", 7, 192158},
	{"KAITAIA", 7, 192159},
	{"JIANGYIN", 8, 192160},
	{"TRANSEPT", 8, 192161},
	{"SYKE", 4, 192162},
	{"SHIMURA", 7, 192163},
	{"NICENESS", 8, 192164},
	{"SHOWJUMPING", 11, 192165},
	{"RIDESHARING", 11, 192166},
	{"VALACYCLOVIR", 12, 192167},
	{"CULOTTE", 7, 192168},
	{"RECENTLYCOMMENTED", 17, 192169},
	{"CATECHISMS", 10, 192170},
	{"BYC", 3, 192171},
	{"UNTRUTHS", 8, 192172},
	{"IMMUNOCHEMICAL", 14, 192173},
	{"AZZURRO", 7, 192174},
	{"AVALIBLE", 8, 192175},
	{"JPP", 3, 192176},
	{"DYEABLES", 8, 192177},
	{"WESTALL", 7, 192178},
	{"CGIS", 4, 192179},
	{"ANZIO", 5, 192180},
	{"NACRE", 5, 192181},
	{"NUNCIO", 6, 192182},
	{"VAPORWARE", 9, 192183},
	{"SWATI", 5, 192184},
	{"ENCAPSULATIONS", 14, 192185},
	{"ALTOOLS", 7, 192186},
	{"PATOIS", 6, 192187},
	{"SNCM", 4, 192188},
	{"FARPOINT", 8, 192189},
	{"AIRSPRUNG", 9, 192190},
	{"EXPOSITOR", 9, 192191},
	{"VATTEROTT", 9, 192192},
	{"SLEEMAN", 7, 192193},
	{"HROFFICE", 8, 192194},
	{"PIRATAS", 7, 192195},
	{"SADDO", 5, 192196},
	{"ATLEE", 5, 192197},
	{"SEUIL", 5, 192198},
	{"ROUTEMASTER", 11, 192199},
	{"JOBSINTHEMONEY", 14, 192200},
	{"TOLKEIN", 7, 192201},
	{"TOOLTALK", 8, 192202},
	{"BANKE", 5, 192203},
	{"ZAMS", 4, 192204},
	{"YDSC", 4, 192205},
	{"WJUL", 4, 192206},
	{"WBYR", 4, 192207},
	{"VOFA", 4, 192208},
	{"TODJ", 4, 192209},
	{"SUGR", 4, 192210},
	{"SLOK", 4, 192211},
	{"SKCL", 4, 192212},
	{"RZIA", 4, 192213},
	{"ROXC", 4, 192214},
	{"RFSC", 4, 192215},
	{"POBS", 4, 192216},
	{"PHPE", 4, 192217},
	{"OLPS", 4, 192218},
	{"NNPU", 4, 192219},
	{"NLLC", 4, 192220},
	{"MREY", 4, 192221},
	{"MLFO", 4, 192222},
	{"MIFW", 4, 192223},
	{"MGEI", 4, 192224},
	{"LVOA", 4, 192225},
	{"LIFD", 4, 192226},
	{"KSEF", 4, 192227},
	{"JOWI", 4, 192228},
	{"JJAR", 4, 192229},
	{"ISPG", 4, 192230},
	{"IKOC", 4, 192231},
	{"HYSD", 4, 192232},
	{"HIBM", 4, 192233},
	{"HCUI", 4, 192234},
	{"GTEB", 4, 192235},
	{"GBAP", 4, 192236},
	{"FBIE", 4, 192237},
	{"EXYL", 4, 192238},
	{"EXXI", 4, 192239},
	{"EDKG", 4, 192240},
	{"AZWI", 4, 192241},
	{"AYZO", 4, 192242},
	{"AMZE", 4, 192243},
	{"ACVE", 4, 192244},
	{"BADGING", 7, 192245},
	{"SABRETOOTH", 10, 192246},
	{"PACKIN", 6, 192247},
	{"PETROGRAD", 9, 192248},
	{"STIME", 5, 192249},
	{"BRUMM", 5, 192250},
	{"WHIPPEDASS", 10, 192251},
	{"KIETH", 5, 192252},
	{"HARDINGE", 8, 192253},
	{"ADRESA", 6, 192254},
	{"SCHUURMAN", 9, 192255},
	{"ENOXAPARIN", 10, 192256},
	{"ELING", 5, 192257},
	{"AVEVA", 5, 192258},
	{"ULTRAWIDEBAND", 13, 192259},
	{"NAMBU", 5, 192260},
	{"SAGET", 5, 192261},
	{"ROWSPAN", 7, 192262},
	{"YANDELL", 7, 192263},
	{"TUBED", 5, 192264},
	{"MONARCHIST", 10, 192265},
	{"VISITEZ", 7, 192266},
	{"BERATING", 8, 192267},
	{"MERCURIUS", 9, 192268},
	{"HYDROLYTIC", 10, 192269},
	{"PRUNELLA", 8, 192270},
	{"RARING", 6, 192271},
	{"BULGED", 6, 192272},
	{"YAKAMA", 6, 192273},
	{"AROM", 4, 192274},
	{"CHRONY", 6, 192275},
	{"REMOSITORY", 10, 192276},
	{"BUZAN", 5, 192277},
	{"BATED", 5, 192278},
	{"JACKLYN", 7, 192279},
	{"DUGDALE", 7, 192280},
	{"SEINES", 6, 192281},
	{"FARON", 5, 192282},
	{"FINANCIEEL", 10, 192283},
	{"MAGNIFICATIONS", 14, 192284},
	{"VERSIONEN", 9, 192285},
	{"THEREAT", 7, 192286},
	{"DADAIMC", 7, 192287},
	{"MEDICIS", 7, 192288},
	{"GORDONVILLE", 11, 192289},
	{"MULVANEY", 8, 192290},
	{"CORDIER", 7, 192291},
	{"QUICKLINX", 9, 192292},
	{"POSIFLEX", 8, 192293},
	{"COXE", 4, 192294},
	{"BARBET", 6, 192295},
	{"CDEF", 4, 192296},
	{"INTERMETALLIC", 13, 192297},
	{"ZENTRALBL", 9, 192298},
	{"UNCHURCHED", 10, 192299},
	{"CANER", 5, 192300},
	{"VRANA", 5, 192301},
	{"BLAKELEY", 8, 192302},
	{"DIETY", 5, 192303},
	{"BRAVOS", 6, 192304},
	{"SHADO", 5, 192305},
	{"VALDIS", 6, 192306},
	{"VENLA", 5, 192307},
	{"KUYA", 4, 192308},
	{"GOUROCK", 7, 192309},
	{"BUBS", 4, 192310},
	{"CYCLOPHILIN", 11, 192311},
	{"YODL", 4, 192312},
	{"CARSTENSEN", 10, 192313},
	{"BEAUPORT", 8, 192314},
	{"TARJAN", 6, 192315},
	{"QUANTOM", 7, 192316},
	{"OVERSIGT", 8, 192317},
	{"MALVERNE", 8, 192318},
	{"JURAJ", 5, 192319},
	{"OSTRIM", 6, 192320},
	{"GOTTLOB", 7, 192321},
	{"NARCISSISTS", 11, 192322},
	{"ENTEROBACTER", 12, 192323},
	{"GERMANYHAVE", 11, 192324},
	{"MUCIC", 5, 192325},
	{"SUSTEEN", 7, 192326},
	{"SECONDAIRE", 10, 192327},
	{"ZUERICH", 7, 192328},
	{"ISHTML", 6, 192329},
	{"CALORIMETERS", 12, 192330},
	{"BAEHR", 5, 192331},
	{"FLOUNDERS", 9, 192332},
	{"STELLVIA", 8, 192333},
	{"BUNCHA", 6, 192334},
	{"HITSQUAD", 8, 192335},
	{"EHRLICHIA", 9, 192336},
	{"EDMISTON", 8, 192337},
	{"LYLLI", 5, 192338},
	{"CANIDAE", 7, 192339},
	{"SCHREYER", 8, 192340},
	{"REALPATH", 8, 192341},
	{"PHALAROPE", 9, 192342},
	{"VEZD", 4, 192343},
	{"ULAJ", 4, 192344},
	{"TPEM", 4, 192345},
	{"THGW", 4, 192346},
	{"SUEK", 4, 192347},
	{"RRBO", 4, 192348},
	{"OGPE", 4, 192349},
	{"NPOX", 4, 192350},
	{"MBBO", 4, 192351},
	{"LGLU", 4, 192352},
	{"KYGU", 4, 192353},
	{"KEHY", 4, 192354},
	{"JJOH", 4, 192355},
	{"IAKM", 4, 192356},
	{"GSJE", 4, 192357},
	{"GHYU", 4, 192358},
	{"FWEJ", 4, 192359},
	{"FNIR", 4, 192360},
	{"FFOI", 4, 192361},
	{"ECPP", 4, 192362},
	{"EBTU", 4, 192363},
	{"DHPU", 4, 192364},
	{"CHTZ", 4, 192365},
	{"BYIO", 4, 192366},
	{"BYCS", 4, 192367},
	{"BUZU", 4, 192368},
	{"BGIV", 4, 192369},
	{"BCFR", 4, 192370},
	{"AJOG", 4, 192371},
	{"RESENDING", 9, 192372},
	{"RECOURS", 7, 192373},
	{"ARAGONITE", 9, 192374},
	{"RIDA", 4, 192375},
	{"GENERICO", 8, 192376},
	{"BUTTTS", 6, 192377},
	{"BANCORPORATION", 14, 192378},
	{"REQUESTORS", 10, 192379},
	{"WESTHAVEN", 9, 192380},
	{"UUENCODED", 9, 192381},
	{"FRAMESETS", 9, 192382},
	{"EVENTUALITIES", 13, 192383},
	{"POLYFONIC", 9, 192384},
	{"MEZZOBLUE", 9, 192385},
	{"KAKASI", 6, 192386},
	{"TEMPLEMAN", 9, 192387},
	{"NEAVE", 5, 192388},
	{"THIERS", 6, 192389},
	{"PHYRIC", 6, 192390},
	{"FYNE", 4, 192391},
	{"SANFILIPPO", 10, 192392},
	{"MARONITE", 8, 192393},
	{"INSERAT", 7, 192394},
	{"HARVILL", 7, 192395},
	{"PERCIEVED", 9, 192396},
	{"LISIANTHUS", 10, 192397},
	{"GUNGAHLIN", 9, 192398},
	{"ACRYL", 5, 192399},
	{"NTDLL", 5, 192400},
	{"LOCALSITEMAP", 12, 192401},
	{"LEGES", 5, 192402},
	{"BLACKNUDE", 9, 192403},
	{"AGGLOMERATIONS", 14, 192404},
	{"VESEY", 5, 192405},
	{"FREMDSPRACHEN", 13, 192406},
	{"SARDS", 5, 192407},
	{"PETMATE", 7, 192408},
	{"CHASS", 5, 192409},
	{"ASHMOLEAN", 9, 192410},
	{"ARGENTINOS", 10, 192411},
	{"AIRBED", 6, 192412},
	{"ROTENONE", 8, 192413},
	{"NARDO", 5, 192414},
	{"CFSAN", 5, 192415},
	{"KLOG", 4, 192416},
	{"CACHEP", 6, 192417},
	{"GAMEBANSHEE", 11, 192418},
	{"BLEWETT", 7, 192419},
	{"GALENIC", 7, 192420},
	{"AXFR", 4, 192421},
	{"SEFYDLU", 7, 192422},
	{"FALKENSTEIN", 11, 192423},
	{"COAGULANT", 9, 192424},
	{"HISTOCYTOCHEMISTRY", 18, 192425},
	{"BUCHUNG", 7, 192426},
	{"PRUDHOMME", 9, 192427},
	{"LASSI", 5, 192428},
	{"GREYSTS", 7, 192429},
	{"AUFBAU", 6, 192430},
	{"VERZORGING", 10, 192431},
	{"ASARCO", 6, 192432},
	{"ENTERCOM", 8, 192433},
	{"JAXME", 5, 192434},
	{"DIGGNATION", 10, 192435},
	{"CIVET", 5, 192436},
	{"CIDES", 5, 192437},
	{"EKTACHROME", 10, 192438},
	{"BLATA", 5, 192439},
	{"COTTERILL", 9, 192440},
	{"PHOSPHOLIPASES", 14, 192441},
	{"OAKVIEW", 7, 192442},
	{"GLASCOCK", 8, 192443},
	{"SCENERIES", 9, 192444},
	{"HAGIN", 5, 192445},
	{"DISTEFANO", 9, 192446},
	{"CLOVEN", 6, 192447},
	{"GOOGOLE", 7, 192448},
	{"MOULE", 5, 192449},
	{"HYPNOS", 6, 192450},
	{"GIASCHI", 7, 192451},
	{"SACHEM", 6, 192452},
	{"APOLLYON", 8, 192453},
	{"TUEBINGEN", 9, 192454},
	{"BTECH", 5, 192455},
	{"BCPS", 4, 192456},
	{"BARSIK", 6, 192457},
	{"ARGENTUM", 8, 192458},
	{"VARIATIONEN", 11, 192459},
	{"FREESTYLES", 10, 192460},
	{"ZENWALK", 7, 192461},
	{"ALLIANCEBERNSTEIN", 17, 192462},
	{"ILWU", 4, 192463},
	{"CALFEE", 6, 192464},
	{"CURRINGTON", 10, 192465},
	{"SENESCENT", 9, 192466},
	{"WALDPORT", 8, 192467},
	{"CSHCN", 5, 192468},
	{"SOLOTHURN", 9, 192469},
	{"GLSEN", 5, 192470},
	{"ALBATROSSES", 11, 192471},
	{"INTEMPERATE", 11, 192472},
	{"IGNAZ", 5, 192473},
	{"BINNER", 6, 192474},
	{"ANDD", 4, 192475},
	{"JUVENAL", 7, 192476},
	{"DUMPERS", 7, 192477},
	{"MODLE", 5, 192478},
	{"SPOSE", 5, 192479},
	{"GLES", 4, 192480},
	{"VASOSPASM", 9, 192481},
	{"SNOWGLOBES", 10, 192482},
	{"ZVER", 4, 192483},
	{"ZEDZ", 4, 192484},
	{"YENU", 4, 192485},
	{"XMER", 4, 192486},
	{"XGIV", 4, 192487},
	{"XEUR", 4, 192488},
	{"XBYA", 4, 192489},
	{"SUVW", 4, 192490},
	{"RUDN", 4, 192491},
	{"ROHW", 4, 192492},
	{"RMGL", 4, 192493},
	{"RGHG", 4, 192494},
	{"OFWM", 4, 192495},
	{"NGEZ", 4, 192496},
	{"LVEZ", 4, 192497},
	{"LDKR", 4, 192498},
	{"KECY", 4, 192499},
	{"IFQU", 4, 192500},
	{"IFFK", 4, 192501},
	{"HODL", 4, 192502},
	{"HEXD", 4, 192503},
	{"GPIZ", 4, 192504},
	{"GOVW", 4, 192505},
	{"GMOC", 4, 192506},
	{"GKOM", 4, 192507},
	{"FKLA", 4, 192508},
	{"EGSG", 4, 192509},
	{"EEXQ", 4, 192510},
	{"DAXL", 4, 192511},
	{"COZA", 4, 192512},
	{"COXF", 4, 192513},
	{"CIAJ", 4, 192514},
	{"BUDU", 4, 192515},
	{"BCOO", 4, 192516},
	{"AZIB", 4, 192517},
	{"AKDR", 4, 192518},
	{"KSCREENSAVER", 12, 192519},
	{"CAREERJOURNALEUROPE", 19, 192520},
	{"TRYNA", 5, 192521},
	{"JUDDS", 5, 192522},
	{"DOWNLODE", 8, 192523},
	{"MELAMED", 7, 192524},
	{"KELPIE", 6, 192525},
	{"ACORDING", 8, 192526},
	{"RECOGNI", 7, 192527},
	{"MECHANICALS", 11, 192528},
	{"BORSATO", 7, 192529},
	{"CUNTT", 5, 192530},
	{"CONFIDING", 9, 192531},
	{"ISTER", 5, 192532},
	{"REINTERPRET", 11, 192533},
	{"SCHURZ", 6, 192534},
	{"OFRA", 4, 192535},
	{"MAYBEE", 6, 192536},
	{"GAMESNOKIA", 10, 192537},
	{"DOSHI", 5, 192538},
	{"COMERFORD", 9, 192539},
	{"OMEG", 4, 192540},
	{"NAZAIRE", 7, 192541},
	{"REMEM", 5, 192542},
	{"WISSENSCHAFTLICHE", 17, 192543},
	{"FLEISCH", 7, 192544},
	{"NAPPED", 6, 192545},
	{"TENDENCI", 8, 192546},
	{"FALEISUS", 8, 192547},
	{"EARES", 5, 192548},
	{"STIMS", 5, 192549},
	{"LAHOUD", 6, 192550},
	{"FTEMPLATE", 9, 192551},
	{"PRESENTAZIONE", 13, 192552},
	{"PLUR", 4, 192553},
	{"DUALITIES", 9, 192554},
	{"COMPUNCTION", 11, 192555},
	{"SNICKERED", 9, 192556},
	{"SERIEN", 6, 192557},
	{"PERSONIFIES", 11, 192558},
	{"FARSIDE", 7, 192559},
	{"BONUM", 5, 192560},
	{"REFRACT", 7, 192561},
	{"CCAR", 4, 192562},
	{"TELEOLOGY", 9, 192563},
	{"SCOLA", 5, 192564},
	{"MICROBICIDE", 11, 192565},
	{"DEEPO", 5, 192566},
	{"MOROSO", 6, 192567},
	{"TWEEK", 5, 192568},
	{"CREWKERNE", 9, 192569},
	{"TOLSON", 6, 192570},
	{"GRUPA", 5, 192571},
	{"XUCHUN", 6, 192572},
	{"FLUOROQUINOLONE", 15, 192573},
	{"TOUCHBACK", 9, 192574},
	{"SUNDSTROM", 9, 192575},
	{"POLLINATE", 9, 192576},
	{"DUNDONALD", 9, 192577},
	{"CHANDER", 7, 192578},
	{"RGDINMALAYSIA", 13, 192579},
	{"FTPS", 4, 192580},
	{"DIVORICED", 9, 192581},
	{"BARY", 4, 192582},
	{"BODYWORKS", 9, 192583},
	{"TESTBENCH", 9, 192584},
	{"MEXICANAS", 9, 192585},
	{"RILE", 4, 192586},
	{"VELOCIRAPTOR", 12, 192587},
	{"CIVILS", 6, 192588},
	{"HALDIR", 6, 192589},
	{"TENDANCY", 8, 192590},
	{"RYCROFT", 7, 192591},
	{"MOVIECLIPS", 10, 192592},
	{"BROODWAR", 8, 192593},
	{"TURKANA", 7, 192594},
	{"WISMA", 5, 192595},
	{"UNCEASINGLY", 11, 192596},
	{"SETVISIBLE", 10, 192597},
	{"TRIMSIZE", 8, 192598},
	{"ACPE", 4, 192599},
	{"HERDSMAN", 8, 192600},
	{"MYCOTOXIN", 9, 192601},
	{"RADIM", 5, 192602},
	{"SILVERSCREEN", 12, 192603},
	{"DIYARBAKIR", 10, 192604},
	{"MOVIEGOER", 9, 192605},
	{"HANDGRIP", 8, 192606},
	{"FRIGHTFULLY", 11, 192607},
	{"ENCASING", 8, 192608},
	{"TELEOSTEI", 9, 192609},
	{"RESTREPO", 8, 192610},
	{"CATALYTICALLY", 13, 192611},
	{"BRITAN", 6, 192612},
	{"REPRISES", 8, 192613},
	{"ARKA", 4, 192614},
	{"VGRD", 4, 192615},
	{"BAZAN", 5, 192616},
	{"TOMOE", 5, 192617},
	{"MACFADYEN", 9, 192618},
	{"AKZENT", 6, 192619},
	{"YCEG", 4, 192620},
	{"YALJ", 4, 192621},
	{"WVIA", 4, 192622},
	{"WITK", 4, 192623},
	{"WINQ", 4, 192624},
	{"VOAL", 4, 192625},
	{"VEOD", 4, 192626},
	{"URZW", 4, 192627},
	{"UNJE", 4, 192628},
	{"UGAY", 4, 192629},
	{"RNZH", 4, 192630},
	{"QFRO", 4, 192631},
	{"PKRA", 4, 192632},
	{"OYGI", 4, 192633},
	{"OLOZ", 4, 192634},
	{"OELV", 4, 192635},
	{"OCUD", 4, 192636},
	{"NVED", 4, 192637},
	{"NPME", 4, 192638},
	{"NNUD", 4, 192639},
	{"NKOG", 4, 192640},
	{"MKUN", 4, 192641},
	{"LLPC", 4, 192642},
	{"LECM", 4, 192643},
	{"LDUD", 4, 192644},
	{"KIPW", 4, 192645},
	{"KCOI", 4, 192646},
	{"KARV", 4, 192647},
	{"JRWE", 4, 192648},
	{"INMB", 4, 192649},
	{"ILZA", 4, 192650},
	{"ECVS", 4, 192651},
	{"CYSN", 4, 192652},
	{"CPUI", 4, 192653},
	{"CPLO", 4, 192654},
	{"COXR", 4, 192655},
	{"BORZ", 4, 192656},
	{"RAMES", 5, 192657},
	{"LIPPE", 5, 192658},
	{"OLESON", 6, 192659},
	{"KARAKORAM", 9, 192660},
	{"SKREVET", 7, 192661},
	{"ENING", 5, 192662},
	{"HINCHLIFFE", 10, 192663},
	{"FIERCENESS", 10, 192664},
	{"DILLA", 5, 192665},
	{"HAJAR", 5, 192666},
	{"DISQUETTE", 9, 192667},
	{"STOVEPIPE", 9, 192668},
	{"REMODELLED", 10, 192669},
	{"NICOS", 5, 192670},
	{"OVERCOOKED", 10, 192671},
	{"ANAMOSA", 7, 192672},
	{"CARDASSIAN", 10, 192673},
	{"LEVASSEUR", 9, 192674},
	{"EJECTS", 6, 192675},
	{"HOKU", 4, 192676},
	{"ECOSSE", 6, 192677},
	{"FOOTLIGHT", 9, 192678},
	{"TEMPORALITY", 11, 192679},
	{"UNPLEASANTLY", 12, 192680},
	{"HUSSON", 6, 192681},
	{"MESSEN", 6, 192682},
	{"BUGWOOD", 7, 192683},
	{"LIBXMU", 6, 192684},
	{"SZENE", 5, 192685},
	{"AMANTES", 7, 192686},
	{"LYMPHOKINES", 11, 192687},
	{"GUIYANG", 7, 192688},
	{"SIMPLOT", 7, 192689},
	{"JAUNTS", 6, 192690},
	{"PYRIDINES", 9, 192691},
	{"SULFASALAZINE", 13, 192692},
	{"MISNER", 6, 192693},
	{"ORGEL", 5, 192694},
	{"CALISTHENICS", 12, 192695},
	{"MEDVEDEV", 8, 192696},
	{"NOFRILLS", 8, 192697},
	{"NEPHROTOXICITY", 14, 192698},
	{"KIRON", 5, 192699},
	{"IRESSA", 6, 192700},
	{"BOUCHES", 7, 192701},
	{"KELY", 4, 192702},
	{"PINWHEELS", 9, 192703},
	{"SHRINKABLE", 10, 192704},
	{"GRIJALVA", 8, 192705},
	{"SIDEMAN", 7, 192706},
	{"LUGG", 4, 192707},
	{"CAMOFLAUGE", 10, 192708},
	{"IDEALIZATION", 12, 192709},
	{"PESCHEL", 7, 192710},
	{"XREFS", 5, 192711},
	{"VLECK", 5, 192712},
	{"KOREY", 5, 192713},
	{"GENTLEMANS", 10, 192714},
	{"BRINEY", 6, 192715},
	{"CATGIRL", 7, 192716},
	{"AGGRESSIONS", 11, 192717},
	{"RGW", 3, 192718},
	{"LASTCHAR", 8, 192719},
	{"YAJOO", 5, 192720},
	{"ERINDALE", 8, 192721},
	{"RODWELL", 7, 192722},
	{"MAKERERE", 8, 192723},
	{"DEAKINS", 7, 192724},
	{"POWERUPS", 8, 192725},
	{"ROSENMAN", 8, 192726},
	{"LITIGATIONS", 11, 192727},
	{"TALLA", 5, 192728},
	{"SPECTACLED", 10, 192729},
	{"BOME", 4, 192730},
	{"YANOO", 5, 192731},
	{"DOMESTICUS", 10, 192732},
	{"DEGROOT", 7, 192733},
	{"OPCS", 4, 192734},
	{"CHOONG", 6, 192735},
	{"ACCME", 5, 192736},
	{"BRIGHTWOOD", 10, 192737},
	{"LRESULT", 7, 192738},
	{"BRUMBAUGH", 9, 192739},
	{"BOERNER", 7, 192740},
	{"HMMWV", 5, 192741},
	{"HABITABILITY", 12, 192742},
	{"GLASTRON", 8, 192743},
	{"TELEGRAPHED", 11, 192744},
	{"RESOUNDED", 9, 192745},
	{"TYRIE", 5, 192746},
	{"GALLIFREY", 9, 192747},
	{"MAMANDO", 7, 192748},
	{"HIWATT", 6, 192749},
	{"THERMOTOGA", 10, 192750},
	{"SOFTIES", 7, 192751},
	{"PIRI", 4, 192752},
	{"MICKLE", 6, 192753},
	{"GEILS", 5, 192754},
	{"CLUBBY", 6, 192755},
	{"FIAMMA", 6, 192756},
	{"YUONG", 5, 192757},
	{"NACD", 4, 192758},
	{"MUDA", 4, 192759},
	{"HALIAEETUS", 10, 192760},
	{"SNEEK", 5, 192761},
	{"DUZE", 4, 192762},
	{"REWINDS", 7, 192763},
	{"TRANSFIRMER", 11, 192764},
	{"PRENOM", 6, 192765},
	{"XPU", 3, 192766},
	{"DESROCHERS", 10, 192767},
	{"FLAMEBAIT", 9, 192768},
	{"TRUCKSTOP", 9, 192769},
	{"SAGACIOUS", 9, 192770},
	{"ALLROUNDER", 10, 192771},
	{"ELIBRON", 7, 192772},
	{"PATRONEN", 8, 192773},
	{"DONENESS", 8, 192774},
	{"ODGE", 4, 192775},
	{"CYBILL", 6, 192776},
	{"BOUFFARD", 8, 192777},
	{"PUCO", 4, 192778},
	{"NAFSA", 5, 192779},
	{"YKOM", 4, 192780},
	{"VSBR", 4, 192781},
	{"UUNL", 4, 192782},
	{"UBCE", 4, 192783},
	{"SYPU", 4, 192784},
	{"SPBU", 4, 192785},
	{"SIXJ", 4, 192786},
	{"PYEV", 4, 192787},
	{"POTV", 4, 192788},
	{"PEYR", 4, 192789},
	{"OPPM", 4, 192790},
	{"NYAZ", 4, 192791},
	{"NKUH", 4, 192792},
	{"MGAB", 4, 192793},
	{"LOMM", 4, 192794},
	{"KCIN", 4, 192795},
	{"JINP", 4, 192796},
	{"JAYK", 4, 192797},
	{"IOFK", 4, 192798},
	{"IKUC", 4, 192799},
	{"GMRB", 4, 192800},
	{"FPAW", 4, 192801},
	{"FLSI", 4, 192802},
	{"EKYE", 4, 192803},
	{"DZHE", 4, 192804},
	{"DBAF", 4, 192805},
	{"COGL", 4, 192806},
	{"AXRI", 4, 192807},
	{"AXOU", 4, 192808},
	{"AERR", 4, 192809},
	{"HANDPRINTS", 10, 192810},
	{"MORALISTS", 9, 192811},
	{"INSULA", 6, 192812},
	{"CRESSY", 6, 192813},
	{"ABIMELECH", 9, 192814},
	{"MAXIMALE", 8, 192815},
	{"CREVIER", 7, 192816},
	{"SCHERR", 6, 192817},
	{"MAYBURY", 7, 192818},
	{"APARENTLY", 9, 192819},
	{"ONDARY", 6, 192820},
	{"STITES", 6, 192821},
	{"WEBLEY", 6, 192822},
	{"WAIALUA", 7, 192823},
	{"PSINET", 6, 192824},
	{"MACINTOUCH", 10, 192825},
	{"FNUMBER", 7, 192826},
	{"DUHON", 5, 192827},
	{"DAMASIO", 7, 192828},
	{"ARDAGH", 6, 192829},
	{"RIAZ", 4, 192830},
	{"ARACHNOID", 9, 192831},
	{"ROLLINGSTONE", 12, 192832},
	{"PROSTITUIEREN", 13, 192833},
	{"PROBAB", 6, 192834},
	{"EVERLONG", 8, 192835},
	{"VALISE", 6, 192836},
	{"NASTURTIUM", 10, 192837},
	{"CRESWICK", 8, 192838},
	{"ROMINE", 6, 192839},
	{"KOMANDO", 7, 192840},
	{"CCBILL", 6, 192841},
	{"STOTIES", 7, 192842},
	{"MICROFILTRATION", 15, 192843},
	{"LYCO", 4, 192844},
	{"COMMENTSCATEGORY", 16, 192845},
	{"SHAHRAM", 7, 192846},
	{"DATBLYGIAD", 10, 192847},
	{"REDIRECTCGIQUERY", 16, 192848},
	{"RECIPEFACTS", 11, 192849},
	{"PROMPTER", 8, 192850},
	{"PROVINCIALS", 11, 192851},
	{"PALLETTE", 8, 192852},
	{"NEWSJUNKIE", 10, 192853},
	{"NEATSUITE", 9, 192854},
	{"THEISEN", 7, 192855},
	{"HIRSUTISM", 9, 192856},
	{"DISTAFF", 7, 192857},
	{"YOUSAVE", 7, 192858},
	{"CLEARCOAT", 9, 192859},
	{"BESPECTACLED", 12, 192860},
	{"BULKIER", 7, 192861},
	{"BILLARDS", 8, 192862},
	{"FACA", 4, 192863},
	{"REDUCERE", 8, 192864},
	{"MESANGIAL", 9, 192865},
	{"MUGWORT", 7, 192866},
	{"TELESCOP", 8, 192867},
	{"CHISQ", 5, 192868},
	{"STARLAND", 8, 192869},
	{"BALC", 4, 192870},
	{"SPENCERPORT", 11, 192871},
	{"SPINORS", 7, 192872},
	{"DIETHYLPROPRION", 15, 192873},
	{"RAGGING", 7, 192874},
	{"CVL", 3, 192875},
	{"WINTERBERG", 10, 192876},
	{"COLLECTIF", 9, 192877},
	{"COLOMBIANA", 10, 192878},
	{"WOODBERRY", 9, 192879},
	{"WORDE", 5, 192880},
	{"ANNUNCIATOR", 11, 192881},
	{"CARRICO", 7, 192882},
	{"GOLDPOINTS", 10, 192883},
	{"DIGITISING", 10, 192884},
	{"FACEOFFS", 8, 192885},
	{"MANDERSON", 9, 192886},
	{"FICKER", 6, 192887},
	{"LENTES", 6, 192888},
	{"IMBIBE", 6, 192889},
	{"QFD", 3, 192890},
	{"LORIDA", 6, 192891},
	{"CADRS", 5, 192892},
	{"CARCOMM", 7, 192893},
	{"STUDYSTACK", 10, 192894},
	{"ONFERENCE", 9, 192895},
	{"TULLIS", 6, 192896},
	{"STEELEYE", 8, 192897},
	{"HOSTETTER", 9, 192898},
	{"FOOTBALLNCAA", 12, 192899},
	{"HISSES", 6, 192900},
	{"MULESHOE", 8, 192901},
	{"GARCON", 6, 192902},
	{"ACMA", 4, 192903},
	{"MICHLMAYR", 9, 192904},
	{"SQUADRA", 7, 192905},
	{"ASCENDERS", 9, 192906},
	{"ZWHA", 4, 192907},
	{"ZOUA", 4, 192908},
	{"ZOFA", 4, 192909},
	{"YUPU", 4, 192910},
	{"YBIE", 4, 192911},
	{"TEZW", 4, 192912},
	{"PDTO", 4, 192913},
	{"OYDJ", 4, 192914},
	{"OJAD", 4, 192915},
	{"NYKR", 4, 192916},
	{"NMRE", 4, 192917},
	{"MLFI", 4, 192918},
	{"MIXH", 4, 192919},
	{"KPHY", 4, 192920},
	{"JETR", 4, 192921},
	{"IDYU", 4, 192922},
	{"ICOJ", 4, 192923},
	{"HULC", 4, 192924},
	{"FYOS", 4, 192925},
	{"FTUI", 4, 192926},
	{"EZOB", 4, 192927},
	{"EYZE", 4, 192928},
	{"EEGM", 4, 192929},
	{"DNDP", 4, 192930},
	{"DEYU", 4, 192931},
	{"CPME", 4, 192932},
	{"CMPU", 4, 192933},
	{"CDUN", 4, 192934},
	{"AUKO", 4, 192935},
	{"AMYK", 4, 192936},
	{"AMDH", 4, 192937},
	{"AGYP", 4, 192938},
	{"AGDR", 4, 192939},
	{"WEBEDITOR", 9, 192940},
	{"RADWARE", 7, 192941},
	{"PREFIXING", 9, 192942},
	{"AUTHORI", 7, 192943},
	{"AEROLITE", 8, 192944},
	{"YAMANE", 6, 192945},
	{"BRONCHODILATORS", 15, 192946},
	{"HINZE", 5, 192947},
	{"TALLENT", 7, 192948},
	{"BASHKORTOSTAN", 13, 192949},
	{"DOEL", 4, 192950},
	{"CHERUBINI", 9, 192951},
	{"MASHBURN", 8, 192952},
	{"HEPATOBILIARY", 13, 192953},
	{"HUDNALL", 7, 192954},
	{"ATIME", 5, 192955},
	{"NOZICK", 6, 192956},
	{"BODDEN", 6, 192957},
	{"STREETFIGHTER", 13, 192958},
	{"PRIMELOCATION", 13, 192959},
	{"FRIESE", 6, 192960},
	{"PROPPER", 7, 192961},
	{"FREUDE", 6, 192962},
	{"WAIHI", 5, 192963},
	{"UFSD", 4, 192964},
	{"MEEM", 4, 192965},
	{"EZPRO", 5, 192966},
	{"EVETT", 5, 192967},
	{"ADELBODEN", 9, 192968},
	{"ETYMOLOGIES", 11, 192969},
	{"BARNARDO", 8, 192970},
	{"SIBU", 4, 192971},
	{"POLYNEUROPATHY", 14, 192972},
	{"KONKURRENT", 10, 192973},
	{"BOGDANOVICH", 11, 192974},
	{"ZAHARA", 6, 192975},
	{"REDUCERI", 8, 192976},
	{"LOMBOZ", 6, 192977},
	{"CALULATOR", 9, 192978},
	{"ACETONIDE", 9, 192979},
	{"NITROPHENYL", 11, 192980},
	{"BLOOMINGDALES", 13, 192981},
	{"MAGLE", 5, 192982},
	{"EGGMAN", 6, 192983},
	{"APARTMENTLINKS", 14, 192984},
	{"EXCEDRIN", 8, 192985},
	{"AENIMIAC", 8, 192986},
	{"GCVS", 4, 192987},
	{"DORNA", 5, 192988},
	{"GNAWED", 6, 192989},
	{"ALANSON", 7, 192990},
	{"KIMBERLING", 10, 192991},
	{"COREX", 5, 192992},
	{"OGHAM", 5, 192993},
	{"BORAS", 5, 192994},
	{"PAPERJET", 8, 192995},
	{"TOFFS", 5, 192996},
	{"MONOCYTIC", 9, 192997},
	{"LONGJMP", 7, 192998},
	{"LIGHTBLUE", 9, 192999},
	{"VBV", 3, 193000},
	{"MANIKINS", 8, 193001},
	{"BRUNELLE", 8, 193002},
	{"WALPAPER", 8, 193003},
	{"GALATIA", 7, 193004},
	{"CAGUAS", 6, 193005},
	{"CHUBBIES", 8, 193006},
	{"OUTAOUAIS", 9, 193007},
	{"WEHNER", 6, 193008},
	{"FRST", 4, 193009},
	{"WIDMARK", 7, 193010},
	{"TANITH", 6, 193011},
	{"PRESTOPUNDIT", 12, 193012},
	{"APPALLINGLY", 11, 193013},
	{"VHDCI", 5, 193014},
	{"LONGWELL", 8, 193015},
	{"HKCR", 4, 193016},
	{"FREDS", 5, 193017},
	{"ADDLOGIX", 8, 193018},
	{"CREAGER", 7, 193019},
	{"GALOPP", 6, 193020},
	{"HYPERNYMS", 9, 193021},
	{"IFICATION", 9, 193022},
	{"FRIIS", 5, 193023},
	{"IUFRO", 5, 193024},
	{"AUTOCLAVED", 10, 193025},
	{"SUPERBA", 7, 193026},
	{"ARISTOC", 7, 193027},
	{"SABRC", 5, 193028},
	{"KASICH", 6, 193029},
	{"VIANNEY", 7, 193030},
	{"USAFE", 5, 193031},
	{"PANDAHEAD", 9, 193032},
	{"FLARESIDE", 9, 193033},
	{"MASTALER", 8, 193034},
	{"BLACKBALL", 9, 193035},
	{"COMPOSI", 7, 193036},
	{"SANCTA", 6, 193037},
	{"PRABHA", 6, 193038},
	{"TOLDE", 5, 193039},
	{"CLATTERING", 10, 193040},
	{"PHALLIX", 7, 193041},
	{"SYNGE", 5, 193042},
	{"CYBERCOMM", 9, 193043},
	{"SUCHAS", 6, 193044},
	{"COLLINWOOD", 10, 193045},
	{"ZESK", 4, 193046},
	{"XBAL", 4, 193047},
	{"WWSO", 4, 193048},
	{"VUJA", 4, 193049},
	{"UZAW", 4, 193050},
	{"UAYU", 4, 193051},
	{"SSVU", 4, 193052},
	{"SGLY", 4, 193053},
	{"SBCE", 4, 193054},
	{"PELY", 4, 193055},
	{"OZIC", 4, 193056},
	{"OMSJ", 4, 193057},
	{"OMML", 4, 193058},
	{"OICP", 4, 193059},
	{"NOGD", 4, 193060},
	{"NGXA", 4, 193061},
	{"KYWR", 4, 193062},
	{"IDKL", 4, 193063},
	{"HYIR", 4, 193064},
	{"HUAF", 4, 193065},
	{"GREO", 4, 193066},
	{"EVEX", 4, 193067},
	{"CGUR", 4, 193068},
	{"BYJR", 4, 193069},
	{"BCHU", 4, 193070},
	{"AMMH", 4, 193071},
	{"AHUK", 4, 193072},
	{"NIJHOFF", 7, 193073},
	{"PARIER", 6, 193074},
	{"CARTMEL", 7, 193075},
	{"BOOGLE", 6, 193076},
	{"PICTURSE", 8, 193077},
	{"BILLEDE", 7, 193078},
	{"TRAITE", 6, 193079},
	{"CELEBOPEDIA", 11, 193080},
	{"INTERTOTO", 9, 193081},
	{"PKGADD", 6, 193082},
	{"BLKD", 4, 193083},
	{"STEPLADDER", 10, 193084},
	{"CLARIANT", 8, 193085},
	{"PRISCO", 6, 193086},
	{"ERHOEHEN", 8, 193087},
	{"ABOGADO", 7, 193088},
	{"BARRETTO", 8, 193089},
	{"BLEUS", 5, 193090},
	{"LAWERENCE", 9, 193091},
	{"NINIAN", 6, 193092},
	{"SONGTEXTS", 9, 193093},
	{"COMCARE", 7, 193094},
	{"REVERBERATING", 13, 193095},
	{"HERMENEUTICAL", 13, 193096},
	{"MOSEY", 5, 193097},
	{"SITUATING", 9, 193098},
	{"RANTES", 6, 193099},
	{"CMFCORE", 7, 193100},
	{"HELMETED", 8, 193101},
	{"CAMBIUM", 7, 193102},
	{"ARBEL", 5, 193103},
	{"HEADRICK", 8, 193104},
	{"WATCHFIRE", 9, 193105},
	{"PENETRANCE", 10, 193106},
	{"NESTREF", 7, 193107},
	{"BOOBBS", 6, 193108},
	{"ODAC", 4, 193109},
	{"FALLOT", 6, 193110},
	{"CARROUSEL", 9, 193111},
	{"VPOP", 4, 193112},
	{"FFFEFFFF", 8, 193113},
	{"STENOGRAPHIC", 12, 193114},
	{"TAGLIABUE", 9, 193115},
	{"STEPHANI", 8, 193116},
	{"ISTIC", 5, 193117},
	{"LAGA", 4, 193118},
	{"VANIA", 5, 193119},
	{"DEXTROAMPHETAMINE", 17, 193120},
	{"APOFASH", 7, 193121},
	{"DOLA", 4, 193122},
	{"ESIGNAL", 7, 193123},
	{"COMMANDES", 9, 193124},
	{"BARCHE", 6, 193125},
	{"MOUSEPLANET", 11, 193126},
	{"KOROLEV", 7, 193127},
	{"INTREPIDS", 9, 193128},
	{"VILLERS", 7, 193129},
	{"PUBIS", 5, 193130},
	{"OLLER", 5, 193131},
	{"LANTRA", 6, 193132},
	{"KVETCH", 6, 193133},
	{"VANNI", 5, 193134},
	{"MRW", 3, 193135},
	{"BINATION", 8, 193136},
	{"JMOB", 4, 193137},
	{"HAIRSTREAK", 10, 193138},
	{"GRONHOLM", 8, 193139},
	{"GUAMANIAN", 9, 193140},
	{"DEMOCRACIA", 10, 193141},
	{"MEWTWO", 6, 193142},
	{"ZOMBI", 5, 193143},
	{"RUMPOLE", 7, 193144},
	{"GALLSTONE", 9, 193145},
	{"WALDWICK", 8, 193146},
	{"KOKB", 4, 193147},
	{"HODES", 5, 193148},
	{"CHECA", 5, 193149},
	{"AKCJI", 5, 193150},
	{"CALIN", 5, 193151},
	{"ZOELLER", 7, 193152},
	{"VODAVI", 6, 193153},
	{"MOHSIN", 6, 193154},
	{"YAGOTTA", 7, 193155},
	{"HARNONCOURT", 11, 193156},
	{"VEXCOM", 6, 193157},
	{"INCOMPARABLY", 12, 193158},
	{"ABELEMENT", 9, 193159},
	{"UNCC", 4, 193160},
	{"METABASE", 8, 193161},
	{"BUNNYKINS", 9, 193162},
	{"JAQUITH", 7, 193163},
	{"VANDERMEER", 10, 193164},
	{"TIJDSCHR", 8, 193165},
	{"GRPS", 4, 193166},
	{"SMARTMOVIE", 10, 193167},
	{"MATRIXES", 8, 193168},
	{"ALIBHAI", 7, 193169},
	{"YPMI", 4, 193170},
	{"WDIT", 4, 193171},
	{"UKOA", 4, 193172},
	{"TTJR", 4, 193173},
	{"TMLT", 4, 193174},
	{"SULZ", 4, 193175},
	{"RYAZ", 4, 193176},
	{"RSPP", 4, 193177},
	{"RSGH", 4, 193178},
	{"RRII", 4, 193179},
	{"RBAZ", 4, 193180},
	{"RARW", 4, 193181},
	{"OZHU", 4, 193182},
	{"OPMP", 4, 193183},
	{"OIDJ", 4, 193184},
	{"OAPY", 4, 193185},
	{"NLLE", 4, 193186},
	{"MPYT", 4, 193187},
	{"ILTZ", 4, 193188},
	{"GVAM", 4, 193189},
	{"GNRO", 4, 193190},
	{"GAOG", 4, 193191},
	{"EYJI", 4, 193192},
	{"DEVG", 4, 193193},
	{"BPTH", 4, 193194},
	{"BOTV", 4, 193195},
	{"AEGR", 4, 193196},
	{"AAUR", 4, 193197},
	{"RIPP", 4, 193198},
	{"IOSTAT", 6, 193199},
	{"ESTONIANS", 9, 193200},
	{"ELLADAS", 7, 193201},
	{"ARRAYTYPE", 9, 193202},
	{"RECUSED", 7, 193203},
	{"FRAHM", 5, 193204},
	{"SPEAKERCABLE", 12, 193205},
	{"XYMOX", 5, 193206},
	{"RESTUARANTS", 11, 193207},
	{"GUADALOUPE", 10, 193208},
	{"DIGESTERS", 9, 193209},
	{"BCANS", 5, 193210},
	{"ZINIO", 5, 193211},
	{"SWELLENDAM", 10, 193212},
	{"SAVERIO", 7, 193213},
	{"TENCEL", 6, 193214},
	{"THALASSAEMIA", 12, 193215},
	{"EPCS", 4, 193216},
	{"BEARSKIN", 8, 193217},
	{"PROLOGIC", 8, 193218},
	{"PRIDDIS", 7, 193219},
	{"PRANG", 5, 193220},
	{"RATHERGATE", 10, 193221},
	{"GASPARILLA", 10, 193222},
	{"GENIUNE", 7, 193223},
	{"ERRORHANDLER", 12, 193224},
	{"GRANER", 6, 193225},
	{"SEQUESTERING", 12, 193226},
	{"SUNVTS", 6, 193227},
	{"TRAPPIST", 8, 193228},
	{"STEGMANN", 8, 193229},
	{"RONNA", 5, 193230},
	{"POWEL", 5, 193231},
	{"NCODE", 5, 193232},
	{"DOGPOUND", 8, 193233},
	{"MAMACITA", 8, 193234},
	{"AKMA", 4, 193235},
	{"EXFOLIATORS", 11, 193236},
	{"BEARMAN", 7, 193237},
	{"TRADUZIONI", 10, 193238},
	{"MASKELL", 7, 193239},
	{"SYSCALLS", 8, 193240},
	{"AKMAL", 5, 193241},
	{"UACC", 4, 193242},
	{"BONFERRONI", 10, 193243},
	{"BIJECTIVE", 9, 193244},
	{"YOHAN", 5, 193245},
	{"SALLALLAHU", 10, 193246},
	{"ONITOR", 6, 193247},
	{"PASCUA", 6, 193248},
	{"FFFBFFFF", 8, 193249},
	{"DIGILUX", 7, 193250},
	{"AGRICOLES", 9, 193251},
	{"GADAMER", 7, 193252},
	{"XTINE", 5, 193253},
	{"SINEWAVE", 8, 193254},
	{"FFFDFFFF", 8, 193255},
	{"ACTERISTICS", 11, 193256},
	{"FEHER", 5, 193257},
	{"EIONET", 6, 193258},
	{"DIMITAR", 7, 193259},
	{"LUMICON", 7, 193260},
	{"MONSTERCOCK", 11, 193261},
	{"BHALLA", 6, 193262},
	{"PELLSTON", 8, 193263},
	{"TROUBLESHOOTERS", 15, 193264},
	{"FFFCFFFF", 8, 193265},
	{"FLEISS", 6, 193266},
	{"NLMISC", 6, 193267},
	{"CONSULTEZ", 9, 193268},
	{"DSCM", 4, 193269},
	{"MCBEAN", 6, 193270},
	{"ALLANOL", 7, 193271},
	{"PLETT", 5, 193272},
	{"BERSHIP", 7, 193273},
	{"ROMANTICIZED", 12, 193274},
	{"ENDSUBSECTION", 13, 193275},
	{"REVIS", 5, 193276},
	{"GENSAP", 6, 193277},
	{"FINTAN", 6, 193278},
	{"ECONOMISCHE", 11, 193279},
	{"AMITABHA", 8, 193280},
	{"PHOTOJOURNAL", 12, 193281},
	{"LEONES", 6, 193282},
	{"VALDECOXIB", 10, 193283},
	{"SETTORE", 7, 193284},
	{"MNEMOSYNE", 9, 193285},
	{"DEMURRER", 8, 193286},
	{"CONTINUOS", 9, 193287},
	{"TARQUIN", 7, 193288},
	{"ORIGINEEL", 9, 193289},
	{"MANIPAL", 7, 193290},
	{"TIVENESS", 8, 193291},
	{"MICKIEWICZ", 10, 193292},
	{"ELENITE", 7, 193293},
	{"TERMIDOR", 8, 193294},
	{"RYDYCH", 6, 193295},
	{"RIPENS", 6, 193296},
	{"TWWLY", 5, 193297},
	{"CUKOR", 5, 193298},
	{"BIBREF", 6, 193299},
	{"PICTYRES", 8, 193300},
	{"SANTACRUZ", 9, 193301},
	{"ENLIGHTENS", 10, 193302},
	{"DUDDY", 5, 193303},
	{"TELEPROMPTER", 12, 193304},
	{"STIGMAS", 7, 193305},
	{"INTELECTUAL", 11, 193306},
	{"DESTRUCTIVELY", 13, 193307},
	{"TWOFISH", 7, 193308},
	{"KUONI", 5, 193309},
	{"IMCO", 4, 193310},
	{"DARUNTER", 8, 193311},
	{"ICARD", 5, 193312},
	{"FRAND", 5, 193313},
	{"YSSQ", 4, 193314},
	{"XITD", 4, 193315},
	{"WSGU", 4, 193316},
	{"VSPL", 4, 193317},
	{"UBNI", 4, 193318},
	{"TZBO", 4, 193319},
	{"TUGH", 4, 193320},
	{"RMCF", 4, 193321},
	{"RLTE", 4, 193322},
	{"PUZH", 4, 193323},
	{"PIKY", 4, 193324},
	{"OTYC", 4, 193325},
	{"MLAA", 4, 193326},
	{"LLPT", 4, 193327},
	{"LKAU", 4, 193328},
	{"LCDD", 4, 193329},
	{"KRIK", 4, 193330},
	{"JABP", 4, 193331},
	{"IXPU", 4, 193332},
	{"IULL", 4, 193333},
	{"GYMM", 4, 193334},
	{"GYCU", 4, 193335},
	{"EZSL", 4, 193336},
	{"EXUL", 4, 193337},
	{"EJCI", 4, 193338},
	{"ECEY", 4, 193339},
	{"EBMC", 4, 193340},
	{"DUAA", 4, 193341},
	{"DAIV", 4, 193342},
	{"BOUA", 4, 193343},
	{"BETD", 4, 193344},
	{"BDRO", 4, 193345},
	{"ATPF", 4, 193346},
	{"AHUC", 4, 193347},
	{"BENARES", 7, 193348},
	{"IMBODEN", 7, 193349},
	{"CLOSECLOSE", 10, 193350},
	{"MONTALBANO", 10, 193351},
	{"SCHEIDER", 8, 193352},
	{"PROMOTII", 8, 193353},
	{"DELMAN", 6, 193354},
	{"RECITATIVE", 10, 193355},
	{"POZNYAKOFF", 10, 193356},
	{"IMPORTANTS", 10, 193357},
	{"ALBINI", 6, 193358},
	{"FACTOTUM", 8, 193359},
	{"ULTRALIGHTS", 11, 193360},
	{"HANDSIGNED", 10, 193361},
	{"ALMARIA", 7, 193362},
	{"CIRCUITED", 9, 193363},
	{"HAIKOU", 6, 193364},
	{"CONTERMINOUS", 12, 193365},
	{"BRAHM", 5, 193366},
	{"IONAL", 5, 193367},
	{"ROCKCASTLE", 10, 193368},
	{"NOCICEPTIVE", 11, 193369},
	{"CIRURGIA", 8, 193370},
	{"MAKEING", 7, 193371},
	{"IMPRESE", 7, 193372},
	{"MISSBRAUCH", 10, 193373},
	{"LOVELADY", 8, 193374},
	{"KERF", 4, 193375},
	{"CUETO", 5, 193376},
	{"INSTITUTS", 9, 193377},
	{"SALAMAT", 7, 193378},
	{"LEUCOCYTE", 9, 193379},
	{"BIBLIOTEKA", 10, 193380},
	{"RISKGRADE", 9, 193381},
	{"KERAMIK", 7, 193382},
	{"BOSCOMBE", 8, 193383},
	{"STENGER", 7, 193384},
	{"LCSC", 4, 193385},
	{"HOMESTEADERS", 12, 193386},
	{"BLANKIE", 7, 193387},
	{"FOXFAN", 6, 193388},
	{"MAROULIS", 8, 193389},
	{"MMUSIC", 6, 193390},
	{"CHARISSE", 8, 193391},
	{"ROTHBERG", 8, 193392},
	{"AXPER", 5, 193393},
	{"BESTMOBILE", 10, 193394},
	{"KAJOL", 5, 193395},
	{"ZOAR", 4, 193396},
	{"FORSEEABLE", 10, 193397},
	{"KAZEMI", 6, 193398},
	{"FRETWELL", 8, 193399},
	{"BARLEYCORN", 10, 193400},
	{"SCREECHED", 9, 193401},
	{"SUBBING", 7, 193402},
	{"GOFEMININ", 9, 193403},
	{"ECOURSE", 7, 193404},
	{"DIFFRACTED", 10, 193405},
	{"TYUMEN", 6, 193406},
	{"SCHIZOAFFECTIVE", 15, 193407},
	{"LAVANDULA", 9, 193408},
	{"NGALA", 5, 193409},
	{"ARROWOOD", 8, 193410},
	{"VIDEOCAMS", 9, 193411},
	{"QUALSTAR", 8, 193412},
	{"UDL", 3, 193413},
	{"GSMP", 4, 193414},
	{"IPODDERX", 8, 193415},
	{"MATROID", 7, 193416},
	{"THEORETICIANS", 13, 193417},
	{"OBSD", 4, 193418},
	{"MICROPAYMENTS", 13, 193419},
	{"INFOCENTRE", 10, 193420},
	{"WHERRY", 6, 193421},
	{"WHACKS", 6, 193422},
	{"QUARE", 5, 193423},
	{"BRAINSTORMED", 12, 193424},
	{"SWIMING", 7, 193425},
	{"ANSWERBOOK", 10, 193426},
	{"GUZZLES", 7, 193427},
	{"MACCABEE", 8, 193428},
	{"SCAQMD", 6, 193429},
	{"CING", 4, 193430},
	{"GRANULOMATOSIS", 14, 193431},
	{"LAVALLEE", 8, 193432},
	{"CENTIPEDES", 10, 193433},
	{"SUNBUCKLE", 9, 193434},
	{"RPAAN", 5, 193435},
	{"GRANDA", 6, 193436},
	{"ACDBSPLINE", 10, 193437},
	{"ABARE", 5, 193438},
	{"ITSEC", 5, 193439},
	{"ETIOLOGIES", 10, 193440},
	{"PRMD", 4, 193441},
	{"ANTICIPATIONS", 13, 193442},
	{"INABA", 5, 193443},
	{"PEYSER", 6, 193444},
	{"GRASSROOTSPA", 12, 193445},
	{"MELTER", 6, 193446},
	{"CCTA", 4, 193447},
	{"FREIZEITNUTTE", 13, 193448},
	{"SYNCROS", 7, 193449},
	{"SWIFTY", 6, 193450},
	{"HANKEY", 6, 193451},
	{"EUSTACHIAN", 10, 193452},
	{"ERICE", 5, 193453},
	{"MTEXTBEGIN", 10, 193454},
	{"COCKK", 5, 193455},
	{"MTEXTEND", 8, 193456},
	{"OSLASH", 6, 193457},
	{"DETERMINEDLY", 12, 193458},
	{"EICHELBERGER", 12, 193459},
	{"CORRESPONDANT", 13, 193460},
	{"JOBZ", 4, 193461},
	{"IMPUESTOS", 9, 193462},
	{"CARIS", 5, 193463},
	{"VIRONMENT", 9, 193464},
	{"DEBAT", 5, 193465},
	{"CALAMITOUS", 10, 193466},
	{"GETY", 4, 193467},
	{"STRIPY", 6, 193468},
	{"WALDER", 6, 193469},
	{"PREETI", 6, 193470},
	{"CUBISIA", 7, 193471},
	{"DOTSTER", 7, 193472},
	{"YPMP", 4, 193473},
	{"XONJ", 4, 193474},
	{"WIPA", 4, 193475},
	{"UMWR", 4, 193476},
	{"UKAE", 4, 193477},
	{"UDGR", 4, 193478},
	{"RWIK", 4, 193479},
	{"RVOM", 4, 193480},
	{"RUZD", 4, 193481},
	{"OKKO", 4, 193482},
	{"OERM", 4, 193483},
	{"NJRR", 4, 193484},
	{"NCPO", 4, 193485},
	{"LNSC", 4, 193486},
	{"LAZH", 4, 193487},
	{"LAVC", 4, 193488},
	{"KMYP", 4, 193489},
	{"JONJ", 4, 193490},
	{"HYOV", 4, 193491},
	{"HYAU", 4, 193492},
	{"HLYY", 4, 193493},
	{"HLGR", 4, 193494},
	{"GEVS", 4, 193495},
	{"FWIE", 4, 193496},
	{"FEYI", 4, 193497},
	{"ENCZ", 4, 193498},
	{"EBGA", 4, 193499},
	{"CTIP", 4, 193500},
	{"CDCH", 4, 193501},
	{"CATK", 4, 193502},
	{"BMIG", 4, 193503},
	{"ARKQ", 4, 193504},
	{"AKMY", 4, 193505},
	{"RENISHAW", 8, 193506},
	{"SHUTTLED", 8, 193507},
	{"DCAA", 4, 193508},
	{"ELODIE", 6, 193509},
	{"WETTON", 6, 193510},
	{"PRIA", 4, 193511},
	{"ORGASEM", 7, 193512},
	{"MCGUFFIN", 8, 193513},
	{"KOGARAH", 7, 193514},
	{"CONDYLE", 7, 193515},
	{"PAYCHEX", 7, 193516},
	{"WORLDSPACE", 10, 193517},
	{"CRISTATA", 8, 193518},
	{"JUSTY", 5, 193519},
	{"ZARI", 4, 193520},
	{"LACUNAE", 7, 193521},
	{"CYMDEITHAS", 10, 193522},
	{"SPINOSA", 7, 193523},
	{"KARLOVO", 7, 193524},
	{"DONATELLA", 9, 193525},
	{"NORMANBY", 8, 193526},
	{"WNPP", 4, 193527},
	{"SHOESOURCE", 10, 193528},
	{"CHITTENANGO", 11, 193529},
	{"TRICHODERMA", 11, 193530},
	{"BAMES", 5, 193531},
	{"HOPLAND", 7, 193532},
	{"STARTELEMENT", 12, 193533},
	{"CHRISS", 6, 193534},
	{"HUGHIE", 6, 193535},
	{"SUBMATRIX", 9, 193536},
	{"PENICUIK", 8, 193537},
	{"EGLI", 4, 193538},
	{"MOPPED", 6, 193539},
	{"EPCGLOBAL", 9, 193540},
	{"WORKMANLIKE", 11, 193541},
	{"SPLUS", 5, 193542},
	{"SCHWEIZERISCHE", 14, 193543},
	{"SCENCE", 6, 193544},
	{"AFDB", 4, 193545},
	{"ELASTO", 6, 193546},
	{"COLESHILL", 9, 193547},
	{"FASION", 6, 193548},
	{"BELGISCHE", 9, 193549},
	{"SACRILEGIOUS", 12, 193550},
	{"CLICKSTREAM", 11, 193551},
	{"ACHILL", 6, 193552},
	{"RYLANDS", 7, 193553},
	{"GOMPERS", 7, 193554},
	{"BONDER", 6, 193555},
	{"MTBR", 4, 193556},
	{"BUTKUS", 6, 193557},
	{"CHASERGOLD", 10, 193558},
	{"BISOPROLOL", 10, 193559},
	{"RAFM", 4, 193560},
	{"LEIKO", 5, 193561},
	{"BEECHMONT", 9, 193562},
	{"APLICATION", 10, 193563},
	{"PRECOMPUTED", 11, 193564},
	{"FATUOUS", 7, 193565},
	{"EMPOLI", 6, 193566},
	{"ARMATRADING", 11, 193567},
	{"RULETA", 6, 193568},
	{"LAFITE", 6, 193569},
	{"ULTA", 4, 193570},
	{"FICHA", 5, 193571},
	{"DUPS", 4, 193572},
	{"THORNTONS", 9, 193573},
	{"SPEEZE", 6, 193574},
	{"POWERHEAD", 9, 193575},
	{"GALLIMORE", 9, 193576},
	{"STEVEO", 6, 193577},
	{"COINTELPRO", 10, 193578},
	{"SEPERATING", 10, 193579},
	{"GAMEJACK", 8, 193580},
	{"SYNCHRON", 8, 193581},
	{"SUSSKIND", 8, 193582},
	{"BUKKAKAE", 8, 193583},
	{"DEVWATCH", 8, 193584},
	{"WYKE", 4, 193585},
	{"ELAPSES", 7, 193586},
	{"ABELS", 5, 193587},
	{"SWFTEXTFIELD", 12, 193588},
	{"KORPELA", 7, 193589},
	{"JOBID", 5, 193590},
	{"CCAMP", 5, 193591},
	{"TASTIER", 7, 193592},
	{"PROTEINASES", 11, 193593},
	{"KABLOOM", 7, 193594},
	{"IIJIMA", 6, 193595},
	{"AIPORT", 6, 193596},
	{"FIOR", 4, 193597},
	{"SNAKEBITE", 9, 193598},
	{"EPASS", 5, 193599},
	{"ELOCUTION", 9, 193600},
	{"DOSANJH", 7, 193601},
	{"NUCOR", 5, 193602},
	{"FRLI", 4, 193603},
	{"ANTAGONIZED", 11, 193604},
	{"PLECTRUM", 8, 193605},
	{"SACCHARUM", 9, 193606},
	{"DEFNYDD", 7, 193607},
	{"BRONCHOPULMONARY", 16, 193608},
	{"OVERPLAYED", 10, 193609},
	{"AGILA", 5, 193610},
	{"ABUSO", 5, 193611},
	{"OAKLEAF", 7, 193612},
	{"HOMEDIR", 7, 193613},
	{"TITELS", 6, 193614},
	{"PREAH", 5, 193615},
	{"NYLE", 4, 193616},
	{"BOXFRESH", 8, 193617},
	{"THESERVERSIDE", 13, 193618},
	{"CILICIA", 7, 193619},
	{"HORAIRE", 7, 193620},
	{"GOERTZEL", 8, 193621},
	{"ZOVI", 4, 193622},
	{"YMOZ", 4, 193623},
	{"YHIB", 4, 193624},
	{"YBYZ", 4, 193625},
	{"WOLY", 4, 193626},
	{"USCP", 4, 193627},
	{"UIEL", 4, 193628},
	{"TURH", 4, 193629},
	{"TOKP", 4, 193630},
	{"TDAB", 4, 193631},
	{"SAFP", 4, 193632},
	{"RYRD", 4, 193633},
	{"RBYZ", 4, 193634},
	{"RAGF", 4, 193635},
	{"QIYA", 4, 193636},
	{"PYTA", 4, 193637},
	{"PYSP", 4, 193638},
	{"OYPI", 4, 193639},
	{"OXXI", 4, 193640},
	{"OFIZ", 4, 193641},
	{"NMRR", 4, 193642},
	{"NAKB", 4, 193643},
	{"MYOG", 4, 193644},
	{"MRSV", 4, 193645},
	{"MHAB", 4, 193646},
	{"LNSU", 4, 193647},
	{"LBSH", 4, 193648},
	{"KOVL", 4, 193649},
	{"JEKA", 4, 193650},
	{"IYOK", 4, 193651},
	{"IMPM", 4, 193652},
	{"IFPH", 4, 193653},
	{"GOWL", 4, 193654},
	{"GJOO", 4, 193655},
	{"EXKE", 4, 193656},
	{"ESMW", 4, 193657},
	{"EGGN", 4, 193658},
	{"DIXT", 4, 193659},
	{"DEKL", 4, 193660},
	{"DAUK", 4, 193661},
	{"BNWH", 4, 193662},
	{"BEMP", 4, 193663},
	{"AWOB", 4, 193664},
	{"AWEG", 4, 193665},
	{"AACU", 4, 193666},
	{"LYNAM", 5, 193667},
	{"JACKASSES", 9, 193668},
	{"BIRTHMOTHER", 11, 193669},
	{"SOFTLINE", 8, 193670},
	{"NONDENOMINATIONAL", 17, 193671},
	{"RETRACED", 8, 193672},
	{"HYPERPLANES", 11, 193673},
	{"HOTWOMEN", 8, 193674},
	{"CONTENTDM", 9, 193675},
	{"CILL", 4, 193676},
	{"SCRIPTURA", 9, 193677},
	{"MATATA", 6, 193678},
	{"MMPS", 4, 193679},
	{"MARKLAND", 8, 193680},
	{"SAPPERS", 7, 193681},
	{"ABELLA", 6, 193682},
	{"MARYKATE", 8, 193683},
	{"UNDERGARMENT", 12, 193684},
	{"SUBORBITAL", 10, 193685},
	{"SCHWA", 5, 193686},
	{"PHOSPHAGEN", 10, 193687},
	{"PRTBL", 5, 193688},
	{"JUDGESHIP", 9, 193689},
	{"FILETYPES", 9, 193690},
	{"GURDY", 5, 193691},
	{"SPYAGENT", 8, 193692},
	{"CLOUDCROFT", 10, 193693},
	{"CESARIA", 7, 193694},
	{"XPPEDIT", 7, 193695},
	{"REPUBIC", 7, 193696},
	{"SCHRANK", 7, 193697},
	{"DEECEE", 6, 193698},
	{"CLW", 3, 193699},
	{"VANDIVER", 8, 193700},
	{"WALDMANN", 8, 193701},
	{"TELLAYE", 7, 193702},
	{"VUOKKO", 6, 193703},
	{"REDLIGHT", 8, 193704},
	{"STARKWEATHER", 12, 193705},
	{"ENVELOPMENT", 11, 193706},
	{"PALLIATION", 10, 193707},
	{"BOLSHEVISM", 10, 193708},
	{"HYGENIC", 7, 193709},
	{"STURDIER", 8, 193710},
	{"MADANG", 6, 193711},
	{"KUNNE", 5, 193712},
	{"SASTRE", 6, 193713},
	{"MISANTHROPY", 11, 193714},
	{"MENINGIOMAS", 11, 193715},
	{"HOAGIE", 6, 193716},
	{"EXTEMPORANEOUS", 14, 193717},
	{"PROTRUDED", 9, 193718},
	{"IRLS", 4, 193719},
	{"HOLLING", 7, 193720},
	{"SALTZ", 5, 193721},
	{"ALRI", 4, 193722},
	{"FERONIA", 7, 193723},
	{"MADLUG", 6, 193724},
	{"DIMED", 5, 193725},
	{"VIRGIE", 6, 193726},
	{"CREU", 4, 193727},
	{"RENOVATOR", 9, 193728},
	{"RECANT", 6, 193729},
	{"KINGHORN", 8, 193730},
	{"TOFFLER", 7, 193731},
	{"RIVM", 4, 193732},
	{"PHYTOSTEROLS", 12, 193733},
	{"UKFF", 4, 193734},
	{"MEDRANO", 7, 193735},
	{"ESPERA", 6, 193736},
	{"CDOS", 4, 193737},
	{"GUSTAVSSON", 10, 193738},
	{"BEHEAD", 6, 193739},
	{"INCOMPETENCY", 12, 193740},
	{"YBARRA", 6, 193741},
	{"REPELLANTS", 10, 193742},
	{"EXERCI", 6, 193743},
	{"FLETT", 5, 193744},
	{"FLICKINGER", 10, 193745},
	{"MEBBE", 5, 193746},
	{"CARRIACOU", 9, 193747},
	{"PORATE", 6, 193748},
	{"ESTACIONES", 10, 193749},
	{"SUBVERSIONS", 11, 193750},
	{"MACGILL", 7, 193751},
	{"TAIPING", 7, 193752},
	{"IRREGARDLESS", 12, 193753},
	{"PLAINER", 7, 193754},
	{"SETBOUNDS", 9, 193755},
	{"UPDRAFT", 7, 193756},
	{"WIGHNOMY", 8, 193757},
	{"ARILD", 5, 193758},
	{"KRYSTLE", 7, 193759},
	{"CENTRISTS", 9, 193760},
	{"HOMUNCULUS", 10, 193761},
	{"CHAMBERMAID", 11, 193762},
	{"PHENTARAMINE", 12, 193763},
	{"LEAKAGES", 8, 193764},
	{"HOISIN", 6, 193765},
	{"FRESCOS", 7, 193766},
	{"SAPPING", 7, 193767},
	{"HEPATECTOMY", 11, 193768},
	{"LABRUM", 6, 193769},
	{"HAMMEN", 6, 193770},
	{"BRYGHT", 6, 193771},
	{"CHED", 4, 193772},
	{"ZCRE", 4, 193773},
	{"YSTV", 4, 193774},
	{"WWEU", 4, 193775},
	{"WNTY", 4, 193776},
	{"WNOD", 4, 193777},
	{"UTTV", 4, 193778},
	{"UOMT", 4, 193779},
	{"UKWO", 4, 193780},
	{"UJUT", 4, 193781},
	{"TKMT", 4, 193782},
	{"TAKW", 4, 193783},
	{"SWOB", 4, 193784},
	{"RMKE", 4, 193785},
	{"RCTU", 4, 193786},
	{"RAHV", 4, 193787},
	{"PPEB", 4, 193788},
	{"PMUT", 4, 193789},
	{"PCRY", 4, 193790},
	{"OWOK", 4, 193791},
	{"OGEV", 4, 193792},
	{"NXAV", 4, 193793},
	{"NPHD", 4, 193794},
	{"MOMR", 4, 193795},
	{"MLOD", 4, 193796},
	{"LKIF", 4, 193797},
	{"LIIM", 4, 193798},
	{"KRIF", 4, 193799},
	{"KALF", 4, 193800},
	{"JAMR", 4, 193801},
	{"IMJI", 4, 193802},
	{"HYWR", 4, 193803},
	{"HTUM", 4, 193804},
	{"GBOE", 4, 193805},
	{"FZOM", 4, 193806},
	{"FLYV", 4, 193807},
	{"FCDA", 4, 193808},
	{"EWNW", 4, 193809},
	{"EVSB", 4, 193810},
	{"ESDK", 4, 193811},
	{"EOJU", 4, 193812},
	{"EOCU", 4, 193813},
	{"ECGI", 4, 193814},
	{"DSUA", 4, 193815},
	{"CYGI", 4, 193816},
	{"CNUR", 4, 193817},
	{"ASMG", 4, 193818},
	{"AOBR", 4, 193819},
	{"JAGEX", 5, 193820},
	{"ZUJI", 4, 193821},
	{"TAGSET", 6, 193822},
	{"MEDITERRANEE", 12, 193823},
	{"WATERHEMP", 9, 193824},
	{"PATINKIN", 8, 193825},
	{"UNDIGESTED", 10, 193826},
	{"YOSHIYUKI", 9, 193827},
	{"SWITCHCRAFT", 11, 193828},
	{"PERFIDIOUS", 10, 193829},
	{"EREWASH", 7, 193830},
	{"CHOK", 4, 193831},
	{"BANDRIDGE", 9, 193832},
	{"NAKEDPICTURES", 13, 193833},
	{"BLUESTAR", 8, 193834},
	{"TOUCAM", 6, 193835},
	{"VOYAGING", 8, 193836},
	{"HUMILIATIONS", 12, 193837},
	{"ARCHANA", 7, 193838},
	{"ALCONA", 6, 193839},
	{"SELBORNE", 8, 193840},
	{"FACEMASK", 8, 193841},
	{"VCORE", 5, 193842},
	{"KYTHIRA", 7, 193843},
	{"WAQAR", 5, 193844},
	{"FARSIGHTEDNESS", 14, 193845},
	{"GOBASE", 6, 193846},
	{"CARDIOMYOCYTES", 14, 193847},
	{"NAPHTALI", 8, 193848},
	{"BISHOUJO", 8, 193849},
	{"UMBRAGE", 7, 193850},
	{"PSPACE", 6, 193851},
	{"PROCMAILRC", 10, 193852},
	{"NORTHCLIFFE", 11, 193853},
	{"MYLINKS", 7, 193854},
	{"MISLABELED", 10, 193855},
	{"BANNEKER", 8, 193856},
	{"FATIGUING", 9, 193857},
	{"AWAKING", 7, 193858},
	{"BLINDSIDED", 10, 193859},
	{"BICENTENARY", 11, 193860},
	{"GNOPPIX", 7, 193861},
	{"MONTMORILLONITE", 15, 193862},
	{"EPIRBS", 6, 193863},
	{"HFILL", 5, 193864},
	{"WATTLES", 7, 193865},
	{"LISTY", 5, 193866},
	{"EDPS", 4, 193867},
	{"ROSSBY", 6, 193868},
	{"RAMZY", 5, 193869},
	{"DANIELI", 7, 193870},
	{"OPERACION", 9, 193871},
	{"INTROVERSION", 12, 193872},
	{"BOUYER", 6, 193873},
	{"GILBEY", 6, 193874},
	{"CARX", 4, 193875},
	{"WENONAH", 7, 193876},
	{"CHUPANDO", 8, 193877},
	{"LAFLAMME", 8, 193878},
	{"DRAKA", 5, 193879},
	{"STRUTTURA", 9, 193880},
	{"TITEC", 5, 193881},
	{"SYLLA", 5, 193882},
	{"INTUOS", 6, 193883},
	{"INFORMAITON", 11, 193884},
	{"FRITTS", 6, 193885},
	{"CROSWELL", 8, 193886},
	{"ASTRING", 7, 193887},
	{"CHIEFLAND", 9, 193888},
	{"PRESENCIA", 9, 193889},
	{"ISOTROPY", 8, 193890},
	{"IPAQS", 5, 193891},
	{"GRAVELLE", 8, 193892},
	{"DRAGER", 6, 193893},
	{"PNEXTBOX", 8, 193894},
	{"BRITESMILE", 10, 193895},
	{"SPETSES", 7, 193896},
	{"PORTMANTEAU", 11, 193897},
	{"FEWS", 4, 193898},
	{"KLINISCHE", 9, 193899},
	{"IPKG", 4, 193900},
	{"CURENT", 6, 193901},
	{"PRUEBAS", 7, 193902},
	{"ARMAGETRON", 10, 193903},
	{"AMERIFIT", 8, 193904},
	{"ALCTS", 5, 193905},
	{"HIPPOLYTUS", 10, 193906},
	{"DANZ", 4, 193907},
	{"CAPITALISING", 12, 193908},
	{"BORSALINO", 9, 193909},
	{"TECNOLOGICO", 11, 193910},
	{"SPECTROPHOTOMETERS", 18, 193911},
	{"HOOVERPHONIC", 12, 193912},
	{"DERIDDER", 8, 193913},
	{"REJUVENATES", 11, 193914},
	{"MENZIESII", 9, 193915},
	{"PNGS", 4, 193916},
	{"WHANGANUI", 9, 193917},
	{"PORTERAGE", 9, 193918},
	{"ARCHITECTE", 10, 193919},
	{"HARBURG", 7, 193920},
	{"OREG", 4, 193921},
	{"FDTD", 4, 193922},
	{"MORALIST", 8, 193923},
	{"NATATORIUM", 10, 193924},
	{"LAMBERTI", 8, 193925},
	{"FARBE", 5, 193926},
	{"MCPARTLAND", 10, 193927},
	{"MEDIADATEN", 10, 193928},
	{"GEORGIO", 7, 193929},
	{"RODRIK", 6, 193930},
	{"VIJAYAN", 7, 193931},
	{"LEGERE", 6, 193932},
	{"BRITTISH", 8, 193933},
	{"ZYNG", 4, 193934},
	{"ZDEF", 4, 193935},
	{"YTOZ", 4, 193936},
	{"WNEQ", 4, 193937},
	{"WIAK", 4, 193938},
	{"UYGR", 4, 193939},
	{"URBB", 4, 193940},
	{"TCOY", 4, 193941},
	{"TBAF", 4, 193942},
	{"SAGM", 4, 193943},
	{"RNJI", 4, 193944},
	{"OUKH", 4, 193945},
	{"ORFD", 4, 193946},
	{"MBYK", 4, 193947},
	{"IMBM", 4, 193948},
	{"IKWO", 4, 193949},
	{"IEVW", 4, 193950},
	{"ICAQ", 4, 193951},
	{"FPEC", 4, 193952},
	{"FAMR", 4, 193953},
	{"EXOG", 4, 193954},
	{"EKFU", 4, 193955},
	{"ECEK", 4, 193956},
	{"DOWU", 4, 193957},
	{"DAKW", 4, 193958},
	{"CHUU", 4, 193959},
	{"CAZE", 4, 193960},
	{"BSTY", 4, 193961},
	{"AVSL", 4, 193962},
	{"AIMV", 4, 193963},
	{"SURFRAW", 7, 193964},
	{"SUPREMUM", 8, 193965},
	{"WOOOO", 5, 193966},
	{"LEECHING", 8, 193967},
	{"DEVENEZ", 7, 193968},
	{"HAYCOCK", 7, 193969},
	{"TOLUIDINE", 9, 193970},
	{"STYLEZ", 6, 193971},
	{"FREDO", 5, 193972},
	{"KIBITZING", 9, 193973},
	{"RELEASEDATE", 11, 193974},
	{"RAMBOUILLET", 11, 193975},
	{"TUBAC", 5, 193976},
	{"LIBDEX", 6, 193977},
	{"COUMARIN", 8, 193978},
	{"CNSC", 4, 193979},
	{"WOJTYLA", 7, 193980},
	{"SHAREDSTATEDIR", 14, 193981},
	{"ELIANE", 6, 193982},
	{"GRAMMAIRE", 9, 193983},
	{"TTDISPLAY", 9, 193984},
	{"TAGESZUGANG", 11, 193985},
	{"MOTORCYLE", 9, 193986},
	{"METHO", 5, 193987},
	{"JAHEIM", 6, 193988},
	{"SCATS", 5, 193989},
	{"AFFIRMANCE", 10, 193990},
	{"TORMENTORS", 10, 193991},
	{"EBARA", 5, 193992},
	{"ZVAL", 4, 193993},
	{"KOZOL", 5, 193994},
	{"DISTINCTNESS", 12, 193995},
	{"TEKENING", 8, 193996},
	{"WEBDATA", 7, 193997},
	{"NUDEPICTURE", 11, 193998},
	{"KULP", 4, 193999},
	{"WIDGEON", 7, 194000},
	{"LAPDANCE", 8, 194001},
	{"STRATEGIA", 9, 194002},
	{"NICATIONS", 9, 194003},
	{"INFOTECHSHOP", 12, 194004},
	{"WATC", 4, 194005},
	{"MACROLIDES", 10, 194006},
	{"LEPTONIC", 8, 194007},
	{"FEATUREFLASH", 12, 194008},
	{"NETZER", 6, 194009},
	{"MIXUP", 5, 194010},
	{"EXPIATION", 9, 194011},
	{"DELITE", 6, 194012},
	{"CRAWLY", 6, 194013},
	{"QUICKGO", 7, 194014},
	{"GRIDPP", 6, 194015},
	{"NALANDA", 7, 194016},
	{"FILEFORUM", 9, 194017},
	{"JARRET", 6, 194018},
	{"PARSEEXCEPTION", 14, 194019},
	{"FUNDABLE", 8, 194020},
	{"GRINSPOON", 9, 194021},
	{"KELLAN", 6, 194022},
	{"SPACESAVER", 10, 194023},
	{"ORNITHOLOGIST", 13, 194024},
	{"AZURITE", 7, 194025},
	{"ALONA", 5, 194026},
	{"MICMAC", 6, 194027},
	{"SPEZZA", 6, 194028},
	{"INSINUATION", 11, 194029},
	{"PHOTOPAINT", 10, 194030},
	{"MCGAVIN", 7, 194031},
	{"DAVO", 4, 194032},
	{"ZAMA", 4, 194033},
	{"INDEM", 5, 194034},
	{"QUASIPARTICLE", 13, 194035},
	{"OFFICEFURNITURE", 15, 194036},
	{"MPLA", 4, 194037},
	{"CHESKY", 6, 194038},
	{"PANTIEHOSE", 10, 194039},
	{"LOCHINVAR", 9, 194040},
	{"YIANNIS", 7, 194041},
	{"SANKEN", 6, 194042},
	{"MAUNDER", 7, 194043},
	{"LATERNE", 7, 194044},
	{"DANIELSSON", 10, 194045},
	{"AVODAH", 6, 194046},
	{"ALEHOUSE", 8, 194047},
	{"SERRATIA", 8, 194048},
	{"KRASS", 5, 194049},
	{"SPELUNKING", 10, 194050},
	{"COOMASSIE", 9, 194051},
	{"GARAGED", 7, 194052},
	{"LYNEHAM", 7, 194053},
	{"DETAINS", 7, 194054},
	{"GCCCC", 5, 194055},
	{"POCKETFUL", 9, 194056},
	{"POWERPLANTS", 11, 194057},
	{"MUTATES", 7, 194058},
	{"HAMERSLEY", 9, 194059},
	{"ZOFRAN", 6, 194060},
	{"DISCUSSIONE", 11, 194061},
	{"QUILLING", 8, 194062},
	{"ZEIGEFREUDIG", 12, 194063},
	{"PRACTICABILITY", 14, 194064},
	{"LAMMAS", 6, 194065},
	{"XPUZZLES", 8, 194066},
	{"GALLIE", 6, 194067},
	{"CATALLARCHY", 11, 194068},
	{"BKM", 3, 194069},
	{"EMPI", 4, 194070},
	{"DEEB", 4, 194071},
	{"TRANSCRIPTIONALLY", 17, 194072},
	{"HOLIDAYCITY", 11, 194073},
	{"DICAMILLO", 9, 194074},
	{"SWINDLER", 8, 194075},
	{"GALLA", 5, 194076},
	{"YMSF", 4, 194077},
	{"YLLK", 4, 194078},
	{"YBDE", 4, 194079},
	{"XIAM", 4, 194080},
	{"WJOS", 4, 194081},
	{"VTWI", 4, 194082},
	{"VSRO", 4, 194083},
	{"VEMV", 4, 194084},
	{"UZEA", 4, 194085},
	{"UCSW", 4, 194086},
	{"TSWU", 4, 194087},
	{"TIMY", 4, 194088},
	{"RYJR", 4, 194089},
	{"RMRD", 4, 194090},
	{"OKUH", 4, 194091},
	{"MLOY", 4, 194092},
	{"MIJI", 4, 194093},
	{"JRON", 4, 194094},
	{"JINB", 4, 194095},
	{"JIMU", 4, 194096},
	{"IMOY", 4, 194097},
	{"IKSB", 4, 194098},
	{"HROR", 4, 194099},
	{"GEIK", 4, 194100},
	{"GBAU", 4, 194101},
	{"FHIB", 4, 194102},
	{"FCYN", 4, 194103},
	{"EXOC", 4, 194104},
	{"EMRJ", 4, 194105},
	{"ELHY", 4, 194106},
	{"ECSD", 4, 194107},
	{"EAYR", 4, 194108},
	{"DUGD", 4, 194109},
	{"DKIA", 4, 194110},
	{"DDRK", 4, 194111},
	{"CVET", 4, 194112},
	{"BEXC", 4, 194113},
	{"AKYW", 4, 194114},
	{"STANDEN", 7, 194115},
	{"RORO", 4, 194116},
	{"GETLASTERROR", 12, 194117},
	{"YAEGER", 6, 194118},
	{"SOLLERS", 7, 194119},
	{"RAYCHEM", 7, 194120},
	{"OBJFILE", 7, 194121},
	{"LOCATELLI", 9, 194122},
	{"PSEG", 4, 194123},
	{"KNOBLAUCH", 9, 194124},
	{"CARDIA", 6, 194125},
	{"FIMBLES", 7, 194126},
	{"PUTED", 5, 194127},
	{"TEABAG", 6, 194128},
	{"CADOU", 5, 194129},
	{"OLDSTYLE", 8, 194130},
	{"MWG", 3, 194131},
	{"RTICLE", 6, 194132},
	{"SHELFORD", 8, 194133},
	{"BEAUSEJOUR", 10, 194134},
	{"GEDLING", 7, 194135},
	{"NURI", 4, 194136},
	{"BLUENOSE", 8, 194137},
	{"EBURY", 5, 194138},
	{"RVISWANADHA", 11, 194139},
	{"LONGUS", 6, 194140},
	{"AVANES", 6, 194141},
	{"BRUYN", 5, 194142},
	{"EXTRABOLD", 9, 194143},
	{"BEEKMANS", 8, 194144},
	{"ENDCSNAME", 9, 194145},
	{"INQUISITORS", 11, 194146},
	{"HASATTR", 7, 194147},
	{"ROLDAN", 6, 194148},
	{"CARBIDOPA", 9, 194149},
	{"KEESLER", 7, 194150},
	{"DREAMILY", 8, 194151},
	{"AGOR", 4, 194152},
	{"OPINIONI", 8, 194153},
	{"RINEX", 5, 194154},
	{"FROBISHER", 9, 194155},
	{"DIGO", 4, 194156},
	{"MOTIVO", 6, 194157},
	{"DOWNPIPE", 8, 194158},
	{"LAXTON", 6, 194159},
	{"KLINGHOFFER", 11, 194160},
	{"COMITATUS", 9, 194161},
	{"INTERPROCEDURAL", 15, 194162},
	{"CNNNN", 5, 194163},
	{"YILDIZ", 6, 194164},
	{"TENTION", 7, 194165},
	{"SOUTHWESTS", 10, 194166},
	{"MERCUTIO", 8, 194167},
	{"GIBBET", 6, 194168},
	{"EXACTITUDE", 10, 194169},
	{"CLOCKTOWER", 10, 194170},
	{"TRIBORO", 7, 194171},
	{"FILIPPI", 7, 194172},
	{"BRAKHAGE", 8, 194173},
	{"EBITA", 5, 194174},
	{"RRL", 3, 194175},
	{"PROMENADES", 10, 194176},
	{"INGHILTERRA", 11, 194177},
	{"PHYLLOSCOPUS", 12, 194178},
	{"PEOLPE", 6, 194179},
	{"SOFTARE", 7, 194180},
	{"MELAS", 5, 194181},
	{"MACROPHYLLA", 11, 194182},
	{"IDEAFLOW", 8, 194183},
	{"DISBELIEVING", 12, 194184},
	{"TRICHOPTERA", 11, 194185},
	{"MYSPACECOM", 10, 194186},
	{"COGNATES", 8, 194187},
	{"ANTIPARALLEL", 12, 194188},
	{"HOMEOMORPHIC", 12, 194189},
	{"DRIVERGUIDE", 11, 194190},
	{"SIARA", 5, 194191},
	{"MARVELING", 9, 194192},
	{"WESTCLIFFE", 10, 194193},
	{"PELARGONIUM", 11, 194194},
	{"MYCENAEAN", 9, 194195},
	{"HUHUU", 5, 194196},
	{"HEPHZIBAH", 9, 194197},
	{"HORSMAN", 7, 194198},
	{"JUNKIN", 6, 194199},
	{"VELL", 4, 194200},
	{"GRISE", 5, 194201},
	{"ASML", 4, 194202},
	{"LINKLETTER", 10, 194203},
	{"AMPHIBOLE", 9, 194204},
	{"ZINR", 4, 194205},
	{"ZBOT", 4, 194206},
	{"YMRD", 4, 194207},
	{"YKLO", 4, 194208},
	{"XTCR", 4, 194209},
	{"VVIN", 4, 194210},
	{"VAOC", 4, 194211},
	{"UZWH", 4, 194212},
	{"UIZW", 4, 194213},
	{"TZDO", 4, 194214},
	{"TMYU", 4, 194215},
	{"SAFB", 4, 194216},
	{"RLCI", 4, 194217},
	{"RHWA", 4, 194218},
	{"QUAF", 4, 194219},
	{"PRIB", 4, 194220},
	{"PHPO", 4, 194221},
	{"NYUW", 4, 194222},
	{"NDMV", 4, 194223},
	{"LBAF", 4, 194224},
	{"KKED", 4, 194225},
	{"KKAA", 4, 194226},
	{"JBAR", 4, 194227},
	{"IYOM", 4, 194228},
	{"HPLY", 4, 194229},
	{"HBBC", 4, 194230},
	{"HAKL", 4, 194231},
	{"FBYI", 4, 194232},
	{"FBYG", 4, 194233},
	{"FAGN", 4, 194234},
	{"EXPH", 4, 194235},
	{"EUCF", 4, 194236},
	{"ERGV", 4, 194237},
	{"EJMO", 4, 194238},
	{"DZEI", 4, 194239},
	{"BCLU", 4, 194240},
	{"AFSY", 4, 194241},
	{"AFMI", 4, 194242},
	{"SYNDROMIC", 9, 194243},
	{"MYRISTATE", 9, 194244},
	{"SWAMIJI", 7, 194245},
	{"EPITAPHS", 8, 194246},
	{"OSTEOPENIA", 10, 194247},
	{"EXUDATES", 8, 194248},
	{"PHILHARMONIKER", 14, 194249},
	{"MATSUNAGA", 9, 194250},
	{"JOSTLED", 7, 194251},
	{"UREMIA", 6, 194252},
	{"MANNEN", 6, 194253},
	{"ENTRYWAYS", 9, 194254},
	{"KAFUE", 5, 194255},
	{"CEDERBERG", 9, 194256},
	{"MESSAGED", 8, 194257},
	{"CACHEXIA", 8, 194258},
	{"TACHI", 5, 194259},
	{"MACIEL", 6, 194260},
	{"SEMISWEET", 9, 194261},
	{"MMCF", 4, 194262},
	{"SLEEPWALKER", 11, 194263},
	{"HULEN", 5, 194264},
	{"CRIMINALIZED", 12, 194265},
	{"SWALL", 5, 194266},
	{"YUNIS", 5, 194267},
	{"UNVERIFIABLE", 12, 194268},
	{"GENIES", 6, 194269},
	{"INFRASOUND", 10, 194270},
	{"GLOBULES", 8, 194271},
	{"MICROCENTRIFUGE", 15, 194272},
	{"UPING", 5, 194273},
	{"ENERCON", 7, 194274},
	{"HERDSMEN", 8, 194275},
	{"DROMEDARY", 9, 194276},
	{"CONMIGO", 7, 194277},
	{"ROSENGARTEN", 11, 194278},
	{"LAROCQUE", 8, 194279},
	{"REPROVE", 7, 194280},
	{"PERSONALIA", 10, 194281},
	{"KUNDA", 5, 194282},
	{"CASELOGIC", 9, 194283},
	{"GARIFUNA", 8, 194284},
	{"MVK", 3, 194285},
	{"DECOM", 5, 194286},
	{"OKIPAGE", 7, 194287},
	{"HOLLERS", 7, 194288},
	{"DIRIGO", 6, 194289},
	{"EVENSTAR", 8, 194290},
	{"ALDRED", 6, 194291},
	{"SYSTEMY", 7, 194292},
	{"AXOAX", 5, 194293},
	{"HEARETH", 7, 194294},
	{"NEWSY", 5, 194295},
	{"SMALLBIZSEARCH", 14, 194296},
	{"OPACITIES", 9, 194297},
	{"PERTWEE", 7, 194298},
	{"MACINTOSHES", 11, 194299},
	{"JUDICE", 6, 194300},
	{"BULLOUS", 7, 194301},
	{"NANOMEDICINE", 12, 194302},
	{"ALLIER", 6, 194303},
	{"GRATISPICS", 10, 194304},
	{"CHARTERER", 9, 194305},
	{"MEDEIA", 6, 194306},
	{"VOLLRATH", 8, 194307},
	{"MULTIEMPLOYER", 13, 194308},
	{"VERHINDERN", 10, 194309},
	{"ROOTLESS", 8, 194310},
	{"INVIOLATE", 9, 194311},
	{"MAGOFFIN", 8, 194312},
	{"BIBEL", 5, 194313},
	{"MOME", 4, 194314},
	{"WATERERS", 8, 194315},
	{"ENERGISING", 10, 194316},
	{"ELUENT", 6, 194317},
	{"WIKIWIKI", 8, 194318},
	{"SPRITZER", 8, 194319},
	{"FLEXIFOIL", 9, 194320},
	{"CLEANABLE", 9, 194321},
	{"FERED", 5, 194322},
	{"BOESE", 5, 194323},
	{"SALVI", 5, 194324},
	{"SILVANO", 7, 194325},
	{"NASOPHARYNX", 11, 194326},
	{"BOOKLOVERS", 10, 194327},
	{"BAGA", 4, 194328},
	{"ALLANTE", 7, 194329},
	{"VOLKSGEZONDHEID", 15, 194330},
	{"SETUBAL", 7, 194331},
	{"PROGRESSO", 9, 194332},
	{"SWITZ", 5, 194333},
	{"PANDO", 5, 194334},
	{"FINESTRA", 8, 194335},
	{"ZOROASTER", 9, 194336},
	{"OBSOLESCENT", 11, 194337},
	{"SHEWE", 5, 194338},
	{"ENBD", 4, 194339},
	{"BIOPOLYMER", 10, 194340},
	{"ZIEF", 4, 194341},
	{"YZIT", 4, 194342},
	{"YDRB", 4, 194343},
	{"XBOU", 4, 194344},
	{"VSDI", 4, 194345},
	{"VPTO", 4, 194346},
	{"VOLH", 4, 194347},
	{"VAQU", 4, 194348},
	{"UTRH", 4, 194349},
	{"UEOW", 4, 194350},
	{"UDVO", 4, 194351},
	{"SYUA", 4, 194352},
	{"SPPG", 4, 194353},
	{"SGOC", 4, 194354},
	{"RPMC", 4, 194355},
	{"PYIE", 4, 194356},
	{"PODH", 4, 194357},
	{"OYRU", 4, 194358},
	{"OVME", 4, 194359},
	{"OFRW", 4, 194360},
	{"MWSA", 4, 194361},
	{"MSIB", 4, 194362},
	{"MBTE", 4, 194363},
	{"LOSJ", 4, 194364},
	{"LHUE", 4, 194365},
	{"LFOG", 4, 194366},
	{"KEYY", 4, 194367},
	{"IGJA", 4, 194368},
	{"HEXG", 4, 194369},
	{"FDIX", 4, 194370},
	{"EWDN", 4, 194371},
	{"EMVC", 4, 194372},
	{"DOKT", 4, 194373},
	{"DEXN", 4, 194374},
	{"DBSI", 4, 194375},
	{"AZRE", 4, 194376},
	{"AUXO", 4, 194377},
	{"MULTIHOP", 8, 194378},
	{"WEGMANS", 7, 194379},
	{"SHEELA", 6, 194380},
	{"SWITCHVIEW", 10, 194381},
	{"KLUBITUS", 8, 194382},
	{"WEINERT", 7, 194383},
	{"NETCAST", 7, 194384},
	{"GRANITEVILLE", 12, 194385},
	{"FOXMAN", 6, 194386},
	{"VRB", 3, 194387},
	{"TRIFFIDS", 8, 194388},
	{"SUBFILE", 7, 194389},
	{"ARSENIO", 7, 194390},
	{"ORATIONS", 8, 194391},
	{"HATCHETT", 8, 194392},
	{"HARMISON", 8, 194393},
	{"KIESLOWSKI", 10, 194394},
	{"KOCHIA", 6, 194395},
	{"ERRORE", 6, 194396},
	{"ANASTROZOLE", 11, 194397},
	{"PRIZREN", 7, 194398},
	{"MASCHINENBAU", 12, 194399},
	{"FINWEEK", 7, 194400},
	{"JABAL", 5, 194401},
	{"HEDER", 5, 194402},
	{"EVADES", 6, 194403},
	{"CONGRADULATIONS", 15, 194404},
	{"PICKTHAL", 8, 194405},
	{"SKYWALK", 7, 194406},
	{"TSITSIKAMMA", 11, 194407},
	{"LOBBED", 6, 194408},
	{"PIRS", 4, 194409},
	{"CBAC", 4, 194410},
	{"HERAULT", 7, 194411},
	{"NAGASE", 6, 194412},
	{"KARIBIK", 7, 194413},
	{"ADELLE", 6, 194414},
	{"PLANKED", 7, 194415},
	{"PARAL", 5, 194416},
	{"ZOWIE", 5, 194417},
	{"BOYDELL", 7, 194418},
	{"VISTULA", 7, 194419},
	{"LATEN", 5, 194420},
	{"EXAMINA", 7, 194421},
	{"DWELLED", 7, 194422},
	{"SCHNAPPI", 8, 194423},
	{"NACELLE", 7, 194424},
	{"GULAGS", 6, 194425},
	{"BANAT", 5, 194426},
	{"USEAND", 6, 194427},
	{"SEQUEIRA", 8, 194428},
	{"KORHONEN", 8, 194429},
	{"INDEXEDCATALOG", 14, 194430},
	{"CAIRNGORM", 9, 194431},
	{"AENSLAND", 8, 194432},
	{"SPEEDLINE", 9, 194433},
	{"SCHMEHL", 7, 194434},
	{"PAWL", 4, 194435},
	{"KEISUKE", 7, 194436},
	{"ERSTER", 6, 194437},
	{"EMBROIDED", 9, 194438},
	{"GAZELLES", 8, 194439},
	{"ARLBERG", 7, 194440},
	{"TEQUESTA", 8, 194441},
	{"RAZIEL", 6, 194442},
	{"HOWLERS", 7, 194443},
	{"CARDIOGENIC", 11, 194444},
	{"SCREEM", 6, 194445},
	{"PREPAREDSTATEMENT", 17, 194446},
	{"UWIN", 4, 194447},
	{"NSDQ", 4, 194448},
	{"DEEDE", 5, 194449},
	{"YOSSARIAN", 9, 194450},
	{"MODMM", 5, 194451},
	{"KINNOCK", 7, 194452},
	{"AQUARION", 8, 194453},
	{"NUMBEROF", 8, 194454},
	{"OPENDIVX", 8, 194455},
	{"BEDOK", 5, 194456},
	{"TROPOMYOSIN", 11, 194457},
	{"AUTANT", 6, 194458},
	{"GNUDIST", 7, 194459},
	{"POONA", 5, 194460},
	{"ETODOLAC", 8, 194461},
	{"TETSUJIN", 8, 194462},
	{"SUDUKO", 6, 194463},
	{"HEMME", 5, 194464},
	{"PINOTAGE", 8, 194465},
	{"APSU", 4, 194466},
	{"VINCENTS", 8, 194467},
	{"CLOYD", 5, 194468},
	{"OVERSTORY", 9, 194469},
	{"RECONSTR", 8, 194470},
	{"DISCREPANT", 10, 194471},
	{"FORMULATOR", 10, 194472},
	{"DELENDA", 7, 194473},
	{"BLACKWOLF", 9, 194474},
	{"SHARONA", 7, 194475},
	{"BILLETES", 8, 194476},
	{"SUBDIVIDERS", 11, 194477},
	{"SCHRIFT", 7, 194478},
	{"ESTUDIANTE", 10, 194479},
	{"WOGAN", 5, 194480},
	{"UNIONIZE", 8, 194481},
	{"ROTENBERG", 9, 194482},
	{"POKORNY", 7, 194483},
	{"CROOKES", 7, 194484},
	{"VICA", 4, 194485},
	{"DARVIN", 6, 194486},
	{"TIKVA", 5, 194487},
	{"TETRAHYDROCANNABINOL", 20, 194488},
	{"CHANCELLORSVILLE", 16, 194489},
	{"POPOLARE", 8, 194490},
	{"TIPTREE", 7, 194491},
	{"KAARTEN", 7, 194492},
	{"ZACS", 4, 194493},
	{"YOGH", 4, 194494},
	{"YNKI", 4, 194495},
	{"YKOB", 4, 194496},
	{"YDMI", 4, 194497},
	{"XMOU", 4, 194498},
	{"WWBE", 4, 194499},
	{"WCOC", 4, 194500},
	{"VSDO", 4, 194501},
	{"VIAQ", 4, 194502},
	{"VEYJ", 4, 194503},
	{"UCLU", 4, 194504},
	{"RUHO", 4, 194505},
	{"RRSI", 4, 194506},
	{"RNGL", 4, 194507},
	{"RBIM", 4, 194508},
	{"PTPM", 4, 194509},
	{"PTHL", 4, 194510},
	{"NXCO", 4, 194511},
	{"MNBO", 4, 194512},
	{"MIOU", 4, 194513},
	{"LUKR", 4, 194514},
	{"LTSJ", 4, 194515},
	{"LIXB", 4, 194516},
	{"IRLK", 4, 194517},
	{"GYRU", 4, 194518},
	{"FSGA", 4, 194519},
	{"FLRU", 4, 194520},
	{"FLIU", 4, 194521},
	{"FKYO", 4, 194522},
	{"EYUU", 4, 194523},
	{"DGMS", 4, 194524},
	{"CHCM", 4, 194525},
	{"BNWI", 4, 194526},
	{"BITJ", 4, 194527},
	{"AVSG", 4, 194528},
	{"ASCF", 4, 194529},
	{"ALCP", 4, 194530},
	{"AGNY", 4, 194531},
	{"JOONG", 5, 194532},
	{"FFELP", 5, 194533},
	{"KRENSKY", 7, 194534},
	{"NOVELIZATION", 12, 194535},
	{"CARFS", 5, 194536},
	{"APACHECTL", 9, 194537},
	{"MAZI", 4, 194538},
	{"STDLIB", 6, 194539},
	{"SPICEWOOD", 9, 194540},
	{"HOOFDDORP", 9, 194541},
	{"XDMCP", 5, 194542},
	{"MINGHELLA", 9, 194543},
	{"POTATOS", 7, 194544},
	{"COLLINA", 7, 194545},
	{"APPART", 6, 194546},
	{"RESEMBLANCES", 12, 194547},
	{"OPITZ", 5, 194548},
	{"ANOMIE", 6, 194549},
	{"CHOLI", 5, 194550},
	{"BRESLOW", 7, 194551},
	{"VISHA", 5, 194552},
	{"METZNER", 7, 194553},
	{"KPARTS", 6, 194554},
	{"CREAMFIELDS", 11, 194555},
	{"TERMINA", 7, 194556},
	{"VELOCIWORLD", 11, 194557},
	{"KATSURA", 7, 194558},
	{"CROSSAN", 7, 194559},
	{"DUSTRY", 6, 194560},
	{"LEONIDS", 7, 194561},
	{"CAMU", 4, 194562},
	{"RETICULOCYTE", 12, 194563},
	{"EDDING", 6, 194564},
	{"OLEKSANDR", 9, 194565},
	{"PHOTOGALLERIES", 14, 194566},
	{"PALOMAS", 7, 194567},
	{"ITCHES", 6, 194568},
	{"ADUR", 4, 194569},
	{"DIANN", 5, 194570},
	{"OVEREAT", 7, 194571},
	{"INSLEE", 6, 194572},
	{"COLLEGEJOURNAL", 14, 194573},
	{"TRANSPO", 7, 194574},
	{"GINGERICH", 9, 194575},
	{"CRESSEY", 7, 194576},
	{"AMHERSTBURG", 11, 194577},
	{"MATHEMETICS", 11, 194578},
	{"EXTERNSHIPS", 11, 194579},
	{"CHICKENHAWK", 11, 194580},
	{"PECTORALIS", 10, 194581},
	{"FREIZEITNUTTEN", 14, 194582},
	{"TEAGASC", 7, 194583},
	{"GABAA", 5, 194584},
	{"LANYA", 5, 194585},
	{"KANAWA", 6, 194586},
	{"KLIPS", 5, 194587},
	{"GAMETALK", 8, 194588},
	{"PIJP", 4, 194589},
	{"DEREGISTRATION", 14, 194590},
	{"BATTERSBY", 9, 194591},
	{"NOBUYUKI", 8, 194592},
	{"MUNSEY", 6, 194593},
	{"HEIDKE", 6, 194594},
	{"POULOS", 6, 194595},
	{"COLLINGE", 8, 194596},
	{"PEPPLE", 6, 194597},
	{"SIPPIN", 6, 194598},
	{"PRODUTO", 7, 194599},
	{"LATIS", 5, 194600},
	{"INTRAORAL", 9, 194601},
	{"BYACC", 5, 194602},
	{"HEYSHAM", 7, 194603},
	{"SYNTHETASES", 11, 194604},
	{"STRINGBUILDER", 13, 194605},
	{"VERTRIEB", 8, 194606},
	{"PARLIER", 7, 194607},
	{"PARADIES", 8, 194608},
	{"CUALES", 6, 194609},
	{"SLOPESTYLE", 10, 194610},
	{"FREDERIKSBERG", 13, 194611},
	{"BADFINGER", 9, 194612},
	{"ALTERNARIA", 10, 194613},
	{"THRANE", 6, 194614},
	{"REFRACTING", 10, 194615},
	{"POLYCYTHEMIA", 12, 194616},
	{"PERSWADED", 9, 194617},
	{"NIKKEN", 6, 194618},
	{"LORDLY", 6, 194619},
	{"HTMERGE", 7, 194620},
	{"TIZANIDINE", 10, 194621},
	{"TEMPNAME", 8, 194622},
	{"SUKKAH", 6, 194623},
	{"MARGINALS", 9, 194624},
	{"COMPLEXIONS", 11, 194625},
	{"MIYOSHI", 7, 194626},
	{"CLAYOQUOT", 9, 194627},
	{"ARTHURCLEMENS", 13, 194628},
	{"MODSC", 5, 194629},
	{"QXW", 3, 194630},
	{"KOORI", 5, 194631},
	{"GAWXNET", 7, 194632},
	{"XMOD", 4, 194633},
	{"HOSPITALIER", 11, 194634},
	{"BEHANG", 6, 194635},
	{"EMPEDOCLES", 10, 194636},
	{"DESPISING", 9, 194637},
	{"BANDOLINO", 9, 194638},
	{"EARDRUMS", 8, 194639},
	{"QPIXMAP", 7, 194640},
	{"SYMPATHOMIMETIC", 15, 194641},
	{"LONEWOLF", 8, 194642},
	{"EUPHORBIACEAE", 13, 194643},
	{"RUTIN", 5, 194644},
	{"REUPHOLSTERY", 12, 194645},
	{"PIERCER", 7, 194646},
	{"TABY", 4, 194647},
	{"OMPHALE", 7, 194648},
	{"CULM", 4, 194649},
	{"DOLOROSA", 8, 194650},
	{"ASSIDUOUS", 9, 194651},
	{"INGOLD", 6, 194652},
	{"HIJACKS", 7, 194653},
	{"STORZ", 5, 194654},
	{"PERFUMY", 7, 194655},
	{"CONSTANTINES", 12, 194656},
	{"LOKALE", 6, 194657},
	{"GPERF", 5, 194658},
	{"STOKOWSKI", 9, 194659},
	{"INFORMATIONABOUT", 16, 194660},
	{"ZAWO", 4, 194661},
	{"YWEJ", 4, 194662},
	{"YKLI", 4, 194663},
	{"YAOL", 4, 194664},
	{"UCOI", 4, 194665},
	{"TOXC", 4, 194666},
	{"TCDI", 4, 194667},
	{"ROIF", 4, 194668},
	{"RFBA", 4, 194669},
	{"RCMI", 4, 194670},
	{"PTVS", 4, 194671},
	{"PRTO", 4, 194672},
	{"PPBU", 4, 194673},
	{"ONWM", 4, 194674},
	{"MUHY", 4, 194675},
	{"MMRO", 4, 194676},
	{"MMIW", 4, 194677},
	{"KOUA", 4, 194678},
	{"KHCO", 4, 194679},
	{"IDLL", 4, 194680},
	{"HEVG", 4, 194681},
	{"GSYL", 4, 194682},
	{"FUIS", 4, 194683},
	{"FSBR", 4, 194684},
	{"FELF", 4, 194685},
	{"EZSM", 4, 194686},
	{"EYEU", 4, 194687},
	{"ETZC", 4, 194688},
	{"ETVL", 4, 194689},
	{"ERUO", 4, 194690},
	{"EEDZ", 4, 194691},
	{"DMCE", 4, 194692},
	{"DENQ", 4, 194693},
	{"CJUL", 4, 194694},
	{"CIKS", 4, 194695},
	{"BPEN", 4, 194696},
	{"ARNV", 4, 194697},
	{"AKFE", 4, 194698},
	{"LINGS", 5, 194699},
	{"GARFORTH", 8, 194700},
	{"EUID", 4, 194701},
	{"PUTRESCINE", 10, 194702},
	{"OVERGROUND", 10, 194703},
	{"ANDALUS", 7, 194704},
	{"YAACOV", 6, 194705},
	{"LEISURES", 8, 194706},
	{"AMIKACIN", 8, 194707},
	{"MADELUNG", 8, 194708},
	{"VERSTEHEN", 9, 194709},
	{"SONIG", 5, 194710},
	{"POLONIUS", 8, 194711},
	{"VORSTER", 7, 194712},
	{"HIPPOCRENE", 10, 194713},
	{"RMJ", 3, 194714},
	{"LPCTSTR", 7, 194715},
	{"CYCLIZATION", 11, 194716},
	{"TOADY", 5, 194717},
	{"MARKETINGX", 10, 194718},
	{"HPSG", 4, 194719},
	{"PERMUTED", 8, 194720},
	{"EPIGRAMS", 8, 194721},
	{"DEVILYN", 7, 194722},
	{"MORTGAGING", 10, 194723},
	{"SAVEUR", 6, 194724},
	{"KRETA", 5, 194725},
	{"COCINAS", 7, 194726},
	{"MODELENG", 8, 194727},
	{"DAGNY", 5, 194728},
	{"REAPPLICATION", 13, 194729},
	{"MONTREAT", 8, 194730},
	{"HEMOSTATIC", 10, 194731},
	{"TEIKOKU", 7, 194732},
	{"NETWORKMANAGER", 14, 194733},
	{"PHENTRIMINE", 11, 194734},
	{"BUYBACKS", 8, 194735},
	{"BEDLINEN", 8, 194736},
	{"GRUN", 4, 194737},
	{"TEMPERMENT", 10, 194738},
	{"FORNIA", 6, 194739},
	{"MULTINET", 8, 194740},
	{"MDOC", 4, 194741},
	{"MAURITS", 7, 194742},
	{"ORDERBY", 7, 194743},
	{"MORIYAMA", 8, 194744},
	{"KRONUR", 6, 194745},
	{"FAWKNER", 7, 194746},
	{"MANOLIS", 7, 194747},
	{"LADOGA", 6, 194748},
	{"FONEJUNKIE", 10, 194749},
	{"ACCUFITNESS", 11, 194750},
	{"SAMITI", 6, 194751},
	{"GDEF", 4, 194752},
	{"SHIPROCK", 8, 194753},
	{"OVERSIGHTS", 10, 194754},
	{"INVISCID", 8, 194755},
	{"BLACKWOMEN", 10, 194756},
	{"PICTOGRAM", 9, 194757},
	{"ORPHEN", 6, 194758},
	{"AUTOU", 5, 194759},
	{"GAVILAN", 7, 194760},
	{"KONTAKTHOF", 10, 194761},
	{"DENTIAL", 7, 194762},
	{"WHEATSTONE", 10, 194763},
	{"PYXML", 5, 194764},
	{"POZYCJONOWANIE", 14, 194765},
	{"THENCEFORTH", 11, 194766},
	{"RUDNER", 6, 194767},
	{"BENEDUM", 7, 194768},
	{"OOPHORECTOMY", 12, 194769},
	{"NEOLOGISM", 9, 194770},
	{"BLANES", 6, 194771},
	{"BLUELIGHT", 9, 194772},
	{"GIRTHS", 6, 194773},
	{"LEXIBOOK", 8, 194774},
	{"CYTOTEC", 7, 194775},
	{"MANDOLINE", 9, 194776},
	{"CDES", 4, 194777},
	{"SANDINISTAS", 11, 194778},
	{"NELVANA", 7, 194779},
	{"LINPACK", 7, 194780},
	{"SWERVING", 8, 194781},
	{"PERFECTS", 8, 194782},
	{"ORIENTATIONAL", 13, 194783},
	{"UNICYCLING", 10, 194784},
	{"HEXCEL", 6, 194785},
	{"ABLEX", 5, 194786},
	{"SLITTER", 7, 194787},
	{"VETUS", 5, 194788},
	{"ECDC", 4, 194789},
	{"JUPP", 4, 194790},
	{"BXL", 3, 194791},
	{"TAMPERS", 7, 194792},
	{"ITOCHU", 6, 194793},
	{"WSAD", 4, 194794},
	{"ROMIKA", 6, 194795},
	{"GIBLET", 6, 194796},
	{"NCUBE", 5, 194797},
	{"CTRY", 4, 194798},
	{"SETGRAY", 7, 194799},
	{"SUSANS", 6, 194800},
	{"KRAVET", 6, 194801},
	{"BERLINALE", 9, 194802},
	{"REINFORCER", 10, 194803},
	{"BERLINGO", 8, 194804},
	{"ORNET", 5, 194805},
	{"DOWNL", 5, 194806},
	{"LUIK", 4, 194807},
	{"BATAK", 5, 194808},
	{"GRIGORI", 7, 194809},
	{"SURPRIS", 7, 194810},
	{"SHAFI", 5, 194811},
	{"GIGARANGE", 9, 194812},
	{"ZCHI", 4, 194813},
	{"YNWE", 4, 194814},
	{"XUPT", 4, 194815},
	{"WLLA", 4, 194816},
	{"UWES", 4, 194817},
	{"UUZH", 4, 194818},
	{"PPFR", 4, 194819},
	{"PHIU", 4, 194820},
	{"LUNM", 4, 194821},
	{"JOSR", 4, 194822},
	{"IUYU", 4, 194823},
	{"HUGW", 4, 194824},
	{"HRUF", 4, 194825},
	{"HLUI", 4, 194826},
	{"GIGT", 4, 194827},
	{"GCES", 4, 194828},
	{"FNUD", 4, 194829},
	{"EYPP", 4, 194830},
	{"EWPC", 4, 194831},
	{"EJAU", 4, 194832},
	{"DUJO", 4, 194833},
	{"DPPO", 4, 194834},
	{"DKYR", 4, 194835},
	{"CEUL", 4, 194836},
	{"BOAP", 4, 194837},
	{"AWCU", 4, 194838},
	{"UVF", 3, 194839},
	{"OUTPACES", 8, 194840},
	{"GRIF", 4, 194841},
	{"DESIGNO", 7, 194842},
	{"RAZVANJP", 8, 194843},
	{"CONTATE", 7, 194844},
	{"GBAGBO", 6, 194845},
	{"ODDIE", 5, 194846},
	{"MONIK", 5, 194847},
	{"KLINT", 5, 194848},
	{"SHOWGROUNDS", 11, 194849},
	{"FRAPPE", 6, 194850},
	{"VZV", 3, 194851},
	{"RALPHY", 6, 194852},
	{"WORKSHY", 7, 194853},
	{"POBRE", 5, 194854},
	{"XARCH", 5, 194855},
	{"TRUSECURE", 9, 194856},
	{"JEWISHGEN", 9, 194857},
	{"RITZVILLE", 9, 194858},
	{"INSEASON", 8, 194859},
	{"FORMSECURE", 10, 194860},
	{"CRACKNELL", 9, 194861},
	{"TORRIDGE", 8, 194862},
	{"ZALESKI", 7, 194863},
	{"SAMWISE", 7, 194864},
	{"TULIPA", 6, 194865},
	{"MURTY", 5, 194866},
	{"KRYPTO", 6, 194867},
	{"BEAUDESERT", 10, 194868},
	{"DONY", 4, 194869},
	{"CONTOS", 6, 194870},
	{"CREATEIMAGE", 11, 194871},
	{"WORRYINGLY", 10, 194872},
	{"ROSENBORG", 9, 194873},
	{"NONBANK", 7, 194874},
	{"LEBENS", 6, 194875},
	{"STOCKINGED", 10, 194876},
	{"SAMPELS", 7, 194877},
	{"TAIRA", 5, 194878},
	{"FILESETS", 8, 194879},
	{"TANKERSLEY", 10, 194880},
	{"NITRIX", 6, 194881},
	{"LINKPARTNERS", 12, 194882},
	{"GAVAN", 5, 194883},
	{"ULRIK", 5, 194884},
	{"MUERTO", 6, 194885},
	{"STOGIES", 7, 194886},
	{"PARYS", 5, 194887},
	{"CARXS", 5, 194888},
	{"NAMIN", 5, 194889},
	{"HYPOKALEMIA", 11, 194890},
	{"HOCEVAR", 7, 194891},
	{"ASIANUX", 7, 194892},
	{"RSAC", 4, 194893},
	{"ASOCIADOS", 9, 194894},
	{"PICADILLY", 9, 194895},
	{"EVERETTE", 8, 194896},
	{"DELIST", 6, 194897},
	{"BRAYBROOK", 9, 194898},
	{"TEMIC", 5, 194899},
	{"SENZATION", 9, 194900},
	{"ENFANCE", 7, 194901},
	{"BORDON", 6, 194902},
	{"SENTAI", 6, 194903},
	{"GESETZ", 6, 194904},
	{"TERIAL", 6, 194905},
	{"MUNIC", 5, 194906},
	{"CARCS", 5, 194907},
	{"TARKETT", 7, 194908},
	{"DIFFRACTOMETER", 14, 194909},
	{"APOLLOS", 7, 194910},
	{"SOUTHS", 6, 194911},
	{"SMITHERMAN", 10, 194912},
	{"IANUARIE", 8, 194913},
	{"BLINDINGLY", 10, 194914},
	{"BALLPEN", 7, 194915},
	{"PORTENTOUS", 10, 194916},
	{"SUNFLY", 6, 194917},
	{"LQFP", 4, 194918},
	{"EXPENDI", 7, 194919},
	{"CYSTOSCOPY", 10, 194920},
	{"FACTORIZATIONS", 14, 194921},
	{"JUICEMAN", 8, 194922},
	{"SPECTRORADIOMETER", 17, 194923},
	{"JLP", 3, 194924},
	{"ALKOHOL", 7, 194925},
	{"UMES", 4, 194926},
	{"MUNICIPALS", 10, 194927},
	{"JERRYS", 6, 194928},
	{"VORPOMMERN", 10, 194929},
	{"SUCCHI", 6, 194930},
	{"LEROI", 5, 194931},
	{"HASKIN", 6, 194932},
	{"SABHARWAL", 9, 194933},
	{"LECO", 4, 194934},
	{"ANGELN", 6, 194935},
	{"IVYBRIDGE", 9, 194936},
	{"CONJURER", 8, 194937},
	{"MAJORITARIAN", 12, 194938},
	{"AHLUL", 5, 194939},
	{"LAMI", 4, 194940},
	{"KENRICK", 7, 194941},
	{"SOFER", 5, 194942},
	{"SMARTPOWER", 10, 194943},
	{"DRAGGIN", 7, 194944},
	{"DRAMATIS", 8, 194945},
	{"STEELWORKS", 10, 194946},
	{"TKACHENKO", 9, 194947},
	{"OLUDENIZ", 8, 194948},
	{"GENEESKUNDE", 11, 194949},
	{"PYRIMETHAMINE", 13, 194950},
	{"TOLLER", 6, 194951},
	{"PTOSIS", 6, 194952},
	{"FLK", 3, 194953},
	{"HUMO", 4, 194954},
	{"MOSTEROTICTEENS", 15, 194955},
	{"MONCRIEFF", 9, 194956},
	{"FOMENTING", 9, 194957},
	{"COMAPNY", 7, 194958},
	{"ALGORITHMICS", 12, 194959},
	{"NEUROFILAMENT", 13, 194960},
	{"ZGAL", 4, 194961},
	{"WUNA", 4, 194962},
	{"WSUD", 4, 194963},
	{"WAHW", 4, 194964},
	{"UHRE", 4, 194965},
	{"UAAL", 4, 194966},
	{"SJRS", 4, 194967},
	{"PYAF", 4, 194968},
	{"PTIP", 4, 194969},
	{"PCWH", 4, 194970},
	{"OYOV", 4, 194971},
	{"OVJI", 4, 194972},
	{"OHPL", 4, 194973},
	{"NKYH", 4, 194974},
	{"NHLB", 4, 194975},
	{"MFAY", 4, 194976},
	{"LIZM", 4, 194977},
	{"LFTW", 4, 194978},
	{"GMRM", 4, 194979},
	{"FYTR", 4, 194980},
	{"FSGR", 4, 194981},
	{"ELKG", 4, 194982},
	{"ECSB", 4, 194983},
	{"CEYD", 4, 194984},
	{"AOUD", 4, 194985},
	{"AERP", 4, 194986},
	{"DESKTOPMODULES", 14, 194987},
	{"ALGERIE", 7, 194988},
	{"ONSETS", 6, 194989},
	{"CAPECITABINE", 12, 194990},
	{"UMEDA", 5, 194991},
	{"RECEIUED", 8, 194992},
	{"RAZING", 6, 194993},
	{"WRONGDOERS", 10, 194994},
	{"POHANG", 6, 194995},
	{"KCET", 4, 194996},
	{"ARENS", 5, 194997},
	{"SUBSUME", 7, 194998},
	{"ROLFING", 7, 194999},
	{"LLONA", 5, 195000},
	{"DUOC", 4, 195001},
	{"SAPERE", 6, 195002},
	{"DROWNINGS", 9, 195003},
	{"KAYANO", 6, 195004},
	{"CACERT", 6, 195005},
	{"JAINS", 5, 195006},
	{"GYEONGGI", 8, 195007},
	{"RENTOKIL", 8, 195008},
	{"GIBBINS", 7, 195009},
	{"BEENLEIGH", 9, 195010},
	{"IQUEST", 6, 195011},
	{"DERVISHES", 9, 195012},
	{"ACTIUS", 6, 195013},
	{"EINKAUFEN", 9, 195014},
	{"NAPTIME", 7, 195015},
	{"WUK", 3, 195016},
	{"NOVOCAINE", 9, 195017},
	{"NOUNCED", 7, 195018},
	{"GLOSSING", 8, 195019},
	{"ARRUDA", 6, 195020},
	{"GOCEK", 5, 195021},
	{"DEMOCRATIZE", 11, 195022},
	{"RELLY", 5, 195023},
	{"DREAMLINER", 10, 195024},
	{"CHEESMAN", 8, 195025},
	{"PAPOOSE", 7, 195026},
	{"SERGENT", 7, 195027},
	{"KRYS", 4, 195028},
	{"CANFORD", 7, 195029},
	{"TERKEL", 6, 195030},
	{"TERP", 4, 195031},
	{"PRECOMPILER", 11, 195032},
	{"DISGORGEMENT", 12, 195033},
	{"COURSEBOOK", 10, 195034},
	{"VESPUCCI", 8, 195035},
	{"TRAVELGOLF", 10, 195036},
	{"MELZER", 6, 195037},
	{"MAUDSLEY", 8, 195038},
	{"WBUR", 4, 195039},
	{"MORGOTH", 7, 195040},
	{"DRAEGER", 7, 195041},
	{"DESTABILISE", 11, 195042},
	{"CONECUH", 7, 195043},
	{"LOSEY", 5, 195044},
	{"DRELL", 5, 195045},
	{"DIERENCE", 8, 195046},
	{"ABSENTEES", 9, 195047},
	{"HURLS", 5, 195048},
	{"GUTTMANN", 8, 195049},
	{"KONSTANTINE", 11, 195050},
	{"DATAPOWER", 9, 195051},
	{"ARMORING", 8, 195052},
	{"CONARD", 6, 195053},
	{"BIFIDOBACTERIUM", 15, 195054},
	{"MATL", 4, 195055},
	{"ALDILA", 6, 195056},
	{"RISEDRONATE", 11, 195057},
	{"NANDINI", 7, 195058},
	{"FCX", 3, 195059},
	{"KCP", 3, 195060},
	{"CORDITE", 7, 195061},
	{"PROMI", 5, 195062},
	{"FILIALE", 7, 195063},
	{"CRIMINOLOGICAL", 14, 195064},
	{"LRWXR", 5, 195065},
	{"FIREWEED", 8, 195066},
	{"RANDEL", 6, 195067},
	{"ORING", 5, 195068},
	{"CONNEXIN", 8, 195069},
	{"GLYCOBIOLOGY", 12, 195070},
	{"DIRECCIONES", 11, 195071},
	{"COURONNE", 8, 195072},
	{"AYAM", 4, 195073},
	{"NONRES", 6, 195074},
	{"RAKYAT", 6, 195075},
	{"ISPAT", 5, 195076},
	{"FLETCHING", 9, 195077},
	{"QCAD", 4, 195078},
	{"NIEUWSTE", 8, 195079},
	{"LANDOLT", 7, 195080},
	{"CHEATCODES", 10, 195081},
	{"BARTOSZ", 7, 195082},
	{"OILCLOTH", 8, 195083},
	{"MESONET", 7, 195084},
	{"LOTHLORIEN", 10, 195085},
	{"ZASB", 4, 195086},
	{"WKEL", 4, 195087},
	{"WAVO", 4, 195088},
	{"VONJ", 4, 195089},
	{"TVVE", 4, 195090},
	{"TMPG", 4, 195091},
	{"TIBY", 4, 195092},
	{"TDRC", 4, 195093},
	{"SMGE", 4, 195094},
	{"SKVO", 4, 195095},
	{"RCAY", 4, 195096},
	{"OWYW", 4, 195097},
	{"OEDL", 4, 195098},
	{"NABM", 4, 195099},
	{"MWEM", 4, 195100},
	{"MUCL", 4, 195101},
	{"LSPM", 4, 195102},
	{"LHEY", 4, 195103},
	{"LCYB", 4, 195104},
	{"IXSM", 4, 195105},
	{"IFIU", 4, 195106},
	{"GDPF", 4, 195107},
	{"EKUH", 4, 195108},
	{"EBCP", 4, 195109},
	{"DOUP", 4, 195110},
	{"DCSO", 4, 195111},
	{"CCDI", 4, 195112},
	{"BSTW", 4, 195113},
	{"APTF", 4, 195114},
	{"APFL", 4, 195115},
	{"ALKV", 4, 195116},
	{"EMOTY", 5, 195117},
	{"AFEGIR", 6, 195118},
	{"WINDUS", 6, 195119},
	{"NSLOG", 5, 195120},
	{"MACCONNECTION", 13, 195121},
	{"GRUS", 4, 195122},
	{"KAIST", 5, 195123},
	{"COTEAU", 6, 195124},
	{"FASTOW", 6, 195125},
	{"DEMOSS", 6, 195126},
	{"ECOVILLAGE", 10, 195127},
	{"CANONICALLY", 11, 195128},
	{"KIMANI", 6, 195129},
	{"RPGNOW", 6, 195130},
	{"SKYWAYS", 7, 195131},
	{"VIDEOPAL", 8, 195132},
	{"NETWELLNESS", 11, 195133},
	{"KDETOYS", 7, 195134},
	{"CHROMITE", 8, 195135},
	{"CASAIS", 6, 195136},
	{"STROOP", 6, 195137},
	{"POLYVIEW", 8, 195138},
	{"BOEHME", 6, 195139},
	{"MANTAS", 6, 195140},
	{"WILDTYPE", 8, 195141},
	{"DULLEST", 7, 195142},
	{"SYNCHRONIC", 10, 195143},
	{"ALSOFT", 6, 195144},
	{"PHLAK", 5, 195145},
	{"CRADS", 5, 195146},
	{"PARTNERWORLD", 12, 195147},
	{"PANGUITCH", 9, 195148},
	{"SAUNIER", 7, 195149},
	{"RESPS", 5, 195150},
	{"PINTA", 5, 195151},
	{"FREYTAG", 7, 195152},
	{"COSME", 5, 195153},
	{"APOPTYGMA", 9, 195154},
	{"ACCP", 4, 195155},
	{"PRESSBOX", 8, 195156},
	{"ERSCHIENEN", 10, 195157},
	{"DOWDEN", 6, 195158},
	{"UNITIZED", 8, 195159},
	{"HYPERIONICS", 11, 195160},
	{"SAYANG", 6, 195161},
	{"VENAL", 5, 195162},
	{"ORTHOLOGY", 9, 195163},
	{"GEBE", 4, 195164},
	{"SAFARILAND", 10, 195165},
	{"LEVERBACK", 9, 195166},
	{"GRETE", 5, 195167},
	{"ESCROWED", 8, 195168},
	{"HUGGIE", 6, 195169},
	{"POLARIMETRY", 11, 195170},
	{"CONCERTANTE", 11, 195171},
	{"CORKMAN", 7, 195172},
	{"UNSENT", 6, 195173},
	{"STEICHEN", 8, 195174},
	{"SOFINA", 6, 195175},
	{"PELED", 5, 195176},
	{"LAUTER", 6, 195177},
	{"DUFFLES", 7, 195178},
	{"BASEHOR", 7, 195179},
	{"GOURMAND", 8, 195180},
	{"EXTRAHEPATIC", 12, 195181},
	{"LEACHMAN", 8, 195182},
	{"KIBITZER", 8, 195183},
	{"GEISINGER", 9, 195184},
	{"SCHTUFF", 7, 195185},
	{"PHONOGRAMS", 10, 195186},
	{"HECKEL", 6, 195187},
	{"TWOMBLY", 7, 195188},
	{"HESSLER", 7, 195189},
	{"ASTRONOMICALLY", 14, 195190},
	{"ARCHANT", 7, 195191},
	{"ANALIZING", 9, 195192},
	{"REIMERS", 7, 195193},
	{"LMOS", 4, 195194},
	{"FATALIS", 7, 195195},
	{"GRANTSBURG", 10, 195196},
	{"COMITTEE", 8, 195197},
	{"NONELDERLY", 10, 195198},
	{"KEYBINDINGS", 11, 195199},
	{"WEARISOME", 9, 195200},
	{"MYMUZI", 6, 195201},
	{"MIDPRICED", 9, 195202},
	{"SORTIR", 6, 195203},
	{"FETTES", 6, 195204},
	{"LYASES", 6, 195205},
	{"EXAGGERATES", 11, 195206},
	{"EMSNOW", 6, 195207},
	{"UNCLOS", 6, 195208},
	{"MONEYBACK", 9, 195209},
	{"LQG", 3, 195210},
	{"FKR", 3, 195211},
	{"DIRECTIVA", 9, 195212},
	{"GURGLE", 6, 195213},
	{"BOURGUIGNON", 11, 195214},
	{"NAJJAR", 6, 195215},
	{"IRCS", 4, 195216},
	{"DAVIDIANS", 9, 195217},
	{"MESAGE", 6, 195218},
	{"LEZBIENS", 8, 195219},
	{"POMPOM", 6, 195220},
	{"ROUN", 4, 195221},
	{"ANTISLAVERY", 11, 195222},
	{"LAERTES", 7, 195223},
	{"HOISINGTON", 10, 195224},
	{"TWIKITUTORIAL", 13, 195225},
	{"SOPHISTS", 8, 195226},
	{"MIDAMERICAN", 11, 195227},
	{"HELLSTROM", 9, 195228},
	{"BMZ", 3, 195229},
	{"SANGAT", 6, 195230},
	{"PERMETTANT", 10, 195231},
	{"HUMANIZE", 8, 195232},
	{"RHINEHART", 9, 195233},
	{"OTAKI", 5, 195234},
	{"WEYR", 4, 195235},
	{"PLDT", 4, 195236},
	{"CHALKIDIKI", 10, 195237},
	{"APOLOGETICALLY", 14, 195238},
	{"TXTWORKCOUNTRY", 14, 195239},
	{"TXTHOMECOUNTRY", 14, 195240},
	{"TRISKELE", 8, 195241},
	{"REFOLDING", 9, 195242},
	{"OVERTRAINING", 12, 195243},
	{"CLIME", 5, 195244},
	{"LIPOLYSIS", 9, 195245},
	{"UPSALA", 6, 195246},
	{"SUPERTECH", 9, 195247},
	{"XOFU", 4, 195248},
	{"XELD", 4, 195249},
	{"WLHI", 4, 195250},
	{"WAPM", 4, 195251},
	{"VSFR", 4, 195252},
	{"VMIT", 4, 195253},
	{"ULKL", 4, 195254},
	{"UDSK", 4, 195255},
	{"SGTB", 4, 195256},
	{"PVIO", 4, 195257},
	{"PKNI", 4, 195258},
	{"MRHY", 4, 195259},
	{"LZIE", 4, 195260},
	{"LFJA", 4, 195261},
	{"KUDR", 4, 195262},
	{"KIWR", 4, 195263},
	{"KHLA", 4, 195264},
	{"KFRU", 4, 195265},
	{"IGUM", 4, 195266},
	{"IBWH", 4, 195267},
	{"HUKH", 4, 195268},
	{"HKAP", 4, 195269},
	{"HJUA", 4, 195270},
	{"GUAW", 4, 195271},
	{"GMCM", 4, 195272},
	{"EBPL", 4, 195273},
	{"COXP", 4, 195274},
	{"CGOI", 4, 195275},
	{"CCTI", 4, 195276},
	{"BKEE", 4, 195277},
	{"BGOL", 4, 195278},
	{"AYRD", 4, 195279},
	{"ANRM", 4, 195280},
	{"WEBSIT", 6, 195281},
	{"JAGIELLONIAN", 12, 195282},
	{"PLUSHIE", 7, 195283},
	{"SORTBY", 6, 195284},
	{"ABCO", 4, 195285},
	{"MAIGRET", 7, 195286},
	{"EXHANGE", 7, 195287},
	{"EUGENIDES", 9, 195288},
	{"XDB", 3, 195289},
	{"BLOWHARD", 8, 195290},
	{"PINTOR", 6, 195291},
	{"COMINCO", 7, 195292},
	{"SISTANCE", 8, 195293},
	{"UBON", 4, 195294},
	{"BOMBSHELLS", 10, 195295},
	{"ADRENALYNN", 10, 195296},
	{"EXHIBITIONISMUS", 15, 195297},
	{"COMPONENTE", 10, 195298},
	{"BOSOX", 5, 195299},
	{"GROUNDE", 7, 195300},
	{"EDELSOHN", 8, 195301},
	{"HELOTES", 7, 195302},
	{"BONNYVILLE", 10, 195303},
	{"BLOGSTER", 8, 195304},
	{"MALAM", 5, 195305},
	{"OPTUSNET", 8, 195306},
	{"LINUXTRENT", 10, 195307},
	{"GRATUITEMENTTELECHARGER", 23, 195308},
	{"BIDZ", 4, 195309},
	{"BARAHONA", 8, 195310},
	{"RHINOSKIN", 9, 195311},
	{"BIRCHFIELD", 10, 195312},
	{"WORLDFORGE", 10, 195313},
	{"FARIAS", 6, 195314},
	{"RHODOBACTER", 11, 195315},
	{"BURCKHARDT", 10, 195316},
	{"MCGRUFF", 7, 195317},
	{"TPDU", 4, 195318},
	{"MDOFPC", 6, 195319},
	{"HIPPED", 6, 195320},
	{"NNRTI", 5, 195321},
	{"MSPB", 4, 195322},
	{"MANARA", 6, 195323},
	{"CHANDRAN", 8, 195324},
	{"SOCIALITY", 9, 195325},
	{"YUFFIE", 6, 195326},
	{"WYANT", 5, 195327},
	{"DOCKETING", 9, 195328},
	{"ABSURDIST", 9, 195329},
	{"MOHIT", 5, 195330},
	{"TYROSINASE", 10, 195331},
	{"ACCUSATORY", 10, 195332},
	{"PREFILTER", 9, 195333},
	{"INETADDRESS", 11, 195334},
	{"POULTICE", 8, 195335},
	{"DULAC", 5, 195336},
	{"AGND", 4, 195337},
	{"SEZER", 5, 195338},
	{"MINISTRATIONS", 13, 195339},
	{"LICIT", 5, 195340},
	{"NOVATCHEV", 9, 195341},
	{"ARTSCROLL", 9, 195342},
	{"BUZIOS", 6, 195343},
	{"PUFFBESUCH", 10, 195344},
	{"GENDARMES", 9, 195345},
	{"SCHAPELLE", 9, 195346},
	{"LABORATORIUM", 12, 195347},
	{"BOVEE", 5, 195348},
	{"STARSIGN", 8, 195349},
	{"ENDOSCOPES", 10, 195350},
	{"FINGERPICKING", 13, 195351},
	{"DADAMOBILE", 10, 195352},
	{"ZLOTYCH", 7, 195353},
	{"FARB", 4, 195354},
	{"DISCOUNTURI", 11, 195355},
	{"HOONAH", 6, 195356},
	{"NITRIDES", 8, 195357},
	{"TELEMACHUS", 10, 195358},
	{"NITROSO", 7, 195359},
	{"PROBAR", 6, 195360},
	{"PUBBLICI", 8, 195361},
	{"TEOTIHUACAN", 11, 195362},
	{"FLEXY", 5, 195363},
	{"BIPARTISANSHIP", 14, 195364},
	{"MULTISPECIES", 12, 195365},
	{"DANAH", 5, 195366},
	{"AUSABLE", 7, 195367},
	{"LIBSOUP", 7, 195368},
	{"ANNUS", 5, 195369},
	{"TARNATION", 9, 195370},
	{"RUBYGEMS", 8, 195371},
	{"ROLEPLAYERS", 11, 195372},
	{"CJM", 3, 195373},
	{"ESSION", 6, 195374},
	{"BOGIES", 6, 195375},
	{"WAVELAN", 7, 195376},
	{"TROPO", 5, 195377},
	{"ELECTROENCEPHALOGRAM", 20, 195378},
	{"DILORENZO", 9, 195379},
	{"AURN", 4, 195380},
	{"MONTIEN", 7, 195381},
	{"KEANSBURG", 9, 195382},
	{"SADEK", 5, 195383},
	{"REIM", 4, 195384},
	{"WRONGNESS", 9, 195385},
	{"UNTRACEABLE", 11, 195386},
	{"RISCH", 5, 195387},
	{"DANNIE", 6, 195388},
	{"SOMMET", 6, 195389},
	{"MAGGIORI", 8, 195390},
	{"SUBLETHAL", 9, 195391},
	{"FRINTON", 7, 195392},
	{"CAROLL", 6, 195393},
	{"RULA", 4, 195394},
	{"ZIGH", 4, 195395},
	{"ZHUS", 4, 195396},
	{"YTVI", 4, 195397},
	{"XNAM", 4, 195398},
	{"WTHG", 4, 195399},
	{"WELU", 4, 195400},
	{"WEIF", 4, 195401},
	{"VOSC", 4, 195402},
	{"UTPS", 4, 195403},
	{"UPLL", 4, 195404},
	{"UMIX", 4, 195405},
	{"TOVW", 4, 195406},
	{"TOVU", 4, 195407},
	{"THPY", 4, 195408},
	{"SYEM", 4, 195409},
	{"RWWE", 4, 195410},
	{"RTZR", 4, 195411},
	{"RAJC", 4, 195412},
	{"PYEX", 4, 195413},
	{"PHBY", 4, 195414},
	{"PEPH", 4, 195415},
	{"OVSU", 4, 195416},
	{"NSKM", 4, 195417},
	{"NKMR", 4, 195418},
	{"NDCV", 4, 195419},
	{"MUPC", 4, 195420},
	{"MPJA", 4, 195421},
	{"LMUH", 4, 195422},
	{"LMCN", 4, 195423},
	{"LIGM", 4, 195424},
	{"KZOO", 4, 195425},
	{"KASV", 4, 195426},
	{"JBRO", 4, 195427},
	{"ISYB", 4, 195428},
	{"HFAK", 4, 195429},
	{"DWTS", 4, 195430},
	{"DRWO", 4, 195431},
	{"DOGY", 4, 195432},
	{"CBUN", 4, 195433},
	{"BEPM", 4, 195434},
	{"BBEV", 4, 195435},
	{"AUMH", 4, 195436},
	{"AKKN", 4, 195437},
	{"ABGO", 4, 195438},
	{"REMONSTRANCE", 12, 195439},
	{"MUNGING", 7, 195440},
	{"EROTIKCHAT", 10, 195441},
	{"CEPEDA", 6, 195442},
	{"CAPITULATED", 11, 195443},
	{"TWIKIVARIABLESATOM", 18, 195444},
	{"MICHELSEN", 9, 195445},
	{"PERSONNELS", 10, 195446},
	{"KARNA", 5, 195447},
	{"ALBENDAZOLE", 11, 195448},
	{"KRIEGEL", 7, 195449},
	{"FLEETWAY", 8, 195450},
	{"OUTHOUSES", 9, 195451},
	{"FARMINGVILLE", 12, 195452},
	{"CERNO", 5, 195453},
	{"NAGAO", 5, 195454},
	{"SUPERCOLLIDER", 13, 195455},
	{"KAIROMONE", 9, 195456},
	{"PEVSNER", 7, 195457},
	{"PSFK", 4, 195458},
	{"DOTPROJECT", 10, 195459},
	{"LOVELAB", 7, 195460},
	{"GARTREF", 7, 195461},
	{"GENEFINDER", 10, 195462},
	{"SMPP", 4, 195463},
	{"MEDICAMENTS", 11, 195464},
	{"DONTCHA", 7, 195465},
	{"AGNETHA", 7, 195466},
	{"TWATT", 5, 195467},
	{"MATINGS", 7, 195468},
	{"KASARA", 6, 195469},
	{"ABSTINENT", 9, 195470},
	{"RAYZ", 4, 195471},
	{"WOVERLOADED", 11, 195472},
	{"TYPUS", 5, 195473},
	{"EXNER", 5, 195474},
	{"CHUPA", 5, 195475},
	{"DIABLERETS", 10, 195476},
	{"DIDLO", 5, 195477},
	{"CESENA", 6, 195478},
	{"PVSS", 4, 195479},
	{"PENSIONES", 9, 195480},
	{"JEOL", 4, 195481},
	{"LOZADA", 6, 195482},
	{"HENNEY", 6, 195483},
	{"REPARATIVE", 10, 195484},
	{"EMPYREAN", 8, 195485},
	{"DECEIVERS", 9, 195486},
	{"HOMEFOCUS", 9, 195487},
	{"CHICAGOAN", 9, 195488},
	{"ACCOMDATION", 11, 195489},
	{"FURUTA", 6, 195490},
	{"MPSM", 4, 195491},
	{"NUPTSE", 6, 195492},
	{"PRETTILY", 8, 195493},
	{"LITWIN", 6, 195494},
	{"BEHALFE", 7, 195495},
	{"LJUNGBERG", 9, 195496},
	{"STEROWNIKI", 10, 195497},
	{"OKUN", 4, 195498},
	{"JAVY", 4, 195499},
	{"NONRELIGIOUS", 12, 195500},
	{"REEKING", 7, 195501},
	{"FOTHERGILL", 10, 195502},
	{"DISGUSTINGLY", 12, 195503},
	{"QCOUNT", 6, 195504},
	{"PHYTOCHEMISTRY", 14, 195505},
	{"SYMBOLISED", 10, 195506},
	{"ALBINA", 6, 195507},
	{"PROPO", 5, 195508},
	{"INNOVATIVENESS", 14, 195509},
	{"FARHAN", 6, 195510},
	{"NUMBERPLATE", 11, 195511},
	{"CHEAPSIDE", 9, 195512},
	{"TRANSPACIFIC", 12, 195513},
	{"DIFFRENCE", 9, 195514},
	{"COMMERCIALISE", 13, 195515},
	{"AITUTAKI", 8, 195516},
	{"OFILE", 5, 195517},
	{"LIFESCAN", 8, 195518},
	{"KDOC", 4, 195519},
	{"SANPETE", 7, 195520},
	{"HORRORFIND", 10, 195521},
	{"FLOREZ", 6, 195522},
	{"ATILDE", 6, 195523},
	{"ICENI", 5, 195524},
	{"PENDERS", 7, 195525},
	{"LIBSSL", 6, 195526},
	{"CEPSTRAL", 8, 195527},
	{"BENNETTSVILLE", 13, 195528},
	{"NSLUG", 5, 195529},
	{"CITIE", 5, 195530},
	{"RETRAINED", 9, 195531},
	{"CHEON", 5, 195532},
	{"NROWS", 5, 195533},
	{"CAMPOBELLO", 10, 195534},
	{"STONERIDGE", 10, 195535},
	{"OUTCLASSED", 10, 195536},
	{"ZUERST", 6, 195537},
	{"LINZI", 5, 195538},
	{"MERIONETHSHIRE", 14, 195539},
	{"COPPED", 6, 195540},
	{"SCANNABLE", 9, 195541},
	{"RATCHASIMA", 10, 195542},
	{"WUNDERKIND", 10, 195543},
	{"REVOLUCION", 10, 195544},
	{"POSTBACK", 8, 195545},
	{"BLANKENHORN", 11, 195546},
	{"PERSUADER", 9, 195547},
	{"YAZD", 4, 195548},
	{"HLDS", 4, 195549},
	{"BOCS", 4, 195550},
	{"ROJECTS", 7, 195551},
	{"MCGILLIVRAY", 11, 195552},
	{"GPSTORE", 7, 195553},
	{"LIZZARD", 7, 195554},
	{"ECMS", 4, 195555},
	{"WHITSETT", 8, 195556},
	{"MIRACOIL", 8, 195557},
	{"IBICO", 5, 195558},
	{"SIEGRIST", 8, 195559},
	{"WALLONIA", 8, 195560},
	{"SARAHJANE", 9, 195561},
	{"GRAHN", 5, 195562},
	{"DALEITHIAU", 10, 195563},
	{"ADELIA", 6, 195564},
	{"SOUTHPOLE", 9, 195565},
	{"ZZYT", 4, 195566},
	{"ZZOC", 4, 195567},
	{"YNGR", 4, 195568},
	{"YMIZ", 4, 195569},
	{"YEUC", 4, 195570},
	{"YEEU", 4, 195571},
	{"UOFH", 4, 195572},
	{"TUPK", 4, 195573},
	{"THGP", 4, 195574},
	{"OOXY", 4, 195575},
	{"ONKD", 4, 195576},
	{"ONCZ", 4, 195577},
	{"OBPU", 4, 195578},
	{"OBPI", 4, 195579},
	{"LOZZ", 4, 195580},
	{"LNEP", 4, 195581},
	{"LCMA", 4, 195582},
	{"KULS", 4, 195583},
	{"IJUL", 4, 195584},
	{"HOGF", 4, 195585},
	{"HEBV", 4, 195586},
	{"FBYL", 4, 195587},
	{"FAYS", 4, 195588},
	{"ESKJ", 4, 195589},
	{"DDRT", 4, 195590},
	{"DACM", 4, 195591},
	{"CTGL", 4, 195592},
	{"COTB", 4, 195593},
	{"BPIC", 4, 195594},
	{"BFEE", 4, 195595},
	{"BETL", 4, 195596},
	{"AOBL", 4, 195597},
	{"AJJI", 4, 195598},
	{"MORELS", 6, 195599},
	{"MITOGENS", 8, 195600},
	{"RAVDA", 5, 195601},
	{"PIPERAZINE", 10, 195602},
	{"TAPPEN", 6, 195603},
	{"METHYLCELLULOSE", 15, 195604},
	{"VERWANDTE", 9, 195605},
	{"KHOURI", 6, 195606},
	{"BIOBASED", 8, 195607},
	{"UPDATERS", 8, 195608},
	{"GASSY", 5, 195609},
	{"BAERTRACKS", 10, 195610},
	{"BEMOANED", 8, 195611},
	{"PERSEKUTUAN", 11, 195612},
	{"FRIZZLE", 7, 195613},
	{"ALESIA", 6, 195614},
	{"NODETYPE", 8, 195615},
	{"GAMEPARK", 8, 195616},
	{"AARTI", 5, 195617},
	{"UNAMSIL", 7, 195618},
	{"DISCRAFT", 8, 195619},
	{"SCHLUETER", 9, 195620},
	{"INVITRO", 7, 195621},
	{"TAKAMATSU", 9, 195622},
	{"SHIHAB", 6, 195623},
	{"LASORDA", 7, 195624},
	{"SOFTCOLORS", 10, 195625},
	{"TMPC", 4, 195626},
	{"TFIXEDIMAGE", 11, 195627},
	{"LMDC", 4, 195628},
	{"COVENEY", 7, 195629},
	{"SARGENTS", 8, 195630},
	{"ESPERAR", 7, 195631},
	{"CAMH", 4, 195632},
	{"BSCAT", 5, 195633},
	{"BEDDEN", 6, 195634},
	{"ULTRAPURE", 9, 195635},
	{"MARIUPOL", 8, 195636},
	{"ELLIMAN", 7, 195637},
	{"BKGD", 4, 195638},
	{"EPISTOLARY", 10, 195639},
	{"WENDLING", 8, 195640},
	{"KRAVIS", 6, 195641},
	{"UCREL", 5, 195642},
	{"RMATION", 7, 195643},
	{"PRCA", 4, 195644},
	{"ATACAND", 7, 195645},
	{"WHISTON", 7, 195646},
	{"DISEGNI", 7, 195647},
	{"BLEARS", 6, 195648},
	{"MELYSSA", 7, 195649},
	{"CORNEAS", 7, 195650},
	{"NITPICKER", 9, 195651},
	{"MEIRA", 5, 195652},
	{"SYSTRAQ", 7, 195653},
	{"BOLLYSCENE", 10, 195654},
	{"PARAMO", 6, 195655},
	{"ELEMENTI", 8, 195656},
	{"ECCL", 4, 195657},
	{"MERCKX", 6, 195658},
	{"CABELLO", 7, 195659},
	{"FLUTTERS", 8, 195660},
	{"SCOOTED", 7, 195661},
	{"HAIRCOLOR", 9, 195662},
	{"AUSTINTOWN", 10, 195663},
	{"DAIEI", 5, 195664},
	{"TDIMENSION", 10, 195665},
	{"AGREEMENTPRIVACY", 16, 195666},
	{"SUNSHADES", 9, 195667},
	{"KATARZYNA", 9, 195668},
	{"INTELLICAD", 10, 195669},
	{"STEFFY", 6, 195670},
	{"ENTFERNEN", 9, 195671},
	{"HURENSUCHE", 10, 195672},
	{"GVIM", 4, 195673},
	{"FASTIDIOSA", 10, 195674},
	{"HEXACHLOROBENZENE", 17, 195675},
	{"GLUCOSIDE", 9, 195676},
	{"CKB", 3, 195677},
	{"ISTICS", 6, 195678},
	{"GUMBALLS", 8, 195679},
	{"DECERTIFICATION", 15, 195680},
	{"CALIBERRM", 9, 195681},
	{"SHADINGS", 8, 195682},
	{"JERSY", 5, 195683},
	{"IMPINGES", 8, 195684},
	{"FAIRLEE", 7, 195685},
	{"CIRCUITING", 10, 195686},
	{"CORNHUSKER", 10, 195687},
	{"ZTAK", 4, 195688},
	{"YUMB", 4, 195689},
	{"YOFX", 4, 195690},
	{"WPIP", 4, 195691},
	{"VDEB", 4, 195692},
	{"UXWO", 4, 195693},
	{"ULKM", 4, 195694},
	{"UAKA", 4, 195695},
	{"TKMI", 4, 195696},
	{"SYQU", 4, 195697},
	{"SKUP", 4, 195698},
	{"SDBU", 4, 195699},
	{"RZEB", 4, 195700},
	{"RORQ", 4, 195701},
	{"RMCP", 4, 195702},
	{"RIKP", 4, 195703},
	{"PMBL", 4, 195704},
	{"PHMS", 4, 195705},
	{"OXOP", 4, 195706},
	{"OFNR", 4, 195707},
	{"NEGM", 4, 195708},
	{"MGOS", 4, 195709},
	{"KOUM", 4, 195710},
	{"IBUA", 4, 195711},
	{"GIQU", 4, 195712},
	{"FLYJ", 4, 195713},
	{"FCEO", 4, 195714},
	{"ETLC", 4, 195715},
	{"DPSP", 4, 195716},
	{"DLAX", 4, 195717},
	{"DAVU", 4, 195718},
	{"CBUY", 4, 195719},
	{"ARRN", 4, 195720},
	{"ALUW", 4, 195721},
	{"AKLU", 4, 195722},
	{"JUBEI", 5, 195723},
	{"HISTORICISM", 11, 195724},
	{"XHILARATION", 11, 195725},
	{"OTOLOGY", 7, 195726},
	{"LEDESMA", 7, 195727},
	{"FARLAND", 7, 195728},
	{"VELDEN", 6, 195729},
	{"JAYANT", 6, 195730},
	{"GYAPOWER", 8, 195731},
	{"KARMEN", 6, 195732},
	{"DUTOIT", 6, 195733},
	{"MISLEADINGLY", 12, 195734},
	{"ELEMENTE", 8, 195735},
	{"RUXPIN", 6, 195736},
	{"DICKSS", 6, 195737},
	{"MAITRESSE", 9, 195738},
	{"REAPPEARING", 11, 195739},
	{"MAIMON", 6, 195740},
	{"DUDGEON", 7, 195741},
	{"YUSUFALI", 8, 195742},
	{"JAMALI", 6, 195743},
	{"HAMMAN", 6, 195744},
	{"DELTACOM", 8, 195745},
	{"THALI", 5, 195746},
	{"BELLBROOK", 9, 195747},
	{"GUARDFORCE", 10, 195748},
	{"PILASTERS", 9, 195749},
	{"DARKLIS", 7, 195750},
	{"SPICING", 7, 195751},
	{"SCHALK", 6, 195752},
	{"RANIER", 6, 195753},
	{"SITERANK", 8, 195754},
	{"TEMPLIN", 7, 195755},
	{"CHEWERS", 7, 195756},
	{"FRIVOL", 6, 195757},
	{"THEBAN", 6, 195758},
	{"ALCUNI", 6, 195759},
	{"TODOROV", 7, 195760},
	{"MEDABOTS", 8, 195761},
	{"TWIDDLING", 9, 195762},
	{"FULMINANT", 9, 195763},
	{"AKTMODELLE", 10, 195764},
	{"KENNIS", 6, 195765},
	{"MILLFIELD", 9, 195766},
	{"GROVEPORT", 9, 195767},
	{"LINGARD", 7, 195768},
	{"WIELAARD", 8, 195769},
	{"BISECTED", 8, 195770},
	{"TARLTON", 7, 195771},
	{"SATARA", 6, 195772},
	{"PICCO", 5, 195773},
	{"CARTRIGES", 9, 195774},
	{"COCKKS", 6, 195775},
	{"AFROL", 5, 195776},
	{"KELLAR", 6, 195777},
	{"UNWISELY", 8, 195778},
	{"PRIVATMODELL", 12, 195779},
	{"IELD", 4, 195780},
	{"EMAILERS", 8, 195781},
	{"ROXX", 4, 195782},
	{"REMINISCES", 10, 195783},
	{"BETWEN", 6, 195784},
	{"RELIVED", 7, 195785},
	{"BRAR", 4, 195786},
	{"TRENCHCOAT", 10, 195787},
	{"JAHANGIR", 8, 195788},
	{"STROP", 5, 195789},
	{"MAPNEW", 6, 195790},
	{"CSUB", 4, 195791},
	{"CSCOPE", 6, 195792},
	{"GRAVEDIGGER", 11, 195793},
	{"ZOETERMEER", 10, 195794},
	{"JIAXING", 7, 195795},
	{"HORSEFLY", 8, 195796},
	{"ESTERIFICATION", 14, 195797},
	{"BURAK", 5, 195798},
	{"UNCAUGHT", 8, 195799},
	{"GRAMMARIAN", 10, 195800},
	{"FIGLIO", 6, 195801},
	{"UNBC", 4, 195802},
	{"PARABENS", 8, 195803},
	{"YYYYMMDDHHMMSST", 15, 195804},
	{"ESTACION", 8, 195805},
	{"PERUVIANS", 9, 195806},
	{"MIRCO", 5, 195807},
	{"MACDOUGAL", 9, 195808},
	{"HAINING", 7, 195809},
	{"KRAAN", 5, 195810},
	{"LOKO", 4, 195811},
	{"BENCE", 5, 195812},
	{"LANGONE", 7, 195813},
	{"CHEPELARE", 9, 195814},
	{"RESOUCE", 7, 195815},
	{"MINIDOKA", 8, 195816},
	{"ACCELERADE", 10, 195817},
	{"TOTTON", 6, 195818},
	{"SIGMAN", 6, 195819},
	{"SILVERMOON", 10, 195820},
	{"WELLGO", 6, 195821},
	{"OUTGASSING", 10, 195822},
	{"LATERAN", 7, 195823},
	{"JEWTOPIA", 8, 195824},
	{"DREAMWAVE", 9, 195825},
	{"DARDENNE", 8, 195826},
	{"WOOLSTON", 8, 195827},
	{"AUTOWORLD", 9, 195828},
	{"BUGGERED", 8, 195829},
	{"MANUGISTICS", 11, 195830},
	{"RAEKA", 5, 195831},
	{"WAINSCOTING", 11, 195832},
	{"TARTARIC", 8, 195833},
	{"UILDING", 7, 195834},
	{"DICITONARY", 10, 195835},
	{"ACPD", 4, 195836},
	{"WOCK", 4, 195837},
	{"WILN", 4, 195838},
	{"WIEK", 4, 195839},
	{"VDVE", 4, 195840},
	{"SLLA", 4, 195841},
	{"RZIL", 4, 195842},
	{"RAAY", 4, 195843},
	{"PPME", 4, 195844},
	{"OYOC", 4, 195845},
	{"NSWP", 4, 195846},
	{"NECM", 4, 195847},
	{"LTFU", 4, 195848},
	{"LNUD", 4, 195849},
	{"LMYG", 4, 195850},
	{"LJEV", 4, 195851},
	{"LAOV", 4, 195852},
	{"KHIP", 4, 195853},
	{"FONR", 4, 195854},
	{"FLSS", 4, 195855},
	{"FLSP", 4, 195856},
	{"ERPK", 4, 195857},
	{"DVAD", 4, 195858},
	{"DNOY", 4, 195859},
	{"CZWA", 4, 195860},
	{"CIWI", 4, 195861},
	{"CBYW", 4, 195862},
	{"BYBH", 4, 195863},
	{"BMWH", 4, 195864},
	{"AUTB", 4, 195865},
	{"ATVW", 4, 195866},
	{"BARGAINLAND", 11, 195867},
	{"RAINMAN", 7, 195868},
	{"ISMAY", 5, 195869},
	{"WINDOWSNT", 9, 195870},
	{"MERLEAU", 7, 195871},
	{"MAMADA", 6, 195872},
	{"LUNATECH", 8, 195873},
	{"AIRHEADED", 9, 195874},
	{"AHCPR", 5, 195875},
	{"FRANCKE", 7, 195876},
	{"TABULOSE", 8, 195877},
	{"ROYALBLUE", 9, 195878},
	{"REVERBERATED", 12, 195879},
	{"JELMER", 6, 195880},
	{"APJS", 4, 195881},
	{"PLENITUDE", 9, 195882},
	{"FACKLER", 7, 195883},
	{"PATERA", 6, 195884},
	{"SPHINGOSINE", 11, 195885},
	{"FAIM", 4, 195886},
	{"THROWBACKS", 10, 195887},
	{"ROSEBUSH", 8, 195888},
	{"QRECT", 5, 195889},
	{"TOOGLE", 6, 195890},
	{"KAPA", 4, 195891},
	{"GPOS", 4, 195892},
	{"HAZELTINE", 9, 195893},
	{"JONTI", 5, 195894},
	{"IOMMI", 5, 195895},
	{"ATSUKO", 6, 195896},
	{"ZIPDATA", 7, 195897},
	{"TSUKAMOTO", 9, 195898},
	{"GHAZPORK", 8, 195899},
	{"GAMEQUEST", 9, 195900},
	{"DUNNER", 6, 195901},
	{"TITJOB", 6, 195902},
	{"LUSBY", 5, 195903},
	{"ITURI", 5, 195904},
	{"EMBERIZA", 8, 195905},
	{"DUNNELLON", 9, 195906},
	{"SYNTHASES", 9, 195907},
	{"BEAV", 4, 195908},
	{"THORNBURGH", 10, 195909},
	{"STRESA", 6, 195910},
	{"BENCHERS", 8, 195911},
	{"ADALBERT", 8, 195912},
	{"DARCI", 5, 195913},
	{"STRATIFY", 8, 195914},
	{"SHROOK", 6, 195915},
	{"UNPARDONABLE", 12, 195916},
	{"SEIYUU", 6, 195917},
	{"ADELIE", 6, 195918},
	{"NIMBIN", 6, 195919},
	{"LOFOTEN", 7, 195920},
	{"HARDYS", 6, 195921},
	{"ROBARTS", 7, 195922},
	{"GLISTENS", 8, 195923},
	{"BABELCVS", 8, 195924},
	{"TOHONO", 6, 195925},
	{"PERSUE", 6, 195926},
	{"LINEZOLID", 9, 195927},
	{"COLANDERS", 9, 195928},
	{"GODZ", 4, 195929},
	{"BILIRAKIS", 9, 195930},
	{"VOLGENS", 7, 195931},
	{"VIACREME", 8, 195932},
	{"OPENSYMPHONY", 12, 195933},
	{"DOTOR", 5, 195934},
	{"BYLINES", 7, 195935},
	{"ALAP", 4, 195936},
	{"GRAFIKEN", 8, 195937},
	{"GRISEOFULVIN", 12, 195938},
	{"PARTICIPAR", 10, 195939},
	{"BOWMEN", 6, 195940},
	{"FARMLET", 7, 195941},
	{"TEMESCAL", 8, 195942},
	{"SIGNATUR", 8, 195943},
	{"AUTOPAY", 7, 195944},
	{"JAQUETTE", 8, 195945},
	{"FORLI", 5, 195946},
	{"STATECHARTS", 11, 195947},
	{"SPID", 4, 195948},
	{"XRC", 3, 195949},
	{"SINDICATO", 9, 195950},
	{"POORMAN", 7, 195951},
	{"SNOOZING", 8, 195952},
	{"COPYCATS", 8, 195953},
	{"BOWLAND", 7, 195954},
	{"TAJIRI", 6, 195955},
	{"NOKES", 5, 195956},
	{"LIMINAL", 7, 195957},
	{"CYCBUFF", 7, 195958},
	{"PREMEDICAL", 10, 195959},
	{"AMBASSADEUR", 11, 195960},
	{"FINZI", 5, 195961},
	{"CARRAGHER", 9, 195962},
	{"BLUNDERING", 10, 195963},
	{"HARDANGER", 9, 195964},
	{"GAMESGAMES", 10, 195965},
	{"FUNSTUFF", 8, 195966},
	{"SULTING", 7, 195967},
	{"COEFFI", 6, 195968},
	{"CHPS", 4, 195969},
	{"DISHEVELLED", 11, 195970},
	{"DIACONATE", 9, 195971},
	{"CENTRING", 8, 195972},
	{"ACOMADATION", 11, 195973},
	{"COMBINATORS", 11, 195974},
	{"BOSSMAN", 7, 195975},
	{"RICCARDI", 8, 195976},
	{"PROSONIQ", 8, 195977},
	{"LIMONE", 6, 195978},
	{"AKLAN", 5, 195979},
	{"STARHUB", 7, 195980},
	{"MERRIWEATHER", 12, 195981},
	{"SETCARD", 7, 195982},
	{"MEDLEM", 6, 195983},
	{"BROMFIELD", 9, 195984},
	{"KYLER", 5, 195985},
	{"EYTON", 5, 195986},
	{"GLYNDON", 7, 195987},
	{"EMBOLDEN", 8, 195988},
	{"OFFPRINT", 8, 195989},
	{"KONGRESS", 8, 195990},
	{"EXORCISE", 8, 195991},
	{"DIEST", 5, 195992},
	{"SCURRILOUS", 10, 195993},
	{"SAHAJA", 6, 195994},
	{"GESTS", 5, 195995},
	{"CINEM", 5, 195996},
	{"YMSS", 4, 195997},
	{"XXIS", 4, 195998},
	{"XTAM", 4, 195999},
	{"WWRA", 4, 196000},
	{"WBEY", 4, 196001},
	{"UYAI", 4, 196002},
	{"UOUN", 4, 196003},
	{"TJRA", 4, 196004},
	{"SUMD", 4, 196005},
	{"SSMD", 4, 196006},
	{"SEGF", 4, 196007},
	{"RHIJ", 4, 196008},
	{"POGG", 4, 196009},
	{"PCOW", 4, 196010},
	{"OKNU", 4, 196011},
	{"OKIV", 4, 196012},
	{"OFJH", 4, 196013},
	{"NIKM", 4, 196014},
	{"NDQB", 4, 196015},
	{"MPSV", 4, 196016},
	{"MMMT", 4, 196017},
	{"MIEK", 4, 196018},
	{"LTGI", 4, 196019},
	{"KOKH", 4, 196020},
	{"KIJI", 4, 196021},
	{"IJKS", 4, 196022},
	{"HPIX", 4, 196023},
	{"HMSL", 4, 196024},
	{"GILK", 4, 196025},
	{"ESWP", 4, 196026},
	{"DDDR", 4, 196027},
	{"DCID", 4, 196028},
	{"DBHU", 4, 196029},
	{"CCTR", 4, 196030},
	{"BSRU", 4, 196031},
	{"BPSO", 4, 196032},
	{"BPSH", 4, 196033},
	{"BOMM", 4, 196034},
	{"BCOV", 4, 196035},
	{"AUXN", 4, 196036},
	{"UNCANNILY", 9, 196037},
	{"HOSOKAWA", 8, 196038},
	{"OAKHILL", 7, 196039},
	{"SPANOS", 6, 196040},
	{"ABELE", 5, 196041},
	{"VIAJAR", 6, 196042},
	{"SERVNT", 6, 196043},
	{"ALTOUGH", 7, 196044},
	{"XANTHI", 6, 196045},
	{"SQUALLS", 7, 196046},
	{"INTERNETTERS", 12, 196047},
	{"UCOP", 4, 196048},
	{"DURBANVILLE", 11, 196049},
	{"KIRSCHENBAUM", 12, 196050},
	{"PLAZES", 6, 196051},
	{"INOVIX", 6, 196052},
	{"TINKERED", 8, 196053},
	{"IOFILM", 6, 196054},
	{"PEROXIDASES", 11, 196055},
	{"YOURNAME", 8, 196056},
	{"BICKERTON", 9, 196057},
	{"APCALIS", 7, 196058},
	{"QIMAGE", 6, 196059},
	{"PYROMANIA", 9, 196060},
	{"FUNEN", 5, 196061},
	{"COMPELLINGLY", 12, 196062},
	{"COFEE", 5, 196063},
	{"DALILA", 6, 196064},
	{"SEATERS", 7, 196065},
	{"SBIC", 4, 196066},
	{"FLOORBOARD", 10, 196067},
	{"CAHALAN", 7, 196068},
	{"MORIAL", 6, 196069},
	{"EMJOI", 5, 196070},
	{"ATHANASIOS", 10, 196071},
	{"FUNKO", 5, 196072},
	{"RIERA", 5, 196073},
	{"LIVEVAULT", 9, 196074},
	{"ELUL", 4, 196075},
	{"OKEMAH", 6, 196076},
	{"FLUPHENAZINE", 12, 196077},
	{"NAPPER", 6, 196078},
	{"ALLOMONE", 8, 196079},
	{"CONFERRAL", 9, 196080},
	{"TRENCHLESS", 10, 196081},
	{"EYEWIRE", 7, 196082},
	{"RVERS", 5, 196083},
	{"PORTACRIBS", 10, 196084},
	{"MJP", 3, 196085},
	{"VEDRAL", 6, 196086},
	{"TRANSLOCATING", 13, 196087},
	{"NANDOR", 6, 196088},
	{"MOSBERGER", 9, 196089},
	{"EXPERTRATING", 12, 196090},
	{"VGR", 3, 196091},
	{"LEROS", 5, 196092},
	{"VERSILIA", 8, 196093},
	{"CONCANNON", 9, 196094},
	{"PARLA", 5, 196095},
	{"LACTONES", 8, 196096},
	{"HOMESCREEN", 10, 196097},
	{"ULTRASOFT", 9, 196098},
	{"JOYE", 4, 196099},
	{"PVCU", 4, 196100},
	{"STAAB", 5, 196101},
	{"SEAGRAVES", 9, 196102},
	{"LECCO", 5, 196103},
	{"SYNOMONE", 8, 196104},
	{"WIENONLINE", 10, 196105},
	{"VMM", 3, 196106},
	{"SQDN", 4, 196107},
	{"PREFORMANCE", 11, 196108},
	{"MANUFACTUER", 11, 196109},
	{"LAWER", 5, 196110},
	{"SUMERS", 6, 196111},
	{"RECOMM", 6, 196112},
	{"CELEBRITYWONDER", 15, 196113},
	{"TRANSHIPMENT", 12, 196114},
	{"FORELAND", 8, 196115},
	{"RUEDIGER", 8, 196116},
	{"AMARC", 5, 196117},
	{"RUMBAUGH", 8, 196118},
	{"FRAUNCE", 7, 196119},
	{"DICKKS", 6, 196120},
	{"ADDENBROOKE", 11, 196121},
	{"DUERO", 5, 196122},
	{"VIDEONTSC", 9, 196123},
	{"CYCADS", 6, 196124},
	{"INVISIBLESPACE", 14, 196125},
	{"PLUSNET", 7, 196126},
	{"NWOBHM", 6, 196127},
	{"VAREKAI", 7, 196128},
	{"VIDEOROLL", 9, 196129},
	{"ANELE", 5, 196130},
	{"QUALIT", 6, 196131},
	{"GDSLOGO", 7, 196132},
	{"TULOGO", 6, 196133},
	{"VASTE", 5, 196134},
	{"KEELGROUP", 9, 196135},
	{"RIGOURS", 7, 196136},
	{"LISHMENTS", 9, 196137},
	{"JEDES", 5, 196138},
	{"KADAR", 5, 196139},
	{"REGISTERATION", 13, 196140},
	{"CANARIE", 7, 196141},
	{"NUTRASWEET", 10, 196142},
	{"KRAFTY", 6, 196143},
	{"DVDX", 4, 196144},
	{"MWRA", 4, 196145},
	{"KOKODA", 6, 196146},
	{"CONSTANTINO", 11, 196147},
	{"PROVINCIALE", 11, 196148},
	{"EQUADOR", 7, 196149},
	{"YBOH", 4, 196150},
	{"XYWA", 4, 196151},
	{"UVEO", 4, 196152},
	{"UIKS", 4, 196153},
	{"UHRM", 4, 196154},
	{"TZFI", 4, 196155},
	{"TCSC", 4, 196156},
	{"SUIG", 4, 196157},
	{"SMRJ", 4, 196158},
	{"RRWO", 4, 196159},
	{"RMRW", 4, 196160},
	{"RCTR", 4, 196161},
	{"PPAK", 4, 196162},
	{"PMEC", 4, 196163},
	{"OGID", 4, 196164},
	{"NCFA", 4, 196165},
	{"MBOK", 4, 196166},
	{"LVOY", 4, 196167},
	{"LFIO", 4, 196168},
	{"LDTC", 4, 196169},
	{"LALV", 4, 196170},
	{"KWAJ", 4, 196171},
	{"KUAS", 4, 196172},
	{"GJUA", 4, 196173},
	{"GGYL", 4, 196174},
	{"FUPH", 4, 196175},
	{"FRYO", 4, 196176},
	{"FLIZ", 4, 196177},
	{"FBYO", 4, 196178},
	{"FAZO", 4, 196179},
	{"EZGE", 4, 196180},
	{"ERRL", 4, 196181},
	{"EJJA", 4, 196182},
	{"EGFA", 4, 196183},
	{"DPAH", 4, 196184},
	{"CSSW", 4, 196185},
	{"BOLB", 4, 196186},
	{"BOKI", 4, 196187},
	{"ANRR", 4, 196188},
	{"VPPON", 5, 196189},
	{"MADOC", 5, 196190},
	{"DERRICKS", 8, 196191},
	{"COUNTABLY", 9, 196192},
	{"ELECTRIQUE", 10, 196193},
	{"HOHMANN", 7, 196194},
	{"SHEWN", 5, 196195},
	{"PHLEBITIS", 9, 196196},
	{"ECOFIN", 6, 196197},
	{"GNOMEFILES", 10, 196198},
	{"LITERARIA", 9, 196199},
	{"BARNOLDSWICK", 12, 196200},
	{"TRENDMICRO", 10, 196201},
	{"SCHRIJF", 7, 196202},
	{"APLYSIA", 7, 196203},
	{"INTERWISE", 9, 196204},
	{"CEPHEIDS", 8, 196205},
	{"VECTORIZATION", 13, 196206},
	{"QUETZALCOATL", 12, 196207},
	{"PROXIMUS", 8, 196208},
	{"DOOLY", 5, 196209},
	{"VASUDEVA", 8, 196210},
	{"SIMPUTER", 8, 196211},
	{"EWAY", 4, 196212},
	{"EMAPS", 5, 196213},
	{"SAVINO", 6, 196214},
	{"DPREFIX", 7, 196215},
	{"RLINETO", 7, 196216},
	{"BARONETAGE", 10, 196217},
	{"PTRF", 4, 196218},
	{"CHEVETTE", 8, 196219},
	{"SOCIATED", 8, 196220},
	{"NOWLIN", 6, 196221},
	{"LIBCORELINUX", 12, 196222},
	{"FLUIDIC", 7, 196223},
	{"SOFTECH", 7, 196224},
	{"DESHA", 5, 196225},
	{"WINKELMAN", 9, 196226},
	{"EXPCITE", 7, 196227},
	{"PINNA", 5, 196228},
	{"IONESCU", 7, 196229},
	{"IMRA", 4, 196230},
	{"ERLEND", 6, 196231},
	{"ANTAR", 5, 196232},
	{"SERVERSIDE", 10, 196233},
	{"COMMONNAME", 10, 196234},
	{"WESTENDORF", 10, 196235},
	{"MIDWOOD", 7, 196236},
	{"MELSON", 6, 196237},
	{"THROMBOPLASTIN", 14, 196238},
	{"WALMER", 6, 196239},
	{"MIRAPLACID", 10, 196240},
	{"ISOCARBOXAZID", 13, 196241},
	{"ELPARENT", 8, 196242},
	{"ONLINEGAMBLING", 14, 196243},
	{"FFFI", 4, 196244},
	{"TMAKE", 5, 196245},
	{"THREADSINDEX", 12, 196246},
	{"BOOMI", 5, 196247},
	{"NADAV", 5, 196248},
	{"KABUSHIKI", 9, 196249},
	{"GADWALL", 7, 196250},
	{"DEHAVILLAND", 11, 196251},
	{"CONTACTE", 8, 196252},
	{"NOMES", 5, 196253},
	{"EYDIE", 5, 196254},
	{"JOBNAME", 7, 196255},
	{"CYPRINIDAE", 10, 196256},
	{"BRUNCHES", 8, 196257},
	{"RAVINDRA", 8, 196258},
	{"GROOMSMAN", 9, 196259},
	{"TOXEMIA", 7, 196260},
	{"RECOLETA", 8, 196261},
	{"POSSO", 5, 196262},
	{"OBJETOS", 7, 196263},
	{"BRIEFE", 6, 196264},
	{"SWITCHBD", 8, 196265},
	{"FORSCOM", 7, 196266},
	{"FILEUPLOAD", 10, 196267},
	{"AKADEMIIA", 9, 196268},
	{"TWATTS", 6, 196269},
	{"SCHOENWAELDER", 13, 196270},
	{"MRPHOTO", 7, 196271},
	{"DOWNLADS", 8, 196272},
	{"TRAIAN", 6, 196273},
	{"RADD", 4, 196274},
	{"BELLERIVE", 9, 196275},
	{"ARASHI", 6, 196276},
	{"TYGO", 4, 196277},
	{"STOCKHOLMS", 10, 196278},
	{"RAVANA", 6, 196279},
	{"MEVACOR", 7, 196280},
	{"MINIMO", 6, 196281},
	{"HANNAM", 6, 196282},
	{"OBEX", 4, 196283},
	{"PENZA", 5, 196284},
	{"FOLS", 4, 196285},
	{"VALETS", 6, 196286},
	{"ORGASEMS", 8, 196287},
	{"INTERCON", 8, 196288},
	{"GROEL", 5, 196289},
	{"ZZBE", 4, 196290},
	{"ZBEF", 4, 196291},
	{"YRSC", 4, 196292},
	{"YEPE", 4, 196293},
	{"WWTI", 4, 196294},
	{"WGLE", 4, 196295},
	{"VGAR", 4, 196296},
	{"VDRI", 4, 196297},
	{"UFIT", 4, 196298},
	{"UBYE", 4, 196299},
	{"THBC", 4, 196300},
	{"SWYN", 4, 196301},
	{"SSYK", 4, 196302},
	{"SIMK", 4, 196303},
	{"ROYY", 4, 196304},
	{"PASX", 4, 196305},
	{"NGYR", 4, 196306},
	{"NECB", 4, 196307},
	{"MAEG", 4, 196308},
	{"LLDY", 4, 196309},
	{"LEAQ", 4, 196310},
	{"KZAP", 4, 196311},
	{"KYSR", 4, 196312},
	{"JCRO", 4, 196313},
	{"IKHU", 4, 196314},
	{"FDAF", 4, 196315},
	{"FABF", 4, 196316},
	{"ENMM", 4, 196317},
	{"DRIY", 4, 196318},
	{"COMK", 4, 196319},
	{"ASKK", 4, 196320},
	{"SKRATCH", 7, 196321},
	{"ROENICK", 7, 196322},
	{"KODERS", 6, 196323},
	{"HARDFLOOR", 9, 196324},
	{"LMFT", 4, 196325},
	{"GOSWIN", 6, 196326},
	{"UNTERMINATED", 12, 196327},
	{"PERSONOL", 8, 196328},
	{"DPATCH", 6, 196329},
	{"BUDERIM", 7, 196330},
	{"MAZAMA", 6, 196331},
	{"CDBI", 4, 196332},
	{"FWM", 3, 196333},
	{"CWG", 3, 196334},
	{"WAINSCOTT", 9, 196335},
	{"SEARCHFIT", 9, 196336},
	{"HOOKA", 5, 196337},
	{"SYNCOPATION", 11, 196338},
	{"ROCKETT", 7, 196339},
	{"KULONGOSKI", 10, 196340},
	{"CORRUPTIBLE", 11, 196341},
	{"BUSED", 5, 196342},
	{"TOMME", 5, 196343},
	{"PEDLAR", 6, 196344},
	{"DUMBASSES", 9, 196345},
	{"SPRIN", 5, 196346},
	{"BIETE", 5, 196347},
	{"VERWENDUNG", 10, 196348},
	{"PRATICE", 7, 196349},
	{"LABETTE", 7, 196350},
	{"TOURISTIQUE", 11, 196351},
	{"MORRE", 5, 196352},
	{"WEATHERNET", 10, 196353},
	{"PYRUS", 5, 196354},
	{"KAFTAN", 6, 196355},
	{"JEJUNAL", 7, 196356},
	{"ACMI", 4, 196357},
	{"SHAFTSBURY", 10, 196358},
	{"AHMADIYYA", 9, 196359},
	{"ARTESANIA", 9, 196360},
	{"AFFIL", 5, 196361},
	{"SKOG", 4, 196362},
	{"JWJ", 3, 196363},
	{"DICTIONAY", 9, 196364},
	{"APUESTAS", 8, 196365},
	{"TRANGIA", 7, 196366},
	{"KITSILANO", 9, 196367},
	{"TEAKETTLE", 9, 196368},
	{"BARRES", 6, 196369},
	{"TIMHOTEL", 8, 196370},
	{"BIKEMAGIC", 9, 196371},
	{"DATACOMS", 8, 196372},
	{"NUTRICRAZE", 10, 196373},
	{"LLDPE", 5, 196374},
	{"GENZ", 4, 196375},
	{"BIRDCHAT", 8, 196376},
	{"SMOCKS", 6, 196377},
	{"APPLICATIVE", 11, 196378},
	{"RESOLV", 6, 196379},
	{"NACKTAUFNAHMEN", 14, 196380},
	{"GEISSLER", 8, 196381},
	{"BALKS", 5, 196382},
	{"STOCKLAND", 9, 196383},
	{"KASSANDRA", 9, 196384},
	{"ELBERTA", 7, 196385},
	{"XRONIA", 6, 196386},
	{"ONGUARD", 7, 196387},
	{"MICROALBUMINURIA", 16, 196388},
	{"IMPASSIVE", 9, 196389},
	{"GIBBY", 5, 196390},
	{"FAKER", 5, 196391},
	{"HECKLE", 6, 196392},
	{"BANYA", 5, 196393},
	{"ASSHATS", 7, 196394},
	{"SQUEEZER", 8, 196395},
	{"HETZEL", 6, 196396},
	{"RAYFORD", 7, 196397},
	{"TRELAWNY", 8, 196398},
	{"PYTHONPOWERED", 13, 196399},
	{"GARANTI", 7, 196400},
	{"FAINTS", 6, 196401},
	{"SEMISTRUCTURED", 14, 196402},
	{"CONFL", 5, 196403},
	{"TELEMANIA", 9, 196404},
	{"VICOMTE", 7, 196405},
	{"SMILAX", 6, 196406},
	{"UNECONOMICAL", 12, 196407},
	{"OXANDROLONE", 11, 196408},
	{"SCHOCKEN", 8, 196409},
	{"NICOLLS", 7, 196410},
	{"GLOBULE", 7, 196411},
	{"PILLORY", 7, 196412},
	{"LEEUWIN", 7, 196413},
	{"JONQUIL", 7, 196414},
	{"NONSCHEDULED", 12, 196415},
	{"ALKAHOLIKS", 10, 196416},
	{"DIEUX", 5, 196417},
	{"SIDNEI", 6, 196418},
	{"CYTOBAND", 8, 196419},
	{"XMLSCHEMA", 9, 196420},
	{"UGUST", 5, 196421},
	{"TKINED", 6, 196422},
	{"BRANCHENBUCH", 12, 196423},
	{"PAPWORTH", 8, 196424},
	{"MASCIS", 6, 196425},
	{"BOWATER", 7, 196426},
	{"SHEETLET", 8, 196427},
	{"MONISHA", 7, 196428},
	{"KARRAS", 6, 196429},
	{"TEENZ", 5, 196430},
	{"FRIGHTS", 7, 196431},
	{"BEDDINGTON", 10, 196432},
	{"BARDSLEY", 8, 196433},
	{"QUATER", 6, 196434},
	{"INQUIRERS", 9, 196435},
	{"FIAR", 4, 196436},
	{"BOBBS", 5, 196437},
	{"DJJ", 3, 196438},
	{"BECOM", 5, 196439},
	{"MICCOSUKEE", 10, 196440},
	{"KRAB", 4, 196441},
	{"BEACHAM", 7, 196442},
	{"BAMBARA", 7, 196443},
	{"SECUREMENT", 10, 196444},
	{"PRIVATKONTAKT", 13, 196445},
	{"UBND", 4, 196446},
	{"PRESBYTER", 9, 196447},
	{"ASSASSINATING", 13, 196448},
	{"BITTORNADO", 10, 196449},
	{"HOVIND", 6, 196450},
	{"JAVALIB", 7, 196451},
	{"YSOX", 4, 196452},
	{"YDGA", 4, 196453},
	{"UIWO", 4, 196454},
	{"TUTZ", 4, 196455},
	{"TUBT", 4, 196456},
	{"TGWE", 4, 196457},
	{"TDYL", 4, 196458},
	{"TADF", 4, 196459},
	{"RRVI", 4, 196460},
	{"RIMV", 4, 196461},
	{"RFOG", 4, 196462},
	{"PMDU", 4, 196463},
	{"PMCE", 4, 196464},
	{"OZEK", 4, 196465},
	{"OMDC", 4, 196466},
	{"OBOZ", 4, 196467},
	{"NCBO", 4, 196468},
	{"LAVL", 4, 196469},
	{"KYJU", 4, 196470},
	{"KMAU", 4, 196471},
	{"JJAN", 4, 196472},
	{"HNWR", 4, 196473},
	{"GOWF", 4, 196474},
	{"GMYJ", 4, 196475},
	{"GKYL", 4, 196476},
	{"GDEI", 4, 196477},
	{"FTSV", 4, 196478},
	{"FBOC", 4, 196479},
	{"ERJC", 4, 196480},
	{"EPMN", 4, 196481},
	{"CKAK", 4, 196482},
	{"BYZH", 4, 196483},
	{"AWIP", 4, 196484},
	{"ECORE", 5, 196485},
	{"WINTERM", 7, 196486},
	{"CLEANROOMS", 10, 196487},
	{"PRIVATCLUB", 10, 196488},
	{"FIRMSITE", 8, 196489},
	{"NCGA", 4, 196490},
	{"ATPM", 4, 196491},
	{"IMBECILES", 9, 196492},
	{"PHORM", 5, 196493},
	{"DOSWELL", 7, 196494},
	{"FORR", 4, 196495},
	{"BRIMS", 5, 196496},
	{"SCROPHULARIACEAE", 16, 196497},
	{"PERIPHYTON", 10, 196498},
	{"TERRORISTIC", 11, 196499},
	{"GREATHOUSE", 10, 196500},
	{"CUNTTS", 6, 196501},
	{"MEDICALS", 8, 196502},
	{"MIZOGUCHI", 9, 196503},
	{"TOURETTES", 9, 196504},
	{"VASIL", 5, 196505},
	{"SCSP", 4, 196506},
	{"POMADE", 6, 196507},
	{"PHYTOLOGIE", 10, 196508},
	{"NCITS", 5, 196509},
	{"CRAYTON", 7, 196510},
	{"FBOS", 4, 196511},
	{"BRAHMANA", 8, 196512},
	{"TOREN", 5, 196513},
	{"JOHANNSEN", 9, 196514},
	{"DESKUTILS", 9, 196515},
	{"SACBEE", 6, 196516},
	{"ONESOURCE", 9, 196517},
	{"MUSITION", 8, 196518},
	{"EECTS", 5, 196519},
	{"GOGOLE", 6, 196520},
	{"WARNUNG", 7, 196521},
	{"KUMITE", 6, 196522},
	{"FIDA", 4, 196523},
	{"ATTRACTANTS", 11, 196524},
	{"MEISLER", 7, 196525},
	{"ICHAEL", 6, 196526},
	{"DITIONARY", 9, 196527},
	{"BIMETALLIC", 10, 196528},
	{"WAITPID", 7, 196529},
	{"BALLATER", 8, 196530},
	{"DECEPTICON", 10, 196531},
	{"VERSUSLAW", 9, 196532},
	{"PROSTITUTED", 11, 196533},
	{"AERES", 5, 196534},
	{"QUARTERING", 10, 196535},
	{"SONNENFELD", 10, 196536},
	{"PVPS", 4, 196537},
	{"SPECKLES", 8, 196538},
	{"ARTSNEWS", 8, 196539},
	{"RESTORMEL", 9, 196540},
	{"PAROWAN", 7, 196541},
	{"MASTURBETION", 12, 196542},
	{"BELAIRE", 7, 196543},
	{"SCOBEY", 6, 196544},
	{"REGULATIVE", 10, 196545},
	{"SANDIP", 6, 196546},
	{"LIRPA", 5, 196547},
	{"EMPIRICIST", 10, 196548},
	{"DUNC", 4, 196549},
	{"AMORITES", 8, 196550},
	{"PBW", 3, 196551},
	{"METATRON", 8, 196552},
	{"CHAC", 4, 196553},
	{"PFG", 3, 196554},
	{"LIBXV", 5, 196555},
	{"CINTRON", 7, 196556},
	{"VISITTEAM", 9, 196557},
	{"QUEENSGATE", 10, 196558},
	{"BISTABLE", 8, 196559},
	{"DAWUD", 5, 196560},
	{"UTTON", 5, 196561},
	{"SAGUACHE", 8, 196562},
	{"GOWELL", 6, 196563},
	{"MALLOREIGH", 10, 196564},
	{"MAYANA", 6, 196565},
	{"MASSIOT", 7, 196566},
	{"DISAVOWED", 9, 196567},
	{"UNDULATIONS", 11, 196568},
	{"REDRESSED", 9, 196569},
	{"BEAMLINES", 9, 196570},
	{"NETNAME", 7, 196571},
	{"SDCFH", 5, 196572},
	{"CROSSFADER", 10, 196573},
	{"MYCOSIS", 7, 196574},
	{"XATTR", 5, 196575},
	{"FWYAF", 5, 196576},
	{"IMBOLC", 6, 196577},
	{"JODHPURS", 8, 196578},
	{"BARBERING", 9, 196579},
	{"WAIFS", 5, 196580},
	{"SPLENDENS", 9, 196581},
	{"SUBSEQUENCES", 12, 196582},
	{"KUEI", 4, 196583},
	{"MIRJAM", 6, 196584},
	{"FIFEDIRECT", 10, 196585},
	{"FAHR", 4, 196586},
	{"RUGOSA", 6, 196587},
	{"ROVNER", 6, 196588},
	{"MONTHLIES", 9, 196589},
	{"CITR", 4, 196590},
	{"GUSSIE", 6, 196591},
	{"SUBTENANT", 9, 196592},
	{"RACCOLTA", 8, 196593},
	{"FAIRIE", 6, 196594},
	{"CORELINUX", 9, 196595},
	{"METERINGMODE", 12, 196596},
	{"DOREAN", 6, 196597},
	{"ARIELLA", 7, 196598},
	{"DPCHALLENGE", 11, 196599},
	{"SPYBUDDY", 8, 196600},
	{"LYGO", 4, 196601},
	{"RARY", 4, 196602},
	{"ZVIL", 4, 196603},
	{"ZFOL", 4, 196604},
	{"YSZA", 4, 196605},
	{"YMCF", 4, 196606},
	{"XAPR", 4, 196607},
	{"WAXP", 4, 196608},
	{"VDEN", 4, 196609},
	{"UYES", 4, 196610},
	{"UPEH", 4, 196611},
	{"UBFE", 4, 196612},
	{"TVEV", 4, 196613},
	{"TJED", 4, 196614},
	{"SBND", 4, 196615},
	{"RIGV", 4, 196616},
	{"RIDY", 4, 196617},
	{"RHPC", 4, 196618},
	{"PTAV", 4, 196619},
	{"OWMD", 4, 196620},
	{"ONDX", 4, 196621},
	{"OIXD", 4, 196622},
	{"NLEL", 4, 196623},
	{"NBYQ", 4, 196624},
	{"LOMC", 4, 196625},
	{"KOMN", 4, 196626},
	{"JICH", 4, 196627},
	{"IMNU", 4, 196628},
	{"IFAY", 4, 196629},
	{"IBYS", 4, 196630},
	{"HUWI", 4, 196631},
	{"HKLE", 4, 196632},
	{"HFAY", 4, 196633},
	{"GVOY", 4, 196634},
	{"FATJ", 4, 196635},
	{"EPEU", 4, 196636},
	{"EEFY", 4, 196637},
	{"DZUM", 4, 196638},
	{"DKAO", 4, 196639},
	{"DEIP", 4, 196640},
	{"DAQG", 4, 196641},
	{"COYH", 4, 196642},
	{"CNAV", 4, 196643},
	{"CEKW", 4, 196644},
	{"AUXM", 4, 196645},
	{"GEMOLOGY", 8, 196646},
	{"FORPLAY", 7, 196647},
	{"VULCANO", 7, 196648},
	{"TRANSGENICS", 11, 196649},
	{"MARKETEERS", 10, 196650},
	{"COURTAULD", 9, 196651},
	{"EPHOTO", 6, 196652},
	{"STEPSIZE", 8, 196653},
	{"BELTER", 6, 196654},
	{"BASADO", 6, 196655},
	{"JANEK", 5, 196656},
	{"CUYO", 4, 196657},
	{"RAMCHARGER", 10, 196658},
	{"MABI", 4, 196659},
	{"GREYWATER", 9, 196660},
	{"THOMASVS", 8, 196661},
	{"MOORAGE", 7, 196662},
	{"QUIROZ", 6, 196663},
	{"FEEST", 5, 196664},
	{"ARLEEN", 6, 196665},
	{"LAUX", 4, 196666},
	{"HAMNETT", 7, 196667},
	{"ANIMIERTE", 9, 196668},
	{"IZSDQWWW", 8, 196669},
	{"DANDIE", 6, 196670},
	{"NUNAWADING", 10, 196671},
	{"GADDY", 5, 196672},
	{"SIEGMUND", 8, 196673},
	{"NETSHELTER", 10, 196674},
	{"PERSAUD", 7, 196675},
	{"LEBOW", 5, 196676},
	{"WEBJUNCTION", 11, 196677},
	{"WEITERLEITEN", 12, 196678},
	{"ARSLAN", 6, 196679},
	{"TOLLHOUSE", 9, 196680},
	{"EIDOSABI", 8, 196681},
	{"JENG", 4, 196682},
	{"SOLANKI", 7, 196683},
	{"NCRA", 4, 196684},
	{"LWL", 3, 196685},
	{"WEHR", 4, 196686},
	{"WEBVERZEICHNIS", 14, 196687},
	{"LEHNERT", 7, 196688},
	{"DEHYDRATING", 11, 196689},
	{"NETSAINT", 8, 196690},
	{"SEPTICAEMIA", 11, 196691},
	{"GIGANTEA", 8, 196692},
	{"YNGHYLCH", 8, 196693},
	{"JUGGALO", 7, 196694},
	{"MAGNESS", 7, 196695},
	{"GOLDENPATH", 10, 196696},
	{"GIRLD", 5, 196697},
	{"ROQUETAS", 8, 196698},
	{"BOUMAN", 6, 196699},
	{"AGENESIS", 8, 196700},
	{"KUUSAMO", 7, 196701},
	{"MACKEN", 6, 196702},
	{"AMBOSMEDIOS", 11, 196703},
	{"LEUPP", 5, 196704},
	{"DETRACTED", 9, 196705},
	{"CITB", 4, 196706},
	{"UNRAVELLED", 10, 196707},
	{"ISDIGIT", 7, 196708},
	{"APDU", 4, 196709},
	{"FDIS", 4, 196710},
	{"ENSDR", 5, 196711},
	{"RUSHMOOR", 8, 196712},
	{"MULLUMBIMBY", 11, 196713},
	{"WORLDMUSIC", 10, 196714},
	{"SETAR", 5, 196715},
	{"JLCONSULTING", 12, 196716},
	{"HARANGUE", 8, 196717},
	{"REDWINGS", 8, 196718},
	{"ASOCIACIONES", 12, 196719},
	{"AARAA", 5, 196720},
	{"DUNKERQUE", 9, 196721},
	{"OVERDOING", 9, 196722},
	{"CROMARTIE", 9, 196723},
	{"UNIONDIAMOND", 12, 196724},
	{"UNIVERSITYOFPHOENIX", 19, 196725},
	{"LIEFDE", 6, 196726},
	{"HILLWOOD", 8, 196727},
	{"WANNEROO", 8, 196728},
	{"EASTWICK", 8, 196729},
	{"ASSATEAGUE", 10, 196730},
	{"ROCE", 4, 196731},
	{"BFB", 3, 196732},
	{"KNAUF", 5, 196733},
	{"AVERTV", 6, 196734},
	{"MVX", 3, 196735},
	{"LAWMAGE", 7, 196736},
	{"PDASTREET", 9, 196737},
	{"FINKBEINER", 10, 196738},
	{"BENCHING", 8, 196739},
	{"BHATTACHARJEE", 13, 196740},
	{"WAVETABLE", 9, 196741},
	{"GINETTE", 7, 196742},
	{"HENATI", 6, 196743},
	{"BUCKMASTER", 10, 196744},
	{"SLANDERING", 10, 196745},
	{"DECANT", 6, 196746},
	{"BLISH", 5, 196747},
	{"YEOMANRY", 8, 196748},
	{"SEASPRAY", 8, 196749},
	{"KYBD", 4, 196750},
	{"ANALG", 5, 196751},
	{"HENSHER", 7, 196752},
	{"CARVERY", 7, 196753},
	{"DIABOLIQUE", 10, 196754},
	{"PRESERVATIONISTS", 16, 196755},
	{"PHXBIRD", 7, 196756},
	{"CHEMOPROPHYLAXIS", 16, 196757},
	{"PROCLEAR", 8, 196758},
	{"NIGHTIME", 8, 196759},
	{"KERASOTES", 9, 196760},
	{"HAEMORRHOIDS", 12, 196761},
	{"TMNET", 5, 196762},
	{"LEPANTO", 7, 196763},
	{"DILLSBORO", 9, 196764},
	{"CHAPSTICK", 9, 196765},
	{"STOCHASTICALLY", 14, 196766},
	{"IDTV", 4, 196767},
	{"JOGI", 4, 196768},
	{"ZZFU", 4, 196769},
	{"YZIP", 4, 196770},
	{"VTOW", 4, 196771},
	{"VIEK", 4, 196772},
	{"TZTR", 4, 196773},
	{"TPUC", 4, 196774},
	{"TOUW", 4, 196775},
	{"SYYE", 4, 196776},
	{"SJIG", 4, 196777},
	{"RMRT", 4, 196778},
	{"RKYM", 4, 196779},
	{"RCME", 4, 196780},
	{"QBTO", 4, 196781},
	{"POPK", 4, 196782},
	{"OXPE", 4, 196783},
	{"ONPF", 4, 196784},
	{"NMCS", 4, 196785},
	{"LTZC", 4, 196786},
	{"LRIB", 4, 196787},
	{"LQAD", 4, 196788},
	{"KYSD", 4, 196789},
	{"KEUC", 4, 196790},
	{"JSCO", 4, 196791},
	{"IYAV", 4, 196792},
	{"HZOR", 4, 196793},
	{"HEXU", 4, 196794},
	{"GUJR", 4, 196795},
	{"GTUI", 4, 196796},
	{"DMST", 4, 196797},
	{"BSEM", 4, 196798},
	{"BBGU", 4, 196799},
	{"ASUZ", 4, 196800},
	{"AFLD", 4, 196801},
	{"TRACKMAN", 8, 196802},
	{"RODINO", 6, 196803},
	{"IRAP", 4, 196804},
	{"DOWNLIGHTS", 10, 196805},
	{"TENNISTENNIS", 12, 196806},
	{"MATILDE", 7, 196807},
	{"USERPROFILE", 11, 196808},
	{"PICTERS", 7, 196809},
	{"LEMA", 4, 196810},
	{"PASSEPARTOUT", 12, 196811},
	{"THRIFTYFUN", 10, 196812},
	{"SCHOOLDAYS", 10, 196813},
	{"MYSTIK", 6, 196814},
	{"ANEROID", 7, 196815},
	{"ARKS", 4, 196816},
	{"PURANA", 6, 196817},
	{"SARGON", 6, 196818},
	{"STOLLE", 6, 196819},
	{"RANTRADIO", 9, 196820},
	{"BEDSHEETS", 9, 196821},
	{"OTOKI", 5, 196822},
	{"VIDEOCAM", 8, 196823},
	{"QUICKNOTES", 10, 196824},
	{"ZOYA", 4, 196825},
	{"DIVESTING", 9, 196826},
	{"CURENTLY", 8, 196827},
	{"PALEOBIOLOGY", 12, 196828},
	{"HOOPES", 6, 196829},
	{"FRICKER", 7, 196830},
	{"TRIETHANOLAMINE", 15, 196831},
	{"CLERY", 5, 196832},
	{"ZCJ", 3, 196833},
	{"ZBG", 3, 196834},
	{"YQX", 3, 196835},
	{"YQK", 3, 196836},
	{"XZY", 3, 196837},
	{"XXQ", 3, 196838},
	{"XRZ", 3, 196839},
	{"XFV", 3, 196840},
	{"XFK", 3, 196841},
	{"WJQ", 3, 196842},
	{"VQB", 3, 196843},
	{"UVZ", 3, 196844},
	{"QYM", 3, 196845},
	{"QVM", 3, 196846},
	{"QDL", 3, 196847},
	{"QDK", 3, 196848},
	{"JMZ", 3, 196849},
	{"GJQ", 3, 196850},
	{"BVJ", 3, 196851},
	{"GLOBEX", 6, 196852},
	{"VALORIE", 7, 196853},
	{"NAZZ", 4, 196854},
	{"HYPERBOREA", 10, 196855},
	{"BRILLION", 8, 196856},
	{"BUETOW", 6, 196857},
	{"INSTALLEDPLUGINS", 16, 196858},
	{"PHPSESSID", 9, 196859},
	{"ECCLESALL", 9, 196860},
	{"DEASE", 5, 196861},
	{"MEDIANET", 8, 196862},
	{"MARKSVILLE", 10, 196863},
	{"COMPLIANCES", 11, 196864},
	{"COLOM", 5, 196865},
	{"BUKAKY", 6, 196866},
	{"KUHNS", 5, 196867},
	{"BITFIELD", 8, 196868},
	{"ACEYALONE", 9, 196869},
	{"KYTHE", 5, 196870},
	{"VAASTU", 6, 196871},
	{"RJD", 3, 196872},
	{"REGLER", 6, 196873},
	{"POINTCUT", 8, 196874},
	{"HYMNES", 6, 196875},
	{"SYMI", 4, 196876},
	{"LOVELIFE", 8, 196877},
	{"TRAWICK", 7, 196878},
	{"PERSONNELLES", 12, 196879},
	{"WALKABOUTS", 10, 196880},
	{"SPILLAGES", 9, 196881},
	{"NOVITA", 6, 196882},
	{"BOATRIGHT", 9, 196883},
	{"AMOXYCILLIN", 11, 196884},
	{"GENTIL", 6, 196885},
	{"BURGHOLZHAUSEN", 14, 196886},
	{"FIXTURING", 9, 196887},
	{"PANKHURST", 9, 196888},
	{"ABLEST", 6, 196889},
	{"JANDA", 5, 196890},
	{"AMERICAL", 8, 196891},
	{"KRYLON", 6, 196892},
	{"NAMETAGS", 8, 196893},
	{"HARARI", 6, 196894},
	{"KADYROV", 7, 196895},
	{"FREECOCK", 8, 196896},
	{"ORIENTALIST", 11, 196897},
	{"BROACHING", 9, 196898},
	{"ULTRAMAFIC", 10, 196899},
	{"DUPL", 4, 196900},
	{"USAFA", 5, 196901},
	{"TSILIVI", 7, 196902},
	{"OUTSIZED", 8, 196903},
	{"MOSKOURI", 8, 196904},
	{"GYMORTH", 7, 196905},
	{"GRANO", 5, 196906},
	{"STURROCK", 8, 196907},
	{"MRSKIN", 6, 196908},
	{"EBROCHURE", 9, 196909},
	{"KPG", 3, 196910},
	{"BOARDWALKS", 10, 196911},
	{"BROWNTROUT", 10, 196912},
	{"BHARDWAJ", 8, 196913},
	{"AYOTTE", 6, 196914},
	{"SNOOPERS", 8, 196915},
	{"LAVEY", 5, 196916},
	{"UUG", 3, 196917},
	{"ODDSPOT", 7, 196918},
	{"BEATLEMANIA", 11, 196919},
	{"CHOCLATE", 8, 196920},
	{"ZYPR", 4, 196921},
	{"ZYKA", 4, 196922},
	{"ZCOA", 4, 196923},
	{"YMMO", 4, 196924},
	{"XSIM", 4, 196925},
	{"XFLO", 4, 196926},
	{"WATG", 4, 196927},
	{"UVRI", 4, 196928},
	{"TZAF", 4, 196929},
	{"SNPC", 4, 196930},
	{"RNTY", 4, 196931},
	{"RJRS", 4, 196932},
	{"RCSP", 4, 196933},
	{"RAUA", 4, 196934},
	{"RABK", 4, 196935},
	{"PPIV", 4, 196936},
	{"PFED", 4, 196937},
	{"ONRM", 4, 196938},
	{"OGMU", 4, 196939},
	{"NOWZ", 4, 196940},
	{"NDNP", 4, 196941},
	{"MNSB", 4, 196942},
	{"LILK", 4, 196943},
	{"LCFO", 4, 196944},
	{"LAVT", 4, 196945},
	{"KYVA", 4, 196946},
	{"KPIP", 4, 196947},
	{"KGAB", 4, 196948},
	{"KAIZ", 4, 196949},
	{"IDYB", 4, 196950},
	{"GYAO", 4, 196951},
	{"FWIF", 4, 196952},
	{"FURF", 4, 196953},
	{"FIFN", 4, 196954},
	{"ERWB", 4, 196955},
	{"EBLM", 4, 196956},
	{"DUPQ", 4, 196957},
	{"DETL", 4, 196958},
	{"CQUO", 4, 196959},
	{"BAMP", 4, 196960},
	{"BAHC", 4, 196961},
	{"LANIUS", 6, 196962},
	{"PARVO", 5, 196963},
	{"NURE", 4, 196964},
	{"PRWEEK", 6, 196965},
	{"AWAMUTU", 7, 196966},
	{"VERISIMILITUDE", 14, 196967},
	{"MIGNOLA", 7, 196968},
	{"KILLEBREW", 9, 196969},
	{"FROUDE", 6, 196970},
	{"DROPDOWNS", 9, 196971},
	{"DENNYS", 6, 196972},
	{"SEEKNCLEAN", 10, 196973},
	{"LIOU", 4, 196974},
	{"GREENHAVEN", 10, 196975},
	{"XSLTPROC", 8, 196976},
	{"URLAUBSFOTOS", 12, 196977},
	{"LEPIDUS", 7, 196978},
	{"HEHEHEH", 7, 196979},
	{"THERMOREGULATION", 16, 196980},
	{"SARWAR", 6, 196981},
	{"QSORT", 5, 196982},
	{"FAVEUR", 6, 196983},
	{"TAPEWORMS", 9, 196984},
	{"ROUTS", 5, 196985},
	{"THEESE", 6, 196986},
	{"FOLLAR", 6, 196987},
	{"LLYWIO", 6, 196988},
	{"SHALER", 6, 196989},
	{"PUBLICKEY", 9, 196990},
	{"SOCIET", 6, 196991},
	{"SCHROEDINGER", 12, 196992},
	{"DICHO", 5, 196993},
	{"RESENTENCING", 12, 196994},
	{"PATTERS", 7, 196995},
	{"NUNCHAKU", 8, 196996},
	{"CURRENTNESS", 11, 196997},
	{"PONDWEED", 8, 196998},
	{"DISHONESTLY", 11, 196999},
	{"DEINOCOCCUS", 11, 197000},
	{"THYRISTORS", 10, 197001},
	{"MIKHAILOV", 9, 197002},
	{"WHITEST", 7, 197003},
	{"BITTMAN", 7, 197004},
	{"BASTANTE", 8, 197005},
	{"POMODORO", 8, 197006},
	{"SCULLING", 8, 197007},
	{"VACC", 4, 197008},
	{"MORTIER", 7, 197009},
	{"NIPPO", 5, 197010},
	{"POPSICLES", 9, 197011},
	{"RYUJI", 5, 197012},
	{"DOWNSVILLE", 10, 197013},
	{"PLANOS", 6, 197014},
	{"MAXIMILIANS", 11, 197015},
	{"HURRICAINE", 10, 197016},
	{"TRUMPER", 7, 197017},
	{"MOVIEW", 6, 197018},
	{"BROTT", 5, 197019},
	{"GILSTRAP", 8, 197020},
	{"GREYWOLF", 8, 197021},
	{"GIFFARD", 7, 197022},
	{"COMANDANTE", 10, 197023},
	{"LANNAN", 6, 197024},
	{"KAIZER", 6, 197025},
	{"TINKERS", 7, 197026},
	{"ABSURDUM", 8, 197027},
	{"GBF", 3, 197028},
	{"SOMG", 4, 197029},
	{"FUNDGRUBE", 9, 197030},
	{"COGILL", 6, 197031},
	{"HOEDSPRUIT", 10, 197032},
	{"PINTURAS", 8, 197033},
	{"HANDMAIDEN", 10, 197034},
	{"FORDINGBRIDGE", 13, 197035},
	{"TOOWONG", 7, 197036},
	{"OPENMANAGE", 10, 197037},
	{"VXVM", 4, 197038},
	{"SUMTHING", 8, 197039},
	{"PYRILAMINE", 10, 197040},
	{"KEYHOLDER", 9, 197041},
	{"HUMORS", 6, 197042},
	{"MONDELLO", 8, 197043},
	{"NEEDLESTICK", 11, 197044},
	{"SHOTCRETE", 9, 197045},
	{"RUBBERBAND", 10, 197046},
	{"MODSP", 5, 197047},
	{"KILWINNING", 10, 197048},
	{"HYOSUNG", 7, 197049},
	{"FUNNELL", 7, 197050},
	{"MISCLASSIFIED", 13, 197051},
	{"COSMETOLOGISTS", 14, 197052},
	{"TRIQUINT", 8, 197053},
	{"GETACODER", 9, 197054},
	{"STRK", 4, 197055},
	{"BULE", 4, 197056},
	{"SOLLEN", 6, 197057},
	{"LINTL", 5, 197058},
	{"JWG", 3, 197059},
	{"OYSTERCATCHER", 13, 197060},
	{"ELLERBE", 7, 197061},
	{"ZERBISIAS", 9, 197062},
	{"SHEQEL", 6, 197063},
	{"BANKRUPTED", 10, 197064},
	{"OFCS", 4, 197065},
	{"WHITESTRIPS", 11, 197066},
	{"COGECO", 6, 197067},
	{"UNALAKLEET", 10, 197068},
	{"TUMBLEWEEDS", 11, 197069},
	{"TERRIFICALLY", 12, 197070},
	{"PROCHLORPERAZINE", 16, 197071},
	{"GROUNDER", 8, 197072},
	{"COOED", 5, 197073},
	{"MIYAZAWA", 8, 197074},
	{"JERR", 4, 197075},
	{"BALCO", 5, 197076},
	{"WALKERSVILLE", 12, 197077},
	{"VASSILIS", 8, 197078},
	{"KATHRINE", 8, 197079},
	{"SPOONING", 8, 197080},
	{"CANBIOTECH", 10, 197081},
	{"TTREE", 5, 197082},
	{"CABAC", 5, 197083},
	{"MOJA", 4, 197084},
	{"LYSE", 4, 197085},
	{"SCHOLASTICS", 11, 197086},
	{"PROTAMINE", 9, 197087},
	{"MODDM", 5, 197088},
	{"BECHET", 6, 197089},
	{"WRAGG", 5, 197090},
	{"CONLAN", 6, 197091},
	{"TRAMA", 5, 197092},
	{"FREIZEITHURE", 12, 197093},
	{"RUDERMAN", 8, 197094},
	{"CAGS", 4, 197095},
	{"SETJMP", 6, 197096},
	{"KNABE", 5, 197097},
	{"FLIPALBUM", 9, 197098},
	{"PYTHIUM", 7, 197099},
	{"KASDAN", 6, 197100},
	{"URR", 3, 197101},
	{"RCWS", 4, 197102},
	{"PROFLEX", 7, 197103},
	{"NICHOLA", 7, 197104},
	{"GUNBOATS", 8, 197105},
	{"TREKKIE", 7, 197106},
	{"ZPIT", 4, 197107},
	{"YMRG", 4, 197108},
	{"YDAP", 4, 197109},
	{"XMIG", 4, 197110},
	{"XAMR", 4, 197111},
	{"UPGL", 4, 197112},
	{"UKKU", 4, 197113},
	{"UGOM", 4, 197114},
	{"UASU", 4, 197115},
	{"TZCR", 4, 197116},
	{"SBDR", 4, 197117},
	{"RSKL", 4, 197118},
	{"RLVI", 4, 197119},
	{"RHBO", 4, 197120},
	{"RCID", 4, 197121},
	{"PEKT", 4, 197122},
	{"PEBI", 4, 197123},
	{"OMPN", 4, 197124},
	{"OKKU", 4, 197125},
	{"OCYP", 4, 197126},
	{"NGRT", 4, 197127},
	{"NBCL", 4, 197128},
	{"MRFU", 4, 197129},
	{"MAKW", 4, 197130},
	{"LOMR", 4, 197131},
	{"KODR", 4, 197132},
	{"KMCL", 4, 197133},
	{"JFKA", 4, 197134},
	{"IRUC", 4, 197135},
	{"FPUG", 4, 197136},
	{"EUWO", 4, 197137},
	{"EUAC", 4, 197138},
	{"EDQA", 4, 197139},
	{"DEXX", 4, 197140},
	{"BOYU", 4, 197141},
	{"BGRI", 4, 197142},
	{"AUGG", 4, 197143},
	{"ANRF", 4, 197144},
	{"ALBN", 4, 197145},
	{"ABGA", 4, 197146},
	{"PUBBLICAZIONE", 13, 197147},
	{"DOMINGOS", 8, 197148},
	{"TRUELOVE", 8, 197149},
	{"INDIVIDUALIZE", 13, 197150},
	{"DETRENDED", 9, 197151},
	{"STAGGS", 6, 197152},
	{"FLOYDADA", 8, 197153},
	{"MADAGASKAR", 10, 197154},
	{"BARMOUTH", 8, 197155},
	{"REMUERA", 7, 197156},
	{"GREENSTREET", 11, 197157},
	{"CALDICOT", 8, 197158},
	{"CAIMANSTORE", 11, 197159},
	{"USHELPSERVICE", 13, 197160},
	{"MARMOSET", 8, 197161},
	{"TRUBRITE", 8, 197162},
	{"BASEBALLMINOR", 13, 197163},
	{"PROVENZANO", 10, 197164},
	{"MYG", 3, 197165},
	{"LESPORTSAC", 10, 197166},
	{"EPISTEMELINKS", 13, 197167},
	{"BOOTHFINDER", 11, 197168},
	{"SAUNACLUB", 9, 197169},
	{"REALCLEAR", 9, 197170},
	{"MEDIASTUDIO", 11, 197171},
	{"COMRADESHIP", 11, 197172},
	{"WHITELAND", 9, 197173},
	{"SCHMOOZE", 8, 197174},
	{"AYACUCHO", 8, 197175},
	{"AVAILA", 6, 197176},
	{"INOPPORTUNE", 11, 197177},
	{"ALGERIANS", 9, 197178},
	{"TRESCOTHICK", 11, 197179},
	{"CASCIO", 6, 197180},
	{"PEOPLESOUND", 11, 197181},
	{"GEPLANTEN", 9, 197182},
	{"REWINDER", 8, 197183},
	{"GIORDANA", 8, 197184},
	{"BODKIN", 6, 197185},
	{"TRACIANNA", 9, 197186},
	{"FUSCA", 5, 197187},
	{"NARVIK", 6, 197188},
	{"SEALSKINZ", 9, 197189},
	{"PEDA", 4, 197190},
	{"BERNT", 5, 197191},
	{"RELMAXTOP", 9, 197192},
	{"MARIBETH", 8, 197193},
	{"CEFTAZIDIME", 11, 197194},
	{"STOKING", 7, 197195},
	{"ENVIRONM", 8, 197196},
	{"GUMSHOE", 7, 197197},
	{"CISION", 6, 197198},
	{"VULVVA", 6, 197199},
	{"ENGRAM", 6, 197200},
	{"BOXTER", 6, 197201},
	{"LAHONTAN", 8, 197202},
	{"WASHLAW", 7, 197203},
	{"SECRETASE", 9, 197204},
	{"LGBTQ", 5, 197205},
	{"LACTULOSE", 9, 197206},
	{"NHLNHL", 6, 197207},
	{"EPHEMEROPTERA", 13, 197208},
	{"PVFTOOLS", 8, 197209},
	{"PROBUS", 6, 197210},
	{"NISSIM", 6, 197211},
	{"ENTEROCOLITIS", 13, 197212},
	{"PRESENTES", 9, 197213},
	{"TMATH", 5, 197214},
	{"STRIPLOKAL", 10, 197215},
	{"BUDDIE", 6, 197216},
	{"DIMMIT", 6, 197217},
	{"FLATTOP", 7, 197218},
	{"GILGER", 6, 197219},
	{"EXHALING", 8, 197220},
	{"EQUALLING", 9, 197221},
	{"HONKBAL", 7, 197222},
	{"PLASTICIZER", 11, 197223},
	{"OBTAINMENT", 10, 197224},
	{"EUROPIUM", 8, 197225},
	{"MINDMAP", 7, 197226},
	{"CALVER", 6, 197227},
	{"LURCHING", 8, 197228},
	{"PRESSWEATHERONLINE", 18, 197229},
	{"FRUSH", 5, 197230},
	{"GUUG", 4, 197231},
	{"SALINITIES", 10, 197232},
	{"RESNIK", 6, 197233},
	{"INDEKS", 6, 197234},
	{"IMPORTERROR", 11, 197235},
	{"DIOPSIDE", 8, 197236},
	{"DAPPLE", 6, 197237},
	{"SUAECIENT", 9, 197238},
	{"MITERED", 7, 197239},
	{"METAPOPULATION", 14, 197240},
	{"VILLAREAL", 9, 197241},
	{"TURQUESA", 8, 197242},
	{"TASTEBUDS", 9, 197243},
	{"BARYONIC", 8, 197244},
	{"WARZ", 4, 197245},
	{"ANDRUW", 6, 197246},
	{"PLUMED", 6, 197247},
	{"UPRATED", 7, 197248},
	{"POESY", 5, 197249},
	{"TONNY", 5, 197250},
	{"ZZWH", 4, 197251},
	{"YCKI", 4, 197252},
	{"XPOC", 4, 197253},
	{"VDCA", 4, 197254},
	{"UPAE", 4, 197255},
	{"UIPO", 4, 197256},
	{"TZME", 4, 197257},
	{"SKPL", 4, 197258},
	{"RUZO", 4, 197259},
	{"RTTV", 4, 197260},
	{"QBJO", 4, 197261},
	{"OXCR", 4, 197262},
	{"ORPK", 4, 197263},
	{"OIFR", 4, 197264},
	{"NKPH", 4, 197265},
	{"MLYF", 4, 197266},
	{"MFAB", 4, 197267},
	{"MEEW", 4, 197268},
	{"LPCI", 4, 197269},
	{"KTAM", 4, 197270},
	{"IYEL", 4, 197271},
	{"HKAZ", 4, 197272},
	{"GSMC", 4, 197273},
	{"GOWB", 4, 197274},
	{"FZEU", 4, 197275},
	{"FRYU", 4, 197276},
	{"FOEW", 4, 197277},
	{"EXID", 4, 197278},
	{"EBCI", 4, 197279},
	{"DNUL", 4, 197280},
	{"DILM", 4, 197281},
	{"BSFL", 4, 197282},
	{"BGOO", 4, 197283},
	{"AYLD", 4, 197284},
	{"AKHP", 4, 197285},
	{"PRORATE", 7, 197286},
	{"NETLABEL", 8, 197287},
	{"CHEAPNESS", 9, 197288},
	{"CORDOVAN", 8, 197289},
	{"SCYTHIAN", 8, 197290},
	{"NAIVETY", 7, 197291},
	{"MORENI", 6, 197292},
	{"FAIRED", 6, 197293},
	{"CASP", 4, 197294},
	{"CSRDS", 5, 197295},
	{"SAFELISTS", 9, 197296},
	{"PARET", 5, 197297},
	{"COUTINHO", 8, 197298},
	{"BEHEER", 6, 197299},
	{"SNUGPAK", 7, 197300},
	{"ODORATA", 7, 197301},
	{"MICROMACHINED", 13, 197302},
	{"PECONIC", 7, 197303},
	{"PROCHE", 6, 197304},
	{"TEPLICE", 7, 197305},
	{"BIONICS", 7, 197306},
	{"CEANOTHUS", 9, 197307},
	{"SLOPESIDE", 9, 197308},
	{"RADLETT", 7, 197309},
	{"INTRONIC", 8, 197310},
	{"SSCC", 4, 197311},
	{"BACKE", 5, 197312},
	{"SEESAT", 6, 197313},
	{"PANDIE", 6, 197314},
	{"BEMAN", 5, 197315},
	{"OXMOOR", 6, 197316},
	{"KALU", 4, 197317},
	{"MISINTERPRETING", 15, 197318},
	{"NEWSPOST", 8, 197319},
	{"SAPPED", 6, 197320},
	{"RANGI", 5, 197321},
	{"STARCHED", 8, 197322},
	{"ERHARDT", 7, 197323},
	{"BUILDSLAVE", 10, 197324},
	{"MEDGAR", 6, 197325},
	{"CANOO", 5, 197326},
	{"RISPARMIA", 9, 197327},
	{"FREEMIND", 8, 197328},
	{"BRAINWAVES", 10, 197329},
	{"KERG", 4, 197330},
	{"EDWYN", 5, 197331},
	{"PHOTOCOPIABLE", 13, 197332},
	{"HOMECONNECTIONS", 15, 197333},
	{"WALLNER", 7, 197334},
	{"KINGSTREE", 9, 197335},
	{"TASCHE", 6, 197336},
	{"CAMPESINOS", 10, 197337},
	{"GHANAIANS", 9, 197338},
	{"SHELBYSTEVENS", 13, 197339},
	{"BLOGENLUST", 10, 197340},
	{"STORYVILLE", 10, 197341},
	{"MCENTEE", 7, 197342},
	{"PUSSSSY", 7, 197343},
	{"KULTURA", 7, 197344},
	{"INSIEME", 7, 197345},
	{"ERRCODE", 7, 197346},
	{"MERRETT", 7, 197347},
	{"SODDY", 5, 197348},
	{"PARISIEN", 8, 197349},
	{"SKYLAND", 7, 197350},
	{"CAPSHAW", 7, 197351},
	{"PRECEPTORSHIP", 13, 197352},
	{"UNDISTINGUISHED", 15, 197353},
	{"TOTALVIEW", 9, 197354},
	{"PELTOR", 6, 197355},
	{"LAZEAR", 6, 197356},
	{"BOCC", 4, 197357},
	{"MARYLHURST", 10, 197358},
	{"COMPENSA", 8, 197359},
	{"PANGKOR", 7, 197360},
	{"VUMC", 4, 197361},
	{"ABHIJEET", 8, 197362},
	{"UTILISEZ", 8, 197363},
	{"THEOLOGICA", 10, 197364},
	{"WOONKAMER", 9, 197365},
	{"OPERACIONES", 11, 197366},
	{"SERIENNUMMER", 12, 197367},
	{"MOCKUPS", 7, 197368},
	{"LAMBRECHT", 9, 197369},
	{"QUEENSCLIFF", 11, 197370},
	{"LUNDELL", 7, 197371},
	{"GOPALAKRISHNAN", 14, 197372},
	{"OUTPUTTED", 9, 197373},
	{"OELWEIN", 7, 197374},
	{"HINDEN", 6, 197375},
	{"BHAGAVATAM", 10, 197376},
	{"NUSIC", 5, 197377},
	{"CUTT", 4, 197378},
	{"SAFECOM", 7, 197379},
	{"QUOTIDIENNE", 11, 197380},
	{"GWAHANOL", 8, 197381},
	{"RYAH", 4, 197382},
	{"NEYTHER", 7, 197383},
	{"REVILLON", 8, 197384},
	{"BATOR", 5, 197385},
	{"OCOLC", 5, 197386},
	{"TOWERSTREAM", 11, 197387},
	{"JRF", 3, 197388},
	{"EYEDROPPER", 10, 197389},
	{"BLOGEBRITY", 10, 197390},
	{"ARTEMIA", 7, 197391},
	{"ANSCHUTZ", 8, 197392},
	{"GAYER", 5, 197393},
	{"PHETREMINE", 10, 197394},
	{"CELEBRETY", 9, 197395},
	{"RAINMAKERS", 10, 197396},
	{"SUENOS", 6, 197397},
	{"EROTIKCENTER", 12, 197398},
	{"ITALICISED", 10, 197399},
	{"ELMERS", 6, 197400},
	{"CONNOTE", 7, 197401},
	{"CATEGORIAL", 10, 197402},
	{"SOGG", 4, 197403},
	{"RESERVER", 8, 197404},
	{"SECEDED", 7, 197405},
	{"MOONVES", 7, 197406},
	{"FFVXZ", 5, 197407},
	{"QCSTRING", 8, 197408},
	{"TATEYAMA", 8, 197409},
	{"ORTING", 6, 197410},
	{"MCKILLOP", 8, 197411},
	{"KAHNAWAKE", 9, 197412},
	{"MASTERMIX", 9, 197413},
	{"FISHIES", 7, 197414},
	{"NUREYEV", 7, 197415},
	{"MIZPAH", 6, 197416},
	{"ZEGI", 4, 197417},
	{"YUBE", 4, 197418},
	{"VMAY", 4, 197419},
	{"VGEO", 4, 197420},
	{"UFAT", 4, 197421},
	{"UCYH", 4, 197422},
	{"SRYO", 4, 197423},
	{"SKAQ", 4, 197424},
	{"RUNZ", 4, 197425},
	{"RPMD", 4, 197426},
	{"ROUV", 4, 197427},
	{"RHTM", 4, 197428},
	{"NJIK", 4, 197429},
	{"NHUC", 4, 197430},
	{"NDHW", 4, 197431},
	{"MRUM", 4, 197432},
	{"MEUG", 4, 197433},
	{"LYOG", 4, 197434},
	{"LNDI", 4, 197435},
	{"IUCA", 4, 197436},
	{"IRUI", 4, 197437},
	{"IGEU", 4, 197438},
	{"GTIB", 4, 197439},
	{"FPTH", 4, 197440},
	{"FMIM", 4, 197441},
	{"FFIO", 4, 197442},
	{"FAUV", 4, 197443},
	{"ERBK", 4, 197444},
	{"EOUD", 4, 197445},
	{"EGDU", 4, 197446},
	{"EFPU", 4, 197447},
	{"DYEO", 4, 197448},
	{"CHLC", 4, 197449},
	{"CGOE", 4, 197450},
	{"BTMO", 4, 197451},
	{"AWFL", 4, 197452},
	{"AFBI", 4, 197453},
	{"DEJOHNETTE", 10, 197454},
	{"SAPPI", 5, 197455},
	{"EXCELON", 7, 197456},
	{"CLUSTAL", 7, 197457},
	{"UNMAINTAINED", 12, 197458},
	{"RIZA", 4, 197459},
	{"ARCSDE", 6, 197460},
	{"ZIPFILE", 7, 197461},
	{"SUPERWOMAN", 10, 197462},
	{"WELBECK", 7, 197463},
	{"NARCISSA", 8, 197464},
	{"MYDOMAIN", 8, 197465},
	{"JOTM", 4, 197466},
	{"GEHL", 4, 197467},
	{"THISIS", 6, 197468},
	{"BELLIGERENTS", 12, 197469},
	{"REWOUND", 7, 197470},
	{"KURUKSHETRA", 11, 197471},
	{"INDABA", 6, 197472},
	{"DETECTO", 7, 197473},
	{"OVIDA", 5, 197474},
	{"PNUM", 4, 197475},
	{"LACKADAISICAL", 13, 197476},
	{"ROSSII", 6, 197477},
	{"BASER", 5, 197478},
	{"FINDA", 5, 197479},
	{"RACINGHORSE", 11, 197480},
	{"RIBALD", 6, 197481},
	{"MULTIRATE", 9, 197482},
	{"FRETTE", 6, 197483},
	{"THRUS", 5, 197484},
	{"MCAST", 5, 197485},
	{"KGW", 3, 197486},
	{"NANKAI", 6, 197487},
	{"CUENTO", 6, 197488},
	{"BULRUSH", 7, 197489},
	{"REPPAS", 6, 197490},
	{"KHABIBULIN", 10, 197491},
	{"BILODEAU", 8, 197492},
	{"OTOPLASTY", 9, 197493},
	{"TRAVAILLEURS", 12, 197494},
	{"STABAT", 6, 197495},
	{"DIFFERANCE", 10, 197496},
	{"MCGURK", 6, 197497},
	{"BAKIT", 5, 197498},
	{"ALTIPLANO", 9, 197499},
	{"BASELAYER", 9, 197500},
	{"DREYA", 5, 197501},
	{"SEACHANGE", 9, 197502},
	{"EPITROPHS", 9, 197503},
	{"AMORIM", 6, 197504},
	{"SALMONS", 7, 197505},
	{"BORICUA", 7, 197506},
	{"IDENTD", 6, 197507},
	{"SCHLOTZSKY", 10, 197508},
	{"KINGSWINFORD", 12, 197509},
	{"SKYMASTER", 9, 197510},
	{"FRANCOEUR", 9, 197511},
	{"GENERAT", 7, 197512},
	{"TEDDER", 6, 197513},
	{"SPORTSFILTER", 12, 197514},
	{"COURSED", 7, 197515},
	{"HLUTTAW", 7, 197516},
	{"KNOLLENBERG", 11, 197517},
	{"INSPORT", 7, 197518},
	{"BURNITZ", 7, 197519},
	{"TERY", 4, 197520},
	{"PREHENSIVE", 10, 197521},
	{"ZANGO", 5, 197522},
	{"PRAHALAD", 8, 197523},
	{"NMLUG", 5, 197524},
	{"DEBRAJEAN", 9, 197525},
	{"CIBOLO", 6, 197526},
	{"BLEN", 4, 197527},
	{"MECK", 4, 197528},
	{"CLAIRTON", 8, 197529},
	{"HEALTHINSURANCE", 15, 197530},
	{"GRANDISON", 9, 197531},
	{"SYNDEL", 6, 197532},
	{"OMNIPRESENCE", 12, 197533},
	{"MIKAELA", 7, 197534},
	{"KNILL", 5, 197535},
	{"MONEYEXTRA", 10, 197536},
	{"YORKUSA", 7, 197537},
	{"COMPTEL", 7, 197538},
	{"RITTAL", 6, 197539},
	{"MNISLAHI", 8, 197540},
	{"SHADOWBOX", 9, 197541},
	{"TURFWAY", 7, 197542},
	{"MARCAR", 6, 197543},
	{"IOERROR", 7, 197544},
	{"YUEH", 4, 197545},
	{"FOLDAWAY", 8, 197546},
	{"GARTIS", 6, 197547},
	{"PAIPIX", 6, 197548},
	{"ORADEA", 6, 197549},
	{"KEYDOWN", 7, 197550},
	{"SMARTBASE", 9, 197551},
	{"ECRANS", 6, 197552},
	{"PICHLER", 7, 197553},
	{"DOWNFORCE", 9, 197554},
	{"XIXI", 4, 197555},
	{"POUNDSTONE", 10, 197556},
	{"VERVIERS", 8, 197557},
	{"PIZZARELLI", 10, 197558},
	{"SUNDSVALL", 9, 197559},
	{"LIBGUPPI", 8, 197560},
	{"SILLAS", 6, 197561},
	{"PROFORCE", 8, 197562},
	{"GROTIUS", 7, 197563},
	{"HABITANTS", 9, 197564},
	{"TREBLINKA", 9, 197565},
	{"MAVA", 4, 197566},
	{"BRUSQUE", 7, 197567},
	{"ZZIO", 4, 197568},
	{"ZTOC", 4, 197569},
	{"YUSG", 4, 197570},
	{"YSLY", 4, 197571},
	{"YLBE", 4, 197572},
	{"YAAF", 4, 197573},
	{"WWDE", 4, 197574},
	{"UTGM", 4, 197575},
	{"USKH", 4, 197576},
	{"UIJA", 4, 197577},
	{"UCYB", 4, 197578},
	{"UBYC", 4, 197579},
	{"TVSD", 4, 197580},
	{"TSYP", 4, 197581},
	{"TMMI", 4, 197582},
	{"TMCO", 4, 197583},
	{"TDSW", 4, 197584},
	{"SDEK", 4, 197585},
	{"PUWA", 4, 197586},
	{"PCBU", 4, 197587},
	{"ORHR", 4, 197588},
	{"NODW", 4, 197589},
	{"NGRP", 4, 197590},
	{"MUPE", 4, 197591},
	{"MPKE", 4, 197592},
	{"MOFQ", 4, 197593},
	{"MDCO", 4, 197594},
	{"LDIK", 4, 197595},
	{"KMEY", 4, 197596},
	{"ISYD", 4, 197597},
	{"IBSF", 4, 197598},
	{"HWIK", 4, 197599},
	{"HUTY", 4, 197600},
	{"HIDM", 4, 197601},
	{"HEFY", 4, 197602},
	{"GUTR", 4, 197603},
	{"GUKR", 4, 197604},
	{"GLAF", 4, 197605},
	{"FLYK", 4, 197606},
	{"EVSD", 4, 197607},
	{"EUDD", 4, 197608},
	{"EBBF", 4, 197609},
	{"DZAH", 4, 197610},
	{"CHTP", 4, 197611},
	{"CDSH", 4, 197612},
	{"AZUO", 4, 197613},
	{"FUNCTIONALIST", 13, 197614},
	{"BRISS", 5, 197615},
	{"IMED", 4, 197616},
	{"STEINHOFF", 9, 197617},
	{"FIREPROOFING", 12, 197618},
	{"EMPATHISE", 9, 197619},
	{"CTCSS", 5, 197620},
	{"CSTD", 4, 197621},
	{"KURZFASSUNG", 11, 197622},
	{"SILVIS", 6, 197623},
	{"KAYNA", 5, 197624},
	{"WXPN", 4, 197625},
	{"LMTP", 4, 197626},
	{"LEONBERGER", 10, 197627},
	{"ESTADUAL", 8, 197628},
	{"BREANNE", 7, 197629},
	{"PRAVIN", 6, 197630},
	{"BAIG", 4, 197631},
	{"AFFORDANCES", 11, 197632},
	{"BARLETTA", 8, 197633},
	{"MIKAL", 5, 197634},
	{"NEASDEN", 7, 197635},
	{"INDECIPHERABLE", 14, 197636},
	{"UNSERVICEABLE", 13, 197637},
	{"LIKEY", 5, 197638},
	{"INFESTANS", 9, 197639},
	{"MACSOFT", 7, 197640},
	{"HEXOSE", 6, 197641},
	{"COARCTATION", 11, 197642},
	{"STOIRES", 7, 197643},
	{"IDENTIFICA", 10, 197644},
	{"SCALLY", 6, 197645},
	{"DENNISTON", 9, 197646},
	{"DANIAL", 6, 197647},
	{"COMBIVIR", 8, 197648},
	{"CHEJU", 5, 197649},
	{"RAGGI", 5, 197650},
	{"COOPERSBURG", 11, 197651},
	{"ETANERCEPT", 10, 197652},
	{"HALMSTAD", 8, 197653},
	{"FANWOOD", 7, 197654},
	{"VACANSEE", 8, 197655},
	{"OFFICIOUS", 9, 197656},
	{"ESCORIAL", 8, 197657},
	{"BRANTON", 7, 197658},
	{"LASKIN", 6, 197659},
	{"SEMIFINALIST", 12, 197660},
	{"NFLNFL", 6, 197661},
	{"DISHMAN", 7, 197662},
	{"PAGEHOME", 8, 197663},
	{"COMTEMPORARY", 12, 197664},
	{"RGBHV", 5, 197665},
	{"CMSS", 4, 197666},
	{"EPHRIN", 6, 197667},
	{"VANCED", 6, 197668},
	{"FIRMSITES", 9, 197669},
	{"ADDTYPE", 7, 197670},
	{"NBANBA", 6, 197671},
	{"MONTGOMERYVILLE", 15, 197672},
	{"BRACLETS", 8, 197673},
	{"MINAL", 5, 197674},
	{"BIONEWS", 7, 197675},
	{"DUIKER", 6, 197676},
	{"NCEST", 5, 197677},
	{"GUINAN", 6, 197678},
	{"GORKA", 5, 197679},
	{"CATC", 4, 197680},
	{"WORKHOLDING", 11, 197681},
	{"FILMFORCE", 9, 197682},
	{"OBFUSCATING", 11, 197683},
	{"FISKING", 7, 197684},
	{"DISORGANISED", 12, 197685},
	{"NLIST", 5, 197686},
	{"LETTON", 6, 197687},
	{"CURSILLO", 8, 197688},
	{"KNUTE", 5, 197689},
	{"BURTT", 5, 197690},
	{"BULLIS", 6, 197691},
	{"XITEL", 5, 197692},
	{"TWEEDLE", 7, 197693},
	{"SOUTHTRUST", 10, 197694},
	{"VIASAT", 6, 197695},
	{"KOMMENDEN", 9, 197696},
	{"PISTOLE", 7, 197697},
	{"ABERLOUR", 8, 197698},
	{"CRYSTALLINITY", 13, 197699},
	{"SPAWNER", 7, 197700},
	{"EASYCODER", 9, 197701},
	{"CARRA", 5, 197702},
	{"SUIF", 4, 197703},
	{"SUJATA", 6, 197704},
	{"ACCRETED", 8, 197705},
	{"DISOR", 5, 197706},
	{"KLARE", 5, 197707},
	{"KASSON", 6, 197708},
	{"DAVEN", 5, 197709},
	{"PLUNKET", 7, 197710},
	{"CONIA", 5, 197711},
	{"SHANER", 6, 197712},
	{"KRAKATOA", 8, 197713},
	{"GURR", 4, 197714},
	{"BUTCHART", 8, 197715},
	{"GRISEUS", 7, 197716},
	{"CTIVITIES", 9, 197717},
	{"CITTIE", 6, 197718},
	{"MACROBLOCK", 10, 197719},
	{"REASSEMBLING", 12, 197720},
	{"HASTING", 7, 197721},
	{"SLIPLOCK", 8, 197722},
	{"ILCA", 4, 197723},
	{"DMAC", 4, 197724},
	{"ENLIGT", 6, 197725},
	{"MCREL", 5, 197726},
	{"INFORMATIC", 10, 197727},
	{"FACTURING", 9, 197728},
	{"OVEMBER", 7, 197729},
	{"VANZARI", 7, 197730},
	{"UNIMODAL", 8, 197731},
	{"SANGYO", 6, 197732},
	{"NEUBERT", 7, 197733},
	{"SILETZ", 6, 197734},
	{"SUCHBEGRIFF", 11, 197735},
	{"LISTITEM", 8, 197736},
	{"XEXC", 4, 197737},
	{"VYCL", 4, 197738},
	{"VEUL", 4, 197739},
	{"VDIE", 4, 197740},
	{"VAKN", 4, 197741},
	{"UZAA", 4, 197742},
	{"UTFT", 4, 197743},
	{"UBYI", 4, 197744},
	{"SKMU", 4, 197745},
	{"SIFJ", 4, 197746},
	{"SDIZ", 4, 197747},
	{"REPY", 4, 197748},
	{"PPHY", 4, 197749},
	{"OVSF", 4, 197750},
	{"ODAJ", 4, 197751},
	{"MKAB", 4, 197752},
	{"MEXO", 4, 197753},
	{"LOAB", 4, 197754},
	{"LMDR", 4, 197755},
	{"KTWE", 4, 197756},
	{"KDIP", 4, 197757},
	{"JRAY", 4, 197758},
	{"IPNU", 4, 197759},
	{"IOMP", 4, 197760},
	{"IKHW", 4, 197761},
	{"GUMC", 4, 197762},
	{"GCYB", 4, 197763},
	{"FUWA", 4, 197764},
	{"FGUM", 4, 197765},
	{"FFYM", 4, 197766},
	{"FEYH", 4, 197767},
	{"EXRU", 4, 197768},
	{"EGJO", 4, 197769},
	{"CEYF", 4, 197770},
	{"CCCL", 4, 197771},
	{"CAUA", 4, 197772},
	{"BHUP", 4, 197773},
	{"BARV", 4, 197774},
	{"AXUN", 4, 197775},
	{"AXEC", 4, 197776},
	{"FLANNELS", 8, 197777},
	{"LIANTE", 6, 197778},
	{"SPINDRIFT", 9, 197779},
	{"MULTITAP", 8, 197780},
	{"NTPDATE", 7, 197781},
	{"MKM", 3, 197782},
	{"LIGURIAN", 8, 197783},
	{"ADMI", 4, 197784},
	{"BELOGRADCHIK", 12, 197785},
	{"UNTETHERED", 10, 197786},
	{"METACYCBUFF", 11, 197787},
	{"MASTERBETION", 12, 197788},
	{"SXEMACS", 7, 197789},
	{"PENNSYLVANIAUSA", 15, 197790},
	{"DSVIEW", 6, 197791},
	{"BOCODE", 6, 197792},
	{"TARTARE", 7, 197793},
	{"KMAX", 4, 197794},
	{"SOITTO", 6, 197795},
	{"SNIPPY", 6, 197796},
	{"FOOGLE", 6, 197797},
	{"PENTERMINE", 10, 197798},
	{"JASSIE", 6, 197799},
	{"TSHWANE", 7, 197800},
	{"EPSXE", 5, 197801},
	{"TERHUNE", 7, 197802},
	{"CONTRIVANCES", 12, 197803},
	{"ITIVE", 5, 197804},
	{"GONEGARDENING", 13, 197805},
	{"FLER", 4, 197806},
	{"SAFEWARE", 8, 197807},
	{"RECOMBINANTS", 12, 197808},
	{"PERCHLOROETHYLENE", 17, 197809},
	{"LITHUANIANS", 11, 197810},
	{"BLOMQUIST", 9, 197811},
	{"PHOTOGRAPHYBLOG", 15, 197812},
	{"MARKTPLATZ", 10, 197813},
	{"PHOSPHORYLATES", 14, 197814},
	{"VREDESTEIN", 10, 197815},
	{"RTGS", 4, 197816},
	{"PEREA", 5, 197817},
	{"ANISOTROPIES", 12, 197818},
	{"BSDMAINUTILS", 12, 197819},
	{"HYDROGELS", 9, 197820},
	{"PATHANAMTHITTA", 14, 197821},
	{"TIMLIN", 6, 197822},
	{"FLURL", 5, 197823},
	{"EIELSON", 7, 197824},
	{"BOWHUNTERS", 10, 197825},
	{"BOTKIN", 6, 197826},
	{"SLAGGING", 8, 197827},
	{"CAPITULATE", 10, 197828},
	{"VIBRANTLY", 9, 197829},
	{"MULUND", 6, 197830},
	{"LOBB", 4, 197831},
	{"PERIODONTISTS", 13, 197832},
	{"OPENTABLE", 9, 197833},
	{"GLENDINNING", 11, 197834},
	{"PHTHALIC", 8, 197835},
	{"NUTELLA", 7, 197836},
	{"QMAKE", 5, 197837},
	{"CFQ", 3, 197838},
	{"NPCA", 4, 197839},
	{"CANLLAWIAU", 10, 197840},
	{"SAFESEARCH", 10, 197841},
	{"FLESHE", 6, 197842},
	{"CONTROVERSIALLY", 15, 197843},
	{"PARAPARAUMU", 11, 197844},
	{"WAYFARING", 9, 197845},
	{"ASSEMBLYMEMBER", 14, 197846},
	{"MCVE", 4, 197847},
	{"BOXINGBOXING", 12, 197848},
	{"RECOMBINASE", 11, 197849},
	{"AHAHAHA", 7, 197850},
	{"WARDLEY", 7, 197851},
	{"KAMMER", 6, 197852},
	{"HEALTHPARTNERS", 14, 197853},
	{"CLEARCUTTING", 12, 197854},
	{"HRSDC", 5, 197855},
	{"HIPPER", 6, 197856},
	{"EIGENFUNCTION", 13, 197857},
	{"SECKER", 6, 197858},
	{"CONNECTABLE", 11, 197859},
	{"HELLYER", 7, 197860},
	{"GRANDMASTERS", 12, 197861},
	{"UNMOUNTING", 10, 197862},
	{"DEACTIVATES", 11, 197863},
	{"OUSTANDING", 10, 197864},
	{"LETROZOLE", 9, 197865},
	{"BENIGNO", 7, 197866},
	{"WHAMPOA", 7, 197867},
	{"BRIQUE", 6, 197868},
	{"ARBI", 4, 197869},
	{"SEIGEL", 6, 197870},
	{"ORENBURG", 8, 197871},
	{"SPORTSUIT", 9, 197872},
	{"APLE", 4, 197873},
	{"DEJAR", 5, 197874},
	{"CHORLEYWOOD", 11, 197875},
	{"OCTAHEDRON", 10, 197876},
	{"BOOHBAH", 7, 197877},
	{"CLEANOUT", 8, 197878},
	{"KURKA", 5, 197879},
	{"MLBMLB", 6, 197880},
	{"HOLLE", 5, 197881},
	{"DLK", 3, 197882},
	{"CCAAT", 5, 197883},
	{"MOANIN", 6, 197884},
	{"GEODATABASE", 11, 197885},
	{"LEMONROCK", 9, 197886},
	{"LYXZEN", 6, 197887},
	{"FCSTS", 5, 197888},
	{"WESTHOFF", 8, 197889},
	{"XXY", 3, 197890},
	{"ITERA", 5, 197891},
	{"ECOTOXICITY", 11, 197892},
	{"QUARANTINES", 11, 197893},
	{"TURGENEV", 8, 197894},
	{"MUSICAS", 7, 197895},
	{"WEBREF", 6, 197896},
	{"INVIDIA", 7, 197897},
	{"COATERS", 7, 197898},
	{"ZWIC", 4, 197899},
	{"ZASF", 4, 197900},
	{"YTAV", 4, 197901},
	{"YPMF", 4, 197902},
	{"XDEB", 4, 197903},
	{"VDWH", 4, 197904},
	{"UZUM", 4, 197905},
	{"UIBA", 4, 197906},
	{"UADG", 4, 197907},
	{"TAKY", 4, 197908},
	{"SYSL", 4, 197909},
	{"STGM", 4, 197910},
	{"OVAY", 4, 197911},
	{"OICF", 4, 197912},
	{"OFPD", 4, 197913},
	{"NYEQ", 4, 197914},
	{"MAOW", 4, 197915},
	{"LWAC", 4, 197916},
	{"LIKK", 4, 197917},
	{"JEWH", 4, 197918},
	{"IZZT", 4, 197919},
	{"HUKL", 4, 197920},
	{"HEMX", 4, 197921},
	{"GMOI", 4, 197922},
	{"GGDR", 4, 197923},
	{"FIPL", 4, 197924},
	{"EDBN", 4, 197925},
	{"DPPG", 4, 197926},
	{"DMRN", 4, 197927},
	{"DLTD", 4, 197928},
	{"DECG", 4, 197929},
	{"CYAU", 4, 197930},
	{"CWIR", 4, 197931},
	{"CMTO", 4, 197932},
	{"CEAQ", 4, 197933},
	{"BEKW", 4, 197934},
	{"KASEM", 5, 197935},
	{"CARMELITA", 9, 197936},
	{"DISFAVOR", 8, 197937},
	{"WOOLFORD", 8, 197938},
	{"GINGA", 5, 197939},
	{"WESTWEGO", 8, 197940},
	{"DOMINICO", 8, 197941},
	{"GEARSHIFT", 9, 197942},
	{"FARDS", 5, 197943},
	{"STADEN", 6, 197944},
	{"KAMES", 5, 197945},
	{"BIMAL", 5, 197946},
	{"NBANASCAR", 9, 197947},
	{"FRICKEN", 7, 197948},
	{"LLEGADA", 7, 197949},
	{"ELLIPTICITY", 11, 197950},
	{"STRACHEY", 8, 197951},
	{"LAKATOS", 7, 197952},
	{"WNBAWNBA", 8, 197953},
	{"UMGEBUNG", 8, 197954},
	{"MLSSOCCER", 9, 197955},
	{"KYPRIAKOY", 9, 197956},
	{"CYLLID", 6, 197957},
	{"NUDEGRILS", 9, 197958},
	{"MALVEAUX", 8, 197959},
	{"ANTIGRAVITY", 11, 197960},
	{"LIVERIES", 8, 197961},
	{"TEETERS", 7, 197962},
	{"MIRKIN", 6, 197963},
	{"ISLETA", 6, 197964},
	{"IMMUNOBIOLOGY", 13, 197965},
	{"PARALLELIZED", 12, 197966},
	{"EQUIVOCATION", 12, 197967},
	{"CROSTHWAITE", 11, 197968},
	{"SPDRS", 5, 197969},
	{"PIERLUIGI", 9, 197970},
	{"YANTRAS", 7, 197971},
	{"AFROBEAT", 8, 197972},
	{"CARLUCCI", 8, 197973},
	{"SOEHNLE", 7, 197974},
	{"GARGANO", 7, 197975},
	{"TONURI", 6, 197976},
	{"SIEUR", 5, 197977},
	{"SURR", 4, 197978},
	{"REICHMAN", 8, 197979},
	{"PAPILLAE", 8, 197980},
	{"CHETEK", 6, 197981},
	{"GRANGERS", 8, 197982},
	{"DEYO", 4, 197983},
	{"CCDC", 4, 197984},
	{"MOTIVA", 6, 197985},
	{"MORNEAU", 7, 197986},
	{"CENTREPOINT", 11, 197987},
	{"PHORUMS", 7, 197988},
	{"PRESSWIRE", 9, 197989},
	{"ONLINEDOCS", 10, 197990},
	{"MDATE", 5, 197991},
	{"SAXAPHONE", 9, 197992},
	{"IDDYBUD", 7, 197993},
	{"HUMMELSTOWN", 11, 197994},
	{"EPFLAGENTAS", 11, 197995},
	{"GIPS", 4, 197996},
	{"BYLAYER", 7, 197997},
	{"ADAMUS", 6, 197998},
	{"BOOKSAMILLION", 13, 197999},
	{"ANIMEIGO", 8, 198000},
	{"BIPOD", 5, 198001},
	{"RUBES", 5, 198002},
	{"BARRACLOUGH", 11, 198003},
	{"AUDAX", 5, 198004},
	{"ARCHITETTURA", 12, 198005},
	{"STEVEG", 6, 198006},
	{"INDIECLICK", 10, 198007},
	{"BOTLEY", 6, 198008},
	{"IPODLOUNGE", 10, 198009},
	{"GUSTATORY", 9, 198010},
	{"DEKKERS", 7, 198011},
	{"BLACKMEN", 8, 198012},
	{"BASTI", 5, 198013},
	{"WACH", 4, 198014},
	{"GOIANIA", 7, 198015},
	{"ECTIVE", 6, 198016},
	{"RIVLIN", 6, 198017},
	{"QUESTEX", 7, 198018},
	{"DISRESPECTED", 12, 198019},
	{"DATAHJAELP", 10, 198020},
	{"KOMPLETTE", 9, 198021},
	{"GLACIATED", 9, 198022},
	{"MINUMUM", 7, 198023},
	{"KOZY", 4, 198024},
	{"EVOLVEMENT", 10, 198025},
	{"DARNALL", 7, 198026},
	{"KORMOS", 6, 198027},
	{"SUNIX", 5, 198028},
	{"MOKE", 4, 198029},
	{"SCHIAPARELLI", 12, 198030},
	{"DROPZONE", 8, 198031},
	{"BACKGROUNDCOLOR", 15, 198032},
	{"DOOGUE", 6, 198033},
	{"ENGULFS", 7, 198034},
	{"DEVEZ", 5, 198035},
	{"ANATOMIST", 9, 198036},
	{"WINDAGE", 7, 198037},
	{"FORMYL", 6, 198038},
	{"DIAMON", 6, 198039},
	{"DEPRIVATIONS", 12, 198040},
	{"PHOSPHORS", 9, 198041},
	{"TIMEWISE", 8, 198042},
	{"MILKYWAY", 8, 198043},
	{"HEILMANN", 8, 198044},
	{"PROSECUTES", 10, 198045},
	{"FORTNIGHTS", 10, 198046},
	{"BUCCO", 5, 198047},
	{"WHITEHAUS", 9, 198048},
	{"WIEDERSEHEN", 11, 198049},
	{"NQMC", 4, 198050},
	{"DORION", 6, 198051},
	{"ANPR", 4, 198052},
	{"BLOGSBLOGS", 10, 198053},
	{"EUROLINE", 8, 198054},
	{"KMRILEY", 7, 198055},
	{"REDBRICK", 8, 198056},
	{"JUMBOS", 6, 198057},
	{"DECELERATE", 10, 198058},
	{"KOOB", 4, 198059},
	{"FUNTASIA", 8, 198060},
	{"ZCRI", 4, 198061},
	{"YMRR", 4, 198062},
	{"YMCB", 4, 198063},
	{"YJAF", 4, 198064},
	{"VIUM", 4, 198065},
	{"UYAK", 4, 198066},
	{"UIAM", 4, 198067},
	{"TVUN", 4, 198068},
	{"TTGU", 4, 198069},
	{"TOZZ", 4, 198070},
	{"RYYI", 4, 198071},
	{"RWYO", 4, 198072},
	{"RMRL", 4, 198073},
	{"RIXL", 4, 198074},
	{"RAZN", 4, 198075},
	{"RACN", 4, 198076},
	{"OZAG", 4, 198077},
	{"OWEQ", 4, 198078},
	{"ORRP", 4, 198079},
	{"OHRU", 4, 198080},
	{"OGGW", 4, 198081},
	{"NWAB", 4, 198082},
	{"MPIQ", 4, 198083},
	{"MOMN", 4, 198084},
	{"MNBE", 4, 198085},
	{"MNAC", 4, 198086},
	{"MMIM", 4, 198087},
	{"LFSY", 4, 198088},
	{"GIKA", 4, 198089},
	{"GHNW", 4, 198090},
	{"EUKV", 4, 198091},
	{"ESUW", 4, 198092},
	{"EDRJ", 4, 198093},
	{"EDCZ", 4, 198094},
	{"DZIG", 4, 198095},
	{"DTCU", 4, 198096},
	{"DEAZ", 4, 198097},
	{"BLIA", 4, 198098},
	{"APSV", 4, 198099},
	{"AFWE", 4, 198100},
	{"SOUNDFEEDER", 11, 198101},
	{"MINDFINDBIND", 12, 198102},
	{"ENGLERT", 7, 198103},
	{"BEIRNE", 6, 198104},
	{"ANTONINUS", 9, 198105},
	{"LUCIENNE", 8, 198106},
	{"STUBB", 5, 198107},
	{"MONODOC", 7, 198108},
	{"DIGISCOPING", 11, 198109},
	{"MEGIS", 5, 198110},
	{"CONCORDESTYLE", 13, 198111},
	{"KUB", 3, 198112},
	{"INTERSITES", 10, 198113},
	{"ITEMTYPE", 8, 198114},
	{"PROVEMENT", 9, 198115},
	{"CCRI", 4, 198116},
	{"NAKEDPICTURE", 12, 198117},
	{"LAUNDRESS", 9, 198118},
	{"EGOR", 4, 198119},
	{"VPNC", 4, 198120},
	{"REFR", 4, 198121},
	{"CTRA", 4, 198122},
	{"BALTICA", 7, 198123},
	{"INFRASTRUC", 10, 198124},
	{"ROBORAPTOR", 10, 198125},
	{"TRYAVNA", 7, 198126},
	{"PLASMASYNC", 10, 198127},
	{"BUGLES", 6, 198128},
	{"BOGDANOV", 8, 198129},
	{"SCTV", 4, 198130},
	{"MICROWAVED", 10, 198131},
	{"ZMODEM", 6, 198132},
	{"PIACE", 5, 198133},
	{"ROCES", 5, 198134},
	{"PROXOMITRON", 11, 198135},
	{"ORARIO", 6, 198136},
	{"RGV", 3, 198137},
	{"JOSCHKA", 7, 198138},
	{"INCOMPLETES", 11, 198139},
	{"MISBEHAVIN", 10, 198140},
	{"DESDEMONIA", 10, 198141},
	{"ONGAKU", 6, 198142},
	{"FRAP", 4, 198143},
	{"AROLWG", 6, 198144},
	{"GLOBBING", 8, 198145},
	{"MANIE", 5, 198146},
	{"BAPS", 4, 198147},
	{"TULALIP", 7, 198148},
	{"CHILENA", 7, 198149},
	{"LOOKY", 5, 198150},
	{"SUPERHIGH", 9, 198151},
	{"IDNR", 4, 198152},
	{"FISHWATCHER", 11, 198153},
	{"POLYSEMY", 8, 198154},
	{"REASSURANCES", 12, 198155},
	{"PLOWSHARES", 10, 198156},
	{"FARANG", 6, 198157},
	{"BMAKE", 5, 198158},
	{"CIVI", 4, 198159},
	{"CFCDEV", 6, 198160},
	{"HURENALMANACH", 13, 198161},
	{"SWINDLERS", 9, 198162},
	{"BLOGOSFERICS", 12, 198163},
	{"MASCARO", 7, 198164},
	{"LUKKA", 5, 198165},
	{"CANCELLER", 9, 198166},
	{"MCGAHEE", 7, 198167},
	{"AMBROISE", 8, 198168},
	{"WALBRIDGE", 9, 198169},
	{"SENATO", 6, 198170},
	{"GLOBALSCAPE", 11, 198171},
	{"SEASTAR", 7, 198172},
	{"NETPERF", 7, 198173},
	{"CLANDESTINELY", 13, 198174},
	{"RECOMBINED", 10, 198175},
	{"HILLHOUSE", 9, 198176},
	{"TRICKSTERS", 10, 198177},
	{"DOVECOTE", 8, 198178},
	{"BIOPORTFOLIO", 12, 198179},
	{"SPILLET", 7, 198180},
	{"PIRG", 4, 198181},
	{"MARIANN", 7, 198182},
	{"BRYDON", 6, 198183},
	{"AVERE", 5, 198184},
	{"SCARABEO", 8, 198185},
	{"SOITTOAANET", 11, 198186},
	{"KYPHOSIS", 8, 198187},
	{"VITRECTOMY", 10, 198188},
	{"TARRIE", 6, 198189},
	{"HEREINBEFORE", 12, 198190},
	{"MSVCRT", 6, 198191},
	{"DURG", 4, 198192},
	{"MOOM", 4, 198193},
	{"LASCELLES", 9, 198194},
	{"MULTILIB", 8, 198195},
	{"CALLISON", 8, 198196},
	{"ESCALATIONS", 11, 198197},
	{"ANATOL", 6, 198198},
	{"STIFFENERS", 10, 198199},
	{"PARAHAEMOLYTICUS", 16, 198200},
	{"TRAIDCRAFT", 10, 198201},
	{"SCHMELZER", 9, 198202},
	{"KIRRA", 5, 198203},
	{"CAPPELLO", 8, 198204},
	{"TUDES", 5, 198205},
	{"UNIBOND", 7, 198206},
	{"DABROWSKI", 9, 198207},
	{"YUVR", 4, 198208},
	{"YMEF", 4, 198209},
	{"YDWO", 4, 198210},
	{"WAPW", 4, 198211},
	{"ULYY", 4, 198212},
	{"ULKB", 4, 198213},
	{"TIDP", 4, 198214},
	{"SZLA", 4, 198215},
	{"RDTC", 4, 198216},
	{"PIDN", 4, 198217},
	{"OUYU", 4, 198218},
	{"ORUE", 4, 198219},
	{"OMRT", 4, 198220},
	{"OLZW", 4, 198221},
	{"OFBT", 4, 198222},
	{"NSUU", 4, 198223},
	{"NIDG", 4, 198224},
	{"MPEM", 4, 198225},
	{"MBEP", 4, 198226},
	{"LIXO", 4, 198227},
	{"LIXF", 4, 198228},
	{"LIEY", 4, 198229},
	{"HRUH", 4, 198230},
	{"HPJO", 4, 198231},
	{"HBYK", 4, 198232},
	{"GWEP", 4, 198233},
	{"EYWC", 4, 198234},
	{"EXVE", 4, 198235},
	{"EWZO", 4, 198236},
	{"EDPD", 4, 198237},
	{"DFAX", 4, 198238},
	{"DDDO", 4, 198239},
	{"CYOB", 4, 198240},
	{"BEKT", 4, 198241},
	{"AWNK", 4, 198242},
	{"FICHTE", 6, 198243},
	{"CABBY", 5, 198244},
	{"RATELY", 6, 198245},
	{"COOLIES", 7, 198246},
	{"CAUSTICS", 8, 198247},
	{"CABIG", 5, 198248},
	{"SUPREMA", 7, 198249},
	{"SPARWOOD", 8, 198250},
	{"OREWA", 5, 198251},
	{"EDRA", 4, 198252},
	{"BYDDWN", 6, 198253},
	{"AJOUTEZ", 7, 198254},
	{"KALINGA", 7, 198255},
	{"ACRDS", 5, 198256},
	{"YELOW", 5, 198257},
	{"QBIC", 4, 198258},
	{"CARDY", 5, 198259},
	{"AGAPEPRESS", 10, 198260},
	{"QUINDLEN", 8, 198261},
	{"RAIKES", 6, 198262},
	{"PARAMETERIZE", 12, 198263},
	{"BOTTLER", 7, 198264},
	{"ERIGERON", 8, 198265},
	{"SIFRE", 5, 198266},
	{"NCNAME", 6, 198267},
	{"SUNRIDGE", 8, 198268},
	{"LANDGOED", 8, 198269},
	{"USDC", 4, 198270},
	{"SYMBOLOGIES", 11, 198271},
	{"MORRISTON", 9, 198272},
	{"KOESTLER", 8, 198273},
	{"NARROGIN", 8, 198274},
	{"TFTPBOOT", 8, 198275},
	{"LAUBER", 6, 198276},
	{"GUPSHUP", 7, 198277},
	{"BRIARS", 6, 198278},
	{"TANTRAMASSAGE", 13, 198279},
	{"WODY", 4, 198280},
	{"TAINTING", 8, 198281},
	{"MDNT", 4, 198282},
	{"ENOSYS", 6, 198283},
	{"PANGBORN", 8, 198284},
	{"OUTLASTED", 9, 198285},
	{"GEOTARGET", 9, 198286},
	{"TARENTUM", 8, 198287},
	{"SECURITE", 8, 198288},
	{"PUU", 3, 198289},
	{"LAROSA", 6, 198290},
	{"KASHRUT", 7, 198291},
	{"AVOGADRO", 8, 198292},
	{"DEMOBILISATION", 14, 198293},
	{"RIPPON", 6, 198294},
	{"CHAUDE", 6, 198295},
	{"UNFITNESS", 9, 198296},
	{"PINBOARD", 8, 198297},
	{"CYPRIS", 6, 198298},
	{"GYMUNED", 7, 198299},
	{"CYBERLIBRARY", 12, 198300},
	{"TUINEN", 6, 198301},
	{"LAMELLAE", 8, 198302},
	{"OCULUS", 6, 198303},
	{"GEODON", 6, 198304},
	{"SWANNANOA", 9, 198305},
	{"BOETHIUS", 8, 198306},
	{"XDC", 3, 198307},
	{"BANNA", 5, 198308},
	{"SIMPLYMEPIS", 11, 198309},
	{"CHALL", 5, 198310},
	{"VANESSADELRIO", 13, 198311},
	{"TITTTIES", 8, 198312},
	{"DIALOGICAL", 10, 198313},
	{"ANNIHILATING", 12, 198314},
	{"AGRARIA", 7, 198315},
	{"NEOMAGIC", 8, 198316},
	{"ISSPACE", 7, 198317},
	{"SWATHED", 7, 198318},
	{"THURLES", 7, 198319},
	{"MAKETEXT", 8, 198320},
	{"ACCRETING", 9, 198321},
	{"TUDIES", 6, 198322},
	{"GRIBBIN", 7, 198323},
	{"ANNELIESE", 9, 198324},
	{"FRAULEIN", 8, 198325},
	{"MYTHIX", 6, 198326},
	{"VCSEL", 5, 198327},
	{"OLEANDERS", 9, 198328},
	{"EXTORTED", 8, 198329},
	{"GAMEDEV", 7, 198330},
	{"MAYAS", 5, 198331},
	{"AVARICIOUS", 10, 198332},
	{"QOUTE", 5, 198333},
	{"FOCKE", 5, 198334},
	{"ACTIVEREPORTS", 13, 198335},
	{"THAIMASSAGE", 11, 198336},
	{"BOARDSHOP", 9, 198337},
	{"PELLERIN", 8, 198338},
	{"FIRSTSPOT", 9, 198339},
	{"MOVA", 4, 198340},
	{"ALIKI", 5, 198341},
	{"VIDEONICS", 9, 198342},
	{"EVENINGWEAR", 11, 198343},
	{"ARENAC", 6, 198344},
	{"ALEERA", 6, 198345},
	{"PRESORTED", 9, 198346},
	{"ZILM", 4, 198347},
	{"ZBEA", 4, 198348},
	{"YLLJ", 4, 198349},
	{"YIAG", 4, 198350},
	{"YHEV", 4, 198351},
	{"XTSB", 4, 198352},
	{"VSLE", 4, 198353},
	{"USYG", 4, 198354},
	{"UDKI", 4, 198355},
	{"SUMG", 4, 198356},
	{"SMIZ", 4, 198357},
	{"OOMQ", 4, 198358},
	{"OCSW", 4, 198359},
	{"NUJA", 4, 198360},
	{"JPUR", 4, 198361},
	{"HYED", 4, 198362},
	{"GNVA", 4, 198363},
	{"GGSU", 4, 198364},
	{"FHIC", 4, 198365},
	{"FEVR", 4, 198366},
	{"FAYU", 4, 198367},
	{"EWYL", 4, 198368},
	{"DYOT", 4, 198369},
	{"DAGY", 4, 198370},
	{"CAWL", 4, 198371},
	{"ATWC", 4, 198372},
	{"ARXB", 4, 198373},
	{"AHLM", 4, 198374},
	{"USALLY", 6, 198375},
	{"OPENWALL", 8, 198376},
	{"FAENZA", 6, 198377},
	{"FABRIKANT", 9, 198378},
	{"CACFP", 5, 198379},
	{"PROCHASKA", 9, 198380},
	{"WHITEFLIES", 10, 198381},
	{"ENTFERNT", 8, 198382},
	{"WAFT", 4, 198383},
	{"LAUB", 4, 198384},
	{"KIDRON", 6, 198385},
	{"RUMBLEPAD", 9, 198386},
	{"SHTUFF", 6, 198387},
	{"AVICENNA", 8, 198388},
	{"GIZMAG", 6, 198389},
	{"ONECHIPCOLORAREA", 16, 198390},
	{"DIGNAN", 6, 198391},
	{"VIEWPORTS", 9, 198392},
	{"MYTREES", 7, 198393},
	{"WONDERBOY", 9, 198394},
	{"XPCSPY", 6, 198395},
	{"SQUIDBLOG", 9, 198396},
	{"ALTHON", 6, 198397},
	{"SPINITRON", 9, 198398},
	{"GERTRUD", 7, 198399},
	{"FINANZ", 6, 198400},
	{"SNAPCASE", 8, 198401},
	{"POPISH", 6, 198402},
	{"STARCHEFS", 9, 198403},
	{"SABUCAT", 7, 198404},
	{"DARNING", 7, 198405},
	{"JAERI", 5, 198406},
	{"ASYMMETRICALLY", 14, 198407},
	{"ZCAT", 4, 198408},
	{"RIGHTMOVE", 9, 198409},
	{"BLOOMQUIST", 10, 198410},
	{"SHAHZAD", 7, 198411},
	{"PICOGRAM", 8, 198412},
	{"YMGYNGHORI", 10, 198413},
	{"OVERSTRETCHED", 13, 198414},
	{"PROEDROY", 8, 198415},
	{"INSTRUCTABLES", 13, 198416},
	{"CARTV", 5, 198417},
	{"DONTE", 5, 198418},
	{"TICARET", 7, 198419},
	{"SELEN", 5, 198420},
	{"RAPSODIES", 9, 198421},
	{"HOPWA", 5, 198422},
	{"NATIONALBANK", 12, 198423},
	{"GANGED", 6, 198424},
	{"BIGASS", 6, 198425},
	{"UNIVERSTIY", 10, 198426},
	{"PHALACROCORAX", 13, 198427},
	{"ZYGOTIC", 7, 198428},
	{"TEEHEE", 6, 198429},
	{"SOLOWAY", 7, 198430},
	{"PASOS", 5, 198431},
	{"DONNO", 5, 198432},
	{"BEHOLDE", 7, 198433},
	{"DULCIMERS", 9, 198434},
	{"CYFLWYNO", 8, 198435},
	{"CUF", 3, 198436},
	{"POLLSTAR", 8, 198437},
	{"REINITIALIZE", 12, 198438},
	{"OHERWYDD", 8, 198439},
	{"CROIS", 5, 198440},
	{"NEWX", 4, 198441},
	{"BMGT", 4, 198442},
	{"DLAN", 4, 198443},
	{"JOCELYNE", 8, 198444},
	{"BICSI", 5, 198445},
	{"FIDGETING", 9, 198446},
	{"CXREF", 5, 198447},
	{"THOMASTOWN", 10, 198448},
	{"TERESE", 6, 198449},
	{"GOLE", 4, 198450},
	{"MYF", 3, 198451},
	{"DOXA", 4, 198452},
	{"ARCHIWEB", 8, 198453},
	{"EARTHJUSTICE", 12, 198454},
	{"JUHASZ", 6, 198455},
	{"UNECESSARY", 10, 198456},
	{"RIFKIND", 7, 198457},
	{"TRUEPOWER", 9, 198458},
	{"DEBITEL", 7, 198459},
	{"WARMACHINE", 10, 198460},
	{"SANOMAT", 7, 198461},
	{"TARANGIRE", 9, 198462},
	{"NICOLLETTA", 10, 198463},
	{"CMDBS", 5, 198464},
	{"PIQUEPAILLE", 11, 198465},
	{"LAMONI", 6, 198466},
	{"MESOPOROUS", 10, 198467},
	{"GARLOCK", 7, 198468},
	{"HOCKENHEIM", 10, 198469},
	{"FRANKENHEIMER", 13, 198470},
	{"KRZYZEWSKI", 10, 198471},
	{"KLUBI", 5, 198472},
	{"ROSKIN", 6, 198473},
	{"FOTOTAUSCH", 10, 198474},
	{"ARENANET", 8, 198475},
	{"RESINOUS", 8, 198476},
	{"GRANIT", 6, 198477},
	{"SCENESTER", 9, 198478},
	{"SLAPPERS", 8, 198479},
	{"FLAYED", 6, 198480},
	{"EXTENDETH", 9, 198481},
	{"YENTA", 5, 198482},
	{"ZAAD", 4, 198483},
	{"NEWSBANK", 8, 198484},
	{"KEPADA", 6, 198485},
	{"AVASCULAR", 9, 198486},
	{"PARAMOUR", 8, 198487},
	{"TERAZOSIN", 9, 198488},
	{"COOLRUNNING", 11, 198489},
	{"ARABINOSE", 9, 198490},
	{"KIERSTEN", 8, 198491},
	{"SAFRA", 5, 198492},
	{"MAPMAKER", 8, 198493},
	{"JUANMA", 6, 198494},
	{"MYUBC", 5, 198495},
	{"CHROMASIA", 9, 198496},
	{"CARTOONETWORK", 13, 198497},
	{"MICHAUX", 7, 198498},
	{"ENUNCIATION", 11, 198499},
	{"ACCESSMYLIBRARY", 15, 198500},
	{"REPROGRAPHIC", 12, 198501},
	{"AMARILLA", 8, 198502},
	{"UCITS", 5, 198503},
	{"SUBURBANITES", 12, 198504},
	{"ZERJ", 4, 198505},
	{"YZOR", 4, 198506},
	{"YOSP", 4, 198507},
	{"YLHE", 4, 198508},
	{"XTAF", 4, 198509},
	{"XINR", 4, 198510},
	{"VMAT", 4, 198511},
	{"VELQ", 4, 198512},
	{"VDIV", 4, 198513},
	{"URKW", 4, 198514},
	{"UKSS", 4, 198515},
	{"UIDG", 4, 198516},
	{"UEIL", 4, 198517},
	{"TUZZ", 4, 198518},
	{"TMOY", 4, 198519},
	{"TMCH", 4, 198520},
	{"RXST", 4, 198521},
	{"ROEU", 4, 198522},
	{"RINX", 4, 198523},
	{"RCOY", 4, 198524},
	{"RCDA", 4, 198525},
	{"QIOF", 4, 198526},
	{"OYAV", 4, 198527},
	{"OKVO", 4, 198528},
	{"NURO", 4, 198529},
	{"NNJU", 4, 198530},
	{"NLVS", 4, 198531},
	{"NLUL", 4, 198532},
	{"LLKU", 4, 198533},
	{"KYVO", 4, 198534},
	{"KBYU", 4, 198535},
	{"JALU", 4, 198536},
	{"IEFY", 4, 198537},
	{"IBIC", 4, 198538},
	{"HRYG", 4, 198539},
	{"HRBA", 4, 198540},
	{"FKMS", 4, 198541},
	{"FIMU", 4, 198542},
	{"FILC", 4, 198543},
	{"EXUR", 4, 198544},
	{"EXOM", 4, 198545},
	{"EXBL", 4, 198546},
	{"ECQU", 4, 198547},
	{"DZED", 4, 198548},
	{"DNDO", 4, 198549},
	{"BYDW", 4, 198550},
	{"BLOV", 4, 198551},
	{"BGOV", 4, 198552},
	{"BFEA", 4, 198553},
	{"BEXL", 4, 198554},
	{"BEJI", 4, 198555},
	{"ARMK", 4, 198556},
	{"AORY", 4, 198557},
	{"XINITRC", 7, 198558},
	{"SANDERLING", 10, 198559},
	{"LILLITHVAIN", 11, 198560},
	{"GARETT", 6, 198561},
	{"FICHES", 6, 198562},
	{"DRUMSTRUCK", 10, 198563},
	{"TEXTPAD", 7, 198564},
	{"RETURNEE", 8, 198565},
	{"NONINSTITUTIONAL", 16, 198566},
	{"LGU", 3, 198567},
	{"HOPETOUN", 8, 198568},
	{"SOLILOQUIES", 11, 198569},
	{"KVUE", 4, 198570},
	{"NUBY", 4, 198571},
	{"GAMM", 4, 198572},
	{"ACTV", 4, 198573},
	{"BROADVOICE", 10, 198574},
	{"HOLLEMAN", 8, 198575},
	{"FESSOR", 6, 198576},
	{"CONTAS", 6, 198577},
	{"NIGHY", 5, 198578},
	{"BADDER", 6, 198579},
	{"EUSTACHE", 8, 198580},
	{"TIMAH", 5, 198581},
	{"SNOWMOBILERS", 12, 198582},
	{"ADSPACE", 7, 198583},
	{"KARDJALI", 8, 198584},
	{"DIFERENTE", 9, 198585},
	{"AMINOTRANSFERASES", 17, 198586},
	{"PALEOCLIMATE", 12, 198587},
	{"NILFISK", 7, 198588},
	{"NEOPOINT", 8, 198589},
	{"HERBEAU", 7, 198590},
	{"BIBO", 4, 198591},
	{"UENCE", 5, 198592},
	{"DIASPORIC", 9, 198593},
	{"THILO", 5, 198594},
	{"KANCHI", 6, 198595},
	{"WESTWORLD", 9, 198596},
	{"ALBANI", 6, 198597},
	{"CALAFATE", 8, 198598},
	{"KICKSTAND", 9, 198599},
	{"CHALTE", 6, 198600},
	{"HEIMLICHE", 9, 198601},
	{"RADDA", 5, 198602},
	{"LIONFISH", 8, 198603},
	{"JOSUE", 5, 198604},
	{"FRAILTIES", 9, 198605},
	{"ENTRADAS", 8, 198606},
	{"VOICEPRINT", 10, 198607},
	{"SPORTBOOK", 9, 198608},
	{"CAMAROS", 7, 198609},
	{"AMYLIN", 6, 198610},
	{"GYATSO", 6, 198611},
	{"VARDS", 5, 198612},
	{"SPIDEAN", 7, 198613},
	{"SEMITRAILER", 11, 198614},
	{"OPTIQUEST", 9, 198615},
	{"GELLMAN", 7, 198616},
	{"MEMORAB", 7, 198617},
	{"GIRARDI", 7, 198618},
	{"ANIMACJE", 8, 198619},
	{"HAUNCHES", 8, 198620},
	{"EBAYCA", 6, 198621},
	{"CONTUSIONS", 10, 198622},
	{"POWERSTRIP", 10, 198623},
	{"UNDERCOUNT", 10, 198624},
	{"RICHY", 5, 198625},
	{"THEONERING", 10, 198626},
	{"NEUROVASCULAR", 13, 198627},
	{"METHYLPARABEN", 13, 198628},
	{"BENCKISER", 9, 198629},
	{"TRUNKLINE", 9, 198630},
	{"STRANI", 6, 198631},
	{"GAVRIEL", 7, 198632},
	{"JOHNATHON", 9, 198633},
	{"IRONPYTHON", 10, 198634},
	{"POSTCOMM", 8, 198635},
	{"BAKO", 4, 198636},
	{"OPTREX", 6, 198637},
	{"TEHSIL", 6, 198638},
	{"MOREA", 5, 198639},
	{"CHASTENED", 9, 198640},
	{"GLYCOLYTIC", 10, 198641},
	{"NORFLOXACIN", 11, 198642},
	{"ESSID", 5, 198643},
	{"EKSTROM", 7, 198644},
	{"SEAMOUNTS", 9, 198645},
	{"MORRISETTE", 10, 198646},
	{"HORRENDOUSLY", 12, 198647},
	{"NLSREF", 6, 198648},
	{"DICTINARY", 9, 198649},
	{"CLASSISM", 8, 198650},
	{"CONNEXES", 8, 198651},
	{"DROPSY", 6, 198652},
	{"BUILDERDEPOT", 12, 198653},
	{"MENY", 4, 198654},
	{"IMPOSITIONS", 11, 198655},
	{"HIMEJI", 6, 198656},
	{"OLIVERI", 7, 198657},
	{"IGERT", 5, 198658},
	{"DOOLING", 7, 198659},
	{"XPLOSION", 8, 198660},
	{"POINTSCORE", 10, 198661},
	{"POLYETHER", 9, 198662},
	{"HELLERSTEIN", 11, 198663},
	{"CCGGG", 5, 198664},
	{"ACCUSAM", 7, 198665},
	{"TEKNISKA", 8, 198666},
	{"DORRELL", 7, 198667},
	{"DIAGENESIS", 10, 198668},
	{"CANCERBUSTERS", 13, 198669},
	{"WAPATO", 6, 198670},
	{"MOONGLOW", 8, 198671},
	{"IFSC", 4, 198672},
	{"AZUCAR", 6, 198673},
	{"WACKENHUT", 9, 198674},
	{"LINDBLOM", 8, 198675},
	{"ASKJ", 4, 198676},
	{"MUHL", 4, 198677},
	{"SHIROW", 6, 198678},
	{"ESATATE", 7, 198679},
	{"LAGUNITAS", 9, 198680},
	{"WRIGGLED", 8, 198681},
	{"MERONA", 6, 198682},
	{"ROWAND", 6, 198683},
	{"MYAKKA", 6, 198684},
	{"FROMMERS", 8, 198685},
	{"YIYI", 4, 198686},
	{"SIRENE", 6, 198687},
	{"CARLOAD", 7, 198688},
	{"ZZYG", 4, 198689},
	{"YGOG", 4, 198690},
	{"WJUR", 4, 198691},
	{"WAGL", 4, 198692},
	{"WADL", 4, 198693},
	{"VNOR", 4, 198694},
	{"VEMS", 4, 198695},
	{"UIRS", 4, 198696},
	{"TDUO", 4, 198697},
	{"PRRE", 4, 198698},
	{"PFIX", 4, 198699},
	{"OYJU", 4, 198700},
	{"OOVY", 4, 198701},
	{"ONDZ", 4, 198702},
	{"NMLA", 4, 198703},
	{"NGYW", 4, 198704},
	{"MXAN", 4, 198705},
	{"MAAV", 4, 198706},
	{"LTSQ", 4, 198707},
	{"LNAU", 4, 198708},
	{"LLMP", 4, 198709},
	{"LIYO", 4, 198710},
	{"KUSM", 4, 198711},
	{"JURC", 4, 198712},
	{"IFVE", 4, 198713},
	{"HMWA", 4, 198714},
	{"GYVI", 4, 198715},
	{"GVEL", 4, 198716},
	{"GMSE", 4, 198717},
	{"GJRA", 4, 198718},
	{"FUIN", 4, 198719},
	{"FLOL", 4, 198720},
	{"FESY", 4, 198721},
	{"FEMT", 4, 198722},
	{"EFPH", 4, 198723},
	{"EFAZ", 4, 198724},
	{"DULB", 4, 198725},
	{"DIVV", 4, 198726},
	{"DIIW", 4, 198727},
	{"DCSH", 4, 198728},
	{"COVS", 4, 198729},
	{"CHMD", 4, 198730},
	{"CGLY", 4, 198731},
	{"BEIK", 4, 198732},
	{"ASVP", 4, 198733},
	{"KIELBASA", 8, 198734},
	{"MARSHALED", 9, 198735},
	{"GAYNESS", 7, 198736},
	{"TEIRLINCK", 9, 198737},
	{"EXPOUNDS", 8, 198738},
	{"COULTRE", 7, 198739},
	{"TELEMANAGEMENT", 14, 198740},
	{"MESCALERO", 9, 198741},
	{"MAJO", 4, 198742},
	{"HURRELL", 7, 198743},
	{"STERIOGRAM", 10, 198744},
	{"NAKATANI", 8, 198745},
	{"METHANOSARCINA", 14, 198746},
	{"GOODGE", 6, 198747},
	{"CARTWHEELS", 10, 198748},
	{"METEOROL", 8, 198749},
	{"POLYBAG", 7, 198750},
	{"SOUTHFIELDS", 11, 198751},
	{"LINEBREAKS", 10, 198752},
	{"WEDDIN", 6, 198753},
	{"RADTKE", 6, 198754},
	{"PARAMORE", 8, 198755},
	{"PAONIA", 6, 198756},
	{"UNPRINTED", 9, 198757},
	{"MANUELS", 7, 198758},
	{"ICKLE", 5, 198759},
	{"HULUD", 5, 198760},
	{"COLONIZERS", 10, 198761},
	{"ALDISS", 6, 198762},
	{"PICH", 4, 198763},
	{"NUTRIA", 6, 198764},
	{"SALLEE", 6, 198765},
	{"RHEOLIADAU", 10, 198766},
	{"RATHAUS", 7, 198767},
	{"HARDSCRABBLE", 12, 198768},
	{"HENNIGAN", 8, 198769},
	{"CDECL", 5, 198770},
	{"MICROSCAN", 9, 198771},
	{"SQUIDU", 6, 198772},
	{"HYDROPLANE", 10, 198773},
	{"BOILSOFT", 8, 198774},
	{"THORACOTOMY", 11, 198775},
	{"SNUFFERS", 8, 198776},
	{"LITLLE", 6, 198777},
	{"EMBROIDERING", 12, 198778},
	{"ARBORTEXT", 9, 198779},
	{"TCPQUOTA", 8, 198780},
	{"CEPHEID", 7, 198781},
	{"SIGNITY", 7, 198782},
	{"DISPLEASE", 9, 198783},
	{"BBDO", 4, 198784},
	{"RUSSAIN", 7, 198785},
	{"NICODERM", 8, 198786},
	{"DENHOLM", 7, 198787},
	{"CLASSNOTFOUNDEXCEPTION", 22, 198788},
	{"VIRTUALBOY", 10, 198789},
	{"SITEWWW", 7, 198790},
	{"DDW", 3, 198791},
	{"CDPD", 4, 198792},
	{"MONEYED", 7, 198793},
	{"PALMERTON", 9, 198794},
	{"DOMTAR", 6, 198795},
	{"TADEMA", 6, 198796},
	{"FRIEDRICHS", 10, 198797},
	{"HELLAH", 6, 198798},
	{"HALTEN", 6, 198799},
	{"CORTOS", 6, 198800},
	{"ROLLESTON", 9, 198801},
	{"MICELLE", 7, 198802},
	{"FREENAKD", 8, 198803},
	{"ACCESSOIRE", 10, 198804},
	{"SITUATIONIST", 12, 198805},
	{"DISCORDANCE", 11, 198806},
	{"ROMANIZED", 9, 198807},
	{"PLACENAME", 9, 198808},
	{"TRASHES", 7, 198809},
	{"CGIAPP", 6, 198810},
	{"VIRU", 4, 198811},
	{"LOUI", 4, 198812},
	{"GUERTIN", 7, 198813},
	{"LISTSERVES", 10, 198814},
	{"ARMLEY", 6, 198815},
	{"APHOBIA", 7, 198816},
	{"PELIGRO", 7, 198817},
	{"MULTICAM", 8, 198818},
	{"CLIENTLESS", 10, 198819},
	{"KLICKA", 6, 198820},
	{"ARMEE", 5, 198821},
	{"WESTED", 6, 198822},
	{"AUTOTRADER", 10, 198823},
	{"ILWACO", 6, 198824},
	{"EPOSTCARDS", 10, 198825},
	{"CHUYEN", 6, 198826},
	{"WINNE", 5, 198827},
	{"REKORD", 6, 198828},
	{"WROD", 4, 198829},
	{"LANGSAM", 7, 198830},
	{"TOUTEFOIS", 9, 198831},
	{"MASTUERBATION", 13, 198832},
	{"JOUET", 5, 198833},
	{"NIKKA", 5, 198834},
	{"DAMPENS", 7, 198835},
	{"CARICATURIST", 12, 198836},
	{"SANITA", 6, 198837},
	{"PLEMENTATION", 12, 198838},
	{"BELNET", 6, 198839},
	{"VIVISECT", 8, 198840},
	{"BOOTHROYD", 9, 198841},
	{"MANPATH", 7, 198842},
	{"BATTLEZONE", 10, 198843},
	{"HAWKINSVILLE", 12, 198844},
	{"REVITALISED", 11, 198845},
	{"BUSTOS", 6, 198846},
	{"ILARIA", 6, 198847},
	{"ECUTIONERS", 10, 198848},
	{"CLOCHE", 6, 198849},
	{"SHARDA", 6, 198850},
	{"BASTIN", 6, 198851},
	{"SCHOR", 5, 198852},
	{"CALVE", 5, 198853},
	{"MADIBA", 6, 198854},
	{"PIETERSBURG", 11, 198855},
	{"ZIWE", 4, 198856},
	{"XERB", 4, 198857},
	{"UONY", 4, 198858},
	{"THCM", 4, 198859},
	{"TEXB", 4, 198860},
	{"STYV", 4, 198861},
	{"RPPI", 4, 198862},
	{"ROOW", 4, 198863},
	{"QBJA", 4, 198864},
	{"PEHU", 4, 198865},
	{"OUMS", 4, 198866},
	{"ONRC", 4, 198867},
	{"OIFF", 4, 198868},
	{"NDJH", 4, 198869},
	{"MKOL", 4, 198870},
	{"MCEM", 4, 198871},
	{"LLCN", 4, 198872},
	{"LELV", 4, 198873},
	{"LEBW", 4, 198874},
	{"LDHY", 4, 198875},
	{"LAUZ", 4, 198876},
	{"IXEM", 4, 198877},
	{"IWID", 4, 198878},
	{"HTPM", 4, 198879},
	{"GGIM", 4, 198880},
	{"FYEX", 4, 198881},
	{"FVAI", 4, 198882},
	{"FUPW", 4, 198883},
	{"FHEU", 4, 198884},
	{"EPHV", 4, 198885},
	{"EAGY", 4, 198886},
	{"EAGP", 4, 198887},
	{"DBUO", 4, 198888},
	{"AXYF", 4, 198889},
	{"AROZ", 4, 198890},
	{"NEATEST", 7, 198891},
	{"ARBEITSGEMEINSCHAFT", 19, 198892},
	{"TANGLAO", 7, 198893},
	{"WOXTER", 6, 198894},
	{"OFFICALLY", 9, 198895},
	{"QUADRUPOLES", 11, 198896},
	{"TREBOR", 6, 198897},
	{"DATALIFEPLUS", 12, 198898},
	{"ANDIJAN", 7, 198899},
	{"KNEPPER", 7, 198900},
	{"INFOPRO", 7, 198901},
	{"BLOOMERY", 8, 198902},
	{"MCMEDIA", 7, 198903},
	{"MAPGUIDE", 8, 198904},
	{"ZORYNADREAMS", 12, 198905},
	{"HANDBILL", 8, 198906},
	{"CAPITALONE", 10, 198907},
	{"DOCUSATE", 8, 198908},
	{"DRIZZLY", 7, 198909},
	{"BRUHN", 5, 198910},
	{"MARNER", 6, 198911},
	{"RWB", 3, 198912},
	{"PAGAL", 5, 198913},
	{"GRITO", 5, 198914},
	{"MULTIOBJECTIVE", 14, 198915},
	{"DATAVIEW", 8, 198916},
	{"LINKMORE", 8, 198917},
	{"HOWITZERS", 9, 198918},
	{"UNPOLLUTED", 10, 198919},
	{"CORTON", 6, 198920},
	{"CARDIOVERTER", 12, 198921},
	{"ANGOSTURA", 9, 198922},
	{"DIGITALCAMERA", 13, 198923},
	{"COMPATIBILE", 11, 198924},
	{"PETERBORO", 9, 198925},
	{"CHEVERLY", 8, 198926},
	{"MENANDER", 8, 198927},
	{"MANTELPIECE", 11, 198928},
	{"CASTIGATED", 10, 198929},
	{"PROCLIVITIES", 12, 198930},
	{"CLEANDIR", 8, 198931},
	{"SOVAGE", 6, 198932},
	{"PYMT", 4, 198933},
	{"MICROFABRICATION", 16, 198934},
	{"ANTIONLINE", 10, 198935},
	{"BUILTWITHNOF", 12, 198936},
	{"BOCCHERINI", 10, 198937},
	{"BLACS", 5, 198938},
	{"XMPUZZLES", 9, 198939},
	{"TERADA", 6, 198940},
	{"RACHE", 5, 198941},
	{"SATCHELL", 8, 198942},
	{"KINGUSSIE", 9, 198943},
	{"INCDIR", 6, 198944},
	{"WAVELAB", 7, 198945},
	{"SMARTBID", 8, 198946},
	{"ROOPIE", 6, 198947},
	{"MULTOCIDA", 9, 198948},
	{"KITZEL", 6, 198949},
	{"ALLINGHAM", 9, 198950},
	{"MYGRID", 6, 198951},
	{"MAGER", 5, 198952},
	{"KRISIUN", 7, 198953},
	{"LEONEL", 6, 198954},
	{"CALIX", 5, 198955},
	{"GANIZATION", 10, 198956},
	{"PRODUCTIMAGES", 13, 198957},
	{"CUTEY", 5, 198958},
	{"MUDRAS", 6, 198959},
	{"ALBORDA", 7, 198960},
	{"STEPANEK", 8, 198961},
	{"QUIZNO", 6, 198962},
	{"LIHTC", 5, 198963},
	{"HORNBURG", 8, 198964},
	{"FLIPFLOP", 8, 198965},
	{"SALIS", 5, 198966},
	{"FALKENBERG", 10, 198967},
	{"DREADNAUGHT", 11, 198968},
	{"TXMT", 4, 198969},
	{"BIOACTIVITY", 11, 198970},
	{"NONSYNON", 8, 198971},
	{"LENK", 4, 198972},
	{"RACONTEUR", 9, 198973},
	{"MINERSVILLE", 11, 198974},
	{"IMITATOR", 8, 198975},
	{"SENCOR", 6, 198976},
	{"CONCRETING", 10, 198977},
	{"NUMBERPLATES", 12, 198978},
	{"BROOKINS", 8, 198979},
	{"BLOUIN", 6, 198980},
	{"ROCKNROLL", 9, 198981},
	{"DEPUY", 5, 198982},
	{"CAMPUSNET", 9, 198983},
	{"BOUTILIER", 9, 198984},
	{"BUNDESAMT", 9, 198985},
	{"WEEKI", 5, 198986},
	{"BENTINCK", 8, 198987},
	{"DENTSPLY", 8, 198988},
	{"CHUPACABRA", 10, 198989},
	{"STEGOSAURUS", 11, 198990},
	{"AGONISING", 9, 198991},
	{"COMMONSTORE", 11, 198992},
	{"MAXIMILIEN", 10, 198993},
	{"TUER", 4, 198994},
	{"GARSTON", 7, 198995},
	{"RETTIG", 6, 198996},
	{"VLAAMSE", 7, 198997},
	{"MEERSCHAUM", 10, 198998},
	{"KIRU", 4, 198999},
	{"GWD", 3, 199000},
	{"PRAVA", 5, 199001},
	{"DANGLY", 6, 199002},
	{"OREB", 4, 199003},
	{"EDELL", 5, 199004},
	{"CHOLA", 5, 199005},
	{"TEKGERGEDAN", 11, 199006},
	{"SONLIGHT", 8, 199007},
	{"CARTOUCHES", 10, 199008},
	{"MANNERING", 9, 199009},
	{"COMELEC", 7, 199010},
	{"FLOODGATE", 9, 199011},
	{"HEADWORDS", 9, 199012},
	{"DECRETO", 7, 199013},
	{"KOROR", 5, 199014},
	{"SHAPPICDISC", 11, 199015},
	{"PTRA", 4, 199016},
	{"EXTRAPYRAMIDAL", 14, 199017},
	{"ZAUS", 4, 199018},
	{"YORQ", 4, 199019},
	{"YIGA", 4, 199020},
	{"YDNS", 4, 199021},
	{"VVYT", 4, 199022},
	{"VEYK", 4, 199023},
	{"UZIO", 4, 199024},
	{"UTAZ", 4, 199025},
	{"UGKI", 4, 199026},
	{"TRUO", 4, 199027},
	{"SUYO", 4, 199028},
	{"SMBI", 4, 199029},
	{"SFAW", 4, 199030},
	{"SDWH", 4, 199031},
	{"RZAB", 4, 199032},
	{"RTZP", 4, 199033},
	{"RGKA", 4, 199034},
	{"REFC", 4, 199035},
	{"PITK", 4, 199036},
	{"PILW", 4, 199037},
	{"OVGR", 4, 199038},
	{"ONUB", 4, 199039},
	{"OKIB", 4, 199040},
	{"OAPM", 4, 199041},
	{"NKGL", 4, 199042},
	{"MSIV", 4, 199043},
	{"MMOA", 4, 199044},
	{"MFTO", 4, 199045},
	{"LMOY", 4, 199046},
	{"LJAW", 4, 199047},
	{"LBMA", 4, 199048},
	{"KSIV", 4, 199049},
	{"HMMI", 4, 199050},
	{"HDRM", 4, 199051},
	{"GNSY", 4, 199052},
	{"GAPG", 4, 199053},
	{"ECEJ", 4, 199054},
	{"DFWA", 4, 199055},
	{"BOSD", 4, 199056},
	{"BBIB", 4, 199057},
	{"AWLU", 4, 199058},
	{"AERD", 4, 199059},
	{"AIRNET", 6, 199060},
	{"RENMIN", 6, 199061},
	{"MAYORGA", 7, 199062},
	{"SKYWEST", 7, 199063},
	{"OBLONGATA", 9, 199064},
	{"KJELDAHL", 8, 199065},
	{"CULLS", 5, 199066},
	{"PACC", 4, 199067},
	{"READOPTED", 9, 199068},
	{"QUIEREN", 7, 199069},
	{"IHERB", 5, 199070},
	{"SPECIOSA", 8, 199071},
	{"TALLAHATCHIE", 12, 199072},
	{"SISTINA", 7, 199073},
	{"TRIGRAM", 7, 199074},
	{"SOAPACTION", 10, 199075},
	{"FERRIN", 6, 199076},
	{"RIPOFFS", 7, 199077},
	{"MIRKWOOD", 8, 199078},
	{"ULTIMATEBET", 11, 199079},
	{"ARRESTEE", 8, 199080},
	{"ENCONTRADO", 10, 199081},
	{"HAUSBESUCHE", 11, 199082},
	{"TUBEROSUM", 9, 199083},
	{"CHEMICON", 8, 199084},
	{"LIENHOLDER", 10, 199085},
	{"BACHRACH", 8, 199086},
	{"USGBC", 5, 199087},
	{"SAFETEA", 7, 199088},
	{"AEREA", 5, 199089},
	{"ASIATINNEN", 10, 199090},
	{"PECT", 4, 199091},
	{"IMPIETY", 7, 199092},
	{"CHADSTONE", 9, 199093},
	{"INITIALIZATIONS", 15, 199094},
	{"HINDQUARTERS", 12, 199095},
	{"EDLER", 5, 199096},
	{"DUSA", 4, 199097},
	{"GLUTES", 6, 199098},
	{"EARTHCAM", 8, 199099},
	{"DUWOP", 5, 199100},
	{"QUICKSTUDY", 10, 199101},
	{"ADAMSKI", 7, 199102},
	{"PORTTYPE", 8, 199103},
	{"MENTHE", 6, 199104},
	{"LAFRENTZ", 8, 199105},
	{"MAMS", 4, 199106},
	{"NEWBOOKS", 8, 199107},
	{"WEBERN", 6, 199108},
	{"RESEED", 6, 199109},
	{"KADIR", 5, 199110},
	{"NICKSERV", 8, 199111},
	{"FASTCALL", 8, 199112},
	{"LOITER", 6, 199113},
	{"ACTUELLE", 8, 199114},
	{"ALINK", 5, 199115},
	{"MXPS", 4, 199116},
	{"TTAGETATTRIBUTE", 15, 199117},
	{"SCHWER", 6, 199118},
	{"CAESIUM", 7, 199119},
	{"REQUISITIONED", 13, 199120},
	{"BEGOT", 5, 199121},
	{"CORDEIRO", 8, 199122},
	{"ALTINKUM", 8, 199123},
	{"PAWSOX", 6, 199124},
	{"EFQM", 4, 199125},
	{"VUELVE", 6, 199126},
	{"SUDDENNESS", 10, 199127},
	{"KARPATHOS", 9, 199128},
	{"EMILYEVE", 8, 199129},
	{"BANEFUL", 7, 199130},
	{"COAR", 4, 199131},
	{"CARRIERSQUOT", 12, 199132},
	{"QUOTFLAG", 8, 199133},
	{"CURWOOD", 7, 199134},
	{"ATTATCHED", 9, 199135},
	{"ASSUALT", 7, 199136},
	{"SUPES", 5, 199137},
	{"TEMPLO", 6, 199138},
	{"LAYA", 4, 199139},
	{"MCPEAK", 6, 199140},
	{"LAYE", 4, 199141},
	{"IFFALSE", 7, 199142},
	{"SHABLA", 6, 199143},
	{"MORILLO", 7, 199144},
	{"HPCB", 4, 199145},
	{"SUPPURATIVE", 11, 199146},
	{"MAXDEV", 6, 199147},
	{"WENDEN", 6, 199148},
	{"NAWAB", 5, 199149},
	{"DISSAPEAR", 9, 199150},
	{"ALLEGIANT", 9, 199151},
	{"MISTERZERO", 10, 199152},
	{"LETTE", 5, 199153},
	{"TANJORE", 7, 199154},
	{"TWIRLED", 7, 199155},
	{"BURGHARDT", 9, 199156},
	{"GALLRIES", 8, 199157},
	{"SINOVIA", 7, 199158},
	{"SAMM", 4, 199159},
	{"BUTENE", 6, 199160},
	{"RETROVIR", 8, 199161},
	{"HEANOR", 6, 199162},
	{"DWPC", 4, 199163},
	{"DREAMZ", 6, 199164},
	{"YAGA", 4, 199165},
	{"VELOMOBILE", 10, 199166},
	{"TRAVELINE", 9, 199167},
	{"FOLDOVER", 8, 199168},
	{"SAFEHOUSE", 9, 199169},
	{"PIXIS", 5, 199170},
	{"DIAVOLO", 7, 199171},
	{"MOGOLLON", 8, 199172},
	{"KOBEC", 5, 199173},
	{"YPUE", 4, 199174},
	{"YNGU", 4, 199175},
	{"YEAD", 4, 199176},
	{"YDAG", 4, 199177},
	{"XJUD", 4, 199178},
	{"XHEW", 4, 199179},
	{"XFUT", 4, 199180},
	{"VTOB", 4, 199181},
	{"UYFA", 4, 199182},
	{"USBM", 4, 199183},
	{"URZI", 4, 199184},
	{"UGCR", 4, 199185},
	{"UBDA", 4, 199186},
	{"UAYE", 4, 199187},
	{"TKWA", 4, 199188},
	{"THQB", 4, 199189},
	{"RUKT", 4, 199190},
	{"RIVS", 4, 199191},
	{"RIBH", 4, 199192},
	{"OMKL", 4, 199193},
	{"OEMD", 4, 199194},
	{"NDRV", 4, 199195},
	{"JHER", 4, 199196},
	{"JARB", 4, 199197},
	{"GNSG", 4, 199198},
	{"FIGM", 4, 199199},
	{"EZUS", 4, 199200},
	{"EYUT", 4, 199201},
	{"EKYI", 4, 199202},
	{"EKGI", 4, 199203},
	{"EIBF", 4, 199204},
	{"ECKK", 4, 199205},
	{"DYGL", 4, 199206},
	{"DRUA", 4, 199207},
	{"DLYQ", 4, 199208},
	{"CODC", 4, 199209},
	{"BIPH", 4, 199210},
	{"AAPU", 4, 199211},
	{"ANJAN", 5, 199212},
	{"POWR", 4, 199213},
	{"HOTCHKIS", 8, 199214},
	{"SPANIER", 7, 199215},
	{"FURTIVELY", 9, 199216},
	{"VERITON", 7, 199217},
	{"TIMEKEEPERS", 11, 199218},
	{"RUBRIQUES", 9, 199219},
	{"OKANO", 5, 199220},
	{"MSNMESSENGER", 12, 199221},
	{"LIBERALISE", 10, 199222},
	{"BETRAYER", 8, 199223},
	{"KEMPNER", 7, 199224},
	{"AKVIS", 5, 199225},
	{"TERRARIUMS", 10, 199226},
	{"HAKATA", 6, 199227},
	{"DYNDNS", 6, 199228},
	{"CALIPHS", 7, 199229},
	{"OOMOO", 5, 199230},
	{"MAYD", 4, 199231},
	{"LOVEBIRD", 8, 199232},
	{"BROOKING", 8, 199233},
	{"AIRPATH", 7, 199234},
	{"INCOPY", 6, 199235},
	{"EMYLOU", 6, 199236},
	{"SESHADRI", 8, 199237},
	{"GAEM", 4, 199238},
	{"SURREALISTS", 11, 199239},
	{"SEQUAL", 6, 199240},
	{"KHAIR", 5, 199241},
	{"DEMOGRAPHERS", 12, 199242},
	{"GLOBIANS", 8, 199243},
	{"RAYVILLE", 8, 199244},
	{"HIWAY", 5, 199245},
	{"TIPTOES", 7, 199246},
	{"MOOGLE", 6, 199247},
	{"DISPL", 5, 199248},
	{"CYCAD", 5, 199249},
	{"CENTROSOME", 10, 199250},
	{"PALINDROMIC", 11, 199251},
	{"MANABU", 6, 199252},
	{"CLEARBROOK", 10, 199253},
	{"ALICUBLOG", 9, 199254},
	{"VAZIRANI", 8, 199255},
	{"UMAGA", 5, 199256},
	{"TREKKIES", 8, 199257},
	{"CVSLOGS", 7, 199258},
	{"VEITH", 5, 199259},
	{"AZCENTRAL", 9, 199260},
	{"XMCD", 4, 199261},
	{"PHILLIPPINES", 12, 199262},
	{"HAMLISCH", 8, 199263},
	{"RIENNER", 7, 199264},
	{"NEUROLEPTICS", 12, 199265},
	{"SETPOINTS", 9, 199266},
	{"JINGLING", 8, 199267},
	{"GAURANTEE", 9, 199268},
	{"REGIONEN", 8, 199269},
	{"OGGETTI", 7, 199270},
	{"ENGELBART", 9, 199271},
	{"CUTOVER", 7, 199272},
	{"MERSEA", 6, 199273},
	{"ROCKFALL", 8, 199274},
	{"LIZAROSE", 8, 199275},
	{"ALEXSANDRIA", 11, 199276},
	{"NAKAO", 5, 199277},
	{"RULON", 5, 199278},
	{"WEIBLICHE", 9, 199279},
	{"MITOXANTRONE", 12, 199280},
	{"GULLAH", 6, 199281},
	{"EMEP", 4, 199282},
	{"PASTURELAND", 11, 199283},
	{"IACOBUCCI", 9, 199284},
	{"FOMENTO", 7, 199285},
	{"CANDIRIA", 8, 199286},
	{"MAPIT", 5, 199287},
	{"GUIDS", 5, 199288},
	{"VAISHALI", 8, 199289},
	{"DEFECTING", 9, 199290},
	{"CASTELNUOVO", 11, 199291},
	{"GETHASHCODE", 11, 199292},
	{"CUISINOX", 8, 199293},
	{"ARROWROOT", 9, 199294},
	{"PRECIOSA", 8, 199295},
	{"INFORMATIONRATING", 17, 199296},
	{"CELENTANO", 9, 199297},
	{"LESSP", 5, 199298},
	{"PERIOXH", 7, 199299},
	{"WELCHER", 7, 199300},
	{"TRAVELWORM", 10, 199301},
	{"RESISTENCIA", 11, 199302},
	{"MISAO", 5, 199303},
	{"DAGUERREOTYPE", 13, 199304},
	{"SIMONETTA", 9, 199305},
	{"HAWKSHEAD", 9, 199306},
	{"IGUCHI", 6, 199307},
	{"BESTWAY", 7, 199308},
	{"UGARTE", 6, 199309},
	{"YONKA", 5, 199310},
	{"WHITESVILLE", 11, 199311},
	{"KITTO", 5, 199312},
	{"DICGIONARY", 10, 199313},
	{"ARNPRIOR", 8, 199314},
	{"ALESI", 5, 199315},
	{"MTWTH", 5, 199316},
	{"NOCASE", 6, 199317},
	{"SCHUMI", 6, 199318},
	{"JUDICIAIRE", 10, 199319},
	{"DANIS", 5, 199320},
	{"SOMERVELL", 9, 199321},
	{"RAVENEL", 7, 199322},
	{"MORRISH", 7, 199323},
	{"DOREMI", 6, 199324},
	{"KSPREAD", 7, 199325},
	{"DISINTEGRATES", 13, 199326},
	{"NUCLEATED", 9, 199327},
	{"JROCK", 5, 199328},
	{"SIPES", 5, 199329},
	{"ICIP", 4, 199330},
	{"READJUSTED", 10, 199331},
	{"NUMCHAN", 7, 199332},
	{"GYDAG", 5, 199333},
	{"CISTELL", 7, 199334},
	{"UNICAMP", 7, 199335},
	{"ODDER", 5, 199336},
	{"ZINNIAS", 7, 199337},
	{"BOLDUC", 6, 199338},
	{"THUAT", 5, 199339},
	{"ASSAILS", 7, 199340},
	{"ALLEGIS", 7, 199341},
	{"UNDERAGED", 9, 199342},
	{"SCOLARI", 7, 199343},
	{"UNDERPERFORMANCE", 16, 199344},
	{"ZYSH", 4, 199345},
	{"ZINB", 4, 199346},
	{"YJRS", 4, 199347},
	{"XACR", 4, 199348},
	{"WWLI", 4, 199349},
	{"WWFC", 4, 199350},
	{"WOBV", 4, 199351},
	{"VPIS", 4, 199352},
	{"VAKR", 4, 199353},
	{"TYAJ", 4, 199354},
	{"TBPA", 4, 199355},
	{"RMPP", 4, 199356},
	{"RGMU", 4, 199357},
	{"RBFR", 4, 199358},
	{"QAFT", 4, 199359},
	{"PSWR", 4, 199360},
	{"PPUM", 4, 199361},
	{"PDHA", 4, 199362},
	{"OWYN", 4, 199363},
	{"OVTW", 4, 199364},
	{"ORYZ", 4, 199365},
	{"OLOJ", 4, 199366},
	{"OIRV", 4, 199367},
	{"OGOJ", 4, 199368},
	{"OFVS", 4, 199369},
	{"NTPP", 4, 199370},
	{"MEYU", 4, 199371},
	{"LKOL", 4, 199372},
	{"LKEX", 4, 199373},
	{"LAZL", 4, 199374},
	{"KILS", 4, 199375},
	{"JARW", 4, 199376},
	{"ILIJ", 4, 199377},
	{"IEMR", 4, 199378},
	{"HUZH", 4, 199379},
	{"GGOB", 4, 199380},
	{"FPTO", 4, 199381},
	{"FLWO", 4, 199382},
	{"FKRY", 4, 199383},
	{"ERWC", 4, 199384},
	{"ELML", 4, 199385},
	{"DOSY", 4, 199386},
	{"DLTC", 4, 199387},
	{"DEMF", 4, 199388},
	{"CAJE", 4, 199389},
	{"BTHU", 4, 199390},
	{"RUCKA", 5, 199391},
	{"HALLINAN", 8, 199392},
	{"PRIESTESSES", 11, 199393},
	{"ALUKH", 5, 199394},
	{"VACCA", 5, 199395},
	{"JBR", 3, 199396},
	{"BUTTA", 5, 199397},
	{"TORBOLE", 7, 199398},
	{"ALPBACH", 7, 199399},
	{"JOSTLE", 6, 199400},
	{"CAMBON", 6, 199401},
	{"AFLATOXINS", 10, 199402},
	{"SUBBASE", 7, 199403},
	{"LORELLE", 7, 199404},
	{"HYGROMETERS", 11, 199405},
	{"GRLS", 4, 199406},
	{"GERMANN", 7, 199407},
	{"ARREARAGES", 10, 199408},
	{"TIMEBASE", 8, 199409},
	{"NEILLSVILLE", 11, 199410},
	{"FOUQUET", 7, 199411},
	{"DENSIFICATION", 13, 199412},
	{"INSOMNIACS", 10, 199413},
	{"FISHWATCHERS", 12, 199414},
	{"CANCERBACUP", 11, 199415},
	{"NOSTOC", 6, 199416},
	{"MOBILTELEFON", 12, 199417},
	{"MISOGYNISTIC", 12, 199418},
	{"ETERNO", 6, 199419},
	{"THERMOMETRY", 11, 199420},
	{"HEDIN", 5, 199421},
	{"CIVILI", 6, 199422},
	{"LEGUMINOSAE", 11, 199423},
	{"ANGIELSKI", 9, 199424},
	{"VALIER", 6, 199425},
	{"RUAHA", 5, 199426},
	{"FRIEDKIN", 8, 199427},
	{"FELODIPINE", 10, 199428},
	{"LONGWALL", 8, 199429},
	{"FFWD", 4, 199430},
	{"WGM", 3, 199431},
	{"RLV", 3, 199432},
	{"COOLFER", 7, 199433},
	{"LEGGO", 5, 199434},
	{"REBUY", 5, 199435},
	{"MINICOMPUTER", 12, 199436},
	{"ADMONISHING", 11, 199437},
	{"CONVENIO", 8, 199438},
	{"CHICKERING", 10, 199439},
	{"AMERIAN", 7, 199440},
	{"TAMILNET", 8, 199441},
	{"ITCHEN", 6, 199442},
	{"HYPOTHESISED", 12, 199443},
	{"DERBI", 5, 199444},
	{"AVOCATIONS", 10, 199445},
	{"ARKAY", 5, 199446},
	{"YEPPOON", 7, 199447},
	{"QUANDT", 6, 199448},
	{"VISHWA", 6, 199449},
	{"ALLONS", 6, 199450},
	{"THISFISHFORUM", 13, 199451},
	{"SPREWELL", 8, 199452},
	{"CUYLER", 6, 199453},
	{"STARSUITE", 9, 199454},
	{"RECANTED", 8, 199455},
	{"MAZZI", 5, 199456},
	{"BOCHNER", 7, 199457},
	{"NICOLLETTE", 10, 199458},
	{"ZHANGJIAGANG", 12, 199459},
	{"HUMPH", 5, 199460},
	{"SPLENOMEGALY", 12, 199461},
	{"TREFFS", 6, 199462},
	{"INTERNETT", 9, 199463},
	{"GARCES", 6, 199464},
	{"WRIA", 4, 199465},
	{"TABORT", 6, 199466},
	{"AMPRENAVIR", 10, 199467},
	{"TINGGI", 6, 199468},
	{"SPROULE", 7, 199469},
	{"BUITENLAND", 10, 199470},
	{"MATERNALLY", 10, 199471},
	{"FORELIMB", 8, 199472},
	{"BANDOLIER", 9, 199473},
	{"PARKINSONIAN", 12, 199474},
	{"NICOLELEE", 9, 199475},
	{"KYW", 3, 199476},
	{"POTTIES", 7, 199477},
	{"FLAVOURINGS", 11, 199478},
	{"PFK", 3, 199479},
	{"HUMBLEST", 8, 199480},
	{"TROPICALE", 9, 199481},
	{"CANDYLAC", 8, 199482},
	{"GAGETOWN", 8, 199483},
	{"EXPWY", 5, 199484},
	{"CHADDERTON", 10, 199485},
	{"ALIREZA", 7, 199486},
	{"GROSSBRITANNIEN", 15, 199487},
	{"VSEARCH", 7, 199488},
	{"SEMISIMPLE", 10, 199489},
	{"PRIVATNUTTE", 11, 199490},
	{"SBARRO", 6, 199491},
	{"GWEITHGAREDDAU", 14, 199492},
	{"FATWAS", 6, 199493},
	{"PETERTHOENYTOPIC", 16, 199494},
	{"RADIOPHARMACEUTICAL", 19, 199495},
	{"COMPETA", 7, 199496},
	{"TEDDIBARRETT", 12, 199497},
	{"DONER", 5, 199498},
	{"VICTORIO", 8, 199499},
	{"TOPOFF", 6, 199500},
	{"IRVS", 4, 199501},
	{"HOMEWHAT", 8, 199502},
	{"DIDTIONARY", 10, 199503},
	{"BACKROAD", 8, 199504},
	{"SCREENHEAD", 10, 199505},
	{"KTRUE", 5, 199506},
	{"DIBOLL", 6, 199507},
	{"CHEETOS", 7, 199508},
	{"MODULARIZED", 11, 199509},
	{"NOMICS", 6, 199510},
	{"DEALLOCATED", 11, 199511},
	{"CLEARWISDOM", 11, 199512},
	{"ANNUA", 5, 199513},
	{"STAGGERINGLY", 12, 199514},
	{"POBJECT", 7, 199515},
	{"CAMOGIE", 7, 199516},
	{"GRNET", 5, 199517},
	{"TUFNELL", 7, 199518},
	{"LAPUTA", 6, 199519},
	{"NOWAIT", 6, 199520},
	{"CATWALKS", 8, 199521},
	{"UNESCAP", 7, 199522},
	{"SCHMO", 5, 199523},
	{"ZZUR", 4, 199524},
	{"YMSC", 4, 199525},
	{"YIFD", 4, 199526},
	{"WIMR", 4, 199527},
	{"VDAT", 4, 199528},
	{"UXPR", 4, 199529},
	{"UGBR", 4, 199530},
	{"UASY", 4, 199531},
	{"RCDR", 4, 199532},
	{"OLMX", 4, 199533},
	{"MPNA", 4, 199534},
	{"MJUR", 4, 199535},
	{"LYUC", 4, 199536},
	{"LYIJ", 4, 199537},
	{"LUPM", 4, 199538},
	{"LKDR", 4, 199539},
	{"KYOL", 4, 199540},
	{"KASZ", 4, 199541},
	{"JOBV", 4, 199542},
	{"JDPO", 4, 199543},
	{"JABH", 4, 199544},
	{"HYEC", 4, 199545},
	{"HWAM", 4, 199546},
	{"GYIF", 4, 199547},
	{"GAEC", 4, 199548},
	{"FSVE", 4, 199549},
	{"FNOG", 4, 199550},
	{"FKAH", 4, 199551},
	{"ETCG", 4, 199552},
	{"EJRS", 4, 199553},
	{"ECPE", 4, 199554},
	{"DSWU", 4, 199555},
	{"DMUK", 4, 199556},
	{"CYUP", 4, 199557},
	{"BCFE", 4, 199558},
	{"APQU", 4, 199559},
	{"ALNC", 4, 199560},
	{"SARBOX", 6, 199561},
	{"CALOGERO", 8, 199562},
	{"KROPOTKIN", 9, 199563},
	{"CORABELLE", 9, 199564},
	{"STELLABLUE", 10, 199565},
	{"SOMITE", 6, 199566},
	{"RIEMER", 6, 199567},
	{"WOLLMAN", 7, 199568},
	{"WATSEKA", 7, 199569},
	{"EVADERS", 7, 199570},
	{"CUNDIFF", 7, 199571},
	{"ANSCHLUSS", 9, 199572},
	{"UPDOWN", 6, 199573},
	{"NORTHLANDS", 10, 199574},
	{"CEDENO", 6, 199575},
	{"XPOSURE", 7, 199576},
	{"FANMAIL", 7, 199577},
	{"AMIELLE", 7, 199578},
	{"DESECRATE", 9, 199579},
	{"DYNAMIN", 7, 199580},
	{"CAEDS", 5, 199581},
	{"PHOTIS", 6, 199582},
	{"THYROIDECTOMY", 13, 199583},
	{"AVESTA", 6, 199584},
	{"ADAAG", 5, 199585},
	{"WILDERNET", 9, 199586},
	{"VRATSA", 6, 199587},
	{"ONEHUNGA", 8, 199588},
	{"WRONGDOER", 9, 199589},
	{"USSSA", 5, 199590},
	{"TSWANA", 6, 199591},
	{"FANGORIA", 8, 199592},
	{"TUXPAINT", 8, 199593},
	{"MICROCOM", 8, 199594},
	{"CLOTHEDD", 8, 199595},
	{"SHEALY", 6, 199596},
	{"AEREO", 5, 199597},
	{"SMAD", 4, 199598},
	{"WEINGARTNER", 11, 199599},
	{"RANDOMIZING", 11, 199600},
	{"CARELINE", 8, 199601},
	{"HYDROUS", 7, 199602},
	{"FRITTER", 7, 199603},
	{"JNLP", 4, 199604},
	{"ILMENITE", 8, 199605},
	{"GIANNETTI", 9, 199606},
	{"GPCRS", 5, 199607},
	{"EPIVIR", 6, 199608},
	{"DADES", 5, 199609},
	{"MUSSELWHITE", 11, 199610},
	{"HAREFIELD", 9, 199611},
	{"POFF", 4, 199612},
	{"CRISTMAS", 8, 199613},
	{"AMARILLASMERCANTIL", 18, 199614},
	{"PHTHIA", 6, 199615},
	{"MYSS", 4, 199616},
	{"PLAYDATES", 9, 199617},
	{"PHENETERMINE", 12, 199618},
	{"MOHAMMEDAN", 10, 199619},
	{"LYNZY", 5, 199620},
	{"NAXIS", 5, 199621},
	{"CRIMEN", 6, 199622},
	{"BLOTCHY", 7, 199623},
	{"SURINDER", 8, 199624},
	{"FAMILLY", 7, 199625},
	{"ALTTEXT", 7, 199626},
	{"PROKOP", 6, 199627},
	{"KAEW", 4, 199628},
	{"HAMANO", 6, 199629},
	{"NORDICWARE", 10, 199630},
	{"MUGLA", 5, 199631},
	{"ZETTEL", 6, 199632},
	{"BRAU", 4, 199633},
	{"CYCLINGNEWS", 11, 199634},
	{"INTERLINGUE", 11, 199635},
	{"SEKIGUCHI", 9, 199636},
	{"PARACHAT", 8, 199637},
	{"MENEHUNE", 8, 199638},
	{"NETMANAGE", 9, 199639},
	{"MARTINBOROUGH", 13, 199640},
	{"LUDDITES", 8, 199641},
	{"SMIRKS", 6, 199642},
	{"INDUSTRIALI", 11, 199643},
	{"ALIGNACE", 8, 199644},
	{"DAYLE", 5, 199645},
	{"SOFTBOX", 7, 199646},
	{"BESSETTE", 8, 199647},
	{"PHUTURE", 7, 199648},
	{"INSOURCING", 10, 199649},
	{"AOSOTH", 6, 199650},
	{"GLENEDEN", 8, 199651},
	{"SOLITUDES", 9, 199652},
	{"ULTRAISO", 8, 199653},
	{"CELCAT", 6, 199654},
	{"VINICIUS", 8, 199655},
	{"VOGLIO", 6, 199656},
	{"FARMACIAS", 9, 199657},
	{"DISCIPLINARIAN", 14, 199658},
	{"KMB", 3, 199659},
	{"QDBM", 4, 199660},
	{"CFV", 3, 199661},
	{"HARDSIDE", 8, 199662},
	{"SOUNDFONT", 9, 199663},
	{"ZORPIA", 6, 199664},
	{"HIRSCHBERG", 10, 199665},
	{"SHAREIT", 7, 199666},
	{"ANORECTAL", 9, 199667},
	{"FLUORESCENTS", 12, 199668},
	{"CICTIONARY", 10, 199669},
	{"RAICES", 6, 199670},
	{"HALABJA", 7, 199671},
	{"HAEMODYNAMIC", 12, 199672},
	{"JDP", 3, 199673},
	{"FURNITUREONLINE", 15, 199674},
	{"DICTIOANRY", 10, 199675},
	{"BACKLOT", 7, 199676},
	{"FOGGED", 6, 199677},
	{"DONATORS", 8, 199678},
	{"ZBRY", 4, 199679},
	{"WYIE", 4, 199680},
	{"WIMD", 4, 199681},
	{"WAHC", 4, 199682},
	{"VEIK", 4, 199683},
	{"VATW", 4, 199684},
	{"UXAL", 4, 199685},
	{"UGGO", 4, 199686},
	{"TUTR", 4, 199687},
	{"TUEC", 4, 199688},
	{"TFAZ", 4, 199689},
	{"RYGG", 4, 199690},
	{"RTIJ", 4, 199691},
	{"RKOE", 4, 199692},
	{"RACW", 4, 199693},
	{"OXYR", 4, 199694},
	{"OWYC", 4, 199695},
	{"OUXT", 4, 199696},
	{"NZBE", 4, 199697},
	{"NJOW", 4, 199698},
	{"NDHC", 4, 199699},
	{"MAXN", 4, 199700},
	{"LUIM", 4, 199701},
	{"LFUM", 4, 199702},
	{"KEWS", 4, 199703},
	{"IRMK", 4, 199704},
	{"IKKH", 4, 199705},
	{"IGIU", 4, 199706},
	{"HVIV", 4, 199707},
	{"FKAD", 4, 199708},
	{"EXBI", 4, 199709},
	{"DSVS", 4, 199710},
	{"DPDF", 4, 199711},
	{"DMSH", 4, 199712},
	{"DMOP", 4, 199713},
	{"DIDQ", 4, 199714},
	{"DDJS", 4, 199715},
	{"CEKL", 4, 199716},
	{"AMJI", 4, 199717},
	{"BOOTHBY", 7, 199718},
	{"MOSSLEY", 7, 199719},
	{"CMAT", 4, 199720},
	{"KIRBYVILLE", 10, 199721},
	{"HONAKER", 7, 199722},
	{"RADIANCES", 9, 199723},
	{"INSURRECTIONS", 13, 199724},
	{"BACKCOUNTRYBLOG", 15, 199725},
	{"ANTIOCHIAN", 10, 199726},
	{"STREETSCAPES", 12, 199727},
	{"PARTENARIAT", 11, 199728},
	{"BILLIEJOE", 9, 199729},
	{"OPENWINDOWS", 11, 199730},
	{"PRONOMINAL", 10, 199731},
	{"FELTMAN", 7, 199732},
	{"CHUKAR", 6, 199733},
	{"SHARECAST", 9, 199734},
	{"DYNATRON", 8, 199735},
	{"SOLUNET", 7, 199736},
	{"BROMWELL", 8, 199737},
	{"LODGERS", 7, 199738},
	{"LIFEHACKS", 9, 199739},
	{"KUNNA", 5, 199740},
	{"CHIAKI", 6, 199741},
	{"PERRANPORTH", 11, 199742},
	{"HUMANIZING", 10, 199743},
	{"STENOGRAPHERS", 13, 199744},
	{"CHAIKEN", 7, 199745},
	{"RADIOMETERS", 11, 199746},
	{"BEJA", 4, 199747},
	{"WILMAR", 6, 199748},
	{"FACEPARTY", 9, 199749},
	{"REINVESTING", 11, 199750},
	{"KLINEFELTER", 11, 199751},
	{"CACIQUE", 7, 199752},
	{"EXALTS", 6, 199753},
	{"ANIMATRONIC", 11, 199754},
	{"WESTRAY", 7, 199755},
	{"FBU", 3, 199756},
	{"STICKYMOAN", 10, 199757},
	{"MAXCHAN", 7, 199758},
	{"KDR", 3, 199759},
	{"GREC", 4, 199760},
	{"REAWAKENING", 11, 199761},
	{"PILLION", 7, 199762},
	{"LAVALAS", 7, 199763},
	{"TRAVESTIE", 9, 199764},
	{"RABLE", 5, 199765},
	{"CAJOLE", 6, 199766},
	{"SURING", 6, 199767},
	{"ZOIDBERG", 8, 199768},
	{"ANKIT", 5, 199769},
	{"ACCENTING", 9, 199770},
	{"QPAINTER", 8, 199771},
	{"DENIMS", 6, 199772},
	{"PALLADIAN", 9, 199773},
	{"HIMANSHU", 8, 199774},
	{"CDIA", 4, 199775},
	{"MATHEMATISCHE", 13, 199776},
	{"LASGO", 5, 199777},
	{"AKHIL", 5, 199778},
	{"PLEIOTROPIC", 11, 199779},
	{"SLNG", 4, 199780},
	{"PLANQUE", 7, 199781},
	{"OBVIATES", 8, 199782},
	{"LIFESKILLS", 10, 199783},
	{"COMPOSITED", 10, 199784},
	{"PHENANTHRENE", 12, 199785},
	{"COFINLUXE", 9, 199786},
	{"SWOONING", 8, 199787},
	{"FEROX", 5, 199788},
	{"DEBIANUTILS", 11, 199789},
	{"ANXIOLYTIC", 10, 199790},
	{"WINCING", 7, 199791},
	{"STORMWIND", 9, 199792},
	{"NURBURGRING", 11, 199793},
	{"DUETIE", 6, 199794},
	{"SAUVEUR", 7, 199795},
	{"PYRETHROID", 10, 199796},
	{"LEGALMATCH", 10, 199797},
	{"COORDINA", 8, 199798},
	{"AIREY", 5, 199799},
	{"HERALDNET", 9, 199800},
	{"SHORTHOPPERS", 12, 199801},
	{"EROTIKFORUM", 11, 199802},
	{"UNSWERVING", 10, 199803},
	{"RETARY", 6, 199804},
	{"BLIT", 4, 199805},
	{"FARMGIRL", 8, 199806},
	{"CLEEVE", 6, 199807},
	{"TRILINOS", 8, 199808},
	{"TAWHID", 6, 199809},
	{"KEPPRA", 6, 199810},
	{"HYDROXYBUTYRATE", 15, 199811},
	{"CONMAN", 6, 199812},
	{"SEALEVEL", 8, 199813},
	{"CMSG", 4, 199814},
	{"BASAYEV", 7, 199815},
	{"PSCS", 4, 199816},
	{"CINEFILE", 8, 199817},
	{"TIEMANN", 7, 199818},
	{"GEBHARD", 7, 199819},
	{"COOLY", 5, 199820},
	{"GETDLGITEM", 10, 199821},
	{"THERETOFORE", 11, 199822},
	{"NEXTHOP", 7, 199823},
	{"MCCULLERS", 9, 199824},
	{"CATDS", 5, 199825},
	{"LOVECH", 6, 199826},
	{"ESSAR", 5, 199827},
	{"FLANNIGAN", 9, 199828},
	{"GYRASE", 6, 199829},
	{"ENJOYMENTS", 10, 199830},
	{"LEEZA", 5, 199831},
	{"TWEEDSMUIR", 10, 199832},
	{"RESERVIERUNG", 12, 199833},
	{"SALEN", 5, 199834},
	{"ZORO", 4, 199835},
	{"TRANSGENDERS", 12, 199836},
	{"BLONDYNKA", 9, 199837},
	{"THIRSTING", 9, 199838},
	{"WINPATROL", 9, 199839},
	{"COSMOPOLIS", 10, 199840},
	{"LUCCHESI", 8, 199841},
	{"CONGR", 5, 199842},
	{"ZLIK", 4, 199843},
	{"YYOG", 4, 199844},
	{"YMOE", 4, 199845},
	{"YIVI", 4, 199846},
	{"YAGY", 4, 199847},
	{"WOLT", 4, 199848},
	{"WKIC", 4, 199849},
	{"VYGO", 4, 199850},
	{"THWW", 4, 199851},
	{"SGSW", 4, 199852},
	{"RLMU", 4, 199853},
	{"RCBO", 4, 199854},
	{"PKEV", 4, 199855},
	{"PHDU", 4, 199856},
	{"OGNU", 4, 199857},
	{"NDBD", 4, 199858},
	{"MAAU", 4, 199859},
	{"LYUM", 4, 199860},
	{"KMCO", 4, 199861},
	{"HKEK", 4, 199862},
	{"GYMR", 4, 199863},
	{"FCPO", 4, 199864},
	{"EVFA", 4, 199865},
	{"DSCY", 4, 199866},
	{"DPPR", 4, 199867},
	{"DCYM", 4, 199868},
	{"DBAV", 4, 199869},
	{"CEYR", 4, 199870},
	{"AUTD", 4, 199871},
	{"ARFB", 4, 199872},
	{"GLENTANA", 8, 199873},
	{"WOLBACHIA", 9, 199874},
	{"SHIELS", 6, 199875},
	{"LIXY", 4, 199876},
	{"AVISOS", 6, 199877},
	{"BCGEU", 5, 199878},
	{"TRYGVE", 6, 199879},
	{"TERENA", 6, 199880},
	{"KILLALOE", 8, 199881},
	{"HOFSTETTER", 10, 199882},
	{"EVERYDAYSOURCE", 14, 199883},
	{"STRAIGHTEDGE", 12, 199884},
	{"SKULD", 5, 199885},
	{"KARELIAN", 8, 199886},
	{"TINMAN", 6, 199887},
	{"HFIL", 4, 199888},
	{"ROKENBOK", 8, 199889},
	{"KAWEAH", 6, 199890},
	{"FRANKTOWN", 9, 199891},
	{"UZBEKS", 6, 199892},
	{"NEYRISSA", 8, 199893},
	{"DENNIE", 6, 199894},
	{"VOLAPUK", 7, 199895},
	{"LEMIRE", 6, 199896},
	{"COOPERSVILLE", 12, 199897},
	{"BOOKRAGS", 8, 199898},
	{"ANGERING", 8, 199899},
	{"JENNROSE", 8, 199900},
	{"NAMIKITERU", 10, 199901},
	{"FRESHCLAM", 9, 199902},
	{"ABSENSE", 7, 199903},
	{"SELLOTAPE", 9, 199904},
	{"SAVANTS", 7, 199905},
	{"IONOMER", 7, 199906},
	{"TETSU", 5, 199907},
	{"TECNICAS", 8, 199908},
	{"CANBET", 6, 199909},
	{"SHNEIDERMAN", 11, 199910},
	{"ITNEWS", 6, 199911},
	{"FLOC", 4, 199912},
	{"BIZERK", 6, 199913},
	{"REENACTMENTS", 12, 199914},
	{"NITROFURANTOIN", 14, 199915},
	{"KENTUCKIANS", 11, 199916},
	{"INDEPEND", 8, 199917},
	{"TEREZA", 6, 199918},
	{"KEYRA", 5, 199919},
	{"STEEDMAN", 8, 199920},
	{"IENTRY", 6, 199921},
	{"EXPERTIZED", 10, 199922},
	{"SOULED", 6, 199923},
	{"PARTIJ", 6, 199924},
	{"MVNFORUM", 8, 199925},
	{"MAXPAYNE", 8, 199926},
	{"LANDHAUS", 8, 199927},
	{"STATCVS", 7, 199928},
	{"LOVEHAMMERS", 11, 199929},
	{"ZILLER", 6, 199930},
	{"VOCIFEROUSLY", 12, 199931},
	{"SYSCA", 5, 199932},
	{"REMEDIA", 7, 199933},
	{"STOMATA", 7, 199934},
	{"KYUN", 4, 199935},
	{"HOMMERSON", 9, 199936},
	{"PARTENARIATS", 12, 199937},
	{"MONARCHICAL", 11, 199938},
	{"MASSAGESTUDIO", 13, 199939},
	{"TROVATORE", 9, 199940},
	{"OPTHALMIC", 9, 199941},
	{"PHRAYA", 6, 199942},
	{"TETRAPLOID", 10, 199943},
	{"CELEBES", 7, 199944},
	{"DIVANS", 6, 199945},
	{"TRADUCIR", 8, 199946},
	{"TOTALTRAVEL", 11, 199947},
	{"TELERIK", 7, 199948},
	{"GESAMTE", 7, 199949},
	{"ERELI", 5, 199950},
	{"RAVENISIS", 9, 199951},
	{"MNEYLU", 6, 199952},
	{"PHARMACEUTICALLY", 16, 199953},
	{"SHABA", 5, 199954},
	{"PERPHENAZINE", 12, 199955},
	{"LURVE", 5, 199956},
	{"CAWSTON", 7, 199957},
	{"RGR", 3, 199958},
	{"HUANGSHAN", 9, 199959},
	{"THORSONS", 8, 199960},
	{"FAUR", 4, 199961},
	{"BUCAREST", 8, 199962},
	{"POSTBOKS", 8, 199963},
	{"MEXICA", 6, 199964},
	{"ADCO", 4, 199965},
	{"IMMODEST", 8, 199966},
	{"OVIDUCT", 7, 199967},
	{"FIELDCREST", 10, 199968},
	{"ESELLS", 6, 199969},
	{"GENMA", 5, 199970},
	{"BLOODSPORT", 10, 199971},
	{"SULFONYL", 8, 199972},
	{"SECADA", 6, 199973},
	{"PERQUISITES", 11, 199974},
	{"BORDERTOWN", 10, 199975},
	{"STRAKA", 6, 199976},
	{"INVIATO", 7, 199977},
	{"XENAKIS", 7, 199978},
	{"FLATTERS", 8, 199979},
	{"CQB", 3, 199980},
	{"WEBCATALOG", 10, 199981},
	{"LAEM", 4, 199982},
	{"DAMAR", 5, 199983},
	{"BACODINE", 8, 199984},
	{"TOPAS", 5, 199985},
	{"DARKWATCH", 9, 199986},
	{"SHIPWRIGHT", 10, 199987},
	{"BIGWIGS", 7, 199988},
	{"DAGSTUHL", 8, 199989},
	{"AQUASANA", 8, 199990},
	{"ROMESH", 6, 199991},
	{"YELPED", 6, 199992},
	{"WESTWAY", 7, 199993},
	{"DDEDDF", 6, 199994},
	{"SYMPATRIC", 9, 199995},
	{"GEDICHTE", 8, 199996},
	{"COGN", 4, 199997},
	{"CABBIES", 7, 199998},
	{"NAMESAKES", 9, 199999},
	{"BANFI", 5, 200000},
	{"PRESELECTION", 12, 200001},
	{"INADMISSIBILITY", 15, 200002},
	{"FREETHINKER", 11, 200003},
	{"BLETHEN", 7, 200004},
	{"CALZETTI", 8, 200005},
	{"ATLASTEST", 9, 200006},
	{"MINU", 4, 200007},
	{"PROSOUND", 8, 200008},
	{"COMMUNIONS", 10, 200009},
	{"ZHUR", 4, 200010},
	{"YJAW", 4, 200011},
	{"VYNO", 4, 200012},
	{"VUEW", 4, 200013},
	{"VOYB", 4, 200014},
	{"UNNB", 4, 200015},
	{"UEYS", 4, 200016},
	{"TVSL", 4, 200017},
	{"TCWO", 4, 200018},
	{"RDRP", 4, 200019},
	{"RAUI", 4, 200020},
	{"PYCL", 4, 200021},
	{"PWHY", 4, 200022},
	{"OWUT", 4, 200023},
	{"OCIG", 4, 200024},
	{"NZWH", 4, 200025},
	{"NMPF", 4, 200026},
	{"NGKG", 4, 200027},
	{"NDDL", 4, 200028},
	{"MLAL", 4, 200029},
	{"MITK", 4, 200030},
	{"LSYR", 4, 200031},
	{"KQUO", 4, 200032},
	{"KHYA", 4, 200033},
	{"KARF", 4, 200034},
	{"JINF", 4, 200035},
	{"IVLE", 4, 200036},
	{"IKDI", 4, 200037},
	{"HVAM", 4, 200038},
	{"GTJO", 4, 200039},
	{"FMAE", 4, 200040},
	{"FIKI", 4, 200041},
	{"EMCT", 4, 200042},
	{"EEXM", 4, 200043},
	{"EDRK", 4, 200044},
	{"DVIJ", 4, 200045},
	{"DEVH", 4, 200046},
	{"DEMJ", 4, 200047},
	{"AZUC", 4, 200048},
	{"HERZEN", 6, 200049},
	{"COMPONENTI", 10, 200050},
	{"PHENYLBUTAZONE", 14, 200051},
	{"EBUILDS", 7, 200052},
	{"TRINKIE", 7, 200053},
	{"SOUNDFORGE", 10, 200054},
	{"PIPIENS", 7, 200055},
	{"LAODICEA", 8, 200056},
	{"DLLTOOL", 7, 200057},
	{"BEURRE", 6, 200058},
	{"WASSAIL", 7, 200059},
	{"TAONGA", 6, 200060},
	{"ASPARAGINASE", 12, 200061},
	{"TKACHUK", 7, 200062},
	{"MIRONOV", 7, 200063},
	{"DINOFLAGELLATE", 14, 200064},
	{"SPONSES", 7, 200065},
	{"BELLEZAS", 8, 200066},
	{"TIMEWASTER", 10, 200067},
	{"KINCH", 5, 200068},
	{"DZDUMMY", 7, 200069},
	{"FREEMONT", 8, 200070},
	{"PULBOROUGH", 10, 200071},
	{"NEWPAGE", 7, 200072},
	{"SCAP", 4, 200073},
	{"GUBBIO", 6, 200074},
	{"SKYDIVERS", 9, 200075},
	{"SKNG", 4, 200076},
	{"ENDOWS", 6, 200077},
	{"ANTIFUNGALS", 11, 200078},
	{"REALLOCATING", 12, 200079},
	{"KLEIST", 6, 200080},
	{"FFACS", 5, 200081},
	{"RWR", 3, 200082},
	{"MARCELINO", 9, 200083},
	{"ACINAR", 6, 200084},
	{"ARTHAS", 6, 200085},
	{"SAYEST", 6, 200086},
	{"CHLD", 4, 200087},
	{"ARPWATCH", 8, 200088},
	{"HTTRACK", 7, 200089},
	{"REDECORATE", 10, 200090},
	{"OCCIDENT", 8, 200091},
	{"LUTTER", 6, 200092},
	{"DAMI", 4, 200093},
	{"BATCAVE", 7, 200094},
	{"RSVPS", 5, 200095},
	{"BEATIFICATION", 13, 200096},
	{"SAARBRUCKEN", 11, 200097},
	{"MAINWARING", 10, 200098},
	{"PAISE", 5, 200099},
	{"ONVISTA", 7, 200100},
	{"CARNIVORA", 9, 200101},
	{"AHMAN", 5, 200102},
	{"HEISSEN", 7, 200103},
	{"BETHELL", 7, 200104},
	{"BULLRING", 8, 200105},
	{"PHANEUF", 7, 200106},
	{"INCLUDIBLE", 10, 200107},
	{"UNFORTUNATLEY", 13, 200108},
	{"KROQ", 4, 200109},
	{"UNMARK", 6, 200110},
	{"ANNIVERSERY", 11, 200111},
	{"POLINI", 6, 200112},
	{"SIXXETTE", 8, 200113},
	{"PRISONACT", 9, 200114},
	{"IROW", 4, 200115},
	{"CABINETMAKER", 12, 200116},
	{"VOEUX", 5, 200117},
	{"SHOWDOWNS", 9, 200118},
	{"FRIVOLE", 7, 200119},
	{"CHAUFFAGE", 9, 200120},
	{"PELADA", 6, 200121},
	{"GOTTWALD", 8, 200122},
	{"DETUNING", 8, 200123},
	{"WAHKIAKUM", 9, 200124},
	{"THALASSA", 8, 200125},
	{"SELWAY", 6, 200126},
	{"PARASTATAL", 10, 200127},
	{"HOLDAY", 6, 200128},
	{"TROTSKYIST", 10, 200129},
	{"LEADBEATER", 10, 200130},
	{"OPPOSITELY", 10, 200131},
	{"LISTWORK", 8, 200132},
	{"BIOCHEMICALLY", 13, 200133},
	{"GNASH", 5, 200134},
	{"FINANZIERUNG", 12, 200135},
	{"COMPAZINE", 9, 200136},
	{"WORTHPLAYING", 12, 200137},
	{"WOOKIEE", 7, 200138},
	{"STASTNY", 7, 200139},
	{"PUKA", 4, 200140},
	{"BRUMMER", 7, 200141},
	{"PLANIFICATION", 13, 200142},
	{"COMPARSION", 10, 200143},
	{"CHANDY", 6, 200144},
	{"PSEUDONYMOUS", 12, 200145},
	{"HCAP", 4, 200146},
	{"SPRINGBANK", 10, 200147},
	{"NOISECOLLECTOR", 14, 200148},
	{"DARKNET", 7, 200149},
	{"ALTSTADT", 8, 200150},
	{"SINGHA", 6, 200151},
	{"POKERPARTY", 10, 200152},
	{"AXIUM", 5, 200153},
	{"ACTIVESCAN", 10, 200154},
	{"IMPACTFUL", 9, 200155},
	{"DISHTV", 6, 200156},
	{"COMPOSTS", 8, 200157},
	{"SIMPLEMENTE", 11, 200158},
	{"JUGES", 5, 200159},
	{"SOLANACEARUM", 12, 200160},
	{"LONGSWORD", 9, 200161},
	{"LEISA", 5, 200162},
	{"DEQUEUE", 7, 200163},
	{"SOLARE", 6, 200164},
	{"NORTONS", 7, 200165},
	{"LIDELL", 6, 200166},
	{"ATARIAGE", 8, 200167},
	{"PAPISTS", 7, 200168},
	{"FLAMER", 6, 200169},
	{"SLIFER", 6, 200170},
	{"LBV", 3, 200171},
	{"WMB", 3, 200172},
	{"MURNANE", 7, 200173},
	{"DICKENSTEN", 10, 200174},
	{"PYGEUM", 6, 200175},
	{"PICHER", 6, 200176},
	{"EUROWEATHER", 11, 200177},
	{"ZFER", 4, 200178},
	{"YKMF", 4, 200179},
	{"WLTR", 4, 200180},
	{"URDC", 4, 200181},
	{"UKVE", 4, 200182},
	{"UJJA", 4, 200183},
	{"UIOF", 4, 200184},
	{"UFCH", 4, 200185},
	{"TTPM", 4, 200186},
	{"TMSM", 4, 200187},
	{"TLLM", 4, 200188},
	{"SPSL", 4, 200189},
	{"RCOK", 4, 200190},
	{"OXFE", 4, 200191},
	{"ORLC", 4, 200192},
	{"OHYB", 4, 200193},
	{"OBUA", 4, 200194},
	{"NEJR", 4, 200195},
	{"MTCO", 4, 200196},
	{"MIVO", 4, 200197},
	{"LUGL", 4, 200198},
	{"KYBY", 4, 200199},
	{"KSAK", 4, 200200},
	{"JASK", 4, 200201},
	{"HZAR", 4, 200202},
	{"HMCM", 4, 200203},
	{"GLUD", 4, 200204},
	{"FUFO", 4, 200205},
	{"FBIZ", 4, 200206},
	{"EKKK", 4, 200207},
	{"DJAF", 4, 200208},
	{"DDCU", 4, 200209},
	{"CNEX", 4, 200210},
	{"BTPE", 4, 200211},
	{"BRUJ", 4, 200212},
	{"APKE", 4, 200213},
	{"AGDP", 4, 200214},
	{"REDVIOLET", 9, 200215},
	{"CHARMIN", 7, 200216},
	{"AFRA", 4, 200217},
	{"UDOT", 4, 200218},
	{"SADIEMAE", 8, 200219},
	{"JEER", 4, 200220},
	{"MADC", 4, 200221},
	{"BENESSERE", 9, 200222},
	{"GFG", 3, 200223},
	{"KATOH", 5, 200224},
	{"CRYSTIAN", 8, 200225},
	{"BRCH", 4, 200226},
	{"SACU", 4, 200227},
	{"ANNECLAIRE", 10, 200228},
	{"STRAUCH", 7, 200229},
	{"SCHARFF", 7, 200230},
	{"HOSSAM", 6, 200231},
	{"PERMANANT", 9, 200232},
	{"SWINK", 5, 200233},
	{"NACHTCLUBS", 10, 200234},
	{"BERBERIS", 8, 200235},
	{"IMPI", 4, 200236},
	{"SNMPD", 5, 200237},
	{"MIZUTANI", 8, 200238},
	{"JOUBEE", 6, 200239},
	{"HOTESL", 6, 200240},
	{"TIPHYS", 6, 200241},
	{"PREMEDITATION", 13, 200242},
	{"KERJA", 5, 200243},
	{"CSSC", 4, 200244},
	{"COTTERELL", 9, 200245},
	{"BINNENKORT", 10, 200246},
	{"MPIX", 4, 200247},
	{"HIBISKISS", 9, 200248},
	{"COFA", 4, 200249},
	{"NEUSCHWANSTEIN", 14, 200250},
	{"SPEARHEADS", 10, 200251},
	{"SOFTONIC", 8, 200252},
	{"MKIII", 5, 200253},
	{"LIGHTPATH", 9, 200254},
	{"CANAZEI", 7, 200255},
	{"AUOYDE", 6, 200256},
	{"WAKEN", 5, 200257},
	{"BAUHINIA", 8, 200258},
	{"SERGI", 5, 200259},
	{"EISDAMME", 8, 200260},
	{"SPYCRAFT", 8, 200261},
	{"SCUOLE", 6, 200262},
	{"GREENHAM", 8, 200263},
	{"ISOBUTANE", 9, 200264},
	{"TEARFULLY", 9, 200265},
	{"FLOREA", 6, 200266},
	{"EPISODI", 7, 200267},
	{"STERIODS", 8, 200268},
	{"SALAAT", 6, 200269},
	{"LINKEDLIST", 10, 200270},
	{"TOXAPHENE", 9, 200271},
	{"SILFLAY", 7, 200272},
	{"GRAL", 4, 200273},
	{"LEPUS", 5, 200274},
	{"KYLEE", 5, 200275},
	{"DATACENTRE", 10, 200276},
	{"RUNDE", 5, 200277},
	{"JSME", 4, 200278},
	{"GROATS", 6, 200279},
	{"SUNDQUIST", 9, 200280},
	{"NUTZER", 6, 200281},
	{"KOOBA", 5, 200282},
	{"JESSAMYN", 8, 200283},
	{"AGORAPHOBIC", 11, 200284},
	{"SOURCEFIRE", 10, 200285},
	{"SINTER", 6, 200286},
	{"TREMAYNE", 8, 200287},
	{"JWM", 3, 200288},
	{"HEUNG", 5, 200289},
	{"EDDYSTONE", 9, 200290},
	{"COLMENAR", 8, 200291},
	{"OLIVIERI", 8, 200292},
	{"VILLUS", 6, 200293},
	{"RADNER", 6, 200294},
	{"EQUALISED", 9, 200295},
	{"DEPLOYER", 8, 200296},
	{"TAHLIANA", 8, 200297},
	{"ROWID", 5, 200298},
	{"FJOLA", 5, 200299},
	{"STICKIN", 7, 200300},
	{"SAFEX", 5, 200301},
	{"SAGGED", 6, 200302},
	{"NIZKOR", 6, 200303},
	{"LEASHED", 7, 200304},
	{"OOLITE", 6, 200305},
	{"INFEED", 6, 200306},
	{"VICTROLA", 8, 200307},
	{"STERNAL", 7, 200308},
	{"PUGNACIOUS", 10, 200309},
	{"PARAINFLUENZA", 13, 200310},
	{"XCORAL", 6, 200311},
	{"XARDS", 5, 200312},
	{"SUBSTANTIATES", 13, 200313},
	{"SEKONIC", 7, 200314},
	{"COMPANIE", 8, 200315},
	{"JENNIRAE", 8, 200316},
	{"CALLIGRAPHERS", 13, 200317},
	{"WELDTITE", 8, 200318},
	{"TOYRKIAS", 8, 200319},
	{"KIMMITT", 7, 200320},
	{"CASETRONIC", 10, 200321},
	{"BEHEMOTHS", 9, 200322},
	{"SORCE", 5, 200323},
	{"SLAPP", 5, 200324},
	{"HOOTON", 6, 200325},
	{"HOFMEISTER", 10, 200326},
	{"COASTSIDER", 10, 200327},
	{"SHOWME", 6, 200328},
	{"OLIMPIA", 7, 200329},
	{"BEDECKED", 8, 200330},
	{"SIEVERT", 7, 200331},
	{"ENGIES", 6, 200332},
	{"VERUS", 5, 200333},
	{"LLAME", 5, 200334},
	{"YCC", 3, 200335},
	{"KEYFOB", 6, 200336},
	{"CHRISTOFLE", 10, 200337},
	{"PLAINED", 7, 200338},
	{"THINKTANKS", 10, 200339},
	{"FLUIDLY", 7, 200340},
	{"CARDMEMBER", 10, 200341},
	{"ISCHGL", 6, 200342},
	{"FUNITURE", 8, 200343},
	{"OPENWORLD", 9, 200344},
	{"LINCROFT", 8, 200345},
	{"COMBIS", 6, 200346},
	{"CHARNOCK", 8, 200347},
	{"LILAMAY", 7, 200348},
	{"AQUATALIA", 9, 200349},
	{"BIOLOGI", 7, 200350},
	{"DELORIUM", 8, 200351},
	{"HOLDBACK", 8, 200352},
	{"FINALMENTE", 10, 200353},
	{"AGURI", 5, 200354},
	{"CHAZY", 5, 200355},
	{"AUSUBEL", 7, 200356},
	{"SHORTYS", 7, 200357},
	{"KORENTO", 7, 200358},
	{"TAVENER", 7, 200359},
	{"FAFNER", 6, 200360},
	{"PANELIZED", 9, 200361},
	{"DICTOINARY", 10, 200362},
	{"STEALTHNET", 10, 200363},
	{"AUTOMOUNTER", 11, 200364},
	{"ZAZE", 4, 200365},
	{"YPOX", 4, 200366},
	{"YEUS", 4, 200367},
	{"VORU", 4, 200368},
	{"VOFS", 4, 200369},
	{"VMIC", 4, 200370},
	{"VEAZ", 4, 200371},
	{"VCOV", 4, 200372},
	{"UPYS", 4, 200373},
	{"UOTJ", 4, 200374},
	{"UKFI", 4, 200375},
	{"UFCI", 4, 200376},
	{"TRDA", 4, 200377},
	{"TJUP", 4, 200378},
	{"RVTU", 4, 200379},
	{"RVPA", 4, 200380},
	{"OYHU", 4, 200381},
	{"OMLB", 4, 200382},
	{"OLEZ", 4, 200383},
	{"ODIK", 4, 200384},
	{"LECP", 4, 200385},
	{"KIRR", 4, 200386},
	{"HNUP", 4, 200387},
	{"HEXK", 4, 200388},
	{"GLAH", 4, 200389},
	{"FGHE", 4, 200390},
	{"FAXB", 4, 200391},
	{"EZOV", 4, 200392},
	{"ESWY", 4, 200393},
	{"ENRD", 4, 200394},
	{"EMKO", 4, 200395},
	{"EFCU", 4, 200396},
	{"CTOJ", 4, 200397},
	{"BYUW", 4, 200398},
	{"BPEA", 4, 200399},
	{"AVIF", 4, 200400},
	{"ARFP", 4, 200401},
	{"ARCJ", 4, 200402},
	{"COMUNISTA", 9, 200403},
	{"STEUART", 7, 200404},
	{"BIRTHMARKS", 10, 200405},
	{"SEMIFINALISTS", 13, 200406},
	{"KOWAL", 5, 200407},
	{"KAGYU", 5, 200408},
	{"NESSUNO", 7, 200409},
	{"NEBBIOLO", 8, 200410},
	{"WORLDVILLAGE", 12, 200411},
	{"TEMAGAMI", 8, 200412},
	{"IDEALE", 6, 200413},
	{"PUCTURES", 8, 200414},
	{"PLOTLINES", 9, 200415},
	{"ELIJA", 5, 200416},
	{"ANNUNZIO", 8, 200417},
	{"TRUMBO", 6, 200418},
	{"HPCC", 4, 200419},
	{"DERK", 4, 200420},
	{"DELP", 4, 200421},
	{"REUSES", 6, 200422},
	{"NGINES", 6, 200423},
	{"DRWXRWXRWX", 10, 200424},
	{"GRAPHIS", 7, 200425},
	{"AFDELING", 8, 200426},
	{"NIGGLING", 8, 200427},
	{"CANLYNOL", 8, 200428},
	{"VERKAIK", 7, 200429},
	{"BROSE", 5, 200430},
	{"ISSION", 6, 200431},
	{"GENITO", 6, 200432},
	{"BOONSTRA", 8, 200433},
	{"INTERCALATION", 13, 200434},
	{"THERMIC", 7, 200435},
	{"IFNUM", 5, 200436},
	{"BOTY", 4, 200437},
	{"FENNEC", 6, 200438},
	{"WILLL", 5, 200439},
	{"SANDSPIT", 8, 200440},
	{"RUSTPROOF", 9, 200441},
	{"POWDERHORN", 10, 200442},
	{"AGENDUS", 7, 200443},
	{"BEARSDEN", 8, 200444},
	{"DAWID", 5, 200445},
	{"CLIB", 4, 200446},
	{"DICTIOARY", 9, 200447},
	{"STELZER", 7, 200448},
	{"AUDIOLOGICAL", 12, 200449},
	{"MPLOYMENT", 9, 200450},
	{"MICROWAVEABLE", 13, 200451},
	{"LAZIER", 6, 200452},
	{"CFCNET", 6, 200453},
	{"SUPORTE", 7, 200454},
	{"LINKBACK", 8, 200455},
	{"NAKEDTEENS", 10, 200456},
	{"RASOOL", 6, 200457},
	{"NONBINDING", 10, 200458},
	{"BARTONVILLE", 11, 200459},
	{"MYBOB", 5, 200460},
	{"BBLOG", 5, 200461},
	{"PROGRAMATICALLY", 15, 200462},
	{"CCID", 4, 200463},
	{"GRAVOIS", 7, 200464},
	{"POLONICA", 8, 200465},
	{"BIOFILTER", 9, 200466},
	{"POWERSVILLE", 11, 200467},
	{"INUPIAK", 7, 200468},
	{"RIASSUNTO", 9, 200469},
	{"ZEPEDA", 6, 200470},
	{"MULTISECTORAL", 13, 200471},
	{"CYANOGEN", 8, 200472},
	{"COCKAPOO", 8, 200473},
	{"MINKS", 5, 200474},
	{"NUREMBURG", 9, 200475},
	{"FREIZEITHUREN", 13, 200476},
	{"WINLOCK", 7, 200477},
	{"NEWISH", 6, 200478},
	{"LUXUS", 5, 200479},
	{"ENTOMOLOGISTS", 13, 200480},
	{"SNRNA", 5, 200481},
	{"PEROUTKA", 8, 200482},
	{"NAUGHTEN", 8, 200483},
	{"MINCHAN", 7, 200484},
	{"ZHUKOV", 6, 200485},
	{"DARCIE", 6, 200486},
	{"XCAT", 4, 200487},
	{"REWORD", 6, 200488},
	{"EVENTGUIDE", 10, 200489},
	{"LKB", 3, 200490},
	{"BOOSLEY", 7, 200491},
	{"AGROSCIENCES", 12, 200492},
	{"ABDALLA", 7, 200493},
	{"WACHEE", 6, 200494},
	{"MIDLETON", 8, 200495},
	{"DELILLA", 7, 200496},
	{"PROGRAMFILES", 12, 200497},
	{"GULBENKIAN", 10, 200498},
	{"SHENNI", 6, 200499},
	{"NEUTRALINO", 10, 200500},
	{"POSTPONEMENTS", 13, 200501},
	{"YAZZIE", 6, 200502},
	{"TERIA", 5, 200503},
	{"REFUGIA", 7, 200504},
	{"TOPICALITY", 10, 200505},
	{"VALLON", 6, 200506},
	{"PURSING", 7, 200507},
	{"HUSKEY", 6, 200508},
	{"SANTIS", 6, 200509},
	{"FODENDO", 7, 200510},
	{"AAACE", 5, 200511},
	{"FRANDSEN", 8, 200512},
	{"CANDIDAT", 8, 200513},
	{"ARTARMON", 8, 200514},
	{"BLONDEL", 7, 200515},
	{"SCRS", 4, 200516},
	{"OFTENER", 7, 200517},
	{"MOTIONING", 9, 200518},
	{"NIKOLAJ", 7, 200519},
	{"CONSULENZA", 10, 200520},
	{"AERONAUTICA", 11, 200521},
	{"SAUNTER", 7, 200522},
	{"TRUNCATES", 9, 200523},
	{"DEVACHKA", 8, 200524},
	{"ROMPS", 5, 200525},
	{"RANUM", 5, 200526},
	{"BROLLY", 6, 200527},
	{"UNIVERSELLE", 11, 200528},
	{"MINCO", 5, 200529},
	{"AFFRICA", 7, 200530},
	{"TROPOS", 6, 200531},
	{"OLARAK", 6, 200532},
	{"NUTJOB", 6, 200533},
	{"INTERNETWIRELESS", 16, 200534},
	{"WILBURTON", 9, 200535},
	{"MERGERPLACE", 11, 200536},
	{"ABSORBTION", 10, 200537},
	{"BORDURE", 7, 200538},
	{"PAIDEIA", 7, 200539},
	{"EREV", 4, 200540},
	{"PDAGEEK", 7, 200541},
	{"QUEIROZ", 7, 200542},
	{"PINATUBO", 8, 200543},
	{"CARAVANAS", 9, 200544},
	{"ZZAG", 4, 200545},
	{"ZYSU", 4, 200546},
	{"ZINP", 4, 200547},
	{"YRSI", 4, 200548},
	{"YAMF", 4, 200549},
	{"XSFA", 4, 200550},
	{"XOSK", 4, 200551},
	{"XCOV", 4, 200552},
	{"WUPG", 4, 200553},
	{"WMYB", 4, 200554},
	{"VFOO", 4, 200555},
	{"VEUM", 4, 200556},
	{"UFFJ", 4, 200557},
	{"UBAE", 4, 200558},
	{"TZAG", 4, 200559},
	{"TWAU", 4, 200560},
	{"TDSL", 4, 200561},
	{"SHKR", 4, 200562},
	{"SBYQ", 4, 200563},
	{"RZUM", 4, 200564},
	{"RTZD", 4, 200565},
	{"RBAW", 4, 200566},
	{"OYPU", 4, 200567},
	{"NUZZ", 4, 200568},
	{"NIDF", 4, 200569},
	{"NGHF", 4, 200570},
	{"LSIK", 4, 200571},
	{"LMBL", 4, 200572},
	{"LEGK", 4, 200573},
	{"KJEA", 4, 200574},
	{"JUWA", 4, 200575},
	{"ISKV", 4, 200576},
	{"IRTG", 4, 200577},
	{"HWYN", 4, 200578},
	{"HNXX", 4, 200579},
	{"HMBA", 4, 200580},
	{"HGLU", 4, 200581},
	{"GYAW", 4, 200582},
	{"GILY", 4, 200583},
	{"FRTH", 4, 200584},
	{"EUXT", 4, 200585},
	{"EOGD", 4, 200586},
	{"ELTK", 4, 200587},
	{"EEMG", 4, 200588},
	{"DTSP", 4, 200589},
	{"BOPO", 4, 200590},
	{"BHRA", 4, 200591},
	{"AMNF", 4, 200592},
	{"AKIZ", 4, 200593},
	{"AGGW", 4, 200594},
	{"ERDAS", 5, 200595},
	{"DEILMANN", 8, 200596},
	{"VERSTRING", 9, 200597},
	{"TRACKWARE", 9, 200598},
	{"LIKY", 4, 200599},
	{"RGL", 3, 200600},
	{"MARLLEE", 7, 200601},
	{"HOGER", 5, 200602},
	{"GNOMEVFS", 8, 200603},
	{"BROOKELYNNE", 11, 200604},
	{"JULIANS", 7, 200605},
	{"MALET", 5, 200606},
	{"HISTOCHEM", 9, 200607},
	{"GARMOND", 7, 200608},
	{"WALCH", 5, 200609},
	{"CINTRA", 6, 200610},
	{"BLUEANT", 7, 200611},
	{"FIRMIN", 6, 200612},
	{"MICROCELL", 9, 200613},
	{"INDIVIDUELLE", 12, 200614},
	{"MUDIC", 5, 200615},
	{"HARGRAVES", 9, 200616},
	{"BOLYAI", 6, 200617},
	{"RETOUCHED", 9, 200618},
	{"NUKKAD", 6, 200619},
	{"CHAPPY", 6, 200620},
	{"VIVISIMO", 8, 200621},
	{"JUXTAPOSING", 11, 200622},
	{"CALAMARIS", 9, 200623},
	{"THOMASTIK", 9, 200624},
	{"SEMANTICAL", 10, 200625},
	{"WINTERY", 7, 200626},
	{"KEEF", 4, 200627},
	{"SONABLE", 7, 200628},
	{"LLAMADO", 7, 200629},
	{"ICOSAHEDRAL", 11, 200630},
	{"CAMPARI", 7, 200631},
	{"ALFVEN", 6, 200632},
	{"STOMPERS", 8, 200633},
	{"ADVENTURESOME", 13, 200634},
	{"VERSANT", 7, 200635},
	{"MACPHEE", 7, 200636},
	{"DOUCHING", 8, 200637},
	{"FLAXEN", 6, 200638},
	{"VISY", 4, 200639},
	{"TALMAN", 6, 200640},
	{"HARLESDEN", 9, 200641},
	{"STAGHORN", 8, 200642},
	{"SANTIANNA", 9, 200643},
	{"GOYETTE", 7, 200644},
	{"PSEUD", 5, 200645},
	{"MENGES", 6, 200646},
	{"ASHWAUBENON", 11, 200647},
	{"PASSEIG", 7, 200648},
	{"PERFE", 5, 200649},
	{"PIHKA", 5, 200650},
	{"LAGANAS", 7, 200651},
	{"SLEEPYTIME", 10, 200652},
	{"GLENHAVEN", 9, 200653},
	{"INTERAMERICAN", 13, 200654},
	{"STEREOCHEMICAL", 14, 200655},
	{"MENDER", 6, 200656},
	{"MCGRUDER", 8, 200657},
	{"BREADING", 8, 200658},
	{"LCX", 3, 200659},
	{"BETSYJANE", 9, 200660},
	{"BACKFILLED", 10, 200661},
	{"METALLOPROTEASE", 15, 200662},
	{"LIBQT", 5, 200663},
	{"WENTE", 5, 200664},
	{"RAGGETT", 7, 200665},
	{"NEUROCOGNITIVE", 14, 200666},
	{"TEMPTER", 7, 200667},
	{"RLR", 3, 200668},
	{"PRECEDENTIAL", 12, 200669},
	{"ZUBIN", 5, 200670},
	{"SHUSH", 5, 200671},
	{"MIAMAZE", 7, 200672},
	{"CHENNIN", 7, 200673},
	{"MARKWEST", 8, 200674},
	{"BOINK", 5, 200675},
	{"VAMPIRISM", 9, 200676},
	{"DIGITIAL", 8, 200677},
	{"BELITTLED", 9, 200678},
	{"BESIKTAS", 8, 200679},
	{"REAKTION", 8, 200680},
	{"SCORELINE", 9, 200681},
	{"HIERARCHIC", 10, 200682},
	{"MISCARRIED", 10, 200683},
	{"CONSTANS", 8, 200684},
	{"BYDDAI", 6, 200685},
	{"JTRADE", 6, 200686},
	{"NASRALLAH", 9, 200687},
	{"EGINES", 6, 200688},
	{"BONDWARE", 8, 200689},
	{"AELISHA", 7, 200690},
	{"OGLETREE", 8, 200691},
	{"INSURANC", 8, 200692},
	{"PARENTCENTER", 12, 200693},
	{"COLORABLE", 9, 200694},
	{"STONEAGE", 8, 200695},
	{"HURENKONTAKTE", 13, 200696},
	{"TAGAYTAY", 8, 200697},
	{"PICTUREE", 8, 200698},
	{"LUCYLYNNE", 9, 200699},
	{"HOBBYHOSTESS", 12, 200700},
	{"LABETALOL", 9, 200701},
	{"THAUVIN", 7, 200702},
	{"NUTIVA", 6, 200703},
	{"COMUNI", 6, 200704},
	{"BOGGESS", 7, 200705},
	{"CHEMISCHE", 9, 200706},
	{"TEEING", 6, 200707},
	{"NAIMA", 5, 200708},
	{"TRACTATUS", 9, 200709},
	{"CANAKKALE", 9, 200710},
	{"GALLAND", 7, 200711},
	{"FRAIYA", 6, 200712},
	{"PHONOGRAPHS", 11, 200713},
	{"DIMMABLE", 8, 200714},
	{"CRUMLEY", 7, 200715},
	{"AUSZUG", 6, 200716},
	{"UTURE", 5, 200717},
	{"LOVEGATE", 8, 200718},
	{"SIEDLER", 7, 200719},
	{"MADDAME", 7, 200720},
	{"SEGRE", 5, 200721},
	{"LUMMI", 5, 200722},
	{"MEDROL", 6, 200723},
	{"DESTABILISING", 13, 200724},
	{"STUDENTINEN", 11, 200725},
	{"MCCOWAN", 7, 200726},
	{"SAADI", 5, 200727},
	{"TWEAKERS", 8, 200728},
	{"RIVULETS", 8, 200729},
	{"SEARSPORT", 9, 200730},
	{"KPDF", 4, 200731},
	{"YWOE", 4, 200732},
	{"YEJE", 4, 200733},
	{"WNIW", 4, 200734},
	{"WDUT", 4, 200735},
	{"VWAT", 4, 200736},
	{"VDUR", 4, 200737},
	{"UOJI", 4, 200738},
	{"UCAB", 4, 200739},
	{"TZEB", 4, 200740},
	{"TOWF", 4, 200741},
	{"SUCI", 4, 200742},
	{"RYIO", 4, 200743},
	{"RNYT", 4, 200744},
	{"RLVO", 4, 200745},
	{"PVET", 4, 200746},
	{"PPFI", 4, 200747},
	{"PESJ", 4, 200748},
	{"PCEO", 4, 200749},
	{"OZOF", 4, 200750},
	{"NLAJ", 4, 200751},
	{"NIKC", 4, 200752},
	{"MTFO", 4, 200753},
	{"KFEM", 4, 200754},
	{"KDUC", 4, 200755},
	{"IYAF", 4, 200756},
	{"INFC", 4, 200757},
	{"IFAJ", 4, 200758},
	{"IAPM", 4, 200759},
	{"HIDF", 4, 200760},
	{"GHKO", 4, 200761},
	{"GDAG", 4, 200762},
	{"FENM", 4, 200763},
	{"EMPD", 4, 200764},
	{"EKWR", 4, 200765},
	{"EGOJ", 4, 200766},
	{"ECYW", 4, 200767},
	{"ECOQ", 4, 200768},
	{"DCIL", 4, 200769},
	{"COSV", 4, 200770},
	{"AYRH", 4, 200771},
	{"ASWW", 4, 200772},
	{"AMOJ", 4, 200773},
	{"OPAHL", 5, 200774},
	{"GLYCOSYLTRANSFERASE", 19, 200775},
	{"COOLIN", 6, 200776},
	{"ARABEYES", 8, 200777},
	{"SWEATIN", 7, 200778},
	{"MOLLYDOLLY", 10, 200779},
	{"CAFS", 4, 200780},
	{"BENEFI", 6, 200781},
	{"GERSHOM", 7, 200782},
	{"ESPIE", 5, 200783},
	{"KAYLIANE", 8, 200784},
	{"CORDE", 5, 200785},
	{"COMMAUNDED", 10, 200786},
	{"SHAWCROSS", 9, 200787},
	{"BLANDIT", 7, 200788},
	{"AREAWIDE", 8, 200789},
	{"YMD", 3, 200790},
	{"SUGER", 5, 200791},
	{"MICARTA", 7, 200792},
	{"CAFDS", 5, 200793},
	{"SOBG", 4, 200794},
	{"FICTIONARY", 10, 200795},
	{"HURENLEXIKON", 12, 200796},
	{"APPERTAINING", 12, 200797},
	{"HETEROTIC", 9, 200798},
	{"LOGLEVEL", 8, 200799},
	{"MSBA", 4, 200800},
	{"MARIUCCI", 8, 200801},
	{"NOSTRE", 6, 200802},
	{"GROBAG", 6, 200803},
	{"BJORKLUND", 9, 200804},
	{"TIGRAN", 6, 200805},
	{"PCHAR", 5, 200806},
	{"IPTG", 4, 200807},
	{"HELLANY", 7, 200808},
	{"AQUAPORIN", 9, 200809},
	{"SCIESZKA", 8, 200810},
	{"MAHALANOBIS", 11, 200811},
	{"BARBIQ", 6, 200812},
	{"TRADESIGNALS", 12, 200813},
	{"KEYSAN", 6, 200814},
	{"HOLLOWARE", 9, 200815},
	{"JALIC", 5, 200816},
	{"LOVELORN", 8, 200817},
	{"BACKYARDIGANS", 13, 200818},
	{"UTILISANT", 9, 200819},
	{"OREST", 5, 200820},
	{"BURNISHING", 10, 200821},
	{"AUREL", 5, 200822},
	{"PSMEG", 5, 200823},
	{"BORLIND", 7, 200824},
	{"WHDH", 4, 200825},
	{"GMW", 3, 200826},
	{"TRISTANO", 8, 200827},
	{"XCIN", 4, 200828},
	{"TILER", 5, 200829},
	{"REPLICON", 8, 200830},
	{"MAXPRICE", 8, 200831},
	{"MASCHERA", 8, 200832},
	{"SALVAGEABLE", 11, 200833},
	{"ROSNY", 5, 200834},
	{"COUNTERREVOLUTIONARY", 20, 200835},
	{"ACRC", 4, 200836},
	{"FIRKIN", 6, 200837},
	{"FINNEGANS", 9, 200838},
	{"CORNEY", 6, 200839},
	{"UNEVENNESS", 10, 200840},
	{"EMISSIVE", 8, 200841},
	{"PROZESSOR", 9, 200842},
	{"DOCTORZIN", 9, 200843},
	{"RIZED", 5, 200844},
	{"MIRABELLA", 9, 200845},
	{"GAUS", 4, 200846},
	{"CSILLAG", 7, 200847},
	{"BORTZ", 5, 200848},
	{"ALANYL", 6, 200849},
	{"AIMPOINT", 8, 200850},
	{"BETTEN", 6, 200851},
	{"LULUMAE", 7, 200852},
	{"BURQA", 5, 200853},
	{"PETRONE", 7, 200854},
	{"GENERICA", 8, 200855},
	{"OUTDOORSMAGIC", 13, 200856},
	{"ALPHABETIZE", 11, 200857},
	{"MERCANTIL", 9, 200858},
	{"COMPIERE", 8, 200859},
	{"MASKE", 5, 200860},
	{"AUTOSTRICH", 10, 200861},
	{"LETTERBOXING", 12, 200862},
	{"CANDU", 5, 200863},
	{"VIEWSTATION", 11, 200864},
	{"STYLEE", 6, 200865},
	{"SLEEPOVERS", 10, 200866},
	{"ALWAR", 5, 200867},
	{"FRISBIE", 7, 200868},
	{"SKIPING", 7, 200869},
	{"HAVANNA", 7, 200870},
	{"IMMUNISED", 9, 200871},
	{"MWU", 3, 200872},
	{"CURRED", 6, 200873},
	{"MIRELLA", 7, 200874},
	{"AUDION", 6, 200875},
	{"TRACTATE", 8, 200876},
	{"SHADETREE", 9, 200877},
	{"SENTATIVE", 9, 200878},
	{"RWJF", 4, 200879},
	{"GEEVA", 5, 200880},
	{"LEMLEY", 6, 200881},
	{"HEATHERMARIE", 12, 200882},
	{"TREANOR", 7, 200883},
	{"QUELLIOUS", 9, 200884},
	{"HABLE", 5, 200885},
	{"BUZZLE", 6, 200886},
	{"PICRURES", 8, 200887},
	{"ITSKILLSPORTAL", 14, 200888},
	{"LAVONIA", 7, 200889},
	{"PROCHAINE", 9, 200890},
	{"NOSTOP", 6, 200891},
	{"EDITTING", 8, 200892},
	{"BLOGRANK", 8, 200893},
	{"ITSEARCHPORTAL", 14, 200894},
	{"ITESP", 5, 200895},
	{"HAKKO", 5, 200896},
	{"DEJESUS", 7, 200897},
	{"NESCONSET", 9, 200898},
	{"COMPETITON", 10, 200899},
	{"ARTAPPRAISER", 12, 200900},
	{"CYMRYD", 6, 200901},
	{"COPYBOOK", 8, 200902},
	{"SETHANDLER", 10, 200903},
	{"PSYCHES", 7, 200904},
	{"MUNMAP", 6, 200905},
	{"YUWH", 4, 200906},
	{"YNSW", 4, 200907},
	{"YILA", 4, 200908},
	{"YBOC", 4, 200909},
	{"WIAR", 4, 200910},
	{"WFES", 4, 200911},
	{"VLIS", 4, 200912},
	{"ULEJ", 4, 200913},
	{"UIFT", 4, 200914},
	{"THRM", 4, 200915},
	{"SMFE", 4, 200916},
	{"SDRH", 4, 200917},
	{"RIFG", 4, 200918},
	{"OHBY", 4, 200919},
	{"OCYL", 4, 200920},
	{"NRRA", 4, 200921},
	{"NOPG", 4, 200922},
	{"NMRL", 4, 200923},
	{"LBOC", 4, 200924},
	{"JPAR", 4, 200925},
	{"IVUN", 4, 200926},
	{"IPMY", 4, 200927},
	{"IBMR", 4, 200928},
	{"GKAB", 4, 200929},
	{"GFEV", 4, 200930},
	{"EXMC", 4, 200931},
	{"EWGC", 4, 200932},
	{"EVYB", 4, 200933},
	{"EVPE", 4, 200934},
	{"AXGA", 4, 200935},
	{"ASBB", 4, 200936},
	{"AMRH", 4, 200937},
	{"AJUK", 4, 200938},
	{"PARTRIDGES", 10, 200939},
	{"EROTICMODELLE", 13, 200940},
	{"ENGNES", 6, 200941},
	{"TOWERRECORDS", 12, 200942},
	{"MACNEE", 6, 200943},
	{"TEXHAX", 6, 200944},
	{"EROTIKMASSAGE", 13, 200945},
	{"QUALCHE", 7, 200946},
	{"KINX", 4, 200947},
	{"MKILA", 5, 200948},
	{"MAFKARAT", 8, 200949},
	{"SWUM", 4, 200950},
	{"HOOTENANNY", 10, 200951},
	{"DUNKLE", 6, 200952},
	{"PRECRIPTION", 11, 200953},
	{"THIELEN", 7, 200954},
	{"REBUILDERS", 10, 200955},
	{"INTERRUPTEDEXCEPTION", 20, 200956},
	{"ZOOMLEVEL", 9, 200957},
	{"WINNABLE", 8, 200958},
	{"MANAYUNK", 8, 200959},
	{"FELTER", 6, 200960},
	{"DRAWMER", 7, 200961},
	{"CQRDS", 5, 200962},
	{"ARISTOCATS", 10, 200963},
	{"EROTIKTREFF", 11, 200964},
	{"MANNSCHAFT", 10, 200965},
	{"MEUSER", 6, 200966},
	{"KAMILA", 6, 200967},
	{"FDUTILS", 7, 200968},
	{"ANGELLO", 7, 200969},
	{"BILDERTAUSCH", 12, 200970},
	{"HUALIEN", 7, 200971},
	{"AFEW", 4, 200972},
	{"PIFS", 4, 200973},
	{"JPGG", 4, 200974},
	{"WINPOPUP", 8, 200975},
	{"MISTREATING", 11, 200976},
	{"ANTONINO", 8, 200977},
	{"FORAGERS", 8, 200978},
	{"CASB", 4, 200979},
	{"THROWIN", 7, 200980},
	{"RIVERWOODS", 10, 200981},
	{"MELIN", 5, 200982},
	{"LILAH", 5, 200983},
	{"LDAPTOR", 7, 200984},
	{"KUSKOKWIM", 9, 200985},
	{"FMX", 3, 200986},
	{"PYSTOL", 6, 200987},
	{"COSTLIER", 8, 200988},
	{"ANCRAM", 6, 200989},
	{"ABBATE", 6, 200990},
	{"WBD", 3, 200991},
	{"TIRUNELVELI", 11, 200992},
	{"FORMALIST", 9, 200993},
	{"DECLUTTER", 9, 200994},
	{"RUBIACEAE", 9, 200995},
	{"THREADNEXT", 10, 200996},
	{"CWRDS", 5, 200997},
	{"BRAKEMAN", 8, 200998},
	{"REGRETFUL", 9, 200999},
	{"COASTED", 7, 201000},
	{"DEMOCRITUS", 10, 201001},
	{"FEDCO", 5, 201002},
	{"YAWL", 4, 201003},
	{"MRZ", 3, 201004},
	{"LVMH", 4, 201005},
	{"ENDAST", 6, 201006},
	{"UNREIMBURSED", 12, 201007},
	{"TELECASTS", 9, 201008},
	{"PERMETTRE", 9, 201009},
	{"PLEASERS", 8, 201010},
	{"KARISMIC", 8, 201011},
	{"IACOCCA", 7, 201012},
	{"BARATO", 6, 201013},
	{"AUGUSTI", 7, 201014},
	{"FEEDROOM", 8, 201015},
	{"EASYCRUISE", 10, 201016},
	{"QPOINT", 6, 201017},
	{"DROOPED", 7, 201018},
	{"GETACTIVE", 9, 201019},
	{"GEBOUWEN", 8, 201020},
	{"DELORIS", 7, 201021},
	{"BUSINESSWEEKONLINE", 18, 201022},
	{"WHITTAM", 7, 201023},
	{"GDD", 3, 201024},
	{"DISAPPLIED", 10, 201025},
	{"SIGNBOARD", 9, 201026},
	{"MARIENBAD", 9, 201027},
	{"MALOUF", 6, 201028},
	{"NIMAN", 5, 201029},
	{"CARIBBEANS", 10, 201030},
	{"MIGRA", 5, 201031},
	{"BRAISING", 8, 201032},
	{"MARGINALITY", 11, 201033},
	{"NETTET", 6, 201034},
	{"NGAMILAND", 9, 201035},
	{"AGUNG", 5, 201036},
	{"OPOSSUMS", 8, 201037},
	{"JURISTIC", 8, 201038},
	{"DEVELOMENT", 10, 201039},
	{"BURBAGE", 7, 201040},
	{"MASSOL", 6, 201041},
	{"JAREK", 5, 201042},
	{"DORMERS", 7, 201043},
	{"BUNDESMINISTERIUM", 17, 201044},
	{"LIBGNOMEDB", 10, 201045},
	{"SADDLERS", 8, 201046},
	{"HAYLES", 6, 201047},
	{"ACCESSIBILTY", 12, 201048},
	{"WIGGLESWORTH", 12, 201049},
	{"VALGUS", 6, 201050},
	{"RYDAL", 5, 201051},
	{"UNMENTIONED", 11, 201052},
	{"NAKING", 6, 201053},
	{"WALKY", 5, 201054},
	{"STUDIOTRAFFIC", 13, 201055},
	{"NECKLET", 7, 201056},
	{"ZPOL", 4, 201057},
	{"ZATR", 4, 201058},
	{"ZANP", 4, 201059},
	{"YNSB", 4, 201060},
	{"YDRR", 4, 201061},
	{"XPIN", 4, 201062},
	{"XPAG", 4, 201063},
	{"XBOM", 4, 201064},
	{"WSKN", 4, 201065},
	{"UBPM", 4, 201066},
	{"TPLI", 4, 201067},
	{"TMAV", 4, 201068},
	{"SYUM", 4, 201069},
	{"SVSM", 4, 201070},
	{"STDJ", 4, 201071},
	{"SDOJ", 4, 201072},
	{"RVOG", 4, 201073},
	{"ROZH", 4, 201074},
	{"QUEQ", 4, 201075},
	{"PUNB", 4, 201076},
	{"PTYM", 4, 201077},
	{"PNUC", 4, 201078},
	{"OUZI", 4, 201079},
	{"OBSQ", 4, 201080},
	{"NTVM", 4, 201081},
	{"NNMU", 4, 201082},
	{"NMUA", 4, 201083},
	{"NIFJ", 4, 201084},
	{"MMHO", 4, 201085},
	{"MJAY", 4, 201086},
	{"MCPR", 4, 201087},
	{"KABD", 4, 201088},
	{"JIVG", 4, 201089},
	{"JAMN", 4, 201090},
	{"ISDV", 4, 201091},
	{"IFSL", 4, 201092},
	{"HEDX", 4, 201093},
	{"FMCM", 4, 201094},
	{"EPYC", 4, 201095},
	{"EMIJ", 4, 201096},
	{"DYEW", 4, 201097},
	{"DOWK", 4, 201098},
	{"DDBI", 4, 201099},
	{"BOUB", 4, 201100},
	{"BBIJ", 4, 201101},
	{"AXMU", 4, 201102},
	{"CORPORATELY", 11, 201103},
	{"ABITI", 5, 201104},
	{"METHAMPHETAMINES", 16, 201105},
	{"TINUOUS", 7, 201106},
	{"SILANES", 7, 201107},
	{"MEHRERE", 7, 201108},
	{"SHRUM", 5, 201109},
	{"MANC", 4, 201110},
	{"SPRAYWAY", 8, 201111},
	{"PIPPIANNA", 9, 201112},
	{"BOOKSFIRST", 10, 201113},
	{"BOATLIFE", 8, 201114},
	{"GIMNASIA", 8, 201115},
	{"ULTY", 4, 201116},
	{"PRESORT", 7, 201117},
	{"HYPOPLASTIC", 11, 201118},
	{"DELMONICO", 9, 201119},
	{"ELCOME", 6, 201120},
	{"CANIO", 5, 201121},
	{"ARRESTORS", 9, 201122},
	{"STEVI", 5, 201123},
	{"KERRIER", 7, 201124},
	{"FUNS", 4, 201125},
	{"XIOLITA", 7, 201126},
	{"GOLDENMOON", 10, 201127},
	{"SMME", 4, 201128},
	{"MINPRICE", 8, 201129},
	{"REALRHAPSODY", 12, 201130},
	{"CANTILEVERS", 11, 201131},
	{"BIOORGANIC", 10, 201132},
	{"BECKERS", 7, 201133},
	{"EROTIKMODELLE", 13, 201134},
	{"RABBITTE", 8, 201135},
	{"SYNCRETISM", 10, 201136},
	{"BOWLINE", 7, 201137},
	{"AKTMODELL", 9, 201138},
	{"NIXIE", 5, 201139},
	{"SHADOWES", 8, 201140},
	{"POTOK", 5, 201141},
	{"THERMOGENICS", 12, 201142},
	{"PERCEIVABLE", 11, 201143},
	{"OSOGARAGE", 9, 201144},
	{"KABAR", 5, 201145},
	{"DEDUCING", 8, 201146},
	{"ANDREAE", 7, 201147},
	{"MADEN", 5, 201148},
	{"EXACTS", 6, 201149},
	{"NANODOT", 7, 201150},
	{"LICENTIOUS", 10, 201151},
	{"ROBA", 4, 201152},
	{"ISHING", 6, 201153},
	{"MILFOIL", 7, 201154},
	{"FHLMC", 5, 201155},
	{"ARMAVIRUMQUE", 12, 201156},
	{"GLAUBER", 7, 201157},
	{"BUDDYSIZE", 9, 201158},
	{"SPOND", 5, 201159},
	{"ANTIGUO", 7, 201160},
	{"NOETHERIAN", 10, 201161},
	{"CAPACIDAD", 9, 201162},
	{"COMPUTERCHEAP", 13, 201163},
	{"ESTOPPED", 8, 201164},
	{"VIDEOCONFERENCES", 16, 201165},
	{"MESMERISING", 11, 201166},
	{"OVERRODE", 8, 201167},
	{"CZRDS", 5, 201168},
	{"CORRELA", 7, 201169},
	{"ABSEIL", 6, 201170},
	{"XIMETA", 6, 201171},
	{"DICTIONRY", 9, 201172},
	{"AMMENITIES", 10, 201173},
	{"FRASI", 5, 201174},
	{"ALLENTON", 8, 201175},
	{"ARCHIMEDEAN", 11, 201176},
	{"AUSSIEWEB", 9, 201177},
	{"ZAPOTEC", 7, 201178},
	{"SHOTTON", 7, 201179},
	{"MULIT", 5, 201180},
	{"MARIEN", 6, 201181},
	{"GALCO", 5, 201182},
	{"ACCRETIVE", 9, 201183},
	{"INJURIA", 7, 201184},
	{"ARIENS", 6, 201185},
	{"RUBBINGS", 8, 201186},
	{"DILIMAN", 7, 201187},
	{"LABRIE", 6, 201188},
	{"CBCA", 4, 201189},
	{"BUGIS", 5, 201190},
	{"PATCHUTILS", 10, 201191},
	{"ANTICORRUPTION", 14, 201192},
	{"MICROWISE", 9, 201193},
	{"GILBERTS", 8, 201194},
	{"AKTMODEL", 8, 201195},
	{"INTRANSIGENT", 12, 201196},
	{"SANDEFUR", 8, 201197},
	{"MESSEGE", 7, 201198},
	{"IMAGEDESC", 9, 201199},
	{"EKBERG", 6, 201200},
	{"DATESTAMP", 9, 201201},
	{"WATERSCAPES", 11, 201202},
	{"NAJERA", 6, 201203},
	{"VALORISATION", 12, 201204},
	{"RECR", 4, 201205},
	{"INTRAPARTUM", 11, 201206},
	{"HALSALL", 7, 201207},
	{"XUV", 3, 201208},
	{"OLOFSSON", 8, 201209},
	{"MICAELANGELO", 12, 201210},
	{"GUYANE", 6, 201211},
	{"ECONODAY", 8, 201212},
	{"ZELIENOPLE", 10, 201213},
	{"VOLLENWEIDER", 12, 201214},
	{"PLDS", 4, 201215},
	{"BENIOFF", 7, 201216},
	{"YXBOOM", 6, 201217},
	{"FERMER", 6, 201218},
	{"WHEATEAR", 8, 201219},
	{"SERRATA", 7, 201220},
	{"POSTBAG", 7, 201221},
	{"ATTRVALUE", 9, 201222},
	{"VIMO", 4, 201223},
	{"VEZC", 4, 201224},
	{"UOBI", 4, 201225},
	{"UHMA", 4, 201226},
	{"UCYC", 4, 201227},
	{"UAOR", 4, 201228},
	{"TSRY", 4, 201229},
	{"SEKW", 4, 201230},
	{"SBWA", 4, 201231},
	{"OFCW", 4, 201232},
	{"NYHY", 4, 201233},
	{"MRIL", 4, 201234},
	{"MOAM", 4, 201235},
	{"LPCE", 4, 201236},
	{"LCUD", 4, 201237},
	{"LAVU", 4, 201238},
	{"KVII", 4, 201239},
	{"JIFI", 4, 201240},
	{"JIDE", 4, 201241},
	{"GSMS", 4, 201242},
	{"FKOO", 4, 201243},
	{"FELN", 4, 201244},
	{"FCMI", 4, 201245},
	{"EBJO", 4, 201246},
	{"DTDE", 4, 201247},
	{"DBCT", 4, 201248},
	{"CHND", 4, 201249},
	{"BJOE", 4, 201250},
	{"BEYF", 4, 201251},
	{"AWDY", 4, 201252},
	{"ASDJ", 4, 201253},
	{"ARBT", 4, 201254},
	{"TRANSHUMANIST", 13, 201255},
	{"SOUTHVIEW", 9, 201256},
	{"OXAZEPAM", 8, 201257},
	{"USABOUT", 7, 201258},
	{"DENYSE", 6, 201259},
	{"NEWFIELDS", 9, 201260},
	{"BOSNIANS", 8, 201261},
	{"BLEEDIN", 7, 201262},
	{"WHIPING", 7, 201263},
	{"DEADLIER", 8, 201264},
	{"PAPAGAYO", 8, 201265},
	{"WALLPAPERING", 12, 201266},
	{"BCV", 3, 201267},
	{"HAEMOLYTIC", 10, 201268},
	{"ITOYA", 5, 201269},
	{"DUIT", 4, 201270},
	{"BRUNOS", 6, 201271},
	{"BAKRI", 5, 201272},
	{"JONESBOROUGH", 12, 201273},
	{"CLEARQUEST", 10, 201274},
	{"NONPERTURBATIVE", 15, 201275},
	{"RESPONSABLES", 12, 201276},
	{"NAUHIM", 6, 201277},
	{"AMERCAN", 7, 201278},
	{"POLYVALENT", 10, 201279},
	{"LUNDSTROM", 9, 201280},
	{"LIOPA", 5, 201281},
	{"VENLO", 5, 201282},
	{"BURSLEM", 7, 201283},
	{"VARICOCELE", 10, 201284},
	{"FRIGUS", 6, 201285},
	{"MAPX", 4, 201286},
	{"FEEDREADER", 10, 201287},
	{"FARD", 4, 201288},
	{"DIEAN", 5, 201289},
	{"BLUETREK", 8, 201290},
	{"AFORA", 5, 201291},
	{"WEVER", 5, 201292},
	{"SHERILYN", 8, 201293},
	{"FORMALIZES", 10, 201294},
	{"DIMON", 5, 201295},
	{"CURCULIONIDAE", 13, 201296},
	{"NONDEGENERATE", 13, 201297},
	{"JOHNSVILLE", 10, 201298},
	{"BAILIE", 6, 201299},
	{"VACUA", 5, 201300},
	{"PRATENSIS", 9, 201301},
	{"KOGUT", 5, 201302},
	{"ICAB", 4, 201303},
	{"UTARA", 5, 201304},
	{"TORSOS", 6, 201305},
	{"SPELLBOOK", 9, 201306},
	{"EYMAN", 5, 201307},
	{"MPGE", 4, 201308},
	{"MUCOSITIS", 9, 201309},
	{"MATHBB", 6, 201310},
	{"DOEST", 5, 201311},
	{"SUBCOMPACT", 10, 201312},
	{"ROMANUS", 7, 201313},
	{"CRISFIELD", 9, 201314},
	{"CIRRHOTIC", 9, 201315},
	{"FUSIFORM", 8, 201316},
	{"CORALINE", 8, 201317},
	{"SPIEWAK", 7, 201318},
	{"PENSIONEN", 9, 201319},
	{"MULTIPLATFORMS", 14, 201320},
	{"CUPA", 4, 201321},
	{"PARENTHETICALLY", 15, 201322},
	{"KLENSIN", 7, 201323},
	{"CASINOFOXX", 10, 201324},
	{"TARKA", 5, 201325},
	{"ENINES", 6, 201326},
	{"BOUNDER", 7, 201327},
	{"RATHDRUM", 8, 201328},
	{"STDCALL", 7, 201329},
	{"UNDA", 4, 201330},
	{"REINHOLDTSEN", 12, 201331},
	{"PESSOAL", 7, 201332},
	{"NEILS", 5, 201333},
	{"VENTIMIGLIA", 11, 201334},
	{"EXPTIME", 7, 201335},
	{"SPIRT", 5, 201336},
	{"GOOM", 4, 201337},
	{"CPRE", 4, 201338},
	{"DOLLA", 5, 201339},
	{"AGOG", 4, 201340},
	{"SIDOR", 5, 201341},
	{"SUMIDA", 6, 201342},
	{"STIFFY", 6, 201343},
	{"PONTS", 5, 201344},
	{"SHARMAT", 7, 201345},
	{"MASTOID", 7, 201346},
	{"IMMUNOLOGICALLY", 15, 201347},
	{"SNOWFALLS", 9, 201348},
	{"WINDBREAKS", 10, 201349},
	{"THICKENERS", 10, 201350},
	{"WAIVERED", 8, 201351},
	{"SPAMHAUS", 8, 201352},
	{"CURTESIE", 8, 201353},
	{"ARRIGONI", 8, 201354},
	{"RECEIPTED", 9, 201355},
	{"APISTOGRAMMA", 12, 201356},
	{"WINTERSPORTS", 12, 201357},
	{"WIGGY", 5, 201358},
	{"PRONGER", 7, 201359},
	{"LAMINAAT", 8, 201360},
	{"HERZIGOVA", 9, 201361},
	{"WAITES", 6, 201362},
	{"SHMEM", 5, 201363},
	{"JUXTAPOSITIONS", 14, 201364},
	{"MILLSTREAM", 10, 201365},
	{"AUROX", 5, 201366},
	{"OVERFISHED", 10, 201367},
	{"FOGPROOF", 8, 201368},
	{"MYTHICA", 7, 201369},
	{"CHENOA", 6, 201370},
	{"KEATHLEY", 8, 201371},
	{"TARAHUMARA", 10, 201372},
	{"DAOIST", 6, 201373},
	{"PERFFORMIAD", 11, 201374},
	{"YEOMEN", 6, 201375},
	{"LOTHARIO", 8, 201376},
	{"UGU", 3, 201377},
	{"MITHRA", 6, 201378},
	{"REALAGE", 7, 201379},
	{"APPLEWHITE", 10, 201380},
	{"MORY", 4, 201381},
	{"MIMER", 5, 201382},
	{"MAAL", 4, 201383},
	{"UVP", 3, 201384},
	{"OPERATIONALIZE", 14, 201385},
	{"DHAWAN", 6, 201386},
	{"SEAGRASSES", 10, 201387},
	{"CHARYBDIS", 9, 201388},
	{"SCALAPACK", 9, 201389},
	{"TEENBOYS", 8, 201390},
	{"ANABOLICS", 9, 201391},
	{"FLETCHERS", 9, 201392},
	{"ZIPO", 4, 201393},
	{"YVOY", 4, 201394},
	{"YDRC", 4, 201395},
	{"XLIS", 4, 201396},
	{"XDON", 4, 201397},
	{"WWTR", 4, 201398},
	{"WWPR", 4, 201399},
	{"WCIS", 4, 201400},
	{"WBIN", 4, 201401},
	{"VRIS", 4, 201402},
	{"UXBE", 4, 201403},
	{"UOGR", 4, 201404},
	{"UMOM", 4, 201405},
	{"UDYK", 4, 201406},
	{"TZIL", 4, 201407},
	{"TUKT", 4, 201408},
	{"SRRE", 4, 201409},
	{"RPPL", 4, 201410},
	{"RLTC", 4, 201411},
	{"PYCU", 4, 201412},
	{"PTYG", 4, 201413},
	{"OSKU", 4, 201414},
	{"OPKN", 4, 201415},
	{"ODUD", 4, 201416},
	{"NLUP", 4, 201417},
	{"NBIP", 4, 201418},
	{"MBII", 4, 201419},
	{"LPPI", 4, 201420},
	{"LIZB", 4, 201421},
	{"JAPR", 4, 201422},
	{"GEPM", 4, 201423},
	{"EZEV", 4, 201424},
	{"EWDY", 4, 201425},
	{"EUCC", 4, 201426},
	{"DLUP", 4, 201427},
	{"CINY", 4, 201428},
	{"AOGU", 4, 201429},
	{"KCM", 3, 201430},
	{"PHOSGENE", 8, 201431},
	{"HEDSTROM", 8, 201432},
	{"GRASSROOT", 9, 201433},
	{"KANOODLE", 8, 201434},
	{"FSOCKOPEN", 9, 201435},
	{"DISTIONARY", 10, 201436},
	{"CAYUCOS", 7, 201437},
	{"AMALGAMS", 8, 201438},
	{"EVANGELOS", 9, 201439},
	{"HOWIES", 6, 201440},
	{"BUECHNER", 8, 201441},
	{"OSTEONECROSIS", 13, 201442},
	{"GELLED", 6, 201443},
	{"FAULTLINE", 9, 201444},
	{"CELLULARFACTORY", 15, 201445},
	{"STICHES", 7, 201446},
	{"FATFREE", 7, 201447},
	{"ESCWA", 5, 201448},
	{"AVEL", 4, 201449},
	{"GLYNDEBOURNE", 12, 201450},
	{"COUNTERDRUG", 11, 201451},
	{"HEMSEDAL", 8, 201452},
	{"FARUK", 5, 201453},
	{"ALTADIS", 7, 201454},
	{"SKRIVER", 7, 201455},
	{"DIELS", 5, 201456},
	{"ASIANOW", 7, 201457},
	{"AKASHI", 6, 201458},
	{"MICROIDS", 8, 201459},
	{"DISCUZ", 6, 201460},
	{"MEDIASUITE", 10, 201461},
	{"BILGI", 5, 201462},
	{"TFUG", 4, 201463},
	{"CEDES", 5, 201464},
	{"NEWSARTICLES", 12, 201465},
	{"NIGHTDRESS", 10, 201466},
	{"GAMESCIENCE", 11, 201467},
	{"CRKT", 4, 201468},
	{"TELLNO", 6, 201469},
	{"KFALSE", 6, 201470},
	{"ERECTA", 6, 201471},
	{"MCMENAMIN", 9, 201472},
	{"ADSORB", 6, 201473},
	{"RENDALL", 7, 201474},
	{"HOMEFURNISHINGS", 15, 201475},
	{"WAZIR", 5, 201476},
	{"POBLANO", 7, 201477},
	{"RESPONSIBILITES", 15, 201478},
	{"BUSSINES", 8, 201479},
	{"AZULES", 6, 201480},
	{"NEGES", 5, 201481},
	{"REINET", 6, 201482},
	{"IORD", 4, 201483},
	{"SERVLETEXCEPTION", 16, 201484},
	{"MINARIK", 7, 201485},
	{"DYSLEXICS", 9, 201486},
	{"FEFE", 4, 201487},
	{"ANONYMOUSFINDER", 15, 201488},
	{"ORIX", 4, 201489},
	{"GRAINING", 8, 201490},
	{"FILEINPUTSTREAM", 15, 201491},
	{"MACHTLFINGER", 12, 201492},
	{"UNDECORATED", 11, 201493},
	{"HABITUATED", 10, 201494},
	{"LIING", 5, 201495},
	{"DOFF", 4, 201496},
	{"ETHNOCENTRISM", 13, 201497},
	{"ROOSENDAAL", 10, 201498},
	{"ARCHIWEBHOSTING", 15, 201499},
	{"ARANJUEZ", 8, 201500},
	{"KONINKRIJK", 10, 201501},
	{"PHYTOCHROME", 11, 201502},
	{"FEDE", 4, 201503},
	{"SUPERMASSIVE", 12, 201504},
	{"PUBLICATIO", 10, 201505},
	{"ORTOVOX", 7, 201506},
	{"NEALON", 6, 201507},
	{"PORTENDS", 8, 201508},
	{"JESTS", 5, 201509},
	{"AIYAR", 5, 201510},
	{"TORGERSON", 9, 201511},
	{"LLEOLIAD", 8, 201512},
	{"BUMBLEBEES", 10, 201513},
	{"PECTS", 5, 201514},
	{"LLAVE", 5, 201515},
	{"ONLINEHELP", 10, 201516},
	{"BRANDISHED", 10, 201517},
	{"COEGA", 5, 201518},
	{"THAWS", 5, 201519},
	{"TOPPEN", 6, 201520},
	{"EBADI", 5, 201521},
	{"TILOS", 5, 201522},
	{"SLIMMEST", 8, 201523},
	{"NOGAPS", 6, 201524},
	{"MIHARA", 6, 201525},
	{"BLATTNER", 8, 201526},
	{"CGCGC", 5, 201527},
	{"GALIUM", 6, 201528},
	{"DUFFIN", 6, 201529},
	{"RAINGEAR", 8, 201530},
	{"NEPONSET", 8, 201531},
	{"KONKANI", 7, 201532},
	{"MERZBOW", 7, 201533},
	{"ETERNIA", 7, 201534},
	{"ABSCISIC", 8, 201535},
	{"LODWICK", 7, 201536},
	{"MCGILLIS", 8, 201537},
	{"KAUNAKAKAI", 10, 201538},
	{"JEREMIAS", 8, 201539},
	{"HUUUGE", 6, 201540},
	{"DOMINUM", 7, 201541},
	{"MACLAY", 6, 201542},
	{"OREJA", 5, 201543},
	{"KUFA", 4, 201544},
	{"BLOGMARKS", 9, 201545},
	{"FONTESQUE", 9, 201546},
	{"HOOLIGANISM", 11, 201547},
	{"NEENER", 6, 201548},
	{"BUSHISMS", 8, 201549},
	{"USEABILITY", 10, 201550},
	{"CURRANCY", 8, 201551},
	{"MCMARTIN", 8, 201552},
	{"JUGADORES", 9, 201553},
	{"OKUBO", 5, 201554},
	{"HAPOEL", 6, 201555},
	{"THISWEEK", 8, 201556},
	{"TARTUFFE", 8, 201557},
	{"REFERALS", 8, 201558},
	{"RAISONS", 7, 201559},
	{"NCMA", 4, 201560},
	{"MVELOPES", 8, 201561},
	{"MINDELL", 7, 201562},
	{"DEVLOPMENT", 10, 201563},
	{"BIOENGINEERED", 13, 201564},
	{"ZIOW", 4, 201565},
	{"ZESY", 4, 201566},
	{"YKAD", 4, 201567},
	{"XDEM", 4, 201568},
	{"WTVS", 4, 201569},
	{"WPOK", 4, 201570},
	{"VFOU", 4, 201571},
	{"UCYL", 4, 201572},
	{"SVSP", 4, 201573},
	{"SGED", 4, 201574},
	{"RYKS", 4, 201575},
	{"RKUB", 4, 201576},
	{"OYVE", 4, 201577},
	{"OERL", 4, 201578},
	{"OCDC", 4, 201579},
	{"NSWW", 4, 201580},
	{"NMRW", 4, 201581},
	{"NCAJ", 4, 201582},
	{"MNIL", 4, 201583},
	{"LSKR", 4, 201584},
	{"KIFU", 4, 201585},
	{"JPAT", 4, 201586},
	{"JHOU", 4, 201587},
	{"IWIF", 4, 201588},
	{"IBEV", 4, 201589},
	{"HMAW", 4, 201590},
	{"FFNU", 4, 201591},
	{"ESGY", 4, 201592},
	{"ELKC", 4, 201593},
	{"EBEJ", 4, 201594},
	{"DRMF", 4, 201595},
	{"CIEB", 4, 201596},
	{"AZAZ", 4, 201597},
	{"ATVU", 4, 201598},
	{"ANUZ", 4, 201599},
	{"ADTB", 4, 201600},
	{"EERC", 4, 201601},
	{"CONTINUOUSWAVE", 14, 201602},
	{"EXTRALIGA", 9, 201603},
	{"BELLIGERENCE", 12, 201604},
	{"ANHOLT", 6, 201605},
	{"AMARU", 5, 201606},
	{"SOMOZA", 6, 201607},
	{"CRONO", 5, 201608},
	{"ORENDA", 6, 201609},
	{"MANTELL", 7, 201610},
	{"SPLATTERS", 9, 201611},
	{"NUCHAL", 6, 201612},
	{"GOUTY", 5, 201613},
	{"LLANIDLOES", 10, 201614},
	{"DENDRIMERS", 10, 201615},
	{"BLOVIATING", 10, 201616},
	{"ALMENA", 6, 201617},
	{"ACTER", 5, 201618},
	{"ACELLULAR", 9, 201619},
	{"XTINA", 5, 201620},
	{"BERTHIER", 8, 201621},
	{"ROJAK", 5, 201622},
	{"QOTSA", 5, 201623},
	{"OXYTETRACYCLINE", 15, 201624},
	{"GATELY", 6, 201625},
	{"COLLUDE", 7, 201626},
	{"TWINED", 6, 201627},
	{"TENNESSEANS", 11, 201628},
	{"HAMMERHEADS", 11, 201629},
	{"WALSCH", 6, 201630},
	{"TOURAINE", 8, 201631},
	{"BELGICA", 7, 201632},
	{"GHARIB", 6, 201633},
	{"MULTIVALUED", 11, 201634},
	{"MILLIONTHS", 10, 201635},
	{"LOFTHOUSE", 9, 201636},
	{"HEBB", 4, 201637},
	{"DAHLQUIST", 9, 201638},
	{"COMPREND", 8, 201639},
	{"LONGIFOLIA", 10, 201640},
	{"FLAGGE", 6, 201641},
	{"APOL", 4, 201642},
	{"RAHAB", 5, 201643},
	{"HORVAT", 6, 201644},
	{"CIPKI", 5, 201645},
	{"PETTERSON", 9, 201646},
	{"RGNL", 4, 201647},
	{"REALIGNMENTS", 12, 201648},
	{"KIRRIEMUIR", 10, 201649},
	{"INVIOLABILITY", 13, 201650},
	{"EUSEBIO", 7, 201651},
	{"RESISTER", 8, 201652},
	{"BOREDOMS", 8, 201653},
	{"BLONDER", 7, 201654},
	{"SABBATS", 7, 201655},
	{"FUSO", 4, 201656},
	{"TBLS", 4, 201657},
	{"MYSTIGAYLE", 10, 201658},
	{"GARANT", 6, 201659},
	{"TUTES", 5, 201660},
	{"NEGATIV", 7, 201661},
	{"LASERMAX", 8, 201662},
	{"DIPPIN", 6, 201663},
	{"LAVI", 4, 201664},
	{"COMPOSITAE", 10, 201665},
	{"STOICS", 6, 201666},
	{"PRIVMSG", 7, 201667},
	{"YABBA", 5, 201668},
	{"EPENDYMOMA", 10, 201669},
	{"AEROSOLIZED", 11, 201670},
	{"RUTABAGA", 8, 201671},
	{"CLENDENIN", 9, 201672},
	{"BEROWRA", 7, 201673},
	{"IRETON", 6, 201674},
	{"GALAGO", 6, 201675},
	{"VASUDEVAN", 9, 201676},
	{"SALONIKA", 8, 201677},
	{"JSENG", 5, 201678},
	{"SOLDIERING", 10, 201679},
	{"KOSKINEN", 8, 201680},
	{"HADID", 5, 201681},
	{"CURWEN", 6, 201682},
	{"BITPIX", 6, 201683},
	{"NONREGULATED", 12, 201684},
	{"TVILUM", 6, 201685},
	{"SUGIURA", 7, 201686},
	{"PLUCKERDB", 9, 201687},
	{"HKMA", 4, 201688},
	{"FOSDICK", 7, 201689},
	{"CORRALLED", 9, 201690},
	{"CMHA", 4, 201691},
	{"OSULLIVAN", 9, 201692},
	{"CVBS", 4, 201693},
	{"BASCH", 5, 201694},
	{"WALKOVER", 8, 201695},
	{"TYRANNIES", 9, 201696},
	{"RIMADYL", 7, 201697},
	{"DAILYDAVE", 9, 201698},
	{"SKRIVE", 6, 201699},
	{"MALVA", 5, 201700},
	{"YATTA", 5, 201701},
	{"WHOAH", 5, 201702},
	{"ARREDONDO", 9, 201703},
	{"WINNOW", 6, 201704},
	{"SARASIN", 7, 201705},
	{"HYDRONEPHROSIS", 14, 201706},
	{"TYLDESLEY", 9, 201707},
	{"SAVERY", 6, 201708},
	{"HEMBREE", 7, 201709},
	{"TOPALOV", 7, 201710},
	{"ALSEA", 5, 201711},
	{"CNPC", 4, 201712},
	{"SANWA", 5, 201713},
	{"UNDOES", 6, 201714},
	{"PJL", 3, 201715},
	{"ENAME", 5, 201716},
	{"DRAGONLORDS", 11, 201717},
	{"NEEDLING", 8, 201718},
	{"CORBEL", 6, 201719},
	{"BRUNN", 5, 201720},
	{"ALBU", 4, 201721},
	{"SYSDATE", 7, 201722},
	{"THESPIANS", 9, 201723},
	{"TEXTY", 5, 201724},
	{"NEOSPORIN", 9, 201725},
	{"INVESTOOLS", 10, 201726},
	{"LAMPPOST", 8, 201727},
	{"VALCOM", 6, 201728},
	{"WAVEMASTER", 10, 201729},
	{"ENLOW", 5, 201730},
	{"DEODORIZING", 11, 201731},
	{"CRIMETHINC", 10, 201732},
	{"LEGENDIA", 8, 201733},
	{"JUBILATE", 8, 201734},
	{"NATUUR", 6, 201735},
	{"MIGNOTTE", 8, 201736},
	{"IBGP", 4, 201737},
	{"CROWSNEST", 9, 201738},
	{"OGUZ", 4, 201739},
	{"HOLLAR", 6, 201740},
	{"EVICTING", 8, 201741},
	{"RATTI", 5, 201742},
	{"CHRISTOFFEL", 11, 201743},
	{"EBERSOLE", 8, 201744},
	{"GREENBACKS", 10, 201745},
	{"SUNVISOR", 8, 201746},
	{"INSTIGATORS", 11, 201747},
	{"PUESTO", 6, 201748},
	{"BALCAR", 6, 201749},
	{"PREE", 4, 201750},
	{"GULBARGA", 8, 201751},
	{"VDBO", 4, 201752},
	{"TZEM", 4, 201753},
	{"SUVT", 4, 201754},
	{"SPGO", 4, 201755},
	{"SJOD", 4, 201756},
	{"SEGD", 4, 201757},
	{"RRBE", 4, 201758},
	{"RMEZ", 4, 201759},
	{"REVK", 4, 201760},
	{"RDPS", 4, 201761},
	{"RBGR", 4, 201762},
	{"POAR", 4, 201763},
	{"OPTY", 4, 201764},
	{"NYMR", 4, 201765},
	{"NGYL", 4, 201766},
	{"MGEA", 4, 201767},
	{"LPGO", 4, 201768},
	{"KKEM", 4, 201769},
	{"HYRY", 4, 201770},
	{"HYKA", 4, 201771},
	{"GOVH", 4, 201772},
	{"FUCL", 4, 201773},
	{"FELW", 4, 201774},
	{"ERFP", 4, 201775},
	{"EDPW", 4, 201776},
	{"CCDO", 4, 201777},
	{"BCIR", 4, 201778},
	{"BCFI", 4, 201779},
	{"AFMO", 4, 201780},
	{"GNER", 4, 201781},
	{"EPISTAXIS", 9, 201782},
	{"OSTEOCALCIN", 11, 201783},
	{"CANNOLI", 7, 201784},
	{"SINGAPURA", 9, 201785},
	{"GOTOH", 5, 201786},
	{"DOTCLEAR", 8, 201787},
	{"BLASCO", 6, 201788},
	{"MICROSURGICAL", 13, 201789},
	{"MAHAPRABHU", 10, 201790},
	{"CACULATOR", 9, 201791},
	{"NIEKERK", 7, 201792},
	{"EDGERRIN", 8, 201793},
	{"ATHIEST", 7, 201794},
	{"LONGSTAFF", 9, 201795},
	{"CLARIFIERS", 10, 201796},
	{"SALTERS", 7, 201797},
	{"MCTELL", 6, 201798},
	{"CANOLBARTH", 10, 201799},
	{"TRAMONTO", 8, 201800},
	{"PREMERA", 7, 201801},
	{"GOOGLEE", 7, 201802},
	{"SACROILIAC", 10, 201803},
	{"HAFF", 4, 201804},
	{"MYHRE", 5, 201805},
	{"HARRYS", 6, 201806},
	{"ARTU", 4, 201807},
	{"OLERUD", 6, 201808},
	{"INFOMEX", 7, 201809},
	{"ENDELEMENT", 10, 201810},
	{"DEOXYCYTIDINE", 13, 201811},
	{"WAKAMATSU", 9, 201812},
	{"MONTHAN", 7, 201813},
	{"ASDVS", 5, 201814},
	{"MERITUS", 7, 201815},
	{"DISASTEROUS", 11, 201816},
	{"ABRIDGING", 9, 201817},
	{"SULLIED", 7, 201818},
	{"IPCHECK", 7, 201819},
	{"ELECTROGRAPH", 12, 201820},
	{"TERCER", 6, 201821},
	{"SYZYGY", 6, 201822},
	{"DEADZONE", 8, 201823},
	{"MULK", 4, 201824},
	{"MEDICOLEGAL", 11, 201825},
	{"APLIN", 5, 201826},
	{"AVAR", 4, 201827},
	{"KUBIK", 5, 201828},
	{"CALVINISTIC", 11, 201829},
	{"DESIGNE", 7, 201830},
	{"KACHIN", 6, 201831},
	{"WELLINGTONS", 11, 201832},
	{"TYLA", 4, 201833},
	{"JOLIN", 5, 201834},
	{"HUNSAKER", 8, 201835},
	{"WHEREAMI", 8, 201836},
	{"YAXIS", 5, 201837},
	{"ELPHICK", 7, 201838},
	{"TAYYIP", 6, 201839},
	{"BEIL", 4, 201840},
	{"HUGER", 5, 201841},
	{"FLUTTERBY", 9, 201842},
	{"ANISHKA", 7, 201843},
	{"KEYPHRASES", 10, 201844},
	{"KAUF", 4, 201845},
	{"VILLAHERMOSA", 12, 201846},
	{"BONIFAY", 7, 201847},
	{"SOWK", 4, 201848},
	{"JARZABEK", 8, 201849},
	{"FEEBACK", 7, 201850},
	{"STOREIS", 7, 201851},
	{"PELIRROJAS", 10, 201852},
	{"NAHAR", 5, 201853},
	{"LUKS", 4, 201854},
	{"INCONGRUENT", 11, 201855},
	{"BUDDYS", 6, 201856},
	{"VIMY", 4, 201857},
	{"FUERST", 6, 201858},
	{"EROGENOUS", 9, 201859},
	{"MASTURBAZIONE", 13, 201860},
	{"SUENO", 5, 201861},
	{"REMAR", 5, 201862},
	{"GRAFIC", 6, 201863},
	{"ABRIDGMENT", 10, 201864},
	{"GAMELOG", 7, 201865},
	{"MATERIALIZATION", 15, 201866},
	{"HUMULIN", 7, 201867},
	{"LIFF", 4, 201868},
	{"TRASIMENO", 9, 201869},
	{"PLAR", 4, 201870},
	{"PETIOLES", 8, 201871},
	{"CYNOSURE", 8, 201872},
	{"BRISCO", 6, 201873},
	{"BLACKVILLE", 10, 201874},
	{"SUKA", 4, 201875},
	{"SMARTEAM", 8, 201876},
	{"DCTIONARY", 9, 201877},
	{"FREQUENTS", 9, 201878},
	{"ALCU", 4, 201879},
	{"SOURPUSS", 8, 201880},
	{"LLEW", 4, 201881},
	{"DCHA", 4, 201882},
	{"VANDERSLICE", 11, 201883},
	{"CHALCOPYRITE", 12, 201884},
	{"AMDAHL", 6, 201885},
	{"SIGCHI", 6, 201886},
	{"SCHAU", 5, 201887},
	{"PPARENT", 7, 201888},
	{"HITCOUNTER", 10, 201889},
	{"FAITE", 5, 201890},
	{"SEMARANG", 8, 201891},
	{"EXPANSIONISM", 12, 201892},
	{"TELEPORTED", 10, 201893},
	{"KLEI", 4, 201894},
	{"CHICAGOANS", 10, 201895},
	{"XSESSION", 8, 201896},
	{"CHWARAE", 7, 201897},
	{"ESSENE", 6, 201898},
	{"DESTINATIONKM", 13, 201899},
	{"PEVENSEY", 8, 201900},
	{"INFORMATIQUES", 13, 201901},
	{"HOFFNUNG", 8, 201902},
	{"UNPRICED", 8, 201903},
	{"FRASCA", 6, 201904},
	{"MILNGAVIE", 9, 201905},
	{"DARRON", 6, 201906},
	{"SHAREOWNER", 10, 201907},
	{"LEIPSIC", 7, 201908},
	{"ZESV", 4, 201909},
	{"WOWF", 4, 201910},
	{"SRYU", 4, 201911},
	{"SJRO", 4, 201912},
	{"PBAB", 4, 201913},
	{"OYAJ", 4, 201914},
	{"OXMU", 4, 201915},
	{"OXHU", 4, 201916},
	{"OVOY", 4, 201917},
	{"OVAV", 4, 201918},
	{"ORPV", 4, 201919},
	{"NGGW", 4, 201920},
	{"MTVW", 4, 201921},
	{"LMQU", 4, 201922},
	{"KORZ", 4, 201923},
	{"KMWH", 4, 201924},
	{"KASJ", 4, 201925},
	{"IKME", 4, 201926},
	{"GMWO", 4, 201927},
	{"FOED", 4, 201928},
	{"FIWH", 4, 201929},
	{"FDAP", 4, 201930},
	{"DSPM", 4, 201931},
	{"DLUF", 4, 201932},
	{"CLAO", 4, 201933},
	{"CIBU", 4, 201934},
	{"BUGC", 4, 201935},
	{"ANZM", 4, 201936},
	{"AKVO", 4, 201937},
	{"HORSEPLAY", 9, 201938},
	{"DANESE", 6, 201939},
	{"ABERTAY", 7, 201940},
	{"GDNF", 4, 201941},
	{"TWAYNE", 6, 201942},
	{"POYNER", 6, 201943},
	{"KALIMBA", 7, 201944},
	{"MISTREAT", 8, 201945},
	{"CONCILIAR", 9, 201946},
	{"PREXUS", 6, 201947},
	{"POOCHES", 7, 201948},
	{"BEKOMMEN", 8, 201949},
	{"GPSD", 4, 201950},
	{"BONZINI", 7, 201951},
	{"RADICCHIO", 9, 201952},
	{"LINTELS", 7, 201953},
	{"OCENA", 5, 201954},
	{"KOBO", 4, 201955},
	{"DATAMODEL", 9, 201956},
	{"NORIO", 5, 201957},
	{"MASSACHUSSETS", 13, 201958},
	{"WEIGHERS", 8, 201959},
	{"FLRS", 4, 201960},
	{"BORGWARD", 8, 201961},
	{"WAUCHULA", 8, 201962},
	{"THIAGO", 6, 201963},
	{"POVIDONE", 8, 201964},
	{"KRONK", 5, 201965},
	{"BRUTTO", 6, 201966},
	{"BLOFELD", 7, 201967},
	{"ROBICHAUX", 9, 201968},
	{"COUPEE", 6, 201969},
	{"CRNP", 4, 201970},
	{"CERTIFICATI", 11, 201971},
	{"APPERANCE", 9, 201972},
	{"NEUROTROPHIN", 12, 201973},
	{"ENGRAVEABLE", 11, 201974},
	{"BOWRIDER", 8, 201975},
	{"BOYETT", 6, 201976},
	{"EXECCGI", 7, 201977},
	{"HBEAG", 5, 201978},
	{"DOCTIONARY", 10, 201979},
	{"SEAPETS", 7, 201980},
	{"BREVETS", 7, 201981},
	{"ORISHAS", 7, 201982},
	{"KAZUKO", 6, 201983},
	{"DICTIONAYR", 10, 201984},
	{"MCCUTCHEN", 9, 201985},
	{"HOSTROCKET", 10, 201986},
	{"COMPARATIVES", 12, 201987},
	{"ARIOLA", 6, 201988},
	{"MELOXICAM", 9, 201989},
	{"KEAST", 5, 201990},
	{"VEVRIER", 7, 201991},
	{"TRENDSETTERS", 12, 201992},
	{"EVGENI", 6, 201993},
	{"AKTUALISIERTE", 13, 201994},
	{"PIRAMIDES", 9, 201995},
	{"MODIF", 5, 201996},
	{"STIFFENER", 9, 201997},
	{"RIMI", 4, 201998},
	{"ROMINA", 6, 201999},
	{"DIMARTINO", 9, 202000},
	{"DERREK", 6, 202001},
	{"COMPOSITESEQUENCE", 17, 202002},
	{"DICTINOARY", 10, 202003},
	{"SOUNDMELODY", 11, 202004},
	{"EROTIKMASSAGEN", 14, 202005},
	{"SONDERANGEBOTE", 14, 202006},
	{"EXTRAVASATION", 13, 202007},
	{"LYGON", 5, 202008},
	{"JAGFLY", 6, 202009},
	{"GRIDVIEW", 8, 202010},
	{"TWINHAN", 7, 202011},
	{"PIPAS", 5, 202012},
	{"COMBUSTED", 9, 202013},
	{"AERONOMY", 8, 202014},
	{"LEGGS", 5, 202015},
	{"FIERCER", 7, 202016},
	{"CASCA", 5, 202017},
	{"TERCERA", 7, 202018},
	{"DATALIST", 8, 202019},
	{"PAVANE", 6, 202020},
	{"DICTIONRAY", 10, 202021},
	{"BLUEJAY", 7, 202022},
	{"FLORET", 6, 202023},
	{"WILBURYS", 8, 202024},
	{"ENTREATY", 8, 202025},
	{"RAMSTAD", 7, 202026},
	{"CHENAULT", 8, 202027},
	{"MASTERPRINTS", 12, 202028},
	{"FLYPAPER", 8, 202029},
	{"DUNLIN", 6, 202030},
	{"DXL", 3, 202031},
	{"DESBOROUGH", 10, 202032},
	{"BEGLEITUNGEN", 12, 202033},
	{"OGSPI", 5, 202034},
	{"MOLEN", 5, 202035},
	{"KULDIP", 6, 202036},
	{"HEYRE", 5, 202037},
	{"UKELELE", 7, 202038},
	{"KOLOROWE", 8, 202039},
	{"ADIERESIS", 9, 202040},
	{"MEYRICK", 7, 202041},
	{"CREAKED", 7, 202042},
	{"PUBLIEZ", 7, 202043},
	{"CROSSLISTED", 11, 202044},
	{"ZLEV", 4, 202045},
	{"YKUS", 4, 202046},
	{"YEEG", 4, 202047},
	{"WPAW", 4, 202048},
	{"WKTH", 4, 202049},
	{"WDNO", 4, 202050},
	{"VIPO", 4, 202051},
	{"VIKO", 4, 202052},
	{"VIAY", 4, 202053},
	{"UXUN", 4, 202054},
	{"UUSH", 4, 202055},
	{"UJUD", 4, 202056},
	{"UBTD", 4, 202057},
	{"TZFA", 4, 202058},
	{"TUWI", 4, 202059},
	{"TRAQ", 4, 202060},
	{"SMPG", 4, 202061},
	{"RUFR", 4, 202062},
	{"RSTZ", 4, 202063},
	{"PUIN", 4, 202064},
	{"OYIM", 4, 202065},
	{"NDBW", 4, 202066},
	{"NAKL", 4, 202067},
	{"MVPF", 4, 202068},
	{"LAUL", 4, 202069},
	{"KRYT", 4, 202070},
	{"IFYV", 4, 202071},
	{"HUDL", 4, 202072},
	{"GLEX", 4, 202073},
	{"GIMU", 4, 202074},
	{"GEYF", 4, 202075},
	{"FIJU", 4, 202076},
	{"ERQB", 4, 202077},
	{"EDPB", 4, 202078},
	{"CTEQ", 4, 202079},
	{"BOHU", 4, 202080},
	{"BDIA", 4, 202081},
	{"BAUB", 4, 202082},
	{"AQUB", 4, 202083},
	{"CLINICOPATHOLOGIC", 17, 202084},
	{"VEREENIGING", 11, 202085},
	{"CCAP", 4, 202086},
	{"CLASICO", 7, 202087},
	{"IMDG", 4, 202088},
	{"ARKLOW", 6, 202089},
	{"GAMETYPE", 8, 202090},
	{"TENSAS", 6, 202091},
	{"ECRIRE", 6, 202092},
	{"RAPIDA", 6, 202093},
	{"DENSITOMETER", 12, 202094},
	{"CRANMORE", 8, 202095},
	{"IOWAN", 5, 202096},
	{"BRCA", 4, 202097},
	{"BIOMETRIKA", 10, 202098},
	{"FAUNAS", 6, 202099},
	{"COMUNALE", 8, 202100},
	{"STIEFF", 6, 202101},
	{"PHOTOSUITE", 10, 202102},
	{"MIKESELL", 8, 202103},
	{"LIBGNOMEPRINTUI", 15, 202104},
	{"SERGUEI", 7, 202105},
	{"LOOOONG", 7, 202106},
	{"EXIGO", 5, 202107},
	{"STARHAWK", 8, 202108},
	{"ELLEDGE", 7, 202109},
	{"DISCONCERTED", 12, 202110},
	{"TOHATSU", 7, 202111},
	{"CYCATA", 6, 202112},
	{"UNISTAR", 7, 202113},
	{"LETTERBOXES", 11, 202114},
	{"MANIATIS", 8, 202115},
	{"FLAVUS", 6, 202116},
	{"KATAVI", 6, 202117},
	{"IOCTLS", 6, 202118},
	{"MONSTERCOM", 10, 202119},
	{"STEENBERG", 9, 202120},
	{"CROSSWAYS", 9, 202121},
	{"ROULE", 5, 202122},
	{"PLUTONIC", 8, 202123},
	{"BACKLUND", 8, 202124},
	{"MEDINAH", 7, 202125},
	{"BROSIUS", 7, 202126},
	{"INTERPOSE", 9, 202127},
	{"BILLI", 5, 202128},
	{"SOSTEGNO", 8, 202129},
	{"PERNELL", 7, 202130},
	{"NEWSDAILY", 9, 202131},
	{"MARITIMO", 8, 202132},
	{"KYNN", 4, 202133},
	{"TUMA", 4, 202134},
	{"QUAKEWORLD", 10, 202135},
	{"LESCH", 5, 202136},
	{"MAKAR", 5, 202137},
	{"MUDDIED", 7, 202138},
	{"METHOXYCINNAMATE", 16, 202139},
	{"WEINRICH", 8, 202140},
	{"SANGUINETTI", 11, 202141},
	{"INVITEE", 7, 202142},
	{"BALKEMA", 7, 202143},
	{"ZLIN", 4, 202144},
	{"GANGLIOSIDES", 12, 202145},
	{"AKTIENKURSE", 11, 202146},
	{"SANGUINO", 8, 202147},
	{"RUFFNER", 7, 202148},
	{"NATSUKI", 7, 202149},
	{"MARDY", 5, 202150},
	{"NEVEU", 5, 202151},
	{"SPORTSWRITERS", 13, 202152},
	{"NATUS", 5, 202153},
	{"CHORTLE", 7, 202154},
	{"BROC", 4, 202155},
	{"WATLEY", 6, 202156},
	{"LUDVIG", 6, 202157},
	{"ATOMIK", 6, 202158},
	{"SULEYMAN", 8, 202159},
	{"PARLIMENT", 9, 202160},
	{"KOELKAST", 8, 202161},
	{"FAUSTINO", 8, 202162},
	{"DCITIONARY", 10, 202163},
	{"CORLETT", 7, 202164},
	{"WATERBORO", 9, 202165},
	{"TAMPING", 7, 202166},
	{"KIRT", 4, 202167},
	{"VISITINT", 8, 202168},
	{"DCAP", 4, 202169},
	{"RESIDUARY", 9, 202170},
	{"BRAUTIGAN", 9, 202171},
	{"INSTALLAZIONE", 13, 202172},
	{"IKAW", 4, 202173},
	{"FARLEIGH", 8, 202174},
	{"BIEHN", 5, 202175},
	{"BOTHY", 5, 202176},
	{"HERTOGENBOSCH", 13, 202177},
	{"RHCP", 4, 202178},
	{"TAXONOMISTS", 11, 202179},
	{"HEARKENED", 9, 202180},
	{"IVANOVIC", 8, 202181},
	{"MOURNFULLY", 10, 202182},
	{"SLIEVE", 6, 202183},
	{"INFINITIES", 10, 202184},
	{"HOPPIPOLLA", 10, 202185},
	{"EMBOLI", 6, 202186},
	{"ESPACES", 7, 202187},
	{"BURKEVILLE", 10, 202188},
	{"OFFICIALDOM", 11, 202189},
	{"SURPRIZE", 8, 202190},
	{"DIMITRY", 7, 202191},
	{"AZZOPARDI", 9, 202192},
	{"BORKOWSKI", 9, 202193},
	{"UNPUB", 5, 202194},
	{"KEROBOKAN", 9, 202195},
	{"CARAVANING", 10, 202196},
	{"ABUBAKAR", 8, 202197},
	{"SALSOUL", 7, 202198},
	{"CYANIDES", 8, 202199},
	{"LAVINE", 6, 202200},
	{"SHEPP", 5, 202201},
	{"RESTRUCTUREDTEXT", 16, 202202},
	{"DEERN", 5, 202203},
	{"DICTIONATY", 10, 202204},
	{"XPHO", 4, 202205},
	{"XIVA", 4, 202206},
	{"XAPA", 4, 202207},
	{"WTUE", 4, 202208},
	{"WGEA", 4, 202209},
	{"VIMI", 4, 202210},
	{"UYFI", 4, 202211},
	{"UJOH", 4, 202212},
	{"UBDR", 4, 202213},
	{"SROX", 4, 202214},
	{"SGIU", 4, 202215},
	{"RWEY", 4, 202216},
	{"RIKF", 4, 202217},
	{"REBH", 4, 202218},
	{"PMWO", 4, 202219},
	{"PMLI", 4, 202220},
	{"ONVP", 4, 202221},
	{"ONLB", 4, 202222},
	{"OFPG", 4, 202223},
	{"OCTL", 4, 202224},
	{"NSKL", 4, 202225},
	{"MSSK", 4, 202226},
	{"LMPH", 4, 202227},
	{"IZWE", 4, 202228},
	{"IBOV", 4, 202229},
	{"GSTJ", 4, 202230},
	{"FFKO", 4, 202231},
	{"FCBE", 4, 202232},
	{"EZUC", 4, 202233},
	{"EOKB", 4, 202234},
	{"ELYZ", 4, 202235},
	{"DMLB", 4, 202236},
	{"COZO", 4, 202237},
	{"BMSA", 4, 202238},
	{"AQAB", 4, 202239},
	{"MERCATUS", 8, 202240},
	{"INANITIES", 9, 202241},
	{"KHARE", 5, 202242},
	{"COREGUARD", 9, 202243},
	{"BURKHALTER", 10, 202244},
	{"PSEEKAAL", 8, 202245},
	{"ETHAMBUTOL", 10, 202246},
	{"EELCO", 5, 202247},
	{"TIGRFAMS", 8, 202248},
	{"MODFLOW", 7, 202249},
	{"JAWE", 4, 202250},
	{"SEDGEMOOR", 9, 202251},
	{"LERCH", 5, 202252},
	{"WYND", 4, 202253},
	{"NOLIMIT", 7, 202254},
	{"OEICS", 5, 202255},
	{"BXWIDTH", 7, 202256},
	{"PASSKEY", 7, 202257},
	{"MACSIMUM", 8, 202258},
	{"CANETTI", 7, 202259},
	{"BEEZER", 6, 202260},
	{"TENANTED", 8, 202261},
	{"METAPOST", 8, 202262},
	{"FEATUR", 6, 202263},
	{"DITCIONARY", 10, 202264},
	{"UITGEBREID", 10, 202265},
	{"KASHMAR", 7, 202266},
	{"YLIOPISTO", 9, 202267},
	{"SPLITTINGS", 10, 202268},
	{"FITTON", 6, 202269},
	{"FILMTRACKS", 10, 202270},
	{"PERFECTA", 8, 202271},
	{"PROGGY", 6, 202272},
	{"BPFK", 4, 202273},
	{"PORDENONE", 9, 202274},
	{"PRATI", 5, 202275},
	{"GUATAMALA", 9, 202276},
	{"ALOR", 4, 202277},
	{"ICHTHYOSIS", 10, 202278},
	{"DAKO", 4, 202279},
	{"HEADLOCK", 8, 202280},
	{"CHEVRONS", 8, 202281},
	{"CARPATHIA", 9, 202282},
	{"SKYLON", 6, 202283},
	{"KERCHIEF", 8, 202284},
	{"ASMUS", 5, 202285},
	{"ESSENZA", 7, 202286},
	{"SCANBIRK", 8, 202287},
	{"GCK", 3, 202288},
	{"CHUCKWAGON", 10, 202289},
	{"SECURA", 6, 202290},
	{"MARVELLOUSLY", 12, 202291},
	{"IVAL", 4, 202292},
	{"DOXOLOGY", 8, 202293},
	{"BERGEY", 6, 202294},
	{"OKAPI", 5, 202295},
	{"SHARC", 5, 202296},
	{"HYPERBOLA", 9, 202297},
	{"ALLERDINGS", 10, 202298},
	{"XOXOX", 5, 202299},
	{"XANTE", 5, 202300},
	{"ACTINFO", 7, 202301},
	{"NAVEED", 6, 202302},
	{"SAROJ", 5, 202303},
	{"REINHARDTII", 11, 202304},
	{"KFK", 3, 202305},
	{"SIMONY", 6, 202306},
	{"SHOPFRONT", 9, 202307},
	{"MACDIARMID", 10, 202308},
	{"GEDNEY", 6, 202309},
	{"DEMCO", 5, 202310},
	{"BOTAFOGO", 8, 202311},
	{"RIGATONI", 8, 202312},
	{"MODIFED", 7, 202313},
	{"APPLEDORE", 9, 202314},
	{"OMNICOM", 7, 202315},
	{"NOODLING", 8, 202316},
	{"LIBSTDCXX", 9, 202317},
	{"CHRISOOC", 8, 202318},
	{"THUROW", 6, 202319},
	{"HORTICOPIA", 10, 202320},
	{"CAMPA", 5, 202321},
	{"DARBAR", 6, 202322},
	{"PAGEMASTER", 10, 202323},
	{"KHURANA", 7, 202324},
	{"PENSATION", 9, 202325},
	{"BRYNNER", 7, 202326},
	{"MPPS", 4, 202327},
	{"POSCO", 5, 202328},
	{"MARITIMEDIGITAL", 15, 202329},
	{"DUCTIONARY", 10, 202330},
	{"SCHULENBURG", 11, 202331},
	{"KLERKSDORP", 10, 202332},
	{"COINTEGRATING", 13, 202333},
	{"ILLUMINANT", 10, 202334},
	{"CRITE", 5, 202335},
	{"ZRJ", 3, 202336},
	{"ZJB", 3, 202337},
	{"XQX", 3, 202338},
	{"XGV", 3, 202339},
	{"WZX", 3, 202340},
	{"VQQ", 3, 202341},
	{"QYZ", 3, 202342},
	{"QWY", 3, 202343},
	{"QQK", 3, 202344},
	{"PVQ", 3, 202345},
	{"PQX", 3, 202346},
	{"PKQ", 3, 202347},
	{"JYY", 3, 202348},
	{"JPZ", 3, 202349},
	{"JPQ", 3, 202350},
	{"JKZ", 3, 202351},
	{"GZX", 3, 202352},
	{"GKQ", 3, 202353},
	{"FXQ", 3, 202354},
	{"FVQ", 3, 202355},
	{"CXZ", 3, 202356},
	{"CXK", 3, 202357},
	{"CXJ", 3, 202358},
	{"HUNZIKER", 8, 202359},
	{"UNENFORCEABILITY", 16, 202360},
	{"LINDEMANS", 9, 202361},
	{"VILLON", 6, 202362},
	{"NEMEC", 5, 202363},
	{"ADAPTATEUR", 10, 202364},
	{"LUDA", 4, 202365},
	{"CRITCHFIELD", 11, 202366},
	{"KOMMISSION", 10, 202367},
	{"BETTAS", 6, 202368},
	{"SKYCITY", 7, 202369},
	{"INFUSER", 7, 202370},
	{"HELDUSTRY", 9, 202371},
	{"IMMUNOCOMPETENT", 15, 202372},
	{"DOMINATORS", 10, 202373},
	{"BAGUA", 5, 202374},
	{"JEZEBELLE", 9, 202375},
	{"WUSSES", 6, 202376},
	{"WINFRED", 7, 202377},
	{"FCCC", 4, 202378},
	{"BONOBOS", 7, 202379},
	{"SOCKFD", 6, 202380},
	{"FAIRMAN", 7, 202381},
	{"COOPERSMITH", 11, 202382},
	{"TAXIWAYS", 8, 202383},
	{"ACTORES", 7, 202384},
	{"CORBEAU", 7, 202385},
	{"MORALIZING", 10, 202386},
	{"ZCAS", 4, 202387},
	{"ZAKT", 4, 202388},
	{"XWOM", 4, 202389},
	{"XSTY", 4, 202390},
	{"XHIM", 4, 202391},
	{"WAJI", 4, 202392},
	{"VDOC", 4, 202393},
	{"VCOC", 4, 202394},
	{"UMHU", 4, 202395},
	{"UGIM", 4, 202396},
	{"UDDC", 4, 202397},
	{"TOKF", 4, 202398},
	{"TMRJ", 4, 202399},
	{"TEPY", 4, 202400},
	{"SRHP", 4, 202401},
	{"RSKH", 4, 202402},
	{"RMMY", 4, 202403},
	{"RDIJ", 4, 202404},
	{"OSYP", 4, 202405},
	{"OCYN", 4, 202406},
	{"NMIZ", 4, 202407},
	{"NIZU", 4, 202408},
	{"NGTC", 4, 202409},
	{"NARJ", 4, 202410},
	{"MOKW", 4, 202411},
	{"LKJU", 4, 202412},
	{"KWAH", 4, 202413},
	{"JALM", 4, 202414},
	{"ISRB", 4, 202415},
	{"IFGU", 4, 202416},
	{"IBNM", 4, 202417},
	{"GYUP", 4, 202418},
	{"GMPL", 4, 202419},
	{"GBAA", 4, 202420},
	{"FSIF", 4, 202421},
	{"EHRY", 4, 202422},
	{"DLHA", 4, 202423},
	{"DESZ", 4, 202424},
	{"DDFU", 4, 202425},
	{"CBSB", 4, 202426},
	{"BTSU", 4, 202427},
	{"BAHW", 4, 202428},
	{"AXAU", 4, 202429},
	{"ALKJ", 4, 202430},
	{"ADDJ", 4, 202431},
	{"ADULTERERS", 10, 202432},
	{"NILAND", 6, 202433},
	{"NETPLAN", 7, 202434},
	{"FERMENTATIONS", 13, 202435},
	{"TPWD", 4, 202436},
	{"SASCO", 5, 202437},
	{"MBW", 3, 202438},
	{"LACON", 5, 202439},
	{"EMILIANA", 8, 202440},
	{"NOETHER", 7, 202441},
	{"COURNOYER", 9, 202442},
	{"AGCY", 4, 202443},
	{"LIBAO", 5, 202444},
	{"JOHNSBURG", 9, 202445},
	{"WHITEGOODS", 10, 202446},
	{"TIMEWASTING", 11, 202447},
	{"TRIAZOLAM", 9, 202448},
	{"PHANTASMAGORIA", 14, 202449},
	{"PAPILLA", 7, 202450},
	{"SARDI", 5, 202451},
	{"RINNA", 5, 202452},
	{"REORGANISE", 10, 202453},
	{"ORDERLINESS", 11, 202454},
	{"SOFORTKONTAKT", 13, 202455},
	{"PARODIED", 8, 202456},
	{"ENAMORADOS", 10, 202457},
	{"OLAZABAL", 8, 202458},
	{"FRESE", 5, 202459},
	{"KUMBIA", 6, 202460},
	{"LAUFHAUS", 8, 202461},
	{"MARIELLE", 8, 202462},
	{"FIDEI", 5, 202463},
	{"CONTEM", 6, 202464},
	{"RPB", 3, 202465},
	{"SLURPEE", 7, 202466},
	{"QUADRILATERALS", 14, 202467},
	{"DWEEB", 5, 202468},
	{"AFTERTHOUGHTS", 13, 202469},
	{"ESTRATEGIA", 10, 202470},
	{"PROVIA", 6, 202471},
	{"VIMPELCOM", 9, 202472},
	{"HARRYPOTTER", 11, 202473},
	{"GLUTINOUS", 9, 202474},
	{"ECHANGE", 7, 202475},
	{"SPBA", 4, 202476},
	{"OLIGOTROPHIC", 12, 202477},
	{"BASETYPE", 8, 202478},
	{"ALKOXY", 6, 202479},
	{"CACHERS", 7, 202480},
	{"QUICKBUY", 8, 202481},
	{"HANAFI", 6, 202482},
	{"CEDIT", 5, 202483},
	{"PRETEXTS", 8, 202484},
	{"SCHEEL", 6, 202485},
	{"NARROWCAST", 10, 202486},
	{"GEUN", 4, 202487},
	{"RECOLLECTING", 12, 202488},
	{"GULA", 4, 202489},
	{"MANVEL", 6, 202490},
	{"BOULANGERIE", 11, 202491},
	{"TBIRD", 5, 202492},
	{"RAOUF", 5, 202493},
	{"SHUPE", 5, 202494},
	{"FOOKS", 5, 202495},
	{"COTOPAXI", 8, 202496},
	{"UNDERLING", 9, 202497},
	{"FREICLUB", 8, 202498},
	{"SAVIDGE", 7, 202499},
	{"KWIC", 4, 202500},
	{"BRASHARES", 9, 202501},
	{"MACDONELL", 9, 202502},
	{"TOMISLAV", 8, 202503},
	{"BIFFY", 5, 202504},
	{"OMDAT", 5, 202505},
	{"TIMPSON", 7, 202506},
	{"LENTEK", 6, 202507},
	{"QUIROGA", 7, 202508},
	{"ELIANA", 6, 202509},
	{"TABULAS", 7, 202510},
	{"SREENIVASAN", 11, 202511},
	{"MORPORK", 7, 202512},
	{"BORNS", 5, 202513},
	{"VIREX", 5, 202514},
	{"TRUSSELL", 8, 202515},
	{"MUSUME", 6, 202516},
	{"DICRIONARY", 10, 202517},
	{"DATAWINDOW", 10, 202518},
	{"SLINT", 5, 202519},
	{"COMISIWN", 8, 202520},
	{"ATEXIT", 6, 202521},
	{"PINCKNEYVILLE", 13, 202522},
	{"DICTIOMARY", 10, 202523},
	{"FESSLER", 7, 202524},
	{"RAMACHANDRA", 11, 202525},
	{"ITEMSETS", 8, 202526},
	{"BOSTIK", 6, 202527},
	{"TOOLMAKERS", 10, 202528},
	{"JEMAND", 6, 202529},
	{"CFLS", 4, 202530},
	{"FERLAND", 7, 202531},
	{"BEMBRIDGE", 9, 202532},
	{"ULEMA", 5, 202533},
	{"SUPERMARINE", 11, 202534},
	{"RADIODURANS", 11, 202535},
	{"VOICEFINDER", 11, 202536},
	{"POLICIA", 7, 202537},
	{"BOOBLE", 6, 202538},
	{"SEMINAIRE", 9, 202539},
	{"WATLINGTON", 10, 202540},
	{"EZYDVD", 6, 202541},
	{"COMICO", 6, 202542},
	{"DWEEZIL", 7, 202543},
	{"DLPE", 4, 202544},
	{"DARYLE", 6, 202545},
	{"MONEYLINE", 9, 202546},
	{"PRESIDER", 8, 202547},
	{"DOWNSET", 7, 202548},
	{"KARUPS", 6, 202549},
	{"IVRY", 4, 202550},
	{"COOLSTREAMS", 11, 202551},
	{"RABIA", 5, 202552},
	{"LITTERMATES", 11, 202553},
	{"CALAME", 6, 202554},
	{"FRYPAN", 6, 202555},
	{"TWITCHELL", 9, 202556},
	{"TORPOINT", 8, 202557},
	{"DICUSSION", 9, 202558},
	{"WPR", 3, 202559},
	{"PUNJA", 5, 202560},
	{"GRECH", 5, 202561},
	{"DICTIONART", 10, 202562},
	{"CUADRA", 6, 202563},
	{"CITEL", 5, 202564},
	{"MINDERSTHOUGHTFULNESS", 21, 202565},
	{"CLOSTER", 7, 202566},
	{"KVAPIL", 6, 202567},
	{"ZOGB", 4, 202568},
	{"ZMAI", 4, 202569},
	{"ZECE", 4, 202570},
	{"ZANB", 4, 202571},
	{"ZALB", 4, 202572},
	{"WWFS", 4, 202573},
	{"VOYH", 4, 202574},
	{"UENF", 4, 202575},
	{"TZOL", 4, 202576},
	{"TZBR", 4, 202577},
	{"TGIM", 4, 202578},
	{"SWWE", 4, 202579},
	{"SAPB", 4, 202580},
	{"SAKL", 4, 202581},
	{"RPFR", 4, 202582},
	{"ROHD", 4, 202583},
	{"OYJA", 4, 202584},
	{"OVOV", 4, 202585},
	{"NXWH", 4, 202586},
	{"NRUH", 4, 202587},
	{"NRBU", 4, 202588},
	{"NBOK", 4, 202589},
	{"MNBU", 4, 202590},
	{"LUMG", 4, 202591},
	{"KUNF", 4, 202592},
	{"JMEG", 4, 202593},
	{"FUPR", 4, 202594},
	{"FSKO", 4, 202595},
	{"FPIK", 4, 202596},
	{"EMLU", 4, 202597},
	{"EFOB", 4, 202598},
	{"EDPN", 4, 202599},
	{"DPFI", 4, 202600},
	{"DIXS", 4, 202601},
	{"CFTH", 4, 202602},
	{"BAHF", 4, 202603},
	{"AVKL", 4, 202604},
	{"AVIZ", 4, 202605},
	{"ASGY", 4, 202606},
	{"AMNB", 4, 202607},
	{"BIBTOOL", 7, 202608},
	{"TRADUCTORES", 11, 202609},
	{"NICAEA", 6, 202610},
	{"GIAPPONESE", 10, 202611},
	{"CHESWICK", 8, 202612},
	{"MADLAX", 6, 202613},
	{"EQUINOXES", 9, 202614},
	{"STITCHERS", 9, 202615},
	{"PTCL", 4, 202616},
	{"LEONEAN", 7, 202617},
	{"RICETTA", 7, 202618},
	{"EDUSHAPE", 8, 202619},
	{"PRIMITIVISM", 11, 202620},
	{"MAIJA", 5, 202621},
	{"STRANGFORD", 10, 202622},
	{"SETOOLS", 7, 202623},
	{"BASFORD", 7, 202624},
	{"GESHE", 5, 202625},
	{"MORGAINE", 8, 202626},
	{"NOVIS", 5, 202627},
	{"MODANO", 6, 202628},
	{"LOHENGRIN", 9, 202629},
	{"GREENSVILLE", 11, 202630},
	{"BROER", 5, 202631},
	{"WAVELL", 6, 202632},
	{"MORRISS", 7, 202633},
	{"HORAK", 5, 202634},
	{"PELIAN", 6, 202635},
	{"ETHANOLAMINE", 12, 202636},
	{"BICH", 4, 202637},
	{"VOICECHAT", 9, 202638},
	{"MATTILA", 7, 202639},
	{"HUSTLA", 6, 202640},
	{"TIJERAS", 7, 202641},
	{"HACERLO", 7, 202642},
	{"CHARO", 5, 202643},
	{"AUTOCORRECT", 11, 202644},
	{"KNIVE", 5, 202645},
	{"CHATEAUBRIAND", 13, 202646},
	{"TAPENADE", 8, 202647},
	{"APCC", 4, 202648},
	{"QONG", 4, 202649},
	{"HUNDREDWEIGHT", 13, 202650},
	{"DISHWARE", 8, 202651},
	{"FIRELANDS", 9, 202652},
	{"TESUQUE", 7, 202653},
	{"RBOCS", 5, 202654},
	{"OTDR", 4, 202655},
	{"NIENHUYS", 8, 202656},
	{"DICTIONARU", 10, 202657},
	{"RSCG", 4, 202658},
	{"CELEBRITES", 10, 202659},
	{"ZUPAN", 5, 202660},
	{"WUCH", 4, 202661},
	{"BUECHE", 6, 202662},
	{"MESSAGERIE", 10, 202663},
	{"HYPHENATE", 9, 202664},
	{"GLENBURN", 8, 202665},
	{"PLAAT", 5, 202666},
	{"MAGNAT", 6, 202667},
	{"TETEVEN", 7, 202668},
	{"INDRI", 5, 202669},
	{"TITBIT", 6, 202670},
	{"SNOOZER", 7, 202671},
	{"ADIPONECTIN", 11, 202672},
	{"TUMORIGENIC", 11, 202673},
	{"DISCONT", 7, 202674},
	{"OTARU", 5, 202675},
	{"DISBARMENT", 10, 202676},
	{"DEVAULT", 7, 202677},
	{"HORSTMANN", 9, 202678},
	{"ULTRASHORT", 10, 202679},
	{"SEVERITIES", 10, 202680},
	{"DIRNE", 5, 202681},
	{"MEYEROWITZ", 10, 202682},
	{"CHEATSHEET", 10, 202683},
	{"CAMCO", 5, 202684},
	{"YOSHIKI", 7, 202685},
	{"KDEACCESSIBILITY", 16, 202686},
	{"SPIAGGE", 7, 202687},
	{"SOBERED", 7, 202688},
	{"CARILLO", 7, 202689},
	{"KIJK", 4, 202690},
	{"DELAGE", 6, 202691},
	{"CHINUA", 6, 202692},
	{"BURIN", 5, 202693},
	{"DUNKED", 6, 202694},
	{"JITENDRA", 8, 202695},
	{"GVANROSSUM", 10, 202696},
	{"BREDERLOW", 9, 202697},
	{"ALLSHIPS", 8, 202698},
	{"DVDENGINE", 9, 202699},
	{"DICYIONARY", 10, 202700},
	{"WITHT", 5, 202701},
	{"LETWIN", 6, 202702},
	{"DAVROS", 6, 202703},
	{"IDCTIONARY", 10, 202704},
	{"CYPHESIS", 8, 202705},
	{"ZIPWHAA", 7, 202706},
	{"SUMERIANS", 9, 202707},
	{"KALEIDOSCOPES", 13, 202708},
	{"VOLUTION", 8, 202709},
	{"TIRANE", 6, 202710},
	{"MAYBOLE", 7, 202711},
	{"GARROW", 6, 202712},
	{"OVEREMPHASIZED", 14, 202713},
	{"ANTENNAL", 8, 202714},
	{"TERESITA", 8, 202715},
	{"ANUJ", 4, 202716},
	{"NICASIO", 7, 202717},
	{"DIXTIONARY", 10, 202718},
	{"CAUVERY", 7, 202719},
	{"RIMU", 4, 202720},
	{"BIOHAZARDOUS", 12, 202721},
	{"JAVARANCH", 9, 202722},
	{"EXODIA", 6, 202723},
	{"DICTIONSRY", 10, 202724},
	{"RETHOUGHT", 9, 202725},
	{"HURENTREFF", 10, 202726},
	{"NRCC", 4, 202727},
	{"COSTIGAN", 8, 202728},
	{"MINTING", 7, 202729},
	{"FOURNIR", 7, 202730},
	{"SIDGWICK", 8, 202731},
	{"DIVTIONARY", 10, 202732},
	{"TOMARROW", 8, 202733},
	{"KARORI", 6, 202734},
	{"COIFFURE", 8, 202735},
	{"PANTHENOL", 9, 202736},
	{"BRASSARD", 8, 202737},
	{"XYLELLA", 7, 202738},
	{"VISIBROKER", 10, 202739},
	{"HANDCUT", 7, 202740},
	{"THEOPHILE", 9, 202741},
	{"ACHAIA", 6, 202742},
	{"OPERATIONALIZED", 15, 202743},
	{"NIBLEY", 6, 202744},
	{"HHDEERNS", 8, 202745},
	{"ACCENTUATING", 12, 202746},
	{"NTOHL", 5, 202747},
	{"ISLAMIYAH", 9, 202748},
	{"SQUIDGUARD", 10, 202749},
	{"SHIRAZI", 7, 202750},
	{"SCINCE", 6, 202751},
	{"SEDOL", 5, 202752},
	{"RETAINAGE", 9, 202753},
	{"INSTALLCHECK", 12, 202754},
	{"DICTIINARY", 10, 202755},
	{"YMNT", 4, 202756},
	{"XADA", 4, 202757},
	{"WLHE", 4, 202758},
	{"VARB", 4, 202759},
	{"UNNP", 4, 202760},
	{"ULFD", 4, 202761},
	{"TYNW", 4, 202762},
	{"SBEQ", 4, 202763},
	{"RYAQ", 4, 202764},
	{"RURS", 4, 202765},
	{"RRHU", 4, 202766},
	{"RPWE", 4, 202767},
	{"PEOL", 4, 202768},
	{"PDAD", 4, 202769},
	{"PBIN", 4, 202770},
	{"OJEL", 4, 202771},
	{"NCNB", 4, 202772},
	{"MNUT", 4, 202773},
	{"LIXJ", 4, 202774},
	{"LEZR", 4, 202775},
	{"LEHW", 4, 202776},
	{"KROV", 4, 202777},
	{"HYNC", 4, 202778},
	{"HGOB", 4, 202779},
	{"GOPV", 4, 202780},
	{"FHUE", 4, 202781},
	{"EPUY", 4, 202782},
	{"EGVI", 4, 202783},
	{"EDKS", 4, 202784},
	{"CDCI", 4, 202785},
	{"BNOV", 4, 202786},
	{"AYZI", 4, 202787},
	{"AUSJ", 4, 202788},
	{"ARNJ", 4, 202789},
	{"ABLV", 4, 202790},
	{"AAUC", 4, 202791},
	{"MARCLE", 6, 202792},
	{"MAHY", 4, 202793},
	{"SHANKLAND", 9, 202794},
	{"JABIR", 5, 202795},
	{"VENTLESS", 8, 202796},
	{"RDOC", 4, 202797},
	{"PRIVATA", 7, 202798},
	{"LARNER", 6, 202799},
	{"MICROTOWER", 10, 202800},
	{"HYPERCAM", 8, 202801},
	{"ZOCALO", 6, 202802},
	{"JENNE", 5, 202803},
	{"APPRECIATIONS", 13, 202804},
	{"HOVNANIAN", 9, 202805},
	{"FORASMUCH", 9, 202806},
	{"USBR", 4, 202807},
	{"OUID", 4, 202808},
	{"AVONMORE", 8, 202809},
	{"WARMONGERS", 10, 202810},
	{"KNIGHTHAWKS", 11, 202811},
	{"NUTTENSUCHE", 11, 202812},
	{"LINIMON", 7, 202813},
	{"SWITCHBACKS", 11, 202814},
	{"PEMCO", 5, 202815},
	{"ELLON", 5, 202816},
	{"YWARE", 5, 202817},
	{"RPBA", 4, 202818},
	{"DICTIONAEY", 10, 202819},
	{"MONOSACCHARIDE", 14, 202820},
	{"DICTIPNARY", 10, 202821},
	{"RESEIDENTIAL", 12, 202822},
	{"MUNSHI", 6, 202823},
	{"LIGE", 4, 202824},
	{"BISC", 4, 202825},
	{"GRUSIN", 6, 202826},
	{"KANEDA", 6, 202827},
	{"DICTIOBARY", 10, 202828},
	{"BEATO", 5, 202829},
	{"WINDTALKERS", 11, 202830},
	{"NEUROPSYCHOPHARMACOLOGY", 23, 202831},
	{"DIFTIONARY", 10, 202832},
	{"ISCED", 5, 202833},
	{"TOLLEFSON", 9, 202834},
	{"DICTIONZRY", 10, 202835},
	{"DICFIONARY", 10, 202836},
	{"BRASSEY", 7, 202837},
	{"FERROELECTRICS", 14, 202838},
	{"ALIMENT", 7, 202839},
	{"VACCUUM", 7, 202840},
	{"SHEETZ", 6, 202841},
	{"HISPANAS", 8, 202842},
	{"HTONL", 5, 202843},
	{"DKCTIONARY", 10, 202844},
	{"DICTIONAFY", 10, 202845},
	{"PHENTERMINES", 12, 202846},
	{"RAPHY", 5, 202847},
	{"TOKAY", 5, 202848},
	{"SHELLHARBOUR", 12, 202849},
	{"GGV", 3, 202850},
	{"GEOSTATISTICS", 13, 202851},
	{"EUPATORIUM", 10, 202852},
	{"DICTIONWRY", 10, 202853},
	{"TACHWEDD", 8, 202854},
	{"DICTIONQRY", 10, 202855},
	{"SERAFINI", 8, 202856},
	{"GEOMEDIA", 8, 202857},
	{"DICTIOHARY", 10, 202858},
	{"SUPIMA", 6, 202859},
	{"PRIMAFORCE", 10, 202860},
	{"DICTIOJARY", 10, 202861},
	{"XICTIONARY", 10, 202862},
	{"DICTILNARY", 10, 202863},
	{"INSTATED", 8, 202864},
	{"EICTIONARY", 10, 202865},
	{"DEWA", 4, 202866},
	{"GEOSAFARI", 9, 202867},
	{"SATCHER", 7, 202868},
	{"DICTIONARH", 10, 202869},
	{"MUNKY", 5, 202870},
	{"EBUILDER", 8, 202871},
	{"SPINDLY", 7, 202872},
	{"DICTIONARG", 10, 202873},
	{"SHIGEO", 6, 202874},
	{"SCARCER", 7, 202875},
	{"MOETEN", 6, 202876},
	{"IMPORTANTI", 10, 202877},
	{"CODESMITH", 9, 202878},
	{"MATRIARCHAL", 11, 202879},
	{"VLB", 3, 202880},
	{"RATAN", 5, 202881},
	{"DENTI", 5, 202882},
	{"PUPILLARY", 9, 202883},
	{"DJCTIONARY", 10, 202884},
	{"RAKSHA", 6, 202885},
	{"MISSTATED", 9, 202886},
	{"INDEPENDENCIA", 13, 202887},
	{"ETHOXY", 6, 202888},
	{"SLEUTHKIT", 9, 202889},
	{"DICTIKNARY", 10, 202890},
	{"JEFFERSONS", 10, 202891},
	{"YACHTMASTER", 11, 202892},
	{"JUUL", 4, 202893},
	{"IGBY", 4, 202894},
	{"COMON", 5, 202895},
	{"PAVIMENTI", 9, 202896},
	{"OVERWATER", 9, 202897},
	{"MECC", 4, 202898},
	{"FAULDS", 6, 202899},
	{"BLOGSGALLERY", 12, 202900},
	{"MOCHIZUKI", 9, 202901},
	{"SAUNACLUBS", 10, 202902},
	{"GAVOTTE", 7, 202903},
	{"COURANTE", 8, 202904},
	{"FORI", 4, 202905},
	{"MAZINGER", 8, 202906},
	{"SNORES", 6, 202907},
	{"DEUTERATED", 10, 202908},
	{"NORDAMERIKA", 11, 202909},
	{"MAMOU", 5, 202910},
	{"JVMS", 4, 202911},
	{"GRAVIDA", 7, 202912},
	{"RADOM", 5, 202913},
	{"NAKAZAWA", 8, 202914},
	{"MEANDERED", 9, 202915},
	{"EASERVER", 8, 202916},
	{"RECAPTURES", 10, 202917},
	{"LOFTING", 7, 202918},
	{"UFINDUS", 7, 202919},
	{"SPREADED", 8, 202920},
	{"AMBASSADORIAL", 13, 202921},
	{"LIVIU", 5, 202922},
	{"HEVEA", 5, 202923},
	{"SALIR", 5, 202924},
	{"BLOCKX", 6, 202925},
	{"BESTSTAR", 8, 202926},
	{"PENETRATIVE", 11, 202927},
	{"HIGHGROVE", 9, 202928},
	{"DIRECTNIC", 9, 202929},
	{"LCLT", 4, 202930},
	{"ECONOMI", 7, 202931},
	{"BINARYCLOUD", 11, 202932},
	{"KIRIL", 5, 202933},
	{"SPOSA", 5, 202934},
	{"PAPAYAS", 7, 202935},
	{"GAGHAN", 6, 202936},
	{"YKOO", 4, 202937},
	{"XGLO", 4, 202938},
	{"WOIR", 4, 202939},
	{"WCAD", 4, 202940},
	{"VMIS", 4, 202941},
	{"VIVU", 4, 202942},
	{"TIFK", 4, 202943},
	{"TDPR", 4, 202944},
	{"RYUH", 4, 202945},
	{"RPFU", 4, 202946},
	{"RDZO", 4, 202947},
	{"RDHY", 4, 202948},
	{"PTVA", 4, 202949},
	{"PMIX", 4, 202950},
	{"PLCT", 4, 202951},
	{"OXVA", 4, 202952},
	{"ORFP", 4, 202953},
	{"OGPU", 4, 202954},
	{"NDTF", 4, 202955},
	{"NDJB", 4, 202956},
	{"MNUN", 4, 202957},
	{"LSTG", 4, 202958},
	{"LCAJ", 4, 202959},
	{"KHBA", 4, 202960},
	{"KGBO", 4, 202961},
	{"HUAJ", 4, 202962},
	{"GUMW", 4, 202963},
	{"GOTQ", 4, 202964},
	{"FIVO", 4, 202965},
	{"FBYN", 4, 202966},
	{"EDGN", 4, 202967},
	{"DRVA", 4, 202968},
	{"DMTO", 4, 202969},
	{"DLOK", 4, 202970},
	{"DDOJ", 4, 202971},
	{"CLYW", 4, 202972},
	{"CLIU", 4, 202973},
	{"BSEP", 4, 202974},
	{"BDRE", 4, 202975},
	{"BBMA", 4, 202976},
	{"AULZ", 4, 202977},
	{"MYARRAY", 7, 202978},
	{"CAPRICES", 8, 202979},
	{"GUILDHOUSE", 10, 202980},
	{"TARIN", 5, 202981},
	{"ACHATS", 6, 202982},
	{"SNAILMAIL", 9, 202983},
	{"NPRI", 4, 202984},
	{"SEIFER", 6, 202985},
	{"RADIONAVIGATION", 15, 202986},
	{"MORHAIM", 7, 202987},
	{"LCBO", 4, 202988},
	{"KURRAJONG", 9, 202989},
	{"KEFIR", 5, 202990},
	{"SABMILLER", 9, 202991},
	{"KURIYAMA", 8, 202992},
	{"KEDRON", 6, 202993},
	{"CROLL", 5, 202994},
	{"LEAKPROOF", 9, 202995},
	{"COMMAUNDE", 9, 202996},
	{"TANDRIDGE", 9, 202997},
	{"SECONDMENTS", 11, 202998},
	{"NINJUTSU", 8, 202999},
	{"KONVERSATION", 12, 203000},
	{"TUCAN", 5, 203001},
	{"MENNINGER", 9, 203002},
	{"AUNZ", 4, 203003},
	{"WADHAM", 6, 203004},
	{"GAMESHOW", 8, 203005},
	{"STUDEN", 6, 203006},
	{"INUVIALUIT", 10, 203007},
	{"CRYOR", 5, 203008},
	{"BETATRON", 8, 203009},
	{"COSENTINO", 9, 203010},
	{"SUGAWARA", 8, 203011},
	{"THEYD", 5, 203012},
	{"ARLIE", 5, 203013},
	{"MASTI", 5, 203014},
	{"WIDOM", 5, 203015},
	{"PAGELS", 6, 203016},
	{"AFRIKAN", 7, 203017},
	{"REPRISING", 9, 203018},
	{"LALLA", 5, 203019},
	{"HINER", 5, 203020},
	{"CARTILAGINOUS", 13, 203021},
	{"QUESTER", 7, 203022},
	{"MORRISONVILLE", 13, 203023},
	{"BLOOGZ", 6, 203024},
	{"SUPPLANTING", 11, 203025},
	{"LAUFEN", 6, 203026},
	{"INTVALUE", 8, 203027},
	{"BLOCKADED", 9, 203028},
	{"DELAVAL", 7, 203029},
	{"FLORINAL", 8, 203030},
	{"ANGEZEIGT", 9, 203031},
	{"NOUGHTS", 7, 203032},
	{"SIUM", 4, 203033},
	{"MANSHIP", 7, 203034},
	{"ARKENSTONE", 10, 203035},
	{"PFLP", 4, 203036},
	{"OPRIMA", 6, 203037},
	{"GRADOS", 6, 203038},
	{"FUTRELL", 7, 203039},
	{"ULLAH", 5, 203040},
	{"MANOEL", 6, 203041},
	{"MAGALLON", 8, 203042},
	{"DEVEDGE", 7, 203043},
	{"EDELNUTTE", 9, 203044},
	{"DOVICO", 6, 203045},
	{"IGNOMINY", 8, 203046},
	{"BECUZ", 5, 203047},
	{"UNITER", 6, 203048},
	{"ODOURLESS", 9, 203049},
	{"DEFECATE", 8, 203050},
	{"TEMPESTS", 8, 203051},
	{"SRAND", 5, 203052},
	{"BRUNICO", 7, 203053},
	{"SCYTHIA", 7, 203054},
	{"ARRIVO", 6, 203055},
	{"VINDO", 5, 203056},
	{"DETERMIN", 8, 203057},
	{"STAIGER", 7, 203058},
	{"CLICKHERE", 9, 203059},
	{"BEAVERDAM", 9, 203060},
	{"SHEEK", 5, 203061},
	{"HALSE", 5, 203062},
	{"MACVISION", 9, 203063},
	{"RECRIMINATIONS", 14, 203064},
	{"FRAUDSTER", 9, 203065},
	{"OLIM", 4, 203066},
	{"GOOGILE", 7, 203067},
	{"VORSPIEL", 8, 203068},
	{"NOCARDIA", 8, 203069},
	{"ONYXIA", 6, 203070},
	{"LINKCHECKER", 11, 203071},
	{"GEEFT", 5, 203072},
	{"PIRU", 4, 203073},
	{"DISMALLY", 8, 203074},
	{"CHROMATOGRAMS", 13, 203075},
	{"UNJUSTIFIABLY", 13, 203076},
	{"MODDD", 5, 203077},
	{"INSINUATIONS", 12, 203078},
	{"PARVIN", 6, 203079},
	{"RELIG", 5, 203080},
	{"ALDERTON", 8, 203081},
	{"SUBOBJECT", 9, 203082},
	{"PAWLAK", 6, 203083},
	{"DEVAL", 5, 203084},
	{"MOVB", 4, 203085},
	{"MINORI", 6, 203086},
	{"OLESTRA", 7, 203087},
	{"VICTIONARY", 10, 203088},
	{"PRIVATIZATIONS", 14, 203089},
	{"KIRKS", 5, 203090},
	{"SEARCHSTORAGE", 13, 203091},
	{"POSTBOX", 7, 203092},
	{"NEUHAUSER", 9, 203093},
	{"PALESTINA", 9, 203094},
	{"BLACKPOWDER", 11, 203095},
	{"ACESSAR", 7, 203096},
	{"ABSQUE", 6, 203097},
	{"DEFL", 4, 203098},
	{"SMITING", 7, 203099},
	{"KEISTER", 7, 203100},
	{"OPENSUBSCRIBER", 14, 203101},
	{"CLER", 4, 203102},
	{"ASTRUD", 6, 203103},
	{"XERS", 4, 203104},
	{"VLOEREN", 7, 203105},
	{"FRIGO", 5, 203106},
	{"COSMODROME", 10, 203107},
	{"POURER", 6, 203108},
	{"EUROSYSTEM", 10, 203109},
	{"BLIS", 4, 203110},
	{"ENDWELL", 7, 203111},
	{"SFAX", 4, 203112},
	{"ZIAW", 4, 203113},
	{"YIDB", 4, 203114},
	{"YHUE", 4, 203115},
	{"VASY", 4, 203116},
	{"UNUT", 4, 203117},
	{"TUOB", 4, 203118},
	{"SXPA", 4, 203119},
	{"SNDC", 4, 203120},
	{"SAPF", 4, 203121},
	{"RPAF", 4, 203122},
	{"ROTD", 4, 203123},
	{"RCSS", 4, 203124},
	{"PMRO", 4, 203125},
	{"OXSL", 4, 203126},
	{"KEEJ", 4, 203127},
	{"JIKO", 4, 203128},
	{"JIDO", 4, 203129},
	{"JEMM", 4, 203130},
	{"ITVC", 4, 203131},
	{"IBUP", 4, 203132},
	{"HZBA", 4, 203133},
	{"HBIP", 4, 203134},
	{"FABN", 4, 203135},
	{"EQUB", 4, 203136},
	{"DTVW", 4, 203137},
	{"DONX", 4, 203138},
	{"DIRM", 4, 203139},
	{"DHPK", 4, 203140},
	{"DFTL", 4, 203141},
	{"COOV", 4, 203142},
	{"CEGH", 4, 203143},
	{"AUEF", 4, 203144},
	{"PATROCLUS", 9, 203145},
	{"NORQUAY", 7, 203146},
	{"NISKU", 5, 203147},
	{"EDGECLIFF", 9, 203148},
	{"DWAIN", 5, 203149},
	{"XIAXUE", 6, 203150},
	{"SAYFA", 5, 203151},
	{"NONMETAL", 8, 203152},
	{"MAGALUF", 7, 203153},
	{"HELMOND", 7, 203154},
	{"FAISANT", 7, 203155},
	{"CADELL", 6, 203156},
	{"STRINGENTLY", 11, 203157},
	{"TUNINGSTRUCT", 12, 203158},
	{"ECTODERMAL", 10, 203159},
	{"SHAREMARKET", 11, 203160},
	{"CARWS", 5, 203161},
	{"EUROPYTHON", 10, 203162},
	{"ARTEMISININ", 11, 203163},
	{"EVART", 5, 203164},
	{"DEMIGODS", 8, 203165},
	{"POSTCONDITIONS", 14, 203166},
	{"SIPPER", 6, 203167},
	{"MYK", 3, 203168},
	{"MAJEED", 6, 203169},
	{"LANGELLA", 8, 203170},
	{"STCW", 4, 203171},
	{"BRANSFORD", 9, 203172},
	{"SUBNETWORKS", 11, 203173},
	{"STARY", 5, 203174},
	{"CRONJE", 6, 203175},
	{"FEDERALS", 8, 203176},
	{"LAAM", 4, 203177},
	{"ASIAXPAT", 8, 203178},
	{"WAUTOMA", 7, 203179},
	{"CLEITE", 6, 203180},
	{"HALEVI", 6, 203181},
	{"KRUMM", 5, 203182},
	{"CORNSILK", 8, 203183},
	{"SOLVABILITY", 11, 203184},
	{"YPBIND", 6, 203185},
	{"XENOGEARS", 9, 203186},
	{"VIBRANCE", 8, 203187},
	{"CONTRAIL", 8, 203188},
	{"CENAR", 5, 203189},
	{"THEWLIS", 7, 203190},
	{"PERRETT", 7, 203191},
	{"PAAL", 4, 203192},
	{"BRASILEIRINHAS", 14, 203193},
	{"YAVIN", 5, 203194},
	{"RITTS", 5, 203195},
	{"HAPSBURG", 8, 203196},
	{"SICTIONARY", 10, 203197},
	{"FFOORR", 6, 203198},
	{"LITEIOFFER", 10, 203199},
	{"LEASURE", 7, 203200},
	{"SUPERFICIALITY", 14, 203201},
	{"RAJAPAKSE", 9, 203202},
	{"BEVOR", 5, 203203},
	{"ZEITEN", 6, 203204},
	{"PERICOM", 7, 203205},
	{"VERITEST", 8, 203206},
	{"POOLESVILLE", 11, 203207},
	{"DOWNLAND", 8, 203208},
	{"SPOTLESSLY", 10, 203209},
	{"LJMCNIVE", 8, 203210},
	{"LLANBERIS", 9, 203211},
	{"CMAC", 4, 203212},
	{"MACRONUCLEAR", 12, 203213},
	{"IMMOBILISATION", 14, 203214},
	{"CMIS", 4, 203215},
	{"DURACAO", 7, 203216},
	{"MYBITTORRENT", 12, 203217},
	{"LULLS", 5, 203218},
	{"HUIZENGA", 8, 203219},
	{"COTTAM", 6, 203220},
	{"STEIF", 5, 203221},
	{"STAGELEFT", 9, 203222},
	{"NORBOTTEN", 9, 203223},
	{"ZEALANDS", 8, 203224},
	{"WICTIONARY", 10, 203225},
	{"WHITIANGA", 9, 203226},
	{"PREDS", 5, 203227},
	{"POKR", 4, 203228},
	{"ESTRIOL", 7, 203229},
	{"POMPEIUS", 8, 203230},
	{"MULLENWEG", 9, 203231},
	{"AUDLT", 5, 203232},
	{"GEOTEXTILES", 11, 203233},
	{"WHEATHER", 8, 203234},
	{"STATU", 5, 203235},
	{"HISTORI", 7, 203236},
	{"PIUTE", 5, 203237},
	{"YRANOITCID", 10, 203238},
	{"FROMA", 5, 203239},
	{"WOUDL", 5, 203240},
	{"KIEWIT", 6, 203241},
	{"LIBCAP", 6, 203242},
	{"GAMMAS", 6, 203243},
	{"REPORTNET", 9, 203244},
	{"ENDRESS", 7, 203245},
	{"BATUMI", 6, 203246},
	{"ZETEX", 5, 203247},
	{"OKHOTSK", 7, 203248},
	{"BICMOS", 6, 203249},
	{"ANGIOLINI", 9, 203250},
	{"STOCKTAKING", 11, 203251},
	{"KASKASKIA", 9, 203252},
	{"FREC", 4, 203253},
	{"FIREBOMBING", 11, 203254},
	{"ARNASON", 7, 203255},
	{"SCIVATION", 9, 203256},
	{"MERIC", 5, 203257},
	{"GLUCURONIDE", 11, 203258},
	{"EYEDROPS", 8, 203259},
	{"EMMERT", 6, 203260},
	{"MOUNTIE", 7, 203261},
	{"CONGENER", 8, 203262},
	{"LEPEL", 5, 203263},
	{"BIRTHRATE", 9, 203264},
	{"RICTIONARY", 10, 203265},
	{"POGGE", 5, 203266},
	{"AIRHEADS", 8, 203267},
	{"DISULFIRAM", 10, 203268},
	{"SCHWAGER", 8, 203269},
	{"QOOL", 4, 203270},
	{"POWERNET", 8, 203271},
	{"KNUTSEN", 7, 203272},
	{"ZISG", 4, 203273},
	{"ZEOP", 4, 203274},
	{"YYAF", 4, 203275},
	{"YKAB", 4, 203276},
	{"WLPL", 4, 203277},
	{"VUAN", 4, 203278},
	{"VTRE", 4, 203279},
	{"UGUM", 4, 203280},
	{"TZLI", 4, 203281},
	{"TKUL", 4, 203282},
	{"TFTM", 4, 203283},
	{"SSYU", 4, 203284},
	{"SPNB", 4, 203285},
	{"SMRN", 4, 203286},
	{"SDPR", 4, 203287},
	{"SBHU", 4, 203288},
	{"RUAC", 4, 203289},
	{"PTPI", 4, 203290},
	{"PDFA", 4, 203291},
	{"ONWP", 4, 203292},
	{"OLNG", 4, 203293},
	{"OKYS", 4, 203294},
	{"MDCA", 4, 203295},
	{"MAZH", 4, 203296},
	{"LLUG", 4, 203297},
	{"LIIP", 4, 203298},
	{"LAXP", 4, 203299},
	{"INLV", 4, 203300},
	{"IBME", 4, 203301},
	{"HYAV", 4, 203302},
	{"FSBI", 4, 203303},
	{"FDEH", 4, 203304},
	{"EGPE", 4, 203305},
	{"DJRA", 4, 203306},
	{"DDFA", 4, 203307},
	{"CNNB", 4, 203308},
	{"BPET", 4, 203309},
	{"ANBC", 4, 203310},
	{"AGPL", 4, 203311},
	{"AGFU", 4, 203312},
	{"AFTK", 4, 203313},
	{"AFTJ", 4, 203314},
	{"AFDI", 4, 203315},
	{"FADA", 4, 203316},
	{"KAIBAB", 6, 203317},
	{"RICHFORD", 8, 203318},
	{"PIVO", 4, 203319},
	{"PAESSLER", 8, 203320},
	{"COMPORTAMENTO", 13, 203321},
	{"ADDUCTOR", 8, 203322},
	{"KWL", 3, 203323},
	{"BUCHI", 5, 203324},
	{"TAVOLI", 6, 203325},
	{"XATOM", 5, 203326},
	{"CHKDIV", 6, 203327},
	{"UFL", 3, 203328},
	{"PRAGMATISTS", 11, 203329},
	{"ODORI", 5, 203330},
	{"PROSPERS", 8, 203331},
	{"CLAZZ", 5, 203332},
	{"MEXE", 4, 203333},
	{"COMMISERATE", 11, 203334},
	{"PERMUTE", 7, 203335},
	{"MOMUS", 5, 203336},
	{"DAINGERFIELD", 12, 203337},
	{"EPLUS", 5, 203338},
	{"AVOCATION", 9, 203339},
	{"MCORMOND", 8, 203340},
	{"MAATSCHAPPIJ", 12, 203341},
	{"DAVEM", 5, 203342},
	{"ANALPICS", 8, 203343},
	{"ZONAS", 5, 203344},
	{"KOMMERSANT", 10, 203345},
	{"PAVLOVICH", 9, 203346},
	{"BAUCHER", 7, 203347},
	{"TOMM", 4, 203348},
	{"ELECTIC", 7, 203349},
	{"METAPACKAGE", 11, 203350},
	{"FREESTYLERS", 11, 203351},
	{"NANPA", 5, 203352},
	{"OTHERTOPIC", 10, 203353},
	{"RDATE", 5, 203354},
	{"LOFTIS", 6, 203355},
	{"WEESE", 5, 203356},
	{"COVERUPS", 8, 203357},
	{"BEBES", 5, 203358},
	{"TORRENTY", 8, 203359},
	{"JUNKFOOD", 8, 203360},
	{"CRANDELL", 8, 203361},
	{"KEMPEN", 6, 203362},
	{"SYSPLEX", 7, 203363},
	{"DUNCANS", 7, 203364},
	{"VEGBANK", 7, 203365},
	{"KEPPLER", 7, 203366},
	{"POLITICIZING", 12, 203367},
	{"MALEVICH", 8, 203368},
	{"VIDEOSPIELE", 11, 203369},
	{"HUGING", 6, 203370},
	{"HUCKABY", 7, 203371},
	{"BUCHENWALD", 10, 203372},
	{"NUCKOLLS", 8, 203373},
	{"KITTING", 7, 203374},
	{"BARBAR", 6, 203375},
	{"PEUX", 4, 203376},
	{"MISRULE", 7, 203377},
	{"PINECONES", 9, 203378},
	{"SOBEK", 5, 203379},
	{"UNASKED", 7, 203380},
	{"TAILWATER", 9, 203381},
	{"IAPPS", 5, 203382},
	{"EKSP", 4, 203383},
	{"CANSON", 6, 203384},
	{"TRANSDUCING", 11, 203385},
	{"ERATING", 7, 203386},
	{"ILLO", 4, 203387},
	{"VARITY", 6, 203388},
	{"NUNAVIK", 7, 203389},
	{"SODUKO", 6, 203390},
	{"VEVEY", 5, 203391},
	{"UCHIYAMA", 8, 203392},
	{"LDAPSEARCH", 10, 203393},
	{"KOMFORT", 7, 203394},
	{"FARRAND", 7, 203395},
	{"ACQUI", 5, 203396},
	{"POTER", 5, 203397},
	{"PLUGINZ", 7, 203398},
	{"KUKA", 4, 203399},
	{"COPIOUSLY", 9, 203400},
	{"BIOINFOBANK", 11, 203401},
	{"MACNAB", 6, 203402},
	{"TUPE", 4, 203403},
	{"ONCOURSE", 8, 203404},
	{"KINGSDOWN", 9, 203405},
	{"UBOUND", 6, 203406},
	{"LUSTED", 6, 203407},
	{"DICHIONARY", 10, 203408},
	{"ROMEU", 5, 203409},
	{"PEGYLATED", 9, 203410},
	{"KINDGIRLS", 9, 203411},
	{"GELATINASE", 10, 203412},
	{"BLURTY", 6, 203413},
	{"THREADSDEV", 10, 203414},
	{"SARAFEM", 7, 203415},
	{"BOROBUDUR", 9, 203416},
	{"KINGSCLIFF", 10, 203417},
	{"DICTIONAGY", 10, 203418},
	{"PLUTON", 6, 203419},
	{"GEERTZ", 6, 203420},
	{"WILIAM", 6, 203421},
	{"HBCUS", 5, 203422},
	{"NEMMCO", 6, 203423},
	{"DICTIONXRY", 10, 203424},
	{"PITAS", 5, 203425},
	{"MISTO", 5, 203426},
	{"ISOSTATIC", 9, 203427},
	{"TECHNOCRATI", 11, 203428},
	{"DICTIONARJ", 10, 203429},
	{"BARBELITH", 9, 203430},
	{"TOTALTRIP", 9, 203431},
	{"ARNP", 4, 203432},
	{"RSTP", 4, 203433},
	{"NARTHEX", 7, 203434},
	{"YWYN", 4, 203435},
	{"YWIK", 4, 203436},
	{"YIMR", 4, 203437},
	{"YADC", 4, 203438},
	{"WOAK", 4, 203439},
	{"VESZ", 4, 203440},
	{"UAUN", 4, 203441},
	{"TDRP", 4, 203442},
	{"SPBS", 4, 203443},
	{"SOUB", 4, 203444},
	{"RIZS", 4, 203445},
	{"RHEQ", 4, 203446},
	{"QPRO", 4, 203447},
	{"PUBF", 4, 203448},
	{"PNEG", 4, 203449},
	{"OXGR", 4, 203450},
	{"OWUR", 4, 203451},
	{"ORFG", 4, 203452},
	{"ONBM", 4, 203453},
	{"NIPM", 4, 203454},
	{"NCUY", 4, 203455},
	{"NAXL", 4, 203456},
	{"MWSE", 4, 203457},
	{"MLUT", 4, 203458},
	{"MFTH", 4, 203459},
	{"LPAH", 4, 203460},
	{"LDZO", 4, 203461},
	{"KOVM", 4, 203462},
	{"KLTD", 4, 203463},
	{"KAIG", 4, 203464},
	{"IWIR", 4, 203465},
	{"IORZ", 4, 203466},
	{"INMG", 4, 203467},
	{"HRCO", 4, 203468},
	{"HKOW", 4, 203469},
	{"FYDI", 4, 203470},
	{"DWEY", 4, 203471},
	{"DTKO", 4, 203472},
	{"DHLA", 4, 203473},
	{"ANPC", 4, 203474},
	{"ABJA", 4, 203475},
	{"ACOMMADATION", 12, 203476},
	{"AMINOPHYLLINE", 13, 203477},
	{"WHISKERED", 9, 203478},
	{"SOMATOTROPIN", 12, 203479},
	{"CHAUNGED", 8, 203480},
	{"CHANNELLOCK", 11, 203481},
	{"CANW", 4, 203482},
	{"FREDDO", 6, 203483},
	{"PREAPPROVAL", 11, 203484},
	{"TERC", 4, 203485},
	{"FREIEN", 6, 203486},
	{"ACTIONFORM", 10, 203487},
	{"SOLTIS", 6, 203488},
	{"SPEAKIN", 7, 203489},
	{"HERZFELD", 8, 203490},
	{"ELECTROPHYSIOLOGIC", 18, 203491},
	{"DUPLESSIS", 9, 203492},
	{"GAKUIN", 6, 203493},
	{"ECLECTUS", 8, 203494},
	{"DIAPERED", 8, 203495},
	{"PORATION", 8, 203496},
	{"MESSIAHS", 8, 203497},
	{"WILDERNESSES", 12, 203498},
	{"BLINKIE", 7, 203499},
	{"LANDWEHR", 8, 203500},
	{"KAMINARI", 8, 203501},
	{"CASEYVILLE", 10, 203502},
	{"SPORTSCARS", 10, 203503},
	{"POLITICANS", 10, 203504},
	{"AUXILLIARY", 10, 203505},
	{"ANNALISA", 8, 203506},
	{"SCHUUR", 6, 203507},
	{"PAGEID", 6, 203508},
	{"HORNADAY", 8, 203509},
	{"AVODART", 7, 203510},
	{"SMITHEE", 7, 203511},
	{"IFNAME", 6, 203512},
	{"WORDFINDER", 10, 203513},
	{"UNINEWS", 7, 203514},
	{"MEKONS", 6, 203515},
	{"TRADA", 5, 203516},
	{"SUBVERTS", 8, 203517},
	{"NUCLEOCAPSID", 12, 203518},
	{"KOMMISSAR", 9, 203519},
	{"FRAGGING", 8, 203520},
	{"TAMARIN", 7, 203521},
	{"PERPETRATION", 12, 203522},
	{"GWANGJU", 7, 203523},
	{"ASPIRA", 6, 203524},
	{"KUVAT", 5, 203525},
	{"FYFFE", 5, 203526},
	{"WARHAWK", 7, 203527},
	{"QUALIDADE", 9, 203528},
	{"FAIRBROTHER", 11, 203529},
	{"LIMEREX", 7, 203530},
	{"DICTIONAWY", 10, 203531},
	{"CONCA", 5, 203532},
	{"TENDLER", 7, 203533},
	{"MYTILUS", 7, 203534},
	{"MBRS", 4, 203535},
	{"LUTHIERS", 8, 203536},
	{"ITEMLIST", 8, 203537},
	{"CANDLEPOWER", 11, 203538},
	{"KENNING", 7, 203539},
	{"INFANTRYMEN", 11, 203540},
	{"DREAMSCAPES", 11, 203541},
	{"CHINAWARE", 9, 203542},
	{"LIBMAD", 6, 203543},
	{"DEFINER", 7, 203544},
	{"BUSHKILL", 8, 203545},
	{"ACKNOWL", 7, 203546},
	{"DICTIOKARY", 10, 203547},
	{"DEPOLARIZING", 12, 203548},
	{"MISURA", 6, 203549},
	{"WICKERS", 7, 203550},
	{"DICTIOGARY", 10, 203551},
	{"ATLANTE", 7, 203552},
	{"TRANSMUTED", 10, 203553},
	{"HOLLOWWARE", 10, 203554},
	{"ABIDETH", 7, 203555},
	{"OSMONICS", 8, 203556},
	{"VINPOCETINE", 11, 203557},
	{"LEPTOPRIN", 9, 203558},
	{"BLASPHEME", 9, 203559},
	{"RABEPRAZOLE", 11, 203560},
	{"WORDINDEX", 9, 203561},
	{"VALJEAN", 7, 203562},
	{"SNAPBACK", 8, 203563},
	{"ORTHODONTIA", 11, 203564},
	{"HEUSER", 6, 203565},
	{"INGENIEUR", 9, 203566},
	{"CAERULEA", 8, 203567},
	{"SHORTT", 6, 203568},
	{"IBEC", 4, 203569},
	{"SOURCESUP", 9, 203570},
	{"ARTIGOS", 7, 203571},
	{"DISQUALIFIES", 12, 203572},
	{"NUDIBRANCH", 10, 203573},
	{"HNRNP", 5, 203574},
	{"BONALDO", 7, 203575},
	{"BLACKING", 8, 203576},
	{"SHEPPEY", 7, 203577},
	{"MYDR", 4, 203578},
	{"SPICATA", 7, 203579},
	{"KOPI", 4, 203580},
	{"TATHAGATA", 9, 203581},
	{"FONZIE", 6, 203582},
	{"IJKL", 4, 203583},
	{"DIVMOD", 6, 203584},
	{"QUELLED", 7, 203585},
	{"WATCHA", 6, 203586},
	{"MERIDIANI", 9, 203587},
	{"XDRS", 4, 203588},
	{"VIDCAST", 7, 203589},
	{"MORTES", 6, 203590},
	{"IGRA", 4, 203591},
	{"FUNCNAME", 8, 203592},
	{"TOMBOW", 6, 203593},
	{"FLOYDS", 6, 203594},
	{"LOJACK", 6, 203595},
	{"IRONFORGE", 9, 203596},
	{"PROPFIND", 8, 203597},
	{"WVC", 3, 203598},
	{"OBJETIVOS", 9, 203599},
	{"WOODLOTS", 8, 203600},
	{"FREIZEITDAME", 12, 203601},
	{"DOOLAN", 6, 203602},
	{"BLACKLICK", 9, 203603},
	{"TEXADA", 6, 203604},
	{"NORIS", 5, 203605},
	{"NELLIGAN", 8, 203606},
	{"BROOKSTON", 9, 203607},
	{"EHRMANN", 7, 203608},
	{"CONFRENCE", 9, 203609},
	{"LINGEN", 6, 203610},
	{"THREESCORE", 10, 203611},
	{"ZWRO", 4, 203612},
	{"ZHIG", 4, 203613},
	{"XITM", 4, 203614},
	{"WDNE", 4, 203615},
	{"VEIB", 4, 203616},
	{"UXAT", 4, 203617},
	{"UHYI", 4, 203618},
	{"SVOG", 4, 203619},
	{"SPND", 4, 203620},
	{"SMOJ", 4, 203621},
	{"SHUU", 4, 203622},
	{"RRSO", 4, 203623},
	{"RRFL", 4, 203624},
	{"PTIR", 4, 203625},
	{"PMOB", 4, 203626},
	{"PELN", 4, 203627},
	{"OXFU", 4, 203628},
	{"ORVL", 4, 203629},
	{"OGSK", 4, 203630},
	{"LYPP", 4, 203631},
	{"LLZA", 4, 203632},
	{"LHYM", 4, 203633},
	{"KNAL", 4, 203634},
	{"KKLE", 4, 203635},
	{"KGIB", 4, 203636},
	{"JIFO", 4, 203637},
	{"IBMM", 4, 203638},
	{"GIDG", 4, 203639},
	{"GGAW", 4, 203640},
	{"EXIU", 4, 203641},
	{"EMPN", 4, 203642},
	{"DGDP", 4, 203643},
	{"CJUM", 4, 203644},
	{"CIEF", 4, 203645},
	{"BJOS", 4, 203646},
	{"AXXI", 4, 203647},
	{"AUAB", 4, 203648},
	{"ACOX", 4, 203649},
	{"WILBON", 6, 203650},
	{"MOBIMB", 6, 203651},
	{"STYLEXP", 7, 203652},
	{"SODOMANIA", 9, 203653},
	{"NEWL", 4, 203654},
	{"FWSM", 4, 203655},
	{"DETERMI", 7, 203656},
	{"TOPSELLERS", 10, 203657},
	{"MONISM", 6, 203658},
	{"SPIRALED", 8, 203659},
	{"MUSSOORIE", 9, 203660},
	{"COBIAN", 6, 203661},
	{"GIGABITS", 8, 203662},
	{"RENALDO", 7, 203663},
	{"BEEBLEX", 7, 203664},
	{"SITTETH", 7, 203665},
	{"DICHROMATE", 10, 203666},
	{"APPRICIATE", 10, 203667},
	{"LAREAU", 6, 203668},
	{"CAMERS", 6, 203669},
	{"ACCESSMEDICINE", 14, 203670},
	{"LADONNA", 7, 203671},
	{"JACKSONIAN", 10, 203672},
	{"INSTANTDOC", 10, 203673},
	{"EUPDATES", 8, 203674},
	{"ASTAXANTHIN", 11, 203675},
	{"PPDS", 4, 203676},
	{"POLYPHASE", 9, 203677},
	{"PFOA", 4, 203678},
	{"SHADOWFAX", 9, 203679},
	{"BZIMAGE", 7, 203680},
	{"MIRKA", 5, 203681},
	{"LABATIDORA", 10, 203682},
	{"JAZMIN", 6, 203683},
	{"RWL", 3, 203684},
	{"NOCTUIDAE", 9, 203685},
	{"INAMED", 6, 203686},
	{"DACRE", 5, 203687},
	{"MISIDENTIFICATION", 17, 203688},
	{"MARSLAND", 8, 203689},
	{"IONESCO", 7, 203690},
	{"HYEONG", 6, 203691},
	{"AMEREN", 6, 203692},
	{"TENDA", 5, 203693},
	{"STABLING", 8, 203694},
	{"HOMESCHOOLER", 12, 203695},
	{"POLITIES", 8, 203696},
	{"QLINKS", 6, 203697},
	{"PREFERITE", 9, 203698},
	{"KAYLOR", 6, 203699},
	{"SAWANT", 6, 203700},
	{"MERIAL", 6, 203701},
	{"VOJISLAV", 8, 203702},
	{"SHAHAB", 6, 203703},
	{"RELAVENT", 8, 203704},
	{"KEENNESS", 8, 203705},
	{"UHHHH", 5, 203706},
	{"LEKEBUSCH", 9, 203707},
	{"BATTERIJ", 8, 203708},
	{"NVIEW", 5, 203709},
	{"KFMB", 4, 203710},
	{"MARIK", 5, 203711},
	{"QUICKENS", 8, 203712},
	{"OXYGENASES", 10, 203713},
	{"MEVAGISSEY", 10, 203714},
	{"NCCS", 4, 203715},
	{"FIREHAWK", 8, 203716},
	{"SWATHE", 6, 203717},
	{"SCORNFULLY", 10, 203718},
	{"VBFORUMS", 8, 203719},
	{"MCLEODS", 7, 203720},
	{"ACTC", 4, 203721},
	{"DOMKE", 5, 203722},
	{"PONCHATOULA", 11, 203723},
	{"ECOOP", 5, 203724},
	{"STRAWBALE", 9, 203725},
	{"PUERPERAL", 9, 203726},
	{"OUTBUF", 6, 203727},
	{"WESTMARK", 8, 203728},
	{"SOMIS", 5, 203729},
	{"MULTIS", 6, 203730},
	{"HOUSEWIVE", 9, 203731},
	{"ILYKA", 5, 203732},
	{"DEARDORFF", 9, 203733},
	{"ZUK", 3, 203734},
	{"DDRII", 5, 203735},
	{"MINIER", 6, 203736},
	{"WORLDLINESS", 11, 203737},
	{"ROWN", 4, 203738},
	{"POSEUR", 6, 203739},
	{"IRRIGATOR", 9, 203740},
	{"GYFRIFOL", 8, 203741},
	{"SUBZONE", 7, 203742},
	{"INCLUS", 6, 203743},
	{"ASKMEN", 6, 203744},
	{"AERODROMES", 10, 203745},
	{"BYROM", 5, 203746},
	{"UNPASTEURIZED", 13, 203747},
	{"SHECYCLES", 9, 203748},
	{"GANSEVOORT", 10, 203749},
	{"SABADELL", 8, 203750},
	{"PERTURBING", 10, 203751},
	{"CROAKING", 8, 203752},
	{"PROJECTNAME", 11, 203753},
	{"IGNORAMUS", 9, 203754},
	{"HOWBEIT", 7, 203755},
	{"DRWX", 4, 203756},
	{"TORMENTA", 8, 203757},
	{"SUBSHELL", 8, 203758},
	{"ATOMIZED", 8, 203759},
	{"LINHOF", 6, 203760},
	{"IMMUNOENZYME", 12, 203761},
	{"FIELDTRIP", 9, 203762},
	{"CITEC", 5, 203763},
	{"SMOKESTACKS", 11, 203764},
	{"ARGIUES", 7, 203765},
	{"MISCELLANIES", 12, 203766},
	{"SONSHIP", 7, 203767},
	{"MARCOUX", 7, 203768},
	{"ECRIT", 5, 203769},
	{"ALORA", 5, 203770},
	{"UPSCALING", 9, 203771},
	{"SINGAPUR", 8, 203772},
	{"MIRES", 5, 203773},
	{"TERLINGUA", 9, 203774},
	{"BOSCAWEN", 8, 203775},
	{"VICKREY", 7, 203776},
	{"ALTARPIECE", 10, 203777},
	{"ROWHOUSE", 8, 203778},
	{"MOONHUNTER", 10, 203779},
	{"GAMEBOARD", 9, 203780},
	{"CHIRSTMAS", 9, 203781},
	{"PRICKETT", 8, 203782},
	{"NETWORKABOUT", 12, 203783},
	{"UNMISSABLE", 10, 203784},
	{"PROTECTIVELY", 12, 203785},
	{"DESENSITIZING", 13, 203786},
	{"NUMINOUS", 8, 203787},
	{"COTININE", 8, 203788},
	{"NOMEM", 5, 203789},
	{"HURLER", 6, 203790},
	{"SPUG", 4, 203791},
	{"HANEDA", 6, 203792},
	{"SETTYPE", 7, 203793},
	{"ESZTER", 6, 203794},
	{"ZENSONIC", 8, 203795},
	{"ZARK", 4, 203796},
	{"REPHRASED", 9, 203797},
	{"MITSUO", 6, 203798},
	{"BOOTLEGGING", 11, 203799},
	{"MEMBERSMEMBERS", 14, 203800},
	{"BRAZE", 5, 203801},
	{"ZSUR", 4, 203802},
	{"YPTM", 4, 203803},
	{"YAXE", 4, 203804},
	{"XRIG", 4, 203805},
	{"WWFO", 4, 203806},
	{"WRYL", 4, 203807},
	{"WDSS", 4, 203808},
	{"VTED", 4, 203809},
	{"UPAO", 4, 203810},
	{"UOFN", 4, 203811},
	{"TZAK", 4, 203812},
	{"STDV", 4, 203813},
	{"RAZH", 4, 203814},
	{"OYOB", 4, 203815},
	{"OPPW", 4, 203816},
	{"OMLS", 4, 203817},
	{"NPPR", 4, 203818},
	{"NMHZ", 4, 203819},
	{"MSKR", 4, 203820},
	{"MOWG", 4, 203821},
	{"MOCI", 4, 203822},
	{"MMHE", 4, 203823},
	{"IRLJ", 4, 203824},
	{"IPGU", 4, 203825},
	{"IAUK", 4, 203826},
	{"HEFX", 4, 203827},
	{"GUTC", 4, 203828},
	{"GMGA", 4, 203829},
	{"FRHI", 4, 203830},
	{"FMWI", 4, 203831},
	{"FDOY", 4, 203832},
	{"EPYH", 4, 203833},
	{"EKSQ", 4, 203834},
	{"EJRW", 4, 203835},
	{"EIYU", 4, 203836},
	{"EHYG", 4, 203837},
	{"EFMU", 4, 203838},
	{"EDGS", 4, 203839},
	{"CTGD", 4, 203840},
	{"BWEC", 4, 203841},
	{"AUXR", 4, 203842},
	{"KEYERROR", 8, 203843},
	{"ADULTPAYPERVIEW", 15, 203844},
	{"YABLOKO", 7, 203845},
	{"NOETIC", 6, 203846},
	{"MONTREUIL", 9, 203847},
	{"TECHNOLGIES", 11, 203848},
	{"FREEGIS", 7, 203849},
	{"LETZTER", 7, 203850},
	{"HILDEN", 6, 203851},
	{"PUBLICOLA", 9, 203852},
	{"HORSEGUARDS", 11, 203853},
	{"PURINERGIC", 10, 203854},
	{"ONDES", 5, 203855},
	{"SIXER", 5, 203856},
	{"UTTERLYRICS", 11, 203857},
	{"PROADULT", 8, 203858},
	{"JPCACHE", 7, 203859},
	{"SAHELIAN", 8, 203860},
	{"CARRENTAL", 9, 203861},
	{"FILESTREAM", 10, 203862},
	{"SISTERLY", 8, 203863},
	{"AUFGEBEN", 8, 203864},
	{"MIKING", 6, 203865},
	{"BRIERS", 6, 203866},
	{"MCVOY", 5, 203867},
	{"INVOCA", 6, 203868},
	{"WAYNES", 6, 203869},
	{"ERMITAGE", 8, 203870},
	{"HAMFEST", 7, 203871},
	{"BULLOSA", 7, 203872},
	{"EWERT", 5, 203873},
	{"WINDBREAK", 9, 203874},
	{"TELMO", 5, 203875},
	{"SMLPBA", 6, 203876},
	{"OUVRAGE", 7, 203877},
	{"LISC", 4, 203878},
	{"COWHERD", 7, 203879},
	{"FAIBLE", 6, 203880},
	{"FREAKOUT", 8, 203881},
	{"DAYSIDE", 7, 203882},
	{"WISHMASTER", 10, 203883},
	{"ORLIMAR", 7, 203884},
	{"SIMULACRUM", 10, 203885},
	{"WANTONNESSE", 11, 203886},
	{"TORSTEIN", 8, 203887},
	{"RUBYONRAILS", 11, 203888},
	{"SWARBRICK", 9, 203889},
	{"CROSSPOST", 9, 203890},
	{"CARLIER", 7, 203891},
	{"SYSCONF", 7, 203892},
	{"DATEFORMAT", 10, 203893},
	{"MEYERHOFF", 9, 203894},
	{"WHITTLING", 9, 203895},
	{"ARISTIDES", 9, 203896},
	{"LARIMORE", 8, 203897},
	{"LILJA", 5, 203898},
	{"USWA", 4, 203899},
	{"KUBAN", 5, 203900},
	{"DHYANA", 6, 203901},
	{"BURNES", 6, 203902},
	{"LCLP", 4, 203903},
	{"CALWELL", 7, 203904},
	{"XWIN", 4, 203905},
	{"OUTGROWING", 10, 203906},
	{"PUNKROCK", 8, 203907},
	{"TANGUY", 6, 203908},
	{"OVERLONG", 8, 203909},
	{"SUBMERSED", 9, 203910},
	{"CLITIC", 6, 203911},
	{"SWEETPOTATO", 11, 203912},
	{"SEQUATCHIE", 10, 203913},
	{"KERATOCONUS", 11, 203914},
	{"TLVS", 4, 203915},
	{"OSTHOFF", 7, 203916},
	{"XDCAM", 5, 203917},
	{"GHOSTWRITING", 12, 203918},
	{"MEDIACORP", 9, 203919},
	{"QUANTRILL", 9, 203920},
	{"PALMITOYL", 9, 203921},
	{"SIXPACK", 7, 203922},
	{"OLVERA", 6, 203923},
	{"INTUSSUSCEPTION", 15, 203924},
	{"CATALOGUER", 10, 203925},
	{"TREATABILITY", 12, 203926},
	{"TOUCHSYSTEMS", 12, 203927},
	{"AVIDITY", 7, 203928},
	{"POLYPHOSPHATE", 13, 203929},
	{"LETTORI", 7, 203930},
	{"SBOX", 4, 203931},
	{"SADAKO", 6, 203932},
	{"DTLR", 4, 203933},
	{"BUER", 4, 203934},
	{"THROMBOSPONDIN", 14, 203935},
	{"CANVASBACK", 10, 203936},
	{"VINDICATOR", 10, 203937},
	{"UTIME", 5, 203938},
	{"RAILFAN", 7, 203939},
	{"KEIRETSU", 8, 203940},
	{"PORTABELLA", 10, 203941},
	{"NOOSAVILLE", 10, 203942},
	{"GASCON", 6, 203943},
	{"ENZYMIC", 7, 203944},
	{"WEEKENDERS", 10, 203945},
	{"TIGHTVNC", 8, 203946},
	{"SAYWARD", 7, 203947},
	{"OBFUSCATOR", 10, 203948},
	{"BERGS", 5, 203949},
	{"CRAIL", 5, 203950},
	{"CANDYBAR", 8, 203951},
	{"BIBLIOGR", 8, 203952},
	{"MAILPARSE", 9, 203953},
	{"LNXC", 4, 203954},
	{"CAFOS", 5, 203955},
	{"ACCUSTOM", 8, 203956},
	{"UNDERCAR", 8, 203957},
	{"DIONEX", 6, 203958},
	{"SOKG", 4, 203959},
	{"QUANTAL", 7, 203960},
	{"PODSEDNIK", 9, 203961},
	{"FAFNIR", 6, 203962},
	{"OVULATING", 9, 203963},
	{"COLORIFFICS", 11, 203964},
	{"BRUUN", 5, 203965},
	{"ERGEN", 5, 203966},
	{"SURIYAN", 7, 203967},
	{"SONATINA", 8, 203968},
	{"DICARBOXYLIC", 12, 203969},
	{"ZIAB", 4, 203970},
	{"YPYR", 4, 203971},
	{"YBAE", 4, 203972},
	{"XELB", 4, 203973},
	{"UZDE", 4, 203974},
	{"UYPO", 4, 203975},
	{"UMOB", 4, 203976},
	{"UFCS", 4, 203977},
	{"TWAX", 4, 203978},
	{"TUJU", 4, 203979},
	{"TMLE", 4, 203980},
	{"TIKR", 4, 203981},
	{"SCIW", 4, 203982},
	{"RVOD", 4, 203983},
	{"ROHY", 4, 203984},
	{"POYN", 4, 203985},
	{"PCPL", 4, 203986},
	{"PBOS", 4, 203987},
	{"OBIZ", 4, 203988},
	{"NIML", 4, 203989},
	{"NBSD", 4, 203990},
	{"MPIM", 4, 203991},
	{"LVOU", 4, 203992},
	{"LVDP", 4, 203993},
	{"LLNF", 4, 203994},
	{"KVAS", 4, 203995},
	{"KIPB", 4, 203996},
	{"KADH", 4, 203997},
	{"IUMY", 4, 203998},
	{"HDUP", 4, 203999},
	{"HCHL", 4, 204000},
	{"FMCO", 4, 204001},
	{"EQBS", 4, 204002},
	{"EEFD", 4, 204003},
	{"DUZB", 4, 204004},
	{"DKME", 4, 204005},
	{"BRND", 4, 204006},
	{"ASWY", 4, 204007},
	{"AHDR", 4, 204008},
	{"CONSISTE", 8, 204009},
	{"MEGALOMANIA", 11, 204010},
	{"KAVALIER", 8, 204011},
	{"POCH", 4, 204012},
	{"NOMENCLATURAL", 13, 204013},
	{"NUTHOUSE", 8, 204014},
	{"MAGICO", 6, 204015},
	{"VENEZ", 5, 204016},
	{"SENDE", 5, 204017},
	{"PROUDER", 7, 204018},
	{"PLIANCE", 7, 204019},
	{"CLSD", 4, 204020},
	{"NAIAD", 5, 204021},
	{"TIMAEUS", 7, 204022},
	{"INSTANTONS", 10, 204023},
	{"YUVRAJ", 6, 204024},
	{"SUDEKI", 6, 204025},
	{"RPGAMER", 7, 204026},
	{"BERANEK", 7, 204027},
	{"ALIBIS", 6, 204028},
	{"KPCC", 4, 204029},
	{"HERBIG", 6, 204030},
	{"ADDAS", 5, 204031},
	{"GNAC", 4, 204032},
	{"CHEAR", 5, 204033},
	{"AZRIEL", 6, 204034},
	{"LUNTZ", 5, 204035},
	{"LIBMCRYPT", 9, 204036},
	{"FUNZONE", 7, 204037},
	{"GRAPHOLOGY", 10, 204038},
	{"SHAHAM", 6, 204039},
	{"LEKO", 4, 204040},
	{"GYNTAF", 6, 204041},
	{"STYGIUS", 7, 204042},
	{"ROZEREM", 7, 204043},
	{"GRANULOMAS", 10, 204044},
	{"CASHER", 6, 204045},
	{"ACEHNESE", 8, 204046},
	{"UCCS", 4, 204047},
	{"PLANETE", 7, 204048},
	{"AMPLIAR", 7, 204049},
	{"JOANE", 5, 204050},
	{"EGAD", 4, 204051},
	{"PEWSEY", 6, 204052},
	{"RGBT", 4, 204053},
	{"MILHOUSE", 8, 204054},
	{"BUDI", 4, 204055},
	{"CHAGOS", 6, 204056},
	{"LEIRIA", 6, 204057},
	{"SNGL", 4, 204058},
	{"ILAB", 4, 204059},
	{"PLEASETH", 8, 204060},
	{"KLEMME", 6, 204061},
	{"VICIOUSNESS", 11, 204062},
	{"NPLS", 4, 204063},
	{"VOSKA", 5, 204064},
	{"VANDALISED", 10, 204065},
	{"TECHLAND", 8, 204066},
	{"OUTLANDERS", 10, 204067},
	{"ANATOMIA", 8, 204068},
	{"NOERR", 5, 204069},
	{"SKOR", 4, 204070},
	{"CORNETS", 7, 204071},
	{"CHEMIK", 6, 204072},
	{"USTC", 4, 204073},
	{"RUOLO", 5, 204074},
	{"BISTROT", 7, 204075},
	{"NAGRAVISION", 11, 204076},
	{"DOHIYI", 6, 204077},
	{"CAUTARE", 7, 204078},
	{"ANSIC", 5, 204079},
	{"CAREERLINK", 10, 204080},
	{"QAIX", 4, 204081},
	{"LENCIONI", 8, 204082},
	{"KEYMAKER", 8, 204083},
	{"CAMOFLAGE", 9, 204084},
	{"ULLIN", 5, 204085},
	{"HOVIS", 5, 204086},
	{"EVERYWHEREPOWER", 15, 204087},
	{"REAGLE", 6, 204088},
	{"BASHEVIS", 8, 204089},
	{"ARTC", 4, 204090},
	{"GPMS", 4, 204091},
	{"GALPIN", 6, 204092},
	{"CANLYNIADAU", 11, 204093},
	{"HILLTOWN", 8, 204094},
	{"REJSER", 6, 204095},
	{"LIPHOOK", 7, 204096},
	{"HALLETTSVILLE", 13, 204097},
	{"VERZEND", 7, 204098},
	{"LOAMS", 5, 204099},
	{"FEIGE", 5, 204100},
	{"STEFFE", 6, 204101},
	{"REGNERY", 7, 204102},
	{"NORVIR", 6, 204103},
	{"BLUCHER", 7, 204104},
	{"TAMAQUA", 7, 204105},
	{"DETRIOT", 7, 204106},
	{"CHAFERS", 7, 204107},
	{"BORAT", 5, 204108},
	{"TYRAMINE", 8, 204109},
	{"REGIER", 6, 204110},
	{"PYRETHRUM", 9, 204111},
	{"REQUISITOS", 10, 204112},
	{"MIDDLEVILLE", 11, 204113},
	{"TIMEIPS", 7, 204114},
	{"WUXIA", 5, 204115},
	{"DELUXEPASS", 10, 204116},
	{"ZIERING", 7, 204117},
	{"FLORETTE", 8, 204118},
	{"DAUN", 4, 204119},
	{"SMALLWARES", 10, 204120},
	{"FICHTNER", 8, 204121},
	{"FBD", 3, 204122},
	{"SHINDIGZ", 8, 204123},
	{"OLUTION", 7, 204124},
	{"MCCRAW", 6, 204125},
	{"FLIST", 5, 204126},
	{"BOULWARE", 8, 204127},
	{"OPBA", 4, 204128},
	{"OUTOKUMPU", 9, 204129},
	{"CAYETANO", 8, 204130},
	{"ZHIK", 4, 204131},
	{"YZAR", 4, 204132},
	{"YUKS", 4, 204133},
	{"YDSB", 4, 204134},
	{"XLAR", 4, 204135},
	{"VAEC", 4, 204136},
	{"UKAV", 4, 204137},
	{"UBTU", 4, 204138},
	{"TCFR", 4, 204139},
	{"SNPR", 4, 204140},
	{"SBPA", 4, 204141},
	{"RXRA", 4, 204142},
	{"RMUF", 4, 204143},
	{"RKEQ", 4, 204144},
	{"RHEX", 4, 204145},
	{"RGPI", 4, 204146},
	{"RARH", 4, 204147},
	{"OVSM", 4, 204148},
	{"OSUW", 4, 204149},
	{"NYLL", 4, 204150},
	{"NIKB", 4, 204151},
	{"NEXG", 4, 204152},
	{"MNMO", 4, 204153},
	{"MGRU", 4, 204154},
	{"MCFO", 4, 204155},
	{"MBIW", 4, 204156},
	{"MAXV", 4, 204157},
	{"MAMD", 4, 204158},
	{"LTPH", 4, 204159},
	{"LGAW", 4, 204160},
	{"GYOV", 4, 204161},
	{"ELEJ", 4, 204162},
	{"EFCE", 4, 204163},
	{"EEVR", 4, 204164},
	{"DZAB", 4, 204165},
	{"DYSV", 4, 204166},
	{"DEOY", 4, 204167},
	{"CSGU", 4, 204168},
	{"CCIF", 4, 204169},
	{"BPUT", 4, 204170},
	{"BLAE", 4, 204171},
	{"PROJETO", 7, 204172},
	{"DEMENTO", 7, 204173},
	{"COTTONWOODS", 11, 204174},
	{"DIPPY", 5, 204175},
	{"CONJUGATIONS", 12, 204176},
	{"SLOSHING", 8, 204177},
	{"NMCI", 4, 204178},
	{"CCNY", 4, 204179},
	{"ESTOU", 5, 204180},
	{"COMPUTACENTER", 13, 204181},
	{"PROCFS", 6, 204182},
	{"VIELLE", 6, 204183},
	{"REFRENCE", 8, 204184},
	{"UNSPECIFIC", 10, 204185},
	{"TREEFROG", 8, 204186},
	{"QUINOLINE", 9, 204187},
	{"LVALUES", 7, 204188},
	{"WINDFALLS", 9, 204189},
	{"SOUNDPROOFED", 12, 204190},
	{"OUTCROPPING", 11, 204191},
	{"WNBL", 4, 204192},
	{"CLST", 4, 204193},
	{"ARETHUSA", 8, 204194},
	{"SUBRIP", 6, 204195},
	{"NASER", 5, 204196},
	{"DRINKABILITY", 12, 204197},
	{"ZZY", 3, 204198},
	{"MOLECULARLY", 11, 204199},
	{"KAMPS", 5, 204200},
	{"DIENSTE", 7, 204201},
	{"INANNA", 6, 204202},
	{"ALLSBURG", 8, 204203},
	{"SUPERINTENDING", 14, 204204},
	{"COLLEAGUEE", 10, 204205},
	{"TMWC", 4, 204206},
	{"HARAWAY", 7, 204207},
	{"TABLECOVER", 10, 204208},
	{"SOCIOLOGIE", 10, 204209},
	{"ENDITEM", 7, 204210},
	{"CINEFORM", 8, 204211},
	{"BENZOCAINE", 10, 204212},
	{"MANKIEWICZ", 10, 204213},
	{"TVPG", 4, 204214},
	{"PHITSANULOK", 11, 204215},
	{"CONVEGNO", 8, 204216},
	{"APQC", 4, 204217},
	{"VELHO", 5, 204218},
	{"SPECTRES", 8, 204219},
	{"PARASITICS", 10, 204220},
	{"PICTIONARY", 10, 204221},
	{"PANTOGRAPH", 10, 204222},
	{"KINEMATICAL", 11, 204223},
	{"DEALGAIN", 8, 204224},
	{"UGUR", 4, 204225},
	{"POETESS", 7, 204226},
	{"FCTC", 4, 204227},
	{"BARKAN", 6, 204228},
	{"BOWHEAD", 7, 204229},
	{"WOODROFFE", 9, 204230},
	{"VALLANCE", 8, 204231},
	{"PICTUREZ", 8, 204232},
	{"PARTIRE", 7, 204233},
	{"SOMATOFORM", 10, 204234},
	{"VOXENGO", 7, 204235},
	{"MOLUCCAS", 8, 204236},
	{"BIERE", 5, 204237},
	{"TENNANTS", 8, 204238},
	{"TEXSPORT", 8, 204239},
	{"KEELUNG", 7, 204240},
	{"MELHORES", 8, 204241},
	{"LUMBEE", 6, 204242},
	{"USERMODE", 8, 204243},
	{"MWANZA", 6, 204244},
	{"MAMM", 4, 204245},
	{"SOLOGALS", 8, 204246},
	{"MACERATA", 8, 204247},
	{"NGTRANS", 7, 204248},
	{"LEGUMINOUS", 10, 204249},
	{"STANDARDISING", 13, 204250},
	{"COREPAD", 7, 204251},
	{"CONTIVITY", 9, 204252},
	{"LAPINE", 6, 204253},
	{"BRIGANDS", 8, 204254},
	{"SCHRAG", 6, 204255},
	{"BOSSCHER", 8, 204256},
	{"JOBB", 4, 204257},
	{"TETRAHYDROFURAN", 15, 204258},
	{"SUBGAME", 7, 204259},
	{"QUARRELSOME", 11, 204260},
	{"MOINE", 5, 204261},
	{"GPLED", 5, 204262},
	{"WINGTIPS", 8, 204263},
	{"SOLIDERS", 8, 204264},
	{"ATLASOFFLINE", 12, 204265},
	{"GUMMERSON", 9, 204266},
	{"BALCONES", 8, 204267},
	{"MIKEINBRAZIL", 12, 204268},
	{"FLAVORPILL", 10, 204269},
	{"BALEARS", 7, 204270},
	{"ZEHR", 4, 204271},
	{"BUTYLENE", 8, 204272},
	{"BRODICK", 7, 204273},
	{"IMAGINEERING", 12, 204274},
	{"EXECUTRIX", 9, 204275},
	{"CENDYNE", 7, 204276},
	{"BOWRING", 7, 204277},
	{"STRANDINGS", 10, 204278},
	{"CONURBATIONS", 12, 204279},
	{"PARABURDOO", 10, 204280},
	{"PETTERSEN", 9, 204281},
	{"REFITTING", 9, 204282},
	{"COSHAM", 6, 204283},
	{"DONOSTIA", 8, 204284},
	{"KOHUT", 5, 204285},
	{"PACKRAT", 7, 204286},
	{"GARANTITO", 9, 204287},
	{"BGAN", 4, 204288},
	{"SUPPORTPLUS", 11, 204289},
	{"QADDAFI", 7, 204290},
	{"LEESA", 5, 204291},
	{"BUDGERIGAR", 10, 204292},
	{"EDMORE", 6, 204293},
	{"SEACLIFF", 8, 204294},
	{"FOGBUGZ", 7, 204295},
	{"UQAM", 4, 204296},
	{"NEWNES", 6, 204297},
	{"MONTANUS", 8, 204298},
	{"GANAS", 5, 204299},
	{"MYTHOMASSAVE", 12, 204300},
	{"TERRORIZER", 10, 204301},
	{"PATHING", 7, 204302},
	{"LULAC", 5, 204303},
	{"LILIOPSIDA", 10, 204304},
	{"RATINGEN", 8, 204305},
	{"BURSTOW", 7, 204306},
	{"EICHENGREEN", 11, 204307},
	{"SWISHMAX", 8, 204308},
	{"FIRSTSEL", 8, 204309},
	{"DETERMINISTICALLY", 17, 204310},
	{"WONDERWARE", 10, 204311},
	{"SCHUMAKER", 9, 204312},
	{"GOALSCORER", 10, 204313},
	{"TIMESLIP", 8, 204314},
	{"JAMEL", 5, 204315},
	{"ISOMERIC", 8, 204316},
	{"ZOMIG", 5, 204317},
	{"BVR", 3, 204318},
	{"PYRIDOSTIGMINE", 14, 204319},
	{"YUKT", 4, 204320},
	{"VDSI", 4, 204321},
	{"UDYV", 4, 204322},
	{"RVOO", 4, 204323},
	{"RVIX", 4, 204324},
	{"RSDW", 4, 204325},
	{"RRSE", 4, 204326},
	{"RKIB", 4, 204327},
	{"RIMJ", 4, 204328},
	{"QINC", 4, 204329},
	{"PRIP", 4, 204330},
	{"OILV", 4, 204331},
	{"NZRI", 4, 204332},
	{"NRDI", 4, 204333},
	{"NORZ", 4, 204334},
	{"NCSW", 4, 204335},
	{"MUEA", 4, 204336},
	{"MLIQ", 4, 204337},
	{"LPOB", 4, 204338},
	{"LAVN", 4, 204339},
	{"LAOB", 4, 204340},
	{"KLIO", 4, 204341},
	{"KISQ", 4, 204342},
	{"KACQ", 4, 204343},
	{"IXIM", 4, 204344},
	{"HYIV", 4, 204345},
	{"GWIZ", 4, 204346},
	{"GAGH", 4, 204347},
	{"FGOG", 4, 204348},
	{"FEEU", 4, 204349},
	{"EZSD", 4, 204350},
	{"EWMR", 4, 204351},
	{"EFKO", 4, 204352},
	{"DZET", 4, 204353},
	{"DUSY", 4, 204354},
	{"BHID", 4, 204355},
	{"AZDI", 4, 204356},
	{"AFPO", 4, 204357},
	{"NDEX", 4, 204358},
	{"ENOSBURG", 8, 204359},
	{"PROPA", 5, 204360},
	{"OXIDISING", 9, 204361},
	{"BLOWTORCH", 9, 204362},
	{"ALLVIEW", 7, 204363},
	{"NUFORC", 6, 204364},
	{"LEME", 4, 204365},
	{"VORT", 4, 204366},
	{"ERESOURCES", 10, 204367},
	{"LFCT", 4, 204368},
	{"ZVONENIA", 8, 204369},
	{"DISTANZA", 8, 204370},
	{"TAMPONADE", 9, 204371},
	{"OFHEO", 5, 204372},
	{"MSUIC", 5, 204373},
	{"HYPOCHONDRIAC", 13, 204374},
	{"LIKLEY", 6, 204375},
	{"SYNOPTICS", 9, 204376},
	{"MALTINGS", 8, 204377},
	{"DENICE", 6, 204378},
	{"SCRI", 4, 204379},
	{"NJPPC", 5, 204380},
	{"DUNCES", 6, 204381},
	{"TUMBA", 5, 204382},
	{"BACCUS", 6, 204383},
	{"PAMI", 4, 204384},
	{"DRYOPTERIS", 10, 204385},
	{"SYMPATHIZER", 11, 204386},
	{"ISOHUNT", 7, 204387},
	{"BOICE", 5, 204388},
	{"AEALAOAU", 8, 204389},
	{"FREEWHEELS", 10, 204390},
	{"INVEN", 5, 204391},
	{"GLUME", 5, 204392},
	{"DAMNABLE", 8, 204393},
	{"GOFFIN", 6, 204394},
	{"ANTECHINUS", 10, 204395},
	{"TEXASHOLDEM", 11, 204396},
	{"JAGERMEISTER", 12, 204397},
	{"IRMS", 4, 204398},
	{"ROOTERS", 7, 204399},
	{"REBUM", 5, 204400},
	{"GIGANEWS", 8, 204401},
	{"MADHAV", 6, 204402},
	{"IMRG", 4, 204403},
	{"HANDYSPIELE", 11, 204404},
	{"HOEFFEL", 7, 204405},
	{"TALESE", 6, 204406},
	{"UNIBRAIN", 8, 204407},
	{"SLADEN", 6, 204408},
	{"REICHARD", 8, 204409},
	{"MAOIS", 5, 204410},
	{"SPITTIN", 7, 204411},
	{"FILION", 6, 204412},
	{"PERONEAL", 8, 204413},
	{"VTRS", 4, 204414},
	{"SWEETPEA", 8, 204415},
	{"DAMARISCOTTA", 12, 204416},
	{"DURAGESIC", 9, 204417},
	{"ANTIPORTER", 10, 204418},
	{"MYRIADOR", 8, 204419},
	{"ETRUSCANS", 9, 204420},
	{"PACKETSHAPER", 12, 204421},
	{"DILGER", 6, 204422},
	{"GOOGLI", 6, 204423},
	{"THOROFARE", 9, 204424},
	{"KUNDER", 6, 204425},
	{"SOPPING", 7, 204426},
	{"LUKIN", 5, 204427},
	{"KUYPER", 6, 204428},
	{"EZGO", 4, 204429},
	{"CPPCC", 5, 204430},
	{"POETA", 5, 204431},
	{"BIOETHICAL", 10, 204432},
	{"ACCELA", 6, 204433},
	{"NPCC", 4, 204434},
	{"BRUSHFIRE", 9, 204435},
	{"GALLEGLY", 8, 204436},
	{"LEGALI", 6, 204437},
	{"CCSF", 4, 204438},
	{"KONZEPT", 7, 204439},
	{"FASC", 4, 204440},
	{"TOUGHENING", 10, 204441},
	{"TECHSTREET", 10, 204442},
	{"HORZ", 4, 204443},
	{"URMILA", 6, 204444},
	{"OLENTANGY", 9, 204445},
	{"TELEVANGELIST", 13, 204446},
	{"SUGESTIONS", 10, 204447},
	{"LARIJANI", 8, 204448},
	{"FISHMONGERS", 11, 204449},
	{"HAGIOGRAPHY", 11, 204450},
	{"BLYTHEWOOD", 10, 204451},
	{"SMOOCHY", 7, 204452},
	{"BREAKZ", 6, 204453},
	{"NECROPHILIA", 11, 204454},
	{"LANIKAI", 7, 204455},
	{"PENDENCE", 8, 204456},
	{"YESSS", 5, 204457},
	{"EPSG", 4, 204458},
	{"DURRING", 7, 204459},
	{"MUSHER", 6, 204460},
	{"PEARPC", 6, 204461},
	{"GLENDALOUGH", 11, 204462},
	{"VERNALIS", 8, 204463},
	{"ULTRATECH", 9, 204464},
	{"SINDHU", 6, 204465},
	{"LABORATOIRES", 12, 204466},
	{"FACTORIA", 8, 204467},
	{"YATTON", 6, 204468},
	{"BRINES", 6, 204469},
	{"XCOM", 4, 204470},
	{"SUTRO", 5, 204471},
	{"BURGMAN", 7, 204472},
	{"NASCANNA", 8, 204473},
	{"EICOSAPENTAENOIC", 16, 204474},
	{"ANTENNES", 8, 204475},
	{"ZMAC", 4, 204476},
	{"XDRU", 4, 204477},
	{"USIU", 4, 204478},
	{"URLC", 4, 204479},
	{"UOBO", 4, 204480},
	{"UJAP", 4, 204481},
	{"UCYR", 4, 204482},
	{"THPK", 4, 204483},
	{"SIDG", 4, 204484},
	{"RYVU", 4, 204485},
	{"RYLG", 4, 204486},
	{"RNOJ", 4, 204487},
	{"RJIH", 4, 204488},
	{"RBME", 4, 204489},
	{"PHGA", 4, 204490},
	{"OZEB", 4, 204491},
	{"OWYF", 4, 204492},
	{"OFDT", 4, 204493},
	{"NSRY", 4, 204494},
	{"NJTR", 4, 204495},
	{"NGYT", 4, 204496},
	{"NDNW", 4, 204497},
	{"MUAM", 4, 204498},
	{"MTWA", 4, 204499},
	{"MEUC", 4, 204500},
	{"KOPL", 4, 204501},
	{"KEMD", 4, 204502},
	{"KAAG", 4, 204503},
	{"IMUH", 4, 204504},
	{"HYJE", 4, 204505},
	{"HNKU", 4, 204506},
	{"GECS", 4, 204507},
	{"GAOY", 4, 204508},
	{"FOAB", 4, 204509},
	{"FHOF", 4, 204510},
	{"EYAZ", 4, 204511},
	{"EKOZ", 4, 204512},
	{"EIQU", 4, 204513},
	{"DOFX", 4, 204514},
	{"DKIK", 4, 204515},
	{"DDUV", 4, 204516},
	{"CRCO", 4, 204517},
	{"CFRU", 4, 204518},
	{"CAOV", 4, 204519},
	{"BYND", 4, 204520},
	{"BPMA", 4, 204521},
	{"AWKG", 4, 204522},
	{"ARDX", 4, 204523},
	{"SONGSEARCH", 10, 204524},
	{"RINCONADA", 9, 204525},
	{"MYRDDIN", 7, 204526},
	{"DAVIDOVICH", 10, 204527},
	{"DGG", 3, 204528},
	{"NEEMAURA", 8, 204529},
	{"REIVERS", 7, 204530},
	{"GVP", 3, 204531},
	{"BLACKHAM", 8, 204532},
	{"TIRAGE", 6, 204533},
	{"SCRIPTWRITERS", 13, 204534},
	{"BRISON", 6, 204535},
	{"KEFFER", 6, 204536},
	{"JOMA", 4, 204537},
	{"DATAMATRIX", 10, 204538},
	{"COZIES", 6, 204539},
	{"RUNA", 4, 204540},
	{"CHAKRAVARTY", 11, 204541},
	{"BERISHA", 7, 204542},
	{"VERINO", 6, 204543},
	{"CRANWELL", 8, 204544},
	{"HOPFIELD", 8, 204545},
	{"MIMULUS", 7, 204546},
	{"FEISE", 5, 204547},
	{"SURFWEAR", 8, 204548},
	{"SCMS", 4, 204549},
	{"LIBWPD", 6, 204550},
	{"TOTTERED", 8, 204551},
	{"MYOCYTE", 7, 204552},
	{"MONETIZING", 10, 204553},
	{"CONCIERGES", 10, 204554},
	{"ZUL", 3, 204555},
	{"FZR", 3, 204556},
	{"SCHOBER", 7, 204557},
	{"OPINON", 6, 204558},
	{"KASHIF", 6, 204559},
	{"BEVACIZUMAB", 11, 204560},
	{"RAGTAG", 6, 204561},
	{"PROPRIOCEPTION", 14, 204562},
	{"FISHBURN", 8, 204563},
	{"NORMDOERING", 11, 204564},
	{"CCBS", 4, 204565},
	{"SINAIS", 6, 204566},
	{"PICSNUDE", 8, 204567},
	{"REMITS", 6, 204568},
	{"SIONALS", 7, 204569},
	{"MOODINESS", 9, 204570},
	{"ENVIORNMENT", 11, 204571},
	{"MESENGER", 8, 204572},
	{"SAMIAM", 6, 204573},
	{"PERROTT", 7, 204574},
	{"FISHMEAL", 8, 204575},
	{"EDINPHOTO", 9, 204576},
	{"CASHFLOWS", 9, 204577},
	{"ULEB", 4, 204578},
	{"HEUCHERA", 8, 204579},
	{"BAGUS", 5, 204580},
	{"DICAS", 5, 204581},
	{"FILIA", 5, 204582},
	{"FATEHPUR", 8, 204583},
	{"TOBRUK", 6, 204584},
	{"STARTCOM", 8, 204585},
	{"NAVIGABILITY", 12, 204586},
	{"COLONSAY", 8, 204587},
	{"BELLISSIMA", 10, 204588},
	{"VOLVULUS", 8, 204589},
	{"MACER", 5, 204590},
	{"FUHRMANN", 8, 204591},
	{"VIRCO", 5, 204592},
	{"MUTU", 4, 204593},
	{"GETIMAGE", 8, 204594},
	{"OXIMETERS", 9, 204595},
	{"MIHOV", 5, 204596},
	{"MOBILEHOME", 10, 204597},
	{"DSTPORT", 7, 204598},
	{"INTERREGNUM", 11, 204599},
	{"SCHUHE", 6, 204600},
	{"COTURNIX", 8, 204601},
	{"EMPRESARIAL", 11, 204602},
	{"DROPBOX", 7, 204603},
	{"HEMPFIELD", 9, 204604},
	{"ROBLIN", 6, 204605},
	{"MECLIZINE", 9, 204606},
	{"POSTTRANSLATIONAL", 17, 204607},
	{"AVIANCA", 7, 204608},
	{"AKOMH", 5, 204609},
	{"UNIFIER", 7, 204610},
	{"IRECTOR", 7, 204611},
	{"ZUBAIR", 6, 204612},
	{"RIGHTIES", 8, 204613},
	{"ANTITOXIN", 9, 204614},
	{"THEIL", 5, 204615},
	{"PORIN", 5, 204616},
	{"JUNAID", 6, 204617},
	{"CACCIATORE", 10, 204618},
	{"PLAGES", 6, 204619},
	{"KOZO", 4, 204620},
	{"DISDAINED", 9, 204621},
	{"HARSTAD", 7, 204622},
	{"USCOLLEGESEARCH", 15, 204623},
	{"TRIMER", 6, 204624},
	{"PERSIMMONS", 10, 204625},
	{"PREDISPOSES", 11, 204626},
	{"BUSSELL", 7, 204627},
	{"TRAVELPOD", 9, 204628},
	{"RECIBIR", 7, 204629},
	{"WWWALTAVISTA", 12, 204630},
	{"WHIPPETS", 8, 204631},
	{"OEDIPAL", 7, 204632},
	{"GALERI", 6, 204633},
	{"COLLUM", 6, 204634},
	{"FREU", 4, 204635},
	{"CLAWBACK", 8, 204636},
	{"ACDBLAYERTABLERECORD", 20, 204637},
	{"STREETWIRES", 11, 204638},
	{"REVVER", 6, 204639},
	{"ATOMIZERS", 9, 204640},
	{"BLEV", 4, 204641},
	{"ANEMOMETERS", 11, 204642},
	{"SEEDINGS", 8, 204643},
	{"TREENODE", 8, 204644},
	{"RICEHAMMER", 10, 204645},
	{"BARETTA", 7, 204646},
	{"ALVOR", 5, 204647},
	{"ZZYF", 4, 204648},
	{"ZAPU", 4, 204649},
	{"YWIV", 4, 204650},
	{"YKOW", 4, 204651},
	{"XBYS", 4, 204652},
	{"XARK", 4, 204653},
	{"WVAA", 4, 204654},
	{"WPON", 4, 204655},
	{"WOJT", 4, 204656},
	{"UYPL", 4, 204657},
	{"UXEE", 4, 204658},
	{"UKME", 4, 204659},
	{"TZKO", 4, 204660},
	{"TDAZ", 4, 204661},
	{"TACM", 4, 204662},
	{"SYFL", 4, 204663},
	{"SMFT", 4, 204664},
	{"SLPR", 4, 204665},
	{"SFBI", 4, 204666},
	{"SDMO", 4, 204667},
	{"SDDE", 4, 204668},
	{"RLPL", 4, 204669},
	{"RGYV", 4, 204670},
	{"PYJO", 4, 204671},
	{"PHYK", 4, 204672},
	{"OYUG", 4, 204673},
	{"OGEC", 4, 204674},
	{"NDVC", 4, 204675},
	{"MOHU", 4, 204676},
	{"LGIT", 4, 204677},
	{"LAOW", 4, 204678},
	{"KILW", 4, 204679},
	{"IOFJ", 4, 204680},
	{"IKGO", 4, 204681},
	{"HYVA", 4, 204682},
	{"FTAJ", 4, 204683},
	{"FOKE", 4, 204684},
	{"FIUM", 4, 204685},
	{"FIKA", 4, 204686},
	{"FEHU", 4, 204687},
	{"ELKW", 4, 204688},
	{"EFCS", 4, 204689},
	{"EACB", 4, 204690},
	{"CDBA", 4, 204691},
	{"CBYD", 4, 204692},
	{"BNFO", 4, 204693},
	{"BLIL", 4, 204694},
	{"BJEL", 4, 204695},
	{"AZBA", 4, 204696},
	{"AXEF", 4, 204697},
	{"AMMV", 4, 204698},
	{"ACAQ", 4, 204699},
	{"VIRAMUNE", 8, 204700},
	{"CONCILIATOR", 11, 204701},
	{"IMTIAZ", 6, 204702},
	{"HISTORICO", 9, 204703},
	{"EHMAC", 5, 204704},
	{"KOPECKY", 7, 204705},
	{"PLAYON", 6, 204706},
	{"MILOSZ", 6, 204707},
	{"KOMMATOS", 8, 204708},
	{"JAVASOFT", 8, 204709},
	{"KASTORIA", 8, 204710},
	{"EYRWPAIKH", 9, 204711},
	{"DRUCKMASCHINEN", 14, 204712},
	{"CLOBETASOL", 10, 204713},
	{"JCOP", 4, 204714},
	{"LIGHTOLIER", 10, 204715},
	{"YUDKOWSKY", 9, 204716},
	{"DERMATOSES", 10, 204717},
	{"ASPECTUAL", 9, 204718},
	{"BIBBS", 5, 204719},
	{"KARNI", 5, 204720},
	{"AUDRE", 5, 204721},
	{"ANHYDRIDES", 10, 204722},
	{"SCHNITZLER", 10, 204723},
	{"MONTALBAN", 9, 204724},
	{"BVP", 3, 204725},
	{"SQLJ", 4, 204726},
	{"BETELGEUSE", 10, 204727},
	{"MARYLOU", 7, 204728},
	{"HAYMAKER", 8, 204729},
	{"CAIL", 4, 204730},
	{"INDICTS", 7, 204731},
	{"FRUITFULLY", 10, 204732},
	{"CHAROLAIS", 9, 204733},
	{"MUDFLAP", 7, 204734},
	{"BRONTOSAURUS", 12, 204735},
	{"ASCIDIAN", 8, 204736},
	{"VASEL", 5, 204737},
	{"VANHANEN", 8, 204738},
	{"SULFATED", 8, 204739},
	{"DECHLORINATION", 14, 204740},
	{"DBENV", 5, 204741},
	{"DOMDORN", 7, 204742},
	{"CORFE", 5, 204743},
	{"ERROLL", 6, 204744},
	{"BIASCO", 6, 204745},
	{"GESOURCE", 8, 204746},
	{"EVERGREY", 8, 204747},
	{"WALBERG", 7, 204748},
	{"VERSON", 6, 204749},
	{"SICKNESSES", 10, 204750},
	{"EGIONAL", 7, 204751},
	{"DESTOP", 6, 204752},
	{"SORGENFREI", 10, 204753},
	{"SHRIVEL", 7, 204754},
	{"OUVRAGES", 8, 204755},
	{"JELCO", 5, 204756},
	{"INDEPENENT", 10, 204757},
	{"DALLEY", 6, 204758},
	{"RECRUITMENTS", 12, 204759},
	{"HOMEWORKING", 11, 204760},
	{"ORED", 4, 204761},
	{"HONEGGER", 8, 204762},
	{"MAGRATH", 7, 204763},
	{"EDGARD", 6, 204764},
	{"CREAMING", 8, 204765},
	{"AVAIENT", 7, 204766},
	{"ANEURIN", 7, 204767},
	{"SUMMERSLAM", 10, 204768},
	{"JOURNALSPACE", 12, 204769},
	{"MEDAILLE", 8, 204770},
	{"BUNNIE", 6, 204771},
	{"WWWGOOGLECOM", 12, 204772},
	{"EMULADOR", 8, 204773},
	{"DADEVILLE", 9, 204774},
	{"CUPPLES", 7, 204775},
	{"CLAIRVOYANTS", 12, 204776},
	{"BSBA", 4, 204777},
	{"BIKIN", 5, 204778},
	{"QUANTITATED", 11, 204779},
	{"DROGEN", 6, 204780},
	{"MATAMORAS", 9, 204781},
	{"COSINES", 7, 204782},
	{"PICTISH", 7, 204783},
	{"GREENGRASS", 10, 204784},
	{"TRAINLINE", 9, 204785},
	{"DISTRIBS", 8, 204786},
	{"SELINGER", 8, 204787},
	{"LEVELONE", 8, 204788},
	{"LASSA", 5, 204789},
	{"HALEVY", 6, 204790},
	{"GRIPPY", 6, 204791},
	{"SAFAVIEH", 8, 204792},
	{"FUCOSE", 6, 204793},
	{"BCSC", 4, 204794},
	{"MUNTZ", 5, 204795},
	{"RIFAT", 5, 204796},
	{"BURNTISLAND", 11, 204797},
	{"BOOKBYTE", 8, 204798},
	{"KASSIM", 6, 204799},
	{"FIELDNOTES", 10, 204800},
	{"TRINIDADIAN", 11, 204801},
	{"SHOCKPROOF", 10, 204802},
	{"MCLARTY", 7, 204803},
	{"LIBDVDCSS", 9, 204804},
	{"AMENDOLA", 8, 204805},
	{"PHILLPPE", 8, 204806},
	{"EMPREGOS", 8, 204807},
	{"NONCITIZENS", 11, 204808},
	{"YDQ", 3, 204809},
	{"TOKER", 5, 204810},
	{"RENUM", 5, 204811},
	{"UNAMERICAN", 10, 204812},
	{"TAKUMA", 6, 204813},
	{"SKAM", 4, 204814},
	{"SEANAID", 7, 204815},
	{"BIGEST", 6, 204816},
	{"KPATHSEA", 8, 204817},
	{"GAMEPORT", 8, 204818},
	{"COEXPRESSION", 12, 204819},
	{"FONER", 5, 204820},
	{"CAPLETON", 8, 204821},
	{"FUZEON", 6, 204822},
	{"NUTOOL", 6, 204823},
	{"KEYMARK", 7, 204824},
	{"BYEBYE", 6, 204825},
	{"DRIPPY", 6, 204826},
	{"MOONTA", 6, 204827},
	{"EYRIE", 5, 204828},
	{"SHIPSHEWANA", 11, 204829},
	{"FIRSTFRUITS", 11, 204830},
	{"ORUM", 4, 204831},
	{"THERMORE", 8, 204832},
	{"SNICKERING", 10, 204833},
	{"BARLOWS", 7, 204834},
	{"FORTENBERRY", 11, 204835},
	{"SUBHARMONIC", 11, 204836},
	{"HIVEMAIL", 8, 204837},
	{"HOPALONG", 8, 204838},
	{"THEORISING", 10, 204839},
	{"MADDOCKS", 8, 204840},
	{"LINGERIES", 9, 204841},
	{"SPESCOM", 7, 204842},
	{"RATZ", 4, 204843},
	{"MARPLAN", 7, 204844},
	{"SUPERBOOKDEALS", 14, 204845},
	{"HAEMOSTASIS", 11, 204846},
	{"NEWSBUSTERS", 11, 204847},
	{"HENDLEY", 7, 204848},
	{"KRANEVO", 7, 204849},
	{"YMLA", 4, 204850},
	{"YLCA", 4, 204851},
	{"YDFO", 4, 204852},
	{"YAAM", 4, 204853},
	{"XICD", 4, 204854},
	{"WMYD", 4, 204855},
	{"WMRS", 4, 204856},
	{"VYAD", 4, 204857},
	{"UMSV", 4, 204858},
	{"UFUL", 4, 204859},
	{"QMAG", 4, 204860},
	{"OGVI", 4, 204861},
	{"OFTJ", 4, 204862},
	{"NLUA", 4, 204863},
	{"NJRI", 4, 204864},
	{"MDOA", 4, 204865},
	{"LVIK", 4, 204866},
	{"LLCP", 4, 204867},
	{"LEHD", 4, 204868},
	{"KSUT", 4, 204869},
	{"KOEP", 4, 204870},
	{"KHEK", 4, 204871},
	{"JRAM", 4, 204872},
	{"IJKA", 4, 204873},
	{"IBSB", 4, 204874},
	{"HYTU", 4, 204875},
	{"GCAF", 4, 204876},
	{"EWAZ", 4, 204877},
	{"EVYP", 4, 204878},
	{"EDJR", 4, 204879},
	{"EBPE", 4, 204880},
	{"DMSD", 4, 204881},
	{"DHYS", 4, 204882},
	{"CDUS", 4, 204883},
	{"BOKC", 4, 204884},
	{"BCES", 4, 204885},
	{"LOKER", 5, 204886},
	{"CONTEXTO", 8, 204887},
	{"PARTWAY", 7, 204888},
	{"MANGESHKAR", 10, 204889},
	{"KEFLAVIK", 8, 204890},
	{"DAIRE", 5, 204891},
	{"BLACKHORSE", 10, 204892},
	{"NERISSA", 7, 204893},
	{"IFUP", 4, 204894},
	{"ROLETTE", 7, 204895},
	{"SPLICEOSOME", 11, 204896},
	{"MEMORIALIZING", 13, 204897},
	{"GROV", 4, 204898},
	{"USSF", 4, 204899},
	{"ISOSURFACE", 10, 204900},
	{"BLANKINGOFF", 11, 204901},
	{"TAKIS", 5, 204902},
	{"PESTOVA", 7, 204903},
	{"JUTS", 4, 204904},
	{"SYRINGA", 7, 204905},
	{"SATURNALIA", 10, 204906},
	{"ONCHOCERCIASIS", 14, 204907},
	{"SCREENIES", 9, 204908},
	{"HODIE", 5, 204909},
	{"BENBECULA", 9, 204910},
	{"DOWNSHIFT", 9, 204911},
	{"PAYBACKS", 8, 204912},
	{"MORANG", 6, 204913},
	{"FINDHORN", 8, 204914},
	{"PILT", 4, 204915},
	{"NEUROLOGICALLY", 14, 204916},
	{"HELLOW", 6, 204917},
	{"DIVINO", 6, 204918},
	{"MMPA", 4, 204919},
	{"DMODULE", 7, 204920},
	{"REINSTATES", 10, 204921},
	{"SOLUTIO", 7, 204922},
	{"ROHRBACH", 8, 204923},
	{"URANYL", 6, 204924},
	{"RAGU", 4, 204925},
	{"SALSBURY", 8, 204926},
	{"DIBIANCO", 8, 204927},
	{"CFINGERD", 8, 204928},
	{"FCCLA", 5, 204929},
	{"CENTERICQ", 9, 204930},
	{"QUICKBASIC", 10, 204931},
	{"XJACK", 5, 204932},
	{"VANZETTI", 8, 204933},
	{"LAOTHIAN", 8, 204934},
	{"JAMILA", 6, 204935},
	{"TAVEUNI", 7, 204936},
	{"TAINTS", 6, 204937},
	{"SZCZAWNICA", 10, 204938},
	{"SYVUM", 5, 204939},
	{"QUANTIZE", 8, 204940},
	{"DARAN", 5, 204941},
	{"NOSTALGIE", 9, 204942},
	{"NEUROPROTECTION", 15, 204943},
	{"BRICKTOWN", 9, 204944},
	{"URRENT", 6, 204945},
	{"RESUL", 5, 204946},
	{"DOKEY", 5, 204947},
	{"VANTAGEPOINT", 12, 204948},
	{"TENDO", 5, 204949},
	{"ABANO", 5, 204950},
	{"DARYLL", 6, 204951},
	{"BAWLS", 5, 204952},
	{"DACH", 4, 204953},
	{"TITLERS", 7, 204954},
	{"KAWANA", 6, 204955},
	{"SUBCOMMENTS", 11, 204956},
	{"ENKIDU", 6, 204957},
	{"UNCORROBORATED", 14, 204958},
	{"AZAZEL", 6, 204959},
	{"MONEYBALL", 9, 204960},
	{"ASMODAI", 7, 204961},
	{"AKTUALISIERT", 12, 204962},
	{"UNTYING", 7, 204963},
	{"PERTHNASOL", 10, 204964},
	{"PATOKA", 6, 204965},
	{"PSYCHOPATHY", 11, 204966},
	{"RELIQUARY", 9, 204967},
	{"ABAG", 4, 204968},
	{"FAXMODEM", 8, 204969},
	{"CINEVISTA", 9, 204970},
	{"GPST", 4, 204971},
	{"LOGARITHMICALLY", 15, 204972},
	{"PVST", 4, 204973},
	{"EFAVORITES", 10, 204974},
	{"WESTERLUND", 10, 204975},
	{"CYBERTERRORISM", 14, 204976},
	{"RESCISSIONS", 11, 204977},
	{"MOTOCYCLE", 9, 204978},
	{"BOONIES", 7, 204979},
	{"NOVALIS", 7, 204980},
	{"SUPERHEROS", 10, 204981},
	{"WIGO", 4, 204982},
	{"EMDA", 4, 204983},
	{"DNTP", 4, 204984},
	{"CONTRABASS", 10, 204985},
	{"BRINKSTER", 9, 204986},
	{"ALSTEAD", 7, 204987},
	{"SINCLAIRE", 9, 204988},
	{"HIGGINSVILLE", 12, 204989},
	{"BEMORECREATIVE", 14, 204990},
	{"SLIGHTS", 7, 204991},
	{"OBERTAUERN", 10, 204992},
	{"CAMOSUN", 7, 204993},
	{"ABRIDGEMENT", 11, 204994},
	{"YOKEL", 5, 204995},
	{"KUROKAWA", 8, 204996},
	{"BREADFRUIT", 10, 204997},
	{"SEMILEPTONIC", 12, 204998},
	{"ENMORE", 6, 204999},
	{"DAYVILLE", 8, 205000},
	{"WMST", 4, 205001},
	{"MARISCAL", 8, 205002},
	{"LAKENHEATH", 10, 205003},
	{"EMINI", 5, 205004},
	{"CPPA", 4, 205005},
	{"ZELNORM", 7, 205006},
	{"RABA", 4, 205007},
	{"INFRINGERS", 10, 205008},
	{"MEHRAN", 6, 205009},
	{"JPEGQUALITY", 11, 205010},
	{"GILLICK", 7, 205011},
	{"EFITS", 5, 205012},
	{"CIERRA", 6, 205013},
	{"SYMFONY", 7, 205014},
	{"YNSM", 4, 205015},
	{"XEQU", 4, 205016},
	{"VYJO", 4, 205017},
	{"VSGR", 4, 205018},
	{"UYTW", 4, 205019},
	{"UUMP", 4, 205020},
	{"ULKD", 4, 205021},
	{"UDSD", 4, 205022},
	{"TPMG", 4, 205023},
	{"RZEZ", 4, 205024},
	{"RCIP", 4, 205025},
	{"PMEW", 4, 205026},
	{"OUHY", 4, 205027},
	{"OFGC", 4, 205028},
	{"NOLG", 4, 205029},
	{"NMWA", 4, 205030},
	{"MOXE", 4, 205031},
	{"MIOP", 4, 205032},
	{"MEYC", 4, 205033},
	{"LSMV", 4, 205034},
	{"LPDU", 4, 205035},
	{"LCYY", 4, 205036},
	{"LAHY", 4, 205037},
	{"KUNW", 4, 205038},
	{"IYUS", 4, 205039},
	{"IFUM", 4, 205040},
	{"HYSK", 4, 205041},
	{"HRWH", 4, 205042},
	{"FYNO", 4, 205043},
	{"FMAB", 4, 205044},
	{"EXUP", 4, 205045},
	{"DTVB", 4, 205046},
	{"BOID", 4, 205047},
	{"BMAG", 4, 205048},
	{"ARPK", 4, 205049},
	{"MOROZOV", 7, 205050},
	{"VIRTUALES", 9, 205051},
	{"THROBS", 6, 205052},
	{"ENDIANNESS", 10, 205053},
	{"CONDUCTIVITIES", 14, 205054},
	{"BUNYA", 5, 205055},
	{"YUYAO", 5, 205056},
	{"INSTALLDIRS", 11, 205057},
	{"GARHWAL", 7, 205058},
	{"WHITENED", 8, 205059},
	{"OPENCCM", 7, 205060},
	{"IERROR", 6, 205061},
	{"DECEPTICONS", 11, 205062},
	{"FOLLICULITIS", 12, 205063},
	{"LELY", 4, 205064},
	{"BILES", 5, 205065},
	{"PETROCHINA", 10, 205066},
	{"GABS", 4, 205067},
	{"EVERYTHIN", 9, 205068},
	{"FRITCH", 6, 205069},
	{"BURPS", 5, 205070},
	{"SCHOCH", 6, 205071},
	{"ATREUS", 6, 205072},
	{"ROSSEN", 6, 205073},
	{"SUBCULTURAL", 11, 205074},
	{"WARNKE", 6, 205075},
	{"SERAL", 5, 205076},
	{"SANDYFORD", 9, 205077},
	{"GENOESE", 7, 205078},
	{"CAPELLE", 7, 205079},
	{"PRINCIP", 7, 205080},
	{"MULTIPHOTON", 11, 205081},
	{"UNPERSUASIVE", 12, 205082},
	{"SHANNYN", 7, 205083},
	{"PARFUMEUR", 9, 205084},
	{"SAIDA", 5, 205085},
	{"DOSTER", 6, 205086},
	{"ANTIDISCRIMINATION", 18, 205087},
	{"PARVEZ", 6, 205088},
	{"VIDEOTEX", 8, 205089},
	{"CEAUSESCU", 9, 205090},
	{"PREFORMS", 8, 205091},
	{"XFSPROGS", 8, 205092},
	{"INCLOSED", 8, 205093},
	{"MYPROXY", 7, 205094},
	{"HEPATICA", 8, 205095},
	{"FLAGELLATION", 12, 205096},
	{"VRX", 3, 205097},
	{"IMMUNOMODULATORY", 16, 205098},
	{"DRAADLOOS", 9, 205099},
	{"WORLDMAP", 8, 205100},
	{"RIECE", 5, 205101},
	{"IDCIN", 5, 205102},
	{"AUDIOMETRIC", 11, 205103},
	{"SYNOVITIS", 9, 205104},
	{"FISHPONDS", 9, 205105},
	{"BKD", 3, 205106},
	{"TREEBANK", 8, 205107},
	{"PROSPECTIVES", 12, 205108},
	{"LEOD", 4, 205109},
	{"ERBS", 4, 205110},
	{"STAMPANTI", 9, 205111},
	{"HEARED", 6, 205112},
	{"DUPELESS", 8, 205113},
	{"STEYNING", 8, 205114},
	{"TIMESHARING", 11, 205115},
	{"CARTONNETWORK", 13, 205116},
	{"BLEEPS", 6, 205117},
	{"COUCHE", 6, 205118},
	{"CABRAMATTA", 10, 205119},
	{"REPOSTS", 7, 205120},
	{"NODC", 4, 205121},
	{"DIARKEIA", 8, 205122},
	{"AUGUSTEN", 8, 205123},
	{"SHOPP", 5, 205124},
	{"REKEY", 5, 205125},
	{"BOLINGER", 8, 205126},
	{"PHOTEK", 6, 205127},
	{"ELITA", 5, 205128},
	{"EXPIRATIONS", 11, 205129},
	{"ASTROMART", 9, 205130},
	{"VENIPUNCTURE", 12, 205131},
	{"PLEXITY", 7, 205132},
	{"COGNOSCENTI", 11, 205133},
	{"TRUTHVALUE", 10, 205134},
	{"EXPORTFORMAT", 12, 205135},
	{"CUSTIS", 6, 205136},
	{"SELEZIONA", 9, 205137},
	{"PLPLOT", 6, 205138},
	{"GUERRIERO", 9, 205139},
	{"COMERGENT", 9, 205140},
	{"LONGMIRE", 8, 205141},
	{"APRE", 4, 205142},
	{"EMBARRASED", 10, 205143},
	{"DISMOUNTING", 11, 205144},
	{"PROCEDE", 7, 205145},
	{"KILLIFISH", 9, 205146},
	{"GEMOLOGIST", 10, 205147},
	{"SCRUTINISING", 12, 205148},
	{"RMMOD", 5, 205149},
	{"PLAYARDS", 8, 205150},
	{"RELEASESNEW", 11, 205151},
	{"BLOMQVIST", 9, 205152},
	{"RUSI", 4, 205153},
	{"SPONDYLOLISTHESIS", 17, 205154},
	{"EFORUM", 6, 205155},
	{"VINDALOO", 8, 205156},
	{"RATIONALISTS", 12, 205157},
	{"INDICATEURS", 11, 205158},
	{"WOODSHOP", 8, 205159},
	{"JACKE", 5, 205160},
	{"AGONISTIC", 9, 205161},
	{"PHINDA", 6, 205162},
	{"BIZEXPRESS", 10, 205163},
	{"CRAVEWORTHY", 11, 205164},
	{"HOTMA", 5, 205165},
	{"HQDA", 4, 205166},
	{"DRAMAMINE", 9, 205167},
	{"TAGEBUCH", 8, 205168},
	{"MURREY", 6, 205169},
	{"JUDKINS", 7, 205170},
	{"OFFERMAN", 8, 205171},
	{"INQUESTS", 8, 205172},
	{"LAZNE", 5, 205173},
	{"JACKD", 5, 205174},
	{"DOUBTFIRE", 9, 205175},
	{"RICHERT", 7, 205176},
	{"FATTENED", 8, 205177},
	{"MIDPOINTS", 9, 205178},
	{"SUBSTITUTABLE", 13, 205179},
	{"POLYCARP", 8, 205180},
	{"INTHIS", 6, 205181},
	{"TERRYVILLE", 10, 205182},
	{"OTELLINI", 8, 205183},
	{"LISTOWNER", 9, 205184},
	{"BUSQUE", 6, 205185},
	{"ZEKO", 4, 205186},
	{"XSFI", 4, 205187},
	{"XEFF", 4, 205188},
	{"WMIA", 4, 205189},
	{"VYGA", 4, 205190},
	{"VJON", 4, 205191},
	{"UXSO", 4, 205192},
	{"UOUR", 4, 205193},
	{"UFLO", 4, 205194},
	{"TUIL", 4, 205195},
	{"TMLF", 4, 205196},
	{"SXRE", 4, 205197},
	{"RYTV", 4, 205198},
	{"RAJG", 4, 205199},
	{"PHUO", 4, 205200},
	{"PCDE", 4, 205201},
	{"OBEZ", 4, 205202},
	{"NRDP", 4, 205203},
	{"NOVV", 4, 205204},
	{"MUTF", 4, 205205},
	{"LORQ", 4, 205206},
	{"KIIC", 4, 205207},
	{"KAOK", 4, 205208},
	{"IDRH", 4, 205209},
	{"HYSF", 4, 205210},
	{"HIKW", 4, 205211},
	{"GTWA", 4, 205212},
	{"GSIK", 4, 205213},
	{"GMBR", 4, 205214},
	{"EUCU", 4, 205215},
	{"ETUV", 4, 205216},
	{"EJLA", 4, 205217},
	{"EECM", 4, 205218},
	{"ECCU", 4, 205219},
	{"EBFE", 4, 205220},
	{"DBLV", 4, 205221},
	{"DAHB", 4, 205222},
	{"CEEW", 4, 205223},
	{"BVOL", 4, 205224},
	{"BCME", 4, 205225},
	{"ANLB", 4, 205226},
	{"AKYI", 4, 205227},
	{"AGFE", 4, 205228},
	{"PLANCHE", 7, 205229},
	{"HULSEY", 6, 205230},
	{"SPAWNERS", 8, 205231},
	{"EQLV", 4, 205232},
	{"ECKS", 4, 205233},
	{"WHOOPIE", 7, 205234},
	{"SWAINE", 6, 205235},
	{"PARLAMENT", 9, 205236},
	{"PREPA", 5, 205237},
	{"VASARI", 6, 205238},
	{"MELLISH", 7, 205239},
	{"STULTZ", 6, 205240},
	{"WINDROW", 7, 205241},
	{"DEFINTELY", 9, 205242},
	{"CASTI", 5, 205243},
	{"ABDUCTING", 9, 205244},
	{"POSTR", 5, 205245},
	{"BELVA", 5, 205246},
	{"ROFESSIONAL", 11, 205247},
	{"MYGEN", 5, 205248},
	{"DEATHTRAP", 9, 205249},
	{"BERENS", 6, 205250},
	{"WMAL", 4, 205251},
	{"JILBAB", 6, 205252},
	{"SAMPLETANK", 10, 205253},
	{"HESLOP", 6, 205254},
	{"BROADHEADS", 10, 205255},
	{"RELATIONSHI", 11, 205256},
	{"HANSHIN", 7, 205257},
	{"BOTAS", 5, 205258},
	{"WIKIFORMATTING", 14, 205259},
	{"PARSEABLE", 9, 205260},
	{"YEMA", 4, 205261},
	{"ANTONELLO", 9, 205262},
	{"SLOOT", 5, 205263},
	{"PETROCHEM", 9, 205264},
	{"FREIER", 6, 205265},
	{"RETOOL", 6, 205266},
	{"LANTHANIDE", 10, 205267},
	{"GRAPHISTOCK", 11, 205268},
	{"DODIE", 5, 205269},
	{"TYAGI", 5, 205270},
	{"MYRURGIA", 8, 205271},
	{"FARFETCHED", 10, 205272},
	{"PREMINGER", 9, 205273},
	{"MEURER", 6, 205274},
	{"ENKEL", 5, 205275},
	{"BRENTA", 6, 205276},
	{"JUPE", 4, 205277},
	{"PLANUM", 6, 205278},
	{"HEWITSON", 8, 205279},
	{"WFL", 3, 205280},
	{"ENANTIOSELECTIVE", 16, 205281},
	{"SINDRA", 6, 205282},
	{"RAYTEK", 6, 205283},
	{"CAVERTA", 7, 205284},
	{"TOWERGROUP", 10, 205285},
	{"JERONIMI", 8, 205286},
	{"IMMUNOSUPPRESSED", 16, 205287},
	{"MUNE", 4, 205288},
	{"GVR", 3, 205289},
	{"NEGOZIO", 7, 205290},
	{"PAEDOPHILIA", 11, 205291},
	{"TEETHER", 7, 205292},
	{"LAXPOWER", 8, 205293},
	{"GRUPP", 5, 205294},
	{"TIING", 5, 205295},
	{"ACTIE", 5, 205296},
	{"REALSECURE", 10, 205297},
	{"TOADIES", 7, 205298},
	{"HEATHS", 6, 205299},
	{"AHTOPOL", 7, 205300},
	{"ACQUISI", 7, 205301},
	{"SCMP", 4, 205302},
	{"CHATEL", 6, 205303},
	{"BURAS", 5, 205304},
	{"CYNNYDD", 7, 205305},
	{"PERSICA", 7, 205306},
	{"GSPH", 4, 205307},
	{"RUGGEDLY", 8, 205308},
	{"POLYNOMIALLY", 12, 205309},
	{"FENOFIBRATE", 11, 205310},
	{"DORIE", 5, 205311},
	{"GRABAR", 6, 205312},
	{"ENJOINS", 7, 205313},
	{"AXILLA", 6, 205314},
	{"OPERONS", 7, 205315},
	{"VISTOR", 6, 205316},
	{"TERRESTRE", 9, 205317},
	{"INSUPERABLE", 11, 205318},
	{"DEADBEATS", 9, 205319},
	{"ZIPING", 6, 205320},
	{"CAAR", 4, 205321},
	{"ENERG", 5, 205322},
	{"BRAINTEASER", 11, 205323},
	{"SIDDIQUE", 8, 205324},
	{"RECAPITULATE", 12, 205325},
	{"BOKO", 4, 205326},
	{"AGAPANTHUS", 10, 205327},
	{"TLAXCALA", 8, 205328},
	{"JOLLIFFE", 8, 205329},
	{"MABUSE", 6, 205330},
	{"ALLAMAKEE", 9, 205331},
	{"WAZZUP", 6, 205332},
	{"LAVALLE", 7, 205333},
	{"FULVIO", 6, 205334},
	{"EBUDDY", 6, 205335},
	{"TDCJ", 4, 205336},
	{"HIGHEND", 7, 205337},
	{"DRAYS", 5, 205338},
	{"DISFAVORED", 10, 205339},
	{"SCHELER", 7, 205340},
	{"ATHENRY", 7, 205341},
	{"RESTER", 6, 205342},
	{"CHEMILUMINESCENT", 16, 205343},
	{"BRANSCOMB", 9, 205344},
	{"POLIZEI", 7, 205345},
	{"CANTIN", 6, 205346},
	{"CARDSSEND", 9, 205347},
	{"WARINESS", 8, 205348},
	{"ARCSECS", 7, 205349},
	{"SOFTCAM", 7, 205350},
	{"ROSENGREN", 9, 205351},
	{"CLEANMYPC", 9, 205352},
	{"OVIES", 5, 205353},
	{"ENCEINTE", 8, 205354},
	{"TAUERNE", 7, 205355},
	{"SCROUNGE", 8, 205356},
	{"XPAT", 4, 205357},
	{"INVENTORYING", 12, 205358},
	{"AMALGAMATING", 12, 205359},
	{"ACTIS", 5, 205360},
	{"WISHER", 6, 205361},
	{"DAGLI", 5, 205362},
	{"PRIMIS", 6, 205363},
	{"OPORTUNITY", 10, 205364},
	{"NTPC", 4, 205365},
	{"VANCEUR", 7, 205366},
	{"TESTDIRECTOR", 12, 205367},
	{"EQUISETUM", 9, 205368},
	{"GRUNDGEBUEHR", 12, 205369},
	{"ZZW", 3, 205370},
	{"HYBRIDIZE", 9, 205371},
	{"STARLIT", 7, 205372},
	{"POLECAMY", 8, 205373},
	{"DISTRIBUTORSHIPS", 16, 205374},
	{"BANKRUPCY", 9, 205375},
	{"WOHNEN", 6, 205376},
	{"QUETICO", 7, 205377},
	{"MCALEESE", 8, 205378},
	{"RPCI", 4, 205379},
	{"HAYFORD", 7, 205380},
	{"YPTP", 4, 205381},
	{"YIOF", 4, 205382},
	{"VSME", 4, 205383},
	{"UDIK", 4, 205384},
	{"TUSZ", 4, 205385},
	{"TKOU", 4, 205386},
	{"POLW", 4, 205387},
	{"OODZ", 4, 205388},
	{"OFKP", 4, 205389},
	{"NCPE", 4, 205390},
	{"MDOD", 4, 205391},
	{"LDUF", 4, 205392},
	{"KYTI", 4, 205393},
	{"KKIH", 4, 205394},
	{"IMKU", 4, 205395},
	{"HMUM", 4, 205396},
	{"HKOD", 4, 205397},
	{"HIDC", 4, 205398},
	{"HCYB", 4, 205399},
	{"GIYA", 4, 205400},
	{"GELJ", 4, 205401},
	{"FYFI", 4, 205402},
	{"FLSD", 4, 205403},
	{"EZSB", 4, 205404},
	{"EYIP", 4, 205405},
	{"EWHL", 4, 205406},
	{"EMJE", 4, 205407},
	{"EKUI", 4, 205408},
	{"EGMB", 4, 205409},
	{"BYUB", 4, 205410},
	{"BMCD", 4, 205411},
	{"AWSV", 4, 205412},
	{"AMCN", 4, 205413},
	{"AJOW", 4, 205414},
	{"AFIQ", 4, 205415},
	{"SIDDUR", 6, 205416},
	{"ENODEV", 6, 205417},
	{"SWINGLE", 7, 205418},
	{"SHIHAN", 6, 205419},
	{"GLOBALIZE", 9, 205420},
	{"CARBONEAR", 9, 205421},
	{"SUPERTYPE", 9, 205422},
	{"DALLMAN", 7, 205423},
	{"WILHELMS", 8, 205424},
	{"GPSS", 4, 205425},
	{"GALLAS", 6, 205426},
	{"MONTR", 5, 205427},
	{"ROVIRA", 6, 205428},
	{"PGMS", 4, 205429},
	{"KRALOVE", 7, 205430},
	{"FOLEX", 5, 205431},
	{"VENDEUR", 7, 205432},
	{"HIGHSTREET", 10, 205433},
	{"CROSSTRACK", 10, 205434},
	{"ACROPORA", 8, 205435},
	{"UNVACCINATED", 12, 205436},
	{"FACULTE", 7, 205437},
	{"DOCT", 4, 205438},
	{"SPOHR", 5, 205439},
	{"INAUSPICIOUS", 12, 205440},
	{"CYBERINFRASTRUCTURE", 19, 205441},
	{"VUW", 3, 205442},
	{"CULLIN", 6, 205443},
	{"USUD", 4, 205444},
	{"EBRARY", 6, 205445},
	{"DIALYSATE", 9, 205446},
	{"LATERALIS", 9, 205447},
	{"AICHNER", 7, 205448},
	{"CNNNEWS", 7, 205449},
	{"BOULTER", 7, 205450},
	{"SYMBIANONE", 10, 205451},
	{"MILHAUD", 7, 205452},
	{"CREP", 4, 205453},
	{"ARNNET", 6, 205454},
	{"OVERHAND", 8, 205455},
	{"ICARDA", 6, 205456},
	{"EDNEY", 5, 205457},
	{"KAHRS", 5, 205458},
	{"BRISTLECONE", 11, 205459},
	{"PRESCIENCE", 10, 205460},
	{"BETRIEB", 7, 205461},
	{"PEPPERIDGE", 10, 205462},
	{"CAPITAINE", 9, 205463},
	{"SELECTEER", 9, 205464},
	{"SPLATTERING", 11, 205465},
	{"APPANOOSE", 9, 205466},
	{"NIGHTSPOT", 9, 205467},
	{"MPREFERRED", 10, 205468},
	{"MAGNATES", 8, 205469},
	{"PREDILECTIONS", 13, 205470},
	{"KRISTER", 7, 205471},
	{"NARCOSIS", 8, 205472},
	{"COLICKY", 7, 205473},
	{"KEZIAH", 6, 205474},
	{"WATERCOOLED", 11, 205475},
	{"LINESTYLE", 9, 205476},
	{"RASPS", 5, 205477},
	{"MORTA", 5, 205478},
	{"CALIMESA", 8, 205479},
	{"TREEN", 5, 205480},
	{"KITCHIN", 7, 205481},
	{"KATIES", 6, 205482},
	{"BUSSY", 5, 205483},
	{"INTERNATIONALIZING", 18, 205484},
	{"SHANDWICK", 9, 205485},
	{"RIBBIT", 6, 205486},
	{"PICKETED", 8, 205487},
	{"BLOGFODDER", 10, 205488},
	{"REPACKING", 9, 205489},
	{"COMPOSTERS", 10, 205490},
	{"BENNIGAN", 8, 205491},
	{"CORRAN", 6, 205492},
	{"TECNOLOGY", 9, 205493},
	{"KNAVES", 6, 205494},
	{"KILLION", 7, 205495},
	{"ACONITE", 7, 205496},
	{"BUSKING", 7, 205497},
	{"BADCOCK", 7, 205498},
	{"ALFONSE", 7, 205499},
	{"NOVELETTE", 9, 205500},
	{"LEOVILLE", 8, 205501},
	{"INSUL", 5, 205502},
	{"JKP", 3, 205503},
	{"SOSSAMON", 8, 205504},
	{"PLANARITY", 9, 205505},
	{"PERIMENTS", 9, 205506},
	{"SUBRAHMANYAM", 12, 205507},
	{"AUPAIRS", 7, 205508},
	{"MCCARRICK", 9, 205509},
	{"ROMANOFF", 8, 205510},
	{"NELNET", 6, 205511},
	{"SMJPEG", 6, 205512},
	{"SCRIVEN", 7, 205513},
	{"RHIZOCTONIA", 11, 205514},
	{"LIQUIDO", 7, 205515},
	{"HENCH", 5, 205516},
	{"BENEDEK", 7, 205517},
	{"ARMOURIES", 9, 205518},
	{"COAGULASE", 9, 205519},
	{"VLTAVA", 6, 205520},
	{"SUPERDOTATI", 11, 205521},
	{"HORNBLENDE", 10, 205522},
	{"GIFTLAW", 7, 205523},
	{"PNEUMA", 6, 205524},
	{"SWARE", 5, 205525},
	{"SCAMPERED", 9, 205526},
	{"COMMO", 5, 205527},
	{"WAKELING", 8, 205528},
	{"LOCAUX", 6, 205529},
	{"COCCYX", 6, 205530},
	{"AUTOSAMPLER", 11, 205531},
	{"AERTS", 5, 205532},
	{"KOBUK", 5, 205533},
	{"STATENS", 7, 205534},
	{"VEGICAPS", 8, 205535},
	{"IMPOSIBLE", 9, 205536},
	{"CAVAL", 5, 205537},
	{"TEPHRA", 6, 205538},
	{"OENOTHERA", 9, 205539},
	{"BOSMA", 5, 205540},
	{"SPONDENT", 8, 205541},
	{"SHTETL", 6, 205542},
	{"REFLEC", 6, 205543},
	{"POSITAS", 7, 205544},
	{"PAVANO", 6, 205545},
	{"NIGRICANS", 9, 205546},
	{"MANGIA", 6, 205547},
	{"BUBO", 4, 205548},
	{"THALASSOTHERAPY", 15, 205549},
	{"CIPLES", 6, 205550},
	{"GRAVEMAN", 8, 205551},
	{"PREOCCUPY", 9, 205552},
	{"KETTLEWELL", 10, 205553},
	{"ACADEMICAL", 10, 205554},
	{"YZEL", 4, 205555},
	{"YMRE", 4, 205556},
	{"XESY", 4, 205557},
	{"WLMV", 4, 205558},
	{"WDMO", 4, 205559},
	{"VARV", 4, 205560},
	{"VAEX", 4, 205561},
	{"UKOM", 4, 205562},
	{"UBKI", 4, 205563},
	{"RWAA", 4, 205564},
	{"RSKM", 4, 205565},
	{"RBBU", 4, 205566},
	{"OFKT", 4, 205567},
	{"NGRM", 4, 205568},
	{"NGCT", 4, 205569},
	{"NDNR", 4, 205570},
	{"MUKR", 4, 205571},
	{"MKUL", 4, 205572},
	{"LBSF", 4, 205573},
	{"KUSR", 4, 205574},
	{"KEOD", 4, 205575},
	{"IIPU", 4, 205576},
	{"HLOK", 4, 205577},
	{"GYJU", 4, 205578},
	{"FCOK", 4, 205579},
	{"EOLU", 4, 205580},
	{"ENJC", 4, 205581},
	{"DUMH", 4, 205582},
	{"DTUD", 4, 205583},
	{"DMIY", 4, 205584},
	{"DAKM", 4, 205585},
	{"CMEG", 4, 205586},
	{"BCDA", 4, 205587},
	{"AZKA", 4, 205588},
	{"AKJU", 4, 205589},
	{"AFBU", 4, 205590},
	{"MONOPHYLETIC", 12, 205591},
	{"KURRI", 5, 205592},
	{"KRANK", 5, 205593},
	{"DOUNREAY", 8, 205594},
	{"DEDICATEDNOW", 12, 205595},
	{"SIDESTEPPED", 11, 205596},
	{"CAUFIELD", 8, 205597},
	{"BACNET", 6, 205598},
	{"ELZA", 4, 205599},
	{"STARTSIDA", 9, 205600},
	{"ENZYMATICALLY", 13, 205601},
	{"DAVIT", 5, 205602},
	{"TSCM", 4, 205603},
	{"SOGNI", 5, 205604},
	{"NITROBENZENE", 12, 205605},
	{"MONSTERGAMER", 12, 205606},
	{"OBLIGA", 6, 205607},
	{"BENSCH", 6, 205608},
	{"UNMENTIONABLES", 14, 205609},
	{"PTERYGOTA", 9, 205610},
	{"CURATING", 8, 205611},
	{"ROZSA", 5, 205612},
	{"PLOUGHMAN", 9, 205613},
	{"DESTAQUE", 8, 205614},
	{"SERVICECEO", 10, 205615},
	{"REFACTORINGS", 12, 205616},
	{"APTECH", 6, 205617},
	{"SVNADMIN", 8, 205618},
	{"APOSTROPHER", 11, 205619},
	{"FREESAT", 7, 205620},
	{"SYSTM", 5, 205621},
	{"SENSORMATIC", 11, 205622},
	{"RFCI", 4, 205623},
	{"FINRG", 5, 205624},
	{"HOKUM", 5, 205625},
	{"HEILIGE", 7, 205626},
	{"SOTTERO", 7, 205627},
	{"PERIODICA", 9, 205628},
	{"DEMOSCENE", 9, 205629},
	{"NUDS", 4, 205630},
	{"MONDI", 5, 205631},
	{"BELASTING", 9, 205632},
	{"FLATWORM", 8, 205633},
	{"OBRIGADO", 8, 205634},
	{"KARNER", 6, 205635},
	{"VALSARTAN", 9, 205636},
	{"STOREDESIGN", 11, 205637},
	{"POULIOT", 7, 205638},
	{"POSTEMERGENCE", 13, 205639},
	{"MIMMS", 5, 205640},
	{"POLLIN", 6, 205641},
	{"OPSIN", 5, 205642},
	{"MSAD", 4, 205643},
	{"MARKETIN", 8, 205644},
	{"WINKELEN", 8, 205645},
	{"DELIC", 5, 205646},
	{"ZACKY", 5, 205647},
	{"MDAY", 4, 205648},
	{"WARRI", 5, 205649},
	{"METTEZ", 6, 205650},
	{"USESCALE", 8, 205651},
	{"ULTIMAS", 7, 205652},
	{"CONSCIENTIOUSNESS", 17, 205653},
	{"BILLA", 5, 205654},
	{"CLANCYS", 7, 205655},
	{"CONNOTEA", 8, 205656},
	{"WEINMANN", 8, 205657},
	{"PERFER", 6, 205658},
	{"LOCHHEAD", 8, 205659},
	{"PACHYDERM", 9, 205660},
	{"MARITTIMA", 9, 205661},
	{"HVORDAN", 7, 205662},
	{"BBCA", 4, 205663},
	{"BASILIO", 7, 205664},
	{"JIMMYO", 6, 205665},
	{"LOUELLA", 7, 205666},
	{"CHEMOSPHERE", 11, 205667},
	{"RIPCORD", 7, 205668},
	{"IRKT", 4, 205669},
	{"GAMEA", 5, 205670},
	{"FRISUREN", 8, 205671},
	{"LUCIDUM", 7, 205672},
	{"WJC", 3, 205673},
	{"DORNEY", 6, 205674},
	{"GRAUER", 6, 205675},
	{"CBV", 3, 205676},
	{"BUFFERSIZE", 10, 205677},
	{"ZEDILLO", 7, 205678},
	{"BORCHERT", 8, 205679},
	{"ROUGHAGE", 8, 205680},
	{"CARTOONNETWORKCOM", 17, 205681},
	{"BELLINGEN", 9, 205682},
	{"ULTRACENTRIFUGATION", 19, 205683},
	{"MORCEAU", 7, 205684},
	{"PKEY", 4, 205685},
	{"CELLTAGS", 8, 205686},
	{"GROUNDNUTS", 10, 205687},
	{"FLOORBALL", 9, 205688},
	{"AXOLOTL", 7, 205689},
	{"GEOGRAFIA", 9, 205690},
	{"NANOWIRE", 8, 205691},
	{"DRAGSTRIP", 9, 205692},
	{"BODYSTYLE", 9, 205693},
	{"EXSPECT", 7, 205694},
	{"FILMTV", 6, 205695},
	{"COLLAROY", 8, 205696},
	{"GULSHAN", 7, 205697},
	{"FILENE", 6, 205698},
	{"DIBLEY", 6, 205699},
	{"ELEKTRON", 8, 205700},
	{"BESTING", 7, 205701},
	{"VIDEK", 5, 205702},
	{"FORMULARIO", 10, 205703},
	{"HIRAYAMA", 8, 205704},
	{"SPLENDIDE", 9, 205705},
	{"CONARY", 6, 205706},
	{"RUTHER", 6, 205707},
	{"FALKO", 5, 205708},
	{"CORREGIDOR", 10, 205709},
	{"BEGINN", 6, 205710},
	{"AHENAKEW", 8, 205711},
	{"MICHCON", 7, 205712},
	{"CARLEEN", 7, 205713},
	{"BRANSTON", 8, 205714},
	{"MOBILON", 7, 205715},
	{"BLOUGH", 6, 205716},
	{"GAMEW", 5, 205717},
	{"ARTSCAPE", 8, 205718},
	{"TRIVIALITY", 10, 205719},
	{"FLOORVAC", 8, 205720},
	{"PROVINCIE", 9, 205721},
	{"GOWDY", 5, 205722},
	{"TRIPLY", 6, 205723},
	{"INFORMASI", 9, 205724},
	{"RONNE", 5, 205725},
	{"CROAKIES", 8, 205726},
	{"SUPPLYLINE", 10, 205727},
	{"RUK", 3, 205728},
	{"DISTENTION", 10, 205729},
	{"CHANGEUP", 8, 205730},
	{"ZUZA", 4, 205731},
	{"YTKO", 4, 205732},
	{"YNUL", 4, 205733},
	{"YDUO", 4, 205734},
	{"WSJE", 4, 205735},
	{"WIMH", 4, 205736},
	{"VICN", 4, 205737},
	{"UFLI", 4, 205738},
	{"UADN", 4, 205739},
	{"RGNI", 4, 205740},
	{"RDPP", 4, 205741},
	{"RBTE", 4, 205742},
	{"ONFB", 4, 205743},
	{"NWCW", 4, 205744},
	{"NGGS", 4, 205745},
	{"MZIM", 4, 205746},
	{"MMYY", 4, 205747},
	{"MGIF", 4, 205748},
	{"LNLA", 4, 205749},
	{"LEBM", 4, 205750},
	{"JORQ", 4, 205751},
	{"IUCO", 4, 205752},
	{"IIDR", 4, 205753},
	{"GOFZ", 4, 205754},
	{"FSVI", 4, 205755},
	{"EPUJ", 4, 205756},
	{"DVEP", 4, 205757},
	{"DAXA", 4, 205758},
	{"CNNY", 4, 205759},
	{"BSFU", 4, 205760},
	{"BNOF", 4, 205761},
	{"AXAG", 4, 205762},
	{"FONES", 5, 205763},
	{"CROSSBREED", 10, 205764},
	{"ABUN", 4, 205765},
	{"DELORAINE", 9, 205766},
	{"SUNDANESE", 9, 205767},
	{"PNNEWS", 6, 205768},
	{"FLAMENCA", 8, 205769},
	{"THERMOCHEMICAL", 14, 205770},
	{"NETMINDER", 9, 205771},
	{"MICHELI", 7, 205772},
	{"MARET", 5, 205773},
	{"IKARA", 5, 205774},
	{"GOVENOR", 7, 205775},
	{"APPLYSCALE", 10, 205776},
	{"PERCENTSCALE", 12, 205777},
	{"MESUREZ", 7, 205778},
	{"GOATSKIN", 8, 205779},
	{"YOUNGADVENTUROUS", 16, 205780},
	{"ADRENALECTOMY", 13, 205781},
	{"NUMENTRIESREQUESTED", 19, 205782},
	{"ITDG", 4, 205783},
	{"HOSTENT", 7, 205784},
	{"ENSFR", 5, 205785},
	{"LYSKOM", 6, 205786},
	{"CHINASTIC", 9, 205787},
	{"NUDD", 4, 205788},
	{"UNMOVING", 8, 205789},
	{"PICTUREBOOKS", 12, 205790},
	{"KUWAITIS", 8, 205791},
	{"JEDEDIAH", 8, 205792},
	{"GREYLOCK", 8, 205793},
	{"CAHSEE", 6, 205794},
	{"DEAK", 4, 205795},
	{"VILANCULOS", 10, 205796},
	{"TURISM", 6, 205797},
	{"PASSTHRU", 8, 205798},
	{"HAUPTSEITE", 10, 205799},
	{"POSTULATING", 11, 205800},
	{"CALELLA", 7, 205801},
	{"ICONOGRAPHIC", 12, 205802},
	{"OCHMAN", 6, 205803},
	{"ACURIAN", 7, 205804},
	{"ZEDEKIAH", 8, 205805},
	{"BYSTRICA", 8, 205806},
	{"SPACELAB", 8, 205807},
	{"COWRIE", 6, 205808},
	{"BLAUER", 6, 205809},
	{"ATIKOKAN", 8, 205810},
	{"ULTRADNS", 8, 205811},
	{"SHINNED", 7, 205812},
	{"URMSTON", 7, 205813},
	{"JPEGSUBSAMPLING", 15, 205814},
	{"JPEGSMOOTHNESS", 14, 205815},
	{"VAMPIRELLA", 10, 205816},
	{"ARABES", 6, 205817},
	{"JOKEY", 5, 205818},
	{"LIFTMASTER", 10, 205819},
	{"DALGETY", 7, 205820},
	{"ACCOMODATED", 11, 205821},
	{"DUESENBERG", 10, 205822},
	{"WEATHERZONE", 11, 205823},
	{"WBG", 3, 205824},
	{"KATSU", 5, 205825},
	{"BRASSERIES", 10, 205826},
	{"TROG", 4, 205827},
	{"REGNIER", 7, 205828},
	{"JABBED", 6, 205829},
	{"SAULNIER", 8, 205830},
	{"CIRE", 4, 205831},
	{"SHAINA", 6, 205832},
	{"HAPTICS", 7, 205833},
	{"CRIBBS", 6, 205834},
	{"CASSANO", 7, 205835},
	{"PALOOZA", 7, 205836},
	{"MARKZWARE", 9, 205837},
	{"LAERDAL", 7, 205838},
	{"INTELLITYPE", 11, 205839},
	{"PAMPLIN", 7, 205840},
	{"RHINOCORT", 9, 205841},
	{"LLANOS", 6, 205842},
	{"THEIF", 5, 205843},
	{"MUTLEY", 6, 205844},
	{"HARIAN", 6, 205845},
	{"FLITWICK", 8, 205846},
	{"BOXCARS", 7, 205847},
	{"AARDMAN", 7, 205848},
	{"NAMICS", 6, 205849},
	{"FABTECH", 7, 205850},
	{"LCCC", 4, 205851},
	{"BULGAKOV", 8, 205852},
	{"PETRILLI", 8, 205853},
	{"ANTIVIRUSI", 10, 205854},
	{"LOADLEVELER", 11, 205855},
	{"WALLHACK", 8, 205856},
	{"FUMAR", 5, 205857},
	{"ALLCLASSIFIEDS", 14, 205858},
	{"REGISTREER", 10, 205859},
	{"POWIS", 5, 205860},
	{"CROONERS", 8, 205861},
	{"SINAUER", 7, 205862},
	{"FASTENAL", 8, 205863},
	{"BODSFORTHEMODS", 14, 205864},
	{"ARAWAK", 6, 205865},
	{"SAMPL", 5, 205866},
	{"ADSORBENTS", 10, 205867},
	{"HORAM", 5, 205868},
	{"ROCHIE", 6, 205869},
	{"PROCARE", 7, 205870},
	{"GOLSON", 6, 205871},
	{"MOSTRANDO", 9, 205872},
	{"SURENDRA", 8, 205873},
	{"DEWOLF", 6, 205874},
	{"COUNTERNARCOTICS", 16, 205875},
	{"CHANNA", 6, 205876},
	{"IRIZARRY", 8, 205877},
	{"SHOPLIFTER", 10, 205878},
	{"POSTHUMAN", 9, 205879},
	{"ACCEPTATION", 11, 205880},
	{"SOUNDDOMAIN", 11, 205881},
	{"SHERR", 5, 205882},
	{"MSED", 4, 205883},
	{"ICANT", 5, 205884},
	{"DELINEATOR", 10, 205885},
	{"CIVS", 4, 205886},
	{"HERENCIA", 8, 205887},
	{"TIGNANELLO", 10, 205888},
	{"FRUTA", 5, 205889},
	{"SONIDOS", 7, 205890},
	{"PLURIPOTENT", 11, 205891},
	{"BULMAN", 6, 205892},
	{"SERIALNUMBER", 12, 205893},
	{"ECOTOURS", 8, 205894},
	{"HAKUNA", 6, 205895},
	{"OSDC", 4, 205896},
	{"NATIVITIES", 10, 205897},
	{"KDG", 3, 205898},
	{"JAROS", 5, 205899},
	{"AUTOTEST", 8, 205900},
	{"DIOPTERS", 8, 205901},
	{"PRINDLE", 7, 205902},
	{"LABLED", 6, 205903},
	{"HUDDY", 5, 205904},
	{"PARKHOUSE", 9, 205905},
	{"CHROMOSPHERE", 12, 205906},
	{"PHENTER", 7, 205907},
	{"ESQUINA", 7, 205908},
	{"BRYONY", 6, 205909},
	{"SCHLUG", 6, 205910},
	{"GUNIT", 5, 205911},
	{"AFGHANIS", 8, 205912},
	{"ZSWI", 4, 205913},
	{"ZLEH", 4, 205914},
	{"YNCL", 4, 205915},
	{"WEEW", 4, 205916},
	{"VROO", 4, 205917},
	{"VBRI", 4, 205918},
	{"UPSJ", 4, 205919},
	{"UBEY", 4, 205920},
	{"SZYM", 4, 205921},
	{"RXEN", 4, 205922},
	{"RTVT", 4, 205923},
	{"RCZY", 4, 205924},
	{"QORA", 4, 205925},
	{"OLHY", 4, 205926},
	{"NUCI", 4, 205927},
	{"NLVI", 4, 205928},
	{"LWWW", 4, 205929},
	{"KTOQ", 4, 205930},
	{"KSHR", 4, 205931},
	{"KALV", 4, 205932},
	{"JJHA", 4, 205933},
	{"IWAD", 4, 205934},
	{"GDAH", 4, 205935},
	{"EYOD", 4, 205936},
	{"EWTC", 4, 205937},
	{"EWGY", 4, 205938},
	{"EDGT", 4, 205939},
	{"DYLY", 4, 205940},
	{"DOIB", 4, 205941},
	{"DFAW", 4, 205942},
	{"CUWH", 4, 205943},
	{"CDPR", 4, 205944},
	{"ANPY", 4, 205945},
	{"MONCH", 5, 205946},
	{"SUPPPORT", 8, 205947},
	{"PHPLIST", 7, 205948},
	{"SACP", 4, 205949},
	{"POMES", 5, 205950},
	{"NOVITIATE", 9, 205951},
	{"ARGUELLO", 8, 205952},
	{"WARSHAW", 7, 205953},
	{"RADIOLIGAND", 11, 205954},
	{"SCAVO", 5, 205955},
	{"VEOLIA", 6, 205956},
	{"VALIDE", 6, 205957},
	{"SLIST", 5, 205958},
	{"HYPERTHYROID", 12, 205959},
	{"SIDEARM", 7, 205960},
	{"CISV", 4, 205961},
	{"COCKERELL", 9, 205962},
	{"BUSN", 4, 205963},
	{"PRPS", 4, 205964},
	{"VINAYAK", 7, 205965},
	{"JOHANNESSEN", 11, 205966},
	{"REZO", 4, 205967},
	{"HARDWEARING", 11, 205968},
	{"RENMEI", 6, 205969},
	{"FRONTSTRETCH", 12, 205970},
	{"DILFER", 6, 205971},
	{"CHOTEAU", 7, 205972},
	{"CATFIGHTING", 11, 205973},
	{"MBABANE", 7, 205974},
	{"HUMOURED", 8, 205975},
	{"GOMS", 4, 205976},
	{"FRACTIONALLY", 12, 205977},
	{"BEAUTYFUL", 9, 205978},
	{"ALLPOETRY", 9, 205979},
	{"MAREEBA", 7, 205980},
	{"TUNECAST", 8, 205981},
	{"MINTA", 5, 205982},
	{"HUGHS", 5, 205983},
	{"SFBC", 4, 205984},
	{"YHVH", 4, 205985},
	{"WAMEGO", 6, 205986},
	{"TRAXION", 7, 205987},
	{"FROEBEL", 7, 205988},
	{"BRAMAN", 6, 205989},
	{"AGMK", 4, 205990},
	{"SUMMITVILLE", 11, 205991},
	{"HENHOUSE", 8, 205992},
	{"CHETTY", 6, 205993},
	{"BLASCHKE", 8, 205994},
	{"FEEDINGSTUFFS", 13, 205995},
	{"POWERSTREAM", 11, 205996},
	{"KALORAMA", 8, 205997},
	{"HUNGARIA", 8, 205998},
	{"ADOR", 4, 205999},
	{"PANAMERA", 8, 206000},
	{"DAMPENER", 8, 206001},
	{"YELLOWMAN", 9, 206002},
	{"LIATRIS", 7, 206003},
	{"TABELLEN", 8, 206004},
	{"NYGREN", 6, 206005},
	{"DEASY", 5, 206006},
	{"WENGE", 5, 206007},
	{"THUMBELINA", 10, 206008},
	{"SCHUELER", 8, 206009},
	{"LECTUS", 6, 206010},
	{"NAZARENO", 8, 206011},
	{"INDUSTRIALES", 12, 206012},
	{"ETHNOCULTURAL", 13, 206013},
	{"REGISTRADO", 10, 206014},
	{"WAIROA", 6, 206015},
	{"NOVACK", 6, 206016},
	{"LONZA", 5, 206017},
	{"WAUKEE", 6, 206018},
	{"ECUADOREAN", 10, 206019},
	{"OFFEREE", 7, 206020},
	{"IDOLIZED", 8, 206021},
	{"INDUSTRIALIZING", 15, 206022},
	{"YALETOWN", 8, 206023},
	{"VMSTAT", 6, 206024},
	{"PPRUNE", 6, 206025},
	{"CFSC", 4, 206026},
	{"ASSISTENT", 9, 206027},
	{"SALVATOR", 8, 206028},
	{"PSYCHOLOGIC", 11, 206029},
	{"JFSUTILS", 8, 206030},
	{"TURIST", 6, 206031},
	{"UNTAET", 6, 206032},
	{"MICROALGAE", 10, 206033},
	{"BULLFIGHTER", 11, 206034},
	{"NUMBEGINNING", 12, 206035},
	{"NEAGLE", 6, 206036},
	{"CULOTTES", 8, 206037},
	{"BREATHNACH", 10, 206038},
	{"BIRDIED", 7, 206039},
	{"COMINTERN", 9, 206040},
	{"PUSHCART", 8, 206041},
	{"ENCROSS", 7, 206042},
	{"FORTUYN", 7, 206043},
	{"CRIPES", 6, 206044},
	{"CABOODLE", 8, 206045},
	{"SCHAUMS", 7, 206046},
	{"POKIE", 5, 206047},
	{"MOUSEY", 6, 206048},
	{"IWMI", 4, 206049},
	{"TURISTICI", 9, 206050},
	{"COMBINERS", 9, 206051},
	{"BUNCO", 5, 206052},
	{"CYPIONATE", 9, 206053},
	{"CHOLE", 5, 206054},
	{"PORTFAST", 8, 206055},
	{"PYATT", 5, 206056},
	{"KARMEL", 6, 206057},
	{"PAGEBACK", 8, 206058},
	{"GREENBERGER", 11, 206059},
	{"TEXTMATE", 8, 206060},
	{"MOXIFLOXACIN", 12, 206061},
	{"MONTIEL", 7, 206062},
	{"ZAMMIT", 6, 206063},
	{"SPRINTBOOKS", 11, 206064},
	{"IWEALA", 6, 206065},
	{"GARO", 4, 206066},
	{"CRAMSESSION", 11, 206067},
	{"MYELOPROLIFERATIVE", 18, 206068},
	{"RUSTS", 5, 206069},
	{"CHALICES", 8, 206070},
	{"MOVIEBOX", 8, 206071},
	{"FIORENTINI", 10, 206072},
	{"FOURNIT", 7, 206073},
	{"UTRITION", 8, 206074},
	{"DEBO", 4, 206075},
	{"TERAGRID", 8, 206076},
	{"MAILSPEED", 9, 206077},
	{"APRENDA", 7, 206078},
	{"ANTITANK", 8, 206079},
	{"TIEBACK", 7, 206080},
	{"YNPR", 4, 206081},
	{"YLCR", 4, 206082},
	{"XFAR", 4, 206083},
	{"VIZQ", 4, 206084},
	{"VIPT", 4, 206085},
	{"UASL", 4, 206086},
	{"TZVO", 4, 206087},
	{"TYOD", 4, 206088},
	{"SAKY", 4, 206089},
	{"PTFU", 4, 206090},
	{"PDED", 4, 206091},
	{"ORHB", 4, 206092},
	{"OPMN", 4, 206093},
	{"NYEY", 4, 206094},
	{"MOOZ", 4, 206095},
	{"LUXC", 4, 206096},
	{"LUGN", 4, 206097},
	{"LNRE", 4, 206098},
	{"LMEP", 4, 206099},
	{"LCIB", 4, 206100},
	{"LAKF", 4, 206101},
	{"KOYU", 4, 206102},
	{"KHMU", 4, 206103},
	{"KDEX", 4, 206104},
	{"KCRY", 4, 206105},
	{"IVSK", 4, 206106},
	{"ISBM", 4, 206107},
	{"IRZE", 4, 206108},
	{"IGMC", 4, 206109},
	{"IALX", 4, 206110},
	{"HKLA", 4, 206111},
	{"HBEV", 4, 206112},
	{"GWOE", 4, 206113},
	{"GOHM", 4, 206114},
	{"GMIE", 4, 206115},
	{"GEMW", 4, 206116},
	{"GCYL", 4, 206117},
	{"FOGT", 4, 206118},
	{"FNEM", 4, 206119},
	{"EVME", 4, 206120},
	{"EBIW", 4, 206121},
	{"DMIO", 4, 206122},
	{"DBHP", 4, 206123},
	{"BBIW", 4, 206124},
	{"ATUV", 4, 206125},
	{"ATGY", 4, 206126},
	{"ASBP", 4, 206127},
	{"ARFM", 4, 206128},
	{"AOBU", 4, 206129},
	{"PREJUDGE", 8, 206130},
	{"NZCITY", 6, 206131},
	{"BULACAN", 7, 206132},
	{"VIERLING", 8, 206133},
	{"PANTOMIMETIC", 12, 206134},
	{"PHOTOBOOKS", 10, 206135},
	{"CREMATIONS", 10, 206136},
	{"REPAIRMASTER", 12, 206137},
	{"IODINATED", 9, 206138},
	{"AGREING", 7, 206139},
	{"FEILDING", 8, 206140},
	{"WWWAOL", 6, 206141},
	{"RIVULET", 7, 206142},
	{"NOBODYS", 7, 206143},
	{"GAKIC", 5, 206144},
	{"WOODSTOWN", 9, 206145},
	{"ULVERSTONE", 10, 206146},
	{"MENASHE", 7, 206147},
	{"SEETHED", 7, 206148},
	{"GEEST", 5, 206149},
	{"TEMPL", 5, 206150},
	{"GIOUS", 5, 206151},
	{"ORRELL", 6, 206152},
	{"OPMODE", 6, 206153},
	{"CRAKS", 5, 206154},
	{"AERONAUT", 8, 206155},
	{"ACETYLSALICYLIC", 15, 206156},
	{"LATINOAMERICANO", 15, 206157},
	{"GALLION", 7, 206158},
	{"GAURI", 5, 206159},
	{"ETRURIA", 7, 206160},
	{"SAISONS", 7, 206161},
	{"DISTRICTING", 11, 206162},
	{"WORLDMATE", 9, 206163},
	{"CONSTANTIUS", 11, 206164},
	{"ANDYT", 5, 206165},
	{"SYMPHYSODON", 11, 206166},
	{"RESTYLED", 8, 206167},
	{"ONSDAG", 6, 206168},
	{"MASUMI", 6, 206169},
	{"EDAC", 4, 206170},
	{"CINIO", 5, 206171},
	{"READI", 5, 206172},
	{"GOODWAY", 7, 206173},
	{"BEATFREAX", 9, 206174},
	{"SUBAGENT", 8, 206175},
	{"LOCHGELLY", 9, 206176},
	{"DYFFRYN", 7, 206177},
	{"CULAR", 5, 206178},
	{"PNEW", 4, 206179},
	{"LAFFER", 6, 206180},
	{"PROSELYTIZE", 11, 206181},
	{"GALBRETH", 8, 206182},
	{"CHORO", 5, 206183},
	{"SCRAPPLE", 8, 206184},
	{"TENDERFOOT", 10, 206185},
	{"NETWOSIX", 8, 206186},
	{"SHOEHORN", 8, 206187},
	{"PRINTMASTER", 11, 206188},
	{"FOREL", 5, 206189},
	{"CREASOURCE", 10, 206190},
	{"REVALUATIONS", 12, 206191},
	{"MCGAURAN", 8, 206192},
	{"GABBEH", 6, 206193},
	{"SHANKMAN", 8, 206194},
	{"HISTORIOGRAPHICAL", 17, 206195},
	{"GEBOREN", 7, 206196},
	{"STAUNCHEST", 10, 206197},
	{"GRINBERG", 8, 206198},
	{"INDEXINDEX", 10, 206199},
	{"AUDIOLINE", 9, 206200},
	{"DAVOR", 5, 206201},
	{"SMEAGOL", 7, 206202},
	{"JACKALOPE", 9, 206203},
	{"YVELINES", 8, 206204},
	{"VERHOEF", 7, 206205},
	{"BLAHA", 5, 206206},
	{"BERGLAND", 8, 206207},
	{"NORADRENERGIC", 13, 206208},
	{"VALERIY", 7, 206209},
	{"DRYCLEANERS", 11, 206210},
	{"REYNOSA", 7, 206211},
	{"PRICESTORM", 10, 206212},
	{"LIBA", 4, 206213},
	{"LESSMAN", 7, 206214},
	{"ABLOY", 5, 206215},
	{"GLINKA", 6, 206216},
	{"CHARLEBOIS", 10, 206217},
	{"JAFFEE", 6, 206218},
	{"DARRAH", 6, 206219},
	{"HPLIP", 5, 206220},
	{"LEWITT", 6, 206221},
	{"TRAJET", 6, 206222},
	{"SARALAND", 8, 206223},
	{"BURDEKIN", 8, 206224},
	{"PYRENEAN", 8, 206225},
	{"MULTITHREAD", 11, 206226},
	{"RUDBECKIA", 9, 206227},
	{"DENTALPLANS", 11, 206228},
	{"ICEFIELDS", 9, 206229},
	{"SHELAH", 6, 206230},
	{"BURING", 6, 206231},
	{"MILNERTON", 9, 206232},
	{"HEINONLINE", 10, 206233},
	{"EMBOLIC", 7, 206234},
	{"AVAILAB", 7, 206235},
	{"MANDRELS", 8, 206236},
	{"JAMESBURG", 9, 206237},
	{"HORIZO", 6, 206238},
	{"CRIXIVAN", 8, 206239},
	{"BARRAL", 6, 206240},
	{"ALLAYED", 7, 206241},
	{"BROADSTONE", 10, 206242},
	{"GNOMEICU", 8, 206243},
	{"CATTERALL", 9, 206244},
	{"BAGPUSS", 7, 206245},
	{"OBREGON", 7, 206246},
	{"FRONTAGES", 9, 206247},
	{"WWWGOO", 6, 206248},
	{"GADGETCENTRE", 12, 206249},
	{"HOUCHES", 7, 206250},
	{"SYNON", 5, 206251},
	{"SLANEY", 6, 206252},
	{"LUMB", 4, 206253},
	{"LELYSTAD", 8, 206254},
	{"CHAMFERED", 9, 206255},
	{"VERION", 6, 206256},
	{"BIFMA", 5, 206257},
	{"OBITER", 6, 206258},
	{"MALAIKA", 7, 206259},
	{"LRAE", 4, 206260},
	{"ESCULENTA", 9, 206261},
	{"PORED", 5, 206262},
	{"LYNNVILLE", 9, 206263},
	{"KALYANI", 7, 206264},
	{"OPNAVINST", 9, 206265},
	{"DIVIS", 5, 206266},
	{"NODOSA", 6, 206267},
	{"HETCH", 5, 206268},
	{"ZZYD", 4, 206269},
	{"ZDIR", 4, 206270},
	{"YTEK", 4, 206271},
	{"YDSP", 4, 206272},
	{"XIGE", 4, 206273},
	{"UEZG", 4, 206274},
	{"SMPU", 4, 206275},
	{"RBBR", 4, 206276},
	{"ONCW", 4, 206277},
	{"OMPG", 4, 206278},
	{"OLGL", 4, 206279},
	{"NXFO", 4, 206280},
	{"NEYQ", 4, 206281},
	{"MUAW", 4, 206282},
	{"MEOK", 4, 206283},
	{"LIKR", 4, 206284},
	{"KAKN", 4, 206285},
	{"IVDI", 4, 206286},
	{"IKUI", 4, 206287},
	{"HVLA", 4, 206288},
	{"HOVL", 4, 206289},
	{"FMRH", 4, 206290},
	{"FBAA", 4, 206291},
	{"EZAY", 4, 206292},
	{"EVSR", 4, 206293},
	{"EVOB", 4, 206294},
	{"ELMG", 4, 206295},
	{"EHDD", 4, 206296},
	{"DTUF", 4, 206297},
	{"DHDA", 4, 206298},
	{"CDMO", 4, 206299},
	{"CBCO", 4, 206300},
	{"CBCH", 4, 206301},
	{"BYOK", 4, 206302},
	{"BPWI", 4, 206303},
	{"BNBA", 4, 206304},
	{"AYLW", 4, 206305},
	{"SACCADIC", 8, 206306},
	{"PETROZAVODSK", 12, 206307},
	{"RECALIBRATE", 11, 206308},
	{"POSTWISE", 8, 206309},
	{"OSTROVSKY", 9, 206310},
	{"LIEDTKE", 7, 206311},
	{"PANSTOCK", 8, 206312},
	{"KINNE", 5, 206313},
	{"WAXHAW", 6, 206314},
	{"ROBERN", 6, 206315},
	{"RATATOUILLE", 11, 206316},
	{"MORTI", 5, 206317},
	{"GINGIVA", 7, 206318},
	{"TCCD", 4, 206319},
	{"LESCOL", 6, 206320},
	{"MYSUN", 5, 206321},
	{"GETSMART", 8, 206322},
	{"PERCEVAL", 8, 206323},
	{"SHELFTAG", 8, 206324},
	{"MIREX", 5, 206325},
	{"YUICHI", 6, 206326},
	{"WRETURN", 7, 206327},
	{"INTRINSIX", 9, 206328},
	{"RXTE", 4, 206329},
	{"GUILLEM", 7, 206330},
	{"RELINQUISHES", 12, 206331},
	{"SASEBO", 6, 206332},
	{"LIGABUE", 7, 206333},
	{"METAVANTE", 9, 206334},
	{"BELORUSSIAN", 11, 206335},
	{"ENACTORS", 8, 206336},
	{"BOURBONS", 8, 206337},
	{"RHODY", 5, 206338},
	{"STRATAGIES", 10, 206339},
	{"HAIBANE", 7, 206340},
	{"FIBO", 4, 206341},
	{"WAGEN", 5, 206342},
	{"NUTRAMERICA", 11, 206343},
	{"BLAXLAND", 8, 206344},
	{"KWANTLEN", 8, 206345},
	{"ROSENROT", 8, 206346},
	{"ANTIQUARY", 9, 206347},
	{"VIATALK", 7, 206348},
	{"URED", 4, 206349},
	{"GRIZZLE", 7, 206350},
	{"EXPLAINER", 9, 206351},
	{"ARCHIWUM", 8, 206352},
	{"MULTIFLORA", 10, 206353},
	{"ZEALOTRY", 8, 206354},
	{"MUSCOVY", 7, 206355},
	{"PROFESORES", 10, 206356},
	{"JAVELINA", 8, 206357},
	{"CONEXION", 8, 206358},
	{"ADRIANE", 7, 206359},
	{"BARCOS", 6, 206360},
	{"BLESSINGTON", 11, 206361},
	{"BERTO", 5, 206362},
	{"AMBAR", 5, 206363},
	{"IPMOVIE", 7, 206364},
	{"OVERSPRAY", 9, 206365},
	{"BRYSTON", 7, 206366},
	{"CHILDERN", 8, 206367},
	{"STARMEDIA", 9, 206368},
	{"OVERDUBS", 8, 206369},
	{"MERITCARE", 9, 206370},
	{"GRENADIN", 8, 206371},
	{"PRESERVEASPECT", 14, 206372},
	{"EALERTS", 7, 206373},
	{"KODAIKANAL", 10, 206374},
	{"KUSHIES", 7, 206375},
	{"HCMV", 4, 206376},
	{"ANGIO", 5, 206377},
	{"TUCKERTON", 9, 206378},
	{"DENOISING", 9, 206379},
	{"CHLORAL", 7, 206380},
	{"DISCON", 6, 206381},
	{"ASGHAR", 6, 206382},
	{"DEVT", 4, 206383},
	{"DEPRESSINGLY", 12, 206384},
	{"AMENIA", 6, 206385},
	{"JAMEEL", 6, 206386},
	{"NADAR", 5, 206387},
	{"TURP", 4, 206388},
	{"ARMYWORM", 8, 206389},
	{"ADVOGADOS", 9, 206390},
	{"ACCREDITS", 9, 206391},
	{"JOUNG", 5, 206392},
	{"GUNDLACH", 8, 206393},
	{"FPING", 5, 206394},
	{"SIEGER", 6, 206395},
	{"SHOEMAKERS", 10, 206396},
	{"MASHANTUCKET", 12, 206397},
	{"WARFIGHTERS", 11, 206398},
	{"NAVFAC", 6, 206399},
	{"STALKPIRE", 9, 206400},
	{"BLOGZ", 5, 206401},
	{"ZULLEN", 6, 206402},
	{"PROTX", 5, 206403},
	{"DRUNKENLY", 9, 206404},
	{"REALLOCATIONS", 13, 206405},
	{"HYDRILLA", 8, 206406},
	{"PJB", 3, 206407},
	{"ODIHR", 5, 206408},
	{"INSURACE", 8, 206409},
	{"SEMCO", 5, 206410},
	{"ORGANIZ", 7, 206411},
	{"BABYSTOCK", 9, 206412},
	{"BLACKY", 6, 206413},
	{"SUPERSATURATION", 15, 206414},
	{"JOHNO", 5, 206415},
	{"ENTRANCEWAY", 11, 206416},
	{"RICTA", 5, 206417},
	{"LFR", 3, 206418},
	{"ONOMATOPOEIA", 12, 206419},
	{"FOREXAMPLE", 10, 206420},
	{"DIGGINGS", 8, 206421},
	{"MEASUR", 6, 206422},
	{"LEGTE", 5, 206423},
	{"MONDRAGON", 9, 206424},
	{"KASHIMA", 7, 206425},
	{"ZYSO", 4, 206426},
	{"ZYAT", 4, 206427},
	{"ZSIG", 4, 206428},
	{"YNEY", 4, 206429},
	{"YMAO", 4, 206430},
	{"XWAY", 4, 206431},
	{"WYDE", 4, 206432},
	{"WKEP", 4, 206433},
	{"UNMS", 4, 206434},
	{"ULKP", 4, 206435},
	{"SPPO", 4, 206436},
	{"SNDP", 4, 206437},
	{"RYNX", 4, 206438},
	{"RYKL", 4, 206439},
	{"ROJI", 4, 206440},
	{"RBNO", 4, 206441},
	{"OFNW", 4, 206442},
	{"MYTY", 4, 206443},
	{"MRYO", 4, 206444},
	{"MRKU", 4, 206445},
	{"MPHD", 4, 206446},
	{"MMVP", 4, 206447},
	{"KYAG", 4, 206448},
	{"KDIL", 4, 206449},
	{"IVWI", 4, 206450},
	{"IRYN", 4, 206451},
	{"IPPT", 4, 206452},
	{"HRBL", 4, 206453},
	{"HLUD", 4, 206454},
	{"HBUZ", 4, 206455},
	{"HABP", 4, 206456},
	{"GODJ", 4, 206457},
	{"FPLI", 4, 206458},
	{"FOLT", 4, 206459},
	{"EZEX", 4, 206460},
	{"EGCL", 4, 206461},
	{"DBUK", 4, 206462},
	{"COFJ", 4, 206463},
	{"BHIP", 4, 206464},
	{"ATCW", 4, 206465},
	{"AHCU", 4, 206466},
	{"AAMM", 4, 206467},
	{"NOVOZYMES", 9, 206468},
	{"EMANCIPATE", 10, 206469},
	{"CHAMPOLUC", 9, 206470},
	{"BPROB", 5, 206471},
	{"PRODUTORA", 9, 206472},
	{"ADOLYGIAD", 9, 206473},
	{"DONALDSONVILLE", 14, 206474},
	{"PRIMEIRO", 8, 206475},
	{"PARTSPRINTERSPRINTER", 20, 206476},
	{"BHARUCH", 7, 206477},
	{"TEAMFANSHOP", 11, 206478},
	{"KLAU", 4, 206479},
	{"ISUPPLI", 7, 206480},
	{"EXPERIENTIA", 11, 206481},
	{"ACHTER", 6, 206482},
	{"COMPENDIUMS", 11, 206483},
	{"BURGHERS", 8, 206484},
	{"BIRCHALL", 8, 206485},
	{"WARMUPS", 7, 206486},
	{"VERSITILE", 9, 206487},
	{"TAURIS", 6, 206488},
	{"SERAFINA", 8, 206489},
	{"BELLYBUTTON", 11, 206490},
	{"SANTEN", 6, 206491},
	{"RECMARTIALARTS", 14, 206492},
	{"MENAUL", 6, 206493},
	{"LYOKO", 5, 206494},
	{"ROSENSTIEL", 10, 206495},
	{"EISCAT", 6, 206496},
	{"EUROMETEO", 9, 206497},
	{"RODUCT", 6, 206498},
	{"RDEV", 4, 206499},
	{"HATEM", 5, 206500},
	{"BUTERA", 6, 206501},
	{"AGENA", 5, 206502},
	{"MBEANS", 6, 206503},
	{"RLIN", 4, 206504},
	{"HORTUS", 6, 206505},
	{"GUILLOT", 7, 206506},
	{"ZILE", 4, 206507},
	{"IGNORANTLY", 10, 206508},
	{"TABATA", 6, 206509},
	{"GLENYS", 6, 206510},
	{"DGX", 3, 206511},
	{"SARAHS", 6, 206512},
	{"BIOSTRATIGRAPHY", 15, 206513},
	{"WHITHAM", 7, 206514},
	{"INKTABLET", 9, 206515},
	{"DEMOCRACTIC", 11, 206516},
	{"MESZAROS", 8, 206517},
	{"KAITO", 5, 206518},
	{"GSUS", 4, 206519},
	{"LUXO", 4, 206520},
	{"KRSTIC", 6, 206521},
	{"CELEBRA", 7, 206522},
	{"HYDROLOGISTS", 12, 206523},
	{"CLARKDALE", 9, 206524},
	{"KEREMEOS", 8, 206525},
	{"CEARA", 5, 206526},
	{"MAATHAI", 7, 206527},
	{"KOMAR", 5, 206528},
	{"GUILFOYLE", 9, 206529},
	{"CINESE", 6, 206530},
	{"SOYINKA", 7, 206531},
	{"PENHALIGON", 10, 206532},
	{"IODP", 4, 206533},
	{"ZELLNER", 7, 206534},
	{"PUREOLOGY", 9, 206535},
	{"NARIMAN", 7, 206536},
	{"JALA", 4, 206537},
	{"CELCOM", 6, 206538},
	{"BANDINI", 7, 206539},
	{"DIGITALIZATION", 14, 206540},
	{"ANCOR", 5, 206541},
	{"LOGOTYPER", 9, 206542},
	{"SUGARHILL", 9, 206543},
	{"KAPADIA", 7, 206544},
	{"RATIONALISED", 12, 206545},
	{"ARMORIES", 8, 206546},
	{"FONTHILL", 8, 206547},
	{"RADIOBIOLOGY", 12, 206548},
	{"DOESNOT", 7, 206549},
	{"TOMBIGBEE", 9, 206550},
	{"MONITER", 7, 206551},
	{"MKWEB", 5, 206552},
	{"TRAVELZOOCOM", 12, 206553},
	{"OLFACTION", 9, 206554},
	{"TECTURE", 7, 206555},
	{"PROTOCOLE", 9, 206556},
	{"DEPORTING", 9, 206557},
	{"REQU", 4, 206558},
	{"JABSCO", 6, 206559},
	{"BANGA", 5, 206560},
	{"ARTISTINDEX", 11, 206561},
	{"UNDERSIDES", 10, 206562},
	{"RIVERKEEPER", 11, 206563},
	{"KAMU", 4, 206564},
	{"CRADDICK", 8, 206565},
	{"CLAUSTHAL", 9, 206566},
	{"DEVDAS", 6, 206567},
	{"LOEWY", 5, 206568},
	{"EPITROPH", 8, 206569},
	{"BRICAT", 6, 206570},
	{"NUKEQUIZ", 8, 206571},
	{"CLAVIERE", 8, 206572},
	{"JACKDAW", 7, 206573},
	{"SUKARNO", 7, 206574},
	{"FERRYBOAT", 9, 206575},
	{"NETWO", 5, 206576},
	{"CARDFILE", 8, 206577},
	{"BLACKWELDER", 11, 206578},
	{"KAMUT", 5, 206579},
	{"ANDROMDA", 8, 206580},
	{"DRAFTY", 6, 206581},
	{"STERRY", 6, 206582},
	{"PROFETIONAL", 11, 206583},
	{"KATV", 4, 206584},
	{"SMTPSENDERHOST", 14, 206585},
	{"ROCKBRITISH", 11, 206586},
	{"ONESHOT", 7, 206587},
	{"HOTMEIL", 7, 206588},
	{"TANGE", 5, 206589},
	{"FORF", 4, 206590},
	{"POLVO", 5, 206591},
	{"MICKEYS", 7, 206592},
	{"ERLAUBT", 7, 206593},
	{"QUARTERSTICK", 12, 206594},
	{"ODAY", 4, 206595},
	{"TATSUMI", 7, 206596},
	{"WEENY", 5, 206597},
	{"PANTAI", 6, 206598},
	{"DOBERMANN", 9, 206599},
	{"DIVINER", 7, 206600},
	{"LAISSER", 7, 206601},
	{"MEMORIAS", 8, 206602},
	{"EXUDING", 7, 206603},
	{"COREDUMP", 8, 206604},
	{"WWWHOTELS", 9, 206605},
	{"HIGHMOON", 8, 206606},
	{"ESTEY", 5, 206607},
	{"PUBLIWEB", 8, 206608},
	{"PICTUREW", 8, 206609},
	{"MACREADY", 8, 206610},
	{"EFALLAI", 7, 206611},
	{"HYPERDAVE", 9, 206612},
	{"EATTORNEY", 9, 206613},
	{"RABINOVITCH", 11, 206614},
	{"PRIMARIA", 8, 206615},
	{"OCHILTREE", 9, 206616},
	{"LETTIN", 6, 206617},
	{"HOUZE", 5, 206618},
	{"BLEIBT", 6, 206619},
	{"ZHOL", 4, 206620},
	{"WPUZ", 4, 206621},
	{"WKWI", 4, 206622},
	{"VSCL", 4, 206623},
	{"VCRI", 4, 206624},
	{"VASG", 4, 206625},
	{"USOK", 4, 206626},
	{"URIJ", 4, 206627},
	{"UKBY", 4, 206628},
	{"UJIF", 4, 206629},
	{"UGNU", 4, 206630},
	{"TSLD", 4, 206631},
	{"TBPS", 4, 206632},
	{"TAZU", 4, 206633},
	{"SVRE", 4, 206634},
	{"SPPE", 4, 206635},
	{"SHPM", 4, 206636},
	{"REAX", 4, 206637},
	{"RAZS", 4, 206638},
	{"PJOU", 4, 206639},
	{"OWIU", 4, 206640},
	{"OSGL", 4, 206641},
	{"OIWR", 4, 206642},
	{"NLVA", 4, 206643},
	{"NDWM", 4, 206644},
	{"NCKT", 4, 206645},
	{"LCAZ", 4, 206646},
	{"KOVP", 4, 206647},
	{"KDOD", 4, 206648},
	{"IGEG", 4, 206649},
	{"IFSY", 4, 206650},
	{"HYSB", 4, 206651},
	{"HNKR", 4, 206652},
	{"HKRE", 4, 206653},
	{"GWEF", 4, 206654},
	{"GPSW", 4, 206655},
	{"EVDI", 4, 206656},
	{"ESYF", 4, 206657},
	{"EDMG", 4, 206658},
	{"DNUA", 4, 206659},
	{"DETB", 4, 206660},
	{"CMYS", 4, 206661},
	{"CKAJ", 4, 206662},
	{"CCMO", 4, 206663},
	{"AWOW", 4, 206664},
	{"ARHW", 4, 206665},
	{"AJUW", 4, 206666},
	{"AIGJ", 4, 206667},
	{"SCHELLER", 8, 206668},
	{"FINNE", 5, 206669},
	{"PRECOMP", 7, 206670},
	{"MONOIDAL", 8, 206671},
	{"ILLU", 4, 206672},
	{"JETLAG", 6, 206673},
	{"DISCOLOURED", 11, 206674},
	{"NSOBJECT", 8, 206675},
	{"NREF", 4, 206676},
	{"QUICKSPECS", 10, 206677},
	{"RANELAGH", 8, 206678},
	{"CEATEC", 6, 206679},
	{"OLTON", 5, 206680},
	{"ADVERSITIES", 11, 206681},
	{"VORTRAG", 7, 206682},
	{"RYEGATE", 7, 206683},
	{"NEYLAND", 7, 206684},
	{"MOGG", 4, 206685},
	{"JIMWORLD", 8, 206686},
	{"CORTA", 5, 206687},
	{"GOOSEBERRIES", 12, 206688},
	{"MACNAMARA", 9, 206689},
	{"TURKISTAN", 9, 206690},
	{"SAWICKI", 7, 206691},
	{"PHILLIPSTON", 11, 206692},
	{"GPSIM", 5, 206693},
	{"ZCOVER", 6, 206694},
	{"TRANSPAC", 8, 206695},
	{"IBMA", 4, 206696},
	{"RESTYLING", 9, 206697},
	{"EXONERATION", 11, 206698},
	{"MARINOS", 7, 206699},
	{"BRIDIE", 6, 206700},
	{"SESSHOMARU", 10, 206701},
	{"GRIPELOG", 8, 206702},
	{"WITKOWSKI", 9, 206703},
	{"KERBER", 6, 206704},
	{"DRPH", 4, 206705},
	{"PADDLEBALL", 10, 206706},
	{"TENNISCHAMPION", 14, 206707},
	{"PCNOTEBOOK", 10, 206708},
	{"EUROSPORTSNEWS", 14, 206709},
	{"ALLANTOIN", 9, 206710},
	{"FOOTBALLPREMIER", 15, 206711},
	{"ECONOMIQUE", 10, 206712},
	{"CHIEVO", 6, 206713},
	{"INTIMAL", 7, 206714},
	{"YOUNGBOY", 8, 206715},
	{"SFWED", 5, 206716},
	{"RUZ", 3, 206717},
	{"HUARACHE", 8, 206718},
	{"CARDW", 5, 206719},
	{"MIKROTIK", 8, 206720},
	{"LOFTIN", 6, 206721},
	{"FASTCASE", 8, 206722},
	{"DEWDNEY", 7, 206723},
	{"CRICKETPREMIER", 14, 206724},
	{"LESIBAN", 7, 206725},
	{"TETRAS", 6, 206726},
	{"MICHELMAN", 9, 206727},
	{"JAHRES", 6, 206728},
	{"IGNOU", 5, 206729},
	{"UKBOOKS", 7, 206730},
	{"WOLDE", 5, 206731},
	{"MOTIONAL", 8, 206732},
	{"AUTOFORMAT", 10, 206733},
	{"BANHAM", 6, 206734},
	{"PITURE", 6, 206735},
	{"RNABASE", 7, 206736},
	{"QUARRELING", 10, 206737},
	{"HARPERTEEN", 10, 206738},
	{"BERAN", 5, 206739},
	{"MURAI", 5, 206740},
	{"GRIEVOR", 7, 206741},
	{"SREENSAVERS", 11, 206742},
	{"GEEKMOD", 7, 206743},
	{"BROK", 4, 206744},
	{"WWWLYCOS", 8, 206745},
	{"RUSTAVI", 7, 206746},
	{"JINHUA", 6, 206747},
	{"FULWOOD", 7, 206748},
	{"FIREPIT", 7, 206749},
	{"ENTERPRIZE", 10, 206750},
	{"CHINOISE", 8, 206751},
	{"WTMP", 4, 206752},
	{"TOYFARE", 7, 206753},
	{"PREEMPTIVELY", 12, 206754},
	{"KORNFELD", 8, 206755},
	{"STEINCHED", 9, 206756},
	{"HOBBYTRON", 9, 206757},
	{"SANAYI", 6, 206758},
	{"BETTYMILLS", 10, 206759},
	{"HSUAN", 5, 206760},
	{"TERRAFORMING", 12, 206761},
	{"BURKBURNETT", 11, 206762},
	{"ANJU", 4, 206763},
	{"MYELINATED", 10, 206764},
	{"FRESHJIVE", 9, 206765},
	{"ERDINGTON", 9, 206766},
	{"AUGUSTAN", 8, 206767},
	{"TOYAH", 5, 206768},
	{"SULPICE", 7, 206769},
	{"SPOJ", 4, 206770},
	{"MARSCHALL", 9, 206771},
	{"WWWOVERTURE", 11, 206772},
	{"FRUITFULNESS", 12, 206773},
	{"CASUS", 5, 206774},
	{"WWWMETACRAWLER", 14, 206775},
	{"UPDAT", 5, 206776},
	{"SIGPIPE", 7, 206777},
	{"LISPREF", 7, 206778},
	{"ILLUSIONARY", 11, 206779},
	{"BEEFEATER", 9, 206780},
	{"ORTHOPEDISTS", 12, 206781},
	{"CITIC", 5, 206782},
	{"TICIPATION", 10, 206783},
	{"SLANDERS", 8, 206784},
	{"ANALYSYS", 8, 206785},
	{"WINNESHIEK", 10, 206786},
	{"BELZER", 6, 206787},
	{"UEHARA", 6, 206788},
	{"SOLAN", 5, 206789},
	{"CLAVELL", 7, 206790},
	{"BVC", 3, 206791},
	{"VARIOLA", 7, 206792},
	{"RISIN", 5, 206793},
	{"QUELLI", 6, 206794},
	{"ANTHRANILATE", 12, 206795},
	{"INTRATEXT", 9, 206796},
	{"GLENLIVET", 9, 206797},
	{"MULDAUR", 7, 206798},
	{"CONSIGNING", 10, 206799},
	{"MODELSIM", 8, 206800},
	{"PNMODULES", 9, 206801},
	{"LAMINECTOMY", 11, 206802},
	{"GETRONICS", 9, 206803},
	{"FTREE", 5, 206804},
	{"BROUWERIJ", 9, 206805},
	{"NETHERCUTT", 10, 206806},
	{"HAWERA", 6, 206807},
	{"WARROAD", 7, 206808},
	{"DIVULGUE", 8, 206809},
	{"BARRELING", 9, 206810},
	{"MERSTER", 7, 206811},
	{"FRIENDSITE", 10, 206812},
	{"DEHYDRATE", 9, 206813},
	{"COLOMBE", 7, 206814},
	{"ROTISSERIES", 11, 206815},
	{"NASIRIYAH", 9, 206816},
	{"ULTRAPRO", 8, 206817},
	{"SYMBOYLIO", 9, 206818},
	{"EXFO", 4, 206819},
	{"EXAMENS", 7, 206820},
	{"TAMMUZ", 6, 206821},
	{"HAYLIE", 6, 206822},
	{"DLING", 5, 206823},
	{"AQUANOX", 7, 206824},
	{"MOCVD", 5, 206825},
	{"SEGEL", 5, 206826},
	{"TPMS", 4, 206827},
	{"TFIID", 5, 206828},
	{"AMBO", 4, 206829},
	{"MORNAY", 6, 206830},
	{"GALACTUS", 8, 206831},
	{"ZCHE", 4, 206832},
	{"ZADR", 4, 206833},
	{"YZOM", 4, 206834},
	{"YMAB", 4, 206835},
	{"YDOK", 4, 206836},
	{"WCOI", 4, 206837},
	{"VSUB", 4, 206838},
	{"UTUK", 4, 206839},
	{"UHIL", 4, 206840},
	{"UFTO", 4, 206841},
	{"TLCA", 4, 206842},
	{"TIRM", 4, 206843},
	{"SRBE", 4, 206844},
	{"RRRI", 4, 206845},
	{"PRUT", 4, 206846},
	{"OUMP", 4, 206847},
	{"OGDR", 4, 206848},
	{"LAVG", 4, 206849},
	{"KMYE", 4, 206850},
	{"KMEF", 4, 206851},
	{"JOSW", 4, 206852},
	{"IVDE", 4, 206853},
	{"HPLI", 4, 206854},
	{"GHZI", 4, 206855},
	{"GEZE", 4, 206856},
	{"GEAK", 4, 206857},
	{"FZHO", 4, 206858},
	{"FUSJ", 4, 206859},
	{"EUSZ", 4, 206860},
	{"EODW", 4, 206861},
	{"DIPB", 4, 206862},
	{"DCDA", 4, 206863},
	{"BYJP", 4, 206864},
	{"BTWT", 4, 206865},
	{"APGI", 4, 206866},
	{"BAUDOUIN", 8, 206867},
	{"CUNNINGHAME", 11, 206868},
	{"COMCOM", 6, 206869},
	{"FREARS", 6, 206870},
	{"SMSCLIENT", 9, 206871},
	{"FRETWORK", 8, 206872},
	{"FAHIM", 5, 206873},
	{"REENACTORS", 10, 206874},
	{"EMANCIPATORY", 12, 206875},
	{"RESSLER", 7, 206876},
	{"MENC", 4, 206877},
	{"DUNO", 4, 206878},
	{"AUTRICHE", 8, 206879},
	{"WTMJ", 4, 206880},
	{"HARDEEVILLE", 11, 206881},
	{"ROTOSOUND", 9, 206882},
	{"PUNCTATUS", 9, 206883},
	{"HUTUS", 5, 206884},
	{"PAVLOVIC", 8, 206885},
	{"COLONIAS", 8, 206886},
	{"SONNAR", 6, 206887},
	{"EMBALMED", 8, 206888},
	{"WHIZZES", 7, 206889},
	{"BTRY", 4, 206890},
	{"UPRIGHTNESS", 11, 206891},
	{"MYDNA", 5, 206892},
	{"LADIESWEAR", 10, 206893},
	{"UPAZILA", 7, 206894},
	{"MOSCATO", 7, 206895},
	{"BASAK", 5, 206896},
	{"SPECTROSC", 9, 206897},
	{"KIRTLEY", 7, 206898},
	{"BROOKMAN", 8, 206899},
	{"LACETTI", 7, 206900},
	{"STEPHANUS", 9, 206901},
	{"KUCHNIA", 7, 206902},
	{"CSUMB", 5, 206903},
	{"BRESNAN", 7, 206904},
	{"CYTOCHALASIN", 12, 206905},
	{"INLINES", 7, 206906},
	{"AUTOIGNITION", 12, 206907},
	{"HOTPLATES", 9, 206908},
	{"SNOGGING", 8, 206909},
	{"OBLI", 4, 206910},
	{"MTCT", 4, 206911},
	{"CORPORATIVE", 11, 206912},
	{"SSEARCH", 7, 206913},
	{"LAMIACEAE", 9, 206914},
	{"LABRETS", 7, 206915},
	{"HAGIA", 5, 206916},
	{"GOWANDA", 7, 206917},
	{"STRAN", 5, 206918},
	{"HISPANIA", 8, 206919},
	{"GOODLINK", 8, 206920},
	{"BESCHRIJVING", 12, 206921},
	{"TRAMADO", 7, 206922},
	{"CLAUDEL", 7, 206923},
	{"BERNHEIM", 8, 206924},
	{"NYHEDSBREV", 10, 206925},
	{"MULKEY", 6, 206926},
	{"MENGELE", 7, 206927},
	{"CULATED", 7, 206928},
	{"KEDO", 4, 206929},
	{"CLIFFHANGERS", 12, 206930},
	{"APPOSITE", 8, 206931},
	{"MSNMEN", 6, 206932},
	{"BUCKHURST", 9, 206933},
	{"JEZTER", 6, 206934},
	{"RAMPAL", 6, 206935},
	{"ROBERTSDALE", 11, 206936},
	{"BURRI", 5, 206937},
	{"CANCELLABLE", 11, 206938},
	{"RECHTLICHE", 10, 206939},
	{"JUNYA", 5, 206940},
	{"DWORK", 5, 206941},
	{"MILLES", 6, 206942},
	{"VANDERJAGT", 10, 206943},
	{"SAPIRO", 6, 206944},
	{"SAKER", 5, 206945},
	{"DOWNPOURS", 9, 206946},
	{"DEBIDO", 6, 206947},
	{"MARLYN", 6, 206948},
	{"KUNSTENAAR", 10, 206949},
	{"ADEX", 4, 206950},
	{"SLAVEHOLDERS", 12, 206951},
	{"REGGINA", 7, 206952},
	{"PCNTL", 5, 206953},
	{"KANSAN", 6, 206954},
	{"GRAPHISOFT", 10, 206955},
	{"PARLEZ", 6, 206956},
	{"NILESH", 6, 206957},
	{"ICARPLAY", 8, 206958},
	{"MONTGENEVRE", 11, 206959},
	{"ERGEBNIS", 8, 206960},
	{"SPINER", 6, 206961},
	{"GERONTOLOGIST", 13, 206962},
	{"STRACK", 6, 206963},
	{"BIOPSYCHOSOCIAL", 15, 206964},
	{"JTREE", 5, 206965},
	{"REPAYS", 6, 206966},
	{"RELEGATING", 10, 206967},
	{"NAGASHIMA", 9, 206968},
	{"HTFR", 4, 206969},
	{"EMPLACED", 8, 206970},
	{"TECHNOLOY", 9, 206971},
	{"ONANIE", 6, 206972},
	{"HARDBACKS", 9, 206973},
	{"CYDONIA", 7, 206974},
	{"UNCIAL", 6, 206975},
	{"SYMMETRA", 8, 206976},
	{"BOSTONIANS", 10, 206977},
	{"BLACKNIGHT", 10, 206978},
	{"JAROSLAW", 8, 206979},
	{"WORLDNEWS", 9, 206980},
	{"LULLABYE", 8, 206981},
	{"ZEEK", 4, 206982},
	{"WILLMORE", 8, 206983},
	{"ARBRES", 6, 206984},
	{"KUBE", 4, 206985},
	{"FRIESENHAHN", 11, 206986},
	{"FLOORINGS", 9, 206987},
	{"DIEHARDS", 8, 206988},
	{"CONSTUCTION", 11, 206989},
	{"MANZANAR", 8, 206990},
	{"BILBY", 5, 206991},
	{"STRTOL", 6, 206992},
	{"KLOSTER", 7, 206993},
	{"YNMC", 4, 206994},
	{"YMRW", 4, 206995},
	{"YCHT", 4, 206996},
	{"VHOW", 4, 206997},
	{"VDAR", 4, 206998},
	{"UHFC", 4, 206999},
	{"UGVI", 4, 207000},
	{"TPEY", 4, 207001},
	{"SYGI", 4, 207002},
	{"SXVE", 4, 207003},
	{"SULM", 4, 207004},
	{"SPOB", 4, 207005},
	{"RYIP", 4, 207006},
	{"RTUF", 4, 207007},
	{"RDKU", 4, 207008},
	{"RDAZ", 4, 207009},
	{"PHPI", 4, 207010},
	{"PEGH", 4, 207011},
	{"OVAZ", 4, 207012},
	{"OJAW", 4, 207013},
	{"NOXB", 4, 207014},
	{"MYIE", 4, 207015},
	{"MGUL", 4, 207016},
	{"KYEV", 4, 207017},
	{"KPSY", 4, 207018},
	{"HRDA", 4, 207019},
	{"GNBI", 4, 207020},
	{"GLUA", 4, 207021},
	{"GGYE", 4, 207022},
	{"GCNN", 4, 207023},
	{"GAMN", 4, 207024},
	{"FUQU", 4, 207025},
	{"FEUI", 4, 207026},
	{"ETKU", 4, 207027},
	{"EDFM", 4, 207028},
	{"DZUN", 4, 207029},
	{"DDCR", 4, 207030},
	{"CDHA", 4, 207031},
	{"BDAC", 4, 207032},
	{"BCAK", 4, 207033},
	{"BAYY", 4, 207034},
	{"AMBP", 4, 207035},
	{"AHGU", 4, 207036},
	{"COMPLEJOS", 9, 207037},
	{"PROVIDERWIRELESS", 16, 207038},
	{"KNEIPP", 6, 207039},
	{"COLESVILLE", 10, 207040},
	{"RIVED", 5, 207041},
	{"PROPUESTA", 9, 207042},
	{"MODDP", 5, 207043},
	{"BOOKA", 5, 207044},
	{"EXCISES", 7, 207045},
	{"CASESENSITIVE", 13, 207046},
	{"FAKS", 4, 207047},
	{"DEEPAVALI", 9, 207048},
	{"RAINLENDAR", 10, 207049},
	{"PERMEO", 6, 207050},
	{"CUSSES", 6, 207051},
	{"LAMPEDUSA", 9, 207052},
	{"GARRIGUES", 9, 207053},
	{"FAECIUM", 7, 207054},
	{"ALTERATIVE", 10, 207055},
	{"ZULUS", 5, 207056},
	{"SLOPPINESS", 10, 207057},
	{"STANKOVIC", 9, 207058},
	{"RETRIBUZIONE", 12, 207059},
	{"CARZONE", 7, 207060},
	{"ARTERIA", 7, 207061},
	{"MYCOL", 5, 207062},
	{"LIMPID", 6, 207063},
	{"ERRORMSG", 8, 207064},
	{"BRIDLED", 7, 207065},
	{"APPLNK", 6, 207066},
	{"KALIA", 5, 207067},
	{"FLEDGLINGS", 10, 207068},
	{"OBIETTIVO", 9, 207069},
	{"POLITICISED", 11, 207070},
	{"MAYLE", 5, 207071},
	{"TUPPENCE", 8, 207072},
	{"HYPOSPADIAS", 11, 207073},
	{"WIDI", 4, 207074},
	{"SCHAD", 5, 207075},
	{"RHAGOR", 6, 207076},
	{"BENZINO", 7, 207077},
	{"BATR", 4, 207078},
	{"FORECASTLE", 10, 207079},
	{"RAJMOHAN", 8, 207080},
	{"GRUNIN", 6, 207081},
	{"CHIARO", 6, 207082},
	{"MIDDLEEAST", 10, 207083},
	{"KAMMERER", 8, 207084},
	{"BRUECKNER", 9, 207085},
	{"BRISTAN", 7, 207086},
	{"ALLENWOOD", 9, 207087},
	{"HEKAFORGE", 9, 207088},
	{"POLARIZE", 8, 207089},
	{"AQUARACER", 9, 207090},
	{"FRANCISCHINA", 12, 207091},
	{"PNTHEMES", 8, 207092},
	{"ALQUILERES", 10, 207093},
	{"NONDISABLED", 11, 207094},
	{"BOWLIN", 6, 207095},
	{"EMERGEN", 7, 207096},
	{"PAULINI", 7, 207097},
	{"MASIELLO", 8, 207098},
	{"CALCULABLE", 10, 207099},
	{"AJITH", 5, 207100},
	{"UNDEMANDING", 11, 207101},
	{"STATUESQUE", 10, 207102},
	{"HOLONOMY", 8, 207103},
	{"BROACHES", 8, 207104},
	{"HELFRICH", 8, 207105},
	{"TETRAZOLIUM", 11, 207106},
	{"NANOMATERIAL", 12, 207107},
	{"JAVASOUND", 9, 207108},
	{"BUISINESS", 9, 207109},
	{"COMPUTERWI", 10, 207110},
	{"UNSATISFIABLE", 13, 207111},
	{"PORTSWOOD", 9, 207112},
	{"JAZMINE", 7, 207113},
	{"FRIDGEMASTER", 12, 207114},
	{"FLANDREAU", 9, 207115},
	{"PRNG", 4, 207116},
	{"CARUANA", 7, 207117},
	{"DATALOGGING", 11, 207118},
	{"CCCU", 4, 207119},
	{"STOREVISIT", 10, 207120},
	{"COMPTUER", 8, 207121},
	{"CEDARPK", 7, 207122},
	{"SHEETAL", 7, 207123},
	{"PATNI", 5, 207124},
	{"BRACER", 6, 207125},
	{"UCHEL", 5, 207126},
	{"FACTURE", 7, 207127},
	{"STIJL", 5, 207128},
	{"NARDIELLO", 9, 207129},
	{"MALADMINISTRATION", 17, 207130},
	{"BRIDALWEAR", 10, 207131},
	{"BRASILIEN", 9, 207132},
	{"SUNNED", 6, 207133},
	{"MULTIFUNCTIONS", 14, 207134},
	{"PRAAG", 5, 207135},
	{"VOLTAMMETRY", 11, 207136},
	{"FIGGINS", 7, 207137},
	{"AIRSON", 6, 207138},
	{"PROSCRIBE", 9, 207139},
	{"NEXLAB", 6, 207140},
	{"MICRONUCLEUS", 12, 207141},
	{"XDICT", 5, 207142},
	{"MIRRO", 5, 207143},
	{"INGAN", 5, 207144},
	{"SHINERS", 7, 207145},
	{"PICTUREA", 8, 207146},
	{"MATTHIJS", 8, 207147},
	{"DAMNUM", 6, 207148},
	{"COTMAN", 6, 207149},
	{"FARSIGHTED", 10, 207150},
	{"DNNFORGE", 8, 207151},
	{"PUZO", 4, 207152},
	{"DIGITALISED", 11, 207153},
	{"SHEDAISY", 8, 207154},
	{"SYNISTER", 8, 207155},
	{"POLYPHEMUS", 10, 207156},
	{"MEGAMALL", 8, 207157},
	{"BEYNON", 6, 207158},
	{"PORSCHES", 8, 207159},
	{"CODERRE", 7, 207160},
	{"CALLON", 6, 207161},
	{"CITRI", 5, 207162},
	{"AMANECER", 8, 207163},
	{"ABDUCTIVE", 9, 207164},
	{"CHOLECALCIFEROL", 15, 207165},
	{"POWERLAW", 8, 207166},
	{"LMSC", 4, 207167},
	{"DISCECTOMY", 10, 207168},
	{"KATTAN", 6, 207169},
	{"GRIPPE", 6, 207170},
	{"ENGIE", 5, 207171},
	{"VISITSCOTLAND", 13, 207172},
	{"MUNCA", 5, 207173},
	{"MAEDER", 6, 207174},
	{"KNOWED", 6, 207175},
	{"ANDALUZ", 7, 207176},
	{"SALOP", 5, 207177},
	{"VENEGAS", 7, 207178},
	{"NCWA", 4, 207179},
	{"INCIPIT", 7, 207180},
	{"MEYNELL", 7, 207181},
	{"LOKOMOTIV", 9, 207182},
	{"LEXPERT", 7, 207183},
	{"DEMYSTIFIES", 11, 207184},
	{"CLONAKILTY", 10, 207185},
	{"HEARNS", 6, 207186},
	{"ENCOURAGINGLY", 13, 207187},
	{"RICHEMONT", 9, 207188},
	{"RECONSTITUTING", 14, 207189},
	{"LOCKSETS", 8, 207190},
	{"AMEER", 5, 207191},
	{"UNBUILT", 7, 207192},
	{"SARAHK", 6, 207193},
	{"SCHEIDT", 7, 207194},
	{"SUBCLONED", 9, 207195},
	{"HAUJOBB", 7, 207196},
	{"HARBOURED", 9, 207197},
	{"YNAF", 4, 207198},
	{"YLUB", 4, 207199},
	{"YCBC", 4, 207200},
	{"WUSO", 4, 207201},
	{"VFRE", 4, 207202},
	{"UKDI", 4, 207203},
	{"UDSR", 4, 207204},
	{"UABR", 4, 207205},
	{"TUGE", 4, 207206},
	{"SYJU", 4, 207207},
	{"SRUC", 4, 207208},
	{"PULU", 4, 207209},
	{"OXYP", 4, 207210},
	{"OMMD", 4, 207211},
	{"OJAG", 4, 207212},
	{"OGYY", 4, 207213},
	{"NYMM", 4, 207214},
	{"NRDS", 4, 207215},
	{"MMUH", 4, 207216},
	{"LLZE", 4, 207217},
	{"LLRY", 4, 207218},
	{"LKTU", 4, 207219},
	{"KYSN", 4, 207220},
	{"KWEF", 4, 207221},
	{"KURM", 4, 207222},
	{"KTAU", 4, 207223},
	{"KRST", 4, 207224},
	{"KOVB", 4, 207225},
	{"KITJ", 4, 207226},
	{"ISCV", 4, 207227},
	{"HEFK", 4, 207228},
	{"GUMU", 4, 207229},
	{"GNVE", 4, 207230},
	{"FVAT", 4, 207231},
	{"FOZA", 4, 207232},
	{"EZAV", 4, 207233},
	{"EGAK", 4, 207234},
	{"EDVL", 4, 207235},
	{"DRTR", 4, 207236},
	{"DMSB", 4, 207237},
	{"CNEG", 4, 207238},
	{"BWRI", 4, 207239},
	{"AZEV", 4, 207240},
	{"AZAU", 4, 207241},
	{"AWOP", 4, 207242},
	{"APUJ", 4, 207243},
	{"AKHL", 4, 207244},
	{"RUSEDSKI", 8, 207245},
	{"SALIVATE", 8, 207246},
	{"CENCE", 5, 207247},
	{"REUEL", 5, 207248},
	{"MYSTICA", 7, 207249},
	{"MALEFICENT", 10, 207250},
	{"IPPO", 4, 207251},
	{"DEANN", 5, 207252},
	{"TSUKIHIME", 9, 207253},
	{"BIODEGRADABILITY", 16, 207254},
	{"MOGENSEN", 8, 207255},
	{"ACHR", 4, 207256},
	{"EMPTYPLUGIN", 11, 207257},
	{"BUMILLER", 8, 207258},
	{"SEMIOCHEMICALS", 14, 207259},
	{"REGOLAMENTO", 11, 207260},
	{"PULSERAS", 8, 207261},
	{"HISASHI", 7, 207262},
	{"SILVERSTAR", 10, 207263},
	{"FOOLE", 5, 207264},
	{"ENSAYO", 6, 207265},
	{"AMAGANSETT", 10, 207266},
	{"BOATERSWORLD", 12, 207267},
	{"ANIMORPHS", 9, 207268},
	{"CUTTHROATS", 10, 207269},
	{"VRWC", 4, 207270},
	{"CHILEANS", 8, 207271},
	{"MUSIKK", 6, 207272},
	{"LAVAR", 5, 207273},
	{"SHRUTI", 6, 207274},
	{"IFUPDOWN", 8, 207275},
	{"SHUTUP", 6, 207276},
	{"PROLABS", 7, 207277},
	{"PASSAMAQUODDY", 13, 207278},
	{"SANCO", 5, 207279},
	{"MAPDELTA", 8, 207280},
	{"ILMAINEN", 8, 207281},
	{"PHRYNIS", 7, 207282},
	{"EVENNESS", 8, 207283},
	{"BEMA", 4, 207284},
	{"ANAPHORIC", 9, 207285},
	{"AMWELL", 6, 207286},
	{"STRUGGLERS", 10, 207287},
	{"MERRIT", 6, 207288},
	{"FBK", 3, 207289},
	{"ADUT", 4, 207290},
	{"BHFUIL", 6, 207291},
	{"REMANDING", 9, 207292},
	{"CAVALCANTI", 10, 207293},
	{"ARIL", 4, 207294},
	{"POSIZIONE", 9, 207295},
	{"REVERSIONARY", 12, 207296},
	{"PANCHEN", 7, 207297},
	{"MISSCHIEN", 9, 207298},
	{"SLOTHS", 6, 207299},
	{"FULCI", 5, 207300},
	{"ANTICHE", 7, 207301},
	{"MLOGIQ", 6, 207302},
	{"ELEVA", 5, 207303},
	{"SHIGELLOSIS", 11, 207304},
	{"DUCANE", 6, 207305},
	{"OUTGROUP", 8, 207306},
	{"SPAREDOLLAR", 11, 207307},
	{"NIRANJAN", 8, 207308},
	{"PUTO", 4, 207309},
	{"EXFOLIANT", 9, 207310},
	{"TOMOHIRO", 8, 207311},
	{"EMPLOYEUR", 9, 207312},
	{"FIRAXIS", 7, 207313},
	{"MOROZ", 5, 207314},
	{"BIOCITY", 7, 207315},
	{"PSTHTTP", 7, 207316},
	{"PCHILDAB", 8, 207317},
	{"SHOGUNATE", 9, 207318},
	{"NOXON", 5, 207319},
	{"NAGPRA", 6, 207320},
	{"KINDERCARE", 10, 207321},
	{"CUSTOMERCARE", 12, 207322},
	{"COMMUNALLY", 10, 207323},
	{"FORTRON", 7, 207324},
	{"DAMONE", 6, 207325},
	{"FUNDO", 5, 207326},
	{"WALBRO", 6, 207327},
	{"DOLOROUS", 8, 207328},
	{"DRESHER", 7, 207329},
	{"PUSHDOWN", 8, 207330},
	{"PLAYBOOKS", 9, 207331},
	{"LIFESITE", 8, 207332},
	{"CLATSKANIE", 10, 207333},
	{"INDEXENTRY", 10, 207334},
	{"DUBIA", 5, 207335},
	{"BENEFICE", 8, 207336},
	{"STRTOTIME", 9, 207337},
	{"KREATIONS", 9, 207338},
	{"DRAGLINE", 8, 207339},
	{"JAVAFORGE", 9, 207340},
	{"INJUN", 5, 207341},
	{"LIVROS", 6, 207342},
	{"UNENLIGHTENED", 13, 207343},
	{"PSYOPS", 6, 207344},
	{"PLUMPING", 8, 207345},
	{"MAHFOUZ", 7, 207346},
	{"STROUSE", 7, 207347},
	{"DONNELLAN", 9, 207348},
	{"CORRIB", 6, 207349},
	{"SAGTE", 5, 207350},
	{"MONKEYBOY", 9, 207351},
	{"DILLSBURG", 9, 207352},
	{"COQUINE", 7, 207353},
	{"PRODRIVE", 8, 207354},
	{"ZOFE", 4, 207355},
	{"WGYM", 4, 207356},
	{"VREU", 4, 207357},
	{"VCOL", 4, 207358},
	{"TXBO", 4, 207359},
	{"TPPR", 4, 207360},
	{"TDSC", 4, 207361},
	{"RXTH", 4, 207362},
	{"RUAP", 4, 207363},
	{"ROXO", 4, 207364},
	{"ROSQ", 4, 207365},
	{"RIKZ", 4, 207366},
	{"PPDI", 4, 207367},
	{"PMGR", 4, 207368},
	{"OLYK", 4, 207369},
	{"OGCL", 4, 207370},
	{"NZIW", 4, 207371},
	{"NNFC", 4, 207372},
	{"NDVH", 4, 207373},
	{"MMSP", 4, 207374},
	{"LVOO", 4, 207375},
	{"LMJU", 4, 207376},
	{"KYMU", 4, 207377},
	{"KPAV", 4, 207378},
	{"KKAP", 4, 207379},
	{"IURN", 4, 207380},
	{"HMOC", 4, 207381},
	{"DYOD", 4, 207382},
	{"CLEQ", 4, 207383},
	{"CASJ", 4, 207384},
	{"BVAR", 4, 207385},
	{"BIYO", 4, 207386},
	{"AZOU", 4, 207387},
	{"ATQW", 4, 207388},
	{"LEGUIN", 6, 207389},
	{"PROTESTA", 8, 207390},
	{"LLYFR", 5, 207391},
	{"HASVALUE", 8, 207392},
	{"HANDSEWN", 8, 207393},
	{"TWININGS", 8, 207394},
	{"KERLEY", 6, 207395},
	{"INCESR", 6, 207396},
	{"HOTSEAT", 7, 207397},
	{"GENNYCH", 7, 207398},
	{"EROSIONS", 8, 207399},
	{"GFORTH", 6, 207400},
	{"PERSOONLIJKE", 12, 207401},
	{"ORTHOSES", 8, 207402},
	{"HOLBERT", 7, 207403},
	{"KAIYA", 5, 207404},
	{"ALFEMMINILE", 11, 207405},
	{"PHPPORTALS", 10, 207406},
	{"NAPHTHOL", 8, 207407},
	{"COVERSLIPS", 10, 207408},
	{"TUTICORIN", 9, 207409},
	{"ROLFS", 5, 207410},
	{"LAMBOOT", 7, 207411},
	{"INSERTIONAL", 11, 207412},
	{"BEDAT", 5, 207413},
	{"HARDCOE", 7, 207414},
	{"CROAKED", 7, 207415},
	{"WHOLESOMENESS", 13, 207416},
	{"TRUCCO", 6, 207417},
	{"HETERODIMERS", 12, 207418},
	{"CAPABLY", 7, 207419},
	{"LEITCHFIELD", 11, 207420},
	{"RACKE", 5, 207421},
	{"DRAKXTOOLS", 10, 207422},
	{"ENCONTRO", 8, 207423},
	{"ATRIPLEX", 8, 207424},
	{"VERGATA", 7, 207425},
	{"RECOMMANDATIONS", 15, 207426},
	{"WERF", 4, 207427},
	{"ALKAN", 5, 207428},
	{"SHIPPINGFREE", 12, 207429},
	{"PIERZYNSKI", 10, 207430},
	{"LILIENTHAL", 10, 207431},
	{"SHOLEM", 6, 207432},
	{"EXCELSUS", 8, 207433},
	{"MAXIMUMASP", 10, 207434},
	{"RECHNER", 7, 207435},
	{"DVDROM", 6, 207436},
	{"NOSEDIVE", 8, 207437},
	{"LAWMEN", 6, 207438},
	{"AVILABLE", 8, 207439},
	{"AWLGRIP", 7, 207440},
	{"FLUBBER", 7, 207441},
	{"SYMBOLICAL", 10, 207442},
	{"ANYWERE", 7, 207443},
	{"MAGISTRACY", 10, 207444},
	{"ELECTRIX", 8, 207445},
	{"ALIGHTING", 9, 207446},
	{"DDOD", 4, 207447},
	{"IMPUT", 5, 207448},
	{"SLIB", 4, 207449},
	{"HONORIS", 7, 207450},
	{"FREEWORLD", 9, 207451},
	{"ROSSMOOR", 8, 207452},
	{"ORBFIT", 6, 207453},
	{"NORTGAGE", 8, 207454},
	{"SCHRITTE", 8, 207455},
	{"QUERYINTERFACE", 14, 207456},
	{"MRMOVIETIMES", 12, 207457},
	{"FORETASTE", 9, 207458},
	{"ZARATE", 6, 207459},
	{"UNIDRAW", 7, 207460},
	{"RAZI", 4, 207461},
	{"LSTRATEGO", 9, 207462},
	{"BANQUES", 7, 207463},
	{"ARTSOPOLIS", 10, 207464},
	{"SUBLETTING", 10, 207465},
	{"TUGGLE", 6, 207466},
	{"PHOSPHOFRUCTOKINASE", 19, 207467},
	{"OHMAN", 5, 207468},
	{"DEBEER", 6, 207469},
	{"ACCEDER", 7, 207470},
	{"PORTHOS", 7, 207471},
	{"PHOTOBANK", 9, 207472},
	{"ANZIANI", 7, 207473},
	{"RISCHIO", 7, 207474},
	{"PAISES", 6, 207475},
	{"ARBS", 4, 207476},
	{"PLEBIUS", 7, 207477},
	{"ASTROWORLD", 10, 207478},
	{"SUPERSTRINGS", 12, 207479},
	{"COVERY", 6, 207480},
	{"IWCONFIG", 8, 207481},
	{"INCOHERENTLY", 12, 207482},
	{"AKITO", 5, 207483},
	{"ONCLUSIONS", 10, 207484},
	{"KINDERMUSIK", 11, 207485},
	{"WYCHE", 5, 207486},
	{"SIMULACRA", 9, 207487},
	{"LADYLIKE", 8, 207488},
	{"YUMIKO", 6, 207489},
	{"PRESURFER", 9, 207490},
	{"PCIS", 4, 207491},
	{"CRPS", 4, 207492},
	{"NEWSLINX", 8, 207493},
	{"SLOCAN", 6, 207494},
	{"MAHARSHI", 8, 207495},
	{"KYANITE", 7, 207496},
	{"ORGANOMETALLICS", 15, 207497},
	{"HEDDLU", 6, 207498},
	{"TROTTA", 6, 207499},
	{"SEBEN", 5, 207500},
	{"CORAX", 5, 207501},
	{"COLUMNNAME", 10, 207502},
	{"ROWLES", 6, 207503},
	{"FERNBOM", 7, 207504},
	{"PYLES", 5, 207505},
	{"HIDEOUTS", 8, 207506},
	{"DYNEBOLIC", 9, 207507},
	{"JEWISON", 7, 207508},
	{"IGUACU", 6, 207509},
	{"LOCKNUT", 7, 207510},
	{"ACTINOMYCIN", 11, 207511},
	{"DEVELOPME", 9, 207512},
	{"TERPENES", 8, 207513},
	{"IPHIGENIA", 9, 207514},
	{"RIKISHI", 7, 207515},
	{"PROOFER", 7, 207516},
	{"PLEINE", 6, 207517},
	{"SOLDANO", 7, 207518},
	{"RHEUMATICA", 10, 207519},
	{"MASTEN", 6, 207520},
	{"HEADDRESSES", 11, 207521},
	{"CLINICALS", 9, 207522},
	{"BUSHORGNZ", 9, 207523},
	{"PHILEAS", 7, 207524},
	{"UGB", 3, 207525},
	{"MANZULLO", 8, 207526},
	{"ALLURED", 7, 207527},
	{"VULKAN", 6, 207528},
	{"DELINEATIONS", 12, 207529},
	{"NONAFFILIATED", 13, 207530},
	{"XMALLOC", 7, 207531},
	{"PANPIPES", 8, 207532},
	{"MYAH", 4, 207533},
	{"EPIRUBICIN", 10, 207534},
	{"POLYTONE", 8, 207535},
	{"ITALICA", 7, 207536},
	{"CLASSICIST", 10, 207537},
	{"SYNGAS", 6, 207538},
	{"GLYCONUTRIENTS", 14, 207539},
	{"INTERRELATE", 11, 207540},
	{"YLTR", 4, 207541},
	{"YDDE", 4, 207542},
	{"XEED", 4, 207543},
	{"WOEQ", 4, 207544},
	{"WBYE", 4, 207545},
	{"UTIZ", 4, 207546},
	{"UOCL", 4, 207547},
	{"SILJ", 4, 207548},
	{"SCDA", 4, 207549},
	{"RUDW", 4, 207550},
	{"RTZL", 4, 207551},
	{"ROOZ", 4, 207552},
	{"ROGF", 4, 207553},
	{"RLGA", 4, 207554},
	{"RGBI", 4, 207555},
	{"RELJ", 4, 207556},
	{"PAEL", 4, 207557},
	{"OZYI", 4, 207558},
	{"OYMC", 4, 207559},
	{"OCEC", 4, 207560},
	{"NZCO", 4, 207561},
	{"NTUW", 4, 207562},
	{"NSKW", 4, 207563},
	{"NSGM", 4, 207564},
	{"NIRB", 4, 207565},
	{"NEXQ", 4, 207566},
	{"NCKR", 4, 207567},
	{"NAYC", 4, 207568},
	{"NAUW", 4, 207569},
	{"LOGV", 4, 207570},
	{"KAEV", 4, 207571},
	{"JMIL", 4, 207572},
	{"JKRO", 4, 207573},
	{"GFRY", 4, 207574},
	{"FYMY", 4, 207575},
	{"FNAJ", 4, 207576},
	{"ERBV", 4, 207577},
	{"DUKO", 4, 207578},
	{"DETV", 4, 207579},
	{"CRDE", 4, 207580},
	{"BAKW", 4, 207581},
	{"APVE", 4, 207582},
	{"CYFRES", 6, 207583},
	{"ATTLEE", 6, 207584},
	{"MELITENSIS", 10, 207585},
	{"SWINDOLL", 8, 207586},
	{"JROLLER", 7, 207587},
	{"DIAECULT", 8, 207588},
	{"TIMEWARP", 8, 207589},
	{"IAPETUS", 7, 207590},
	{"STOPZILLA", 9, 207591},
	{"DISCUSSIONI", 11, 207592},
	{"ARTIF", 5, 207593},
	{"MECKLER", 7, 207594},
	{"DENTINE", 7, 207595},
	{"STEEPING", 8, 207596},
	{"LIVEMODERN", 10, 207597},
	{"ESCUTCHEONS", 11, 207598},
	{"COCKRING", 8, 207599},
	{"NONDETERMINISM", 14, 207600},
	{"MARSAN", 6, 207601},
	{"PLAYMAT", 7, 207602},
	{"KAMO", 4, 207603},
	{"COPEN", 5, 207604},
	{"MAINWINDOW", 10, 207605},
	{"QTEC", 4, 207606},
	{"MINIDISK", 8, 207607},
	{"SAXMAN", 6, 207608},
	{"LLANDAFF", 8, 207609},
	{"CLUMPED", 7, 207610},
	{"BILO", 4, 207611},
	{"TRAMADL", 7, 207612},
	{"MENTO", 5, 207613},
	{"JAHRHUNDERTS", 12, 207614},
	{"ONFOCUS", 7, 207615},
	{"LOVELIES", 8, 207616},
	{"FRAENKEL", 8, 207617},
	{"LUCILLA", 7, 207618},
	{"SOUTHDOWN", 9, 207619},
	{"TECTONOPHYSICS", 14, 207620},
	{"PAFOS", 5, 207621},
	{"DESMOPRESSIN", 12, 207622},
	{"DATAWATCH", 9, 207623},
	{"LAPU", 4, 207624},
	{"FOIRE", 5, 207625},
	{"PHENOXY", 7, 207626},
	{"CONSTITUE", 9, 207627},
	{"VAGRANCY", 8, 207628},
	{"SOGAR", 5, 207629},
	{"HENARES", 7, 207630},
	{"COLLEN", 6, 207631},
	{"PANDANUS", 8, 207632},
	{"LAKS", 4, 207633},
	{"COTERMINOUS", 11, 207634},
	{"LIGNAN", 6, 207635},
	{"UFOLOGY", 7, 207636},
	{"TOMMO", 5, 207637},
	{"GCIDE", 5, 207638},
	{"MCKEEN", 6, 207639},
	{"LJK", 3, 207640},
	{"INDOOROOPILLY", 13, 207641},
	{"FOIST", 5, 207642},
	{"BSCI", 4, 207643},
	{"PALPABLY", 8, 207644},
	{"LBOX", 4, 207645},
	{"SOFTY", 5, 207646},
	{"POWERSHRED", 10, 207647},
	{"ADDRESSE", 8, 207648},
	{"DDAU", 4, 207649},
	{"LAFFEY", 6, 207650},
	{"INTERATOMIC", 11, 207651},
	{"AUFL", 4, 207652},
	{"VDB", 3, 207653},
	{"OPHRYS", 6, 207654},
	{"CATIZONE", 8, 207655},
	{"COFFEESHOPS", 11, 207656},
	{"VANDERMARK", 10, 207657},
	{"RESSURECTION", 12, 207658},
	{"UROPEAN", 7, 207659},
	{"DIAMONDHEAD", 11, 207660},
	{"NORIYUKI", 8, 207661},
	{"GANGER", 6, 207662},
	{"THERMOGENESIS", 13, 207663},
	{"SHOWWINDOW", 10, 207664},
	{"OPTEX", 5, 207665},
	{"WEDER", 5, 207666},
	{"INGVAR", 6, 207667},
	{"ASFALEIAS", 9, 207668},
	{"ABLEDATA", 8, 207669},
	{"BOONES", 6, 207670},
	{"VARIABILIS", 10, 207671},
	{"IMPROBABLY", 10, 207672},
	{"MULTITOOL", 9, 207673},
	{"MILION", 6, 207674},
	{"COLNEY", 6, 207675},
	{"BUMPERSTICKERS", 14, 207676},
	{"SCALI", 5, 207677},
	{"LUCENA", 6, 207678},
	{"BRADLEE", 7, 207679},
	{"KIYO", 4, 207680},
	{"EXPRESSIONLESS", 14, 207681},
	{"DMCS", 4, 207682},
	{"MKEA", 4, 207683},
	{"BOWSTRING", 9, 207684},
	{"BANGERTH", 8, 207685},
	{"DOORDARSHAN", 11, 207686},
	{"WOTSAP", 6, 207687},
	{"STUTZMAN", 8, 207688},
	{"LEBEC", 5, 207689},
	{"COLLIMATORS", 11, 207690},
	{"USEPERL", 7, 207691},
	{"ABRADED", 7, 207692},
	{"NACKTBILDER", 11, 207693},
	{"MANNAR", 6, 207694},
	{"THALMANN", 8, 207695},
	{"AGORED", 6, 207696},
	{"IGITAL", 6, 207697},
	{"UOFM", 4, 207698},
	{"DENAR", 5, 207699},
	{"SATCHMO", 7, 207700},
	{"PRWORA", 6, 207701},
	{"BANDAGING", 9, 207702},
	{"LUBRICITY", 9, 207703},
	{"ARDALOEDD", 9, 207704},
	{"BINIONS", 7, 207705},
	{"PSBL", 4, 207706},
	{"ENSGG", 5, 207707},
	{"APPLEMAN", 8, 207708},
	{"SICKENS", 7, 207709},
	{"MAJIN", 5, 207710},
	{"FDQ", 3, 207711},
	{"CHANTERS", 8, 207712},
	{"AUTOCHANGER", 11, 207713},
	{"FACEDOWN", 8, 207714},
	{"AKINORI", 7, 207715},
	{"UPV", 3, 207716},
	{"BROMELIADS", 10, 207717},
	{"STOCKBROKING", 12, 207718},
	{"REGEHR", 6, 207719},
	{"ZZGU", 4, 207720},
	{"ZPOS", 4, 207721},
	{"ZOFC", 4, 207722},
	{"YNHL", 4, 207723},
	{"YDRD", 4, 207724},
	{"WKEA", 4, 207725},
	{"WEDQ", 4, 207726},
	{"WDSF", 4, 207727},
	{"UYDR", 4, 207728},
	{"UAYH", 4, 207729},
	{"UAAR", 4, 207730},
	{"SJUP", 4, 207731},
	{"SDRW", 4, 207732},
	{"SCBU", 4, 207733},
	{"SBPS", 4, 207734},
	{"RPGI", 4, 207735},
	{"RPCM", 4, 207736},
	{"RIKD", 4, 207737},
	{"RIIK", 4, 207738},
	{"RGWR", 4, 207739},
	{"PYKI", 4, 207740},
	{"OXDA", 4, 207741},
	{"ONWF", 4, 207742},
	{"NZUL", 4, 207743},
	{"NUKS", 4, 207744},
	{"NPWH", 4, 207745},
	{"NGFS", 4, 207746},
	{"NEKM", 4, 207747},
	{"NCDU", 4, 207748},
	{"MPBL", 4, 207749},
	{"MKAY", 4, 207750},
	{"KUSK", 4, 207751},
	{"JKOV", 4, 207752},
	{"JETD", 4, 207753},
	{"IRKG", 4, 207754},
	{"IKSM", 4, 207755},
	{"HYFU", 4, 207756},
	{"HUSJ", 4, 207757},
	{"FGLY", 4, 207758},
	{"ERNX", 4, 207759},
	{"EDTB", 4, 207760},
	{"EDKW", 4, 207761},
	{"DMCH", 4, 207762},
	{"DEOJ", 4, 207763},
	{"DDIZ", 4, 207764},
	{"CVEG", 4, 207765},
	{"CEDZ", 4, 207766},
	{"BOJU", 4, 207767},
	{"AMELINDA", 8, 207768},
	{"GASTRULATION", 12, 207769},
	{"DIMETHICONE", 11, 207770},
	{"BHLH", 4, 207771},
	{"ZODIACO", 7, 207772},
	{"XLOADIMAGE", 10, 207773},
	{"RWANDESE", 8, 207774},
	{"CAJAL", 5, 207775},
	{"TICLOPIDINE", 11, 207776},
	{"CYCLEOPS", 8, 207777},
	{"COTUIT", 6, 207778},
	{"BUSBAR", 6, 207779},
	{"CILENTO", 7, 207780},
	{"BROCKMANN", 9, 207781},
	{"SLUGGO", 6, 207782},
	{"PUMPERNICKEL", 12, 207783},
	{"KANCHIPURAM", 11, 207784},
	{"WIESER", 6, 207785},
	{"KINNERET", 8, 207786},
	{"DETRIMENTALLY", 13, 207787},
	{"FILMORE", 7, 207788},
	{"MAIDMENT", 8, 207789},
	{"HELLHOLE", 8, 207790},
	{"COPIAH", 6, 207791},
	{"KLEIBER", 7, 207792},
	{"JOLTING", 7, 207793},
	{"CAREONE", 7, 207794},
	{"SHIPBUILDER", 11, 207795},
	{"OVERHEARS", 9, 207796},
	{"ORGANOPHOSPHATES", 16, 207797},
	{"CONTROLLA", 9, 207798},
	{"SEISMOGRAM", 10, 207799},
	{"RENAN", 5, 207800},
	{"COVENANTAL", 10, 207801},
	{"BEDOUINS", 8, 207802},
	{"KCFS", 4, 207803},
	{"TITION", 6, 207804},
	{"CONSTRUCTEUR", 12, 207805},
	{"PCAS", 4, 207806},
	{"PASSIONE", 8, 207807},
	{"CPSA", 4, 207808},
	{"ROSBERG", 7, 207809},
	{"MEDIMMUNE", 9, 207810},
	{"VASP", 4, 207811},
	{"FLOATPLANE", 10, 207812},
	{"ASMP", 4, 207813},
	{"BATEY", 5, 207814},
	{"SOLANI", 6, 207815},
	{"PEIMS", 5, 207816},
	{"OMAC", 4, 207817},
	{"TAILBONE", 8, 207818},
	{"QUADRI", 6, 207819},
	{"ARTERIOGRAPHY", 13, 207820},
	{"HYBRIDOMAS", 10, 207821},
	{"DNAPL", 5, 207822},
	{"BEEBLEBROX", 10, 207823},
	{"PHYCOERYTHRIN", 13, 207824},
	{"FANSHOP", 7, 207825},
	{"SENSITIZER", 10, 207826},
	{"POSTKARTEN", 10, 207827},
	{"INTRAMUSCULARLY", 15, 207828},
	{"ELONGATUS", 9, 207829},
	{"SMSU", 4, 207830},
	{"RETRACEMENT", 11, 207831},
	{"HAMMADI", 7, 207832},
	{"TRANSCENDENTALISM", 17, 207833},
	{"HELICE", 6, 207834},
	{"FORSHAW", 7, 207835},
	{"AENEON", 6, 207836},
	{"BOTEVGRAD", 9, 207837},
	{"MANCHACA", 8, 207838},
	{"CONCOLOR", 8, 207839},
	{"NAMD", 4, 207840},
	{"REALADVENTURES", 14, 207841},
	{"HUMANNESS", 9, 207842},
	{"METRONET", 8, 207843},
	{"OVERCONFIDENT", 13, 207844},
	{"HOTSHEET", 8, 207845},
	{"GULPS", 5, 207846},
	{"SOUNDLESS", 9, 207847},
	{"TRAILSIDE", 9, 207848},
	{"ILYUSHIN", 8, 207849},
	{"CALZONES", 8, 207850},
	{"RENNET", 6, 207851},
	{"CASTANO", 7, 207852},
	{"SAMBUCA", 7, 207853},
	{"MARIINSKY", 9, 207854},
	{"FRANCI", 6, 207855},
	{"METROPARK", 9, 207856},
	{"LEADSINGER", 10, 207857},
	{"UPSTAGED", 8, 207858},
	{"KURIL", 5, 207859},
	{"JOOMLABOARD", 11, 207860},
	{"PUKIWIKI", 8, 207861},
	{"MOVIEJACK", 9, 207862},
	{"MACKALL", 7, 207863},
	{"DIOICA", 6, 207864},
	{"PREETY", 6, 207865},
	{"INTEGUMENTARY", 13, 207866},
	{"ESHAM", 5, 207867},
	{"SALESIAN", 8, 207868},
	{"POKET", 5, 207869},
	{"JANNIE", 6, 207870},
	{"TRANSTECH", 9, 207871},
	{"RESPIGHI", 8, 207872},
	{"MELANOCYTE", 10, 207873},
	{"JAXON", 5, 207874},
	{"VALIN", 5, 207875},
	{"MACLEISH", 8, 207876},
	{"HYNDE", 5, 207877},
	{"CHIANA", 6, 207878},
	{"ERIOGONUM", 9, 207879},
	{"HADDE", 5, 207880},
	{"BOXSHADE", 8, 207881},
	{"NEKTAR", 6, 207882},
	{"JEFFCO", 6, 207883},
	{"FREEST", 6, 207884},
	{"COOPERATIVITY", 13, 207885},
	{"TROPICA", 7, 207886},
	{"BUCHMANN", 8, 207887},
	{"SPYWAR", 6, 207888},
	{"LOAR", 4, 207889},
	{"HELPMAN", 7, 207890},
	{"ROMANTICI", 9, 207891},
	{"HYBRIDIZING", 11, 207892},
	{"BRIONES", 7, 207893},
	{"VANNELLI", 8, 207894},
	{"PUBCOOKIE", 9, 207895},
	{"DISCOLOURATION", 14, 207896},
	{"UNSPEAKABLY", 11, 207897},
	{"SHERAWAT", 8, 207898},
	{"TEARFUND", 8, 207899},
	{"BLATMATCH", 9, 207900},
	{"ENGROSSMENT", 11, 207901},
	{"THIBEAULT", 9, 207902},
	{"JOHNDOE", 7, 207903},
	{"CLAYMAN", 7, 207904},
	{"TRANCEIVERS", 11, 207905},
	{"ARRESTERS", 9, 207906},
	{"IXPK", 4, 207907},
	{"CHEANN", 6, 207908},
	{"HETRICK", 7, 207909},
	{"CAIRD", 5, 207910},
	{"STEPDAD", 7, 207911},
	{"HEPLER", 6, 207912},
	{"GESTALTEN", 9, 207913},
	{"NGOSS", 5, 207914},
	{"CBSS", 4, 207915},
	{"ASARO", 5, 207916},
	{"ZTEL", 4, 207917},
	{"ZPAH", 4, 207918},
	{"ZECT", 4, 207919},
	{"YVEJ", 4, 207920},
	{"WOLM", 4, 207921},
	{"WKRE", 4, 207922},
	{"VKOV", 4, 207923},
	{"VEMD", 4, 207924},
	{"UZCA", 4, 207925},
	{"USBH", 4, 207926},
	{"ULOK", 4, 207927},
	{"UAWO", 4, 207928},
	{"TMFR", 4, 207929},
	{"RMMC", 4, 207930},
	{"RMEK", 4, 207931},
	{"RDRR", 4, 207932},
	{"PUCA", 4, 207933},
	{"PIKM", 4, 207934},
	{"OXDR", 4, 207935},
	{"OCIU", 4, 207936},
	{"NGBM", 4, 207937},
	{"NFUK", 4, 207938},
	{"MOMG", 4, 207939},
	{"KYBI", 4, 207940},
	{"JPAY", 4, 207941},
	{"JIMV", 4, 207942},
	{"JCLA", 4, 207943},
	{"IWRE", 4, 207944},
	{"IJIP", 4, 207945},
	{"HYSR", 4, 207946},
	{"GMYK", 4, 207947},
	{"GDUD", 4, 207948},
	{"GBYY", 4, 207949},
	{"ETVV", 4, 207950},
	{"DZUC", 4, 207951},
	{"DSSQ", 4, 207952},
	{"DCSP", 4, 207953},
	{"CYPI", 4, 207954},
	{"CUSY", 4, 207955},
	{"CJUR", 4, 207956},
	{"CAYC", 4, 207957},
	{"BAYK", 4, 207958},
	{"SONGSTERS", 9, 207959},
	{"COMUNES", 7, 207960},
	{"NUDED", 5, 207961},
	{"UMMC", 4, 207962},
	{"TEMPEATURE", 10, 207963},
	{"SNEAKIN", 7, 207964},
	{"FLIPPY", 6, 207965},
	{"CIPLA", 5, 207966},
	{"BORROWDALE", 10, 207967},
	{"SKLANSKY", 8, 207968},
	{"XTREMETONES", 11, 207969},
	{"CRANKBAITS", 10, 207970},
	{"VORSITZENDE", 11, 207971},
	{"SIDESTEPS", 9, 207972},
	{"NANOSYSTEMS", 11, 207973},
	{"DINKUM", 6, 207974},
	{"BANDER", 6, 207975},
	{"PAINTLESS", 9, 207976},
	{"SYNTHESE", 8, 207977},
	{"SUBNORMAL", 9, 207978},
	{"KOKATAT", 7, 207979},
	{"SARSFIELD", 9, 207980},
	{"COMNAV", 6, 207981},
	{"COLORIMETER", 11, 207982},
	{"GARANZIA", 8, 207983},
	{"CHABROL", 7, 207984},
	{"VICTO", 5, 207985},
	{"ROTECTION", 9, 207986},
	{"DARKMOON", 8, 207987},
	{"WEATHERMATRIX", 13, 207988},
	{"UNCONQUERABLE", 13, 207989},
	{"BEDSIT", 6, 207990},
	{"PAYPALSHOW", 10, 207991},
	{"HISCOX", 6, 207992},
	{"BARTMAN", 7, 207993},
	{"RUNONCE", 7, 207994},
	{"LEFEVER", 7, 207995},
	{"CODEBANK", 8, 207996},
	{"MANNI", 5, 207997},
	{"CONTEMPLATIONS", 14, 207998},
	{"HUBNER", 6, 207999},
	{"HLBUSINESS", 10, 208000},
	{"DANDI", 5, 208001},
	{"CDICT", 5, 208002},
	{"CITYWALK", 8, 208003},
	{"UTRA", 4, 208004},
	{"OFFERTORY", 9, 208005},
	{"WELP", 4, 208006},
	{"GEOSTATISTICAL", 14, 208007},
	{"LANXESS", 7, 208008},
	{"EINGETRAGEN", 11, 208009},
	{"DELLWOOD", 8, 208010},
	{"CANCHILD", 8, 208011},
	{"RIDOUT", 6, 208012},
	{"PLIKO", 5, 208013},
	{"UTHORITY", 8, 208014},
	{"GEOTAGGED", 9, 208015},
	{"MAUNDY", 6, 208016},
	{"HELIUS", 6, 208017},
	{"GOLDNER", 7, 208018},
	{"WHISH", 5, 208019},
	{"TALUK", 5, 208020},
	{"HVDC", 4, 208021},
	{"FORETELLS", 9, 208022},
	{"HEIDRICK", 8, 208023},
	{"ENFEMENINO", 10, 208024},
	{"GHANIAN", 7, 208025},
	{"SOROKIN", 7, 208026},
	{"POLARON", 7, 208027},
	{"EMPOR", 5, 208028},
	{"INBUF", 5, 208029},
	{"USNM", 4, 208030},
	{"SRVC", 4, 208031},
	{"MAXRECORDS", 10, 208032},
	{"ECHECKS", 7, 208033},
	{"PLASS", 5, 208034},
	{"MAPD", 4, 208035},
	{"IMPREGNATING", 12, 208036},
	{"TERRAZAS", 8, 208037},
	{"PASTEBOARD", 10, 208038},
	{"LEIOMYOMA", 9, 208039},
	{"UNBILLED", 8, 208040},
	{"TEEMIX", 6, 208041},
	{"DOWNGRADIENT", 12, 208042},
	{"QUARTZSITE", 10, 208043},
	{"CFDS", 4, 208044},
	{"NEBOSH", 6, 208045},
	{"FLOWABLE", 8, 208046},
	{"CELF", 4, 208047},
	{"CALMAR", 6, 208048},
	{"VISIBILIDAD", 11, 208049},
	{"GLOWSTICK", 9, 208050},
	{"DAHM", 4, 208051},
	{"CHAKRABARTY", 11, 208052},
	{"KAJI", 4, 208053},
	{"CNIL", 4, 208054},
	{"MAMADOU", 7, 208055},
	{"GRAPHICSDATA", 12, 208056},
	{"WISMAR", 6, 208057},
	{"SUNBATHE", 8, 208058},
	{"PREAUTHORIZATION", 16, 208059},
	{"BEASON", 6, 208060},
	{"MANGY", 5, 208061},
	{"SNOCORE", 7, 208062},
	{"CATARRH", 7, 208063},
	{"YODELING", 8, 208064},
	{"FONTANE", 7, 208065},
	{"ETCHER", 6, 208066},
	{"MARINSHIP", 9, 208067},
	{"SETDASH", 7, 208068},
	{"FREDRIKSTAD", 11, 208069},
	{"MUSTAINE", 8, 208070},
	{"MATUS", 5, 208071},
	{"INTERZONE", 9, 208072},
	{"HELIOSPHERE", 11, 208073},
	{"MIXDOWN", 7, 208074},
	{"ANTHOCYANINS", 12, 208075},
	{"NEROLINUX", 9, 208076},
	{"LUDI", 4, 208077},
	{"MAGNETOHYDRODYNAMIC", 19, 208078},
	{"ARTAXERXES", 10, 208079},
	{"WOLSTENHOLME", 12, 208080},
	{"TERRYCLOTH", 10, 208081},
	{"DOFFING", 7, 208082},
	{"MAGNETOPAUSE", 12, 208083},
	{"HEADLINESMOST", 13, 208084},
	{"BROMIDES", 8, 208085},
	{"ORGANA", 6, 208086},
	{"MICROSOLUTIONS", 14, 208087},
	{"COOPERMAN", 9, 208088},
	{"STEEDA", 6, 208089},
	{"UPHOLLAND", 9, 208090},
	{"MALOTT", 6, 208091},
	{"XBLAST", 6, 208092},
	{"QCOLOR", 6, 208093},
	{"DERIVA", 6, 208094},
	{"SERGEJ", 6, 208095},
	{"DIGITALVISION", 13, 208096},
	{"INDUSTRIELLES", 13, 208097},
	{"EVERMAN", 7, 208098},
	{"TOSHIAKI", 8, 208099},
	{"PUBBLICAZIONI", 13, 208100},
	{"GLADDING", 8, 208101},
	{"EXONUMIA", 8, 208102},
	{"RCGP", 4, 208103},
	{"KOLPIN", 6, 208104},
	{"MISAPPREHENSION", 15, 208105},
	{"MULTIBOOT", 9, 208106},
	{"DEMUDI", 6, 208107},
	{"ZUSH", 4, 208108},
	{"ZREL", 4, 208109},
	{"ZKIT", 4, 208110},
	{"XCOP", 4, 208111},
	{"WYVE", 4, 208112},
	{"WWVI", 4, 208113},
	{"VDHA", 4, 208114},
	{"UPEU", 4, 208115},
	{"UPEB", 4, 208116},
	{"UORN", 4, 208117},
	{"TUBW", 4, 208118},
	{"TDAF", 4, 208119},
	{"SIDP", 4, 208120},
	{"RJRW", 4, 208121},
	{"RCSW", 4, 208122},
	{"PTKE", 4, 208123},
	{"PFEM", 4, 208124},
	{"PEZR", 4, 208125},
	{"NXUA", 4, 208126},
	{"NIBY", 4, 208127},
	{"NDUJ", 4, 208128},
	{"MUNB", 4, 208129},
	{"LLGY", 4, 208130},
	{"LEZF", 4, 208131},
	{"IRUG", 4, 208132},
	{"HOFZ", 4, 208133},
	{"HMPS", 4, 208134},
	{"GLBS", 4, 208135},
	{"GHUD", 4, 208136},
	{"FLTI", 4, 208137},
	{"EPNP", 4, 208138},
	{"DOLJ", 4, 208139},
	{"DKMO", 4, 208140},
	{"DGMC", 4, 208141},
	{"DCPL", 4, 208142},
	{"CYID", 4, 208143},
	{"BOWK", 4, 208144},
	{"BCEX", 4, 208145},
	{"YIZKOR", 6, 208146},
	{"CULTUR", 6, 208147},
	{"SAWAN", 5, 208148},
	{"PARTICIPANTES", 13, 208149},
	{"DRAK", 4, 208150},
	{"VERTI", 5, 208151},
	{"SEIKEN", 6, 208152},
	{"MACROEVOLUTION", 14, 208153},
	{"PERCHE", 6, 208154},
	{"MILSAP", 6, 208155},
	{"EPIMEDIUM", 9, 208156},
	{"AUTOLINK", 8, 208157},
	{"APRSSIG", 7, 208158},
	{"DRUMCREE", 8, 208159},
	{"AVAGO", 5, 208160},
	{"VESUVIO", 7, 208161},
	{"WINNOWING", 9, 208162},
	{"DJANGOS", 7, 208163},
	{"ORIC", 4, 208164},
	{"LEAV", 4, 208165},
	{"CODIFIES", 8, 208166},
	{"AMITA", 5, 208167},
	{"RISPOSTE", 8, 208168},
	{"GLANDULARS", 10, 208169},
	{"XERISCAPE", 9, 208170},
	{"REZENSION", 9, 208171},
	{"LAGUERRE", 8, 208172},
	{"SHAMEN", 6, 208173},
	{"SEGESTA", 7, 208174},
	{"GABINETE", 8, 208175},
	{"ASPIRATOR", 9, 208176},
	{"MATCHCOM", 8, 208177},
	{"BIEDERMEIER", 11, 208178},
	{"THINKFUN", 8, 208179},
	{"MOLIETS", 7, 208180},
	{"MOBILITIES", 10, 208181},
	{"HOLDOUTS", 8, 208182},
	{"COMPUSTAT", 9, 208183},
	{"ALPHEUS", 7, 208184},
	{"WRED", 4, 208185},
	{"REVERENTIAL", 11, 208186},
	{"LAFE", 4, 208187},
	{"HCARD", 5, 208188},
	{"BULLGUARD", 9, 208189},
	{"SEEDQUEST", 9, 208190},
	{"NAKAMOTO", 8, 208191},
	{"ASIANEWS", 8, 208192},
	{"ASSOCIATESHIP", 13, 208193},
	{"MALIKA", 6, 208194},
	{"ISAPNP", 6, 208195},
	{"USDF", 4, 208196},
	{"TOXICOLOGISTS", 13, 208197},
	{"AFLEET", 6, 208198},
	{"TOURCAST", 8, 208199},
	{"SCHWENDT", 8, 208200},
	{"GODO", 4, 208201},
	{"DANKS", 5, 208202},
	{"DALGLEISH", 9, 208203},
	{"PEGASO", 6, 208204},
	{"EXCE", 4, 208205},
	{"ARBOREA", 7, 208206},
	{"MENNEN", 6, 208207},
	{"SLEDGES", 7, 208208},
	{"OBIDOS", 6, 208209},
	{"TYPEID", 6, 208210},
	{"SCHOOLMATE", 10, 208211},
	{"KAIRO", 5, 208212},
	{"UTILES", 6, 208213},
	{"MULTIMEDIACARDS", 15, 208214},
	{"PEDLEY", 6, 208215},
	{"VFORK", 5, 208216},
	{"ATTORNE", 7, 208217},
	{"ASPARTYL", 8, 208218},
	{"FIGURAS", 7, 208219},
	{"DHINPUT", 7, 208220},
	{"ONCORE", 6, 208221},
	{"GIANNIS", 7, 208222},
	{"DENKE", 5, 208223},
	{"SAPARD", 6, 208224},
	{"DESTINOS", 8, 208225},
	{"DARWISH", 7, 208226},
	{"SHAMIL", 6, 208227},
	{"LUHRS", 5, 208228},
	{"UJC", 3, 208229},
	{"APPLELINKS", 10, 208230},
	{"ANANZI", 6, 208231},
	{"VIEWCAST", 8, 208232},
	{"BEFINDEN", 8, 208233},
	{"OPTIES", 6, 208234},
	{"SETLAYOUT", 9, 208235},
	{"VELMONT", 7, 208236},
	{"UNDAF", 5, 208237},
	{"NELLORE", 7, 208238},
	{"KOSEI", 5, 208239},
	{"DERIK", 5, 208240},
	{"DALLAM", 6, 208241},
	{"SCRIVERE", 8, 208242},
	{"REBIND", 6, 208243},
	{"ORIENTS", 7, 208244},
	{"COMINT", 6, 208245},
	{"HOLAND", 6, 208246},
	{"ESPER", 5, 208247},
	{"EMPLOYEMENT", 11, 208248},
	{"EDIF", 4, 208249},
	{"BIGGY", 5, 208250},
	{"POLITO", 6, 208251},
	{"PDFLATEX", 8, 208252},
	{"INDOCIN", 7, 208253},
	{"TONEARM", 7, 208254},
	{"ORCISH", 6, 208255},
	{"IWERDDON", 8, 208256},
	{"LEPP", 4, 208257},
	{"TRUSTUK", 7, 208258},
	{"GORRELL", 7, 208259},
	{"COPPERTONE", 10, 208260},
	{"ENSAM", 5, 208261},
	{"MOUNTAINBIKES", 13, 208262},
	{"MEANINGLESSNESS", 15, 208263},
	{"EVOY", 4, 208264},
	{"THANKFULL", 9, 208265},
	{"KAMERS", 6, 208266},
	{"ALVY", 4, 208267},
	{"ESOTERICISM", 11, 208268},
	{"ROCKO", 5, 208269},
	{"FIGGIS", 6, 208270},
	{"PROTIST", 7, 208271},
	{"LXEXT", 5, 208272},
	{"STOSUR", 6, 208273},
	{"DISTLER", 7, 208274},
	{"CORTICES", 8, 208275},
	{"WILCOCK", 7, 208276},
	{"MARKETINGPOWER", 14, 208277},
	{"PATENS", 6, 208278},
	{"WARHORSE", 8, 208279},
	{"CERVUS", 6, 208280},
	{"UVR", 3, 208281},
	{"MOUSA", 5, 208282},
	{"PANTAGRUEL", 10, 208283},
	{"DEFUNS", 6, 208284},
	{"DAMILOLA", 8, 208285},
	{"LINDVALL", 8, 208286},
	{"VALETTE", 7, 208287},
	{"SENSATIONALIST", 14, 208288},
	{"FORMOSAN", 8, 208289},
	{"CCLC", 4, 208290},
	{"ZAFE", 4, 208291},
	{"YRMI", 4, 208292},
	{"WOLU", 4, 208293},
	{"VYEM", 4, 208294},
	{"VSKO", 4, 208295},
	{"VDSW", 4, 208296},
	{"URDN", 4, 208297},
	{"UNNR", 4, 208298},
	{"UEIC", 4, 208299},
	{"TSYW", 4, 208300},
	{"TSDC", 4, 208301},
	{"SJUT", 4, 208302},
	{"SIXQ", 4, 208303},
	{"SGAW", 4, 208304},
	{"RTMD", 4, 208305},
	{"RLFA", 4, 208306},
	{"RIGM", 4, 208307},
	{"RGJO", 4, 208308},
	{"RFFR", 4, 208309},
	{"RDRG", 4, 208310},
	{"RBGA", 4, 208311},
	{"PODP", 4, 208312},
	{"PHRU", 4, 208313},
	{"PAKC", 4, 208314},
	{"OZYM", 4, 208315},
	{"OVJE", 4, 208316},
	{"NAYD", 4, 208317},
	{"NAKW", 4, 208318},
	{"LNMA", 4, 208319},
	{"LKOO", 4, 208320},
	{"LECW", 4, 208321},
	{"KOUC", 4, 208322},
	{"KMYD", 4, 208323},
	{"KKHU", 4, 208324},
	{"JOUA", 4, 208325},
	{"ISFC", 4, 208326},
	{"IKHC", 4, 208327},
	{"IKCH", 4, 208328},
	{"HMMW", 4, 208329},
	{"HAPC", 4, 208330},
	{"GMDE", 4, 208331},
	{"FOKA", 4, 208332},
	{"FIRW", 4, 208333},
	{"FGEI", 4, 208334},
	{"FCAO", 4, 208335},
	{"ESRW", 4, 208336},
	{"ELNG", 4, 208337},
	{"EFYO", 4, 208338},
	{"DXIS", 4, 208339},
	{"DMUZ", 4, 208340},
	{"DCAH", 4, 208341},
	{"DABK", 4, 208342},
	{"BODR", 4, 208343},
	{"AYUC", 4, 208344},
	{"AWKV", 4, 208345},
	{"INERRANT", 8, 208346},
	{"PESSAC", 6, 208347},
	{"CARLOCK", 7, 208348},
	{"BARGA", 5, 208349},
	{"BEREND", 6, 208350},
	{"RAVENHILL", 9, 208351},
	{"INFALLIBLY", 10, 208352},
	{"MINDHUNTERS", 11, 208353},
	{"LOGOWEAR", 8, 208354},
	{"OUNDATION", 9, 208355},
	{"VIOLIST", 7, 208356},
	{"OZGUR", 5, 208357},
	{"TRIGONAL", 8, 208358},
	{"IPOSTERS", 8, 208359},
	{"ILEUS", 5, 208360},
	{"LINNE", 5, 208361},
	{"ELSBERRY", 8, 208362},
	{"MYFILMZ", 7, 208363},
	{"DOGPLIE", 7, 208364},
	{"UNBIDDEN", 8, 208365},
	{"LPIC", 4, 208366},
	{"PAMIBE", 6, 208367},
	{"LEYVA", 5, 208368},
	{"FMW", 3, 208369},
	{"GERPOK", 6, 208370},
	{"FAMILIY", 7, 208371},
	{"PRABHAKARAN", 11, 208372},
	{"KURSER", 6, 208373},
	{"MAGNER", 6, 208374},
	{"VALENCY", 7, 208375},
	{"LOSSIEMOUTH", 11, 208376},
	{"BITC", 4, 208377},
	{"ZQB", 3, 208378},
	{"ZPV", 3, 208379},
	{"ZJG", 3, 208380},
	{"ZGV", 3, 208381},
	{"YQJ", 3, 208382},
	{"XGK", 3, 208383},
	{"QYK", 3, 208384},
	{"QVD", 3, 208385},
	{"QLK", 3, 208386},
	{"QKC", 3, 208387},
	{"QDG", 3, 208388},
	{"QCG", 3, 208389},
	{"PWQ", 3, 208390},
	{"MJQ", 3, 208391},
	{"LQY", 3, 208392},
	{"LJX", 3, 208393},
	{"JQR", 3, 208394},
	{"JQM", 3, 208395},
	{"GJX", 3, 208396},
	{"CQY", 3, 208397},
	{"BKZ", 3, 208398},
	{"BJZ", 3, 208399},
	{"MATERIALISTS", 12, 208400},
	{"CRAWLIES", 8, 208401},
	{"WAHHABISM", 9, 208402},
	{"USADA", 5, 208403},
	{"PRIMP", 5, 208404},
	{"MOVIEPOST", 9, 208405},
	{"ICONNECT", 8, 208406},
	{"CLEARASIL", 9, 208407},
	{"BAYOUS", 6, 208408},
	{"EUGENIC", 7, 208409},
	{"CHUK", 4, 208410},
	{"LICENZA", 7, 208411},
	{"HELWIG", 6, 208412},
	{"PREINCUBATION", 13, 208413},
	{"PRESBYTERIES", 12, 208414},
	{"PERNIK", 6, 208415},
	{"DIGICON", 7, 208416},
	{"ANVERS", 6, 208417},
	{"NONMEMBERSHIP", 13, 208418},
	{"LINDAUER", 8, 208419},
	{"RESELLERRATINGS", 15, 208420},
	{"OTOGI", 5, 208421},
	{"POSTLETHWAITE", 13, 208422},
	{"SLUGGERS", 8, 208423},
	{"RENEGOTIATING", 13, 208424},
	{"JUNTAS", 6, 208425},
	{"SERVERBEACH", 11, 208426},
	{"RESERACH", 8, 208427},
	{"RITORNO", 7, 208428},
	{"ACEY", 4, 208429},
	{"YNGHYD", 6, 208430},
	{"IPPM", 4, 208431},
	{"POLIFONICAS", 11, 208432},
	{"KREDITKARTE", 11, 208433},
	{"DRUBBING", 8, 208434},
	{"CALLOUSNESS", 11, 208435},
	{"TRATTA", 6, 208436},
	{"RAKER", 5, 208437},
	{"PREISER", 7, 208438},
	{"BATTAMBANG", 10, 208439},
	{"KURUMI", 6, 208440},
	{"GRIPTAPE", 8, 208441},
	{"GIPPER", 6, 208442},
	{"BERIO", 5, 208443},
	{"ENDECA", 6, 208444},
	{"CLNT", 4, 208445},
	{"ATACK", 5, 208446},
	{"PJUR", 4, 208447},
	{"TAILORMADE", 10, 208448},
	{"IUDS", 4, 208449},
	{"COWPENS", 7, 208450},
	{"BLOSS", 5, 208451},
	{"UNSELFISHLY", 11, 208452},
	{"ARCHWAYS", 8, 208453},
	{"FATWALLET", 9, 208454},
	{"APOLOGISING", 11, 208455},
	{"CORTELCO", 8, 208456},
	{"SKIPTOOLS", 9, 208457},
	{"BAIYOKE", 7, 208458},
	{"WARC", 4, 208459},
	{"SIMENON", 7, 208460},
	{"STREGA", 6, 208461},
	{"VISCOSITIES", 11, 208462},
	{"MFGQUOTE", 8, 208463},
	{"FLUOROSCOPIC", 12, 208464},
	{"KEECH", 5, 208465},
	{"BEJING", 6, 208466},
	{"BAKHTIAR", 8, 208467},
	{"EILERS", 6, 208468},
	{"ONTBIRDS", 8, 208469},
	{"TRANSPOSONS", 11, 208470},
	{"PHINE", 5, 208471},
	{"NONTRANSFERABLE", 15, 208472},
	{"SEKTION", 7, 208473},
	{"PENTECOSTALISM", 14, 208474},
	{"LEMUS", 5, 208475},
	{"LASKEY", 6, 208476},
	{"HUBBARDTON", 10, 208477},
	{"HARRING", 7, 208478},
	{"VALLA", 5, 208479},
	{"TOOKE", 5, 208480},
	{"PREFATORY", 9, 208481},
	{"PKER", 4, 208482},
	{"CPOE", 4, 208483},
	{"SPEEDHORN", 9, 208484},
	{"RELOCATEABLE", 12, 208485},
	{"LIION", 5, 208486},
	{"HERAKLES", 8, 208487},
	{"NICEBLOG", 8, 208488},
	{"SUETONIUS", 9, 208489},
	{"NCCAM", 5, 208490},
	{"EXTIRPATION", 11, 208491},
	{"SANGOMA", 7, 208492},
	{"GILDAS", 6, 208493},
	{"ZDRO", 4, 208494},
	{"YOXY", 4, 208495},
	{"YIFL", 4, 208496},
	{"XAMB", 4, 208497},
	{"VROV", 4, 208498},
	{"VOKA", 4, 208499},
	{"UTTD", 4, 208500},
	{"UOOU", 4, 208501},
	{"UOFU", 4, 208502},
	{"UIGO", 4, 208503},
	{"TJEM", 4, 208504},
	{"TGHZ", 4, 208505},
	{"RYLR", 4, 208506},
	{"RYCK", 4, 208507},
	{"RUTM", 4, 208508},
	{"RGMS", 4, 208509},
	{"RFOF", 4, 208510},
	{"PITV", 4, 208511},
	{"PGST", 4, 208512},
	{"PAYV", 4, 208513},
	{"OVRU", 4, 208514},
	{"OVEX", 4, 208515},
	{"OEUG", 4, 208516},
	{"OCEB", 4, 208517},
	{"OCDI", 4, 208518},
	{"NWAM", 4, 208519},
	{"NUEY", 4, 208520},
	{"NNWR", 4, 208521},
	{"NDDP", 4, 208522},
	{"MLEX", 4, 208523},
	{"MBSN", 4, 208524},
	{"LBAW", 4, 208525},
	{"LAXB", 4, 208526},
	{"KVAU", 4, 208527},
	{"KMYL", 4, 208528},
	{"KLYK", 4, 208529},
	{"HVOW", 4, 208530},
	{"HUYG", 4, 208531},
	{"HRIZ", 4, 208532},
	{"HELZ", 4, 208533},
	{"GYUR", 4, 208534},
	{"GOGL", 4, 208535},
	{"GMCL", 4, 208536},
	{"GEEJ", 4, 208537},
	{"GAOU", 4, 208538},
	{"FDWE", 4, 208539},
	{"FDRD", 4, 208540},
	{"EBFA", 4, 208541},
	{"DPIV", 4, 208542},
	{"DMSU", 4, 208543},
	{"DJIH", 4, 208544},
	{"DHPA", 4, 208545},
	{"DHAJ", 4, 208546},
	{"CDVE", 4, 208547},
	{"BYVL", 4, 208548},
	{"BULH", 4, 208549},
	{"BODL", 4, 208550},
	{"BACF", 4, 208551},
	{"AYHY", 4, 208552},
	{"AJME", 4, 208553},
	{"SCYLD", 5, 208554},
	{"PANTALOONS", 10, 208555},
	{"KILLINGLY", 9, 208556},
	{"CMGI", 4, 208557},
	{"PUNCTATA", 8, 208558},
	{"SIMMENTAL", 9, 208559},
	{"DIETERICH", 9, 208560},
	{"AINGE", 5, 208561},
	{"HELMING", 7, 208562},
	{"RESEVOIR", 8, 208563},
	{"PRELIT", 6, 208564},
	{"KARIMI", 6, 208565},
	{"HERRAMIENTA", 11, 208566},
	{"ELECTROMAGNETS", 14, 208567},
	{"DELMORE", 7, 208568},
	{"WARSONG", 7, 208569},
	{"TINDERSTICKS", 12, 208570},
	{"SPANA", 5, 208571},
	{"MOENCH", 6, 208572},
	{"COTULLA", 7, 208573},
	{"YYC", 3, 208574},
	{"KASD", 4, 208575},
	{"SHOUSE", 6, 208576},
	{"OPPURE", 6, 208577},
	{"ILDEFONSO", 9, 208578},
	{"SKADDEN", 7, 208579},
	{"PROCESSSES", 10, 208580},
	{"CULICIDAE", 9, 208581},
	{"RAWDATA", 7, 208582},
	{"PLOSIVE", 7, 208583},
	{"NOISELESSLY", 11, 208584},
	{"BOMBECK", 7, 208585},
	{"VORTAC", 6, 208586},
	{"CUFFE", 5, 208587},
	{"WOOLER", 6, 208588},
	{"OGMORE", 6, 208589},
	{"INFOGENIUS", 10, 208590},
	{"CENTRI", 6, 208591},
	{"BREEZED", 7, 208592},
	{"PASAY", 5, 208593},
	{"LONGHURST", 9, 208594},
	{"ENDSEC", 6, 208595},
	{"BECOMMING", 9, 208596},
	{"PLASM", 5, 208597},
	{"AMITAVA", 7, 208598},
	{"ROSTERING", 9, 208599},
	{"ANGELIDES", 9, 208600},
	{"PCRS", 4, 208601},
	{"DISPENSATIONALISM", 17, 208602},
	{"FURA", 4, 208603},
	{"INTERDOMAIN", 11, 208604},
	{"CHECOTAH", 8, 208605},
	{"BAROTROPIC", 10, 208606},
	{"AKERSHUS", 8, 208607},
	{"BURNUP", 6, 208608},
	{"FADEN", 5, 208609},
	{"PANAM", 5, 208610},
	{"JAMBS", 5, 208611},
	{"CROWSON", 7, 208612},
	{"LEYKWSIA", 8, 208613},
	{"GLOUCS", 6, 208614},
	{"AUKCJE", 6, 208615},
	{"QUALCUNO", 8, 208616},
	{"DCCA", 4, 208617},
	{"TOOLZ", 5, 208618},
	{"DIOMED", 6, 208619},
	{"CAWOOD", 6, 208620},
	{"KOTEL", 5, 208621},
	{"COCKFIGHTING", 12, 208622},
	{"TALICOR", 7, 208623},
	{"CRAVER", 6, 208624},
	{"ANGOULEME", 9, 208625},
	{"NOLES", 5, 208626},
	{"MOTTARET", 8, 208627},
	{"OPHTHALMOLOGICAL", 16, 208628},
	{"ZIEFERT", 7, 208629},
	{"INFECTIVES", 10, 208630},
	{"PRESENILIN", 10, 208631},
	{"BMAX", 4, 208632},
	{"SYREN", 5, 208633},
	{"STANCO", 6, 208634},
	{"KALUZA", 6, 208635},
	{"ARRAWARRA", 9, 208636},
	{"ANSWERPAGE", 10, 208637},
	{"POTENTLY", 8, 208638},
	{"APBA", 4, 208639},
	{"PAWPAW", 6, 208640},
	{"MARIJKE", 7, 208641},
	{"SYNESTHESIA", 11, 208642},
	{"ADVENTURESS", 11, 208643},
	{"BROCKWELL", 9, 208644},
	{"AVONEX", 6, 208645},
	{"FINKLE", 6, 208646},
	{"TAPPAHANNOCK", 12, 208647},
	{"INTERFIT", 8, 208648},
	{"CHFC", 4, 208649},
	{"PIXTURES", 8, 208650},
	{"NAWQA", 5, 208651},
	{"GEOGRAPHIE", 10, 208652},
	{"AUTOTEXT", 8, 208653},
	{"STOIES", 6, 208654},
	{"SLOBBERING", 10, 208655},
	{"STOLBERG", 8, 208656},
	{"MIMD", 4, 208657},
	{"CZESLAW", 7, 208658},
	{"LABELERS", 8, 208659},
	{"KYOUIKU", 7, 208660},
	{"TERMAN", 6, 208661},
	{"INVERGORDON", 11, 208662},
	{"THUMBNAILER", 11, 208663},
	{"OUER", 4, 208664},
	{"DRDA", 4, 208665},
	{"BEAUTYDENTAL", 12, 208666},
	{"SWEEDISH", 8, 208667},
	{"CHEESESUPPLY", 12, 208668},
	{"BBCANADA", 8, 208669},
	{"METALSMITH", 10, 208670},
	{"BLACKJACKS", 10, 208671},
	{"ADRENOCEPTORS", 13, 208672},
	{"TYROLIA", 7, 208673},
	{"LASCAUX", 7, 208674},
	{"REWORDING", 9, 208675},
	{"KNOBEL", 6, 208676},
	{"NEWBLOCK", 8, 208677},
	{"PNCVS", 5, 208678},
	{"NIKONOS", 7, 208679},
	{"STEAMFITTERS", 12, 208680},
	{"RABBITT", 7, 208681},
	{"DEFEO", 5, 208682},
	{"EDSALL", 6, 208683},
	{"ILLOGIC", 7, 208684},
	{"WCVB", 4, 208685},
	{"PANDAMONIUM", 11, 208686},
	{"QUINAPRIL", 9, 208687},
	{"CEGEP", 5, 208688},
	{"REITSMA", 7, 208689},
	{"ENGRG", 5, 208690},
	{"TURBOJET", 8, 208691},
	{"ELBOWING", 8, 208692},
	{"CHOOK", 5, 208693},
	{"BROILMASTER", 11, 208694},
	{"FLUCH", 5, 208695},
	{"KUMAGAI", 7, 208696},
	{"FINNING", 7, 208697},
	{"ZGIB", 4, 208698},
	{"YRDT", 4, 208699},
	{"YMLE", 4, 208700},
	{"YACY", 4, 208701},
	{"WCWA", 4, 208702},
	{"VBAN", 4, 208703},
	{"UZIA", 4, 208704},
	{"TSUU", 4, 208705},
	{"SRBA", 4, 208706},
	{"RUPY", 4, 208707},
	{"RBSN", 4, 208708},
	{"PUNF", 4, 208709},
	{"OOZL", 4, 208710},
	{"NXWA", 4, 208711},
	{"NGUH", 4, 208712},
	{"MSNC", 4, 208713},
	{"MLAV", 4, 208714},
	{"MIIK", 4, 208715},
	{"MAXK", 4, 208716},
	{"LAKM", 4, 208717},
	{"KMCA", 4, 208718},
	{"GAYV", 4, 208719},
	{"FOVA", 4, 208720},
	{"FCSP", 4, 208721},
	{"EYIV", 4, 208722},
	{"DROQ", 4, 208723},
	{"BFIS", 4, 208724},
	{"BBEE", 4, 208725},
	{"AWKL", 4, 208726},
	{"AUUN", 4, 208727},
	{"AUTF", 4, 208728},
	{"AKFU", 4, 208729},
	{"HIERBA", 6, 208730},
	{"BARLOWORLD", 10, 208731},
	{"POLITICIZE", 10, 208732},
	{"NAGDU", 5, 208733},
	{"INDIVIDUALISTS", 14, 208734},
	{"YARRAWONGA", 10, 208735},
	{"VEIGA", 5, 208736},
	{"INVESTORFLIX", 12, 208737},
	{"REEB", 4, 208738},
	{"LIQUIDMETAL", 11, 208739},
	{"JKB", 3, 208740},
	{"GAYWORLD", 8, 208741},
	{"XTASY", 5, 208742},
	{"MILONAKIS", 9, 208743},
	{"VDET", 4, 208744},
	{"MCATEE", 6, 208745},
	{"LANDSPEED", 9, 208746},
	{"GRIPEN", 6, 208747},
	{"CHICAGOTRIBUNE", 14, 208748},
	{"JOCKEYCHAMPION", 14, 208749},
	{"ARCHMAGE", 8, 208750},
	{"MORTGAE", 7, 208751},
	{"SIDDALL", 7, 208752},
	{"CROSLAND", 8, 208753},
	{"LAROCCA", 7, 208754},
	{"BENEDICK", 8, 208755},
	{"VEGS", 4, 208756},
	{"RETRANSMITTING", 14, 208757},
	{"LIEBERMANN", 10, 208758},
	{"JFF", 3, 208759},
	{"PHYTASE", 7, 208760},
	{"DESLORATADINE", 13, 208761},
	{"METROMIX", 8, 208762},
	{"LEADERSHIPS", 11, 208763},
	{"IASUS", 5, 208764},
	{"ALHAJI", 6, 208765},
	{"REDWINE", 7, 208766},
	{"SUGGERIMENTI", 12, 208767},
	{"MORCEY", 6, 208768},
	{"INFLATORS", 9, 208769},
	{"BUNDESWEHR", 10, 208770},
	{"BERNARDINI", 10, 208771},
	{"AFRICAIN", 8, 208772},
	{"RICHTEXT", 8, 208773},
	{"LEOPA", 5, 208774},
	{"MPVS", 4, 208775},
	{"MANDARA", 7, 208776},
	{"HYDRAPAK", 8, 208777},
	{"COMMODIOUS", 10, 208778},
	{"LANDSBOROUGH", 12, 208779},
	{"BRIODOL", 7, 208780},
	{"VRONSKY", 7, 208781},
	{"SKULLDUGGERY", 12, 208782},
	{"SCRN", 4, 208783},
	{"MAGZ", 4, 208784},
	{"CFECLIPSE", 9, 208785},
	{"STUMBLERS", 9, 208786},
	{"MICROCHANNEL", 12, 208787},
	{"GHOSTRIDER", 10, 208788},
	{"DISFIGURING", 11, 208789},
	{"SUBCLUSTID", 10, 208790},
	{"FAIRSTEIN", 9, 208791},
	{"ABBI", 4, 208792},
	{"MINGETTY", 8, 208793},
	{"BIDNESS", 7, 208794},
	{"PLEYRA", 6, 208795},
	{"SPELLCASTING", 12, 208796},
	{"PINCERS", 7, 208797},
	{"ADAMJ", 5, 208798},
	{"WBNS", 4, 208799},
	{"SPICOLI", 7, 208800},
	{"MALLAIG", 7, 208801},
	{"FRODA", 5, 208802},
	{"KLAATU", 6, 208803},
	{"BODI", 4, 208804},
	{"KLUGER", 6, 208805},
	{"INDUSTRIALISM", 13, 208806},
	{"BANDYOPADHYAY", 13, 208807},
	{"MEDIX", 5, 208808},
	{"MANDARINA", 9, 208809},
	{"BANDOW", 6, 208810},
	{"SWANSBORO", 9, 208811},
	{"SESBANIA", 8, 208812},
	{"SURVIVIN", 8, 208813},
	{"STRUBLE", 7, 208814},
	{"SGRAM", 5, 208815},
	{"SUOZZI", 6, 208816},
	{"GOULDSBORO", 10, 208817},
	{"FRESHENED", 9, 208818},
	{"GABB", 4, 208819},
	{"ACIDMAN", 7, 208820},
	{"PTION", 5, 208821},
	{"PALAKKAD", 8, 208822},
	{"LUDWICK", 7, 208823},
	{"VCHKPW", 6, 208824},
	{"NUCLEOBASE", 10, 208825},
	{"MONITEAU", 8, 208826},
	{"INHAMBANE", 9, 208827},
	{"CRDI", 4, 208828},
	{"MENTEN", 6, 208829},
	{"LAYO", 4, 208830},
	{"MCMILLIAN", 9, 208831},
	{"GRUNBERG", 8, 208832},
	{"UFP", 3, 208833},
	{"REVAN", 5, 208834},
	{"SANGA", 5, 208835},
	{"JARVI", 5, 208836},
	{"CFAR", 4, 208837},
	{"MARZANO", 7, 208838},
	{"MAROONDAH", 9, 208839},
	{"AUTOMATONS", 10, 208840},
	{"HULST", 5, 208841},
	{"CAPWAP", 6, 208842},
	{"ARTIFICER", 9, 208843},
	{"MIDLEVEL", 8, 208844},
	{"CHISUM", 6, 208845},
	{"BACKHANDED", 10, 208846},
	{"VGM", 3, 208847},
	{"STEPSIDE", 8, 208848},
	{"GUNTHORPE", 9, 208849},
	{"OPRN", 4, 208850},
	{"EMULSIFYING", 11, 208851},
	{"BISMOL", 6, 208852},
	{"DUFFIE", 6, 208853},
	{"WILSEY", 6, 208854},
	{"WEBTOP", 6, 208855},
	{"MOCHRIE", 7, 208856},
	{"SHOPPINGMALL", 12, 208857},
	{"TCHAD", 5, 208858},
	{"RACC", 4, 208859},
	{"MALMSTROM", 9, 208860},
	{"PARENTE", 7, 208861},
	{"NARAMATA", 8, 208862},
	{"KINDERS", 7, 208863},
	{"POPUL", 5, 208864},
	{"MKL", 3, 208865},
	{"RHOSTS", 6, 208866},
	{"RBB", 3, 208867},
	{"DREWRY", 6, 208868},
	{"QUIM", 4, 208869},
	{"PERIPHERIES", 11, 208870},
	{"PAUMA", 5, 208871},
	{"NIEUWSOVERZICHT", 15, 208872},
	{"OMEGATRON", 9, 208873},
	{"TOURERS", 7, 208874},
	{"APCALC", 6, 208875},
	{"AKAYEV", 6, 208876},
	{"MIEKE", 5, 208877},
	{"ANIMAE", 6, 208878},
	{"AHELP", 5, 208879},
	{"THEANINE", 8, 208880},
	{"NIGHTERS", 8, 208881},
	{"MTEF", 4, 208882},
	{"ASPERSIONS", 10, 208883},
	{"ANIMO", 5, 208884},
	{"DIGIMAGIC", 9, 208885},
	{"CALORIMETRIC", 12, 208886},
	{"WJR", 3, 208887},
	{"VOYCE", 5, 208888},
	{"PRZY", 4, 208889},
	{"ARTCC", 5, 208890},
	{"ZICK", 4, 208891},
	{"WOODING", 7, 208892},
	{"TYPEWRITING", 11, 208893},
	{"HERPETIC", 8, 208894},
	{"ECOLLEGE", 8, 208895},
	{"VUTECH", 6, 208896},
	{"TERRACING", 9, 208897},
	{"HAINAULT", 8, 208898},
	{"SPONSIBLE", 9, 208899},
	{"CROOME", 6, 208900},
	{"AUCTOR", 6, 208901},
	{"REFERAT", 7, 208902},
	{"KEYNAME", 7, 208903},
	{"LOPPERS", 7, 208904},
	{"DYNOMAX", 7, 208905},
	{"EVHEAD", 6, 208906},
	{"SUCHMASCHINEN", 13, 208907},
	{"CREATER", 7, 208908},
	{"SAJJAD", 6, 208909},
	{"OLYMPIADA", 9, 208910},
	{"ZDNE", 4, 208911},
	{"YPMM", 4, 208912},
	{"YNNG", 4, 208913},
	{"YKOD", 4, 208914},
	{"YJAD", 4, 208915},
	{"YDAB", 4, 208916},
	{"XMEE", 4, 208917},
	{"WSVO", 4, 208918},
	{"VVED", 4, 208919},
	{"VSEC", 4, 208920},
	{"UTKH", 4, 208921},
	{"ULEZ", 4, 208922},
	{"TZPL", 4, 208923},
	{"TSGM", 4, 208924},
	{"SCBO", 4, 208925},
	{"RPBS", 4, 208926},
	{"PLCW", 4, 208927},
	{"OICL", 4, 208928},
	{"OGUM", 4, 208929},
	{"ODHP", 4, 208930},
	{"NPPI", 4, 208931},
	{"MREU", 4, 208932},
	{"MKRE", 4, 208933},
	{"MJAZ", 4, 208934},
	{"MBUH", 4, 208935},
	{"LYKH", 4, 208936},
	{"LTDM", 4, 208937},
	{"LSJI", 4, 208938},
	{"LOVT", 4, 208939},
	{"LEZD", 4, 208940},
	{"KBUE", 4, 208941},
	{"IVFO", 4, 208942},
	{"GNBC", 4, 208943},
	{"GCOG", 4, 208944},
	{"GAHM", 4, 208945},
	{"FKUL", 4, 208946},
	{"ERVH", 4, 208947},
	{"EDLW", 4, 208948},
	{"DGEQ", 4, 208949},
	{"DCWO", 4, 208950},
	{"CODF", 4, 208951},
	{"BMWO", 4, 208952},
	{"BIAJ", 4, 208953},
	{"BAAP", 4, 208954},
	{"AEUG", 4, 208955},
	{"AERW", 4, 208956},
	{"ABHB", 4, 208957},
	{"WEAREVER", 8, 208958},
	{"INGEMAR", 7, 208959},
	{"RAGER", 5, 208960},
	{"NEEDLED", 7, 208961},
	{"LIPOPLASTY", 10, 208962},
	{"HUMALOG", 7, 208963},
	{"HEIKA", 5, 208964},
	{"ITJOBUNIVERSE", 13, 208965},
	{"ENTANGLING", 10, 208966},
	{"RASER", 5, 208967},
	{"WESTBERG", 8, 208968},
	{"VENKATA", 7, 208969},
	{"COUTU", 5, 208970},
	{"MINITEL", 7, 208971},
	{"PICTUTES", 8, 208972},
	{"FLB", 3, 208973},
	{"DOGBERT", 7, 208974},
	{"WNYW", 4, 208975},
	{"INVASIVES", 9, 208976},
	{"FRANCH", 6, 208977},
	{"RNRS", 4, 208978},
	{"SHEELER", 7, 208979},
	{"UNDCP", 5, 208980},
	{"ARENACROSS", 10, 208981},
	{"VINAYA", 6, 208982},
	{"SCOPETRONIX", 11, 208983},
	{"HEADWALL", 8, 208984},
	{"PLAISIO", 7, 208985},
	{"SINGL", 5, 208986},
	{"HELPFILE", 8, 208987},
	{"CULHAM", 6, 208988},
	{"MARGRAVE", 8, 208989},
	{"THROUG", 6, 208990},
	{"QUARRELLING", 11, 208991},
	{"SULINDAC", 8, 208992},
	{"CEFALU", 6, 208993},
	{"BULOW", 5, 208994},
	{"RIFABUTIN", 9, 208995},
	{"MORLAN", 6, 208996},
	{"KANYAKUMARI", 11, 208997},
	{"ADLANDPRO", 9, 208998},
	{"PMFIREWALL", 10, 208999},
	{"MENTZER", 7, 209000},
	{"GILBANE", 7, 209001},
	{"SYSTEMATIZED", 12, 209002},
	{"GUYSBOROUGH", 11, 209003},
	{"VONZIPPER", 9, 209004},
	{"CONURBATION", 11, 209005},
	{"PRGS", 4, 209006},
	{"DOUGLASSVILLE", 13, 209007},
	{"CRYTEK", 6, 209008},
	{"COMUS", 5, 209009},
	{"PLAINCLOTHES", 12, 209010},
	{"EARTHED", 7, 209011},
	{"BRIGHTLINGSEA", 13, 209012},
	{"BRACKENDALE", 11, 209013},
	{"VOCI", 4, 209014},
	{"KISTA", 5, 209015},
	{"MUSICOLOGICAL", 13, 209016},
	{"RRQ", 3, 209017},
	{"ARKEIA", 6, 209018},
	{"CUPHOLDER", 9, 209019},
	{"VENDERS", 7, 209020},
	{"PANAS", 5, 209021},
	{"CYTOL", 5, 209022},
	{"HITLERS", 7, 209023},
	{"PRISION", 7, 209024},
	{"KINGA", 5, 209025},
	{"EPIPHYTIC", 9, 209026},
	{"LONGBRIDGE", 10, 209027},
	{"PROVENZA", 8, 209028},
	{"VOICINGS", 8, 209029},
	{"COOTIES", 7, 209030},
	{"CLASSPATHX", 10, 209031},
	{"BURNINSENSATION", 15, 209032},
	{"ROELOFS", 7, 209033},
	{"POCTURES", 8, 209034},
	{"KOSTOVA", 7, 209035},
	{"SETSTATE", 8, 209036},
	{"KIRJA", 5, 209037},
	{"DJCE", 4, 209038},
	{"SUNTORY", 7, 209039},
	{"INFANTA", 7, 209040},
	{"HCFCS", 5, 209041},
	{"PUDU", 4, 209042},
	{"AMSEL", 5, 209043},
	{"SOFEMININ", 9, 209044},
	{"MCSWAIN", 7, 209045},
	{"SPARCBOOK", 9, 209046},
	{"KYNETON", 7, 209047},
	{"WALKE", 5, 209048},
	{"GIMLET", 6, 209049},
	{"MATIS", 5, 209050},
	{"ANEROS", 6, 209051},
	{"SKOLEM", 6, 209052},
	{"KOSMETIK", 8, 209053},
	{"NUMLOCK", 7, 209054},
	{"KNOWIN", 6, 209055},
	{"BRISTER", 7, 209056},
	{"TRANSCOM", 8, 209057},
	{"LOGISTIK", 8, 209058},
	{"EFRAIM", 6, 209059},
	{"FOWLERVILLE", 11, 209060},
	{"WKPA", 4, 209061},
	{"TCLX", 4, 209062},
	{"STILBAAI", 8, 209063},
	{"ANLAGE", 6, 209064},
	{"HARRIOTT", 8, 209065},
	{"DAMASCENE", 9, 209066},
	{"MAGNIFICA", 9, 209067},
	{"KLIM", 4, 209068},
	{"PINCER", 6, 209069},
	{"LINESRV", 7, 209070},
	{"JOBES", 5, 209071},
	{"TAKASHIMA", 9, 209072},
	{"MOUNTA", 6, 209073},
	{"FREEADS", 7, 209074},
	{"ABDUS", 5, 209075},
	{"ICELANDERS", 10, 209076},
	{"BLEAH", 5, 209077},
	{"SITEMAKER", 9, 209078},
	{"MDCK", 4, 209079},
	{"EARPIECES", 9, 209080},
	{"MONASTERIO", 10, 209081},
	{"LIGNUM", 6, 209082},
	{"ENAMELING", 9, 209083},
	{"FERRANTI", 8, 209084},
	{"PEROXYNITRITE", 13, 209085},
	{"MCLAURIN", 8, 209086},
	{"TRADIN", 6, 209087},
	{"LWIN", 4, 209088},
	{"GODINE", 6, 209089},
	{"BUGMAIL", 7, 209090},
	{"PSYCHOLINGUISTIC", 16, 209091},
	{"MUSETTE", 7, 209092},
	{"ZCOM", 4, 209093},
	{"LEFROY", 6, 209094},
	{"ARTBASE", 7, 209095},
	{"FENSE", 5, 209096},
	{"SUBCARD", 7, 209097},
	{"ZRAI", 4, 209098},
	{"ZMEN", 4, 209099},
	{"YROH", 4, 209100},
	{"XSLO", 4, 209101},
	{"XITL", 4, 209102},
	{"WRIB", 4, 209103},
	{"UNNF", 4, 209104},
	{"UKHK", 4, 209105},
	{"TODG", 4, 209106},
	{"SEUB", 4, 209107},
	{"PSUE", 4, 209108},
	{"OVDO", 4, 209109},
	{"OMMB", 4, 209110},
	{"OERB", 4, 209111},
	{"NXMA", 4, 209112},
	{"NPMC", 4, 209113},
	{"NNBY", 4, 209114},
	{"NMMI", 4, 209115},
	{"LPNA", 4, 209116},
	{"KCAD", 4, 209117},
	{"IJIL", 4, 209118},
	{"HUEC", 4, 209119},
	{"HMOZ", 4, 209120},
	{"GLUO", 4, 209121},
	{"GHHY", 4, 209122},
	{"EURJ", 4, 209123},
	{"DVDH", 4, 209124},
	{"DTVR", 4, 209125},
	{"DJIT", 4, 209126},
	{"DDRF", 4, 209127},
	{"DDHU", 4, 209128},
	{"CDIL", 4, 209129},
	{"AUBY", 4, 209130},
	{"ARKX", 4, 209131},
	{"AOLU", 4, 209132},
	{"SHUTTLECOCK", 11, 209133},
	{"WEIFANG", 7, 209134},
	{"SUBSTORM", 8, 209135},
	{"MCISAAC", 7, 209136},
	{"JONNA", 5, 209137},
	{"CAPITOLS", 8, 209138},
	{"TROTZDEM", 8, 209139},
	{"NESSUNA", 7, 209140},
	{"MATTHIESSEN", 11, 209141},
	{"BLACKENING", 10, 209142},
	{"WAITLISTED", 10, 209143},
	{"SEMANAS", 7, 209144},
	{"POSSIBLITIES", 12, 209145},
	{"FUCUS", 5, 209146},
	{"EXPROPRIATE", 11, 209147},
	{"MSRI", 4, 209148},
	{"GAVIA", 5, 209149},
	{"EMPANADAS", 9, 209150},
	{"APPENDCHILD", 11, 209151},
	{"WOOLMER", 7, 209152},
	{"PGPLOT", 6, 209153},
	{"ILLEGALSTATEEXCEPTION", 21, 209154},
	{"BIGGZ", 5, 209155},
	{"NEWSWEEKLIES", 12, 209156},
	{"ROGALAND", 8, 209157},
	{"PASSINGS", 8, 209158},
	{"ZUCCHINO", 8, 209159},
	{"POLYBROMINATED", 14, 209160},
	{"JUNTOS", 6, 209161},
	{"FIELDSET", 8, 209162},
	{"LJUNG", 5, 209163},
	{"HANAHAN", 7, 209164},
	{"KONZERTE", 8, 209165},
	{"FOTOCAMERE", 10, 209166},
	{"UMAMI", 5, 209167},
	{"CASTRES", 7, 209168},
	{"QMB", 3, 209169},
	{"DZSOFT", 6, 209170},
	{"ARTEMIDE", 8, 209171},
	{"SCHW", 4, 209172},
	{"EPIDERMOLYSIS", 13, 209173},
	{"NILL", 4, 209174},
	{"MXG", 3, 209175},
	{"MARKETINGSHERPA", 15, 209176},
	{"FRAGA", 5, 209177},
	{"BONNIER", 7, 209178},
	{"JEBUS", 5, 209179},
	{"DONELAN", 7, 209180},
	{"APPEARETH", 9, 209181},
	{"PARTAKES", 8, 209182},
	{"LINESMEN", 8, 209183},
	{"AXIMSITE", 8, 209184},
	{"CETACEA", 7, 209185},
	{"BUCKFASTLEIGH", 13, 209186},
	{"CHELLO", 6, 209187},
	{"MENNE", 5, 209188},
	{"BARIL", 5, 209189},
	{"HULT", 4, 209190},
	{"ALEJO", 5, 209191},
	{"IMPORTIN", 8, 209192},
	{"BWF", 3, 209193},
	{"LAMBE", 5, 209194},
	{"CONTABILIDADE", 13, 209195},
	{"BRAUNER", 7, 209196},
	{"REASSIGNING", 11, 209197},
	{"GODREJ", 6, 209198},
	{"DEWARS", 6, 209199},
	{"HERRIMAN", 8, 209200},
	{"GETCHAR", 7, 209201},
	{"PIRAN", 5, 209202},
	{"NNAMDI", 6, 209203},
	{"BOUCHON", 7, 209204},
	{"POTAMOGETON", 11, 209205},
	{"LOFRA", 5, 209206},
	{"BXYORG", 6, 209207},
	{"REGALED", 7, 209208},
	{"JULIES", 6, 209209},
	{"FOURXM", 6, 209210},
	{"COLLER", 6, 209211},
	{"MANCALA", 7, 209212},
	{"QUANDRY", 7, 209213},
	{"METROLOGICAL", 12, 209214},
	{"GUMMER", 6, 209215},
	{"VELOCIMETRY", 11, 209216},
	{"MAZZONE", 7, 209217},
	{"SUBSAMPLING", 11, 209218},
	{"HETCHY", 6, 209219},
	{"BULT", 4, 209220},
	{"WARIS", 5, 209221},
	{"KLEINSCHMIDT", 12, 209222},
	{"SINTHETIC", 9, 209223},
	{"TWEAKTOWN", 9, 209224},
	{"INGERSOL", 8, 209225},
	{"CRYPTONOMICON", 13, 209226},
	{"GUESTBOOKDE", 11, 209227},
	{"RETAKES", 7, 209228},
	{"KRYSTYNA", 8, 209229},
	{"RELATIVIST", 10, 209230},
	{"CAMSERV", 7, 209231},
	{"TOUREN", 6, 209232},
	{"KARLSON", 7, 209233},
	{"KAIL", 4, 209234},
	{"SIGAL", 5, 209235},
	{"MATCO", 5, 209236},
	{"ALGONQUIAN", 10, 209237},
	{"PRIMASOFT", 9, 209238},
	{"WASHIN", 6, 209239},
	{"RINGU", 5, 209240},
	{"LACTAMASES", 10, 209241},
	{"BOOMSTICK", 9, 209242},
	{"QUEENSLANDERS", 13, 209243},
	{"GADSBY", 6, 209244},
	{"TOMLAB", 6, 209245},
	{"KRISTAN", 7, 209246},
	{"DELVIN", 6, 209247},
	{"DANTZIG", 7, 209248},
	{"CAMARILLA", 9, 209249},
	{"AUDIOVISUALS", 12, 209250},
	{"GENTNER", 7, 209251},
	{"TAXPROF", 7, 209252},
	{"FILIUS", 6, 209253},
	{"DISPUTANTS", 10, 209254},
	{"METHACHOLINE", 12, 209255},
	{"LIBSNDFILE", 10, 209256},
	{"IDENTIX", 7, 209257},
	{"HAKODATE", 8, 209258},
	{"ALTTABIT", 8, 209259},
	{"MICHEYL", 7, 209260},
	{"RELEA", 5, 209261},
	{"IBIZ", 4, 209262},
	{"AMARGOSA", 8, 209263},
	{"ORDERID", 7, 209264},
	{"ELECTROTECHNOLOGY", 17, 209265},
	{"COMPACTA", 8, 209266},
	{"BOYSFIRSTTIME", 13, 209267},
	{"MITMENT", 7, 209268},
	{"YAOOH", 5, 209269},
	{"VITALIC", 7, 209270},
	{"REDISH", 6, 209271},
	{"NAWCC", 5, 209272},
	{"MIYAGAWA", 8, 209273},
	{"IFLAG", 5, 209274},
	{"MILLPORT", 8, 209275},
	{"DHMH", 4, 209276},
	{"SWPP", 4, 209277},
	{"YOUVILLE", 8, 209278},
	{"ZMET", 4, 209279},
	{"ZKYA", 4, 209280},
	{"YXIN", 4, 209281},
	{"YNSP", 4, 209282},
	{"YAKW", 4, 209283},
	{"UGEQ", 4, 209284},
	{"TZMI", 4, 209285},
	{"TYHY", 4, 209286},
	{"TLOK", 4, 209287},
	{"TDYS", 4, 209288},
	{"SGWA", 4, 209289},
	{"RYAJ", 4, 209290},
	{"RSYU", 4, 209291},
	{"RPIU", 4, 209292},
	{"RPGE", 4, 209293},
	{"RLIH", 4, 209294},
	{"RIJI", 4, 209295},
	{"PYEL", 4, 209296},
	{"PSPG", 4, 209297},
	{"OYCI", 4, 209298},
	{"OMRW", 4, 209299},
	{"OJOG", 4, 209300},
	{"NVOD", 4, 209301},
	{"NIRC", 4, 209302},
	{"NABK", 4, 209303},
	{"MREW", 4, 209304},
	{"LUCU", 4, 209305},
	{"LKGO", 4, 209306},
	{"KAMT", 4, 209307},
	{"IUBA", 4, 209308},
	{"ISYL", 4, 209309},
	{"IJAG", 4, 209310},
	{"HMUK", 4, 209311},
	{"HLCD", 4, 209312},
	{"GTDA", 4, 209313},
	{"GAEP", 4, 209314},
	{"FIDT", 4, 209315},
	{"FBST", 4, 209316},
	{"FALH", 4, 209317},
	{"EVCR", 4, 209318},
	{"ERZS", 4, 209319},
	{"EOLG", 4, 209320},
	{"ENZR", 4, 209321},
	{"DYNU", 4, 209322},
	{"DPWO", 4, 209323},
	{"DFAA", 4, 209324},
	{"DECV", 4, 209325},
	{"CZYS", 4, 209326},
	{"CSIX", 4, 209327},
	{"COYC", 4, 209328},
	{"CKOH", 4, 209329},
	{"BSYE", 4, 209330},
	{"AGPE", 4, 209331},
	{"SEALDRI", 7, 209332},
	{"SANCERRE", 8, 209333},
	{"MALVO", 5, 209334},
	{"SLAMMERS", 8, 209335},
	{"DERIVATIZATION", 14, 209336},
	{"WHEAL", 5, 209337},
	{"FIDOGATE", 8, 209338},
	{"VIGILANZA", 9, 209339},
	{"TUTWILER", 8, 209340},
	{"KINGSCOTE", 9, 209341},
	{"CONNAUGHTON", 11, 209342},
	{"RNWL", 4, 209343},
	{"MCVICAR", 7, 209344},
	{"IMIDACLOPRID", 12, 209345},
	{"BARTOLINI", 9, 209346},
	{"FREUNDLICH", 10, 209347},
	{"PORO", 4, 209348},
	{"AFFITTI", 7, 209349},
	{"BURCHAM", 7, 209350},
	{"SOAVE", 5, 209351},
	{"REPARTITION", 11, 209352},
	{"JOSTEIN", 7, 209353},
	{"BELDAR", 6, 209354},
	{"POLYCOTTON", 10, 209355},
	{"KFX", 3, 209356},
	{"HANDSTANDS", 10, 209357},
	{"CCCGC", 5, 209358},
	{"EPPSTEIN", 8, 209359},
	{"COMPARTMENTAL", 13, 209360},
	{"SOZIALE", 7, 209361},
	{"KHATTAB", 7, 209362},
	{"STAPEDECTOMY", 12, 209363},
	{"RIESZ", 5, 209364},
	{"ODDBALLS", 8, 209365},
	{"JUNKS", 5, 209366},
	{"HALMRK", 6, 209367},
	{"FOREMSKI", 8, 209368},
	{"INGENUOUS", 9, 209369},
	{"IMPE", 4, 209370},
	{"HAYSTACKS", 9, 209371},
	{"SKYKOMISH", 9, 209372},
	{"BSPLAYER", 8, 209373},
	{"CUONG", 5, 209374},
	{"LACC", 4, 209375},
	{"TGSTORES", 8, 209376},
	{"SMARTPAGES", 10, 209377},
	{"KATAOKA", 7, 209378},
	{"GENOMENET", 9, 209379},
	{"CARPEL", 6, 209380},
	{"ZAKHAROV", 8, 209381},
	{"NALICK", 6, 209382},
	{"GUDGIN", 6, 209383},
	{"FLOUNDERED", 10, 209384},
	{"ARSENITE", 8, 209385},
	{"SYNDICALISM", 11, 209386},
	{"SBSTTA", 6, 209387},
	{"MARKETCLUB", 10, 209388},
	{"KEELED", 6, 209389},
	{"BLAYNEY", 7, 209390},
	{"VELVEETA", 8, 209391},
	{"TRADESKILLS", 11, 209392},
	{"STAMPEDERS", 10, 209393},
	{"CASADY", 6, 209394},
	{"IRLO", 4, 209395},
	{"GATHERUM", 8, 209396},
	{"ENTRER", 6, 209397},
	{"COALESCENT", 10, 209398},
	{"MURAYAMA", 8, 209399},
	{"HEADIN", 6, 209400},
	{"CHAPLEAU", 8, 209401},
	{"SISTAH", 6, 209402},
	{"DEREGISTER", 10, 209403},
	{"DANEMAN", 7, 209404},
	{"UALS", 4, 209405},
	{"WAYAN", 5, 209406},
	{"TATUS", 5, 209407},
	{"NIWAS", 5, 209408},
	{"BRANNEN", 7, 209409},
	{"JEERED", 6, 209410},
	{"STRABO", 6, 209411},
	{"REKENING", 8, 209412},
	{"OLLERTON", 8, 209413},
	{"TCAM", 4, 209414},
	{"SAYALONGA", 9, 209415},
	{"NORDHEIM", 8, 209416},
	{"BEGGIN", 6, 209417},
	{"WERKT", 5, 209418},
	{"BADM", 4, 209419},
	{"APPENZELL", 9, 209420},
	{"LEVELLER", 8, 209421},
	{"TAVOLA", 6, 209422},
	{"CUBIX", 5, 209423},
	{"ASSIGNATION", 11, 209424},
	{"WESTENRA", 8, 209425},
	{"MINUTI", 6, 209426},
	{"JAVATM", 6, 209427},
	{"ESSENTIALISM", 12, 209428},
	{"GANGING", 7, 209429},
	{"APPIAH", 6, 209430},
	{"EDVENTURES", 10, 209431},
	{"BARTIMAEUS", 10, 209432},
	{"TYPOPHILE", 9, 209433},
	{"PELLENTESQUE", 12, 209434},
	{"KLEIDER", 7, 209435},
	{"VAVIN", 5, 209436},
	{"SANDOW", 6, 209437},
	{"GASTROINTEST", 12, 209438},
	{"SUSTEREN", 8, 209439},
	{"TRAILHEADS", 10, 209440},
	{"CONECTOR", 8, 209441},
	{"MATTAPAN", 8, 209442},
	{"EPPI", 4, 209443},
	{"EFFICENT", 8, 209444},
	{"BACKCOLOR", 9, 209445},
	{"SMUTTY", 6, 209446},
	{"MISMOS", 6, 209447},
	{"NONPLUSSED", 10, 209448},
	{"PHILE", 5, 209449},
	{"MBEAT", 5, 209450},
	{"WOUD", 4, 209451},
	{"TESSELLATIONS", 13, 209452},
	{"ALTIUM", 6, 209453},
	{"AIRTOUCH", 8, 209454},
	{"VOLA", 4, 209455},
	{"THERMOFORMED", 12, 209456},
	{"DAYTRIP", 7, 209457},
	{"ZODIACS", 7, 209458},
	{"MIKIO", 5, 209459},
	{"ETOPPS", 6, 209460},
	{"BRAHMAPUTRA", 11, 209461},
	{"SHEETED", 7, 209462},
	{"MIRFIELD", 8, 209463},
	{"BLINUX", 6, 209464},
	{"MCIVOR", 6, 209465},
	{"INFOTRIEVE", 10, 209466},
	{"GUDGEON", 7, 209467},
	{"LEIBOVITZ", 9, 209468},
	{"YALI", 4, 209469},
	{"WEBDISPLAY", 10, 209470},
	{"FOARD", 5, 209471},
	{"BEEFSTEAK", 9, 209472},
	{"PINCODE", 7, 209473},
	{"MRSC", 4, 209474},
	{"GAMEX", 5, 209475},
	{"ENTATION", 8, 209476},
	{"DRWEB", 5, 209477},
	{"CPES", 4, 209478},
	{"PRETTYMAN", 9, 209479},
	{"PWNS", 4, 209480},
	{"FOXED", 5, 209481},
	{"VENTSPILS", 9, 209482},
	{"OLOR", 4, 209483},
	{"COCKLEBUR", 9, 209484},
	{"ZAZI", 4, 209485},
	{"ZAVO", 4, 209486},
	{"YPLI", 4, 209487},
	{"YEPS", 4, 209488},
	{"WNTV", 4, 209489},
	{"UTKY", 4, 209490},
	{"USAQ", 4, 209491},
	{"UMAJ", 4, 209492},
	{"UITK", 4, 209493},
	{"TZSU", 4, 209494},
	{"TVSR", 4, 209495},
	{"TLCO", 4, 209496},
	{"SWYA", 4, 209497},
	{"SPFR", 4, 209498},
	{"SOWL", 4, 209499},
	{"SMUA", 4, 209500},
	{"SCFI", 4, 209501},
	{"RSOJ", 4, 209502},
	{"QBIN", 4, 209503},
	{"PYFE", 4, 209504},
	{"PSKO", 4, 209505},
	{"PAMD", 4, 209506},
	{"PAAF", 4, 209507},
	{"OYGU", 4, 209508},
	{"OKSQ", 4, 209509},
	{"NMPP", 4, 209510},
	{"MPYL", 4, 209511},
	{"MPFL", 4, 209512},
	{"MAQA", 4, 209513},
	{"LCDA", 4, 209514},
	{"KZIN", 4, 209515},
	{"KGUE", 4, 209516},
	{"JRHE", 4, 209517},
	{"JPRE", 4, 209518},
	{"IPEY", 4, 209519},
	{"IGEK", 4, 209520},
	{"HMAB", 4, 209521},
	{"HILV", 4, 209522},
	{"GZIM", 4, 209523},
	{"GSEF", 4, 209524},
	{"FYAF", 4, 209525},
	{"EZJR", 4, 209526},
	{"ELOX", 4, 209527},
	{"EFEY", 4, 209528},
	{"DRMB", 4, 209529},
	{"DJAH", 4, 209530},
	{"DEIK", 4, 209531},
	{"DACB", 4, 209532},
	{"BTAF", 4, 209533},
	{"BLAV", 4, 209534},
	{"RAVL", 4, 209535},
	{"VMG", 3, 209536},
	{"VIDMAR", 6, 209537},
	{"KERATOPLASTY", 12, 209538},
	{"BOTELHO", 7, 209539},
	{"RACEWEAR", 8, 209540},
	{"LINUXHQ", 7, 209541},
	{"TRIPLOID", 8, 209542},
	{"PAMIR", 5, 209543},
	{"FALSIFIABLE", 11, 209544},
	{"TRANSFORMATOR", 13, 209545},
	{"SALMINEN", 8, 209546},
	{"WMG", 3, 209547},
	{"WOMANIZER", 9, 209548},
	{"SYNAPTOSOMES", 12, 209549},
	{"MCCALLS", 7, 209550},
	{"BACKBENCHERS", 12, 209551},
	{"FILAPTOP", 8, 209552},
	{"KOTOBUKI", 8, 209553},
	{"TRANSALTA", 9, 209554},
	{"GLASSBLOWING", 12, 209555},
	{"VECTORED", 8, 209556},
	{"NETZWERKE", 9, 209557},
	{"UNDERVALUE", 10, 209558},
	{"SEKTOR", 6, 209559},
	{"PAYMENTSCREDIT", 14, 209560},
	{"MOPE", 4, 209561},
	{"BAMIYAN", 7, 209562},
	{"WOLE", 4, 209563},
	{"TROLS", 5, 209564},
	{"AMERIKAN", 8, 209565},
	{"SCRIS", 5, 209566},
	{"BASTOS", 6, 209567},
	{"VILIFY", 6, 209568},
	{"PICKABOOOK", 10, 209569},
	{"PENSAR", 6, 209570},
	{"INFORMACE", 9, 209571},
	{"GROUPERS", 8, 209572},
	{"CAREFIRST", 9, 209573},
	{"SHOPSITE", 8, 209574},
	{"HEARTMATH", 9, 209575},
	{"SELEX", 5, 209576},
	{"REDEN", 5, 209577},
	{"PNEUMATICALLY", 13, 209578},
	{"PHYTOTHERAPY", 12, 209579},
	{"DEOXYGLUCOSE", 12, 209580},
	{"EXPLOITER", 9, 209581},
	{"ZACKARY", 7, 209582},
	{"SERVICEMEMBER", 13, 209583},
	{"ISIKOFF", 7, 209584},
	{"FLINK", 5, 209585},
	{"ORIENTABLE", 10, 209586},
	{"TERAX", 5, 209587},
	{"STATD", 5, 209588},
	{"OFFSETOF", 8, 209589},
	{"LPQ", 3, 209590},
	{"GYROSCOPIC", 10, 209591},
	{"PARTICULIERS", 12, 209592},
	{"VIZAG", 5, 209593},
	{"STRECKER", 8, 209594},
	{"GUNTON", 6, 209595},
	{"SILKTIDE", 8, 209596},
	{"CHARLO", 6, 209597},
	{"LABBE", 5, 209598},
	{"FISCHBACH", 9, 209599},
	{"BOCCHINI", 8, 209600},
	{"WENK", 4, 209601},
	{"ORATORICAL", 10, 209602},
	{"JSOU", 4, 209603},
	{"FLUDARABINE", 11, 209604},
	{"JOSSELIN", 8, 209605},
	{"ELCOM", 5, 209606},
	{"STUTTERS", 8, 209607},
	{"AENEAN", 6, 209608},
	{"REFERENCER", 10, 209609},
	{"NEVRON", 6, 209610},
	{"REINACKER", 9, 209611},
	{"MACULATUS", 9, 209612},
	{"SITEWORK", 8, 209613},
	{"CHRONOMETERS", 12, 209614},
	{"PUSTULES", 8, 209615},
	{"MASHHAD", 7, 209616},
	{"CSXT", 4, 209617},
	{"LULLY", 5, 209618},
	{"KIDSPIRATION", 12, 209619},
	{"ACUARIO", 7, 209620},
	{"TATTNALL", 8, 209621},
	{"OCWEN", 5, 209622},
	{"IDDON", 5, 209623},
	{"PREDISPOSITIONS", 15, 209624},
	{"HAYDAR", 6, 209625},
	{"SAFELITE", 8, 209626},
	{"INFOSECURITY", 12, 209627},
	{"CAGDS", 5, 209628},
	{"USUALL", 6, 209629},
	{"SAJID", 5, 209630},
	{"LAUNDERETTE", 11, 209631},
	{"DAINES", 6, 209632},
	{"CSIKSZENTMIHALYI", 16, 209633},
	{"PILAT", 5, 209634},
	{"EURACTIV", 8, 209635},
	{"SCHNUPPERZUGANG", 15, 209636},
	{"PRATS", 5, 209637},
	{"MAXS", 4, 209638},
	{"EZPROXY", 7, 209639},
	{"AIRTICKET", 9, 209640},
	{"TTORNEY", 7, 209641},
	{"METACHARACTERS", 14, 209642},
	{"HPFS", 4, 209643},
	{"ARKY", 4, 209644},
	{"TIDB", 4, 209645},
	{"PASWORD", 7, 209646},
	{"HANSELL", 7, 209647},
	{"FIBRILLARY", 10, 209648},
	{"RAXXESS", 7, 209649},
	{"JOBSPART", 8, 209650},
	{"ISENABLED", 9, 209651},
	{"OLDCASTLE", 9, 209652},
	{"INTERBIKE", 9, 209653},
	{"HERTA", 5, 209654},
	{"AMPRO", 5, 209655},
	{"WHATEVA", 7, 209656},
	{"LAYBY", 5, 209657},
	{"SACERDOTAL", 10, 209658},
	{"IMPALE", 6, 209659},
	{"DEPTO", 5, 209660},
	{"BAYING", 6, 209661},
	{"GREIDER", 7, 209662},
	{"FREDHOLM", 8, 209663},
	{"FEMENINO", 8, 209664},
	{"INCUBATIONS", 11, 209665},
	{"ETOOLS", 6, 209666},
	{"PACCAR", 6, 209667},
	{"BALLBUSTING", 11, 209668},
	{"GINGRAS", 7, 209669},
	{"DEPAKENE", 8, 209670},
	{"ARROWTOWN", 9, 209671},
	{"TJADER", 6, 209672},
	{"ZZSO", 4, 209673},
	{"ZREN", 4, 209674},
	{"ZREG", 4, 209675},
	{"ZPAC", 4, 209676},
	{"ZHKO", 4, 209677},
	{"ZFUS", 4, 209678},
	{"XROO", 4, 209679},
	{"XARO", 4, 209680},
	{"VMAK", 4, 209681},
	{"VIIP", 4, 209682},
	{"UGAK", 4, 209683},
	{"UCOC", 4, 209684},
	{"TUCU", 4, 209685},
	{"TFOW", 4, 209686},
	{"SUMH", 4, 209687},
	{"SULB", 4, 209688},
	{"RLSY", 4, 209689},
	{"PEZB", 4, 209690},
	{"OZAF", 4, 209691},
	{"OVFI", 4, 209692},
	{"OIDX", 4, 209693},
	{"OFUH", 4, 209694},
	{"NUFR", 4, 209695},
	{"NPMW", 4, 209696},
	{"NPAX", 4, 209697},
	{"NKEG", 4, 209698},
	{"MNAK", 4, 209699},
	{"MIEX", 4, 209700},
	{"LEIJ", 4, 209701},
	{"LACF", 4, 209702},
	{"KMCD", 4, 209703},
	{"JSKI", 4, 209704},
	{"JRDI", 4, 209705},
	{"JIEF", 4, 209706},
	{"INUF", 4, 209707},
	{"GAOV", 4, 209708},
	{"FIMT", 4, 209709},
	{"FGIO", 4, 209710},
	{"EYUE", 4, 209711},
	{"ETDY", 4, 209712},
	{"ERWT", 4, 209713},
	{"ENXU", 4, 209714},
	{"DSUH", 4, 209715},
	{"DPSO", 4, 209716},
	{"DPAE", 4, 209717},
	{"DMIH", 4, 209718},
	{"BPHI", 4, 209719},
	{"BNCA", 4, 209720},
	{"BBCE", 4, 209721},
	{"AKBI", 4, 209722},
	{"UNOMAT", 6, 209723},
	{"LEARNABILITY", 12, 209724},
	{"REDBOX", 6, 209725},
	{"BARKERVILLE", 11, 209726},
	{"WHASSUP", 7, 209727},
	{"DEFINATLEY", 10, 209728},
	{"MINICOMPUTERS", 13, 209729},
	{"LATINUS", 7, 209730},
	{"FERROL", 6, 209731},
	{"TROUTVILLE", 10, 209732},
	{"RESCORLA", 8, 209733},
	{"HIGHPASS", 8, 209734},
	{"SUBMERGING", 10, 209735},
	{"HIJINX", 6, 209736},
	{"SOCIATION", 9, 209737},
	{"ELLENBURG", 9, 209738},
	{"BORTON", 6, 209739},
	{"ROENTGENOL", 10, 209740},
	{"PMQ", 3, 209741},
	{"KETERA", 6, 209742},
	{"DARRA", 5, 209743},
	{"DYNAGROOVE", 10, 209744},
	{"LIDGE", 5, 209745},
	{"GAMBRELL", 8, 209746},
	{"FUNKHOUSER", 10, 209747},
	{"ROSENSTOCK", 10, 209748},
	{"REBUILDABLE", 11, 209749},
	{"LUAS", 4, 209750},
	{"LAYDOWN", 7, 209751},
	{"WHODUNNIT", 9, 209752},
	{"QUIVIRA", 7, 209753},
	{"DIKKE", 5, 209754},
	{"TERAMO", 6, 209755},
	{"PARASHAT", 8, 209756},
	{"DORSUM", 6, 209757},
	{"CZERNY", 6, 209758},
	{"PHOOL", 5, 209759},
	{"OLIGODEOXYRIBONUCLEOTIDES", 25, 209760},
	{"HAMRA", 5, 209761},
	{"PAWLEY", 6, 209762},
	{"XCONFIG", 7, 209763},
	{"GOURLAY", 7, 209764},
	{"ENDGROUP", 8, 209765},
	{"TERES", 5, 209766},
	{"SUPERCHARGING", 13, 209767},
	{"MWYAF", 5, 209768},
	{"LLAMADA", 7, 209769},
	{"DIEREN", 6, 209770},
	{"TRITONE", 7, 209771},
	{"MALINDI", 7, 209772},
	{"ADAMEC", 6, 209773},
	{"ONTOGENETIC", 11, 209774},
	{"CROSSHATCH", 10, 209775},
	{"FIEF", 4, 209776},
	{"BILINGUE", 8, 209777},
	{"KISHI", 5, 209778},
	{"ASTRONOTUS", 10, 209779},
	{"PAYIN", 5, 209780},
	{"DINARDO", 7, 209781},
	{"CRONJOB", 7, 209782},
	{"SITEGROUND", 10, 209783},
	{"PRECIPITABLE", 12, 209784},
	{"FIREKING", 8, 209785},
	{"CARMEX", 6, 209786},
	{"VOPR", 4, 209787},
	{"HEVER", 5, 209788},
	{"DONIMAGE", 8, 209789},
	{"RAYMORE", 7, 209790},
	{"ARCHITECTONIC", 13, 209791},
	{"LITZ", 4, 209792},
	{"GOPINATH", 8, 209793},
	{"APPY", 4, 209794},
	{"HOOGLE", 6, 209795},
	{"BELLHORN", 8, 209796},
	{"ARMHOLE", 7, 209797},
	{"POATE", 5, 209798},
	{"WTTC", 4, 209799},
	{"SUPERCOOLED", 11, 209800},
	{"ICELAKE", 7, 209801},
	{"SIPEX", 5, 209802},
	{"TRPT", 4, 209803},
	{"ARCHITECH", 9, 209804},
	{"VAISHNAVA", 9, 209805},
	{"ECONOMICINVESTOR", 16, 209806},
	{"DISPARAGED", 10, 209807},
	{"BARTOS", 6, 209808},
	{"GRSECURITY", 10, 209809},
	{"DLEG", 4, 209810},
	{"OVERGAARD", 9, 209811},
	{"RAMASUBRAMANIAN", 15, 209812},
	{"MMCMOBILE", 9, 209813},
	{"STARDIC", 7, 209814},
	{"SIXTUS", 6, 209815},
	{"CRIMI", 5, 209816},
	{"HODDLE", 6, 209817},
	{"LEVERINGSTID", 12, 209818},
	{"HYDROBIOLOGIA", 13, 209819},
	{"REPENTS", 7, 209820},
	{"LEREN", 5, 209821},
	{"SOFTRAX", 7, 209822},
	{"PEAKWARE", 8, 209823},
	{"CLEVERER", 8, 209824},
	{"SYNCHRONISING", 13, 209825},
	{"WENDELIN", 8, 209826},
	{"SIRIO", 5, 209827},
	{"ROTORA", 6, 209828},
	{"REBASE", 6, 209829},
	{"PEGGIE", 6, 209830},
	{"CXRDS", 5, 209831},
	{"SCHEIDEN", 8, 209832},
	{"REMORA", 6, 209833},
	{"COURBET", 7, 209834},
	{"FULLFILE", 8, 209835},
	{"DENIGRATED", 10, 209836},
	{"BARBERINI", 9, 209837},
	{"ZIMBALIST", 9, 209838},
	{"RESPECTIVOS", 11, 209839},
	{"PREWRITING", 10, 209840},
	{"DALBELLO", 8, 209841},
	{"CHEESEY", 7, 209842},
	{"CACIB", 5, 209843},
	{"ALBENIZ", 7, 209844},
	{"SILICONIX", 9, 209845},
	{"OPISY", 5, 209846},
	{"JOURNALLING", 11, 209847},
	{"CDFA", 4, 209848},
	{"BOULT", 5, 209849},
	{"RECOMMANDATION", 14, 209850},
	{"PROSEMINAR", 10, 209851},
	{"DISEMBARKATION", 14, 209852},
	{"BOMBYX", 6, 209853},
	{"IKEBUKURO", 9, 209854},
	{"VIVEKA", 6, 209855},
	{"TAINTY", 6, 209856},
	{"HARTON", 6, 209857},
	{"YICHANG", 7, 209858},
	{"MCCARVER", 8, 209859},
	{"GEOSYNTHETICS", 13, 209860},
	{"FAHRRAD", 7, 209861},
	{"RIEKE", 5, 209862},
	{"TECHVIBES", 9, 209863},
	{"ZAMIR", 5, 209864},
	{"PROLAPSED", 9, 209865},
	{"PHOTOCONDUCTOR", 14, 209866},
	{"FORKHEAD", 8, 209867},
	{"SCIENT", 6, 209868},
	{"DISPROVING", 10, 209869},
	{"EMPICS", 6, 209870},
	{"AWRA", 4, 209871},
	{"NGAM", 4, 209872},
	{"HUERFANO", 8, 209873},
	{"OLINGER", 7, 209874},
	{"CAMPESINO", 9, 209875},
	{"SUPRIS", 6, 209876},
	{"ACRYLATES", 9, 209877},
	{"OHRP", 4, 209878},
	{"CRMS", 4, 209879},
	{"STATEGY", 7, 209880},
	{"PUZZLERS", 8, 209881},
	{"NORBY", 5, 209882},
	{"EMBAYMENTS", 10, 209883},
	{"DEMOUNTABLE", 11, 209884},
	{"XRANGE", 6, 209885},
	{"ZKHA", 4, 209886},
	{"YUPM", 4, 209887},
	{"YSPS", 4, 209888},
	{"YPIV", 4, 209889},
	{"XMIC", 4, 209890},
	{"VVIS", 4, 209891},
	{"UORP", 4, 209892},
	{"UKDO", 4, 209893},
	{"TMRI", 4, 209894},
	{"TCIC", 4, 209895},
	{"SGCO", 4, 209896},
	{"SDYK", 4, 209897},
	{"RTUZ", 4, 209898},
	{"RPDO", 4, 209899},
	{"PINZ", 4, 209900},
	{"PDTH", 4, 209901},
	{"OZIP", 4, 209902},
	{"OPRB", 4, 209903},
	{"OHLW", 4, 209904},
	{"MPGU", 4, 209905},
	{"LYOX", 4, 209906},
	{"LOXF", 4, 209907},
	{"KIRL", 4, 209908},
	{"JUNW", 4, 209909},
	{"JESP", 4, 209910},
	{"JCRE", 4, 209911},
	{"IRPC", 4, 209912},
	{"HULG", 4, 209913},
	{"HKUN", 4, 209914},
	{"GVOR", 4, 209915},
	{"GSIP", 4, 209916},
	{"GPLI", 4, 209917},
	{"FUNJ", 4, 209918},
	{"FOXV", 4, 209919},
	{"FLLI", 4, 209920},
	{"ESDL", 4, 209921},
	{"ECRD", 4, 209922},
	{"DWOE", 4, 209923},
	{"DSJI", 4, 209924},
	{"DKIW", 4, 209925},
	{"DAHP", 4, 209926},
	{"CTLU", 4, 209927},
	{"COUB", 4, 209928},
	{"CAUR", 4, 209929},
	{"BBAF", 4, 209930},
	{"AYEY", 4, 209931},
	{"AKUJ", 4, 209932},
	{"AFFV", 4, 209933},
	{"AFBL", 4, 209934},
	{"PEDALLING", 9, 209935},
	{"TERRAVITA", 9, 209936},
	{"PETROPAVLOVSK", 13, 209937},
	{"ATTUNE", 6, 209938},
	{"SCHULICH", 8, 209939},
	{"NIHAL", 5, 209940},
	{"FARMACY", 7, 209941},
	{"NUJAZZ", 6, 209942},
	{"SCOREKEEPER", 11, 209943},
	{"ROSTROPOVICH", 12, 209944},
	{"BROOMBALL", 9, 209945},
	{"VESTEL", 6, 209946},
	{"NIMMER", 6, 209947},
	{"JAMESPORT", 9, 209948},
	{"GUNARATNE", 9, 209949},
	{"SUNDAZED", 8, 209950},
	{"METHYLASE", 9, 209951},
	{"KAPPAN", 6, 209952},
	{"WSDM", 4, 209953},
	{"PRWI", 4, 209954},
	{"NIEDERMAYER", 11, 209955},
	{"HIBACHI", 7, 209956},
	{"BLAUE", 5, 209957},
	{"IFREMER", 7, 209958},
	{"ASSOCIATIO", 10, 209959},
	{"SITIONS", 7, 209960},
	{"RECTED", 6, 209961},
	{"PLASMATICS", 10, 209962},
	{"GOADED", 6, 209963},
	{"PHYTOCHEMICAL", 13, 209964},
	{"ABBIAMO", 7, 209965},
	{"ASSITANT", 8, 209966},
	{"XENOGRAFTS", 10, 209967},
	{"OLDINCLUDEDIR", 13, 209968},
	{"MYVAR", 5, 209969},
	{"FLORINA", 7, 209970},
	{"SERES", 5, 209971},
	{"LIPKIN", 6, 209972},
	{"WXIA", 4, 209973},
	{"TIPBC", 5, 209974},
	{"RAJAB", 5, 209975},
	{"PURFLEET", 8, 209976},
	{"UNSCREENED", 10, 209977},
	{"RECIVE", 6, 209978},
	{"NCCR", 4, 209979},
	{"JAVAN", 5, 209980},
	{"PYCON", 5, 209981},
	{"GERONTOL", 8, 209982},
	{"THEORET", 7, 209983},
	{"JOLIETTE", 8, 209984},
	{"GETTITLE", 8, 209985},
	{"HELV", 4, 209986},
	{"CALLICOON", 9, 209987},
	{"ECKE", 4, 209988},
	{"LOGICIANS", 9, 209989},
	{"NAUTIQUE", 8, 209990},
	{"STUDLY", 6, 209991},
	{"MISLAID", 7, 209992},
	{"FILESPEC", 8, 209993},
	{"MUSHING", 7, 209994},
	{"TUITIONS", 8, 209995},
	{"SNOVER", 6, 209996},
	{"PROCTORED", 9, 209997},
	{"HEXXAGON", 8, 209998},
	{"EVERYBODYS", 10, 209999},
	{"GIGOLOS", 7, 210000},
	{"SMALLHOLDING", 12, 210001},
	{"SCHOELLER", 9, 210002},
	{"MESOSPHERE", 10, 210003},
	{"FIXNUM", 6, 210004},
	{"SNEADS", 6, 210005},
	{"AUROVILLE", 9, 210006},
	{"CSDS", 4, 210007},
	{"STOELEN", 7, 210008},
	{"DISKGO", 6, 210009},
	{"PAASCHE", 7, 210010},
	{"DDARPARU", 8, 210011},
	{"ANTIDIABETIC", 12, 210012},
	{"NAWBO", 5, 210013},
	{"FROLOV", 6, 210014},
	{"EFFORD", 6, 210015},
	{"METACYC", 7, 210016},
	{"GREYING", 7, 210017},
	{"DESMARAIS", 9, 210018},
	{"NENANA", 6, 210019},
	{"GNWT", 4, 210020},
	{"GAMESMORE", 9, 210021},
	{"ADDIO", 5, 210022},
	{"RODUCTS", 7, 210023},
	{"MERIS", 5, 210024},
	{"CUGAT", 5, 210025},
	{"OUTLASTS", 8, 210026},
	{"LEXBLOG", 7, 210027},
	{"FREND", 5, 210028},
	{"ALIC", 4, 210029},
	{"ICRISAT", 7, 210030},
	{"CARVS", 5, 210031},
	{"BROADWING", 9, 210032},
	{"SINCERLY", 8, 210033},
	{"CONCISENESS", 11, 210034},
	{"MLODE", 5, 210035},
	{"URVEY", 5, 210036},
	{"SETSER", 6, 210037},
	{"LAGAAN", 6, 210038},
	{"IVORIES", 7, 210039},
	{"IMPREST", 7, 210040},
	{"FETTUCCINI", 10, 210041},
	{"DIDOT", 5, 210042},
	{"LARIX", 5, 210043},
	{"JARET", 5, 210044},
	{"PROCCESS", 8, 210045},
	{"BREAKAGES", 9, 210046},
	{"HANKEL", 6, 210047},
	{"GAILEY", 6, 210048},
	{"VERCELLI", 8, 210049},
	{"PRECONDITIONERS", 15, 210050},
	{"EZETIMIBE", 9, 210051},
	{"INTERPOLATIONS", 14, 210052},
	{"PREPLANT", 8, 210053},
	{"CHATURVEDI", 10, 210054},
	{"PRODUCTCASTS", 12, 210055},
	{"TOLENTINO", 9, 210056},
	{"BADHAM", 6, 210057},
	{"COCKCROFT", 9, 210058},
	{"TRADUCTIONS", 11, 210059},
	{"SCHLUTER", 8, 210060},
	{"JACANA", 6, 210061},
	{"ANTONINI", 8, 210062},
	{"OVERPRINTED", 11, 210063},
	{"BCW", 3, 210064},
	{"CEDARHURST", 10, 210065},
	{"UNFIRED", 7, 210066},
	{"MCNICHOLS", 9, 210067},
	{"GFSD", 4, 210068},
	{"HAMACHI", 7, 210069},
	{"EBAUMS", 6, 210070},
	{"CHILDR", 6, 210071},
	{"TIMESERIES", 10, 210072},
	{"SEGUES", 6, 210073},
	{"SUROWIECKI", 10, 210074},
	{"REHASHED", 8, 210075},
	{"PTDINS", 6, 210076},
	{"LIFESCIENCES", 12, 210077},
	{"GRAPHIQUES", 10, 210078},
	{"FIDONEWS", 8, 210079},
	{"ROTUND", 6, 210080},
	{"OLEMA", 5, 210081},
	{"LUTHERANISM", 11, 210082},
	{"SHELBEE", 7, 210083},
	{"IONOPHORE", 9, 210084},
	{"GUISELEY", 8, 210085},
	{"CHATELAIN", 9, 210086},
	{"MITCHINSON", 10, 210087},
	{"KAWAHARA", 8, 210088},
	{"CAWDS", 5, 210089},
	{"SABERCATS", 9, 210090},
	{"EXPERIENCIAS", 12, 210091},
	{"BANDI", 5, 210092},
	{"ZSOL", 4, 210093},
	{"ZOVA", 4, 210094},
	{"ZOKU", 4, 210095},
	{"ZHIR", 4, 210096},
	{"YREZ", 4, 210097},
	{"YNIM", 4, 210098},
	{"XDET", 4, 210099},
	{"WMYH", 4, 210100},
	{"VACR", 4, 210101},
	{"UXSE", 4, 210102},
	{"UOEV", 4, 210103},
	{"UKWU", 4, 210104},
	{"TRMI", 4, 210105},
	{"TMPA", 4, 210106},
	{"TIPB", 4, 210107},
	{"TCBA", 4, 210108},
	{"SYWR", 4, 210109},
	{"SDSP", 4, 210110},
	{"RTZU", 4, 210111},
	{"RPCE", 4, 210112},
	{"PDGR", 4, 210113},
	{"OZNY", 4, 210114},
	{"OKUJ", 4, 210115},
	{"NPOZ", 4, 210116},
	{"NIXU", 4, 210117},
	{"NGYD", 4, 210118},
	{"NDXX", 4, 210119},
	{"NDMN", 4, 210120},
	{"MNEB", 4, 210121},
	{"MMEU", 4, 210122},
	{"MGUS", 4, 210123},
	{"MDPR", 4, 210124},
	{"LOMY", 4, 210125},
	{"LNOJ", 4, 210126},
	{"KOUK", 4, 210127},
	{"KAEX", 4, 210128},
	{"HLCH", 4, 210129},
	{"GFAD", 4, 210130},
	{"FTHV", 4, 210131},
	{"FISJ", 4, 210132},
	{"EMDS", 4, 210133},
	{"EIZZ", 4, 210134},
	{"DUVI", 4, 210135},
	{"DOCM", 4, 210136},
	{"DLAA", 4, 210137},
	{"DGYR", 4, 210138},
	{"DBAX", 4, 210139},
	{"BSSM", 4, 210140},
	{"AVSR", 4, 210141},
	{"AJUB", 4, 210142},
	{"ADHR", 4, 210143},
	{"BROTHE", 6, 210144},
	{"SIEGERT", 7, 210145},
	{"DOBROIDE", 8, 210146},
	{"GBG", 3, 210147},
	{"STUDENTSREVIEW", 14, 210148},
	{"GREENGROCERS", 12, 210149},
	{"DECENTRALIZING", 14, 210150},
	{"ZENOBIA", 7, 210151},
	{"RIGAUD", 6, 210152},
	{"ANTEPOST", 8, 210153},
	{"THREADPREVIOUS", 14, 210154},
	{"SCHLUSSEL", 9, 210155},
	{"PICKAXE", 7, 210156},
	{"WESTNET", 7, 210157},
	{"MODIFIEDS", 9, 210158},
	{"GRIDLINES", 9, 210159},
	{"CROISETTE", 9, 210160},
	{"NABER", 5, 210161},
	{"ESPECIALMENTE", 13, 210162},
	{"PHPMYFAQ", 8, 210163},
	{"DISSAPEARED", 11, 210164},
	{"SCALPELS", 8, 210165},
	{"MANZI", 5, 210166},
	{"YCHWANEGU", 9, 210167},
	{"LAYPERSONS", 10, 210168},
	{"EPPERLY", 7, 210169},
	{"CURDLING", 8, 210170},
	{"COATTAILS", 9, 210171},
	{"MARGARETE", 9, 210172},
	{"GYMN", 4, 210173},
	{"ARTICULO", 8, 210174},
	{"OAKMOSS", 7, 210175},
	{"BORRIS", 6, 210176},
	{"DROPSHIPPER", 11, 210177},
	{"BAGONG", 6, 210178},
	{"TYLE", 4, 210179},
	{"BENTWOOD", 8, 210180},
	{"GANJI", 5, 210181},
	{"WATERCHUTES", 11, 210182},
	{"CHAPUT", 6, 210183},
	{"VTUNE", 5, 210184},
	{"TERRITO", 7, 210185},
	{"NMLKJ", 5, 210186},
	{"CHECKABLE", 9, 210187},
	{"BIOWEAPONS", 10, 210188},
	{"BABBLED", 7, 210189},
	{"TROOST", 6, 210190},
	{"WMASS", 5, 210191},
	{"THEODORAKIS", 11, 210192},
	{"KINTERA", 7, 210193},
	{"IDPH", 4, 210194},
	{"STYPE", 5, 210195},
	{"NOKON", 5, 210196},
	{"CHARLOTTENBURG", 14, 210197},
	{"GENTLEST", 8, 210198},
	{"POLITICKER", 10, 210199},
	{"DEDADABLOG", 10, 210200},
	{"PROPERT", 7, 210201},
	{"FOGHAT", 6, 210202},
	{"SORBO", 5, 210203},
	{"BRACKETOLOGY", 12, 210204},
	{"GIANA", 5, 210205},
	{"PLEATHER", 8, 210206},
	{"MEADOWOOD", 9, 210207},
	{"ILIST", 5, 210208},
	{"BETHAN", 6, 210209},
	{"MUSICIENS", 9, 210210},
	{"ASPIC", 5, 210211},
	{"IDRA", 4, 210212},
	{"PHYSIOLOGIE", 11, 210213},
	{"GASTENBOEK", 10, 210214},
	{"SZANALMAS", 9, 210215},
	{"CIDCO", 5, 210216},
	{"SAVEGAME", 8, 210217},
	{"ROCKHOUSE", 9, 210218},
	{"BESIEGE", 7, 210219},
	{"SWORDSMANSHIP", 13, 210220},
	{"HORMONALLY", 10, 210221},
	{"CREDITWORTHY", 12, 210222},
	{"BRKT", 4, 210223},
	{"PHOTOBOOTH", 10, 210224},
	{"CDPATH", 6, 210225},
	{"STEREOGRAPHIC", 13, 210226},
	{"STEITZ", 6, 210227},
	{"DOKTA", 5, 210228},
	{"SHERPAS", 7, 210229},
	{"JFREECHART", 10, 210230},
	{"XCELITE", 7, 210231},
	{"BLANDLY", 7, 210232},
	{"PROGESS", 7, 210233},
	{"MAEL", 4, 210234},
	{"HOBBLING", 8, 210235},
	{"BUSSER", 6, 210236},
	{"HOWER", 5, 210237},
	{"CENTRATIONS", 11, 210238},
	{"PAEONIA", 7, 210239},
	{"HOPELINE", 8, 210240},
	{"FLINSTONES", 10, 210241},
	{"ADDN", 4, 210242},
	{"SEVENTEENLIVE", 13, 210243},
	{"KOLIN", 5, 210244},
	{"MMCX", 4, 210245},
	{"JOVENS", 6, 210246},
	{"DOLLSHOUSE", 10, 210247},
	{"SENSUALLY", 9, 210248},
	{"MILETUS", 7, 210249},
	{"CYBERARMY", 9, 210250},
	{"MYSA", 4, 210251},
	{"JACQUOT", 7, 210252},
	{"COSTI", 5, 210253},
	{"MINOOKA", 7, 210254},
	{"BAIGENT", 7, 210255},
	{"CUDDALORE", 9, 210256},
	{"COMPUTERHQ", 10, 210257},
	{"WESTMORE", 8, 210258},
	{"NETROOTS", 8, 210259},
	{"FAVORE", 6, 210260},
	{"CONTACTABLE", 11, 210261},
	{"BOHLEN", 6, 210262},
	{"AXSYS", 5, 210263},
	{"WOOLLAHRA", 9, 210264},
	{"KRICHEL", 7, 210265},
	{"MUTABILITY", 10, 210266},
	{"FREEMAIL", 8, 210267},
	{"UNFROZEN", 8, 210268},
	{"OXYBUTYNIN", 10, 210269},
	{"EFRAT", 5, 210270},
	{"CONFIGURATIONAL", 15, 210271},
	{"PXP", 3, 210272},
	{"FONTENAY", 8, 210273},
	{"JOBZONE", 7, 210274},
	{"CINEMASCOPE", 11, 210275},
	{"CDY", 3, 210276},
	{"HORTONVILLE", 11, 210277},
	{"ORBSVCS", 7, 210278},
	{"GAVIOTA", 7, 210279},
	{"VARICK", 6, 210280},
	{"IMPERFORATE", 11, 210281},
	{"WESTTOWN", 8, 210282},
	{"MIDAMERICA", 10, 210283},
	{"CLEON", 5, 210284},
	{"SCYTHIANS", 9, 210285},
	{"HOPTON", 6, 210286},
	{"ARMD", 4, 210287},
	{"WYNKOOP", 7, 210288},
	{"DIAPOSITIVE", 11, 210289},
	{"OBLIGORS", 8, 210290},
	{"ZHOM", 4, 210291},
	{"YTYC", 4, 210292},
	{"YDCC", 4, 210293},
	{"VYPU", 4, 210294},
	{"UUMB", 4, 210295},
	{"UPTN", 4, 210296},
	{"UDPI", 4, 210297},
	{"TEYW", 4, 210298},
	{"SWWI", 4, 210299},
	{"RCTV", 4, 210300},
	{"RAVG", 4, 210301},
	{"PEKK", 4, 210302},
	{"OZYC", 4, 210303},
	{"ODUG", 4, 210304},
	{"OBIP", 4, 210305},
	{"NTZP", 4, 210306},
	{"NKUE", 4, 210307},
	{"NKKN", 4, 210308},
	{"NCOZ", 4, 210309},
	{"MBMI", 4, 210310},
	{"LLUI", 4, 210311},
	{"INUW", 4, 210312},
	{"HSUZ", 4, 210313},
	{"GOZI", 4, 210314},
	{"FYSI", 4, 210315},
	{"ETRC", 4, 210316},
	{"ESDB", 4, 210317},
	{"EDHB", 4, 210318},
	{"DRSD", 4, 210319},
	{"CWHY", 4, 210320},
	{"BSKE", 4, 210321},
	{"BOYY", 4, 210322},
	{"ARCV", 4, 210323},
	{"ADTC", 4, 210324},
	{"AAGG", 4, 210325},
	{"MAINSPRING", 10, 210326},
	{"DIEFENBAKER", 11, 210327},
	{"SANJIV", 6, 210328},
	{"IICD", 4, 210329},
	{"JOTTER", 6, 210330},
	{"MYELITIS", 8, 210331},
	{"VINHO", 5, 210332},
	{"DISTO", 5, 210333},
	{"AGAGOOGA", 8, 210334},
	{"MENTALE", 7, 210335},
	{"TWISS", 5, 210336},
	{"TARGOVISHTE", 11, 210337},
	{"ZICAM", 5, 210338},
	{"MUSHERS", 7, 210339},
	{"FGB", 3, 210340},
	{"ALGONAC", 7, 210341},
	{"WYLAND", 6, 210342},
	{"MAZZ", 4, 210343},
	{"FADDEN", 6, 210344},
	{"SUBGRANT", 8, 210345},
	{"GRAPPELLI", 9, 210346},
	{"SEPERATOR", 9, 210347},
	{"EVENTTYPE", 9, 210348},
	{"KLEMTU", 6, 210349},
	{"BURUNDIAN", 9, 210350},
	{"SPACETIMES", 10, 210351},
	{"PONYBOY", 7, 210352},
	{"INTERCLUB", 9, 210353},
	{"CLINTOCK", 8, 210354},
	{"MFIP", 4, 210355},
	{"BAYON", 5, 210356},
	{"TRUMANSBURG", 11, 210357},
	{"OPENVRML", 8, 210358},
	{"FDRAKE", 6, 210359},
	{"CORNEJO", 7, 210360},
	{"COBI", 4, 210361},
	{"SPHYGMOMANOMETER", 16, 210362},
	{"DIRECTDRAW", 10, 210363},
	{"SHERWD", 6, 210364},
	{"RETEK", 5, 210365},
	{"NORRINGTON", 10, 210366},
	{"SPELLETJES", 10, 210367},
	{"JIAOTONG", 8, 210368},
	{"INTERNECINE", 11, 210369},
	{"ERECIPES", 8, 210370},
	{"DINGE", 5, 210371},
	{"AUTONOMEDIA", 11, 210372},
	{"DONLOADS", 8, 210373},
	{"PREFONTAINE", 11, 210374},
	{"KOYAANISQATSI", 13, 210375},
	{"JUM", 3, 210376},
	{"SLAKE", 5, 210377},
	{"MOYET", 5, 210378},
	{"OSMOLAR", 7, 210379},
	{"GROMACS", 7, 210380},
	{"CANNINGS", 8, 210381},
	{"SCHROETER", 9, 210382},
	{"ONOFRE", 6, 210383},
	{"MOUNTAINTOPS", 12, 210384},
	{"PERIBOOB", 8, 210385},
	{"DOMINAS", 7, 210386},
	{"WLADYSLAW", 9, 210387},
	{"STREUSEL", 8, 210388},
	{"NASOGASTRIC", 11, 210389},
	{"DRAME", 5, 210390},
	{"ROADCYCLINGUK", 13, 210391},
	{"LIEBLING", 8, 210392},
	{"ICHARD", 6, 210393},
	{"GARDENJEWELRYKIDSVIDEO", 22, 210394},
	{"DIRENT", 6, 210395},
	{"MECHANISATION", 13, 210396},
	{"ZWINGLI", 7, 210397},
	{"WEALDSTONE", 10, 210398},
	{"MISKOLC", 7, 210399},
	{"ILITY", 5, 210400},
	{"HELLBENT", 8, 210401},
	{"ADDITIONALUSER", 14, 210402},
	{"RANDOLF", 7, 210403},
	{"OCATION", 7, 210404},
	{"MASHAM", 6, 210405},
	{"REMOVEALL", 9, 210406},
	{"STEFANOS", 8, 210407},
	{"NONDEGREE", 9, 210408},
	{"VERDIER", 7, 210409},
	{"SWIFTNET", 8, 210410},
	{"LEWICKI", 7, 210411},
	{"AHURA", 5, 210412},
	{"NADYA", 5, 210413},
	{"HIGHEREDJOBS", 12, 210414},
	{"EPOST", 5, 210415},
	{"BIWA", 4, 210416},
	{"JEDEM", 5, 210417},
	{"ACTIFS", 6, 210418},
	{"DIMORPHIC", 9, 210419},
	{"WISSAHICKON", 11, 210420},
	{"LOCKBACK", 8, 210421},
	{"COMPUTERBANK", 12, 210422},
	{"MECHANICVILLE", 13, 210423},
	{"IOLTA", 5, 210424},
	{"RECIVED", 7, 210425},
	{"RELEATED", 8, 210426},
	{"BUFFA", 5, 210427},
	{"WIERDNESS", 9, 210428},
	{"REUBENS", 7, 210429},
	{"SEDGLEY", 7, 210430},
	{"BEGBIE", 6, 210431},
	{"GABRIELS", 8, 210432},
	{"BALUNS", 6, 210433},
	{"COMPADRE", 8, 210434},
	{"AMBROSIUS", 9, 210435},
	{"CENTERA", 7, 210436},
	{"SUMISION", 8, 210437},
	{"CORBRIDGE", 9, 210438},
	{"ALLON", 5, 210439},
	{"WOOLLARD", 8, 210440},
	{"BOTTA", 5, 210441},
	{"NEIGES", 6, 210442},
	{"EXPEDI", 6, 210443},
	{"ABIJAH", 6, 210444},
	{"TEUBNER", 7, 210445},
	{"PORTUNITY", 9, 210446},
	{"POSITIV", 7, 210447},
	{"ISAKMPD", 7, 210448},
	{"ASSITANCE", 9, 210449},
	{"APOPHYSIS", 9, 210450},
	{"RICOEUR", 7, 210451},
	{"MEXI", 4, 210452},
	{"CHRONIQUE", 9, 210453},
	{"DAYPREVIOUS", 11, 210454},
	{"USCHO", 5, 210455},
	{"PRSI", 4, 210456},
	{"ILISP", 5, 210457},
	{"DIMETHOXY", 9, 210458},
	{"BEDSKIRTS", 9, 210459},
	{"SPEARED", 7, 210460},
	{"EESTLANE", 8, 210461},
	{"LRESOLV", 7, 210462},
	{"SULPHIDES", 9, 210463},
	{"POLESTAR", 8, 210464},
	{"OOGENESIS", 9, 210465},
	{"CUBITT", 6, 210466},
	{"SUPERGLUE", 9, 210467},
	{"BPV", 3, 210468},
	{"MOTHERNATURE", 12, 210469},
	{"MILAZZO", 7, 210470},
	{"TRADELINE", 9, 210471},
	{"LOVENOX", 7, 210472},
	{"CHARMERS", 8, 210473},
	{"BOOTLEGGER", 10, 210474},
	{"TRILINEAR", 9, 210475},
	{"PENTIUMPRO", 10, 210476},
	{"ZZGR", 4, 210477},
	{"ZYPO", 4, 210478},
	{"YGMY", 4, 210479},
	{"YADL", 4, 210480},
	{"XICL", 4, 210481},
	{"WZON", 4, 210482},
	{"URRR", 4, 210483},
	{"UPAZ", 4, 210484},
	{"UDUC", 4, 210485},
	{"TTPB", 4, 210486},
	{"SPNP", 4, 210487},
	{"REXU", 4, 210488},
	{"RDAJ", 4, 210489},
	{"PPCH", 4, 210490},
	{"PGWH", 4, 210491},
	{"OMBK", 4, 210492},
	{"OGFE", 4, 210493},
	{"NTCD", 4, 210494},
	{"NNJR", 4, 210495},
	{"NGPG", 4, 210496},
	{"NDGD", 4, 210497},
	{"MKOT", 4, 210498},
	{"MDWI", 4, 210499},
	{"MBCT", 4, 210500},
	{"LZAD", 4, 210501},
	{"JPAN", 4, 210502},
	{"JIBT", 4, 210503},
	{"IXVA", 4, 210504},
	{"HUEB", 4, 210505},
	{"GMCK", 4, 210506},
	{"FVED", 4, 210507},
	{"FOSU", 4, 210508},
	{"FNOK", 4, 210509},
	{"FIQU", 4, 210510},
	{"FAJI", 4, 210511},
	{"EUCR", 4, 210512},
	{"EBPI", 4, 210513},
	{"DWOV", 4, 210514},
	{"DWAU", 4, 210515},
	{"DIKT", 4, 210516},
	{"DGID", 4, 210517},
	{"BIFT", 4, 210518},
	{"AYIJ", 4, 210519},
	{"WONEN", 5, 210520},
	{"EMANUELA", 8, 210521},
	{"GILGIT", 6, 210522},
	{"ACCOMMIDATION", 13, 210523},
	{"SIMILAN", 7, 210524},
	{"ISTRUZIONE", 10, 210525},
	{"ECORSE", 6, 210526},
	{"AIADA", 5, 210527},
	{"ONLLINE", 7, 210528},
	{"MARTEK", 6, 210529},
	{"ATTAQUE", 7, 210530},
	{"EDTECH", 6, 210531},
	{"NONUDE", 6, 210532},
	{"KALLOY", 6, 210533},
	{"ENCYCLOPAEDIC", 13, 210534},
	{"CONNECTIONISM", 13, 210535},
	{"ZECK", 4, 210536},
	{"TORREQUEBRADA", 13, 210537},
	{"JARBOE", 6, 210538},
	{"SOUKUP", 6, 210539},
	{"LABEM", 5, 210540},
	{"TAMLA", 5, 210541},
	{"ARTRESOURCES", 12, 210542},
	{"ALCA", 4, 210543},
	{"FFRENGIG", 8, 210544},
	{"BINGOS", 6, 210545},
	{"SERVERAID", 9, 210546},
	{"LAWGURU", 7, 210547},
	{"WHIRLIGIG", 9, 210548},
	{"BOTW", 4, 210549},
	{"ANAFRANIL", 9, 210550},
	{"AIIMS", 5, 210551},
	{"TEAMADVANTAGE", 13, 210552},
	{"MCMORRIS", 8, 210553},
	{"NPPS", 4, 210554},
	{"INTERORGANIZATIONAL", 19, 210555},
	{"LEETCH", 6, 210556},
	{"RPPC", 4, 210557},
	{"OUTL", 4, 210558},
	{"MARSEDIT", 8, 210559},
	{"WOERNER", 7, 210560},
	{"NETIMPERATIVE", 13, 210561},
	{"TELESYSTEMS", 11, 210562},
	{"MOTZ", 4, 210563},
	{"CHAPALA", 7, 210564},
	{"VARIFOCAL", 9, 210565},
	{"SEEARCH", 7, 210566},
	{"PROSQESE", 8, 210567},
	{"AGENCYS", 7, 210568},
	{"GALLEONS", 8, 210569},
	{"KOGELSCHARNIER", 14, 210570},
	{"BLOGINALITY", 11, 210571},
	{"TRULLY", 6, 210572},
	{"MATTOS", 6, 210573},
	{"LORAX", 5, 210574},
	{"LIMITEDS", 8, 210575},
	{"FIBFACT", 7, 210576},
	{"SENSORIAL", 9, 210577},
	{"LEGATION", 8, 210578},
	{"UCSIMM", 6, 210579},
	{"TRANSMISSIVITY", 14, 210580},
	{"STRUTTED", 8, 210581},
	{"GOBIES", 6, 210582},
	{"FLOWAGE", 7, 210583},
	{"ELECTRIFY", 9, 210584},
	{"BYG", 3, 210585},
	{"VRU", 3, 210586},
	{"DININGROOM", 10, 210587},
	{"ALLERDALE", 9, 210588},
	{"MANCHEGO", 8, 210589},
	{"AHELOY", 6, 210590},
	{"SUBSYS", 6, 210591},
	{"SCHONE", 6, 210592},
	{"MCSS", 4, 210593},
	{"LEAFLESS", 8, 210594},
	{"DUNCOMBE", 8, 210595},
	{"VIDEODROME", 10, 210596},
	{"CAZADERO", 8, 210597},
	{"PSYGNOSIS", 9, 210598},
	{"NOMADIX", 7, 210599},
	{"EMBR", 4, 210600},
	{"MOVIESFREE", 10, 210601},
	{"DEMOBILIZED", 11, 210602},
	{"PIPERACILLIN", 12, 210603},
	{"CHAUVINISTIC", 12, 210604},
	{"DUNNAGE", 7, 210605},
	{"BELISLE", 7, 210606},
	{"SOEREN", 6, 210607},
	{"GEKAS", 5, 210608},
	{"DEIGNED", 7, 210609},
	{"PENTOP", 6, 210610},
	{"FBF", 3, 210611},
	{"BANDHAN", 7, 210612},
	{"THAYERS", 7, 210613},
	{"GOMO", 4, 210614},
	{"KIBO", 4, 210615},
	{"GILLER", 6, 210616},
	{"FAQDESK", 7, 210617},
	{"JOBIN", 5, 210618},
	{"TREAMENT", 8, 210619},
	{"GOLDSTON", 8, 210620},
	{"DUCTIVITY", 9, 210621},
	{"TEODOR", 6, 210622},
	{"TACHIKAWA", 9, 210623},
	{"NORDOST", 7, 210624},
	{"BURGHLEY", 8, 210625},
	{"UNITEL", 6, 210626},
	{"GRAYSTONE", 9, 210627},
	{"CMSR", 4, 210628},
	{"ROSKILL", 7, 210629},
	{"TREVALLY", 8, 210630},
	{"TOKENRING", 9, 210631},
	{"RESOURSE", 8, 210632},
	{"BORKED", 6, 210633},
	{"SLAVER", 6, 210634},
	{"KAPUSKASING", 11, 210635},
	{"KAHANAMOKU", 10, 210636},
	{"ROMULANS", 8, 210637},
	{"GOODSTEIN", 9, 210638},
	{"SETCURSOR", 9, 210639},
	{"MABEN", 5, 210640},
	{"DESCUBRE", 8, 210641},
	{"SIDLE", 5, 210642},
	{"KUSS", 4, 210643},
	{"ARBUSCULAR", 10, 210644},
	{"SDRAC", 5, 210645},
	{"CONTORTION", 10, 210646},
	{"BRICS", 5, 210647},
	{"REMINISCED", 10, 210648},
	{"GREASER", 7, 210649},
	{"EJEMPLOS", 8, 210650},
	{"SUNSTROKE", 9, 210651},
	{"ISEULT", 6, 210652},
	{"AYLETT", 6, 210653},
	{"XWRIS", 5, 210654},
	{"MCCARDELL", 9, 210655},
	{"FLAMERS", 7, 210656},
	{"HOEHRMANN", 9, 210657},
	{"CLYWD", 5, 210658},
	{"SUCHA", 5, 210659},
	{"RECOMMENCE", 10, 210660},
	{"PHOTODISSOCIATION", 17, 210661},
	{"FORMICIDAE", 10, 210662},
	{"ECPA", 4, 210663},
	{"DEVASTATOR", 10, 210664},
	{"SADDLEBRED", 10, 210665},
	{"MASSANA", 7, 210666},
	{"PIRAMAL", 7, 210667},
	{"AIRIS", 5, 210668},
	{"ZUBI", 4, 210669},
	{"ZKNO", 4, 210670},
	{"YMYI", 4, 210671},
	{"YMRT", 4, 210672},
	{"XTIR", 4, 210673},
	{"WYNM", 4, 210674},
	{"WMIT", 4, 210675},
	{"WIFM", 4, 210676},
	{"UTKG", 4, 210677},
	{"UHAY", 4, 210678},
	{"TGOC", 4, 210679},
	{"TDUQ", 4, 210680},
	{"SMVI", 4, 210681},
	{"SLCA", 4, 210682},
	{"SKLU", 4, 210683},
	{"SJOP", 4, 210684},
	{"RZHI", 4, 210685},
	{"RUYN", 4, 210686},
	{"RAKD", 4, 210687},
	{"RAFN", 4, 210688},
	{"PUSV", 4, 210689},
	{"PSNU", 4, 210690},
	{"POLM", 4, 210691},
	{"PGCO", 4, 210692},
	{"OYFL", 4, 210693},
	{"OMIQ", 4, 210694},
	{"OMDW", 4, 210695},
	{"OIPL", 4, 210696},
	{"NAKY", 4, 210697},
	{"MQUO", 4, 210698},
	{"LXAN", 4, 210699},
	{"KYOV", 4, 210700},
	{"JJAJ", 4, 210701},
	{"IPHM", 4, 210702},
	{"HUNZ", 4, 210703},
	{"HJUI", 4, 210704},
	{"GZAN", 4, 210705},
	{"GLYQ", 4, 210706},
	{"FNDA", 4, 210707},
	{"FIXN", 4, 210708},
	{"FBUK", 4, 210709},
	{"EPMB", 4, 210710},
	{"DRDS", 4, 210711},
	{"DETP", 4, 210712},
	{"DDVI", 4, 210713},
	{"DDUI", 4, 210714},
	{"CFEM", 4, 210715},
	{"CDVD", 4, 210716},
	{"BJOI", 4, 210717},
	{"BEGH", 4, 210718},
	{"AWNV", 4, 210719},
	{"AVOP", 4, 210720},
	{"AQBY", 4, 210721},
	{"AKKH", 4, 210722},
	{"SIMCARDS", 8, 210723},
	{"ACTIO", 5, 210724},
	{"RELIGON", 7, 210725},
	{"CSENGOHANGOK", 12, 210726},
	{"HYPERSOMNIA", 11, 210727},
	{"ZINMAN", 6, 210728},
	{"PEDIGREED", 9, 210729},
	{"FUNZIONE", 8, 210730},
	{"BOOGERS", 7, 210731},
	{"TURRIFF", 7, 210732},
	{"KERRICK", 7, 210733},
	{"IGCSE", 5, 210734},
	{"GREENMARKET", 11, 210735},
	{"CYTOGENET", 9, 210736},
	{"TREMPER", 7, 210737},
	{"FREEGIFT", 8, 210738},
	{"EQUILIBRATE", 11, 210739},
	{"PROOFPOINT", 10, 210740},
	{"BFINANCIAL", 10, 210741},
	{"ZONEPERFECT", 11, 210742},
	{"MSAR", 4, 210743},
	{"MEGGER", 6, 210744},
	{"KELEMEN", 7, 210745},
	{"BIOTOPE", 7, 210746},
	{"GIUE", 4, 210747},
	{"POEHLMAN", 8, 210748},
	{"BIRDSEED", 8, 210749},
	{"COMENT", 6, 210750},
	{"AVENTURES", 9, 210751},
	{"CROSSBARS", 9, 210752},
	{"SEAMANS", 7, 210753},
	{"LAKERIDGE", 9, 210754},
	{"KWQ", 3, 210755},
	{"BRUEGGEMANN", 11, 210756},
	{"MISCEGENATION", 13, 210757},
	{"FBSD", 4, 210758},
	{"SUBSTRATA", 9, 210759},
	{"FLIGHTAWARE", 11, 210760},
	{"MELAY", 5, 210761},
	{"TRIHYDRATE", 10, 210762},
	{"COLLEGEDALE", 11, 210763},
	{"MAZO", 4, 210764},
	{"BYEONG", 6, 210765},
	{"ARRIAGA", 7, 210766},
	{"MENISCAL", 8, 210767},
	{"HENZINGER", 9, 210768},
	{"ECHOLOCATION", 12, 210769},
	{"FORFATTER", 9, 210770},
	{"FILEWATCHER", 11, 210771},
	{"CHLORTHALIDONE", 14, 210772},
	{"SOUNDVIEW", 9, 210773},
	{"BLANCHARDSTOWN", 14, 210774},
	{"MYOBLASTS", 9, 210775},
	{"FAIRHURST", 9, 210776},
	{"IPRO", 4, 210777},
	{"BROADCASTMESSAGE", 16, 210778},
	{"WEBCONCEPTS", 11, 210779},
	{"UNGRAMMATICAL", 13, 210780},
	{"SPAWAR", 6, 210781},
	{"MERRYMAN", 8, 210782},
	{"DEPAR", 5, 210783},
	{"SCOLDS", 6, 210784},
	{"SCHOEPS", 7, 210785},
	{"GEFESSELT", 9, 210786},
	{"STYRON", 6, 210787},
	{"KHAMIS", 6, 210788},
	{"BINGHAMPTON", 11, 210789},
	{"KRISTOFF", 8, 210790},
	{"CLELLAND", 8, 210791},
	{"TRAWLED", 7, 210792},
	{"PROTONATION", 11, 210793},
	{"NEWBIGGIN", 9, 210794},
	{"LANIE", 5, 210795},
	{"ETOKEN", 6, 210796},
	{"PROJEKTOR", 9, 210797},
	{"HELLESPONT", 10, 210798},
	{"GUION", 5, 210799},
	{"YASHIN", 6, 210800},
	{"ANONCVS", 7, 210801},
	{"SAURUS", 6, 210802},
	{"MILLOM", 6, 210803},
	{"SCLERAL", 7, 210804},
	{"PERSUADERS", 10, 210805},
	{"MASTRO", 6, 210806},
	{"ADMONISHES", 10, 210807},
	{"ALBH", 4, 210808},
	{"TACONITE", 8, 210809},
	{"MICROWAVABLE", 12, 210810},
	{"GENETICAL", 9, 210811},
	{"CLAROLINE", 9, 210812},
	{"BOOKSMITH", 9, 210813},
	{"ANCIENNES", 9, 210814},
	{"CHOWS", 5, 210815},
	{"WODNA", 5, 210816},
	{"OSTERVILLE", 10, 210817},
	{"GLUTTONOUS", 10, 210818},
	{"MEDDWL", 6, 210819},
	{"ONTAP", 5, 210820},
	{"WILLIG", 6, 210821},
	{"PRWTH", 5, 210822},
	{"EUROZINE", 8, 210823},
	{"SCHOEMAN", 8, 210824},
	{"KRF", 3, 210825},
	{"HEFTET", 6, 210826},
	{"HARTLINE", 8, 210827},
	{"STUKA", 5, 210828},
	{"MUSIKHAUS", 9, 210829},
	{"LIBDV", 5, 210830},
	{"FMOD", 4, 210831},
	{"ASURA", 5, 210832},
	{"SITIES", 6, 210833},
	{"NACCHO", 6, 210834},
	{"BAHMAN", 6, 210835},
	{"TOPHOMES", 8, 210836},
	{"RAGOUT", 6, 210837},
	{"MILLENDER", 9, 210838},
	{"DALLIANCE", 9, 210839},
	{"YOUTHFULNESS", 12, 210840},
	{"WEBBLOG", 7, 210841},
	{"GURDON", 6, 210842},
	{"SUPERCASE", 9, 210843},
	{"PHARMACOLOGIST", 14, 210844},
	{"PHARMACO", 8, 210845},
	{"ULTRALAB", 8, 210846},
	{"PUNYA", 5, 210847},
	{"POPWAR", 6, 210848},
	{"JADORE", 6, 210849},
	{"TANARUS", 7, 210850},
	{"SKELETONKEY", 11, 210851},
	{"RESERVATIONLESS", 15, 210852},
	{"LATREILLE", 9, 210853},
	{"ALIPAC", 6, 210854},
	{"SANDON", 6, 210855},
	{"HANDBELLS", 9, 210856},
	{"COLOBUS", 7, 210857},
	{"CARW", 4, 210858},
	{"BESELER", 7, 210859},
	{"BERARDINELLI", 12, 210860},
	{"LEUCAENA", 8, 210861},
	{"FELBER", 6, 210862},
	{"UNHOOK", 6, 210863},
	{"MAAM", 4, 210864},
	{"CHEAH", 5, 210865},
	{"ZYNA", 4, 210866},
	{"ZYBO", 4, 210867},
	{"ZREF", 4, 210868},
	{"ZFAC", 4, 210869},
	{"ZDEA", 4, 210870},
	{"ZAIB", 4, 210871},
	{"YRWA", 4, 210872},
	{"YNAW", 4, 210873},
	{"YKMM", 4, 210874},
	{"XTSM", 4, 210875},
	{"XRID", 4, 210876},
	{"WPLY", 4, 210877},
	{"WBYI", 4, 210878},
	{"VSBI", 4, 210879},
	{"VORV", 4, 210880},
	{"UOGU", 4, 210881},
	{"UAMB", 4, 210882},
	{"TVLO", 4, 210883},
	{"TKOK", 4, 210884},
	{"TEJR", 4, 210885},
	{"SYYO", 4, 210886},
	{"RTVP", 4, 210887},
	{"RSHG", 4, 210888},
	{"RNZA", 4, 210889},
	{"RGEZ", 4, 210890},
	{"RFBE", 4, 210891},
	{"RBTR", 4, 210892},
	{"PEGP", 4, 210893},
	{"OZWA", 4, 210894},
	{"OCTV", 4, 210895},
	{"NGHG", 4, 210896},
	{"NDKP", 4, 210897},
	{"MNDO", 4, 210898},
	{"LNAB", 4, 210899},
	{"LAVW", 4, 210900},
	{"KSNY", 4, 210901},
	{"KSKO", 4, 210902},
	{"KICI", 4, 210903},
	{"KFEB", 4, 210904},
	{"KEWT", 4, 210905},
	{"KEBB", 4, 210906},
	{"IOUL", 4, 210907},
	{"IGEY", 4, 210908},
	{"HVIB", 4, 210909},
	{"FYFR", 4, 210910},
	{"FPEG", 4, 210911},
	{"FJAB", 4, 210912},
	{"FFOW", 4, 210913},
	{"EPPG", 4, 210914},
	{"EGEX", 4, 210915},
	{"DZUL", 4, 210916},
	{"DYKR", 4, 210917},
	{"DRBS", 4, 210918},
	{"DEZL", 4, 210919},
	{"CYVO", 4, 210920},
	{"CSKN", 4, 210921},
	{"CIOG", 4, 210922},
	{"BYUI", 4, 210923},
	{"BROF", 4, 210924},
	{"BJOB", 4, 210925},
	{"BHUR", 4, 210926},
	{"AJCO", 4, 210927},
	{"AIBY", 4, 210928},
	{"AGSY", 4, 210929},
	{"OVERSTATES", 10, 210930},
	{"HOUSINGZONE", 11, 210931},
	{"ESAMI", 5, 210932},
	{"CERTIAN", 7, 210933},
	{"ABUM", 4, 210934},
	{"PRIVATIONS", 10, 210935},
	{"DAOISM", 6, 210936},
	{"NOTICABLY", 9, 210937},
	{"CARRYBACK", 9, 210938},
	{"FEVEREIRO", 9, 210939},
	{"TROUVEZ", 7, 210940},
	{"STANFORDS", 9, 210941},
	{"REEKER", 6, 210942},
	{"SUPRISES", 8, 210943},
	{"MONSTROSITIES", 13, 210944},
	{"MANETTE", 7, 210945},
	{"HATEMAIL", 8, 210946},
	{"PYRETHROIDS", 11, 210947},
	{"COMPOSIT", 8, 210948},
	{"KRAYZIE", 7, 210949},
	{"ELECTROCHEM", 11, 210950},
	{"LUBRICATES", 10, 210951},
	{"CLITA", 5, 210952},
	{"ROAMANS", 7, 210953},
	{"SHINDER", 7, 210954},
	{"DIVISI", 6, 210955},
	{"ARREARAGE", 9, 210956},
	{"ZDJECIA", 7, 210957},
	{"PRATIK", 6, 210958},
	{"GAZI", 4, 210959},
	{"BACKLOGGED", 10, 210960},
	{"HYDRON", 6, 210961},
	{"MONETE", 6, 210962},
	{"EXOD", 4, 210963},
	{"YMCAS", 5, 210964},
	{"LEANE", 5, 210965},
	{"GOEST", 5, 210966},
	{"BOAG", 4, 210967},
	{"TRABALHADORES", 13, 210968},
	{"ONTOLOG", 7, 210969},
	{"NIGRUM", 6, 210970},
	{"AUEL", 4, 210971},
	{"WINKELMANN", 10, 210972},
	{"PATAPSCO", 8, 210973},
	{"MARUHN", 6, 210974},
	{"LEGGERE", 7, 210975},
	{"ICCP", 4, 210976},
	{"GEETHA", 6, 210977},
	{"WOWING", 6, 210978},
	{"GRANDAM", 7, 210979},
	{"PEGASOS", 7, 210980},
	{"EMPORER", 7, 210981},
	{"SHIRAI", 6, 210982},
	{"ISELDIROEDD", 11, 210983},
	{"HRISTOV", 7, 210984},
	{"TATOOED", 7, 210985},
	{"HUNTE", 5, 210986},
	{"PORTON", 6, 210987},
	{"ECSU", 4, 210988},
	{"PARTICULARILY", 13, 210989},
	{"DELGADA", 7, 210990},
	{"WHOOO", 5, 210991},
	{"JKG", 3, 210992},
	{"GULFCOAST", 9, 210993},
	{"BONBONS", 7, 210994},
	{"WIXON", 5, 210995},
	{"KITKAT", 6, 210996},
	{"QUADRILOGY", 10, 210997},
	{"ANBIETERN", 9, 210998},
	{"CHUGOKU", 7, 210999},
	{"BELLATRIX", 9, 211000},
	{"SEROXAT", 7, 211001},
	{"CHRONICLERS", 11, 211002},
	{"TRACKDAYS", 9, 211003},
	{"HAYTON", 6, 211004},
	{"DLRS", 4, 211005},
	{"ROLIE", 5, 211006},
	{"SRSG", 4, 211007},
	{"MRCOG", 5, 211008},
	{"CDBABY", 6, 211009},
	{"AABBCCDD", 8, 211010},
	{"KUMBA", 5, 211011},
	{"ENIWETOK", 8, 211012},
	{"LHCC", 4, 211013},
	{"GPB", 3, 211014},
	{"KHATRI", 6, 211015},
	{"FLOWCHARTING", 12, 211016},
	{"GRITTING", 8, 211017},
	{"GERUND", 6, 211018},
	{"MERY", 4, 211019},
	{"DERKSEN", 7, 211020},
	{"GANDHIJI", 8, 211021},
	{"WEBTRADE", 8, 211022},
	{"GIUNTA", 6, 211023},
	{"CCAMLR", 6, 211024},
	{"PRESTATIONS", 11, 211025},
	{"VERRIER", 7, 211026},
	{"VINYARD", 7, 211027},
	{"THIRU", 5, 211028},
	{"PORARY", 6, 211029},
	{"IWRM", 4, 211030},
	{"EPILEPSIA", 9, 211031},
	{"CROSSFLOW", 9, 211032},
	{"CONSULTORES", 11, 211033},
	{"CAGER", 5, 211034},
	{"VITAM", 5, 211035},
	{"POWERCABLESTECKER", 17, 211036},
	{"ITAWAMBA", 8, 211037},
	{"DEFILEMENTS", 11, 211038},
	{"DECANTING", 9, 211039},
	{"ALMQUIST", 8, 211040},
	{"SLUMMING", 8, 211041},
	{"SCHEIDLER", 9, 211042},
	{"JOURNALIZED", 11, 211043},
	{"ERREGT", 6, 211044},
	{"DIGNITIES", 9, 211045},
	{"HYPOTENUSE", 10, 211046},
	{"CVRD", 4, 211047},
	{"WINDRIVER", 9, 211048},
	{"MEHEFIN", 7, 211049},
	{"THEREBETWEEN", 12, 211050},
	{"HARLESTON", 9, 211051},
	{"JFFNMS", 6, 211052},
	{"FLASHCHAT", 9, 211053},
	{"AIZU", 4, 211054},
	{"SUBAREAS", 8, 211055},
	{"ESTREMO", 7, 211056},
	{"TECHNIUM", 8, 211057},
	{"MONAVIE", 7, 211058},
	{"HYDROPEROXIDE", 13, 211059},
	{"EMERAUDE", 8, 211060},
	{"INTELIUS", 8, 211061},
	{"FUNDIE", 6, 211062},
	{"AAPELI", 6, 211063},
	{"EASTCOAST", 9, 211064},
	{"YNIP", 4, 211065},
	{"YNBU", 4, 211066},
	{"YEBL", 4, 211067},
	{"XDEN", 4, 211068},
	{"WIGR", 4, 211069},
	{"VUKO", 4, 211070},
	{"VICV", 4, 211071},
	{"URDB", 4, 211072},
	{"UPIK", 4, 211073},
	{"UMYA", 4, 211074},
	{"TWYT", 4, 211075},
	{"TVSY", 4, 211076},
	{"TSCB", 4, 211077},
	{"SREK", 4, 211078},
	{"RMYY", 4, 211079},
	{"PTTU", 4, 211080},
	{"PJAR", 4, 211081},
	{"PAKW", 4, 211082},
	{"ORQB", 4, 211083},
	{"OPKO", 4, 211084},
	{"OFEZ", 4, 211085},
	{"NTMV", 4, 211086},
	{"NGBN", 4, 211087},
	{"MRDR", 4, 211088},
	{"MILJ", 4, 211089},
	{"MGIS", 4, 211090},
	{"LOYR", 4, 211091},
	{"JAAL", 4, 211092},
	{"IZLE", 4, 211093},
	{"HUCL", 4, 211094},
	{"HRRE", 4, 211095},
	{"GUSV", 4, 211096},
	{"FSYE", 4, 211097},
	{"FKUA", 4, 211098},
	{"EBPU", 4, 211099},
	{"EBDU", 4, 211100},
	{"DOUW", 4, 211101},
	{"DDSG", 4, 211102},
	{"BTOJ", 4, 211103},
	{"AZBE", 4, 211104},
	{"ATPB", 4, 211105},
	{"AQAD", 4, 211106},
	{"AJGA", 4, 211107},
	{"MEMOR", 5, 211108},
	{"LIVINGS", 7, 211109},
	{"SYSTOLE", 7, 211110},
	{"SORBATE", 7, 211111},
	{"BENICAR", 7, 211112},
	{"PREWRITTEN", 10, 211113},
	{"GAMEBOOKS", 9, 211114},
	{"BARDEM", 6, 211115},
	{"CHIPGEEK", 8, 211116},
	{"RHAYADER", 8, 211117},
	{"CATENARY", 8, 211118},
	{"STRANGLES", 9, 211119},
	{"MATTSSON", 8, 211120},
	{"TRAVELON", 8, 211121},
	{"WIREWOUND", 9, 211122},
	{"VIGOTTI", 7, 211123},
	{"OKABE", 5, 211124},
	{"LIGNANS", 7, 211125},
	{"FERRYMAN", 8, 211126},
	{"MLTERM", 6, 211127},
	{"APPARTAMENTO", 12, 211128},
	{"PRESENNOL", 9, 211129},
	{"PLEDGER", 7, 211130},
	{"BROUN", 5, 211131},
	{"CRANIOTOMY", 10, 211132},
	{"UNAPOLOGETICALLY", 16, 211133},
	{"CAVAZOS", 7, 211134},
	{"TULARENSIS", 10, 211135},
	{"MOCKINGLY", 9, 211136},
	{"CUNTY", 5, 211137},
	{"BELGRANO", 8, 211138},
	{"CUOCO", 5, 211139},
	{"MCFADYEN", 8, 211140},
	{"BIRN", 4, 211141},
	{"BELFAIR", 7, 211142},
	{"MCCALEB", 7, 211143},
	{"LORETTE", 7, 211144},
	{"ABCDEFG", 7, 211145},
	{"PHOTODETECTORS", 14, 211146},
	{"INFARED", 7, 211147},
	{"GENERO", 6, 211148},
	{"JUNCTURES", 9, 211149},
	{"TYRANNUS", 8, 211150},
	{"GDW", 3, 211151},
	{"BOLLA", 5, 211152},
	{"SOLEN", 5, 211153},
	{"JUNETEENTH", 10, 211154},
	{"DAMGAARD", 8, 211155},
	{"ISCUSSION", 9, 211156},
	{"FAVORITETRAIL", 13, 211157},
	{"BURKERT", 7, 211158},
	{"TRANSPORTES", 11, 211159},
	{"NEUROT", 6, 211160},
	{"GLAVIN", 6, 211161},
	{"FJC", 3, 211162},
	{"SHEIL", 5, 211163},
	{"CAISSES", 7, 211164},
	{"DWPT", 4, 211165},
	{"SPEK", 4, 211166},
	{"NARES", 5, 211167},
	{"GRATI", 5, 211168},
	{"DONOHO", 6, 211169},
	{"DIHYDROGEN", 10, 211170},
	{"DEVOLVES", 8, 211171},
	{"BRANDENBURGER", 13, 211172},
	{"BARONG", 6, 211173},
	{"HILITE", 6, 211174},
	{"CHWEFROR", 8, 211175},
	{"KPP", 3, 211176},
	{"HERBATINT", 9, 211177},
	{"GENETIDE", 8, 211178},
	{"FFOR", 4, 211179},
	{"RECONDITION", 11, 211180},
	{"CONRADO", 7, 211181},
	{"SPIREA", 6, 211182},
	{"ROUTEING", 8, 211183},
	{"IHOLSMAN", 8, 211184},
	{"SHEIKS", 6, 211185},
	{"JELLIFFE", 8, 211186},
	{"REIL", 4, 211187},
	{"NABIKI", 6, 211188},
	{"BERNI", 5, 211189},
	{"HEADUNIT", 8, 211190},
	{"EPITOMIZE", 9, 211191},
	{"CRACKA", 6, 211192},
	{"AMARNATH", 8, 211193},
	{"MORRICE", 7, 211194},
	{"SCISUP", 6, 211195},
	{"METALLURGIST", 12, 211196},
	{"PENICK", 6, 211197},
	{"DECELERATING", 12, 211198},
	{"BLOTTERS", 8, 211199},
	{"PHOSPHORYLATE", 13, 211200},
	{"XENOGRAFT", 9, 211201},
	{"PERDER", 6, 211202},
	{"DULAIMI", 7, 211203},
	{"YMARFER", 7, 211204},
	{"VIRTUOSIC", 9, 211205},
	{"BIZNESS", 7, 211206},
	{"BEHL", 4, 211207},
	{"MXC", 3, 211208},
	{"BIOPROCESSING", 13, 211209},
	{"TAKUO", 5, 211210},
	{"AKADEMIA", 8, 211211},
	{"INDUSTY", 7, 211212},
	{"PANHANDLING", 11, 211213},
	{"GYRATING", 8, 211214},
	{"CHEMINS", 7, 211215},
	{"HOEING", 6, 211216},
	{"POLSKU", 6, 211217},
	{"MONIE", 5, 211218},
	{"LEHTO", 5, 211219},
	{"ELEGIR", 6, 211220},
	{"SIGNORIA", 8, 211221},
	{"WOBBLED", 7, 211222},
	{"TLRS", 4, 211223},
	{"KUMIKO", 6, 211224},
	{"CIRCU", 5, 211225},
	{"UNANET", 6, 211226},
	{"BULGUR", 6, 211227},
	{"VICEVERSA", 9, 211228},
	{"KOUNTZE", 7, 211229},
	{"DIOGO", 5, 211230},
	{"ASCARIS", 7, 211231},
	{"NUED", 4, 211232},
	{"KARMALOOP", 9, 211233},
	{"BLONDINEN", 9, 211234},
	{"SIGCHLD", 7, 211235},
	{"ORVAL", 5, 211236},
	{"MONOLITHICS", 11, 211237},
	{"COGENTLY", 8, 211238},
	{"RUNNEMEDE", 9, 211239},
	{"KOVEL", 5, 211240},
	{"KERNVILLE", 9, 211241},
	{"WALDECK", 7, 211242},
	{"MAIRIE", 6, 211243},
	{"MORANIS", 7, 211244},
	{"KEALAKEKUA", 10, 211245},
	{"REDLIN", 6, 211246},
	{"JUNKYARDBLOG", 12, 211247},
	{"EQNIKHS", 7, 211248},
	{"BLOCKSVIEW", 10, 211249},
	{"EVAW", 4, 211250},
	{"MRBROWN", 7, 211251},
	{"DANGERMOUSE", 11, 211252},
	{"STUDING", 7, 211253},
	{"TAKIMATA", 8, 211254},
	{"YRTH", 4, 211255},
	{"XWES", 4, 211256},
	{"XMID", 4, 211257},
	{"WAZS", 4, 211258},
	{"VMOR", 4, 211259},
	{"VIWI", 4, 211260},
	{"UIZB", 4, 211261},
	{"UGDU", 4, 211262},
	{"UFUR", 4, 211263},
	{"TUED", 4, 211264},
	{"TOCW", 4, 211265},
	{"SRFO", 4, 211266},
	{"SKEC", 4, 211267},
	{"SDJS", 4, 211268},
	{"RJIG", 4, 211269},
	{"RFSO", 4, 211270},
	{"PPEV", 4, 211271},
	{"PEPB", 4, 211272},
	{"NPEK", 4, 211273},
	{"MNYO", 4, 211274},
	{"MDIP", 4, 211275},
	{"LZAM", 4, 211276},
	{"LTUL", 4, 211277},
	{"LAPG", 4, 211278},
	{"LAIZ", 4, 211279},
	{"KUPK", 4, 211280},
	{"KEUT", 4, 211281},
	{"JAWW", 4, 211282},
	{"IRRD", 4, 211283},
	{"HAKM", 4, 211284},
	{"GRDE", 4, 211285},
	{"GKAH", 4, 211286},
	{"EVSL", 4, 211287},
	{"ELLZ", 4, 211288},
	{"EGOZ", 4, 211289},
	{"CFAU", 4, 211290},
	{"BULD", 4, 211291},
	{"AUGN", 4, 211292},
	{"ATKW", 4, 211293},
	{"ASZU", 4, 211294},
	{"TENPIN", 6, 211295},
	{"SIRMIONE", 8, 211296},
	{"DALARAN", 7, 211297},
	{"BURAN", 5, 211298},
	{"SUMMAND", 7, 211299},
	{"DUBLINER", 8, 211300},
	{"UYGHURCHE", 9, 211301},
	{"DORTCH", 6, 211302},
	{"TRUESDALE", 9, 211303},
	{"OTOSCOPE", 8, 211304},
	{"NEWGRANGE", 9, 211305},
	{"GETLENGTH", 9, 211306},
	{"SCHRODERS", 9, 211307},
	{"MEDIRATTA", 9, 211308},
	{"PARMIGIANA", 10, 211309},
	{"OPINIO", 6, 211310},
	{"EQUIPOISE", 9, 211311},
	{"ELEKTROTECHNIK", 14, 211312},
	{"WILSONIAN", 9, 211313},
	{"GUNSTAR", 7, 211314},
	{"FLOKATI", 7, 211315},
	{"ASKAR", 5, 211316},
	{"WAQT", 4, 211317},
	{"MACES", 5, 211318},
	{"CARIDAD", 7, 211319},
	{"ARELIS", 6, 211320},
	{"TOOLSETS", 8, 211321},
	{"MCKIBBIN", 8, 211322},
	{"LIPPO", 5, 211323},
	{"JCCC", 4, 211324},
	{"TSUGA", 5, 211325},
	{"WERC", 4, 211326},
	{"TELDEC", 6, 211327},
	{"SUICIDALITY", 11, 211328},
	{"NICKING", 7, 211329},
	{"IBCS", 4, 211330},
	{"DEBAUCHED", 9, 211331},
	{"SKOLE", 5, 211332},
	{"CHATTERIS", 9, 211333},
	{"TCPD", 4, 211334},
	{"DOUTE", 5, 211335},
	{"PRECISIONS", 10, 211336},
	{"TACKER", 6, 211337},
	{"SPITALFIELD", 11, 211338},
	{"SNORTS", 6, 211339},
	{"DUCKWEED", 8, 211340},
	{"PICHURES", 8, 211341},
	{"NAWAIWAQT", 9, 211342},
	{"MALHAVOC", 8, 211343},
	{"GLYCOLIPIDS", 11, 211344},
	{"ALMENO", 6, 211345},
	{"PARLONS", 7, 211346},
	{"HOYLAKE", 7, 211347},
	{"BLOGCHALK", 9, 211348},
	{"SEPULCHER", 9, 211349},
	{"INDUSTRYPLASTICS", 16, 211350},
	{"NONFREE", 7, 211351},
	{"TTFF", 4, 211352},
	{"HYPOCALCEMIA", 12, 211353},
	{"BEHCET", 6, 211354},
	{"SUMRALL", 7, 211355},
	{"RAIMUND", 7, 211356},
	{"GALESVILLE", 10, 211357},
	{"DJVULIBRE", 9, 211358},
	{"TRIAN", 5, 211359},
	{"SUCTIONING", 10, 211360},
	{"REGISTRATO", 10, 211361},
	{"TRANSPUTER", 10, 211362},
	{"MYSIC", 5, 211363},
	{"JUCO", 4, 211364},
	{"BOOQ", 4, 211365},
	{"TRANSFIG", 8, 211366},
	{"LAAKSO", 6, 211367},
	{"VALLONE", 7, 211368},
	{"RELAZIONI", 9, 211369},
	{"FARROWING", 9, 211370},
	{"MANNINGHAM", 10, 211371},
	{"LOQUACIOUS", 10, 211372},
	{"LIMITADA", 8, 211373},
	{"REBRAND", 7, 211374},
	{"PORZO", 5, 211375},
	{"FLUBS", 5, 211376},
	{"PCMALL", 6, 211377},
	{"MERCANTILISM", 12, 211378},
	{"BUTTONDOWN", 10, 211379},
	{"ARCANGELO", 9, 211380},
	{"OVERIJSSEL", 10, 211381},
	{"FALS", 4, 211382},
	{"QCOM", 4, 211383},
	{"IDOG", 4, 211384},
	{"UNDISCOUNTED", 12, 211385},
	{"SIENKIEWICZ", 11, 211386},
	{"ADUNLAP", 7, 211387},
	{"VORE", 4, 211388},
	{"CRAGHOPPERS", 11, 211389},
	{"RAYTRACING", 10, 211390},
	{"MARUBENI", 8, 211391},
	{"LANETT", 6, 211392},
	{"BOGA", 4, 211393},
	{"PASTORATE", 9, 211394},
	{"YACUTE", 6, 211395},
	{"XBAI", 4, 211396},
	{"EUPHEMISTICALLY", 15, 211397},
	{"CLOR", 4, 211398},
	{"PINJARRA", 8, 211399},
	{"OMORI", 5, 211400},
	{"GUBERGREN", 9, 211401},
	{"INSURAN", 7, 211402},
	{"ACDBHATCH", 9, 211403},
	{"PANDY", 5, 211404},
	{"NEWSTARGET", 10, 211405},
	{"PFORZHEIM", 9, 211406},
	{"SOTOGRANDE", 10, 211407},
	{"PAYO", 4, 211408},
	{"TRAMDOL", 7, 211409},
	{"PRESSTIME", 9, 211410},
	{"PIVOTTABLE", 10, 211411},
	{"OVERLINE", 8, 211412},
	{"VENUSIAN", 8, 211413},
	{"MINIC", 5, 211414},
	{"ALLENSTOWN", 10, 211415},
	{"VASOPRO", 7, 211416},
	{"THROU", 5, 211417},
	{"PAPANICOLAOU", 12, 211418},
	{"HEIDT", 5, 211419},
	{"DERYCK", 6, 211420},
	{"SERGERS", 7, 211421},
	{"REGLAN", 6, 211422},
	{"NBCI", 4, 211423},
	{"FLURBIPROFEN", 12, 211424},
	{"ZAZIE", 5, 211425},
	{"UNREG", 5, 211426},
	{"SAADA", 5, 211427},
	{"HOTBARS", 7, 211428},
	{"COLDSPRING", 10, 211429},
	{"PRORODEO", 8, 211430},
	{"PHTHALOCYANINE", 14, 211431},
	{"INTESTINALIS", 12, 211432},
	{"ECHOICE", 7, 211433},
	{"YOND", 4, 211434},
	{"FRUMPY", 6, 211435},
	{"CHONDRITE", 9, 211436},
	{"SATER", 5, 211437},
	{"PTERODACTYL", 11, 211438},
	{"GUPPI", 5, 211439},
	{"SANBORNTON", 10, 211440},
	{"KENNON", 6, 211441},
	{"ZJUS", 4, 211442},
	{"ZEDQ", 4, 211443},
	{"ZAZZ", 4, 211444},
	{"WWFT", 4, 211445},
	{"WWCI", 4, 211446},
	{"WTIL", 4, 211447},
	{"VLIG", 4, 211448},
	{"VHAR", 4, 211449},
	{"UYCL", 4, 211450},
	{"UQIN", 4, 211451},
	{"TDRD", 4, 211452},
	{"SUIW", 4, 211453},
	{"SIPW", 4, 211454},
	{"SDPE", 4, 211455},
	{"ROAV", 4, 211456},
	{"QISC", 4, 211457},
	{"PECM", 4, 211458},
	{"ODUO", 4, 211459},
	{"NJRT", 4, 211460},
	{"NGYB", 4, 211461},
	{"MEEB", 4, 211462},
	{"MCUN", 4, 211463},
	{"LWIG", 4, 211464},
	{"LKCU", 4, 211465},
	{"LITQ", 4, 211466},
	{"LIAY", 4, 211467},
	{"KMPE", 4, 211468},
	{"IYOG", 4, 211469},
	{"ITKU", 4, 211470},
	{"GSSK", 4, 211471},
	{"FTSQ", 4, 211472},
	{"FTEQ", 4, 211473},
	{"FJAD", 4, 211474},
	{"FDAK", 4, 211475},
	{"EYPT", 4, 211476},
	{"EXMM", 4, 211477},
	{"ESCG", 4, 211478},
	{"EFHR", 4, 211479},
	{"EBSL", 4, 211480},
	{"EBRS", 4, 211481},
	{"DUWI", 4, 211482},
	{"BHAP", 4, 211483},
	{"AZOF", 4, 211484},
	{"AXVI", 4, 211485},
	{"ARFH", 4, 211486},
	{"AGHC", 4, 211487},
	{"EBBETS", 6, 211488},
	{"BOUTWELL", 8, 211489},
	{"COCON", 5, 211490},
	{"EDIFICIOS", 9, 211491},
	{"TIRAN", 5, 211492},
	{"STRIATE", 7, 211493},
	{"GPZ", 3, 211494},
	{"SALIBA", 6, 211495},
	{"LINUXELECTRONS", 14, 211496},
	{"CULLOMPTON", 10, 211497},
	{"PRELUTSKY", 9, 211498},
	{"MODELLEN", 8, 211499},
	{"MAROMA", 6, 211500},
	{"ELCS", 4, 211501},
	{"CADENHEAD", 9, 211502},
	{"JKJ", 3, 211503},
	{"INCUNABULA", 10, 211504},
	{"FCHAIN", 6, 211505},
	{"REINSERTED", 10, 211506},
	{"MONSTERSHOP", 11, 211507},
	{"LIMAPAGES", 9, 211508},
	{"ZINDAGI", 7, 211509},
	{"HPCS", 4, 211510},
	{"COLDHARBOUR", 11, 211511},
	{"NUNLEY", 6, 211512},
	{"KAPOW", 5, 211513},
	{"POMERON", 7, 211514},
	{"NPWJ", 4, 211515},
	{"IMATERNITY", 10, 211516},
	{"TELENOVELA", 10, 211517},
	{"RATABLY", 7, 211518},
	{"OFICE", 5, 211519},
	{"COCKERILL", 9, 211520},
	{"WHITESIDES", 10, 211521},
	{"AFTERS", 6, 211522},
	{"GYSYLLTU", 8, 211523},
	{"UNEXCITING", 10, 211524},
	{"GSCHEM", 6, 211525},
	{"REGGS", 5, 211526},
	{"DISPLEASING", 11, 211527},
	{"DEFLECTA", 8, 211528},
	{"ALEGA", 5, 211529},
	{"MUYBRIDGE", 9, 211530},
	{"BULDING", 7, 211531},
	{"AUFREGUNG", 9, 211532},
	{"THINLINE", 8, 211533},
	{"INTRUSTED", 9, 211534},
	{"CARMO", 5, 211535},
	{"VELAR", 5, 211536},
	{"SHALLOTTE", 9, 211537},
	{"PROJECTX", 8, 211538},
	{"DAHLEN", 6, 211539},
	{"HANYA", 5, 211540},
	{"PRUDISH", 7, 211541},
	{"PENTAGONAL", 10, 211542},
	{"BAUDETTE", 8, 211543},
	{"MYFORECAST", 10, 211544},
	{"LEAVELL", 7, 211545},
	{"CONFOUNDERS", 11, 211546},
	{"PELTING", 7, 211547},
	{"DEXTROUS", 8, 211548},
	{"LORG", 4, 211549},
	{"INFANTILES", 10, 211550},
	{"DILYN", 5, 211551},
	{"DATAVIDEO", 9, 211552},
	{"ELFYN", 5, 211553},
	{"BREESY", 6, 211554},
	{"FRIEN", 5, 211555},
	{"BEVINGTON", 9, 211556},
	{"REGOLE", 6, 211557},
	{"FRANSENR", 8, 211558},
	{"DRIZZLING", 9, 211559},
	{"TTANEXTSIBLING", 14, 211560},
	{"RAZLOG", 6, 211561},
	{"HATORAH", 7, 211562},
	{"CINQUEFOIL", 10, 211563},
	{"PROUDHON", 8, 211564},
	{"GUGGUL", 6, 211565},
	{"ACCIONES", 8, 211566},
	{"XPL", 3, 211567},
	{"TROGIR", 6, 211568},
	{"WEITEREMPFEHLEN", 15, 211569},
	{"WAKELY", 6, 211570},
	{"GLOBOROTALIA", 12, 211571},
	{"FITHIAN", 7, 211572},
	{"SOOTHINGLY", 10, 211573},
	{"NOCAT", 5, 211574},
	{"BANGO", 5, 211575},
	{"SUGARPLUM", 9, 211576},
	{"SEQTPA", 6, 211577},
	{"ATTENZIONE", 10, 211578},
	{"ARANG", 5, 211579},
	{"STROOD", 6, 211580},
	{"NMBD", 4, 211581},
	{"SERDAR", 6, 211582},
	{"ADDIDAS", 7, 211583},
	{"ANDREASTERBINI", 14, 211584},
	{"ADELINA", 7, 211585},
	{"SUBPROCESSES", 12, 211586},
	{"HARTA", 5, 211587},
	{"TOUCHSTONES", 11, 211588},
	{"BATTERYINTEGRATED", 17, 211589},
	{"BLACKSHAW", 9, 211590},
	{"WAYFARERS", 9, 211591},
	{"FRAIN", 5, 211592},
	{"SHOVELED", 8, 211593},
	{"NETZMARKT", 9, 211594},
	{"TRISTEZA", 8, 211595},
	{"CENTRALR", 8, 211596},
	{"ENGLANDERS", 10, 211597},
	{"CSRWIRE", 7, 211598},
	{"MICHX", 5, 211599},
	{"TRANSMAP", 8, 211600},
	{"NOCLEGI", 7, 211601},
	{"EMCC", 4, 211602},
	{"VIZCAINO", 8, 211603},
	{"CASADEI", 7, 211604},
	{"TORTUE", 6, 211605},
	{"DDAVP", 5, 211606},
	{"SURFMAGIC", 9, 211607},
	{"CONCESSIONE", 11, 211608},
	{"STUCKY", 6, 211609},
	{"TESSERACT", 9, 211610},
	{"MOGLEN", 6, 211611},
	{"MORPHEUX", 8, 211612},
	{"CAPALDI", 7, 211613},
	{"LIBGIMP", 7, 211614},
	{"TURRALL", 7, 211615},
	{"DRILLDOWN", 9, 211616},
	{"MAWS", 4, 211617},
	{"LAQUER", 6, 211618},
	{"EASTPOINT", 9, 211619},
	{"BAILER", 6, 211620},
	{"FLOUTED", 7, 211621},
	{"CIDS", 4, 211622},
	{"STRENESSE", 9, 211623},
	{"OBSAH", 5, 211624},
	{"CINNABON", 8, 211625},
	{"STRATHAVEN", 10, 211626},
	{"CHILLINGLY", 10, 211627},
	{"NONPROFESSIONAL", 15, 211628},
	{"ASSMAN", 6, 211629},
	{"BANDARA", 7, 211630},
	{"NUVI", 4, 211631},
	{"YOAD", 4, 211632},
	{"XYOF", 4, 211633},
	{"WBYL", 4, 211634},
	{"VBAL", 4, 211635},
	{"UODR", 4, 211636},
	{"RRSH", 4, 211637},
	{"PRFO", 4, 211638},
	{"OUJE", 4, 211639},
	{"OLBW", 4, 211640},
	{"OFUW", 4, 211641},
	{"NEVR", 4, 211642},
	{"MMCN", 4, 211643},
	{"KOZH", 4, 211644},
	{"HKOM", 4, 211645},
	{"HGEL", 4, 211646},
	{"HAJD", 4, 211647},
	{"GSKO", 4, 211648},
	{"GJIE", 4, 211649},
	{"GGYG", 4, 211650},
	{"GCDS", 4, 211651},
	{"FSDA", 4, 211652},
	{"ETVG", 4, 211653},
	{"ERZW", 4, 211654},
	{"DUJA", 4, 211655},
	{"ATZB", 4, 211656},
	{"ANXP", 4, 211657},
	{"AMNP", 4, 211658},
	{"XSPF", 4, 211659},
	{"GIRON", 5, 211660},
	{"CAPERCAILLIE", 12, 211661},
	{"OAKFORD", 7, 211662},
	{"GERSHMAN", 8, 211663},
	{"CINFO", 5, 211664},
	{"ZELLA", 5, 211665},
	{"FOSSETT", 7, 211666},
	{"AHRB", 4, 211667},
	{"LATOURETTE", 10, 211668},
	{"ALVERNIA", 8, 211669},
	{"BIKED", 5, 211670},
	{"WORTHIES", 8, 211671},
	{"LIEBOWITZ", 9, 211672},
	{"NISHIO", 6, 211673},
	{"MARTH", 5, 211674},
	{"AEROJET", 7, 211675},
	{"COURTESANS", 10, 211676},
	{"CONCS", 5, 211677},
	{"POWERARCHIVER", 13, 211678},
	{"STRADALI", 8, 211679},
	{"HEAVENWARD", 10, 211680},
	{"AGENTX", 6, 211681},
	{"SHAPLEIGH", 9, 211682},
	{"LAYPEOPLE", 9, 211683},
	{"GROKKING", 8, 211684},
	{"THEODORIC", 9, 211685},
	{"MSDICT", 6, 211686},
	{"DOLEV", 5, 211687},
	{"LEOPARDSTOWN", 12, 211688},
	{"INDOCTRINATE", 12, 211689},
	{"BOHANAN", 7, 211690},
	{"WOTW", 4, 211691},
	{"JEWLICIOUS", 10, 211692},
	{"BARRELLED", 9, 211693},
	{"SUNYAC", 6, 211694},
	{"SPORTWAGON", 10, 211695},
	{"MEGET", 5, 211696},
	{"FLINSTONE", 9, 211697},
	{"ONDAS", 5, 211698},
	{"SUBMASTER", 9, 211699},
	{"WALSHE", 6, 211700},
	{"CGGGA", 5, 211701},
	{"REMSAINT", 8, 211702},
	{"LIVESCORE", 9, 211703},
	{"LAFRAMBOISE", 11, 211704},
	{"NATFHE", 6, 211705},
	{"TOUCANS", 7, 211706},
	{"MANNVILLE", 9, 211707},
	{"GREENLINE", 9, 211708},
	{"COLORGRAPHICS", 13, 211709},
	{"BLAKLEY", 7, 211710},
	{"ENDRIN", 6, 211711},
	{"COLLIGAN", 8, 211712},
	{"CHELY", 5, 211713},
	{"APPLICATIO", 10, 211714},
	{"ZECHEEZIE", 9, 211715},
	{"TILLINGHAST", 11, 211716},
	{"GRETL", 5, 211717},
	{"UPLINE", 6, 211718},
	{"TORTFEASOR", 10, 211719},
	{"HEMIASCOMYCETES", 15, 211720},
	{"WESER", 5, 211721},
	{"SMEETS", 6, 211722},
	{"BHMA", 4, 211723},
	{"COUGAAR", 7, 211724},
	{"VERNOR", 6, 211725},
	{"PCLINUXONLINE", 13, 211726},
	{"PYRIDYL", 7, 211727},
	{"MASAYOSHI", 9, 211728},
	{"YOHKO", 5, 211729},
	{"CHEWABLES", 9, 211730},
	{"BONDWELL", 8, 211731},
	{"ZEPH", 4, 211732},
	{"PROPLE", 6, 211733},
	{"RNUM", 4, 211734},
	{"CHISCO", 6, 211735},
	{"CHARMIAN", 8, 211736},
	{"BARKLY", 6, 211737},
	{"FINANZE", 7, 211738},
	{"BODEANS", 7, 211739},
	{"EROOM", 5, 211740},
	{"HOHOKAM", 7, 211741},
	{"CLEAVELAND", 10, 211742},
	{"BRITNEYS", 8, 211743},
	{"WARKANOID", 9, 211744},
	{"TLIST", 5, 211745},
	{"POSTMARKETING", 13, 211746},
	{"FALLIBILITY", 11, 211747},
	{"COSSETTE", 8, 211748},
	{"SHURTRAX", 8, 211749},
	{"SHEDSTORE", 9, 211750},
	{"REEXAMINING", 11, 211751},
	{"IRRELEVENT", 10, 211752},
	{"GEMMY", 5, 211753},
	{"PETSC", 5, 211754},
	{"FFDCA", 5, 211755},
	{"FRANGLO", 7, 211756},
	{"AFFRAID", 7, 211757},
	{"SCARIFICATION", 13, 211758},
	{"NAKAHARA", 8, 211759},
	{"KENNITH", 7, 211760},
	{"DISCOID", 7, 211761},
	{"BEZIT", 5, 211762},
	{"WHATTA", 6, 211763},
	{"AMPHIPHILIC", 11, 211764},
	{"SHUICHI", 7, 211765},
	{"BPDUS", 5, 211766},
	{"ALEXANDERPLATZ", 14, 211767},
	{"SAMPAIO", 7, 211768},
	{"PERR", 4, 211769},
	{"KNUCKLEDUSTER", 13, 211770},
	{"USTEDES", 7, 211771},
	{"PIKAONE", 7, 211772},
	{"INTRACARDIAC", 12, 211773},
	{"EXHILARATED", 11, 211774},
	{"BRAMBILLA", 9, 211775},
	{"STOMPSOFT", 9, 211776},
	{"GAERTNER", 8, 211777},
	{"COMPNAY", 7, 211778},
	{"IDEOGRAPHIC", 11, 211779},
	{"GADUS", 5, 211780},
	{"HALAS", 5, 211781},
	{"SIGNEDDATA", 10, 211782},
	{"PHALABORWA", 10, 211783},
	{"DABO", 4, 211784},
	{"CLOPTON", 7, 211785},
	{"CELSUS", 6, 211786},
	{"TESTEN", 6, 211787},
	{"VALEDICTORY", 11, 211788},
	{"PROFANITIES", 11, 211789},
	{"BWYSIG", 6, 211790},
	{"INFORAMTION", 11, 211791},
	{"ECONOMIZER", 10, 211792},
	{"NEWSMONSTER", 11, 211793},
	{"SHIZNIT", 7, 211794},
	{"SWICK", 5, 211795},
	{"GUNITE", 6, 211796},
	{"ELLIN", 5, 211797},
	{"LINKSET", 7, 211798},
	{"PHTML", 5, 211799},
	{"OSIER", 5, 211800},
	{"BERTOLA", 7, 211801},
	{"ACORDES", 7, 211802},
	{"SKOOKUMCHUCK", 12, 211803},
	{"IDENTIDAD", 9, 211804},
	{"CLASSCASTEXCEPTION", 18, 211805},
	{"ZKOA", 4, 211806},
	{"ZIPT", 4, 211807},
	{"YBAM", 4, 211808},
	{"YABN", 4, 211809},
	{"XCRA", 4, 211810},
	{"WYNW", 4, 211811},
	{"USRS", 4, 211812},
	{"UOLU", 4, 211813},
	{"TODB", 4, 211814},
	{"THLB", 4, 211815},
	{"ROZY", 4, 211816},
	{"RLCD", 4, 211817},
	{"RBDI", 4, 211818},
	{"PTBI", 4, 211819},
	{"PMYB", 4, 211820},
	{"OWJI", 4, 211821},
	{"OPMR", 4, 211822},
	{"NYKU", 4, 211823},
	{"NWAP", 4, 211824},
	{"NGGN", 4, 211825},
	{"NCUD", 4, 211826},
	{"IXOC", 4, 211827},
	{"IUDE", 4, 211828},
	{"HUKC", 4, 211829},
	{"GOLP", 4, 211830},
	{"EPJI", 4, 211831},
	{"DMCP", 4, 211832},
	{"DKAV", 4, 211833},
	{"COVY", 4, 211834},
	{"BYKM", 4, 211835},
	{"AZEK", 4, 211836},
	{"ATGC", 4, 211837},
	{"ADRW", 4, 211838},
	{"ACIB", 4, 211839},
	{"GUESTWORLD", 10, 211840},
	{"AEROLINEAS", 10, 211841},
	{"BUNTINGFORD", 11, 211842},
	{"AHLERS", 6, 211843},
	{"TREVISAN", 8, 211844},
	{"SHABBA", 6, 211845},
	{"PIENAAR", 7, 211846},
	{"HOMESCAPE", 9, 211847},
	{"HEELING", 7, 211848},
	{"ECOCYC", 6, 211849},
	{"SUSPERIA", 8, 211850},
	{"QAPPLICATION", 12, 211851},
	{"ELLINIKA", 8, 211852},
	{"ANEXTEK", 7, 211853},
	{"ZYTEL", 5, 211854},
	{"AUROSHIKHA", 10, 211855},
	{"MEDREADER", 9, 211856},
	{"HUMANI", 6, 211857},
	{"WINTERIZE", 9, 211858},
	{"MUDIE", 5, 211859},
	{"MASPIRO", 7, 211860},
	{"LATVIANS", 8, 211861},
	{"PRIAPISM", 8, 211862},
	{"LAVERN", 6, 211863},
	{"EIMERIA", 7, 211864},
	{"COLORSTIX", 9, 211865},
	{"MERSON", 6, 211866},
	{"VISUALIZES", 10, 211867},
	{"ALMADA", 6, 211868},
	{"SERDEV", 6, 211869},
	{"ANTIMALARIALS", 13, 211870},
	{"POKO", 4, 211871},
	{"OATLANDS", 8, 211872},
	{"ANSICHT", 7, 211873},
	{"USHL", 4, 211874},
	{"MUSIV", 5, 211875},
	{"SHOEGAZING", 10, 211876},
	{"BEVIER", 6, 211877},
	{"LCDTV", 5, 211878},
	{"GREHAN", 6, 211879},
	{"SAWZALL", 7, 211880},
	{"KDYH", 4, 211881},
	{"VUONG", 5, 211882},
	{"JOSEFA", 6, 211883},
	{"ULEN", 4, 211884},
	{"TAVERNER", 8, 211885},
	{"CARFINDER", 9, 211886},
	{"KONDRACKE", 9, 211887},
	{"GCV", 3, 211888},
	{"CLANKING", 8, 211889},
	{"CARDON", 6, 211890},
	{"BUTTONCONTACT", 13, 211891},
	{"SOCCORSO", 8, 211892},
	{"SINAL", 5, 211893},
	{"SCUSE", 5, 211894},
	{"RAGAZZO", 7, 211895},
	{"BROADLAND", 9, 211896},
	{"MULTISESSION", 12, 211897},
	{"MUHLY", 5, 211898},
	{"OBLIGATING", 10, 211899},
	{"MOBITEL", 7, 211900},
	{"REPUGNANCE", 10, 211901},
	{"INSULATIONS", 11, 211902},
	{"GARVINHICKING", 13, 211903},
	{"MYANCHOR", 8, 211904},
	{"IEARN", 5, 211905},
	{"ABSORBAID", 9, 211906},
	{"WHOULD", 6, 211907},
	{"HOLMWOOD", 8, 211908},
	{"ROADER", 6, 211909},
	{"MKSTEMP", 7, 211910},
	{"DEMURRAGE", 9, 211911},
	{"KREVIAZUK", 9, 211912},
	{"JOYLESS", 7, 211913},
	{"FASCICULARIS", 12, 211914},
	{"EXPRESSIVITY", 12, 211915},
	{"DIAPORAMA", 9, 211916},
	{"YOUNES", 6, 211917},
	{"MWL", 3, 211918},
	{"LAVEEN", 6, 211919},
	{"COMPONETS", 9, 211920},
	{"AUBA", 4, 211921},
	{"FIZZLES", 7, 211922},
	{"AIKENS", 6, 211923},
	{"PAINTBOX", 8, 211924},
	{"OPLER", 5, 211925},
	{"MYELOPATHY", 10, 211926},
	{"BARABBAS", 8, 211927},
	{"ANTONIE", 7, 211928},
	{"HTMLELEMENT", 11, 211929},
	{"BIZZARRE", 8, 211930},
	{"EABISIM", 7, 211931},
	{"CHRISTELLE", 10, 211932},
	{"TRADEWIND", 9, 211933},
	{"EDUPRESS", 8, 211934},
	{"TURRENTINE", 10, 211935},
	{"SPQR", 4, 211936},
	{"ISMAILI", 7, 211937},
	{"GMAES", 5, 211938},
	{"COTTONDALE", 10, 211939},
	{"LORRAIN", 7, 211940},
	{"TILBROOK", 8, 211941},
	{"CHERNOV", 7, 211942},
	{"VRG", 3, 211943},
	{"NEOMAIL", 7, 211944},
	{"EXECRABLE", 9, 211945},
	{"CAJINJOHN", 9, 211946},
	{"FELSIC", 6, 211947},
	{"ALLIEN", 6, 211948},
	{"IMAGESIZE", 9, 211949},
	{"ESTELA", 6, 211950},
	{"LIFESTREAM", 10, 211951},
	{"LASKOWSKI", 9, 211952},
	{"BROCKETT", 8, 211953},
	{"XSTRATA", 7, 211954},
	{"COLINDALE", 9, 211955},
	{"BINDU", 5, 211956},
	{"LUCREZIA", 8, 211957},
	{"MONIA", 5, 211958},
	{"ENCEPHALOPATHIES", 16, 211959},
	{"POTENTIATES", 11, 211960},
	{"PEROXISOMES", 11, 211961},
	{"MONTIGNY", 8, 211962},
	{"TECHO", 5, 211963},
	{"BREEZEWOOD", 10, 211964},
	{"CONCEPTUALISED", 14, 211965},
	{"HAWKSLEY", 8, 211966},
	{"AMPEZZO", 7, 211967},
	{"KHANG", 5, 211968},
	{"SCLUG", 5, 211969},
	{"CIIP", 4, 211970},
	{"YOUNGTOWN", 9, 211971},
	{"TAMADOL", 7, 211972},
	{"LOFTIER", 7, 211973},
	{"SODOMISATION", 12, 211974},
	{"SALAIRES", 8, 211975},
	{"KUNTH", 5, 211976},
	{"VERWOOD", 7, 211977},
	{"MOBILIS", 7, 211978},
	{"MACDAILYNEWS", 12, 211979},
	{"KARLI", 5, 211980},
	{"STOLID", 6, 211981},
	{"SKEY", 4, 211982},
	{"GENIS", 5, 211983},
	{"SPEAKERPHONES", 13, 211984},
	{"KREATIVE", 8, 211985},
	{"CYBERWURX", 9, 211986},
	{"BEILIN", 6, 211987},
	{"GELBER", 6, 211988},
	{"RYBAK", 5, 211989},
	{"ZOMI", 4, 211990},
	{"ZKER", 4, 211991},
	{"ZFAN", 4, 211992},
	{"YUDE", 4, 211993},
	{"YBUO", 4, 211994},
	{"XSHU", 4, 211995},
	{"WOXF", 4, 211996},
	{"VSQU", 4, 211997},
	{"VDTO", 4, 211998},
	{"USZI", 4, 211999},
	{"UPOE", 4, 212000},
	{"UCFA", 4, 212001},
	{"TUCF", 4, 212002},
	{"TRSP", 4, 212003},
	{"TMCE", 4, 212004},
	{"SUTL", 4, 212005},
	{"RFSW", 4, 212006},
	{"PNDA", 4, 212007},
	{"NGPD", 4, 212008},
	{"MBKI", 4, 212009},
	{"LPMS", 4, 212010},
	{"LOKK", 4, 212011},
	{"LOKH", 4, 212012},
	{"LOJU", 4, 212013},
	{"KAYY", 4, 212014},
	{"ISGM", 4, 212015},
	{"HPOK", 4, 212016},
	{"HACY", 4, 212017},
	{"GMPR", 4, 212018},
	{"FESG", 4, 212019},
	{"ETDP", 4, 212020},
	{"DVOU", 4, 212021},
	{"DVOG", 4, 212022},
	{"DMCB", 4, 212023},
	{"CTXI", 4, 212024},
	{"CSJA", 4, 212025},
	{"CJSP", 4, 212026},
	{"CCSH", 4, 212027},
	{"BOAM", 4, 212028},
	{"BBOW", 4, 212029},
	{"AGOQ", 4, 212030},
	{"FORTIORI", 8, 212031},
	{"FEMP", 4, 212032},
	{"COFER", 5, 212033},
	{"HESTIA", 6, 212034},
	{"ACHOSION", 8, 212035},
	{"SINEMET", 7, 212036},
	{"CABINETMAKING", 13, 212037},
	{"AZERTY", 6, 212038},
	{"UNACQUAINTED", 12, 212039},
	{"TEEMS", 5, 212040},
	{"MACAROONS", 9, 212041},
	{"EROTHIK", 7, 212042},
	{"MANJULA", 7, 212043},
	{"QUEVEDO", 7, 212044},
	{"FLUVASTATIN", 11, 212045},
	{"FFV", 3, 212046},
	{"COMMENTORS", 10, 212047},
	{"AHIMA", 5, 212048},
	{"MARCELINE", 9, 212049},
	{"BULLFINCH", 9, 212050},
	{"MALCO", 5, 212051},
	{"KGDB", 4, 212052},
	{"SANDSTON", 8, 212053},
	{"ORDEREDLOCUSNAMES", 17, 212054},
	{"WILLMAN", 7, 212055},
	{"WADIA", 5, 212056},
	{"JEPSEN", 6, 212057},
	{"DOCSHOP", 7, 212058},
	{"SHIRDI", 6, 212059},
	{"KAWANO", 6, 212060},
	{"EARWIGS", 7, 212061},
	{"BASTARDIZED", 11, 212062},
	{"SOMALIAN", 8, 212063},
	{"MUSUC", 5, 212064},
	{"IRED", 4, 212065},
	{"HOMEWRECKER", 11, 212066},
	{"GRADEN", 6, 212067},
	{"PONTIFEX", 8, 212068},
	{"IIMAGE", 6, 212069},
	{"COMMEN", 6, 212070},
	{"KAUPAPA", 7, 212071},
	{"MUESTRAS", 8, 212072},
	{"LAUN", 4, 212073},
	{"SIMONIDES", 9, 212074},
	{"DANUTA", 6, 212075},
	{"BEAUPRE", 7, 212076},
	{"WOODCRAFTS", 10, 212077},
	{"MCCAUSLAND", 10, 212078},
	{"APID", 4, 212079},
	{"ROMMON", 6, 212080},
	{"POTWS", 5, 212081},
	{"OPORTUNIDAD", 11, 212082},
	{"AUCHTERARDER", 12, 212083},
	{"PAWING", 6, 212084},
	{"NYMPHAEA", 8, 212085},
	{"DELEVAN", 7, 212086},
	{"GRANDAUGHTER", 12, 212087},
	{"GAMELY", 6, 212088},
	{"FCV", 3, 212089},
	{"SHOPPINGSITE", 12, 212090},
	{"SAMBUCUS", 8, 212091},
	{"ABENAKI", 7, 212092},
	{"JOSEE", 5, 212093},
	{"LSCS", 4, 212094},
	{"KILOJOULES", 10, 212095},
	{"RETALIATING", 11, 212096},
	{"SLAVISHLY", 9, 212097},
	{"LAUNDROMATS", 11, 212098},
	{"GEOCHIMICA", 10, 212099},
	{"SARTELL", 7, 212100},
	{"PAWLET", 6, 212101},
	{"LEEDY", 5, 212102},
	{"HEFFRON", 7, 212103},
	{"CORGIS", 6, 212104},
	{"PYRAZINAMIDE", 12, 212105},
	{"ZHAOQING", 8, 212106},
	{"SUPRE", 5, 212107},
	{"QUEENSBERRY", 11, 212108},
	{"DRUMMOYNE", 9, 212109},
	{"PRICEMATCH", 10, 212110},
	{"MANDRELL", 8, 212111},
	{"APPOLOGIZE", 10, 212112},
	{"JAKUBOWSKI", 10, 212113},
	{"ETTERCAP", 8, 212114},
	{"LMAX", 4, 212115},
	{"CONDITIES", 9, 212116},
	{"IPVS", 4, 212117},
	{"BARILLA", 7, 212118},
	{"ACCESSORIOS", 11, 212119},
	{"KURYAKYN", 8, 212120},
	{"GREENWILLOW", 11, 212121},
	{"LINDSBORG", 9, 212122},
	{"KONFIGURATION", 13, 212123},
	{"FROELICH", 8, 212124},
	{"LEUCYL", 6, 212125},
	{"GISSING", 7, 212126},
	{"WILLETS", 7, 212127},
	{"OFFPRINTS", 9, 212128},
	{"WEATHERCITY", 11, 212129},
	{"MIZRACHI", 8, 212130},
	{"LAMMY", 5, 212131},
	{"CODEWEAVERS", 11, 212132},
	{"BEARDMORE", 9, 212133},
	{"UUDECODE", 8, 212134},
	{"BALCON", 6, 212135},
	{"PHENTERPRIN", 11, 212136},
	{"MULTIPLA", 8, 212137},
	{"LIPCOLOR", 8, 212138},
	{"VAIDYANATHAN", 12, 212139},
	{"TAHSIS", 6, 212140},
	{"CAPTIAL", 7, 212141},
	{"PATHFINDING", 11, 212142},
	{"ONTWERP", 7, 212143},
	{"MCAFFEE", 7, 212144},
	{"ASYNCHRONY", 10, 212145},
	{"MERR", 4, 212146},
	{"VISIGOTHS", 9, 212147},
	{"ANTHUS", 6, 212148},
	{"SAFLEOEDD", 9, 212149},
	{"RESTURAUNT", 10, 212150},
	{"ARRT", 4, 212151},
	{"UNACHIEVABLE", 12, 212152},
	{"SHEFC", 5, 212153},
	{"MANDRAGORA", 10, 212154},
	{"PETITIVE", 8, 212155},
	{"HOSFORD", 7, 212156},
	{"TRAMPOLINING", 12, 212157},
	{"QUEENSLANDER", 12, 212158},
	{"MISNAMED", 8, 212159},
	{"SCXI", 4, 212160},
	{"PLATTNER", 8, 212161},
	{"TROTSKYISM", 10, 212162},
	{"REHOMING", 8, 212163},
	{"SESSOGRATIS", 11, 212164},
	{"TAHER", 5, 212165},
	{"NASAR", 5, 212166},
	{"LEUPROLIDE", 10, 212167},
	{"DYSTROPHIC", 10, 212168},
	{"SENATOBIA", 9, 212169},
	{"MONKLAND", 8, 212170},
	{"ROEX", 4, 212171},
	{"LEASEHOLDER", 11, 212172},
	{"GKP", 3, 212173},
	{"ZELENKA", 7, 212174},
	{"TITTER", 6, 212175},
	{"ISVISIBLE", 9, 212176},
	{"CHINNED", 7, 212177},
	{"MILITATE", 8, 212178},
	{"BOSCHERT", 8, 212179},
	{"OTRANTO", 7, 212180},
	{"GOTEN", 5, 212181},
	{"SAHITYA", 7, 212182},
	{"BUBL", 4, 212183},
	{"BEDWELL", 7, 212184},
	{"CHANGO", 6, 212185},
	{"WEBALIAS", 8, 212186},
	{"NASBA", 5, 212187},
	{"DOLPHINMUSIC", 12, 212188},
	{"CONFLATED", 9, 212189},
	{"SIGERSON", 8, 212190},
	{"RINCEWIND", 9, 212191},
	{"MUTS", 4, 212192},
	{"VIRTUANEWS", 10, 212193},
	{"STORIS", 6, 212194},
	{"MAGNUMS", 7, 212195},
	{"LOGGA", 5, 212196},
	{"ISOBARS", 7, 212197},
	{"DBCODES", 7, 212198},
	{"PENTOXIFYLLINE", 14, 212199},
	{"ESCOVEDO", 8, 212200},
	{"ZTER", 4, 212201},
	{"ZEMB", 4, 212202},
	{"ZDAT", 4, 212203},
	{"YZAT", 4, 212204},
	{"XELW", 4, 212205},
	{"VUND", 4, 212206},
	{"URLL", 4, 212207},
	{"UETP", 4, 212208},
	{"UDPL", 4, 212209},
	{"SYKI", 4, 212210},
	{"SAPG", 4, 212211},
	{"RYUC", 4, 212212},
	{"RDND", 4, 212213},
	{"RCKC", 4, 212214},
	{"PHIZ", 4, 212215},
	{"PGOD", 4, 212216},
	{"ORUH", 4, 212217},
	{"ORBF", 4, 212218},
	{"OKIG", 4, 212219},
	{"NMOK", 4, 212220},
	{"MHZF", 4, 212221},
	{"MHEU", 4, 212222},
	{"MHAZ", 4, 212223},
	{"MECT", 4, 212224},
	{"MCDY", 4, 212225},
	{"MAMW", 4, 212226},
	{"LMEF", 4, 212227},
	{"KOLH", 4, 212228},
	{"KKOL", 4, 212229},
	{"JRCA", 4, 212230},
	{"JENC", 4, 212231},
	{"IZAG", 4, 212232},
	{"IXCU", 4, 212233},
	{"IVMA", 4, 212234},
	{"IMUD", 4, 212235},
	{"HUPU", 4, 212236},
	{"HSPY", 4, 212237},
	{"GYAI", 4, 212238},
	{"GSMD", 4, 212239},
	{"GAXE", 4, 212240},
	{"FLRO", 4, 212241},
	{"ENCW", 4, 212242},
	{"EJRI", 4, 212243},
	{"EFVA", 4, 212244},
	{"EDDP", 4, 212245},
	{"DJOV", 4, 212246},
	{"CFIC", 4, 212247},
	{"BRYT", 4, 212248},
	{"BPHO", 4, 212249},
	{"BBIH", 4, 212250},
	{"UNBEKANNT", 9, 212251},
	{"GREENZAP", 8, 212252},
	{"COLDSTONE", 9, 212253},
	{"PROCESSI", 8, 212254},
	{"HAMBRECHT", 9, 212255},
	{"UMSL", 4, 212256},
	{"NEFAC", 5, 212257},
	{"KONZE", 5, 212258},
	{"RENAU", 5, 212259},
	{"RAKUTEN", 7, 212260},
	{"MDNS", 4, 212261},
	{"AMLI", 4, 212262},
	{"ARTLIST", 7, 212263},
	{"SODIPODI", 8, 212264},
	{"BUSHWHACKED", 11, 212265},
	{"LOUVRES", 7, 212266},
	{"DARCEY", 6, 212267},
	{"NEWAVE", 6, 212268},
	{"INSTYMEDS", 9, 212269},
	{"LENSKI", 6, 212270},
	{"SEIBERG", 7, 212271},
	{"PARIVAR", 7, 212272},
	{"COMMODUS", 8, 212273},
	{"YOSHITAKA", 9, 212274},
	{"GUNNE", 5, 212275},
	{"FENNECUS", 8, 212276},
	{"SALZBURGER", 10, 212277},
	{"NAPPANEE", 8, 212278},
	{"PAQUETE", 7, 212279},
	{"MUAMMAR", 7, 212280},
	{"BANPRESTO", 9, 212281},
	{"DEFRAYING", 9, 212282},
	{"ASHAWAY", 7, 212283},
	{"VISITAR", 7, 212284},
	{"KTTV", 4, 212285},
	{"AXXESS", 6, 212286},
	{"TIRUCHIRAPALLI", 14, 212287},
	{"GOMI", 4, 212288},
	{"RECOMIENDO", 10, 212289},
	{"GEKAUFT", 7, 212290},
	{"FIRMWARES", 9, 212291},
	{"ETICHETTE", 9, 212292},
	{"EPCC", 4, 212293},
	{"WACKINESS", 9, 212294},
	{"RCSFILE", 7, 212295},
	{"KOLK", 4, 212296},
	{"FINGAZ", 6, 212297},
	{"STRAFING", 8, 212298},
	{"PALEOCLIMATOLOGY", 16, 212299},
	{"THEXTON", 7, 212300},
	{"PNBLOCKS", 8, 212301},
	{"AYANA", 5, 212302},
	{"GOGUEN", 6, 212303},
	{"GEEKDOM", 7, 212304},
	{"DAMEWARE", 8, 212305},
	{"COCCIDIOSIS", 11, 212306},
	{"AXING", 5, 212307},
	{"PRIVELEGES", 10, 212308},
	{"MONDES", 6, 212309},
	{"CHAINSET", 8, 212310},
	{"GIORGIA", 7, 212311},
	{"ADULTI", 6, 212312},
	{"NONGOVERNMENT", 13, 212313},
	{"CONNECTIO", 9, 212314},
	{"RIDGETOP", 8, 212315},
	{"CERTICOM", 8, 212316},
	{"BRADDON", 7, 212317},
	{"SKETCHER", 8, 212318},
	{"RICEVILLE", 9, 212319},
	{"POLARLAKE", 9, 212320},
	{"EUROBOYS", 8, 212321},
	{"CHLOROBENZENE", 13, 212322},
	{"SCHOTEL", 7, 212323},
	{"CHARLOT", 7, 212324},
	{"NCPS", 4, 212325},
	{"CONCERTMASTER", 13, 212326},
	{"WASMACHINE", 10, 212327},
	{"POLEWARD", 8, 212328},
	{"GUNNARSSON", 10, 212329},
	{"DUCTIVE", 7, 212330},
	{"ULOGD", 5, 212331},
	{"MERIVALE", 8, 212332},
	{"SAULS", 5, 212333},
	{"MSFN", 4, 212334},
	{"KUKLA", 5, 212335},
	{"DEIFIED", 7, 212336},
	{"SCHMOOZING", 10, 212337},
	{"HERZEGOVINIA", 12, 212338},
	{"DEONTIC", 7, 212339},
	{"MELVINA", 7, 212340},
	{"WRITERSUA", 9, 212341},
	{"OTOLITHS", 8, 212342},
	{"TRAVAL", 6, 212343},
	{"RPMBUILD", 8, 212344},
	{"PRICEMINISTER", 13, 212345},
	{"LODHI", 5, 212346},
	{"GRECIANS", 8, 212347},
	{"RETOOLED", 8, 212348},
	{"LEZZIE", 6, 212349},
	{"DCW", 3, 212350},
	{"INTELLEGENT", 11, 212351},
	{"COLONES", 7, 212352},
	{"WANTA", 5, 212353},
	{"IISTAR", 6, 212354},
	{"GEFORCEFX", 9, 212355},
	{"BOURGOIN", 8, 212356},
	{"MRTGAGE", 7, 212357},
	{"GGR", 3, 212358},
	{"SUBRECIPIENTS", 13, 212359},
	{"KITTSON", 7, 212360},
	{"RELATEDCHANGES", 14, 212361},
	{"PRINCEPS", 8, 212362},
	{"LARYNGOL", 8, 212363},
	{"XPERTHR", 7, 212364},
	{"NEELIX", 6, 212365},
	{"INTRACYTOPLASMIC", 16, 212366},
	{"DOWSON", 6, 212367},
	{"STEARMAN", 8, 212368},
	{"NIZZA", 5, 212369},
	{"PLEASANCE", 9, 212370},
	{"ESSENSE", 7, 212371},
	{"DOLF", 4, 212372},
	{"ORANA", 5, 212373},
	{"OENANTHE", 8, 212374},
	{"MONETARILY", 10, 212375},
	{"LEUCOCYTES", 10, 212376},
	{"EPISTEMOLOGIES", 14, 212377},
	{"COUNTIN", 7, 212378},
	{"IMMUNOELECTROPHORESIS", 21, 212379},
	{"DUSEN", 5, 212380},
	{"AEROMAGNETIC", 12, 212381},
	{"KEILY", 5, 212382},
	{"VODCAST", 7, 212383},
	{"SEDLEY", 6, 212384},
	{"WAKELIN", 7, 212385},
	{"PULSION", 7, 212386},
	{"PEACHEZ", 7, 212387},
	{"CODEPINK", 8, 212388},
	{"SPKRS", 5, 212389},
	{"DUELFER", 7, 212390},
	{"CANHAM", 6, 212391},
	{"ALAVES", 6, 212392},
	{"LATVISKS", 8, 212393},
	{"RATHORE", 7, 212394},
	{"SUMPTUOUSLY", 11, 212395},
	{"COPC", 4, 212396},
	{"RATU", 4, 212397},
	{"GUITARSITES", 11, 212398},
	{"EARTHLITE", 9, 212399},
	{"CLEARVUE", 8, 212400},
	{"ANTIPROLIFERATIVE", 17, 212401},
	{"NOOBIE", 6, 212402},
	{"SAMSUN", 6, 212403},
	{"DOWNTREND", 9, 212404},
	{"ZZYL", 4, 212405},
	{"ZTOD", 4, 212406},
	{"YIFG", 4, 212407},
	{"XIVI", 4, 212408},
	{"VOCT", 4, 212409},
	{"ULUF", 4, 212410},
	{"SVSB", 4, 212411},
	{"STYJ", 4, 212412},
	{"SBAW", 4, 212413},
	{"RZBA", 4, 212414},
	{"RLUL", 4, 212415},
	{"PPPE", 4, 212416},
	{"PMUP", 4, 212417},
	{"PKIR", 4, 212418},
	{"NPUC", 4, 212419},
	{"NLUO", 4, 212420},
	{"MTVM", 4, 212421},
	{"LRYL", 4, 212422},
	{"JUQU", 4, 212423},
	{"JOSF", 4, 212424},
	{"ILPP", 4, 212425},
	{"HLEQ", 4, 212426},
	{"HIVC", 4, 212427},
	{"GYUL", 4, 212428},
	{"GMEP", 4, 212429},
	{"FSUZ", 4, 212430},
	{"EVYE", 4, 212431},
	{"ERDQ", 4, 212432},
	{"EEYR", 4, 212433},
	{"EBSF", 4, 212434},
	{"DLMA", 4, 212435},
	{"CVIT", 4, 212436},
	{"CURH", 4, 212437},
	{"CODW", 4, 212438},
	{"CCUE", 4, 212439},
	{"BUES", 4, 212440},
	{"AUXL", 4, 212441},
	{"ANZK", 4, 212442},
	{"ALZU", 4, 212443},
	{"ABIJ", 4, 212444},
	{"LONDONBEST", 10, 212445},
	{"LABORATORYTALK", 14, 212446},
	{"PROPACK", 7, 212447},
	{"FONDREN", 7, 212448},
	{"FADL", 4, 212449},
	{"SPATH", 5, 212450},
	{"SEARCHHELP", 10, 212451},
	{"SNUFFER", 7, 212452},
	{"AQUASCAPE", 9, 212453},
	{"SKORTS", 6, 212454},
	{"ILLITERATES", 11, 212455},
	{"BREASTPUMP", 10, 212456},
	{"EVERYNIGHT", 10, 212457},
	{"EATABILITY", 10, 212458},
	{"TIARE", 5, 212459},
	{"GOOGLD", 6, 212460},
	{"EPIGRAPH", 8, 212461},
	{"TAWNEY", 6, 212462},
	{"OUTREBOUNDED", 12, 212463},
	{"NORDMARK", 8, 212464},
	{"UNEMOTIONAL", 11, 212465},
	{"NOURSE", 6, 212466},
	{"IFYOU", 5, 212467},
	{"LODINE", 6, 212468},
	{"AWBREY", 6, 212469},
	{"DESCRAMBLERS", 12, 212470},
	{"DBCONN", 6, 212471},
	{"RESURRECTS", 10, 212472},
	{"INSPECTORATES", 13, 212473},
	{"ANALS", 5, 212474},
	{"SWIMMINGLY", 10, 212475},
	{"KEEPN", 5, 212476},
	{"USUFRUCT", 8, 212477},
	{"SHOHAM", 6, 212478},
	{"SQLCONNECTION", 13, 212479},
	{"BETHKE", 6, 212480},
	{"IMAPS", 5, 212481},
	{"ALURIA", 6, 212482},
	{"JUTA", 4, 212483},
	{"METALHEADS", 10, 212484},
	{"FOLLIE", 6, 212485},
	{"COARSENESS", 10, 212486},
	{"CORIE", 5, 212487},
	{"BAHRI", 5, 212488},
	{"GALANIN", 7, 212489},
	{"TUOHY", 5, 212490},
	{"RESPIRATORIO", 12, 212491},
	{"DAULT", 5, 212492},
	{"BODMER", 6, 212493},
	{"SCEEN", 5, 212494},
	{"NEWSARAMA", 9, 212495},
	{"QUICKSTUDIES", 12, 212496},
	{"HAMMES", 6, 212497},
	{"ANDALESELL", 10, 212498},
	{"TOSATTI", 7, 212499},
	{"RIEF", 4, 212500},
	{"TEFF", 4, 212501},
	{"FEMENINA", 8, 212502},
	{"UNIVERSEL", 9, 212503},
	{"DEMULTIPLEXING", 14, 212504},
	{"URLENCODED", 10, 212505},
	{"BERGAN", 6, 212506},
	{"PERFORMAN", 9, 212507},
	{"NOTTM", 5, 212508},
	{"EXTERNALIZING", 13, 212509},
	{"AXIGN", 5, 212510},
	{"VITTLES", 7, 212511},
	{"BRUEGHEL", 8, 212512},
	{"ENORMES", 7, 212513},
	{"MWPS", 4, 212514},
	{"REDUCIBILITY", 12, 212515},
	{"NICOLETTI", 9, 212516},
	{"FLEECED", 7, 212517},
	{"EUROCENTRIC", 11, 212518},
	{"CONGRUENCES", 11, 212519},
	{"SIRIS", 5, 212520},
	{"IVWHAT", 6, 212521},
	{"PIEDI", 5, 212522},
	{"WEATHERSPOON", 12, 212523},
	{"PLUSDUNGEON", 11, 212524},
	{"CODEWOLF", 8, 212525},
	{"CHAPTERSCREATIVE", 16, 212526},
	{"AHPF", 4, 212527},
	{"MOTHERBOARDCALL", 15, 212528},
	{"KITFIFA", 7, 212529},
	{"GAMEPADFABLE", 12, 212530},
	{"FIREBUG", 7, 212531},
	{"AKTIE", 5, 212532},
	{"HEMERA", 6, 212533},
	{"BLUECAT", 7, 212534},
	{"GRAINES", 7, 212535},
	{"CONCHOS", 7, 212536},
	{"UNDERNUTRITION", 14, 212537},
	{"SEARCHWORD", 10, 212538},
	{"PRESENTAN", 9, 212539},
	{"CMND", 4, 212540},
	{"SIMPLICES", 9, 212541},
	{"YASUI", 5, 212542},
	{"COOKOUTS", 8, 212543},
	{"CONLANG", 7, 212544},
	{"SEVP", 4, 212545},
	{"ORLI", 4, 212546},
	{"MIYAJIMA", 8, 212547},
	{"DIALUPADMIN", 11, 212548},
	{"MARKETEER", 9, 212549},
	{"WINNFIELD", 9, 212550},
	{"POOPIE", 6, 212551},
	{"MORTGGE", 7, 212552},
	{"BROXTON", 7, 212553},
	{"AFTERBURN", 9, 212554},
	{"SABATINO", 8, 212555},
	{"ERYTHROPOIESIS", 14, 212556},
	{"KAITOS", 6, 212557},
	{"CRESTONE", 8, 212558},
	{"FLAMME", 6, 212559},
	{"DEAFBASE", 8, 212560},
	{"KIDSCOM", 7, 212561},
	{"ESSENTIALIST", 12, 212562},
	{"CZR", 3, 212563},
	{"COORPAROO", 9, 212564},
	{"ASSEGNO", 7, 212565},
	{"SPONDS", 6, 212566},
	{"GORLLEWIN", 9, 212567},
	{"GETTO", 5, 212568},
	{"LARRIVEE", 8, 212569},
	{"BIOINORGANIC", 12, 212570},
	{"PAEDIATRICIANS", 14, 212571},
	{"SUGARDVD", 8, 212572},
	{"ICLASSICS", 9, 212573},
	{"TASSOS", 6, 212574},
	{"NYTDIGITAL", 10, 212575},
	{"KENNECOTT", 9, 212576},
	{"SATIVUS", 7, 212577},
	{"TICLES", 6, 212578},
	{"SPRE", 4, 212579},
	{"RUCKMAN", 7, 212580},
	{"SENTINAL", 8, 212581},
	{"HILEYTECH", 9, 212582},
	{"AMARNA", 6, 212583},
	{"UCHAF", 5, 212584},
	{"RULERSHIP", 9, 212585},
	{"PETERSONS", 9, 212586},
	{"AUTUM", 5, 212587},
	{"NONBUSINESS", 11, 212588},
	{"RINNAI", 6, 212589},
	{"LOTENSIN", 8, 212590},
	{"DISPERSIBLE", 11, 212591},
	{"SORAT", 5, 212592},
	{"GPHOTO", 6, 212593},
	{"DIMI", 4, 212594},
	{"COMEDIA", 7, 212595},
	{"BEAMWIDTH", 9, 212596},
	{"XICO", 4, 212597},
	{"VIDYALAYA", 9, 212598},
	{"VRAIN", 5, 212599},
	{"VILKET", 6, 212600},
	{"RECHENZENTRUM", 13, 212601},
	{"PIGGYBACKING", 12, 212602},
	{"ICMR", 4, 212603},
	{"CONCHOLOGY", 10, 212604},
	{"ASHURA", 6, 212605},
	{"MYCIN", 5, 212606},
	{"LEUKE", 5, 212607},
	{"KEYW", 4, 212608},
	{"AUDITEE", 7, 212609},
	{"BLANKETING", 10, 212610},
	{"HYDROPHONE", 10, 212611},
	{"ZYBA", 4, 212612},
	{"ZRAC", 4, 212613},
	{"YNJA", 4, 212614},
	{"YMCP", 4, 212615},
	{"YMCE", 4, 212616},
	{"WKHE", 4, 212617},
	{"WAUC", 4, 212618},
	{"VHOL", 4, 212619},
	{"UPIV", 4, 212620},
	{"ULSG", 4, 212621},
	{"TURW", 4, 212622},
	{"TOJR", 4, 212623},
	{"RIBT", 4, 212624},
	{"RDYK", 4, 212625},
	{"PPGI", 4, 212626},
	{"OXYE", 4, 212627},
	{"OLFK", 4, 212628},
	{"NDYY", 4, 212629},
	{"NDLH", 4, 212630},
	{"MYMY", 4, 212631},
	{"LTYJ", 4, 212632},
	{"LSVS", 4, 212633},
	{"LMYN", 4, 212634},
	{"LDJR", 4, 212635},
	{"LALK", 4, 212636},
	{"KJAZ", 4, 212637},
	{"JERG", 4, 212638},
	{"IJRA", 4, 212639},
	{"HYIB", 4, 212640},
	{"HUMC", 4, 212641},
	{"HLSU", 4, 212642},
	{"HCAK", 4, 212643},
	{"GNYE", 4, 212644},
	{"GEYT", 4, 212645},
	{"GAIK", 4, 212646},
	{"FYUA", 4, 212647},
	{"EVBR", 4, 212648},
	{"EDDG", 4, 212649},
	{"DOXH", 4, 212650},
	{"DOEP", 4, 212651},
	{"DMEK", 4, 212652},
	{"DEGN", 4, 212653},
	{"ARUY", 4, 212654},
	{"KOZIOL", 6, 212655},
	{"TIERSEN", 7, 212656},
	{"GITTE", 5, 212657},
	{"DRYANOVO", 8, 212658},
	{"MGET", 4, 212659},
	{"SODOR", 5, 212660},
	{"PSMISC", 6, 212661},
	{"SELBER", 6, 212662},
	{"TOCCA", 5, 212663},
	{"KITTLE", 6, 212664},
	{"SHILDON", 7, 212665},
	{"MAESTRA", 7, 212666},
	{"VISIPRISE", 9, 212667},
	{"TAGGERS", 7, 212668},
	{"MONTFORD", 8, 212669},
	{"FLITTED", 7, 212670},
	{"ROOYEN", 6, 212671},
	{"CARZ", 4, 212672},
	{"YURA", 4, 212673},
	{"NDEBUG", 6, 212674},
	{"FACER", 5, 212675},
	{"ECOG", 4, 212676},
	{"CONSULATION", 11, 212677},
	{"RAMANUJA", 8, 212678},
	{"CAHPS", 5, 212679},
	{"SORBIAN", 7, 212680},
	{"CHISM", 5, 212681},
	{"RIBONUCLEASES", 13, 212682},
	{"PRECOGNITION", 12, 212683},
	{"GTHUMB", 6, 212684},
	{"FETICHISMO", 10, 212685},
	{"PERNOTTATO", 10, 212686},
	{"INTERMITTENCY", 13, 212687},
	{"ASCQ", 4, 212688},
	{"TRMADOL", 7, 212689},
	{"SOLFEGE", 7, 212690},
	{"BRORA", 5, 212691},
	{"GANTS", 5, 212692},
	{"DRAMATURGY", 10, 212693},
	{"WATCHE", 6, 212694},
	{"PAUP", 4, 212695},
	{"NUKEZONE", 8, 212696},
	{"GISCARD", 7, 212697},
	{"BUTTONWILLOW", 12, 212698},
	{"ARTINCONTEXT", 12, 212699},
	{"VIRENDER", 8, 212700},
	{"LELIE", 5, 212701},
	{"DISPROPORTION", 13, 212702},
	{"MELIS", 5, 212703},
	{"HEDGER", 6, 212704},
	{"LIBTOOLIZE", 10, 212705},
	{"FRECHETTE", 9, 212706},
	{"EHRET", 5, 212707},
	{"COUNTERPANE", 11, 212708},
	{"SODEN", 5, 212709},
	{"GULFS", 5, 212710},
	{"SIGNWRITING", 11, 212711},
	{"NETSPACE", 8, 212712},
	{"MCNAIRY", 7, 212713},
	{"ATTACHLINKBOX", 13, 212714},
	{"UNPROFOR", 8, 212715},
	{"INSULINA", 8, 212716},
	{"CLRC", 4, 212717},
	{"AMPHIPOD", 8, 212718},
	{"TRUISMS", 7, 212719},
	{"ABOVETOPSECRET", 14, 212720},
	{"ASPDOTNETSTOREFRONT", 19, 212721},
	{"GEOMETER", 8, 212722},
	{"CLORIUS", 7, 212723},
	{"GEWALT", 6, 212724},
	{"ENDUSER", 7, 212725},
	{"SURNAMED", 8, 212726},
	{"IGFA", 4, 212727},
	{"BERTHNASOL", 10, 212728},
	{"MBDA", 4, 212729},
	{"PONTINE", 7, 212730},
	{"KONEISTO", 8, 212731},
	{"HANSER", 6, 212732},
	{"DAHLSTROM", 9, 212733},
	{"MANAT", 5, 212734},
	{"BIGGINS", 7, 212735},
	{"PERIMENOPAUSAL", 14, 212736},
	{"TOTALIZER", 9, 212737},
	{"HALESWORTH", 10, 212738},
	{"DORWARD", 7, 212739},
	{"TRADITONAL", 10, 212740},
	{"BBVA", 4, 212741},
	{"LOCALSTREETS", 12, 212742},
	{"RTIME", 5, 212743},
	{"NEGATIONS", 9, 212744},
	{"TCRP", 4, 212745},
	{"POKERTIME", 9, 212746},
	{"AFBACKUP", 8, 212747},
	{"HEITZ", 5, 212748},
	{"SPOREN", 6, 212749},
	{"PUSILLA", 7, 212750},
	{"PFAELZER", 8, 212751},
	{"LITTL", 5, 212752},
	{"DIERENTUIN", 10, 212753},
	{"TAGESGALERIE", 12, 212754},
	{"SKYSCAN", 7, 212755},
	{"VOOGLE", 6, 212756},
	{"RUDIGER", 7, 212757},
	{"CAWDOR", 6, 212758},
	{"AUTOCLAVABLE", 12, 212759},
	{"VWAR", 4, 212760},
	{"SCHOLTZ", 7, 212761},
	{"WCET", 4, 212762},
	{"MAHOROMATIC", 11, 212763},
	{"COCKHEAD", 8, 212764},
	{"RADLIGHT", 8, 212765},
	{"SENDSTATION", 11, 212766},
	{"NULLIFYING", 10, 212767},
	{"KEADY", 5, 212768},
	{"GAYMOVIE", 8, 212769},
	{"ZSNES", 5, 212770},
	{"WIKIWEBLIST", 11, 212771},
	{"STEINITZ", 8, 212772},
	{"BRAES", 5, 212773},
	{"ABUND", 5, 212774},
	{"NAGAS", 5, 212775},
	{"VOORN", 5, 212776},
	{"VALARRAY", 8, 212777},
	{"FREGNA", 6, 212778},
	{"JFL", 3, 212779},
	{"DEPA", 4, 212780},
	{"PETCARERX", 9, 212781},
	{"MENTER", 6, 212782},
	{"CROFTERS", 8, 212783},
	{"BIZREPORT", 9, 212784},
	{"LAWTEK", 6, 212785},
	{"MAXY", 4, 212786},
	{"HTREQUEST", 9, 212787},
	{"EYELESS", 7, 212788},
	{"WINTERLAND", 10, 212789},
	{"INLIVE", 6, 212790},
	{"CENTRICITY", 10, 212791},
	{"VAUCANSON", 9, 212792},
	{"SUPERMOTARD", 11, 212793},
	{"POTBELLY", 8, 212794},
	{"YJUG", 4, 212795},
	{"WUWA", 4, 212796},
	{"UMRS", 4, 212797},
	{"TMAW", 4, 212798},
	{"SLUF", 4, 212799},
	{"RFCL", 4, 212800},
	{"OGOZ", 4, 212801},
	{"NREZ", 4, 212802},
	{"NNYQ", 4, 212803},
	{"NMUJ", 4, 212804},
	{"NDFF", 4, 212805},
	{"MPUD", 4, 212806},
	{"MEKS", 4, 212807},
	{"LTOZ", 4, 212808},
	{"LMKE", 4, 212809},
	{"LAOG", 4, 212810},
	{"KGAU", 4, 212811},
	{"JUSH", 4, 212812},
	{"IKSU", 4, 212813},
	{"HDEW", 4, 212814},
	{"GQIA", 4, 212815},
	{"GMSB", 4, 212816},
	{"FHEZ", 4, 212817},
	{"FDRC", 4, 212818},
	{"EGYU", 4, 212819},
	{"EGIJ", 4, 212820},
	{"DTVM", 4, 212821},
	{"DFAH", 4, 212822},
	{"BOCT", 4, 212823},
	{"ANMG", 4, 212824},
	{"NORCIA", 6, 212825},
	{"LOGIQUE", 7, 212826},
	{"AVIONES", 7, 212827},
	{"IWANTU", 6, 212828},
	{"URANDOM", 7, 212829},
	{"IGSMAIL", 7, 212830},
	{"LINEX", 5, 212831},
	{"BTCV", 4, 212832},
	{"OMNIVORE", 8, 212833},
	{"RICINUS", 7, 212834},
	{"PENGO", 5, 212835},
	{"DIERS", 5, 212836},
	{"SCHANTZ", 7, 212837},
	{"PANDEX", 6, 212838},
	{"LACHAISE", 8, 212839},
	{"KETUBAH", 7, 212840},
	{"DEARE", 5, 212841},
	{"BAILAR", 6, 212842},
	{"YOOGLE", 6, 212843},
	{"FTPMIRROR", 9, 212844},
	{"HILDREN", 7, 212845},
	{"MERSEYBEAT", 10, 212846},
	{"ARCHNET", 7, 212847},
	{"NYRO", 4, 212848},
	{"SALMI", 5, 212849},
	{"EMBRITTLEMENT", 13, 212850},
	{"AIRCONDITIONER", 14, 212851},
	{"PARVEEN", 7, 212852},
	{"JALTUS", 6, 212853},
	{"ELTYPENUMBER", 12, 212854},
	{"CTAF", 4, 212855},
	{"HISTON", 6, 212856},
	{"CORBEIL", 7, 212857},
	{"ZBIG", 4, 212858},
	{"VIRGENES", 8, 212859},
	{"MUXIC", 5, 212860},
	{"ONUR", 4, 212861},
	{"GOOGPE", 6, 212862},
	{"DECLIN", 6, 212863},
	{"UYU", 3, 212864},
	{"RUMBO", 5, 212865},
	{"NEIRA", 5, 212866},
	{"FINANCEREAL", 11, 212867},
	{"TILECALORIMETER", 15, 212868},
	{"CHODESH", 7, 212869},
	{"RABO", 4, 212870},
	{"GWF", 3, 212871},
	{"CSAIL", 5, 212872},
	{"COLLEMBOLA", 10, 212873},
	{"JUGGLED", 7, 212874},
	{"VENERATE", 8, 212875},
	{"TOSELAND", 8, 212876},
	{"SUNGMIN", 7, 212877},
	{"OGOGLE", 6, 212878},
	{"COOPERATIVA", 11, 212879},
	{"NONCANCER", 9, 212880},
	{"BATY", 4, 212881},
	{"INAGAKI", 7, 212882},
	{"YABE", 4, 212883},
	{"KNOKKE", 6, 212884},
	{"GKOGLE", 6, 212885},
	{"EXOTIQUE", 8, 212886},
	{"MANCA", 5, 212887},
	{"STACKLESS", 9, 212888},
	{"MULTIARCH", 9, 212889},
	{"MICROVILLI", 10, 212890},
	{"LUSHLY", 6, 212891},
	{"DISTRIBUZIONE", 13, 212892},
	{"RIMANTADINE", 11, 212893},
	{"KOLLEL", 6, 212894},
	{"GOOGLEEARTH", 11, 212895},
	{"SMAF", 4, 212896},
	{"LEVENS", 6, 212897},
	{"BKB", 3, 212898},
	{"KUNIO", 5, 212899},
	{"XPAND", 5, 212900},
	{"TELES", 5, 212901},
	{"RIOUX", 5, 212902},
	{"KARNEY", 6, 212903},
	{"DETERMINERS", 11, 212904},
	{"DOWNLOWDS", 9, 212905},
	{"APSIS", 5, 212906},
	{"GAZIANTEP", 9, 212907},
	{"TOMAHAWKS", 9, 212908},
	{"KSHV", 4, 212909},
	{"KUNITZ", 6, 212910},
	{"AMPHIPODS", 9, 212911},
	{"REIFIED", 7, 212912},
	{"LIKETELEVISION", 14, 212913},
	{"KONIGSBURG", 10, 212914},
	{"PSYCHOANALYSTS", 14, 212915},
	{"KIKA", 4, 212916},
	{"GASSMAN", 7, 212917},
	{"CHADIAN", 7, 212918},
	{"LATHEM", 6, 212919},
	{"CANTONA", 7, 212920},
	{"PAYDIRECT", 9, 212921},
	{"HAPMAP", 6, 212922},
	{"SHIGEKI", 7, 212923},
	{"VAWTER", 6, 212924},
	{"TELAMON", 7, 212925},
	{"SARTORIAL", 9, 212926},
	{"PLSS", 4, 212927},
	{"MACMINI", 7, 212928},
	{"SHININ", 6, 212929},
	{"NYRA", 4, 212930},
	{"URTICA", 6, 212931},
	{"TECHTREE", 8, 212932},
	{"REMOTO", 6, 212933},
	{"BAGGIO", 6, 212934},
	{"LIBGTKHTML", 10, 212935},
	{"SHOTWELL", 8, 212936},
	{"CATHEDRA", 8, 212937},
	{"AUCT", 4, 212938},
	{"ADDONMAIL", 9, 212939},
	{"USERADMIN", 9, 212940},
	{"KBSAM", 5, 212941},
	{"SUPERFECTA", 10, 212942},
	{"NEPTUN", 6, 212943},
	{"ABSOFT", 6, 212944},
	{"SAGAL", 5, 212945},
	{"GRAPHI", 6, 212946},
	{"STRIBLING", 9, 212947},
	{"OCEANOGRAPHERS", 14, 212948},
	{"JNGFA", 5, 212949},
	{"IGNITIONS", 9, 212950},
	{"NOREVE", 6, 212951},
	{"KUTTY", 5, 212952},
	{"JINXED", 6, 212953},
	{"INCY", 4, 212954},
	{"STELLUNGEN", 10, 212955},
	{"SHEWANELLA", 10, 212956},
	{"INKCYCLE", 8, 212957},
	{"EAPC", 4, 212958},
	{"DIGIZEITSCHRIFTEN", 17, 212959},
	{"CATALLAXY", 9, 212960},
	{"UMBRIAN", 7, 212961},
	{"KFJC", 4, 212962},
	{"WILMOTT", 7, 212963},
	{"SHEPPERD", 8, 212964},
	{"SDBOT", 5, 212965},
	{"TRAVANCORE", 10, 212966},
	{"SCOFFS", 6, 212967},
	{"WUSSY", 5, 212968},
	{"PARTNERIAETH", 12, 212969},
	{"MULTIPACKS", 10, 212970},
	{"FRESNOS", 7, 212971},
	{"BECKA", 5, 212972},
	{"AGGRE", 5, 212973},
	{"LLYS", 4, 212974},
	{"EFFICACE", 8, 212975},
	{"YLC", 3, 212976},
	{"TOMATOS", 7, 212977},
	{"MOBILEMATE", 10, 212978},
	{"LEESE", 5, 212979},
	{"KURUMIN", 7, 212980},
	{"UNSAVOURY", 9, 212981},
	{"CLUNE", 5, 212982},
	{"ASTBURY", 7, 212983},
	{"PROCEEDETH", 10, 212984},
	{"PATRIMONIO", 10, 212985},
	{"INDICUS", 7, 212986},
	{"DONNAN", 6, 212987},
	{"PIVOTALLY", 9, 212988},
	{"BARNWOOD", 8, 212989},
	{"NAMBISAN", 8, 212990},
	{"MPTP", 4, 212991},
	{"YROR", 4, 212992},
	{"YPTR", 4, 212993},
	{"YAAB", 4, 212994},
	{"WCAV", 4, 212995},
	{"UDBL", 4, 212996},
	{"UATW", 4, 212997},
	{"UAMU", 4, 212998},
	{"RRLA", 4, 212999},
	{"PMOO", 4, 213000},
	{"PJES", 4, 213001},
	{"PIFE", 4, 213002},
	{"OVPO", 4, 213003},
	{"ORBD", 4, 213004},
	{"OELY", 4, 213005},
	{"NSDY", 4, 213006},
	{"NPUD", 4, 213007},
	{"NGMW", 4, 213008},
	{"MUCC", 4, 213009},
	{"MNBY", 4, 213010},
	{"MBAV", 4, 213011},
	{"LUGB", 4, 213012},
	{"LMJO", 4, 213013},
	{"LIUH", 4, 213014},
	{"KWIR", 4, 213015},
	{"KOVD", 4, 213016},
	{"KHUB", 4, 213017},
	{"IXJU", 4, 213018},
	{"ICYV", 4, 213019},
	{"IBSP", 4, 213020},
	{"HIFW", 4, 213021},
	{"GTDS", 4, 213022},
	{"GMTA", 4, 213023},
	{"GMEY", 4, 213024},
	{"FASJ", 4, 213025},
	{"EVYN", 4, 213026},
	{"EDCW", 4, 213027},
	{"DHIF", 4, 213028},
	{"DAKC", 4, 213029},
	{"CIBR", 4, 213030},
	{"CFIV", 4, 213031},
	{"CEGY", 4, 213032},
	{"AZOW", 4, 213033},
	{"AKRY", 4, 213034},
	{"ZEPHYRS", 7, 213035},
	{"SVCE", 4, 213036},
	{"BFV", 3, 213037},
	{"PETRICK", 7, 213038},
	{"WWWWYAHOO", 9, 213039},
	{"EXEMPLIFICATION", 15, 213040},
	{"AQSIS", 5, 213041},
	{"ONLINECASINO", 12, 213042},
	{"LLAM", 4, 213043},
	{"HYUK", 4, 213044},
	{"HODOGRAPH", 9, 213045},
	{"GOSPER", 6, 213046},
	{"KLUGMAN", 7, 213047},
	{"DEPLETIONS", 10, 213048},
	{"ASIAONE", 7, 213049},
	{"WAAROM", 6, 213050},
	{"RAPIDIO", 7, 213051},
	{"ENSAG", 5, 213052},
	{"PLEADER", 7, 213053},
	{"HYPERALGESIA", 12, 213054},
	{"PERSONIFY", 9, 213055},
	{"ALLIEDSIGNAL", 12, 213056},
	{"JUNKMAIL", 8, 213057},
	{"GDBARCH", 7, 213058},
	{"BLINGO", 6, 213059},
	{"FRENS", 5, 213060},
	{"PAVLOVIAN", 9, 213061},
	{"MOONLITE", 8, 213062},
	{"CHELATES", 8, 213063},
	{"POCKETEC", 8, 213064},
	{"LIEBEN", 6, 213065},
	{"HICKENLOOPER", 12, 213066},
	{"EDIINT", 6, 213067},
	{"UNDERSTOREY", 11, 213068},
	{"TIETOENATOR", 11, 213069},
	{"NZPAGES", 7, 213070},
	{"FIGUERES", 8, 213071},
	{"SEAGREEN", 8, 213072},
	{"SARU", 4, 213073},
	{"BAWL", 4, 213074},
	{"WFLA", 4, 213075},
	{"SHALIT", 6, 213076},
	{"OPMERKINGEN", 11, 213077},
	{"WELTEN", 6, 213078},
	{"CASQUE", 6, 213079},
	{"VAINGLORY", 9, 213080},
	{"PRODUCENT", 9, 213081},
	{"JEOPARDISED", 11, 213082},
	{"EVASON", 6, 213083},
	{"ROTISSERRIE", 11, 213084},
	{"PQFP", 4, 213085},
	{"PMAS", 4, 213086},
	{"EXPLORATIVE", 11, 213087},
	{"WEHAVE", 6, 213088},
	{"TRILLS", 6, 213089},
	{"SURFCAM", 7, 213090},
	{"OVERLAYED", 9, 213091},
	{"SPANNE", 6, 213092},
	{"RADIOWORKS", 10, 213093},
	{"PLAMONDON", 9, 213094},
	{"INPUTSOURCE", 11, 213095},
	{"DIHYDROCODEINE", 14, 213096},
	{"DEPTT", 5, 213097},
	{"ROBAR", 5, 213098},
	{"MALTHUSIAN", 10, 213099},
	{"COPAS", 5, 213100},
	{"WAFS", 4, 213101},
	{"URRUTIA", 7, 213102},
	{"MINNER", 6, 213103},
	{"LOWERMOST", 9, 213104},
	{"TRACTED", 7, 213105},
	{"BERBERS", 7, 213106},
	{"ONEGREATFAMILY", 14, 213107},
	{"MARVY", 5, 213108},
	{"LLUIS", 5, 213109},
	{"BRAINBENCH", 10, 213110},
	{"PARTCH", 6, 213111},
	{"WSIF", 4, 213112},
	{"RENTOUL", 7, 213113},
	{"PROJEKTY", 8, 213114},
	{"NEOLA", 5, 213115},
	{"GAASTRA", 7, 213116},
	{"CLEVEREST", 9, 213117},
	{"THRACIANS", 9, 213118},
	{"MEMON", 5, 213119},
	{"SPLENDORED", 10, 213120},
	{"SLICKED", 7, 213121},
	{"PURCHAS", 7, 213122},
	{"ARTHRODESIS", 11, 213123},
	{"TEMPLET", 7, 213124},
	{"RISSO", 5, 213125},
	{"ASCUTNEY", 8, 213126},
	{"CONVOLUTIONS", 12, 213127},
	{"WINGET", 6, 213128},
	{"INUNDATE", 8, 213129},
	{"QUATRAIN", 8, 213130},
	{"PENETRAZIONI", 12, 213131},
	{"JUWEL", 5, 213132},
	{"GARAGING", 8, 213133},
	{"SUNDARI", 7, 213134},
	{"NAILSWORTH", 10, 213135},
	{"HOOFED", 6, 213136},
	{"TIONG", 5, 213137},
	{"DEBARGE", 7, 213138},
	{"BELLDANDY", 9, 213139},
	{"POLLUT", 6, 213140},
	{"OUTWASH", 7, 213141},
	{"MEASE", 5, 213142},
	{"GURMUKHI", 8, 213143},
	{"TRANSAM", 7, 213144},
	{"SARVA", 5, 213145},
	{"BENUTZEN", 8, 213146},
	{"QUITING", 7, 213147},
	{"CHUNGKING", 9, 213148},
	{"ARPIN", 5, 213149},
	{"CRUZEIRO", 8, 213150},
	{"XGBOX", 5, 213151},
	{"UNICOS", 6, 213152},
	{"DCAL", 4, 213153},
	{"SETBACKGROUND", 13, 213154},
	{"PROXAD", 6, 213155},
	{"BACKBURNER", 10, 213156},
	{"BELLVIEW", 8, 213157},
	{"VIVAS", 5, 213158},
	{"IFOAM", 5, 213159},
	{"COALMINE", 8, 213160},
	{"CARRITO", 7, 213161},
	{"SUPERTEX", 8, 213162},
	{"MASAHARU", 8, 213163},
	{"SIENDO", 6, 213164},
	{"MIKVAH", 6, 213165},
	{"SPRECKELS", 9, 213166},
	{"MATRICE", 7, 213167},
	{"GENERALITAT", 11, 213168},
	{"PAGINASNBSPSIMILARES", 20, 213169},
	{"FLASHTRAX", 9, 213170},
	{"KEVINS", 6, 213171},
	{"DOLAR", 5, 213172},
	{"SCRAPAHOLICS", 12, 213173},
	{"RISUS", 5, 213174},
	{"SHELLER", 7, 213175},
	{"PANTAGRAPH", 10, 213176},
	{"CALIFONIA", 9, 213177},
	{"UBF", 3, 213178},
	{"NAZIONALI", 9, 213179},
	{"EINSTELLUNG", 11, 213180},
	{"BITRIX", 6, 213181},
	{"UMSIC", 5, 213182},
	{"RADIOCHEMICAL", 13, 213183},
	{"NOFFLE", 6, 213184},
	{"DEPAOLA", 7, 213185},
	{"DIGIX", 5, 213186},
	{"SQUAWKING", 9, 213187},
	{"BABT", 4, 213188},
	{"TANNERIES", 9, 213189},
	{"LANGTRY", 7, 213190},
	{"CMFDEFAULT", 10, 213191},
	{"TOPLINK", 7, 213192},
	{"PLUSHENKO", 9, 213193},
	{"ZHAOXING", 8, 213194},
	{"MEMORIUM", 8, 213195},
	{"BENZALDEHYDE", 12, 213196},
	{"SELINDA", 7, 213197},
	{"LILLO", 5, 213198},
	{"GRAECO", 6, 213199},
	{"PROCESOS", 8, 213200},
	{"HARBORNE", 8, 213201},
	{"ESTRANGE", 8, 213202},
	{"COLDSYNC", 8, 213203},
	{"HMIC", 4, 213204},
	{"NAPALI", 6, 213205},
	{"MURAWSKI", 8, 213206},
	{"METAKIT", 7, 213207},
	{"HOPCROFT", 8, 213208},
	{"BLARED", 6, 213209},
	{"YSUK", 4, 213210},
	{"YFSY", 4, 213211},
	{"XTYM", 4, 213212},
	{"WWBO", 4, 213213},
	{"WDUM", 4, 213214},
	{"VIVR", 4, 213215},
	{"URPT", 4, 213216},
	{"TUBM", 4, 213217},
	{"TFUZ", 4, 213218},
	{"TECB", 4, 213219},
	{"RPAH", 4, 213220},
	{"RKMT", 4, 213221},
	{"RIQA", 4, 213222},
	{"RFOA", 4, 213223},
	{"QTAD", 4, 213224},
	{"OSYC", 4, 213225},
	{"OFRN", 4, 213226},
	{"NMSD", 4, 213227},
	{"NMGM", 4, 213228},
	{"MOBM", 4, 213229},
	{"MLOF", 4, 213230},
	{"MDWH", 4, 213231},
	{"MDTO", 4, 213232},
	{"MBAZ", 4, 213233},
	{"LUOF", 4, 213234},
	{"LMOW", 4, 213235},
	{"LJOA", 4, 213236},
	{"LCPU", 4, 213237},
	{"LBFN", 4, 213238},
	{"KMAM", 4, 213239},
	{"IKOG", 4, 213240},
	{"FDRJ", 4, 213241},
	{"EWDL", 4, 213242},
	{"DSZA", 4, 213243},
	{"DFSA", 4, 213244},
	{"DCWE", 4, 213245},
	{"BMIK", 4, 213246},
	{"BIEJ", 4, 213247},
	{"BHAC", 4, 213248},
	{"AIBL", 4, 213249},
	{"APOPHENIA", 9, 213250},
	{"MICOM", 5, 213251},
	{"GRIDDING", 8, 213252},
	{"WVEC", 4, 213253},
	{"SWANEE", 6, 213254},
	{"GEEZE", 5, 213255},
	{"ASIGNATURAS", 11, 213256},
	{"SALESRANK", 9, 213257},
	{"LUCKOVICH", 9, 213258},
	{"ARMEDIA", 7, 213259},
	{"ZOOLOGISTS", 10, 213260},
	{"THERMAGE", 8, 213261},
	{"NOMIS", 5, 213262},
	{"MONCADA", 7, 213263},
	{"ASHMONT", 7, 213264},
	{"PUNAHOU", 7, 213265},
	{"ANIMALISTIC", 11, 213266},
	{"FUMETTI", 7, 213267},
	{"SARAMAGO", 8, 213268},
	{"PUMMELING", 9, 213269},
	{"ONINOCOMPUTING", 14, 213270},
	{"VERGIST", 7, 213271},
	{"WEBMONEY", 8, 213272},
	{"STAATSOPER", 10, 213273},
	{"PRESSBURGER", 11, 213274},
	{"LOPPING", 7, 213275},
	{"CAFFEY", 6, 213276},
	{"LOPERAMIDE", 10, 213277},
	{"RIRDC", 5, 213278},
	{"JIRKA", 5, 213279},
	{"BARRANQUERO", 11, 213280},
	{"SPORTSPLEX", 10, 213281},
	{"ARABELLASHERATON", 16, 213282},
	{"QUICKTAX", 8, 213283},
	{"PATHES", 6, 213284},
	{"ZOEKMACHINE", 11, 213285},
	{"SIGNICANT", 9, 213286},
	{"CANINA", 6, 213287},
	{"VERLOREN", 8, 213288},
	{"TINTERN", 7, 213289},
	{"DOWNSCALING", 11, 213290},
	{"CHATLINE", 8, 213291},
	{"SYRINX", 6, 213292},
	{"DOWIE", 5, 213293},
	{"WOODWORM", 8, 213294},
	{"LOGGE", 5, 213295},
	{"ANYOTHER", 8, 213296},
	{"SCRIPTPRO", 9, 213297},
	{"BRIANT", 6, 213298},
	{"MONODROMY", 9, 213299},
	{"ESSONNE", 7, 213300},
	{"RAMANI", 6, 213301},
	{"CAIAPHAS", 8, 213302},
	{"BJECT", 5, 213303},
	{"PIGALLE", 7, 213304},
	{"LIBGMODULE", 10, 213305},
	{"FORETELLING", 11, 213306},
	{"PUPP", 4, 213307},
	{"MUNCHED", 7, 213308},
	{"GUSS", 4, 213309},
	{"SANTUCCI", 8, 213310},
	{"ANANL", 5, 213311},
	{"SANDIFER", 8, 213312},
	{"MAZIE", 5, 213313},
	{"FECUND", 6, 213314},
	{"EXPRESSIVELY", 12, 213315},
	{"STRATEGI", 8, 213316},
	{"BENTE", 5, 213317},
	{"AMINOS", 6, 213318},
	{"ENSLER", 6, 213319},
	{"DRIFTNET", 8, 213320},
	{"VEHICROSS", 9, 213321},
	{"GLYCO", 5, 213322},
	{"ATCHAFALAYA", 11, 213323},
	{"VRIENDEN", 8, 213324},
	{"EUPHONY", 7, 213325},
	{"DYAS", 4, 213326},
	{"ASKARI", 6, 213327},
	{"LAUREUS", 7, 213328},
	{"JANDEK", 6, 213329},
	{"HAZYVIEW", 8, 213330},
	{"TAMERA", 6, 213331},
	{"PEQUENO", 7, 213332},
	{"PITCHERSALL", 11, 213333},
	{"PENNEBAKER", 10, 213334},
	{"UNCLIPPED", 9, 213335},
	{"FUGRO", 5, 213336},
	{"PATHOPHYSIOLOGIC", 16, 213337},
	{"ADPTR", 5, 213338},
	{"BALTAR", 6, 213339},
	{"ULFA", 4, 213340},
	{"PIRATESLIVE", 11, 213341},
	{"FORN", 4, 213342},
	{"OZER", 4, 213343},
	{"GELCOAT", 7, 213344},
	{"ISRAELLYCOOL", 12, 213345},
	{"FISHMONGER", 10, 213346},
	{"KWASNIEWSKI", 11, 213347},
	{"DWW", 3, 213348},
	{"CARRAWAY", 8, 213349},
	{"TELEPORTS", 9, 213350},
	{"FORESTIER", 9, 213351},
	{"VLES", 4, 213352},
	{"OPENGROUPWARE", 13, 213353},
	{"MOTORED", 7, 213354},
	{"MINDESTUMSATZ", 13, 213355},
	{"KISSABLE", 8, 213356},
	{"ALEXANDERS", 10, 213357},
	{"AGNESS", 6, 213358},
	{"INTERVENTIONISM", 15, 213359},
	{"FIGHETTE", 8, 213360},
	{"GGZ", 3, 213361},
	{"DARTBOARDS", 10, 213362},
	{"RCMS", 4, 213363},
	{"GIGO", 4, 213364},
	{"REINIER", 7, 213365},
	{"KINKIEST", 8, 213366},
	{"GIGANTOSKOP", 11, 213367},
	{"DISKONCHIP", 10, 213368},
	{"RECEIVETH", 9, 213369},
	{"SHOUDL", 6, 213370},
	{"EPACT", 5, 213371},
	{"CRIANCA", 7, 213372},
	{"BASOPHILS", 9, 213373},
	{"POLLINATING", 11, 213374},
	{"CRESSKILL", 9, 213375},
	{"CEPACIA", 7, 213376},
	{"EASEUS", 6, 213377},
	{"COTTENCEAU", 10, 213378},
	{"UIDL", 4, 213379},
	{"MIKROBIOL", 9, 213380},
	{"HAUSSMANN", 9, 213381},
	{"QUADRIC", 7, 213382},
	{"WHITETOP", 8, 213383},
	{"PALLETIZED", 10, 213384},
	{"KNAUSS", 6, 213385},
	{"REXDALE", 7, 213386},
	{"NOTABILITY", 10, 213387},
	{"MARNA", 5, 213388},
	{"COPR", 4, 213389},
	{"MULTIPLETS", 10, 213390},
	{"GARBAREK", 8, 213391},
	{"KIRORO", 6, 213392},
	{"AMFM", 4, 213393},
	{"NORTHVALE", 9, 213394},
	{"BALUSTERS", 9, 213395},
	{"SCRIPTURI", 9, 213396},
	{"NERIAH", 6, 213397},
	{"CLINICOPATHOLOGICAL", 19, 213398},
	{"YKOC", 4, 213399},
	{"WYMO", 4, 213400},
	{"WOOW", 4, 213401},
	{"WEGU", 4, 213402},
	{"VIGL", 4, 213403},
	{"VGRO", 4, 213404},
	{"VAKP", 4, 213405},
	{"UYEX", 4, 213406},
	{"ULQA", 4, 213407},
	{"TVYO", 4, 213408},
	{"TKUC", 4, 213409},
	{"TAKL", 4, 213410},
	{"SKGE", 4, 213411},
	{"SDRG", 4, 213412},
	{"RUMV", 4, 213413},
	{"PLAV", 4, 213414},
	{"PIOW", 4, 213415},
	{"PIFR", 4, 213416},
	{"OUGK", 4, 213417},
	{"OKHZ", 4, 213418},
	{"OEPU", 4, 213419},
	{"NDKT", 4, 213420},
	{"MYEC", 4, 213421},
	{"MVES", 4, 213422},
	{"MPSJ", 4, 213423},
	{"MOAJ", 4, 213424},
	{"MMBE", 4, 213425},
	{"MBAJ", 4, 213426},
	{"LTAJ", 4, 213427},
	{"KYGI", 4, 213428},
	{"KEXH", 4, 213429},
	{"IACQ", 4, 213430},
	{"GYMH", 4, 213431},
	{"FTPH", 4, 213432},
	{"FRYB", 4, 213433},
	{"FGYM", 4, 213434},
	{"DZIW", 4, 213435},
	{"DVST", 4, 213436},
	{"DUWE", 4, 213437},
	{"DJDA", 4, 213438},
	{"CIKA", 4, 213439},
	{"CHDY", 4, 213440},
	{"CAUP", 4, 213441},
	{"BTSP", 4, 213442},
	{"BSVE", 4, 213443},
	{"BNIG", 4, 213444},
	{"BAYJ", 4, 213445},
	{"BATJ", 4, 213446},
	{"MEDIALINK", 9, 213447},
	{"TATEMENT", 8, 213448},
	{"DEMOREST", 8, 213449},
	{"ANGLOPHONES", 11, 213450},
	{"SALER", 5, 213451},
	{"FADI", 4, 213452},
	{"KARLSKRONA", 10, 213453},
	{"GSPC", 4, 213454},
	{"PANU", 4, 213455},
	{"FORBUSH", 7, 213456},
	{"IMRIE", 5, 213457},
	{"TREVES", 6, 213458},
	{"IRONWORKERS", 11, 213459},
	{"GILDEN", 6, 213460},
	{"EMBETH", 6, 213461},
	{"BELBIN", 6, 213462},
	{"ARACHNIDA", 9, 213463},
	{"PERISTALSIS", 11, 213464},
	{"WOODSBORO", 9, 213465},
	{"TANEJA", 6, 213466},
	{"IXQUICK", 7, 213467},
	{"CYBERWORLD", 10, 213468},
	{"NEWLC", 5, 213469},
	{"KUSIC", 5, 213470},
	{"MERIONETH", 9, 213471},
	{"VERIFIABILITY", 13, 213472},
	{"JUHI", 4, 213473},
	{"RETLW", 5, 213474},
	{"OSTLER", 6, 213475},
	{"GAYSITE", 7, 213476},
	{"FTPADMIN", 8, 213477},
	{"BUSINESSWORLD", 13, 213478},
	{"SENSORO", 7, 213479},
	{"TELECOMUNICAZIONI", 17, 213480},
	{"PRODUCCION", 10, 213481},
	{"STARTPRICE", 10, 213482},
	{"SNDX", 4, 213483},
	{"HARVILLE", 8, 213484},
	{"NINETIETH", 9, 213485},
	{"RICARDIAN", 9, 213486},
	{"PLEOMORPHIC", 11, 213487},
	{"GOTCH", 5, 213488},
	{"TSERING", 7, 213489},
	{"SCRIPTLOGIC", 11, 213490},
	{"MEGALOPOLIS", 11, 213491},
	{"MCSORLEY", 8, 213492},
	{"MILIBAND", 8, 213493},
	{"SPICULES", 8, 213494},
	{"PREPROFESSIONAL", 15, 213495},
	{"BARRAGES", 8, 213496},
	{"MEDICALE", 8, 213497},
	{"CLSHDRAWNIL", 11, 213498},
	{"SCRIPS", 6, 213499},
	{"NITROGENASE", 11, 213500},
	{"HANDLEKURV", 10, 213501},
	{"COLG", 4, 213502},
	{"SOMEDAYS", 8, 213503},
	{"LOREE", 5, 213504},
	{"ILLIA", 5, 213505},
	{"TWINTALK", 8, 213506},
	{"ZANZIE", 6, 213507},
	{"GIMPS", 5, 213508},
	{"WIKIA", 5, 213509},
	{"REVISON", 7, 213510},
	{"RAGWORT", 7, 213511},
	{"KAMUI", 5, 213512},
	{"DULCINEA", 8, 213513},
	{"SCHEELE", 7, 213514},
	{"KETING", 6, 213515},
	{"GARNHAM", 7, 213516},
	{"GARF", 4, 213517},
	{"FARNUM", 6, 213518},
	{"AERATE", 6, 213519},
	{"PATTEE", 6, 213520},
	{"EXTORTIONATE", 12, 213521},
	{"DIPTYCH", 7, 213522},
	{"DITTMAN", 7, 213523},
	{"WADDLING", 8, 213524},
	{"SYLWEDDOL", 9, 213525},
	{"FLOTO", 5, 213526},
	{"REKNOWNED", 9, 213527},
	{"UNCENCORED", 10, 213528},
	{"ASTHENIA", 8, 213529},
	{"DESERIALIZE", 11, 213530},
	{"SBAC", 4, 213531},
	{"KLOGD", 5, 213532},
	{"WHOLESALEHUNTER", 15, 213533},
	{"PUBD", 4, 213534},
	{"NAVAJOS", 7, 213535},
	{"TRIHALOMETHANES", 15, 213536},
	{"KRATOM", 6, 213537},
	{"SUMMARIZER", 10, 213538},
	{"PCMARKET", 8, 213539},
	{"SPARERIBS", 9, 213540},
	{"EVERWORLD", 9, 213541},
	{"CRITO", 5, 213542},
	{"AYTHYA", 6, 213543},
	{"AMERICREDIT", 11, 213544},
	{"THANKX", 6, 213545},
	{"MULERO", 6, 213546},
	{"INTERVENERS", 11, 213547},
	{"HERZLIYA", 8, 213548},
	{"ANAVAR", 6, 213549},
	{"PENCILLED", 9, 213550},
	{"CHEWELAH", 8, 213551},
	{"BENNE", 5, 213552},
	{"SPESSARTITE", 11, 213553},
	{"SOKOLOWSKI", 10, 213554},
	{"CCMP", 4, 213555},
	{"BOOLS", 5, 213556},
	{"MALIS", 5, 213557},
	{"SYNTENY", 7, 213558},
	{"NETSCRIPT", 9, 213559},
	{"MFUME", 5, 213560},
	{"CONGAREE", 8, 213561},
	{"NISTIR", 6, 213562},
	{"HOFFMANIA", 9, 213563},
	{"BURGON", 6, 213564},
	{"GAUSSKW", 7, 213565},
	{"PCOUNT", 6, 213566},
	{"MONTEAGLE", 9, 213567},
	{"IPCTURES", 8, 213568},
	{"DMXZONE", 7, 213569},
	{"BUDWORM", 7, 213570},
	{"ANALECTS", 8, 213571},
	{"RSIP", 4, 213572},
	{"LGDBM", 5, 213573},
	{"DRUIDIC", 7, 213574},
	{"STMP", 4, 213575},
	{"FEINER", 6, 213576},
	{"ESCALIER", 8, 213577},
	{"BUBBY", 5, 213578},
	{"EPONYMS", 7, 213579},
	{"DRACHM", 6, 213580},
	{"CJMURLEY", 8, 213581},
	{"OXMAN", 5, 213582},
	{"MARTOCK", 7, 213583},
	{"CHUC", 4, 213584},
	{"BOHLE", 5, 213585},
	{"BIORESOURCE", 11, 213586},
	{"SPECAPC", 7, 213587},
	{"SAXIFRAGA", 9, 213588},
	{"MABYE", 5, 213589},
	{"ANTAGONISMS", 11, 213590},
	{"ANNOUNCEMEN", 11, 213591},
	{"SHIMKUS", 7, 213592},
	{"KISHINEV", 8, 213593},
	{"DIRECTSYNC", 10, 213594},
	{"FIDIC", 5, 213595},
	{"WILLINGDON", 10, 213596},
	{"RADY", 4, 213597},
	{"DUCLOS", 6, 213598},
	{"ALMAR", 5, 213599},
	{"HARTES", 6, 213600},
	{"SIMENS", 6, 213601},
	{"DSSUBSCRIBER", 12, 213602},
	{"COLLINE", 7, 213603},
	{"BIGSBY", 6, 213604},
	{"PUTAMEN", 7, 213605},
	{"FOLKE", 5, 213606},
	{"FETISHIST", 9, 213607},
	{"YOBI", 4, 213608},
	{"YNME", 4, 213609},
	{"YGID", 4, 213610},
	{"WOCD", 4, 213611},
	{"WETY", 4, 213612},
	{"VRIG", 4, 213613},
	{"VPAS", 4, 213614},
	{"UMJE", 4, 213615},
	{"UECY", 4, 213616},
	{"TMSW", 4, 213617},
	{"TDRR", 4, 213618},
	{"RPDA", 4, 213619},
	{"RLUF", 4, 213620},
	{"RGJU", 4, 213621},
	{"QQAN", 4, 213622},
	{"QAMA", 4, 213623},
	{"PMCD", 4, 213624},
	{"OXCU", 4, 213625},
	{"ORGV", 4, 213626},
	{"ONXR", 4, 213627},
	{"OFWP", 4, 213628},
	{"OFLG", 4, 213629},
	{"ODRM", 4, 213630},
	{"NEZZ", 4, 213631},
	{"LTEK", 4, 213632},
	{"LOXY", 4, 213633},
	{"LDRH", 4, 213634},
	{"LBSS", 4, 213635},
	{"IVTR", 4, 213636},
	{"IDUB", 4, 213637},
	{"HROF", 4, 213638},
	{"HDFO", 4, 213639},
	{"GWIK", 4, 213640},
	{"EXAU", 4, 213641},
	{"CKTS", 4, 213642},
	{"BREK", 4, 213643},
	{"BPCO", 4, 213644},
	{"BAAM", 4, 213645},
	{"ATVD", 4, 213646},
	{"AJOV", 4, 213647},
	{"AIGK", 4, 213648},
	{"WSMO", 4, 213649},
	{"FOCA", 4, 213650},
	{"CERRONE", 7, 213651},
	{"UITENHAGE", 9, 213652},
	{"KHACHATURIAN", 12, 213653},
	{"JARMO", 5, 213654},
	{"SUPUESTO", 8, 213655},
	{"SONDAGE", 7, 213656},
	{"VAGY", 4, 213657},
	{"POLITIEK", 8, 213658},
	{"MAGIZINE", 8, 213659},
	{"TTAINSERTSIBLING", 16, 213660},
	{"PHENTERNINE", 11, 213661},
	{"MAYNARDVILLE", 12, 213662},
	{"LINKNAME", 8, 213663},
	{"WRECSAM", 7, 213664},
	{"VAILABLE", 8, 213665},
	{"ELECTROFISHING", 14, 213666},
	{"ALTHOFF", 7, 213667},
	{"DINOPROSTONE", 12, 213668},
	{"MICAWBER", 8, 213669},
	{"JAGAN", 5, 213670},
	{"AFOEV", 5, 213671},
	{"PBCC", 4, 213672},
	{"IIIXE", 5, 213673},
	{"PLEBEIAN", 8, 213674},
	{"AWGN", 4, 213675},
	{"WIDDECOMBE", 10, 213676},
	{"TICLE", 5, 213677},
	{"LEOTA", 5, 213678},
	{"DEFCUSTOM", 9, 213679},
	{"GIVI", 4, 213680},
	{"EINTRITT", 8, 213681},
	{"INTROSPECT", 10, 213682},
	{"BENAZEPRIL", 10, 213683},
	{"TEMPERLEY", 9, 213684},
	{"MOGU", 4, 213685},
	{"LEWA", 4, 213686},
	{"JAPEN", 5, 213687},
	{"STEREOTAXIC", 11, 213688},
	{"ROZENBERG", 9, 213689},
	{"AMERISOURCEBERGEN", 17, 213690},
	{"TROLLY", 6, 213691},
	{"IZING", 5, 213692},
	{"IONIANS", 7, 213693},
	{"SHOSHANNA", 9, 213694},
	{"ILLIDAN", 7, 213695},
	{"BENEFICIATION", 13, 213696},
	{"AVIANO", 6, 213697},
	{"TYROS", 5, 213698},
	{"BANZ", 4, 213699},
	{"PENRHYN", 7, 213700},
	{"HEPCAT", 6, 213701},
	{"AIRBENDER", 9, 213702},
	{"NUMBERP", 7, 213703},
	{"TATRAS", 6, 213704},
	{"GEOSPHERE", 9, 213705},
	{"TMPSTR", 6, 213706},
	{"THIOLS", 6, 213707},
	{"HANVEY", 6, 213708},
	{"DEOXYRIBONUCLEASE", 17, 213709},
	{"IFCP", 4, 213710},
	{"JUSTFORMUMZ", 11, 213711},
	{"SEMIALDEHYDE", 12, 213712},
	{"RINNE", 5, 213713},
	{"TREKSTOR", 8, 213714},
	{"PATHOLOGIE", 10, 213715},
	{"BEKANNT", 7, 213716},
	{"DANOS", 5, 213717},
	{"SENNEN", 6, 213718},
	{"CONDUCTANCES", 12, 213719},
	{"WUV", 3, 213720},
	{"VARADARAJAN", 11, 213721},
	{"TFILE", 5, 213722},
	{"COMENTARIS", 10, 213723},
	{"VETER", 5, 213724},
	{"WWWDOCS", 7, 213725},
	{"LVP", 3, 213726},
	{"GURLCHECKER", 11, 213727},
	{"DERMATOPATHOLOGY", 16, 213728},
	{"STELA", 5, 213729},
	{"SPIRAEA", 7, 213730},
	{"LEYSIN", 6, 213731},
	{"CHMIELEWSKI", 11, 213732},
	{"BLACKHAT", 8, 213733},
	{"SERVPRO", 7, 213734},
	{"JUIL", 4, 213735},
	{"GRAMMARIANS", 11, 213736},
	{"TANISHA", 7, 213737},
	{"PFLANZEN", 8, 213738},
	{"ADLARD", 6, 213739},
	{"PHENYLENE", 9, 213740},
	{"BISSINGER", 9, 213741},
	{"VOLTAR", 6, 213742},
	{"INDL", 4, 213743},
	{"MEDICALLIBRARY", 14, 213744},
	{"GIGBAG", 6, 213745},
	{"VIORST", 6, 213746},
	{"PATRONE", 7, 213747},
	{"NEGOMBO", 7, 213748},
	{"UNDEFILED", 9, 213749},
	{"LOCATIE", 7, 213750},
	{"AEROPLAN", 8, 213751},
	{"RETHINKS", 8, 213752},
	{"RAUS", 4, 213753},
	{"KWANDWE", 7, 213754},
	{"ENTREPRENEURIALISM", 18, 213755},
	{"NEWJERSEY", 9, 213756},
	{"ISERVER", 7, 213757},
	{"TIPU", 4, 213758},
	{"ACOOMODATION", 12, 213759},
	{"FURRED", 6, 213760},
	{"SBSTA", 5, 213761},
	{"SEPHADEX", 8, 213762},
	{"HIRSHHORN", 9, 213763},
	{"HARMONICALLY", 12, 213764},
	{"MANDALUYONG", 11, 213765},
	{"OMANTIK", 7, 213766},
	{"JONNO", 5, 213767},
	{"HOVERGEN", 8, 213768},
	{"ICONES", 6, 213769},
	{"SEABRA", 6, 213770},
	{"TITTENHEUDICKE", 14, 213771},
	{"MACROCOSM", 9, 213772},
	{"ITALIENSPANIEN", 14, 213773},
	{"ENRIC", 5, 213774},
	{"WHITESELL", 9, 213775},
	{"TITTENSKINDER", 13, 213776},
	{"TITTENKINDERDICKE", 17, 213777},
	{"SUDHAKAR", 8, 213778},
	{"MORROCAN", 8, 213779},
	{"LONDONDICKE", 11, 213780},
	{"LEIPZIGLASTMINUTE", 17, 213781},
	{"HOTBEDS", 7, 213782},
	{"GLENROY", 7, 213783},
	{"DEUTSCHLANDFAMILIENDICKE", 24, 213784},
	{"BAYERNHEIDELBERG", 16, 213785},
	{"ALCOVEBOOK", 10, 213786},
	{"GEOCHIM", 7, 213787},
	{"PARCHE", 6, 213788},
	{"PANIAGUA", 8, 213789},
	{"BONNINGTON", 10, 213790},
	{"TANACH", 6, 213791},
	{"GRINDLE", 7, 213792},
	{"GARNISHMENTS", 12, 213793},
	{"SOCALGAS", 8, 213794},
	{"RASKOLNIKOV", 11, 213795},
	{"CONDITONS", 9, 213796},
	{"TRACS", 5, 213797},
	{"ADVENTURELAND", 13, 213798},
	{"YSEK", 4, 213799},
	{"YRSS", 4, 213800},
	{"YMCH", 4, 213801},
	{"XTJA", 4, 213802},
	{"VRAH", 4, 213803},
	{"UUMW", 4, 213804},
	{"STGY", 4, 213805},
	{"SLWA", 4, 213806},
	{"SKHU", 4, 213807},
	{"SEMG", 4, 213808},
	{"RHOY", 4, 213809},
	{"RFMO", 4, 213810},
	{"PMIA", 4, 213811},
	{"PFRY", 4, 213812},
	{"OXAB", 4, 213813},
	{"ONVL", 4, 213814},
	{"OJAB", 4, 213815},
	{"OIBR", 4, 213816},
	{"NZRE", 4, 213817},
	{"NULU", 4, 213818},
	{"MPUG", 4, 213819},
	{"MBBY", 4, 213820},
	{"LOVU", 4, 213821},
	{"LCHH", 4, 213822},
	{"KYQU", 4, 213823},
	{"KPUP", 4, 213824},
	{"KKET", 4, 213825},
	{"IRGH", 4, 213826},
	{"IBIU", 4, 213827},
	{"HPFO", 4, 213828},
	{"HMSG", 4, 213829},
	{"HDUD", 4, 213830},
	{"GNJU", 4, 213831},
	{"GADF", 4, 213832},
	{"FDIT", 4, 213833},
	{"EZCL", 4, 213834},
	{"ESVR", 4, 213835},
	{"ERJS", 4, 213836},
	{"DZIK", 4, 213837},
	{"CADF", 4, 213838},
	{"BYPC", 4, 213839},
	{"BIDJ", 4, 213840},
	{"ATVL", 4, 213841},
	{"AKHW", 4, 213842},
	{"AGLY", 4, 213843},
	{"THUBAN", 6, 213844},
	{"SCOLAIRES", 9, 213845},
	{"MOOERS", 6, 213846},
	{"IMAGINAT", 8, 213847},
	{"SEGUN", 5, 213848},
	{"OVERHEARING", 11, 213849},
	{"DEROGATE", 8, 213850},
	{"SURVIVA", 7, 213851},
	{"FECK", 4, 213852},
	{"NEWINSTANCE", 11, 213853},
	{"CLARKESVILLE", 12, 213854},
	{"WEATHERLEY", 10, 213855},
	{"PISCINAS", 8, 213856},
	{"FOREBAY", 7, 213857},
	{"OLASKY", 6, 213858},
	{"MYROW", 5, 213859},
	{"COLORSIT", 8, 213860},
	{"VEGASTRIKE", 10, 213861},
	{"KEHL", 4, 213862},
	{"PUISSANT", 8, 213863},
	{"CAMPANAS", 8, 213864},
	{"WPAFB", 5, 213865},
	{"SANDRIDGE", 9, 213866},
	{"EGOISTIC", 8, 213867},
	{"CANDYSHOP", 9, 213868},
	{"TELAH", 5, 213869},
	{"STRAINT", 7, 213870},
	{"SHEVAT", 6, 213871},
	{"FUTUREDIAL", 10, 213872},
	{"DONNEZ", 6, 213873},
	{"RSSOWL", 6, 213874},
	{"KLU", 3, 213875},
	{"GILLMORE", 8, 213876},
	{"FBL", 3, 213877},
	{"LAWNCARE", 8, 213878},
	{"ANALGALLERY", 11, 213879},
	{"SHIRER", 6, 213880},
	{"DELETER", 7, 213881},
	{"WACHS", 5, 213882},
	{"ROTOZIP", 7, 213883},
	{"LASSALE", 7, 213884},
	{"CSHOW", 5, 213885},
	{"BHAKTA", 6, 213886},
	{"WORKSDOTMP", 10, 213887},
	{"MICROELECTROMECHANICAL", 22, 213888},
	{"CSWHY", 5, 213889},
	{"XASER", 5, 213890},
	{"KOMP", 4, 213891},
	{"PILEGGI", 7, 213892},
	{"HARMONIZES", 10, 213893},
	{"FASTSIGNS", 9, 213894},
	{"COBAS", 5, 213895},
	{"SEMINARE", 8, 213896},
	{"OVERPOPULATED", 13, 213897},
	{"KOLCHAK", 7, 213898},
	{"ENTHUSE", 7, 213899},
	{"NANEU", 5, 213900},
	{"MEATRIARCHY", 11, 213901},
	{"PHOSPHOSERINE", 13, 213902},
	{"MASCULIN", 8, 213903},
	{"COUNTACH", 8, 213904},
	{"BEATMANIA", 9, 213905},
	{"ARTCHIVE", 8, 213906},
	{"THEATERWIDE", 11, 213907},
	{"COOKHAM", 7, 213908},
	{"CHUMMY", 6, 213909},
	{"TRIMARAN", 8, 213910},
	{"LYDD", 4, 213911},
	{"BLUNDERED", 9, 213912},
	{"RDV", 3, 213913},
	{"LEIOMYOSARCOMA", 14, 213914},
	{"NANOBIOTECHNOLOGY", 17, 213915},
	{"MICROSPHERE", 11, 213916},
	{"INSWEB", 6, 213917},
	{"WISPER", 6, 213918},
	{"KOSTENLOSEN", 11, 213919},
	{"ESTELL", 6, 213920},
	{"BADDIE", 6, 213921},
	{"ANEFERE", 7, 213922},
	{"MEINES", 6, 213923},
	{"JFACE", 5, 213924},
	{"HEATSTROKE", 10, 213925},
	{"LUHMANN", 7, 213926},
	{"INGENTACONNECT", 14, 213927},
	{"CONGEALED", 9, 213928},
	{"TREKTODAY", 9, 213929},
	{"SETTIN", 6, 213930},
	{"CALIFORINA", 10, 213931},
	{"AMINI", 5, 213932},
	{"STEERE", 6, 213933},
	{"CUTIS", 5, 213934},
	{"VISTALITE", 9, 213935},
	{"GAMEC", 5, 213936},
	{"CERGY", 5, 213937},
	{"JELD", 4, 213938},
	{"FANTASIC", 8, 213939},
	{"CROCIERE", 8, 213940},
	{"CLOUDBURST", 10, 213941},
	{"UNICON", 6, 213942},
	{"MAHANEY", 7, 213943},
	{"WEBDEVELOPMENT", 14, 213944},
	{"TAEJON", 6, 213945},
	{"STORMBRINGER", 12, 213946},
	{"RAINSTORMS", 10, 213947},
	{"MYSTRANDS", 9, 213948},
	{"CHARG", 5, 213949},
	{"TRACERT", 7, 213950},
	{"RIVERMEN", 8, 213951},
	{"HEFFLEY", 7, 213952},
	{"KINZER", 6, 213953},
	{"ETHNOCENTRIC", 12, 213954},
	{"PIGSTY", 6, 213955},
	{"LPTV", 4, 213956},
	{"ROUNDWORMS", 10, 213957},
	{"FREDRIX", 7, 213958},
	{"OCTOGENARIAN", 12, 213959},
	{"PIERRES", 7, 213960},
	{"MEDCAREERS", 10, 213961},
	{"OLIGODENDROCYTES", 16, 213962},
	{"OAKTREE", 7, 213963},
	{"MERTEN", 6, 213964},
	{"DEMARCHE", 8, 213965},
	{"ROLEPLA", 7, 213966},
	{"POUVOIRS", 8, 213967},
	{"PERINI", 6, 213968},
	{"DOLMAN", 6, 213969},
	{"BUCHSTABEN", 10, 213970},
	{"SETOM", 5, 213971},
	{"PATY", 4, 213972},
	{"FIDDY", 5, 213973},
	{"FEUERBACH", 9, 213974},
	{"FOGWARE", 7, 213975},
	{"RAMETER", 7, 213976},
	{"MCCOYPOTTERY", 12, 213977},
	{"LESNEY", 6, 213978},
	{"SUCRALFATE", 10, 213979},
	{"NICKLEN", 7, 213980},
	{"BEIERSDORF", 10, 213981},
	{"CAPROCK", 7, 213982},
	{"FONTBONNE", 9, 213983},
	{"SAKAKI", 6, 213984},
	{"SPECTRALINK", 11, 213985},
	{"GEEKING", 7, 213986},
	{"WCRP", 4, 213987},
	{"SANTONI", 7, 213988},
	{"DUROCHER", 8, 213989},
	{"DAUMIER", 7, 213990},
	{"APEARS", 6, 213991},
	{"ILOVE", 5, 213992},
	{"BRUUNS", 6, 213993},
	{"ALSAGER", 7, 213994},
	{"CAVALLINO", 9, 213995},
	{"MAISTER", 7, 213996},
	{"KOOPER", 6, 213997},
	{"FXD", 3, 213998},
	{"TROUNCE", 7, 213999},
	{"PRAETORIANS", 11, 214000},
	{"STURMINSTER", 11, 214001},
	{"NEWSEDGE", 8, 214002},
	{"FOLLIS", 6, 214003},
	{"GAMEBIZ", 7, 214004},
	{"SANJOY", 6, 214005},
	{"LIGHTBODY", 9, 214006},
	{"KOVELS", 6, 214007},
	{"AZENRAM", 7, 214008},
	{"MASHRIQ", 7, 214009},
	{"GUIAS", 5, 214010},
	{"PATAS", 5, 214011},
	{"MUSOC", 5, 214012},
	{"DOMINGUE", 8, 214013},
	{"SLIPWAY", 7, 214014},
	{"SCHIEBER", 8, 214015},
	{"PENDIDIKAN", 10, 214016},
	{"NAPM", 4, 214017},
	{"SIDDONS", 7, 214018},
	{"HARGA", 5, 214019},
	{"EBNF", 4, 214020},
	{"BLASPHEMIES", 11, 214021},
	{"ARCHWILIO", 9, 214022},
	{"ZZCA", 4, 214023},
	{"ZIGW", 4, 214024},
	{"ZDEM", 4, 214025},
	{"YMIO", 4, 214026},
	{"XLON", 4, 214027},
	{"XGOV", 4, 214028},
	{"WNIK", 4, 214029},
	{"WJET", 4, 214030},
	{"WJAI", 4, 214031},
	{"WIGB", 4, 214032},
	{"VOLQ", 4, 214033},
	{"VDRO", 4, 214034},
	{"VAJP", 4, 214035},
	{"TLCD", 4, 214036},
	{"TCEV", 4, 214037},
	{"SXTR", 4, 214038},
	{"RWAF", 4, 214039},
	{"RIUC", 4, 214040},
	{"RIGC", 4, 214041},
	{"RGDR", 4, 214042},
	{"PTHM", 4, 214043},
	{"POXA", 4, 214044},
	{"OGPL", 4, 214045},
	{"MDAU", 4, 214046},
	{"MBFI", 4, 214047},
	{"LOKT", 4, 214048},
	{"LGHE", 4, 214049},
	{"LFOT", 4, 214050},
	{"KPTH", 4, 214051},
	{"JWHE", 4, 214052},
	{"JRBE", 4, 214053},
	{"JBUT", 4, 214054},
	{"ITVP", 4, 214055},
	{"ILUL", 4, 214056},
	{"GNYS", 4, 214057},
	{"GJUI", 4, 214058},
	{"FHEY", 4, 214059},
	{"FAIC", 4, 214060},
	{"ERKK", 4, 214061},
	{"ENZD", 4, 214062},
	{"ECBL", 4, 214063},
	{"DVOK", 4, 214064},
	{"DSZE", 4, 214065},
	{"DIZO", 4, 214066},
	{"DIGF", 4, 214067},
	{"DEXV", 4, 214068},
	{"BUKT", 4, 214069},
	{"ARZY", 4, 214070},
	{"AKCI", 4, 214071},
	{"TECHNINE", 8, 214072},
	{"MELNIKOV", 8, 214073},
	{"FIBROTIC", 8, 214074},
	{"TOWNIES", 7, 214075},
	{"OLIVERS", 7, 214076},
	{"NONMILITARY", 11, 214077},
	{"NONDEDUCTIBLE", 13, 214078},
	{"GLAZUNOV", 8, 214079},
	{"FREEMINT", 8, 214080},
	{"COVENANTED", 10, 214081},
	{"SUMMERTON", 9, 214082},
	{"AMITECH", 7, 214083},
	{"PERMEABILIZED", 13, 214084},
	{"OSTEOGENIC", 10, 214085},
	{"HUMIDISTAT", 10, 214086},
	{"FRAISE", 6, 214087},
	{"SCHEFFAU", 8, 214088},
	{"LAUREEN", 7, 214089},
	{"CONIGLIO", 8, 214090},
	{"UNFURL", 6, 214091},
	{"SHEPSHED", 8, 214092},
	{"NEUROECTODERMAL", 15, 214093},
	{"LOAIZA", 6, 214094},
	{"TEXSHOP", 7, 214095},
	{"MALELANE", 8, 214096},
	{"REINGOLD", 8, 214097},
	{"RASHARD", 7, 214098},
	{"GEOMECHANICS", 12, 214099},
	{"SHEED", 5, 214100},
	{"BADAXE", 6, 214101},
	{"METRON", 6, 214102},
	{"LIBOSAN", 7, 214103},
	{"LAINIE", 6, 214104},
	{"MAGNETOMETERS", 13, 214105},
	{"KICKBOXER", 9, 214106},
	{"GHALIB", 6, 214107},
	{"CATOCTIN", 8, 214108},
	{"DESULFURIZATION", 15, 214109},
	{"XPRESSO", 7, 214110},
	{"MUAIC", 5, 214111},
	{"ENTHROPIA", 9, 214112},
	{"PRAKTIKE", 8, 214113},
	{"AYELET", 6, 214114},
	{"THERETHROUGH", 12, 214115},
	{"DIFFERNET", 9, 214116},
	{"MULTIMILLIONAIRE", 16, 214117},
	{"MINIPCI", 7, 214118},
	{"BEIHAI", 6, 214119},
	{"BROKENHEARTED", 13, 214120},
	{"VAGOTOMY", 8, 214121},
	{"NORDBERG", 8, 214122},
	{"FRIEDAN", 7, 214123},
	{"BRMS", 4, 214124},
	{"WWWE", 4, 214125},
	{"PIPERAZINES", 11, 214126},
	{"YUKIKO", 6, 214127},
	{"STRANDBERG", 10, 214128},
	{"FLORENCIO", 9, 214129},
	{"KIRSCHBAUM", 10, 214130},
	{"PESET", 5, 214131},
	{"LOBAL", 5, 214132},
	{"DISPARAGEMENT", 13, 214133},
	{"DEEPLINK", 8, 214134},
	{"FLATBREAD", 9, 214135},
	{"CEFACLOR", 8, 214136},
	{"VENDEEN", 7, 214137},
	{"SETPARENT", 9, 214138},
	{"ONCOLOGICAL", 11, 214139},
	{"MIDMORNING", 10, 214140},
	{"MICROSIMULATION", 15, 214141},
	{"FACEY", 5, 214142},
	{"VIEWSCREEN", 10, 214143},
	{"PROCESADOR", 10, 214144},
	{"NEXTPAGE", 8, 214145},
	{"MENARDS", 7, 214146},
	{"HEERDEN", 7, 214147},
	{"VILLACH", 7, 214148},
	{"PRASLIN", 7, 214149},
	{"AGGR", 4, 214150},
	{"NONSELECTIVE", 12, 214151},
	{"ELAB", 4, 214152},
	{"ANSTATT", 7, 214153},
	{"MUSKIES", 7, 214154},
	{"FISTICUFFS", 10, 214155},
	{"DENKO", 5, 214156},
	{"RUTHERFORDTON", 13, 214157},
	{"PUGGLE", 6, 214158},
	{"LISCENSE", 8, 214159},
	{"USCHI", 5, 214160},
	{"MINUT", 5, 214161},
	{"GRTST", 5, 214162},
	{"REPERCUSSION", 12, 214163},
	{"JAMESRL", 7, 214164},
	{"SADDR", 5, 214165},
	{"KIEREN", 6, 214166},
	{"JANKO", 5, 214167},
	{"UNIVERAL", 8, 214168},
	{"OLIFANTS", 8, 214169},
	{"MARKEE", 6, 214170},
	{"EXLUSIVE", 8, 214171},
	{"PHENTEREMINE", 12, 214172},
	{"MEDICOS", 7, 214173},
	{"MAGNESITE", 9, 214174},
	{"JACCARD", 7, 214175},
	{"COMBUSTORS", 10, 214176},
	{"SIGTRAN", 7, 214177},
	{"CONFIGURAZIONE", 14, 214178},
	{"WEIDEN", 6, 214179},
	{"EYEOS", 5, 214180},
	{"XVCD", 4, 214181},
	{"PENNINSULA", 10, 214182},
	{"NOTARIZATION", 12, 214183},
	{"BADI", 4, 214184},
	{"EGTRRA", 6, 214185},
	{"HODER", 5, 214186},
	{"HISPANOS", 8, 214187},
	{"SUPERFOOD", 9, 214188},
	{"GODUNOV", 7, 214189},
	{"FSCS", 4, 214190},
	{"MYOSINS", 7, 214191},
	{"HARDCOPIES", 10, 214192},
	{"SUGARCREEK", 10, 214193},
	{"STRINGTOKENIZER", 15, 214194},
	{"ICFA", 4, 214195},
	{"CHIROPTERA", 10, 214196},
	{"DAVIDTZ", 7, 214197},
	{"WARA", 4, 214198},
	{"VOLLEYBALLS", 11, 214199},
	{"VADE", 4, 214200},
	{"POKAZUJE", 8, 214201},
	{"FREERANGE", 9, 214202},
	{"COELI", 5, 214203},
	{"YOUKAI", 6, 214204},
	{"FAVOURITISM", 11, 214205},
	{"DNREC", 5, 214206},
	{"SACHEN", 6, 214207},
	{"RAVA", 4, 214208},
	{"REVERBS", 7, 214209},
	{"PRETENCES", 9, 214210},
	{"JERMAIN", 7, 214211},
	{"ZRSQ", 4, 214212},
	{"ZIMP", 4, 214213},
	{"YUDO", 4, 214214},
	{"YPRY", 4, 214215},
	{"XDAN", 4, 214216},
	{"WUER", 4, 214217},
	{"WEBN", 4, 214218},
	{"USBT", 4, 214219},
	{"TOXB", 4, 214220},
	{"TDOJ", 4, 214221},
	{"SWYO", 4, 214222},
	{"RZWA", 4, 214223},
	{"RYRY", 4, 214224},
	{"RUTB", 4, 214225},
	{"RSYP", 4, 214226},
	{"REZU", 4, 214227},
	{"RCBA", 4, 214228},
	{"OFXR", 4, 214229},
	{"NZUN", 4, 214230},
	{"NACF", 4, 214231},
	{"MUCI", 4, 214232},
	{"MLYM", 4, 214233},
	{"LAMJ", 4, 214234},
	{"KIIW", 4, 214235},
	{"KHAJ", 4, 214236},
	{"JVAN", 4, 214237},
	{"HUTF", 4, 214238},
	{"FAMT", 4, 214239},
	{"FAGH", 4, 214240},
	{"EWRS", 4, 214241},
	{"EUTU", 4, 214242},
	{"ETMP", 4, 214243},
	{"ESBM", 4, 214244},
	{"EMMG", 4, 214245},
	{"EFMS", 4, 214246},
	{"DUBT", 4, 214247},
	{"DTUP", 4, 214248},
	{"DORQ", 4, 214249},
	{"CHLS", 4, 214250},
	{"BFAL", 4, 214251},
	{"ANBB", 4, 214252},
	{"STATISTI", 8, 214253},
	{"DOORY", 5, 214254},
	{"WINDFARMS", 9, 214255},
	{"UNMENTIONABLE", 13, 214256},
	{"SKIATOOK", 8, 214257},
	{"ATTIAS", 6, 214258},
	{"UNIMPEACHABLE", 13, 214259},
	{"NASELJE", 7, 214260},
	{"ROACHE", 6, 214261},
	{"MEDITATES", 9, 214262},
	{"CIEGO", 5, 214263},
	{"PERSUASIVENESS", 14, 214264},
	{"KONCERT", 7, 214265},
	{"SOLIDI", 6, 214266},
	{"SIMPATICO", 9, 214267},
	{"RARO", 4, 214268},
	{"GDG", 3, 214269},
	{"BARCODED", 8, 214270},
	{"PRAWF", 5, 214271},
	{"MANZWORLD", 9, 214272},
	{"EXTRANS", 7, 214273},
	{"STIERS", 6, 214274},
	{"PROPYLPARABEN", 13, 214275},
	{"GESCHENKE", 9, 214276},
	{"CREATIVENESS", 12, 214277},
	{"NCADI", 5, 214278},
	{"MALLEABILITY", 12, 214279},
	{"ACOMIDATION", 11, 214280},
	{"MUTLI", 5, 214281},
	{"HARDHAT", 7, 214282},
	{"UNDERPAYMENTS", 13, 214283},
	{"YASMEEN", 7, 214284},
	{"CHEERILY", 8, 214285},
	{"BIBLIOGRAPHER", 13, 214286},
	{"THEODOROS", 9, 214287},
	{"CAVORTING", 9, 214288},
	{"SICKBAY", 7, 214289},
	{"FREUDENTHAL", 11, 214290},
	{"FOURNISSEUR", 11, 214291},
	{"PAPAVERINE", 10, 214292},
	{"ALEKHINE", 8, 214293},
	{"HERAUSGEGEBEN", 13, 214294},
	{"CABEL", 5, 214295},
	{"JUSIC", 5, 214296},
	{"URINATED", 8, 214297},
	{"RATDOG", 6, 214298},
	{"MENAHEM", 7, 214299},
	{"ALKENE", 6, 214300},
	{"ZIGGURAT", 8, 214301},
	{"NONMONETARY", 11, 214302},
	{"TTAGETFIRSTCHILD", 16, 214303},
	{"VTKDATAOBJECT", 13, 214304},
	{"MINATURES", 9, 214305},
	{"PAYET", 5, 214306},
	{"DETONATIONS", 11, 214307},
	{"AMALTHEA", 8, 214308},
	{"ZEFFIRELLI", 10, 214309},
	{"ABBO", 4, 214310},
	{"HOFNER", 6, 214311},
	{"DECLARATOR", 10, 214312},
	{"DEBAR", 5, 214313},
	{"BALLYKISSANGEL", 14, 214314},
	{"MINDESTENS", 10, 214315},
	{"JACKLIN", 7, 214316},
	{"CHEMEXPER", 9, 214317},
	{"PHOTOSHOPS", 10, 214318},
	{"LSSU", 4, 214319},
	{"NEVEN", 5, 214320},
	{"FAINTNESS", 9, 214321},
	{"MAMTA", 5, 214322},
	{"GROUNDHOGS", 10, 214323},
	{"CLUBBIN", 7, 214324},
	{"DOWNLOADA", 9, 214325},
	{"PASSALONG", 9, 214326},
	{"NIKLAUS", 7, 214327},
	{"STORFJORDEN", 11, 214328},
	{"ATTELL", 6, 214329},
	{"ASAKURA", 7, 214330},
	{"FIGUEIRA", 8, 214331},
	{"DEMARCATE", 9, 214332},
	{"VANZANT", 7, 214333},
	{"OAKESHOTT", 9, 214334},
	{"THEPEG", 6, 214335},
	{"ZSCHECH", 7, 214336},
	{"BHAVA", 5, 214337},
	{"RODENSTOCK", 10, 214338},
	{"FORDSON", 7, 214339},
	{"ELECTROHOME", 11, 214340},
	{"CARDELLI", 8, 214341},
	{"REFERENZEN", 10, 214342},
	{"GRANDPAS", 8, 214343},
	{"CLWB", 4, 214344},
	{"BRIGHTWELL", 10, 214345},
	{"ENTEL", 5, 214346},
	{"SANDALL", 7, 214347},
	{"NORTHANGER", 10, 214348},
	{"EFFACED", 7, 214349},
	{"DAMSELFLY", 9, 214350},
	{"CRAZILY", 7, 214351},
	{"GEOMAGNETISM", 12, 214352},
	{"REGULARISATION", 14, 214353},
	{"MESELF", 6, 214354},
	{"MONGKOK", 7, 214355},
	{"DEINSTALL", 9, 214356},
	{"BEGUILE", 7, 214357},
	{"ABERAERON", 9, 214358},
	{"SELCUK", 6, 214359},
	{"GATORLAND", 9, 214360},
	{"BACKPRESSURE", 12, 214361},
	{"POLISARIO", 9, 214362},
	{"BRADYRHIZOBIUM", 14, 214363},
	{"WOODVIEW", 8, 214364},
	{"HIGHFIELDS", 10, 214365},
	{"GYPSYMAN", 8, 214366},
	{"UNDRAFTED", 9, 214367},
	{"REVENUS", 7, 214368},
	{"DISTRIBUT", 9, 214369},
	{"CROSSBILL", 9, 214370},
	{"CNIDARIA", 8, 214371},
	{"GEEKFINDER", 10, 214372},
	{"OLEARI", 6, 214373},
	{"HOBBYZONE", 9, 214374},
	{"EUCALYPTS", 9, 214375},
	{"SASSONE", 7, 214376},
	{"RYKER", 5, 214377},
	{"NIGHTSHIRTS", 11, 214378},
	{"BADIN", 5, 214379},
	{"ROBINSONVILLE", 13, 214380},
	{"WEBWORLD", 8, 214381},
	{"REOCCURRENCE", 12, 214382},
	{"KHOU", 4, 214383},
	{"EXPLICATED", 10, 214384},
	{"ASCENTIA", 8, 214385},
	{"WORKOVER", 8, 214386},
	{"SENARIO", 7, 214387},
	{"INSHALLAH", 9, 214388},
	{"DODEA", 5, 214389},
	{"SVERDLOVSK", 10, 214390},
	{"ENVIO", 5, 214391},
	{"MAMMAS", 6, 214392},
	{"LOUDS", 5, 214393},
	{"HEARTEDNESS", 11, 214394},
	{"BINGES", 6, 214395},
	{"KUNZITE", 7, 214396},
	{"CYTOMEL", 7, 214397},
	{"UPPERCLASS", 10, 214398},
	{"WARDNER", 7, 214399},
	{"PERMEASES", 9, 214400},
	{"BOIES", 5, 214401},
	{"ZMIG", 4, 214402},
	{"YIWR", 4, 214403},
	{"YCZA", 4, 214404},
	{"XTFL", 4, 214405},
	{"WWTO", 4, 214406},
	{"VOYR", 4, 214407},
	{"UILH", 4, 214408},
	{"UCOT", 4, 214409},
	{"TYVS", 4, 214410},
	{"RRIU", 4, 214411},
	{"RMII", 4, 214412},
	{"PADJ", 4, 214413},
	{"OOUP", 4, 214414},
	{"ODZO", 4, 214415},
	{"NUHF", 4, 214416},
	{"NMCR", 4, 214417},
	{"MNLE", 4, 214418},
	{"MBCE", 4, 214419},
	{"LRIM", 4, 214420},
	{"LPDA", 4, 214421},
	{"LEOZ", 4, 214422},
	{"LCPR", 4, 214423},
	{"LCBS", 4, 214424},
	{"KKNA", 4, 214425},
	{"KIOM", 4, 214426},
	{"JCAA", 4, 214427},
	{"ITZJ", 4, 214428},
	{"IKFI", 4, 214429},
	{"IICR", 4, 214430},
	{"IBMO", 4, 214431},
	{"HKDO", 4, 214432},
	{"FOPH", 4, 214433},
	{"FBHU", 4, 214434},
	{"FAMH", 4, 214435},
	{"EWIB", 4, 214436},
	{"ENCF", 4, 214437},
	{"DRII", 4, 214438},
	{"DFAG", 4, 214439},
	{"COXB", 4, 214440},
	{"CKIK", 4, 214441},
	{"CDIZ", 4, 214442},
	{"AYPP", 4, 214443},
	{"AELZ", 4, 214444},
	{"AAFG", 4, 214445},
	{"CIRS", 4, 214446},
	{"BERLIND", 7, 214447},
	{"STRATITEC", 9, 214448},
	{"INFERENCING", 11, 214449},
	{"FORESHADOWS", 11, 214450},
	{"LEVENT", 6, 214451},
	{"FDEP", 4, 214452},
	{"ALTERRA", 7, 214453},
	{"VAJRAYANA", 9, 214454},
	{"POSTBACCALAUREATE", 17, 214455},
	{"MASCOUTAH", 9, 214456},
	{"DIGGLE", 6, 214457},
	{"JIANGUO", 7, 214458},
	{"OBJECTDOCK", 10, 214459},
	{"RACELAND", 8, 214460},
	{"MDCH", 4, 214461},
	{"FARNESYL", 8, 214462},
	{"COONAN", 6, 214463},
	{"IRCNET", 6, 214464},
	{"LANFORD", 7, 214465},
	{"NATURALI", 8, 214466},
	{"FRIEDEMANN", 10, 214467},
	{"TOREX", 5, 214468},
	{"TALLCOOLONE", 11, 214469},
	{"MERNIT", 6, 214470},
	{"INHALATIONAL", 12, 214471},
	{"MYLANTA", 7, 214472},
	{"BOMBAS", 6, 214473},
	{"ERRORLOG", 8, 214474},
	{"GWERTH", 6, 214475},
	{"SMOOCHES", 8, 214476},
	{"RUKA", 4, 214477},
	{"HOAGIES", 7, 214478},
	{"MINIMALITY", 10, 214479},
	{"DOCUDRAMA", 9, 214480},
	{"BOOTBLOG", 8, 214481},
	{"KUERTEN", 7, 214482},
	{"COTONEASTER", 11, 214483},
	{"PRETATION", 9, 214484},
	{"NUDECAMS", 8, 214485},
	{"EMBEZZLED", 9, 214486},
	{"HEDGECO", 7, 214487},
	{"CLASSIXX", 8, 214488},
	{"STICKLEBACK", 11, 214489},
	{"GREENSPOINT", 11, 214490},
	{"GLOGG", 5, 214491},
	{"EMBROIDERERS", 12, 214492},
	{"AMALGAMATIONS", 13, 214493},
	{"SUCCASUNNA", 10, 214494},
	{"SEALAB", 6, 214495},
	{"RODO", 4, 214496},
	{"MIRAGES", 7, 214497},
	{"KITTIWAKE", 9, 214498},
	{"INTERPRETE", 10, 214499},
	{"DUWAMISH", 8, 214500},
	{"BERKNER", 7, 214501},
	{"SHOPFACTORY", 11, 214502},
	{"PATNAIK", 7, 214503},
	{"DOFS", 4, 214504},
	{"DAGAR", 5, 214505},
	{"CVSTEST", 7, 214506},
	{"VENIZELOS", 9, 214507},
	{"FAYARD", 6, 214508},
	{"PALEOMAGNETIC", 13, 214509},
	{"GIOACCHINO", 10, 214510},
	{"DECORTE", 7, 214511},
	{"INDUSTRIAS", 10, 214512},
	{"REARGUARD", 9, 214513},
	{"PIERIS", 6, 214514},
	{"DESTRUCTIONS", 12, 214515},
	{"MLJ", 3, 214516},
	{"OPTIMAX", 7, 214517},
	{"PCSS", 4, 214518},
	{"TITTENBUCHUNG", 13, 214519},
	{"ADALT", 5, 214520},
	{"KRAVEN", 6, 214521},
	{"CHAZAL", 6, 214522},
	{"PISCOPO", 7, 214523},
	{"OFFICEHOLDER", 12, 214524},
	{"SAIDE", 5, 214525},
	{"POWERFREESTUFF", 14, 214526},
	{"POPOL", 5, 214527},
	{"MICROPLATES", 11, 214528},
	{"MAHAVIR", 7, 214529},
	{"WEBMINERAL", 10, 214530},
	{"INEXTRICABLE", 12, 214531},
	{"CRUFTS", 6, 214532},
	{"CANTERA", 7, 214533},
	{"REPECHAGE", 9, 214534},
	{"CLOUSER", 7, 214535},
	{"DEDDF", 5, 214536},
	{"BONELLI", 7, 214537},
	{"ZYMOL", 5, 214538},
	{"RAMESES", 7, 214539},
	{"UHLIG", 5, 214540},
	{"GUIDEWIRE", 9, 214541},
	{"ANSBACH", 7, 214542},
	{"SCHLICHTING", 11, 214543},
	{"CARPI", 5, 214544},
	{"KADABRA", 7, 214545},
	{"SYBILLA", 7, 214546},
	{"RSRCH", 5, 214547},
	{"DMERC", 5, 214548},
	{"SUPERKARAMBA", 12, 214549},
	{"STORIESFREE", 11, 214550},
	{"PIACERE", 7, 214551},
	{"FUGAWI", 6, 214552},
	{"DITTMAR", 7, 214553},
	{"ANZLIC", 6, 214554},
	{"WATERSKIS", 9, 214555},
	{"RACERBACK", 9, 214556},
	{"ONDERDELEN", 10, 214557},
	{"INVENDIUM", 9, 214558},
	{"UNEMPLOY", 8, 214559},
	{"MUSID", 5, 214560},
	{"ABMS", 4, 214561},
	{"WATCHBLOG", 9, 214562},
	{"STROMAN", 7, 214563},
	{"BURNOUTS", 8, 214564},
	{"SATINE", 6, 214565},
	{"REPETTO", 7, 214566},
	{"PAMELOR", 7, 214567},
	{"TIPOFF", 6, 214568},
	{"DISJUNCTIONS", 12, 214569},
	{"ALLEMAAL", 8, 214570},
	{"ATTORNY", 7, 214571},
	{"NYLANDER", 8, 214572},
	{"UNDERPRICING", 12, 214573},
	{"SIMPLETYPE", 10, 214574},
	{"SIGNBOARDS", 10, 214575},
	{"MIRAMARE", 8, 214576},
	{"SMARTT", 6, 214577},
	{"GUARRA", 6, 214578},
	{"UNLOCKTOPIC", 11, 214579},
	{"GUNDERLOY", 9, 214580},
	{"FFYRDD", 6, 214581},
	{"ESTERNO", 7, 214582},
	{"STRC", 4, 214583},
	{"POPERY", 6, 214584},
	{"MISIONES", 8, 214585},
	{"BASHAN", 6, 214586},
	{"TRUSTFUL", 8, 214587},
	{"FIXATE", 6, 214588},
	{"ERWITT", 6, 214589},
	{"CAROLI", 6, 214590},
	{"ALFABETICALLY", 13, 214591},
	{"MANSA", 5, 214592},
	{"GREYSTONES", 10, 214593},
	{"ZUHA", 4, 214594},
	{"ZLAC", 4, 214595},
	{"ZEKS", 4, 214596},
	{"YRDB", 4, 214597},
	{"YNMU", 4, 214598},
	{"YJAB", 4, 214599},
	{"XYWI", 4, 214600},
	{"XORN", 4, 214601},
	{"XDOU", 4, 214602},
	{"WDHU", 4, 214603},
	{"UCAW", 4, 214604},
	{"UBVI", 4, 214605},
	{"TAGY", 4, 214606},
	{"SQLD", 4, 214607},
	{"SIDF", 4, 214608},
	{"RZEW", 4, 214609},
	{"RYGY", 4, 214610},
	{"RULS", 4, 214611},
	{"ROUF", 4, 214612},
	{"RMJE", 4, 214613},
	{"REBN", 4, 214614},
	{"RDPC", 4, 214615},
	{"POPV", 4, 214616},
	{"PIGB", 4, 214617},
	{"OFDL", 4, 214618},
	{"NPFO", 4, 214619},
	{"MTMO", 4, 214620},
	{"MPUC", 4, 214621},
	{"MPOK", 4, 214622},
	{"KOKR", 4, 214623},
	{"KMWA", 4, 214624},
	{"KMEH", 4, 214625},
	{"JURR", 4, 214626},
	{"IUYI", 4, 214627},
	{"IOLD", 4, 214628},
	{"IDYC", 4, 214629},
	{"HJEL", 4, 214630},
	{"GUIE", 4, 214631},
	{"GITK", 4, 214632},
	{"FDRW", 4, 214633},
	{"FBPS", 4, 214634},
	{"EVWO", 4, 214635},
	{"ERHB", 4, 214636},
	{"ECDF", 4, 214637},
	{"DMGM", 4, 214638},
	{"DMBE", 4, 214639},
	{"DAWL", 4, 214640},
	{"CYOC", 4, 214641},
	{"CHDW", 4, 214642},
	{"BYMP", 4, 214643},
	{"AZIJ", 4, 214644},
	{"AMBB", 4, 214645},
	{"AIQU", 4, 214646},
	{"CIABATTA", 8, 214647},
	{"GWAII", 5, 214648},
	{"AMORT", 5, 214649},
	{"LEWDNESS", 8, 214650},
	{"KIENZLE", 7, 214651},
	{"FAILLE", 6, 214652},
	{"ECOTALK", 7, 214653},
	{"BRECKLAND", 9, 214654},
	{"TURMAN", 6, 214655},
	{"MOISTURIZATION", 14, 214656},
	{"MISGUIDE", 8, 214657},
	{"CRISTIN", 7, 214658},
	{"VALLIS", 6, 214659},
	{"SMARTST", 7, 214660},
	{"EIGENSTATE", 10, 214661},
	{"ARMIJO", 6, 214662},
	{"MCKENZIES", 9, 214663},
	{"MUJAHEDIN", 9, 214664},
	{"CHETUMAL", 8, 214665},
	{"VEIRS", 5, 214666},
	{"PARAVIEW", 8, 214667},
	{"GETED", 5, 214668},
	{"MAILSCAN", 8, 214669},
	{"TJUTA", 5, 214670},
	{"OPRAHNESS", 9, 214671},
	{"VIENNAAUTOSHOW", 14, 214672},
	{"NETWORTH", 8, 214673},
	{"WBAL", 4, 214674},
	{"EROTICY", 7, 214675},
	{"APIARIES", 8, 214676},
	{"SUKANTA", 7, 214677},
	{"GLUCOMANNAN", 11, 214678},
	{"BREEZEWAY", 9, 214679},
	{"ZFISH", 5, 214680},
	{"ROTER", 5, 214681},
	{"OPTEKA", 6, 214682},
	{"KNULLA", 6, 214683},
	{"FAZAL", 5, 214684},
	{"CASHMORE", 8, 214685},
	{"DUREN", 5, 214686},
	{"MAUDIE", 6, 214687},
	{"MACHOS", 6, 214688},
	{"MILLIPEDES", 10, 214689},
	{"LOOTER", 6, 214690},
	{"EDICION", 7, 214691},
	{"GORIZIA", 7, 214692},
	{"CORDATA", 7, 214693},
	{"MASSAD", 6, 214694},
	{"DESPINA", 7, 214695},
	{"NPPL", 4, 214696},
	{"GARDING", 7, 214697},
	{"PHIR", 4, 214698},
	{"MULTIFACTOR", 11, 214699},
	{"TRANSVESTISM", 12, 214700},
	{"GREATSKIN", 9, 214701},
	{"ALESHA", 6, 214702},
	{"UNEARTHS", 8, 214703},
	{"PDW", 3, 214704},
	{"LOTERIJ", 7, 214705},
	{"FASCICLE", 8, 214706},
	{"CHEESESTEAK", 11, 214707},
	{"NMMA", 4, 214708},
	{"MISSPELL", 8, 214709},
	{"MALAWIAN", 8, 214710},
	{"BESUCHST", 8, 214711},
	{"WELLL", 5, 214712},
	{"NASTASE", 7, 214713},
	{"GAWRILOW", 8, 214714},
	{"COYLY", 5, 214715},
	{"MYCOPHENOLATE", 13, 214716},
	{"MALINGERING", 11, 214717},
	{"BLACKSTREET", 11, 214718},
	{"PONTON", 6, 214719},
	{"EDDELBUETTEL", 12, 214720},
	{"AMSTELVEEN", 10, 214721},
	{"DARWINISTS", 10, 214722},
	{"SOFTRIDE", 8, 214723},
	{"SANAM", 5, 214724},
	{"NOTLEY", 6, 214725},
	{"GRAEBER", 7, 214726},
	{"AKALI", 5, 214727},
	{"WOTAN", 5, 214728},
	{"DIXI", 4, 214729},
	{"SHAFTING", 8, 214730},
	{"YAQUINA", 7, 214731},
	{"HDAC", 4, 214732},
	{"DESTRO", 6, 214733},
	{"SHAKED", 6, 214734},
	{"CHRISTAL", 8, 214735},
	{"UNMC", 4, 214736},
	{"CHORALES", 8, 214737},
	{"PALTAK", 6, 214738},
	{"GRAVID", 6, 214739},
	{"ENANTIOMER", 10, 214740},
	{"QDISC", 5, 214741},
	{"IMPRIMABLE", 10, 214742},
	{"FICULT", 6, 214743},
	{"ARTISTER", 8, 214744},
	{"OWUSU", 5, 214745},
	{"MOULINEAUX", 10, 214746},
	{"DVDSOURCE", 9, 214747},
	{"DESTROOT", 8, 214748},
	{"MILTARY", 7, 214749},
	{"ELSEN", 5, 214750},
	{"BIOSOURCE", 9, 214751},
	{"SMIC", 4, 214752},
	{"PECH", 4, 214753},
	{"STONEBRAKER", 11, 214754},
	{"SUPERDUPERITEM", 14, 214755},
	{"BUFR", 4, 214756},
	{"PICZ", 4, 214757},
	{"ACOMMIDATION", 12, 214758},
	{"LILLIS", 6, 214759},
	{"INFP", 4, 214760},
	{"ALTY", 4, 214761},
	{"WARMWATER", 9, 214762},
	{"ICONZ", 5, 214763},
	{"DOGEN", 5, 214764},
	{"DNAK", 4, 214765},
	{"ACOUSTECH", 9, 214766},
	{"TICKETSWITCH", 12, 214767},
	{"TANDARDS", 8, 214768},
	{"SCHMEISER", 9, 214769},
	{"FORMULATORS", 11, 214770},
	{"LESUEUR", 7, 214771},
	{"KESTRELS", 8, 214772},
	{"ESCHE", 5, 214773},
	{"KODALY", 6, 214774},
	{"JOHARI", 6, 214775},
	{"JAGANNATH", 9, 214776},
	{"MASATAKA", 8, 214777},
	{"ROSSMANN", 8, 214778},
	{"LINENUMBER", 10, 214779},
	{"LGLIB", 5, 214780},
	{"LUDGER", 6, 214781},
	{"SIBENIK", 7, 214782},
	{"PHPMAILER", 9, 214783},
	{"PENTOSE", 7, 214784},
	{"HOMANN", 6, 214785},
	{"DUCALE", 6, 214786},
	{"WOAD", 4, 214787},
	{"COMD", 4, 214788},
	{"KORVER", 6, 214789},
	{"INTERLINKING", 12, 214790},
	{"CANDESARTAN", 11, 214791},
	{"BRASSWARE", 9, 214792},
	{"UUM", 3, 214793},
	{"KAYLYNN", 7, 214794},
	{"NASCA", 5, 214795},
	{"EXITO", 5, 214796},
	{"CKP", 3, 214797},
	{"UBX", 3, 214798},
	{"JUGHEAD", 7, 214799},
	{"USUSALLY", 8, 214800},
	{"PEPPERTREE", 10, 214801},
	{"BARINGS", 7, 214802},
	{"LAMBIC", 6, 214803},
	{"DEMYELINATION", 13, 214804},
	{"CHEYANNE", 8, 214805},
	{"ALTAF", 5, 214806},
	{"STEPHENIE", 9, 214807},
	{"ELECTROPHILIC", 13, 214808},
	{"YUDI", 4, 214809},
	{"YPMW", 4, 214810},
	{"YMTV", 4, 214811},
	{"XWAN", 4, 214812},
	{"XRIO", 4, 214813},
	{"WGAY", 4, 214814},
	{"VHER", 4, 214815},
	{"VBOA", 4, 214816},
	{"USRY", 4, 214817},
	{"THCF", 4, 214818},
	{"THBM", 4, 214819},
	{"TAXV", 4, 214820},
	{"SMCB", 4, 214821},
	{"RYVS", 4, 214822},
	{"RVLE", 4, 214823},
	{"ROGP", 4, 214824},
	{"RLAX", 4, 214825},
	{"REVN", 4, 214826},
	{"RDCT", 4, 214827},
	{"PLTH", 4, 214828},
	{"ORMQ", 4, 214829},
	{"OJIL", 4, 214830},
	{"OAPW", 4, 214831},
	{"NECP", 4, 214832},
	{"MSIK", 4, 214833},
	{"MKAP", 4, 214834},
	{"MCIA", 4, 214835},
	{"LZBE", 4, 214836},
	{"LSUO", 4, 214837},
	{"LOOV", 4, 214838},
	{"LELG", 4, 214839},
	{"LDTB", 4, 214840},
	{"LDKU", 4, 214841},
	{"ILSQ", 4, 214842},
	{"HWAJ", 4, 214843},
	{"GHEJ", 4, 214844},
	{"FWAU", 4, 214845},
	{"FKEM", 4, 214846},
	{"EUMV", 4, 214847},
	{"DUKK", 4, 214848},
	{"CPUP", 4, 214849},
	{"BZON", 4, 214850},
	{"BYTK", 4, 214851},
	{"BPIT", 4, 214852},
	{"HAZAN", 5, 214853},
	{"CPIM", 4, 214854},
	{"BAINE", 5, 214855},
	{"BABINE", 6, 214856},
	{"SHANTA", 6, 214857},
	{"PLECO", 5, 214858},
	{"IRRAWADDY", 9, 214859},
	{"SUBGRANTEE", 10, 214860},
	{"PLAINSONG", 9, 214861},
	{"INTRATRACHEAL", 13, 214862},
	{"THRID", 5, 214863},
	{"RECOMENDADO", 11, 214864},
	{"ACHALASIA", 9, 214865},
	{"GROOP", 5, 214866},
	{"FIRELITE", 8, 214867},
	{"SANDWITCH", 9, 214868},
	{"MACLAURIN", 9, 214869},
	{"BOHLIN", 6, 214870},
	{"GABBARD", 7, 214871},
	{"ZWANE", 5, 214872},
	{"SECHREST", 8, 214873},
	{"PURSH", 5, 214874},
	{"MULTIZONE", 9, 214875},
	{"UPCONVERSION", 12, 214876},
	{"MAGICPOINT", 10, 214877},
	{"ULLOA", 5, 214878},
	{"STEADYSHOT", 10, 214879},
	{"HOUSEBROKEN", 11, 214880},
	{"CONVIENCE", 9, 214881},
	{"PHONOGRAM", 9, 214882},
	{"CELIS", 5, 214883},
	{"SATIATE", 7, 214884},
	{"MAPUCHE", 7, 214885},
	{"GWIRFODDOL", 10, 214886},
	{"KINFOCENTER", 11, 214887},
	{"TOLBUTAMIDE", 11, 214888},
	{"PHEROBASE", 9, 214889},
	{"SORGE", 5, 214890},
	{"NOTUNDELEND", 11, 214891},
	{"ENDOSC", 6, 214892},
	{"PINNELL", 7, 214893},
	{"CLEARBLUE", 9, 214894},
	{"SAFON", 5, 214895},
	{"STEVIES", 7, 214896},
	{"YAMILA", 6, 214897},
	{"KIDSPACE", 8, 214898},
	{"GOCH", 4, 214899},
	{"DELENN", 6, 214900},
	{"STUPEFIED", 9, 214901},
	{"REALGM", 6, 214902},
	{"DETACHEES", 9, 214903},
	{"CLJ", 3, 214904},
	{"MUSIF", 5, 214905},
	{"TUGBOATS", 8, 214906},
	{"PENNSYL", 7, 214907},
	{"AUSSTELLUNGEN", 13, 214908},
	{"MOTABILITY", 10, 214909},
	{"GTCAG", 5, 214910},
	{"POPULARIZING", 12, 214911},
	{"VINDIGO", 7, 214912},
	{"JOURNOS", 7, 214913},
	{"FILMATO", 7, 214914},
	{"MCHARDY", 7, 214915},
	{"ENTRETENIMIENTO", 15, 214916},
	{"TREU", 4, 214917},
	{"DIGICEL", 7, 214918},
	{"CAIRE", 5, 214919},
	{"PREDA", 5, 214920},
	{"NITROSAMINES", 12, 214921},
	{"GYU", 3, 214922},
	{"BRASSES", 7, 214923},
	{"LETHE", 5, 214924},
	{"AGGIORNATO", 10, 214925},
	{"FINANCIA", 8, 214926},
	{"ROTTON", 6, 214927},
	{"ELEMENTO", 8, 214928},
	{"DEMOD", 5, 214929},
	{"SECONDES", 8, 214930},
	{"RTDS", 4, 214931},
	{"EMBOLUS", 7, 214932},
	{"PMPO", 4, 214933},
	{"MOTHBOARD", 9, 214934},
	{"FIDJI", 5, 214935},
	{"HUMMM", 5, 214936},
	{"SCIENTOMETRICS", 14, 214937},
	{"SCHNELLSUCHE", 12, 214938},
	{"RAPSTER", 7, 214939},
	{"HEPP", 4, 214940},
	{"ASTYANAX", 8, 214941},
	{"ULUDAG", 6, 214942},
	{"INTERCHG", 8, 214943},
	{"DEZINA", 6, 214944},
	{"HETTIE", 6, 214945},
	{"HIRSCHHORN", 10, 214946},
	{"GERAGOS", 7, 214947},
	{"COMPETITVE", 10, 214948},
	{"ULITMATE", 8, 214949},
	{"DOGBANE", 7, 214950},
	{"WARRIER", 7, 214951},
	{"LIVESUPPORT", 11, 214952},
	{"LAWQUOTE", 8, 214953},
	{"TEPEE", 5, 214954},
	{"UTBILDNING", 10, 214955},
	{"NEWGROUP", 8, 214956},
	{"MEITO", 5, 214957},
	{"KIGER", 5, 214958},
	{"PUFFBALL", 8, 214959},
	{"GOUGET", 6, 214960},
	{"CALCULATORRETIREMENT", 20, 214961},
	{"TITTENGRIECHENLAND", 18, 214962},
	{"SAUKVILLE", 9, 214963},
	{"QCIF", 4, 214964},
	{"NOURBAKHSH", 10, 214965},
	{"NAVITEX", 7, 214966},
	{"GRIECHENLANDBAUERNHOF", 21, 214967},
	{"RPGFAN", 6, 214968},
	{"NORTHPARK", 9, 214969},
	{"ILLUMINATUS", 11, 214970},
	{"RABINOVICH", 10, 214971},
	{"PATHUMWAN", 9, 214972},
	{"OUTRAM", 6, 214973},
	{"FASTMAIL", 8, 214974},
	{"SZECHWAN", 8, 214975},
	{"DERNIERE", 8, 214976},
	{"CUSTOMERSERVICE", 15, 214977},
	{"KOFF", 4, 214978},
	{"SHIMOMURA", 9, 214979},
	{"LECKT", 5, 214980},
	{"FREYCINET", 9, 214981},
	{"NIEUPORT", 8, 214982},
	{"ZJZ", 3, 214983},
	{"ZGZ", 3, 214984},
	{"ZCG", 3, 214985},
	{"XFQ", 3, 214986},
	{"UQG", 3, 214987},
	{"QLX", 3, 214988},
	{"KGX", 3, 214989},
	{"JBX", 3, 214990},
	{"JBQ", 3, 214991},
	{"GVQ", 3, 214992},
	{"GFQ", 3, 214993},
	{"FQY", 3, 214994},
	{"BZX", 3, 214995},
	{"BXJ", 3, 214996},
	{"BVY", 3, 214997},
	{"FAMITSU", 7, 214998},
	{"ZHARK", 5, 214999},
	{"PLAYARD", 7, 215000},
	{"PRIVA", 5, 215001},
	{"FLYTRAP", 7, 215002},
	{"DOWSE", 5, 215003},
	{"SIGURDSSON", 10, 215004},
	{"BUGDOM", 6, 215005},
	{"MUF", 3, 215006},
	{"CMOV", 4, 215007},
	{"GRWP", 4, 215008},
	{"EVOLVABLE", 9, 215009},
	{"EUPHEMIA", 8, 215010},
	{"DISMANTLES", 10, 215011},
	{"BUSK", 4, 215012},
	{"BRAMLETT", 8, 215013},
	{"ANGELICUS", 9, 215014},
	{"SCATTYFOX", 9, 215015},
	{"SCHAFFE", 7, 215016},
	{"LIBINTL", 7, 215017},
	{"INITDB", 6, 215018},
	{"FASTHEALTH", 10, 215019},
	{"DURATRAX", 8, 215020},
	{"UGANDANS", 8, 215021},
	{"NAVAIDS", 7, 215022},
	{"RETRACTORS", 10, 215023},
	{"QUSAY", 5, 215024},
	{"DIMAXX", 6, 215025},
	{"JOUE", 4, 215026},
	{"ELEPHANTINE", 11, 215027},
	{"VBRICK", 6, 215028},
	{"MEASURELESS", 11, 215029},
	{"KINKED", 6, 215030},
	{"WISHIN", 6, 215031},
	{"NORTHEASTWARD", 13, 215032},
	{"MOEVENPICK", 10, 215033},
	{"ZBRI", 4, 215034},
	{"YRHA", 4, 215035},
	{"WTAG", 4, 215036},
	{"WRYT", 4, 215037},
	{"WITY", 4, 215038},
	{"WBAK", 4, 215039},
	{"VYSS", 4, 215040},
	{"VWIN", 4, 215041},
	{"UDPU", 4, 215042},
	{"TMWH", 4, 215043},
	{"SRPR", 4, 215044},
	{"SKMB", 4, 215045},
	{"SBCB", 4, 215046},
	{"RYNF", 4, 215047},
	{"RMGM", 4, 215048},
	{"PHMU", 4, 215049},
	{"OXDU", 4, 215050},
	{"OICM", 4, 215051},
	{"NWUL", 4, 215052},
	{"NRUE", 4, 215053},
	{"MTMA", 4, 215054},
	{"MLIP", 4, 215055},
	{"LIWR", 4, 215056},
	{"LDMD", 4, 215057},
	{"LBFO", 4, 215058},
	{"LAVM", 4, 215059},
	{"KDAD", 4, 215060},
	{"INXP", 4, 215061},
	{"INLB", 4, 215062},
	{"IFOV", 4, 215063},
	{"ICEZ", 4, 215064},
	{"GWAM", 4, 215065},
	{"GMSI", 4, 215066},
	{"FNSW", 4, 215067},
	{"EUAV", 4, 215068},
	{"DYEP", 4, 215069},
	{"DUAI", 4, 215070},
	{"DMYY", 4, 215071},
	{"DEVC", 4, 215072},
	{"DBAJ", 4, 215073},
	{"COPB", 4, 215074},
	{"CLYL", 4, 215075},
	{"BIFA", 4, 215076},
	{"BCTR", 4, 215077},
	{"AYLM", 4, 215078},
	{"ASYK", 4, 215079},
	{"AGDU", 4, 215080},
	{"ADUH", 4, 215081},
	{"SCANDALIZED", 11, 215082},
	{"PARACRINE", 9, 215083},
	{"WFTV", 4, 215084},
	{"REDER", 5, 215085},
	{"LASERPRINTER", 12, 215086},
	{"BELFER", 6, 215087},
	{"PUMORI", 6, 215088},
	{"ASCRIPTION", 10, 215089},
	{"REFTEX", 6, 215090},
	{"MICRODISPLAY", 12, 215091},
	{"NAVPRESS", 8, 215092},
	{"MUVEE", 5, 215093},
	{"MOTRICITY", 9, 215094},
	{"MOMSENSE", 8, 215095},
	{"GMRES", 5, 215096},
	{"OVERFLIGHT", 10, 215097},
	{"MACTEL", 6, 215098},
	{"COMPET", 6, 215099},
	{"PROGDVB", 7, 215100},
	{"FLEXIGLOW", 9, 215101},
	{"CHAISSON", 8, 215102},
	{"BABBLINGS", 9, 215103},
	{"AMAURY", 6, 215104},
	{"LGTH", 4, 215105},
	{"FORTSCHR", 8, 215106},
	{"IACHR", 5, 215107},
	{"GUILHEM", 7, 215108},
	{"BLINKERED", 9, 215109},
	{"EREKTION", 8, 215110},
	{"WOLSKI", 6, 215111},
	{"GENOLEVURES", 11, 215112},
	{"OUTDID", 6, 215113},
	{"MANICS", 6, 215114},
	{"TROPEA", 6, 215115},
	{"TISZA", 5, 215116},
	{"DUITS", 5, 215117},
	{"SCORESBY", 8, 215118},
	{"MUZIO", 5, 215119},
	{"SNOMED", 6, 215120},
	{"ISOSPEEDRATINGS", 15, 215121},
	{"ECOTEC", 6, 215122},
	{"CITYFEET", 8, 215123},
	{"JERKIN", 6, 215124},
	{"KISKI", 5, 215125},
	{"BLOGARITHMIC", 12, 215126},
	{"KAMEI", 5, 215127},
	{"HAMRE", 5, 215128},
	{"GIRSL", 5, 215129},
	{"DOORN", 5, 215130},
	{"LOCKNEY", 7, 215131},
	{"BAUCH", 5, 215132},
	{"UNICHROME", 9, 215133},
	{"DEMERARA", 8, 215134},
	{"JERUSHA", 7, 215135},
	{"HUARD", 5, 215136},
	{"MUTILATING", 10, 215137},
	{"STUNDE", 6, 215138},
	{"NOTICEBOARDS", 12, 215139},
	{"ANGEMELDET", 10, 215140},
	{"AFORETIME", 9, 215141},
	{"CONSTRUCCION", 12, 215142},
	{"PARTLOW", 7, 215143},
	{"ABARTLET", 8, 215144},
	{"YOGURTS", 7, 215145},
	{"MORPHOMETRY", 11, 215146},
	{"KEYE", 4, 215147},
	{"KAPTAIN", 7, 215148},
	{"AKHBAR", 6, 215149},
	{"STANDORT", 8, 215150},
	{"FLAGSTONES", 10, 215151},
	{"CYANINE", 7, 215152},
	{"FLORENZ", 7, 215153},
	{"CREEPIN", 7, 215154},
	{"CONCEPTUALIZATIONS", 18, 215155},
	{"RFDS", 4, 215156},
	{"REDESIGNATE", 11, 215157},
	{"GROENEVELD", 10, 215158},
	{"DUIVEN", 6, 215159},
	{"JAYBIRD", 7, 215160},
	{"ELECDIR", 7, 215161},
	{"PERIMENTAL", 10, 215162},
	{"NAULT", 5, 215163},
	{"EQUAT", 5, 215164},
	{"LOWRIDERS", 9, 215165},
	{"CYTEC", 5, 215166},
	{"TARPORLEY", 9, 215167},
	{"SUBTILISIN", 10, 215168},
	{"REFLECTIVELY", 12, 215169},
	{"BECKTON", 7, 215170},
	{"CODIGOS", 7, 215171},
	{"KINDERMANN", 10, 215172},
	{"HILTS", 5, 215173},
	{"CHAGNON", 7, 215174},
	{"NIEUWENHUIZEN", 13, 215175},
	{"CONSTRUCTIONMAIL", 16, 215176},
	{"MOOMIN", 6, 215177},
	{"TABARROK", 8, 215178},
	{"INTERSET", 8, 215179},
	{"HEALTHWORLD", 11, 215180},
	{"GIMBEL", 6, 215181},
	{"DOWNSPOUT", 9, 215182},
	{"ATBOOTTIME", 10, 215183},
	{"SBORNIK", 7, 215184},
	{"KHUMBU", 6, 215185},
	{"INLAWS", 6, 215186},
	{"HAPPYCHILD", 10, 215187},
	{"CANAPES", 7, 215188},
	{"BUTTERLIES", 10, 215189},
	{"TRACKLESS", 9, 215190},
	{"STOPES", 6, 215191},
	{"TAXIDERMISTS", 12, 215192},
	{"ICBO", 4, 215193},
	{"KORU", 4, 215194},
	{"COPPOCK", 7, 215195},
	{"ABIDED", 6, 215196},
	{"PEREGRINUS", 10, 215197},
	{"INTERSESSIONAL", 14, 215198},
	{"BMNH", 4, 215199},
	{"MELLER", 6, 215200},
	{"CLONINGER", 9, 215201},
	{"AUSGAMERS", 9, 215202},
	{"AVCC", 4, 215203},
	{"PELUSO", 6, 215204},
	{"SKILS", 5, 215205},
	{"LICEN", 5, 215206},
	{"ROLLENSPIELE", 12, 215207},
	{"DEMOGRAPHER", 11, 215208},
	{"KREUZNACH", 9, 215209},
	{"GLOMUS", 6, 215210},
	{"NINTAUS", 7, 215211},
	{"UNTPDC", 6, 215212},
	{"DEDICADA", 8, 215213},
	{"QLEN", 4, 215214},
	{"DEOXYS", 6, 215215},
	{"BUYERZONE", 9, 215216},
	{"SUPERMAJORITY", 13, 215217},
	{"PATRONESS", 9, 215218},
	{"MONISTAT", 8, 215219},
	{"FLECKTONES", 10, 215220},
	{"LYRICSONDEMAND", 14, 215221},
	{"DONIGER", 7, 215222},
	{"ARTICAL", 7, 215223},
	{"CAMOCARE", 8, 215224},
	{"PERFEKT", 7, 215225},
	{"HOYOS", 5, 215226},
	{"SAOTOME", 7, 215227},
	{"MICHE", 5, 215228},
	{"IMPOSSIBILITIES", 15, 215229},
	{"DATACASTING", 11, 215230},
	{"MIRTGAGE", 8, 215231},
	{"SMALLCAPS", 9, 215232},
	{"UPGRADER", 8, 215233},
	{"SUBADDRESS", 10, 215234},
	{"MICROB", 6, 215235},
	{"GEBUNDENE", 9, 215236},
	{"POLYNUCLEOTIDES", 15, 215237},
	{"PITINO", 6, 215238},
	{"INCONSOLABLE", 12, 215239},
	{"CORSTORPHINE", 12, 215240},
	{"HORARY", 6, 215241},
	{"PMSG", 4, 215242},
	{"ZEZI", 4, 215243},
	{"ZDEV", 4, 215244},
	{"ZAGU", 4, 215245},
	{"XYAS", 4, 215246},
	{"XRBI", 4, 215247},
	{"WBUN", 4, 215248},
	{"VSUC", 4, 215249},
	{"VRIT", 4, 215250},
	{"VDBU", 4, 215251},
	{"UTUE", 4, 215252},
	{"UBSK", 4, 215253},
	{"TMPR", 4, 215254},
	{"RPGT", 4, 215255},
	{"PMSC", 4, 215256},
	{"OMIJ", 4, 215257},
	{"OBLY", 4, 215258},
	{"NROK", 4, 215259},
	{"MUDL", 4, 215260},
	{"MRVE", 4, 215261},
	{"MMDE", 4, 215262},
	{"LPEG", 4, 215263},
	{"LFVA", 4, 215264},
	{"LDUO", 4, 215265},
	{"LALY", 4, 215266},
	{"KAWR", 4, 215267},
	{"IYUR", 4, 215268},
	{"IVIU", 4, 215269},
	{"HMUE", 4, 215270},
	{"HDIX", 4, 215271},
	{"HAYU", 4, 215272},
	{"HAGB", 4, 215273},
	{"GMSM", 4, 215274},
	{"ERCV", 4, 215275},
	{"EKAJ", 4, 215276},
	{"DPMJ", 4, 215277},
	{"DIHY", 4, 215278},
	{"DBPA", 4, 215279},
	{"DAIJ", 4, 215280},
	{"CNRE", 4, 215281},
	{"CKUR", 4, 215282},
	{"BIBR", 4, 215283},
	{"BAOW", 4, 215284},
	{"AMMP", 4, 215285},
	{"REALNESS", 8, 215286},
	{"SPIESS", 6, 215287},
	{"GAMESMOTOROLA", 13, 215288},
	{"CTLS", 4, 215289},
	{"SHOULDEST", 9, 215290},
	{"SABRENT", 7, 215291},
	{"LULWORTH", 8, 215292},
	{"ALIEV", 5, 215293},
	{"ZOTOB", 5, 215294},
	{"YAMAMURA", 8, 215295},
	{"TUMMIES", 7, 215296},
	{"RYUN", 4, 215297},
	{"JJR", 3, 215298},
	{"HERBER", 6, 215299},
	{"MICROCOSMS", 10, 215300},
	{"SDMG", 4, 215301},
	{"MEALWORMS", 9, 215302},
	{"AARGAU", 6, 215303},
	{"SEIPP", 5, 215304},
	{"OFFLOADED", 9, 215305},
	{"MARIEHAMN", 9, 215306},
	{"LIUNA", 5, 215307},
	{"METAPHYSICALLY", 14, 215308},
	{"DAREY", 5, 215309},
	{"VIRTU", 5, 215310},
	{"VERGEWALTIGT", 12, 215311},
	{"DOGBYTES", 8, 215312},
	{"EXPLICABLE", 10, 215313},
	{"NICOLAY", 7, 215314},
	{"CSELT", 5, 215315},
	{"MCCOLLOUGH", 10, 215316},
	{"LISTERA", 7, 215317},
	{"FINDU", 5, 215318},
	{"HANGAROO", 8, 215319},
	{"XINTEX", 6, 215320},
	{"BURBIDGE", 8, 215321},
	{"SUBTHRESHOLD", 12, 215322},
	{"PLUCKS", 6, 215323},
	{"OUTDOORSGARDEN", 14, 215324},
	{"BOKEN", 5, 215325},
	{"SLASHCODE", 9, 215326},
	{"QPCR", 4, 215327},
	{"UFD", 3, 215328},
	{"HANDBLOWN", 9, 215329},
	{"SUPERBUG", 8, 215330},
	{"ROLPH", 5, 215331},
	{"UNREASON", 8, 215332},
	{"PITTSVILLE", 10, 215333},
	{"EVISUM", 6, 215334},
	{"BRICKSHOOTER", 12, 215335},
	{"CEOL", 4, 215336},
	{"ANTLE", 5, 215337},
	{"WORLDBUILDER", 12, 215338},
	{"TEMPA", 5, 215339},
	{"GARROD", 6, 215340},
	{"CLARKSTOWN", 10, 215341},
	{"PAPERT", 6, 215342},
	{"OLEX", 4, 215343},
	{"ALDS", 4, 215344},
	{"WATERSMEET", 10, 215345},
	{"REINCARNATE", 11, 215346},
	{"CRUMPTON", 8, 215347},
	{"WREATHED", 8, 215348},
	{"COWARE", 6, 215349},
	{"MUGGERS", 7, 215350},
	{"MARCHESI", 8, 215351},
	{"CARIGNAN", 8, 215352},
	{"VATTON", 6, 215353},
	{"ANTALL", 6, 215354},
	{"CRIMINEL", 8, 215355},
	{"EUROPHYS", 8, 215356},
	{"NARTEN", 6, 215357},
	{"GLENROCK", 8, 215358},
	{"ALEXIUS", 7, 215359},
	{"BALLACK", 7, 215360},
	{"SUNBURNS", 8, 215361},
	{"STRIES", 6, 215362},
	{"GRIMMETT", 8, 215363},
	{"CATEGORISING", 12, 215364},
	{"DARKANE", 7, 215365},
	{"WHEREIS", 7, 215366},
	{"HOLBY", 5, 215367},
	{"STARLOG", 7, 215368},
	{"CREPUSCULE", 10, 215369},
	{"MMJ", 3, 215370},
	{"MELOS", 5, 215371},
	{"SEISMOGRAMS", 11, 215372},
	{"ENTREVISTAS", 11, 215373},
	{"NDATA", 5, 215374},
	{"MARKSMEN", 8, 215375},
	{"DESIDERI", 8, 215376},
	{"COLOURATION", 11, 215377},
	{"ZOEKT", 5, 215378},
	{"MONOLAKE", 8, 215379},
	{"EXIBITION", 9, 215380},
	{"VADNAIS", 7, 215381},
	{"ENTHUSIASMS", 11, 215382},
	{"TROUBADOR", 9, 215383},
	{"SHALHOUB", 8, 215384},
	{"NITSCHKE", 8, 215385},
	{"CLEN", 4, 215386},
	{"TREWS", 5, 215387},
	{"QPSMTPD", 7, 215388},
	{"LIFESOURCE", 10, 215389},
	{"RULLION", 7, 215390},
	{"SBAR", 4, 215391},
	{"DEMONIZATION", 12, 215392},
	{"TAPOS", 5, 215393},
	{"SPAW", 4, 215394},
	{"INTERFER", 8, 215395},
	{"ANTIEMETIC", 10, 215396},
	{"MOLLISON", 8, 215397},
	{"KUSTER", 6, 215398},
	{"BPITCH", 6, 215399},
	{"ROSENBERRY", 10, 215400},
	{"FLUEVOG", 7, 215401},
	{"BADGED", 6, 215402},
	{"NEWMANS", 7, 215403},
	{"INTERRA", 7, 215404},
	{"ROBG", 4, 215405},
	{"GASTROPOD", 9, 215406},
	{"BURRINGTON", 10, 215407},
	{"SLAVEN", 6, 215408},
	{"PROLOGIS", 8, 215409},
	{"TELBEC", 6, 215410},
	{"MOGILEV", 7, 215411},
	{"FIGLET", 6, 215412},
	{"ISOBAR", 6, 215413},
	{"BUGGS", 5, 215414},
	{"ABBASID", 7, 215415},
	{"WHYY", 4, 215416},
	{"RUSTICANA", 9, 215417},
	{"KARIS", 5, 215418},
	{"DANIELSVILLE", 12, 215419},
	{"PERUANA", 7, 215420},
	{"SALTCOATS", 9, 215421},
	{"AGAGO", 5, 215422},
	{"MANICURIST", 10, 215423},
	{"BRDF", 4, 215424},
	{"INTERMINGLE", 11, 215425},
	{"BUGGERY", 7, 215426},
	{"PGINA", 5, 215427},
	{"EXPRESSINDIA", 12, 215428},
	{"SHAHINE", 7, 215429},
	{"SCHULDEN", 8, 215430},
	{"PENGUINSLIVE", 12, 215431},
	{"DOCUPEN", 7, 215432},
	{"MONLY", 5, 215433},
	{"LYNCHINGS", 9, 215434},
	{"DIATE", 5, 215435},
	{"YAHOOO", 6, 215436},
	{"STANDETH", 8, 215437},
	{"PAPIST", 6, 215438},
	{"MIMETYPES", 9, 215439},
	{"GEVEN", 5, 215440},
	{"WFOR", 4, 215441},
	{"MUSKC", 5, 215442},
	{"WABA", 4, 215443},
	{"BILDUA", 6, 215444},
	{"SVERRE", 6, 215445},
	{"KAQE", 4, 215446},
	{"ANTONIOU", 8, 215447},
	{"YNMI", 4, 215448},
	{"YMRK", 4, 215449},
	{"YKMS", 4, 215450},
	{"YHIV", 4, 215451},
	{"YEPH", 4, 215452},
	{"XYWH", 4, 215453},
	{"XELT", 4, 215454},
	{"XCUL", 4, 215455},
	{"WVAS", 4, 215456},
	{"WTAM", 4, 215457},
	{"WIFR", 4, 215458},
	{"VAAF", 4, 215459},
	{"UMGL", 4, 215460},
	{"UGGR", 4, 215461},
	{"TVAW", 4, 215462},
	{"TFKE", 4, 215463},
	{"TBOF", 4, 215464},
	{"TAFC", 4, 215465},
	{"STVM", 4, 215466},
	{"SEDX", 4, 215467},
	{"RZUR", 4, 215468},
	{"RLKI", 4, 215469},
	{"RFSP", 4, 215470},
	{"REHB", 4, 215471},
	{"PYAH", 4, 215472},
	{"PUSJ", 4, 215473},
	{"PHEY", 4, 215474},
	{"PARZ", 4, 215475},
	{"PACG", 4, 215476},
	{"OWYM", 4, 215477},
	{"OKJE", 4, 215478},
	{"ODWY", 4, 215479},
	{"MPCU", 4, 215480},
	{"LOYL", 4, 215481},
	{"LEBP", 4, 215482},
	{"KJOC", 4, 215483},
	{"KDAS", 4, 215484},
	{"KALN", 4, 215485},
	{"JUSA", 4, 215486},
	{"IVPA", 4, 215487},
	{"IVKA", 4, 215488},
	{"HPEC", 4, 215489},
	{"HKAC", 4, 215490},
	{"HDMA", 4, 215491},
	{"FVOW", 4, 215492},
	{"FQAT", 4, 215493},
	{"DVOO", 4, 215494},
	{"DVEW", 4, 215495},
	{"DTYN", 4, 215496},
	{"CYGU", 4, 215497},
	{"BSBL", 4, 215498},
	{"BIKS", 4, 215499},
	{"AUKT", 4, 215500},
	{"ATVF", 4, 215501},
	{"ALXI", 4, 215502},
	{"JUP", 3, 215503},
	{"DVDSHRINK", 9, 215504},
	{"NINTEK", 6, 215505},
	{"LACTOBACILLI", 12, 215506},
	{"PAYOH", 5, 215507},
	{"SIRAJ", 5, 215508},
	{"GENTILLY", 8, 215509},
	{"FITZROVIA", 9, 215510},
	{"GABER", 5, 215511},
	{"MUEIC", 5, 215512},
	{"HUNNICUTT", 9, 215513},
	{"BOLETIN", 7, 215514},
	{"BIDIL", 5, 215515},
	{"REPORTE", 7, 215516},
	{"OLINA", 5, 215517},
	{"GOBEL", 5, 215518},
	{"AMMUCCHIATE", 11, 215519},
	{"WWB", 3, 215520},
	{"QUELLEN", 7, 215521},
	{"LITHOGRAPHED", 12, 215522},
	{"MUSEOLOGY", 9, 215523},
	{"BRIJ", 4, 215524},
	{"BAUMER", 6, 215525},
	{"ZESTRA", 6, 215526},
	{"TATERS", 6, 215527},
	{"SUBEXPRESSIONS", 14, 215528},
	{"LIBI", 4, 215529},
	{"ELISEO", 6, 215530},
	{"FRESHNER", 8, 215531},
	{"BURGAN", 6, 215532},
	{"VALDIFF", 7, 215533},
	{"REXTON", 6, 215534},
	{"MOTORCRAFT", 10, 215535},
	{"PHENDERMINE", 11, 215536},
	{"WINSTRONICS", 11, 215537},
	{"PIPO", 4, 215538},
	{"SUREPOS", 7, 215539},
	{"SOFFE", 5, 215540},
	{"MINERVE", 7, 215541},
	{"MONOZYGOTIC", 11, 215542},
	{"CYBERVIEW", 9, 215543},
	{"SCHACH", 6, 215544},
	{"KOHANIM", 7, 215545},
	{"PINEAU", 6, 215546},
	{"CORSER", 6, 215547},
	{"BLONG", 5, 215548},
	{"INSOUND", 7, 215549},
	{"WERRINGTON", 10, 215550},
	{"THEFORUM", 8, 215551},
	{"DOLLED", 6, 215552},
	{"DHRUV", 5, 215553},
	{"ARGOT", 5, 215554},
	{"MVV", 3, 215555},
	{"MEDIAMOUNTS", 11, 215556},
	{"MARQUESA", 8, 215557},
	{"AGHIOS", 6, 215558},
	{"NAGARAJAN", 9, 215559},
	{"ACCIDENTALS", 11, 215560},
	{"HAFLER", 6, 215561},
	{"EMMI", 4, 215562},
	{"FLASHPLAYER", 11, 215563},
	{"MOOPUNA", 7, 215564},
	{"SWITCHGRASS", 11, 215565},
	{"PNDOCS", 6, 215566},
	{"WORTE", 5, 215567},
	{"WAIALAE", 7, 215568},
	{"UBP", 3, 215569},
	{"XBF", 3, 215570},
	{"MINELRES", 8, 215571},
	{"BELTERRA", 8, 215572},
	{"AUSTENITE", 9, 215573},
	{"TORNILLO", 8, 215574},
	{"SUCCINYL", 8, 215575},
	{"HARDWAREZONE", 12, 215576},
	{"SCHEMBECHLER", 12, 215577},
	{"WILLAM", 6, 215578},
	{"FONTANELLI", 10, 215579},
	{"PUNCTATE", 8, 215580},
	{"ORMEAU", 6, 215581},
	{"LASERPOINT", 10, 215582},
	{"TAMERS", 6, 215583},
	{"GREETIN", 7, 215584},
	{"ARLT", 4, 215585},
	{"POWAZEK", 7, 215586},
	{"MJSIC", 5, 215587},
	{"MALDIVIAN", 9, 215588},
	{"HALOBACTERIUM", 13, 215589},
	{"EUCLIDIAN", 9, 215590},
	{"REOVIRUS", 8, 215591},
	{"ZEBALLOS", 8, 215592},
	{"YOURSITE", 8, 215593},
	{"WAKEHAM", 7, 215594},
	{"PHENTRMINE", 10, 215595},
	{"ADELBERT", 8, 215596},
	{"BREWERTON", 9, 215597},
	{"SWENSEN", 7, 215598},
	{"NUCLEOTIDASE", 12, 215599},
	{"LEMONHEAD", 9, 215600},
	{"DCML", 4, 215601},
	{"OUYANG", 6, 215602},
	{"CCNOW", 5, 215603},
	{"TRETH", 5, 215604},
	{"CERDA", 5, 215605},
	{"ARMINIAN", 8, 215606},
	{"DEPOS", 5, 215607},
	{"CARLON", 6, 215608},
	{"QUIERAS", 7, 215609},
	{"FONTINA", 7, 215610},
	{"DRAVE", 5, 215611},
	{"GERBERDING", 10, 215612},
	{"LUCES", 5, 215613},
	{"CHOREOGRAPH", 11, 215614},
	{"BLOWED", 6, 215615},
	{"VBNEWLINE", 9, 215616},
	{"NEWD", 4, 215617},
	{"FHSAA", 5, 215618},
	{"XELODA", 6, 215619},
	{"SCRAPJAZZ", 9, 215620},
	{"MARESME", 7, 215621},
	{"HYPOCHONDRIA", 12, 215622},
	{"AFROTC", 6, 215623},
	{"REGLES", 6, 215624},
	{"PIRN", 4, 215625},
	{"HARRASSED", 9, 215626},
	{"OSWER", 5, 215627},
	{"ICOSAHEDRON", 11, 215628},
	{"MAESTRI", 7, 215629},
	{"CARMELITES", 10, 215630},
	{"CONFIGU", 7, 215631},
	{"MOAKLEY", 7, 215632},
	{"DORES", 5, 215633},
	{"ANNESLEY", 8, 215634},
	{"MEMINFO", 7, 215635},
	{"ZAINAB", 6, 215636},
	{"SYQUEST", 7, 215637},
	{"VARE", 4, 215638},
	{"NYOMI", 5, 215639},
	{"MILLITARY", 9, 215640},
	{"SHORTCHANGED", 12, 215641},
	{"POTTINGER", 9, 215642},
	{"CLADISTIC", 9, 215643},
	{"CANTANTE", 8, 215644},
	{"JENIFFER", 8, 215645},
	{"ACONITUM", 8, 215646},
	{"CHERVIL", 7, 215647},
	{"ZMED", 4, 215648},
	{"YMRL", 4, 215649},
	{"YMNE", 4, 215650},
	{"YCEK", 4, 215651},
	{"XUST", 4, 215652},
	{"XIEM", 4, 215653},
	{"WOCT", 4, 215654},
	{"WNAJ", 4, 215655},
	{"VEXC", 4, 215656},
	{"TYUL", 4, 215657},
	{"TMOG", 4, 215658},
	{"SZIL", 4, 215659},
	{"RNYM", 4, 215660},
	{"RMEJ", 4, 215661},
	{"RCDI", 4, 215662},
	{"PHIW", 4, 215663},
	{"PHEV", 4, 215664},
	{"PGUE", 4, 215665},
	{"PAKK", 4, 215666},
	{"OULY", 4, 215667},
	{"NGMV", 4, 215668},
	{"NBMW", 4, 215669},
	{"MGTH", 4, 215670},
	{"LYFT", 4, 215671},
	{"LCZA", 4, 215672},
	{"KARJ", 4, 215673},
	{"JAYV", 4, 215674},
	{"IZOF", 4, 215675},
	{"IMIP", 4, 215676},
	{"ILND", 4, 215677},
	{"IGRS", 4, 215678},
	{"HACM", 4, 215679},
	{"GWVA", 4, 215680},
	{"FOUD", 4, 215681},
	{"FBAJ", 4, 215682},
	{"EWYC", 4, 215683},
	{"ESGB", 4, 215684},
	{"ESDM", 4, 215685},
	{"ERXM", 4, 215686},
	{"EGGU", 4, 215687},
	{"EFMC", 4, 215688},
	{"EBIJ", 4, 215689},
	{"DLLE", 4, 215690},
	{"ALOJ", 4, 215691},
	{"DEVRA", 5, 215692},
	{"WHANG", 5, 215693},
	{"SHERPANI", 8, 215694},
	{"COSMOCHIMICA", 12, 215695},
	{"BEAUTIFIES", 10, 215696},
	{"CALABAR", 7, 215697},
	{"XMLSERIALIZER", 13, 215698},
	{"KELMSCOTT", 9, 215699},
	{"CHRISTOFFER", 11, 215700},
	{"OGONI", 5, 215701},
	{"CANTING", 7, 215702},
	{"UNIVERITY", 9, 215703},
	{"PROPITIATION", 12, 215704},
	{"DISPROVES", 9, 215705},
	{"VIENA", 5, 215706},
	{"TRIFLUOPERAZINE", 15, 215707},
	{"TOUSE", 5, 215708},
	{"SINEMORETS", 10, 215709},
	{"NEGRITO", 7, 215710},
	{"VINLAND", 7, 215711},
	{"SINEWY", 6, 215712},
	{"GAMEKEEPER", 10, 215713},
	{"COATE", 5, 215714},
	{"CINDERFORD", 10, 215715},
	{"NNEREN", 6, 215716},
	{"CICLOSPORT", 10, 215717},
	{"UKOLN", 5, 215718},
	{"NLME", 4, 215719},
	{"POPBYTES", 8, 215720},
	{"LAUCH", 5, 215721},
	{"ROLLEIFLEX", 10, 215722},
	{"REPARTO", 7, 215723},
	{"REPLIC", 6, 215724},
	{"IRVINGWASHINGTON", 16, 215725},
	{"BITERS", 6, 215726},
	{"TELEPATHICALLY", 14, 215727},
	{"GOGLLE", 6, 215728},
	{"FRILLED", 7, 215729},
	{"AMREF", 5, 215730},
	{"SOULJAH", 7, 215731},
	{"RISULTATO", 9, 215732},
	{"TEENGIRLS", 9, 215733},
	{"PHYLOGENETICALLY", 16, 215734},
	{"PHARSALIA", 9, 215735},
	{"PATAN", 5, 215736},
	{"MOBILTELEFONER", 14, 215737},
	{"IQUIQUE", 7, 215738},
	{"GODDAMMIT", 9, 215739},
	{"DULCIE", 6, 215740},
	{"BEKAH", 5, 215741},
	{"MAGALLUF", 8, 215742},
	{"GOPA", 4, 215743},
	{"GLITTERZ", 8, 215744},
	{"LALOO", 5, 215745},
	{"SPIKEMASTER", 11, 215746},
	{"COLONIALISTS", 12, 215747},
	{"PUTTED", 6, 215748},
	{"GELFONDS", 8, 215749},
	{"ALWIL", 5, 215750},
	{"THIBAUT", 7, 215751},
	{"MENCIUS", 7, 215752},
	{"MALASIA", 7, 215753},
	{"AHOSKIE", 7, 215754},
	{"AGIR", 4, 215755},
	{"ARTBOX", 6, 215756},
	{"MORGANNWG", 9, 215757},
	{"INTERLABORATORY", 15, 215758},
	{"FEEDLOUNGE", 10, 215759},
	{"VALMEINIER", 10, 215760},
	{"GERIN", 5, 215761},
	{"MAAKT", 5, 215762},
	{"WORSHIPER", 9, 215763},
	{"STITTSVILLE", 11, 215764},
	{"SELZER", 6, 215765},
	{"NCDS", 4, 215766},
	{"LAMON", 5, 215767},
	{"BUMPUS", 6, 215768},
	{"SUAECIENTLY", 11, 215769},
	{"TASHIRO", 7, 215770},
	{"TAGAR", 5, 215771},
	{"ELFQUEST", 8, 215772},
	{"ABIOLA", 6, 215773},
	{"RADIOCHEMISTRY", 14, 215774},
	{"CLAVULANIC", 10, 215775},
	{"BOLSTAD", 7, 215776},
	{"UPROARIOUS", 10, 215777},
	{"POLYMYOSITIS", 12, 215778},
	{"FADD", 4, 215779},
	{"GESAMT", 6, 215780},
	{"BLYNYDDOL", 9, 215781},
	{"LAURENTIDES", 11, 215782},
	{"VALODA", 6, 215783},
	{"UNSPUN", 6, 215784},
	{"FANTAZY", 7, 215785},
	{"GEBRUIKT", 8, 215786},
	{"SISOFT", 6, 215787},
	{"MORTGSGE", 8, 215788},
	{"FOODGRAINS", 10, 215789},
	{"PCIFU", 5, 215790},
	{"PERIANAL", 8, 215791},
	{"FSPEIRS", 7, 215792},
	{"DIOTEC", 6, 215793},
	{"WEBAWARD", 8, 215794},
	{"LAMOURE", 7, 215795},
	{"ATHAME", 6, 215796},
	{"POYNTING", 8, 215797},
	{"HEUDICKE", 8, 215798},
	{"GAMBRILLS", 9, 215799},
	{"XCDROAST", 8, 215800},
	{"MELS", 4, 215801},
	{"LAMBIE", 6, 215802},
	{"SLOSH", 5, 215803},
	{"BUYDOWN", 7, 215804},
	{"NICKO", 5, 215805},
	{"MARTINCLEAVER", 13, 215806},
	{"GABBAY", 6, 215807},
	{"AMERIBAG", 8, 215808},
	{"WORKPIECES", 10, 215809},
	{"CRIC", 4, 215810},
	{"PACIS", 5, 215811},
	{"LIGHTSTALKERS", 13, 215812},
	{"AGROSTIS", 8, 215813},
	{"SCHANK", 6, 215814},
	{"VINCENTIAN", 10, 215815},
	{"ROLT", 4, 215816},
	{"PENITENTIAL", 11, 215817},
	{"EPUBLISHING", 11, 215818},
	{"BOATERTALK", 10, 215819},
	{"AUTOPHOSPHORYLATION", 19, 215820},
	{"PHRENIC", 7, 215821},
	{"ASTONE", 6, 215822},
	{"SLOAT", 5, 215823},
	{"SHMOP", 5, 215824},
	{"SCIENTIFICA", 11, 215825},
	{"VOTOMS", 6, 215826},
	{"CAOIMH", 6, 215827},
	{"LCAS", 4, 215828},
	{"GLINTING", 8, 215829},
	{"LUDGATE", 7, 215830},
	{"DAGGA", 5, 215831},
	{"CORFF", 5, 215832},
	{"AUTOANTIGEN", 11, 215833},
	{"MITSURU", 7, 215834},
	{"TELETECH", 8, 215835},
	{"PETONE", 6, 215836},
	{"ALKALOSIS", 9, 215837},
	{"STEELSQUIRE", 11, 215838},
	{"SAPPINGTON", 10, 215839},
	{"FUTTERMAN", 9, 215840},
	{"DATEING", 7, 215841},
	{"REENTERING", 10, 215842},
	{"ALLEGRI", 7, 215843},
	{"WOODHILL", 8, 215844},
	{"MADELAINE", 9, 215845},
	{"FISKER", 6, 215846},
	{"DABBS", 5, 215847},
	{"SEEKETH", 7, 215848},
	{"CHUGAI", 6, 215849},
	{"ANOTHERS", 8, 215850},
	{"CAPACITANCES", 12, 215851},
	{"SURFWATCH", 9, 215852},
	{"TALKSWITCH", 10, 215853},
	{"HMENU", 5, 215854},
	{"CROATIEN", 8, 215855},
	{"CADC", 4, 215856},
	{"VERSANDHANDEL", 13, 215857},
	{"BHARATHI", 8, 215858},
	{"SOTER", 5, 215859},
	{"ZKIA", 4, 215860},
	{"YWOV", 4, 215861},
	{"YVIP", 4, 215862},
	{"WBEP", 4, 215863},
	{"WAGH", 4, 215864},
	{"UYMU", 4, 215865},
	{"UNHY", 4, 215866},
	{"TNGU", 4, 215867},
	{"SUFC", 4, 215868},
	{"SBFL", 4, 215869},
	{"RYUW", 4, 215870},
	{"RKIK", 4, 215871},
	{"PSOY", 4, 215872},
	{"ORJP", 4, 215873},
	{"NDKD", 4, 215874},
	{"MKHO", 4, 215875},
	{"MBTR", 4, 215876},
	{"LIXE", 4, 215877},
	{"KAAV", 4, 215878},
	{"IDTC", 4, 215879},
	{"HKLO", 4, 215880},
	{"FLOI", 4, 215881},
	{"FKES", 4, 215882},
	{"EVGR", 4, 215883},
	{"EHRC", 4, 215884},
	{"DOCF", 4, 215885},
	{"BUFA", 4, 215886},
	{"AWKP", 4, 215887},
	{"XAVER", 5, 215888},
	{"SAYAN", 5, 215889},
	{"POLYNESIANS", 11, 215890},
	{"KERNOW", 6, 215891},
	{"DONEY", 5, 215892},
	{"FERRING", 7, 215893},
	{"CONDESCEND", 10, 215894},
	{"ROSENAU", 7, 215895},
	{"FIBRIL", 6, 215896},
	{"TERRIFIES", 9, 215897},
	{"FORUMER", 7, 215898},
	{"CNRI", 4, 215899},
	{"HUMBLER", 7, 215900},
	{"CABINDA", 7, 215901},
	{"VACUO", 5, 215902},
	{"PSYCHOEDUCATIONAL", 17, 215903},
	{"NCHAN", 5, 215904},
	{"MEDITECH", 8, 215905},
	{"JUGLANS", 7, 215906},
	{"JSYS", 4, 215907},
	{"TERRESTRIALS", 12, 215908},
	{"REYNAUD", 7, 215909},
	{"EMOTO", 5, 215910},
	{"KIMBERLEE", 9, 215911},
	{"GALSWORTHY", 10, 215912},
	{"VALUEOF", 7, 215913},
	{"GUNGA", 5, 215914},
	{"BURNISH", 7, 215915},
	{"IRLINES", 7, 215916},
	{"ROMILA", 6, 215917},
	{"DACORUM", 7, 215918},
	{"RECHECKED", 9, 215919},
	{"MUWIC", 5, 215920},
	{"SVENDOWIDEIT", 12, 215921},
	{"PHERTERMINE", 11, 215922},
	{"HOSUR", 5, 215923},
	{"EXPENCE", 7, 215924},
	{"MULTIM", 6, 215925},
	{"BLACKTAIL", 9, 215926},
	{"PARLEMENTAIRE", 13, 215927},
	{"KJAER", 5, 215928},
	{"AIMR", 4, 215929},
	{"PUCKA", 5, 215930},
	{"JODECI", 6, 215931},
	{"DECTALK", 7, 215932},
	{"BUILDIN", 7, 215933},
	{"NONTHABURI", 10, 215934},
	{"CASACAIMAN", 10, 215935},
	{"SUSANN", 6, 215936},
	{"LAYMON", 6, 215937},
	{"KEYSTONES", 9, 215938},
	{"EACCELERATOR", 12, 215939},
	{"DOWNLOASD", 9, 215940},
	{"PAPELES", 7, 215941},
	{"MAXM", 4, 215942},
	{"KANNER", 6, 215943},
	{"HUNKERED", 8, 215944},
	{"SIEWERT", 7, 215945},
	{"MHSIC", 5, 215946},
	{"MADRASSAS", 9, 215947},
	{"LIEBMANN", 8, 215948},
	{"VENNER", 6, 215949},
	{"SMOOVE", 6, 215950},
	{"PRINTSELF", 9, 215951},
	{"VIBRAPOD", 8, 215952},
	{"OPHTHALMOLOGIC", 14, 215953},
	{"REDECLARE", 9, 215954},
	{"FLF", 3, 215955},
	{"HOFGASTEIN", 10, 215956},
	{"SCOTTIES", 8, 215957},
	{"LOWERMYBILLS", 12, 215958},
	{"KUTLESS", 7, 215959},
	{"ELDERSBURG", 10, 215960},
	{"TUFTONBORO", 10, 215961},
	{"TELEPHONICALLY", 14, 215962},
	{"SALONE", 6, 215963},
	{"KITZMILLER", 10, 215964},
	{"JUJUY", 5, 215965},
	{"DECADRON", 8, 215966},
	{"BUMBO", 5, 215967},
	{"VIEWCAM", 7, 215968},
	{"FETTUCINE", 9, 215969},
	{"BREAKWATERS", 11, 215970},
	{"WDVL", 4, 215971},
	{"TANDA", 5, 215972},
	{"LIBDIRECTFB", 11, 215973},
	{"WADHURST", 8, 215974},
	{"SHRP", 4, 215975},
	{"GUITA", 5, 215976},
	{"SIECI", 5, 215977},
	{"ROBERTSHAW", 10, 215978},
	{"REDBULL", 7, 215979},
	{"POLYPRO", 7, 215980},
	{"YEAMAN", 6, 215981},
	{"HYPOXEMIA", 9, 215982},
	{"ETOWN", 5, 215983},
	{"LOLITS", 6, 215984},
	{"REPEATMASKER", 12, 215985},
	{"NETBASE", 7, 215986},
	{"GRISEA", 6, 215987},
	{"HYPERPOLARIZATION", 17, 215988},
	{"AXESS", 5, 215989},
	{"BKL", 3, 215990},
	{"ARRGH", 5, 215991},
	{"BALDO", 5, 215992},
	{"RHETORICS", 9, 215993},
	{"COLORFAST", 9, 215994},
	{"FRENO", 5, 215995},
	{"CAVALIERE", 9, 215996},
	{"THEMAINSAIL", 11, 215997},
	{"FACTIONALISM", 12, 215998},
	{"HELZBERG", 8, 215999},
	{"FOTOGRAFICA", 11, 216000},
	{"SULFONAMIDE", 11, 216001},
	{"LIEPAJA", 7, 216002},
	{"BLONDYNKI", 9, 216003},
	{"UNTERRICHT", 10, 216004},
	{"FLASHGAMES", 10, 216005},
	{"MUSIS", 5, 216006},
	{"GONADORELIN", 11, 216007},
	{"GAMESCOM", 8, 216008},
	{"ANALQUEEN", 9, 216009},
	{"AGSM", 4, 216010},
	{"SPOTTISWOODE", 12, 216011},
	{"SANDPIT", 7, 216012},
	{"BELDARBLOG", 10, 216013},
	{"VICTORIAVILLE", 13, 216014},
	{"TEXTCOLOR", 9, 216015},
	{"SAMPATH", 7, 216016},
	{"SUPERINTENDENCY", 15, 216017},
	{"MALATTIE", 8, 216018},
	{"ENGINEERIN", 10, 216019},
	{"SOLDEN", 6, 216020},
	{"LFF", 3, 216021},
	{"CITICASE", 8, 216022},
	{"OVERDEVELOPED", 13, 216023},
	{"AKAL", 4, 216024},
	{"PLAYUS", 6, 216025},
	{"CHRYSOMELIDAE", 13, 216026},
	{"MICROLITERS", 11, 216027},
	{"MASTICATION", 11, 216028},
	{"HYOSCYAMINE", 11, 216029},
	{"NOKTA", 5, 216030},
	{"VERHEYEN", 8, 216031},
	{"NYLABONE", 8, 216032},
	{"BOUCHET", 7, 216033},
	{"PHOTOFLEX", 9, 216034},
	{"CREEDE", 6, 216035},
	{"CHAVA", 5, 216036},
	{"ARTISTIQUE", 10, 216037},
	{"DRINKSTUFF", 10, 216038},
	{"AFGHANCHAPLAIN", 14, 216039},
	{"ZECU", 4, 216040},
	{"YPSA", 4, 216041},
	{"YIJI", 4, 216042},
	{"XXCO", 4, 216043},
	{"XLEN", 4, 216044},
	{"XCOS", 4, 216045},
	{"WTUB", 4, 216046},
	{"VURA", 4, 216047},
	{"VAER", 4, 216048},
	{"UMOI", 4, 216049},
	{"TUCB", 4, 216050},
	{"TCYM", 4, 216051},
	{"TCME", 4, 216052},
	{"SKUD", 4, 216053},
	{"SCWE", 4, 216054},
	{"RGMD", 4, 216055},
	{"RDJS", 4, 216056},
	{"PJAP", 4, 216057},
	{"PBYU", 4, 216058},
	{"OYKO", 4, 216059},
	{"OKIP", 4, 216060},
	{"ODKO", 4, 216061},
	{"NYLY", 4, 216062},
	{"NDJT", 4, 216063},
	{"MNOY", 4, 216064},
	{"MGOP", 4, 216065},
	{"MCOX", 4, 216066},
	{"MCAE", 4, 216067},
	{"LYAZ", 4, 216068},
	{"KSMC", 4, 216069},
	{"JAAF", 4, 216070},
	{"IKIV", 4, 216071},
	{"HMCO", 4, 216072},
	{"HCOG", 4, 216073},
	{"EVWE", 4, 216074},
	{"ERVM", 4, 216075},
	{"EFPS", 4, 216076},
	{"EFFV", 4, 216077},
	{"DRRU", 4, 216078},
	{"DOHR", 4, 216079},
	{"COBF", 4, 216080},
	{"BASY", 4, 216081},
	{"AUZO", 4, 216082},
	{"AICB", 4, 216083},
	{"DAREBIN", 7, 216084},
	{"HOTWIRED", 8, 216085},
	{"HOOEY", 5, 216086},
	{"CHILLISAUCE", 11, 216087},
	{"DECENDING", 9, 216088},
	{"CHIRAG", 6, 216089},
	{"SIDEEFFECTS", 11, 216090},
	{"PETTINESS", 9, 216091},
	{"ISPRS", 5, 216092},
	{"SLACKENED", 9, 216093},
	{"OXOGLUTARATE", 12, 216094},
	{"NICKLEBACK", 10, 216095},
	{"LIMBED", 6, 216096},
	{"HEUR", 4, 216097},
	{"DESULFOVIBRIO", 13, 216098},
	{"DAHLBACK", 8, 216099},
	{"SINDBAD", 7, 216100},
	{"IMMANENCE", 9, 216101},
	{"BUNDESREPUBLIK", 14, 216102},
	{"REISINGER", 9, 216103},
	{"LINDENBERG", 10, 216104},
	{"LAYTONVILLE", 11, 216105},
	{"BARTY", 5, 216106},
	{"ASMUSSEN", 8, 216107},
	{"SUNALLIANCE", 11, 216108},
	{"SKULLY", 6, 216109},
	{"PRESSRELEASE", 12, 216110},
	{"GOPGLE", 6, 216111},
	{"THROUGHPUTS", 11, 216112},
	{"GALLATE", 7, 216113},
	{"THOREN", 6, 216114},
	{"POLYMYALGIA", 11, 216115},
	{"HETEROSCEDASTICITY", 18, 216116},
	{"DEVERE", 6, 216117},
	{"NEWSML", 6, 216118},
	{"EXCELSIS", 8, 216119},
	{"ILLEAGAL", 8, 216120},
	{"IBIDEM", 6, 216121},
	{"ARKELL", 6, 216122},
	{"OPATIJA", 7, 216123},
	{"CHUMPHON", 8, 216124},
	{"GLIN", 4, 216125},
	{"DORIT", 5, 216126},
	{"CTEST", 5, 216127},
	{"WORDWRAP", 8, 216128},
	{"BRAATEN", 7, 216129},
	{"BENTS", 5, 216130},
	{"ELEXON", 6, 216131},
	{"TOPICSWATCHED", 13, 216132},
	{"SUNROOFS", 8, 216133},
	{"GILKEY", 6, 216134},
	{"BUFFALOS", 8, 216135},
	{"PREDOMINATING", 13, 216136},
	{"BUSONI", 6, 216137},
	{"SIKRI", 5, 216138},
	{"MOTHERF", 7, 216139},
	{"DIRECORY", 8, 216140},
	{"UDAILY", 6, 216141},
	{"KINGFIELD", 9, 216142},
	{"ENNBSPCACHE", 11, 216143},
	{"AVACADO", 7, 216144},
	{"AUFTRAG", 7, 216145},
	{"ZIPPEL", 6, 216146},
	{"HAMPEL", 6, 216147},
	{"VESTFOLD", 8, 216148},
	{"MCCAUGHEY", 9, 216149},
	{"SCOTCHGARD", 10, 216150},
	{"DEVOL", 5, 216151},
	{"MYELOPEROXIDASE", 15, 216152},
	{"LEIFER", 6, 216153},
	{"BREEZER", 7, 216154},
	{"ENDURETH", 8, 216155},
	{"RECORDSETS", 10, 216156},
	{"MNEMO", 5, 216157},
	{"MANAWA", 6, 216158},
	{"LISAS", 5, 216159},
	{"DIHYDROLIPOAMIDE", 16, 216160},
	{"MEREKA", 6, 216161},
	{"SOUNDTRACKNET", 13, 216162},
	{"ACTIUM", 6, 216163},
	{"MCLUSKY", 7, 216164},
	{"FREESHIP", 8, 216165},
	{"TOMSON", 6, 216166},
	{"TELEGLOBE", 9, 216167},
	{"DRAWLINE", 8, 216168},
	{"CANOEISTS", 9, 216169},
	{"AKUREYRI", 8, 216170},
	{"USDIN", 5, 216171},
	{"STEREOSELECTIVE", 15, 216172},
	{"MARTIS", 6, 216173},
	{"YUKARI", 6, 216174},
	{"VARD", 4, 216175},
	{"DSCS", 4, 216176},
	{"CURY", 4, 216177},
	{"WECHT", 5, 216178},
	{"HUMN", 4, 216179},
	{"ZOOG", 4, 216180},
	{"INDUSTRIELS", 11, 216181},
	{"CSERVER", 7, 216182},
	{"CCGCCC", 6, 216183},
	{"UNAPPROACHABLE", 14, 216184},
	{"TWDB", 4, 216185},
	{"PAMP", 4, 216186},
	{"BOONS", 5, 216187},
	{"TORD", 4, 216188},
	{"PUTATIVELY", 10, 216189},
	{"KFSW", 4, 216190},
	{"GUNSTOCK", 8, 216191},
	{"FABREGAS", 8, 216192},
	{"MIZTIQUE", 8, 216193},
	{"LEFORT", 6, 216194},
	{"WIERDO", 6, 216195},
	{"GREYLIST", 8, 216196},
	{"BUPLEURUM", 9, 216197},
	{"GIPP", 4, 216198},
	{"SHELLEN", 7, 216199},
	{"RAJSHAHI", 8, 216200},
	{"INCAPACITATE", 12, 216201},
	{"WLOX", 4, 216202},
	{"SCATTERERS", 10, 216203},
	{"NEAPOLIS", 8, 216204},
	{"AROHA", 5, 216205},
	{"DIMITROVGRAD", 12, 216206},
	{"CALLIPER", 8, 216207},
	{"MOTOREX", 7, 216208},
	{"VOUCHSAFED", 10, 216209},
	{"STIGMATIZE", 10, 216210},
	{"MORIOKA", 7, 216211},
	{"CULTURAS", 8, 216212},
	{"MBSA", 4, 216213},
	{"JUNKYARDS", 9, 216214},
	{"COMPONENTEN", 11, 216215},
	{"CARRARO", 7, 216216},
	{"UNNOTICEABLE", 12, 216217},
	{"CONNESSIONE", 11, 216218},
	{"ZISOFS", 6, 216219},
	{"MICHALAK", 8, 216220},
	{"CONSOLADORES", 12, 216221},
	{"BIOREGIONS", 10, 216222},
	{"REPPIN", 6, 216223},
	{"CIALUG", 6, 216224},
	{"FULLMER", 7, 216225},
	{"TOSHIHIRO", 9, 216226},
	{"ONNLINE", 7, 216227},
	{"HALINA", 6, 216228},
	{"SUBMISSIVES", 11, 216229},
	{"BATIKS", 6, 216230},
	{"ZUP", 3, 216231},
	{"THUGZ", 5, 216232},
	{"AGUAYO", 6, 216233},
	{"DISABIL", 7, 216234},
	{"RIDEABLE", 8, 216235},
	{"LUNGA", 5, 216236},
	{"TEXTBOXES", 9, 216237},
	{"HOLTSBERRY", 10, 216238},
	{"ELFUTILS", 8, 216239},
	{"HARPERSANFRANCISCO", 18, 216240},
	{"EUREKSTER", 9, 216241},
	{"CALIFANO", 8, 216242},
	{"WUSAGE", 6, 216243},
	{"VIRTEK", 6, 216244},
	{"PANWEST", 7, 216245},
	{"MCATEER", 7, 216246},
	{"GAMLE", 5, 216247},
	{"CARRILES", 8, 216248},
	{"TECHNOOGIES", 11, 216249},
	{"ZJOI", 4, 216250},
	{"ZIKI", 4, 216251},
	{"YYUM", 4, 216252},
	{"YGNU", 4, 216253},
	{"WMEG", 4, 216254},
	{"WBYD", 4, 216255},
	{"VOSW", 4, 216256},
	{"VETP", 4, 216257},
	{"VEAX", 4, 216258},
	{"URDP", 4, 216259},
	{"URBF", 4, 216260},
	{"UGPE", 4, 216261},
	{"TOBM", 4, 216262},
	{"TKEW", 4, 216263},
	{"RPUD", 4, 216264},
	{"RGUP", 4, 216265},
	{"RDMK", 4, 216266},
	{"PYJU", 4, 216267},
	{"OAMD", 4, 216268},
	{"NEXF", 4, 216269},
	{"MENQ", 4, 216270},
	{"LYBC", 4, 216271},
	{"LUZA", 4, 216272},
	{"LECN", 4, 216273},
	{"IFUK", 4, 216274},
	{"IADP", 4, 216275},
	{"GYOK", 4, 216276},
	{"GYKN", 4, 216277},
	{"GEJI", 4, 216278},
	{"CYSK", 4, 216279},
	{"CHVS", 4, 216280},
	{"BLUC", 4, 216281},
	{"BBKI", 4, 216282},
	{"ALKK", 4, 216283},
	{"SPHEREX", 7, 216284},
	{"NADOLIG", 7, 216285},
	{"MARSCH", 6, 216286},
	{"ALCOVES", 7, 216287},
	{"HOTARU", 6, 216288},
	{"CONTAMI", 7, 216289},
	{"MYPIXMANIA", 10, 216290},
	{"CHIAVATE", 8, 216291},
	{"ASWAD", 5, 216292},
	{"TARKINGTON", 10, 216293},
	{"PHILIBERT", 9, 216294},
	{"PASTORALISM", 11, 216295},
	{"MARTINU", 7, 216296},
	{"RAWNSLEY", 8, 216297},
	{"SALABLE", 7, 216298},
	{"BRAINE", 6, 216299},
	{"MEAFORD", 7, 216300},
	{"HORDALAND", 9, 216301},
	{"CHLOROSIS", 9, 216302},
	{"CERENKOV", 8, 216303},
	{"ANNONA", 6, 216304},
	{"VLOS", 4, 216305},
	{"ZUGANG", 6, 216306},
	{"PINKAS", 6, 216307},
	{"VETRO", 5, 216308},
	{"CORDIALITY", 10, 216309},
	{"LASAT", 5, 216310},
	{"TECHRANKINGS", 12, 216311},
	{"VOLUNTARINESS", 13, 216312},
	{"FATHI", 5, 216313},
	{"LEMASTER", 8, 216314},
	{"NITROPHENOL", 11, 216315},
	{"GATWAY", 6, 216316},
	{"REINTERPRETING", 14, 216317},
	{"RAYNSFORD", 9, 216318},
	{"KIMBELL", 7, 216319},
	{"ARCSECONDS", 10, 216320},
	{"SYLFAENOL", 9, 216321},
	{"HELPROOM", 8, 216322},
	{"ALINUX", 6, 216323},
	{"IVANISEVIC", 10, 216324},
	{"CHRP", 4, 216325},
	{"GLAISHERK", 9, 216326},
	{"FRAUENFELDER", 12, 216327},
	{"ALICO", 5, 216328},
	{"HOMESTUDY", 9, 216329},
	{"ELITSERIEN", 10, 216330},
	{"HOTBAG", 6, 216331},
	{"BRITASIAN", 9, 216332},
	{"NOROVIRUS", 9, 216333},
	{"MBJ", 3, 216334},
	{"AVILLA", 6, 216335},
	{"ARSONS", 6, 216336},
	{"SARRACENIA", 10, 216337},
	{"EBADF", 5, 216338},
	{"SOMAS", 5, 216339},
	{"BILLOW", 6, 216340},
	{"UDGET", 5, 216341},
	{"GRUNDLER", 8, 216342},
	{"DOTSOUNDZ", 9, 216343},
	{"REINFECTION", 11, 216344},
	{"OCIETY", 6, 216345},
	{"RASC", 4, 216346},
	{"FACNET", 6, 216347},
	{"HARTEIS", 7, 216348},
	{"HALDEN", 6, 216349},
	{"KILGALLEN", 9, 216350},
	{"WANNABEES", 9, 216351},
	{"SPORTCOAT", 9, 216352},
	{"INSIDEGOOGLE", 12, 216353},
	{"HIROKAZU", 8, 216354},
	{"PROGRAMACION", 12, 216355},
	{"HARDHATS", 8, 216356},
	{"BUTTERBALL", 10, 216357},
	{"KANETIX", 7, 216358},
	{"NOVINKY", 7, 216359},
	{"SCOUPE", 6, 216360},
	{"INTERIEUR", 9, 216361},
	{"NDFEB", 5, 216362},
	{"HENNIE", 6, 216363},
	{"FEDAYEEN", 8, 216364},
	{"PUTTEN", 6, 216365},
	{"CUSTOMERID", 10, 216366},
	{"BITNEY", 6, 216367},
	{"NORC", 4, 216368},
	{"PALMIRA", 7, 216369},
	{"MAYBES", 6, 216370},
	{"TODY", 4, 216371},
	{"BROADLEY", 8, 216372},
	{"AUDUN", 5, 216373},
	{"AGARD", 5, 216374},
	{"THUGGERY", 8, 216375},
	{"EASYLINE", 8, 216376},
	{"RELATIVEMENT", 12, 216377},
	{"PATHUMTHANI", 11, 216378},
	{"MULTIMODALITY", 13, 216379},
	{"GILLON", 6, 216380},
	{"THEDELBOY", 9, 216381},
	{"EUPDATE", 7, 216382},
	{"CATRIN", 6, 216383},
	{"BLOGSGALLERYLIVE", 16, 216384},
	{"SUSHMITA", 8, 216385},
	{"HYPERREF", 8, 216386},
	{"GEILHEIT", 8, 216387},
	{"SATURABLE", 9, 216388},
	{"RETYPING", 8, 216389},
	{"LOVEGROVE", 9, 216390},
	{"OROPHARYNX", 10, 216391},
	{"CARLUKE", 7, 216392},
	{"TEASINGLY", 9, 216393},
	{"INCONSTANT", 10, 216394},
	{"AMIYUMI", 7, 216395},
	{"WESSINGTON", 10, 216396},
	{"OPENSTREETMAP", 13, 216397},
	{"ALOUETTES", 9, 216398},
	{"PYRROLE", 7, 216399},
	{"COTYLEDON", 9, 216400},
	{"COCCINEA", 8, 216401},
	{"NANOSTRUCTURE", 13, 216402},
	{"WOMBS", 5, 216403},
	{"POINTELLE", 9, 216404},
	{"EFFETE", 6, 216405},
	{"INVESTIMENTI", 12, 216406},
	{"STOREHOUSES", 11, 216407},
	{"CARCASES", 8, 216408},
	{"SOLIDARIDAD", 11, 216409},
	{"MOTHBALLED", 10, 216410},
	{"SGID", 4, 216411},
	{"ASSER", 5, 216412},
	{"RMAP", 4, 216413},
	{"CRESTFALLEN", 11, 216414},
	{"LINKPOINT", 9, 216415},
	{"GATECH", 6, 216416},
	{"STAMPANTE", 9, 216417},
	{"RIFERIMENTO", 11, 216418},
	{"MELMAN", 6, 216419},
	{"VWIC", 4, 216420},
	{"VISUALISATIONS", 14, 216421},
	{"VADEN", 5, 216422},
	{"SUCHLIKE", 8, 216423},
	{"ZIRCONS", 7, 216424},
	{"SPLASHBACK", 10, 216425},
	{"IEMAND", 6, 216426},
	{"CREASEY", 7, 216427},
	{"MULTIVALENT", 11, 216428},
	{"ELLHNIKH", 8, 216429},
	{"PUBLISHAMERICA", 14, 216430},
	{"NEWTONMORE", 10, 216431},
	{"EGLA", 4, 216432},
	{"TANGIBLY", 8, 216433},
	{"TANEYTOWN", 9, 216434},
	{"NITERIDER", 9, 216435},
	{"MASCARENHAS", 11, 216436},
	{"NAUMBURG", 8, 216437},
	{"IRONBARK", 8, 216438},
	{"GEYLANG", 7, 216439},
	{"DELTEK", 6, 216440},
	{"LUCIANI", 7, 216441},
	{"INNOTECH", 8, 216442},
	{"DCERPC", 6, 216443},
	{"SKIPA", 5, 216444},
	{"GLOOMILY", 8, 216445},
	{"HYPERPLASTIC", 12, 216446},
	{"ABLEAFTYPE", 10, 216447},
	{"ZIME", 4, 216448},
	{"ZALC", 4, 216449},
	{"YIBO", 4, 216450},
	{"YEAM", 4, 216451},
	{"VAYO", 4, 216452},
	{"UOPL", 4, 216453},
	{"ULGL", 4, 216454},
	{"UBYM", 4, 216455},
	{"TUEM", 4, 216456},
	{"SVOM", 4, 216457},
	{"RBNE", 4, 216458},
	{"PHGI", 4, 216459},
	{"OMPY", 4, 216460},
	{"OMMW", 4, 216461},
	{"OIMR", 4, 216462},
	{"OGPI", 4, 216463},
	{"OCBO", 4, 216464},
	{"MNFR", 4, 216465},
	{"MFIC", 4, 216466},
	{"LZAW", 4, 216467},
	{"LKIA", 4, 216468},
	{"LEOJ", 4, 216469},
	{"KMRE", 4, 216470},
	{"KMFO", 4, 216471},
	{"KDUS", 4, 216472},
	{"HBVI", 4, 216473},
	{"GVIK", 4, 216474},
	{"GUAP", 4, 216475},
	{"FWAH", 4, 216476},
	{"FROV", 4, 216477},
	{"FEYT", 4, 216478},
	{"EDRN", 4, 216479},
	{"DAUA", 4, 216480},
	{"AUAF", 4, 216481},
	{"AMMM", 4, 216482},
	{"AMCB", 4, 216483},
	{"SHIRAKAWA", 9, 216484},
	{"SAGECRM", 7, 216485},
	{"SLYKE", 5, 216486},
	{"KOVAR", 5, 216487},
	{"CHATTANOOGAN", 12, 216488},
	{"MERIDIANA", 9, 216489},
	{"QUALCAST", 8, 216490},
	{"MULTIFRACTAL", 12, 216491},
	{"PERFECTIVE", 10, 216492},
	{"DEEPSKY", 7, 216493},
	{"CUPRATES", 8, 216494},
	{"AARAU", 5, 216495},
	{"DEDALUS", 7, 216496},
	{"NORGREN", 7, 216497},
	{"LOVAGE", 6, 216498},
	{"SHARPSVILLE", 11, 216499},
	{"GRAUMAN", 7, 216500},
	{"PRESUPUESTOS", 12, 216501},
	{"PRATICAL", 8, 216502},
	{"POUTED", 6, 216503},
	{"MELLINGER", 9, 216504},
	{"BIEHL", 5, 216505},
	{"ALTAMAP", 7, 216506},
	{"REMOVEL", 7, 216507},
	{"WILLAN", 6, 216508},
	{"MISERERE", 8, 216509},
	{"LERDORF", 7, 216510},
	{"CHONDROCYTE", 11, 216511},
	{"FOZEN", 5, 216512},
	{"SETDATA", 7, 216513},
	{"METHODIUS", 9, 216514},
	{"MAFIOSO", 7, 216515},
	{"VOORBEHOUDEN", 12, 216516},
	{"MYSTRING", 8, 216517},
	{"ALSC", 4, 216518},
	{"BULKS", 5, 216519},
	{"SCHISMS", 7, 216520},
	{"EXPECTA", 7, 216521},
	{"DUF", 3, 216522},
	{"ALFRE", 5, 216523},
	{"KSDK", 4, 216524},
	{"ICARE", 5, 216525},
	{"AUSTAR", 6, 216526},
	{"GNATCATCHER", 11, 216527},
	{"CHERNOMYRDIN", 12, 216528},
	{"VORKOSIGAN", 10, 216529},
	{"POTHEAD", 7, 216530},
	{"OTTERHOUND", 10, 216531},
	{"DBUG", 4, 216532},
	{"BRIL", 4, 216533},
	{"BRESSE", 6, 216534},
	{"YSSK", 4, 216535},
	{"SEAARCH", 7, 216536},
	{"STEAROTHERMOPHILUS", 18, 216537},
	{"BUMGARNER", 9, 216538},
	{"BOTSTEIN", 8, 216539},
	{"BITTINGER", 9, 216540},
	{"SHINKO", 6, 216541},
	{"LIBZ", 4, 216542},
	{"TELANJANG", 9, 216543},
	{"ZOLADEX", 7, 216544},
	{"SJOBERG", 7, 216545},
	{"SCAMBISTI", 9, 216546},
	{"LLWYD", 5, 216547},
	{"BOWLEY", 6, 216548},
	{"RUSTICO", 7, 216549},
	{"ROSEHIP", 7, 216550},
	{"QUEENSBOROUGH", 13, 216551},
	{"OGER", 4, 216552},
	{"KENANSVILLE", 11, 216553},
	{"LUNCHING", 8, 216554},
	{"ELKFORD", 7, 216555},
	{"BRETTH", 6, 216556},
	{"BILLETING", 9, 216557},
	{"WAKENED", 7, 216558},
	{"SHELTIES", 8, 216559},
	{"DOGSLEDDING", 11, 216560},
	{"ADULTERER", 9, 216561},
	{"WILLNER", 7, 216562},
	{"MATHSTEAM", 9, 216563},
	{"LEGROS", 6, 216564},
	{"JEPPE", 5, 216565},
	{"LASLEY", 6, 216566},
	{"PFLUGERS", 8, 216567},
	{"TEDDYBEAR", 9, 216568},
	{"SOPHISTICATES", 13, 216569},
	{"REER", 4, 216570},
	{"QUAPAW", 6, 216571},
	{"WETFEET", 7, 216572},
	{"TELINDUS", 8, 216573},
	{"CEMENTATION", 11, 216574},
	{"YARDSTICKS", 10, 216575},
	{"ELANVITAL", 9, 216576},
	{"LEFKAS", 6, 216577},
	{"SYMBOYLIOY", 10, 216578},
	{"INTERINSTITUTIONAL", 18, 216579},
	{"ENNIES", 6, 216580},
	{"CHECKSERVICE", 12, 216581},
	{"VINNITSA", 8, 216582},
	{"GYRATIONS", 9, 216583},
	{"ROINN", 5, 216584},
	{"PEDRA", 5, 216585},
	{"PODEM", 5, 216586},
	{"DILOS", 5, 216587},
	{"COMICBOOK", 9, 216588},
	{"PICTUREBOOK", 11, 216589},
	{"SCAREDY", 7, 216590},
	{"EERST", 5, 216591},
	{"SOCIALSOFTWARE", 14, 216592},
	{"BOBST", 5, 216593},
	{"AYUDAS", 6, 216594},
	{"THEROPOD", 8, 216595},
	{"ALPERN", 6, 216596},
	{"NEWBEE", 6, 216597},
	{"INCANDESCENCE", 13, 216598},
	{"MYTABLE", 7, 216599},
	{"BODYFIT", 7, 216600},
	{"SIMAZINE", 8, 216601},
	{"GRAYLEVEL", 9, 216602},
	{"EGRETTA", 7, 216603},
	{"STOICA", 6, 216604},
	{"SCHIEK", 6, 216605},
	{"DATATEL", 7, 216606},
	{"RAGHAVENDRA", 11, 216607},
	{"WHEELIN", 7, 216608},
	{"LLED", 4, 216609},
	{"ELEPHUNK", 8, 216610},
	{"KOTSIKONAS", 10, 216611},
	{"CLADISTICS", 10, 216612},
	{"PADRAIC", 7, 216613},
	{"EPCR", 4, 216614},
	{"BIOCHEMIE", 9, 216615},
	{"WIXCOM", 6, 216616},
	{"IDENTS", 6, 216617},
	{"WINNY", 5, 216618},
	{"REMOTELYANYWHERE", 16, 216619},
	{"POPOLA", 6, 216620},
	{"GARDEL", 6, 216621},
	{"DACTINOMYCIN", 12, 216622},
	{"FLUOROPHORE", 11, 216623},
	{"PRMS", 4, 216624},
	{"KNIRSCH", 7, 216625},
	{"KOGER", 5, 216626},
	{"COUPDEN", 7, 216627},
	{"BANGALI", 7, 216628},
	{"BALLAS", 6, 216629},
	{"BLIC", 4, 216630},
	{"TEAYS", 5, 216631},
	{"DULBECCO", 8, 216632},
	{"LUCIDLY", 7, 216633},
	{"KIRLIAN", 7, 216634},
	{"MERCERSBURG", 11, 216635},
	{"FORESTHILL", 10, 216636},
	{"XENIX", 5, 216637},
	{"SIDLED", 6, 216638},
	{"ISPRA", 5, 216639},
	{"DULLING", 7, 216640},
	{"IMPORTEL", 8, 216641},
	{"CHEVRE", 6, 216642},
	{"PLANETARIUMS", 12, 216643},
	{"ZOMO", 4, 216644},
	{"ZCIT", 4, 216645},
	{"YYUK", 4, 216646},
	{"YVST", 4, 216647},
	{"YJEE", 4, 216648},
	{"YGDA", 4, 216649},
	{"XALE", 4, 216650},
	{"VEZR", 4, 216651},
	{"UKSB", 4, 216652},
	{"UKAY", 4, 216653},
	{"UKAJ", 4, 216654},
	{"UHRI", 4, 216655},
	{"TUDF", 4, 216656},
	{"TFSU", 4, 216657},
	{"TCUD", 4, 216658},
	{"STCM", 4, 216659},
	{"RPUC", 4, 216660},
	{"PMPT", 4, 216661},
	{"OBDR", 4, 216662},
	{"NYLP", 4, 216663},
	{"NKUD", 4, 216664},
	{"MUDU", 4, 216665},
	{"LVDW", 4, 216666},
	{"LUNH", 4, 216667},
	{"LCZE", 4, 216668},
	{"LCSS", 4, 216669},
	{"KIBL", 4, 216670},
	{"JRED", 4, 216671},
	{"IZLA", 4, 216672},
	{"HUIW", 4, 216673},
	{"HIKR", 4, 216674},
	{"GUMN", 4, 216675},
	{"GSKU", 4, 216676},
	{"GMCR", 4, 216677},
	{"GFET", 4, 216678},
	{"FMSA", 4, 216679},
	{"FCCW", 4, 216680},
	{"ERVW", 4, 216681},
	{"ERTQ", 4, 216682},
	{"EGEQ", 4, 216683},
	{"DURC", 4, 216684},
	{"DSND", 4, 216685},
	{"DDAO", 4, 216686},
	{"DAOW", 4, 216687},
	{"CSIW", 4, 216688},
	{"CEJR", 4, 216689},
	{"BFLI", 4, 216690},
	{"AWGU", 4, 216691},
	{"ALCK", 4, 216692},
	{"AGBR", 4, 216693},
	{"WERNICK", 7, 216694},
	{"RESTOR", 6, 216695},
	{"ELLIPSOIDS", 10, 216696},
	{"ALESINA", 7, 216697},
	{"RESPRO", 6, 216698},
	{"TARTARS", 7, 216699},
	{"OMNITURE", 8, 216700},
	{"NOVASTAR", 8, 216701},
	{"LOLIUM", 6, 216702},
	{"MONOGENIC", 9, 216703},
	{"PROMINENCES", 11, 216704},
	{"SHOPVUE", 7, 216705},
	{"KANDER", 6, 216706},
	{"WLADIMIR", 8, 216707},
	{"KRY", 3, 216708},
	{"EBBED", 5, 216709},
	{"DELIBES", 7, 216710},
	{"STREAMLOAD", 10, 216711},
	{"CRAZYHORSE", 10, 216712},
	{"INTERCEA", 8, 216713},
	{"INCLUSO", 7, 216714},
	{"CRUNCHERS", 9, 216715},
	{"CAPPELLI", 8, 216716},
	{"MYCONNECT", 9, 216717},
	{"ELIASON", 7, 216718},
	{"BLOUNTSTOWN", 11, 216719},
	{"HEWLET", 6, 216720},
	{"CLEMM", 5, 216721},
	{"BYTEWIZE", 8, 216722},
	{"ARGENTINES", 10, 216723},
	{"MUSICIANSBUY", 12, 216724},
	{"LUDE", 4, 216725},
	{"JACQUELIN", 9, 216726},
	{"COMBIVENT", 9, 216727},
	{"BOESHIELD", 9, 216728},
	{"ARPHIC", 6, 216729},
	{"TONKAWA", 7, 216730},
	{"TDRS", 4, 216731},
	{"STECKTE", 7, 216732},
	{"BIRYANI", 7, 216733},
	{"VTKIDTYPE", 9, 216734},
	{"POLITIEKE", 9, 216735},
	{"ISSACHAR", 8, 216736},
	{"CONSPIRES", 9, 216737},
	{"COUNTERFLOW", 11, 216738},
	{"INCORPORATORS", 13, 216739},
	{"TONGKAT", 7, 216740},
	{"ASTRAFFIC", 9, 216741},
	{"COMORO", 6, 216742},
	{"HEWLLETT", 8, 216743},
	{"AIRLIN", 6, 216744},
	{"KNUCKLEHEADS", 12, 216745},
	{"ASTIR", 5, 216746},
	{"PENTAMIDINE", 11, 216747},
	{"NIMAL", 5, 216748},
	{"LINKBOT", 7, 216749},
	{"INTERST", 7, 216750},
	{"MCGREEVY", 8, 216751},
	{"MALISSA", 7, 216752},
	{"KRIZ", 4, 216753},
	{"INPUTFILE", 9, 216754},
	{"CALLEY", 6, 216755},
	{"METAZOAN", 8, 216756},
	{"DEMONIA", 7, 216757},
	{"ENTEOS", 6, 216758},
	{"DUALBAND", 8, 216759},
	{"PSYCHOANALYTICAL", 16, 216760},
	{"BUSSED", 6, 216761},
	{"POSABLE", 7, 216762},
	{"LINEKER", 7, 216763},
	{"KPOP", 4, 216764},
	{"HEBEL", 5, 216765},
	{"ORTIGAS", 7, 216766},
	{"ETHERSWITCH", 11, 216767},
	{"CLINES", 6, 216768},
	{"BRYANNA", 7, 216769},
	{"OCCULTIST", 9, 216770},
	{"TOPXML", 6, 216771},
	{"SUECIA", 6, 216772},
	{"ALWIN", 5, 216773},
	{"REVESBY", 7, 216774},
	{"GERLS", 5, 216775},
	{"KRAJICEK", 8, 216776},
	{"STUDE", 5, 216777},
	{"CATECHIST", 9, 216778},
	{"SARLAT", 6, 216779},
	{"RESOLVENT", 9, 216780},
	{"INTERHOME", 9, 216781},
	{"THERMOSTABLE", 12, 216782},
	{"PILLE", 5, 216783},
	{"MATREN", 6, 216784},
	{"VITELLO", 7, 216785},
	{"EMMEN", 5, 216786},
	{"ETUC", 4, 216787},
	{"PINBACKS", 8, 216788},
	{"MPOA", 4, 216789},
	{"FICON", 5, 216790},
	{"REASSERTED", 10, 216791},
	{"SUBJURISDICTION", 15, 216792},
	{"XDOC", 4, 216793},
	{"CASINI", 6, 216794},
	{"AUTOPHAGY", 9, 216795},
	{"NEWBOROUGH", 10, 216796},
	{"LATOR", 5, 216797},
	{"GALLORIES", 9, 216798},
	{"ELECTRICA", 9, 216799},
	{"MUSHI", 5, 216800},
	{"DAVITT", 6, 216801},
	{"FREAKISHLY", 10, 216802},
	{"CHAORDIC", 8, 216803},
	{"DEGRESS", 7, 216804},
	{"MABO", 4, 216805},
	{"EXTASY", 6, 216806},
	{"CORPWATCH", 9, 216807},
	{"TRENTE", 6, 216808},
	{"RUBRIPES", 8, 216809},
	{"NBSPVIA", 7, 216810},
	{"ASTRAFIC", 8, 216811},
	{"ANDF", 4, 216812},
	{"LOURIE", 6, 216813},
	{"FUNY", 4, 216814},
	{"VERGA", 5, 216815},
	{"BAGAGE", 6, 216816},
	{"STRAWBRIDGE", 11, 216817},
	{"HARDI", 5, 216818},
	{"EMAGAZINE", 9, 216819},
	{"SCHRANZ", 7, 216820},
	{"HONEYNET", 8, 216821},
	{"EBAUMSWORLD", 11, 216822},
	{"CORSINI", 7, 216823},
	{"CITYCASE", 8, 216824},
	{"WBAY", 4, 216825},
	{"REEKED", 6, 216826},
	{"PAPULES", 7, 216827},
	{"CURBISHLEY", 10, 216828},
	{"BRIGHTSURF", 10, 216829},
	{"SEIICHI", 7, 216830},
	{"MOSCOLONI", 9, 216831},
	{"KETTENIS", 8, 216832},
	{"ELECTROSTATICALLY", 17, 216833},
	{"XLOCK", 5, 216834},
	{"NTURER", 6, 216835},
	{"FERRAZ", 6, 216836},
	{"DDQ", 3, 216837},
	{"ZFIN", 4, 216838},
	{"HANDLEEVENT", 11, 216839},
	{"PHOTOCOAGULATION", 16, 216840},
	{"GLAMORISE", 9, 216841},
	{"EROTIKFOTOS", 11, 216842},
	{"DISPIRITED", 10, 216843},
	{"MANUFACTURELINKS", 16, 216844},
	{"HEMAN", 5, 216845},
	{"CORAN", 5, 216846},
	{"ANALGAMES", 9, 216847},
	{"PENTAGRA", 8, 216848},
	{"ZERIT", 5, 216849},
	{"VXW", 3, 216850},
	{"IECC", 4, 216851},
	{"BLOGMARK", 8, 216852},
	{"ECHINODERM", 10, 216853},
	{"ALBARN", 6, 216854},
	{"ZIFA", 4, 216855},
	{"YLDI", 4, 216856},
	{"XMLA", 4, 216857},
	{"XICF", 4, 216858},
	{"WMYA", 4, 216859},
	{"UZMN", 4, 216860},
	{"UPRS", 4, 216861},
	{"UEMB", 4, 216862},
	{"TWSU", 4, 216863},
	{"SPSF", 4, 216864},
	{"SEFM", 4, 216865},
	{"RAZT", 4, 216866},
	{"RAEQ", 4, 216867},
	{"QITR", 4, 216868},
	{"OSKV", 4, 216869},
	{"OMWY", 4, 216870},
	{"NXER", 4, 216871},
	{"NOXM", 4, 216872},
	{"NLOK", 4, 216873},
	{"NBOZ", 4, 216874},
	{"NAMJ", 4, 216875},
	{"NAGB", 4, 216876},
	{"MOZY", 4, 216877},
	{"MEZT", 4, 216878},
	{"MAOC", 4, 216879},
	{"LNCI", 4, 216880},
	{"LMCM", 4, 216881},
	{"LACB", 4, 216882},
	{"KOUJ", 4, 216883},
	{"JMER", 4, 216884},
	{"IZDA", 4, 216885},
	{"IXOL", 4, 216886},
	{"IVOU", 4, 216887},
	{"IDLS", 4, 216888},
	{"GRYY", 4, 216889},
	{"FUPL", 4, 216890},
	{"FSDR", 4, 216891},
	{"EDUQ", 4, 216892},
	{"DFAE", 4, 216893},
	{"CZES", 4, 216894},
	{"CUNH", 4, 216895},
	{"CNYS", 4, 216896},
	{"BIZI", 4, 216897},
	{"ATDF", 4, 216898},
	{"ARPV", 4, 216899},
	{"AQCA", 4, 216900},
	{"ANJW", 4, 216901},
	{"ACTZ", 4, 216902},
	{"MOXIBUSTION", 11, 216903},
	{"DREAMCATCHERS", 13, 216904},
	{"SPHAEROIDES", 11, 216905},
	{"FABBRICA", 8, 216906},
	{"DICHLOROETHENE", 14, 216907},
	{"FINDITINCANADA", 14, 216908},
	{"ETIQUETA", 8, 216909},
	{"UNIBLUE", 7, 216910},
	{"CARLSBRO", 8, 216911},
	{"AUTOMOBIL", 9, 216912},
	{"HARPSWELL", 9, 216913},
	{"AFFILATE", 8, 216914},
	{"SANITARYWARE", 12, 216915},
	{"RAXCO", 5, 216916},
	{"QABALAH", 7, 216917},
	{"LOCATIONNEW", 11, 216918},
	{"IMMISCIBLE", 10, 216919},
	{"GRABE", 5, 216920},
	{"DRECTORY", 8, 216921},
	{"RHAIN", 5, 216922},
	{"NIGHTOWL", 8, 216923},
	{"DARNLEY", 7, 216924},
	{"TYNES", 5, 216925},
	{"MAELIN", 6, 216926},
	{"HOBGOOD", 7, 216927},
	{"WILLIRAYE", 9, 216928},
	{"MKK", 3, 216929},
	{"LLANTWIT", 8, 216930},
	{"RODDERS", 7, 216931},
	{"PREPENDING", 10, 216932},
	{"CELEBERTIES", 11, 216933},
	{"HIGSON", 6, 216934},
	{"DORSTONE", 8, 216935},
	{"IMAGISTICS", 10, 216936},
	{"BLONDIN", 7, 216937},
	{"REGREP", 6, 216938},
	{"BASTELN", 7, 216939},
	{"THICKE", 6, 216940},
	{"MITZVA", 6, 216941},
	{"VELHA", 5, 216942},
	{"BUSIEK", 6, 216943},
	{"DATALINE", 8, 216944},
	{"EBATTS", 6, 216945},
	{"BRANTA", 6, 216946},
	{"APPLICAZIONI", 12, 216947},
	{"KOKEN", 5, 216948},
	{"FALLIMENTO", 10, 216949},
	{"DISINFLATION", 12, 216950},
	{"NONCONTACT", 10, 216951},
	{"FREEADULT", 9, 216952},
	{"MUNU", 4, 216953},
	{"TURY", 4, 216954},
	{"VOICEMESSAGE", 12, 216955},
	{"AYAKO", 5, 216956},
	{"SOUNDDOCK", 9, 216957},
	{"RAPORTU", 7, 216958},
	{"MORTGAGR", 8, 216959},
	{"GORN", 4, 216960},
	{"DIATELY", 7, 216961},
	{"LIMPS", 5, 216962},
	{"OVARIECTOMIZED", 14, 216963},
	{"INSIDIOUSLY", 11, 216964},
	{"INBOXER", 7, 216965},
	{"GETVERSION", 10, 216966},
	{"UNEXPANDED", 10, 216967},
	{"HELLEBORE", 9, 216968},
	{"PANADOL", 7, 216969},
	{"EGREGIOUSLY", 11, 216970},
	{"FUNHOU", 6, 216971},
	{"RICCATI", 7, 216972},
	{"WHIZZER", 7, 216973},
	{"KUNENE", 6, 216974},
	{"HYPNOBIRTHING", 13, 216975},
	{"VIDOS", 5, 216976},
	{"DIVINED", 7, 216977},
	{"COOLTHREADS", 11, 216978},
	{"CAFFIENE", 8, 216979},
	{"UITLATEN", 8, 216980},
	{"SULPHITE", 8, 216981},
	{"YUYU", 4, 216982},
	{"RESIDEN", 7, 216983},
	{"NDBC", 4, 216984},
	{"VIPUL", 5, 216985},
	{"BERNTSEN", 8, 216986},
	{"SHAREOWNERS", 11, 216987},
	{"OJALA", 5, 216988},
	{"CAREERJET", 9, 216989},
	{"CARYVILLE", 9, 216990},
	{"CALMETTE", 8, 216991},
	{"RSVPED", 6, 216992},
	{"GONTHIER", 8, 216993},
	{"UNGULATE", 8, 216994},
	{"ENTIAT", 6, 216995},
	{"WALDON", 6, 216996},
	{"RSBC", 4, 216997},
	{"WITTERING", 9, 216998},
	{"SHIPSHAPE", 9, 216999},
	{"GSMES", 5, 217000},
	{"COOTIE", 6, 217001},
	{"ZONECAST", 8, 217002},
	{"REVELLING", 9, 217003},
	{"MINTZBERG", 9, 217004},
	{"UNILANG", 7, 217005},
	{"TETRAMETHYL", 11, 217006},
	{"POPOS", 5, 217007},
	{"MAZZINI", 7, 217008},
	{"GLAMORGANSHIRE", 14, 217009},
	{"NICODEMO", 8, 217010},
	{"EAUDIO", 6, 217011},
	{"TENORIO", 7, 217012},
	{"SGRO", 4, 217013},
	{"WORDLY", 6, 217014},
	{"PRISTON", 7, 217015},
	{"BIRGE", 5, 217016},
	{"SLEVIN", 6, 217017},
	{"FASTFORWARD", 11, 217018},
	{"DOWNLOADX", 9, 217019},
	{"COCCI", 5, 217020},
	{"EMTALA", 6, 217021},
	{"CONKLING", 8, 217022},
	{"MERLONI", 7, 217023},
	{"LEVITATED", 9, 217024},
	{"ALEXANDRINA", 11, 217025},
	{"DYERSVILLE", 10, 217026},
	{"FLUGZEUG", 8, 217027},
	{"DISTRIC", 7, 217028},
	{"MAHLE", 5, 217029},
	{"WSBA", 4, 217030},
	{"ORANGETRAVEL", 12, 217031},
	{"AEWM", 4, 217032},
	{"YMWELD", 6, 217033},
	{"IPHONE", 6, 217034},
	{"SUPERMAX", 8, 217035},
	{"FABIANI", 7, 217036},
	{"MOBBING", 7, 217037},
	{"CHURCHWARDENS", 13, 217038},
	{"PRTYPE", 6, 217039},
	{"DEBUTANT", 8, 217040},
	{"BEAUTYDAY", 9, 217041},
	{"EURIBOR", 7, 217042},
	{"AYLESWORTH", 10, 217043},
	{"SEPIK", 5, 217044},
	{"PREJEAN", 7, 217045},
	{"CONVEYANCER", 11, 217046},
	{"SUMMERCLUB", 10, 217047},
	{"MEANES", 6, 217048},
	{"KRISTEVA", 8, 217049},
	{"OUTCROPPINGS", 12, 217050},
	{"GLOBALISING", 11, 217051},
	{"ARLETTE", 7, 217052},
	{"ZAHAR", 5, 217053},
	{"WATONGA", 7, 217054},
	{"AXIOMATIZATION", 14, 217055},
	{"VALERATE", 8, 217056},
	{"SOLEILMOON", 10, 217057},
	{"LOLLI", 5, 217058},
	{"ACROIEHLPROBJ", 13, 217059},
	{"ZELP", 4, 217060},
	{"YNTR", 4, 217061},
	{"YMAF", 4, 217062},
	{"XADM", 4, 217063},
	{"VEXT", 4, 217064},
	{"VAPU", 4, 217065},
	{"URRW", 4, 217066},
	{"UCOW", 4, 217067},
	{"UBYP", 4, 217068},
	{"TZPO", 4, 217069},
	{"TYIG", 4, 217070},
	{"TMYY", 4, 217071},
	{"RUBW", 4, 217072},
	{"ROIW", 4, 217073},
	{"RBOZ", 4, 217074},
	{"OJRA", 4, 217075},
	{"OGUP", 4, 217076},
	{"NEZL", 4, 217077},
	{"MDIT", 4, 217078},
	{"KWWW", 4, 217079},
	{"KBYK", 4, 217080},
	{"JUNM", 4, 217081},
	{"JHEL", 4, 217082},
	{"IZMI", 4, 217083},
	{"IXRB", 4, 217084},
	{"GVAG", 4, 217085},
	{"FABK", 4, 217086},
	{"EJPA", 4, 217087},
	{"EJLE", 4, 217088},
	{"EEXW", 4, 217089},
	{"CEWW", 4, 217090},
	{"BUEC", 4, 217091},
	{"BTAG", 4, 217092},
	{"BOLH", 4, 217093},
	{"BOBV", 4, 217094},
	{"BEVS", 4, 217095},
	{"APUG", 4, 217096},
	{"ALSZ", 4, 217097},
	{"GLUECIFER", 9, 217098},
	{"SEIDEN", 6, 217099},
	{"INTERCESSOR", 11, 217100},
	{"MISB", 4, 217101},
	{"GOSOD", 5, 217102},
	{"BANKWEST", 8, 217103},
	{"DSBL", 4, 217104},
	{"SIEVED", 6, 217105},
	{"BEFAHL", 6, 217106},
	{"MARKWELL", 8, 217107},
	{"LOVELIER", 8, 217108},
	{"ATCHAM", 6, 217109},
	{"YEESH", 5, 217110},
	{"BOTANIQUE", 9, 217111},
	{"YGNACIO", 7, 217112},
	{"NUWE", 4, 217113},
	{"FUNCALL", 7, 217114},
	{"HILLSLOPE", 9, 217115},
	{"GAEMS", 5, 217116},
	{"PAROL", 5, 217117},
	{"COMPILABLE", 10, 217118},
	{"CLAPTRAP", 8, 217119},
	{"MERIVA", 6, 217120},
	{"AMFPHP", 6, 217121},
	{"DYSAN", 5, 217122},
	{"GOETZE", 6, 217123},
	{"REVOL", 5, 217124},
	{"ODIUM", 5, 217125},
	{"BONDIES", 7, 217126},
	{"SECONDER", 8, 217127},
	{"RYZE", 4, 217128},
	{"KIELI", 5, 217129},
	{"KALLIO", 6, 217130},
	{"BELLTECH", 8, 217131},
	{"LESIONED", 8, 217132},
	{"MCCRERY", 7, 217133},
	{"RHODOPSEUDOMONAS", 16, 217134},
	{"JOFFRE", 6, 217135},
	{"FETTERED", 8, 217136},
	{"DOCTRINAIRE", 11, 217137},
	{"KRYSIAK", 7, 217138},
	{"SIPHONS", 7, 217139},
	{"MAYBELLE", 8, 217140},
	{"DRUPA", 5, 217141},
	{"AJOUT", 5, 217142},
	{"METALCALC", 9, 217143},
	{"WARANGAL", 8, 217144},
	{"HUSTINGS", 8, 217145},
	{"GENICA", 6, 217146},
	{"GBADVANCE", 9, 217147},
	{"PASTURED", 8, 217148},
	{"COMPLAINERS", 11, 217149},
	{"SUQUAMISH", 9, 217150},
	{"RASPING", 7, 217151},
	{"PHMC", 4, 217152},
	{"SUTEKH", 6, 217153},
	{"ORGANISA", 8, 217154},
	{"NEWSIES", 7, 217155},
	{"FASTFIND", 8, 217156},
	{"ROCKMART", 8, 217157},
	{"NASIM", 5, 217158},
	{"MACTAGGART", 10, 217159},
	{"AQUAGLIDE", 9, 217160},
	{"LMWH", 4, 217161},
	{"IMPORTANCIA", 11, 217162},
	{"UKDA", 4, 217163},
	{"PANDAY", 6, 217164},
	{"EMED", 4, 217165},
	{"MCMUFFIN", 8, 217166},
	{"DRIBBLES", 8, 217167},
	{"STEPANOV", 8, 217168},
	{"BESOTTED", 8, 217169},
	{"CASNER", 6, 217170},
	{"CCAT", 4, 217171},
	{"MANITO", 6, 217172},
	{"VIRGINIAUSA", 11, 217173},
	{"SHIREY", 6, 217174},
	{"UEXPRESS", 8, 217175},
	{"ESTERNI", 7, 217176},
	{"BLUEGREEN", 9, 217177},
	{"ATTERBURY", 9, 217178},
	{"WAGLE", 5, 217179},
	{"CONCERTINO", 10, 217180},
	{"ELECTROMOTIVE", 13, 217181},
	{"DERWENTSIDE", 11, 217182},
	{"MANDOLA", 7, 217183},
	{"HEINICKE", 8, 217184},
	{"HAWLIAU", 7, 217185},
	{"GUNILLA", 7, 217186},
	{"CALIPATRIA", 10, 217187},
	{"ZKLFK", 5, 217188},
	{"SLEZAK", 6, 217189},
	{"CARRELS", 7, 217190},
	{"SWANEPOEL", 9, 217191},
	{"BARGINS", 7, 217192},
	{"KPIC", 4, 217193},
	{"MAKARA", 6, 217194},
	{"HENKIN", 6, 217195},
	{"DOUB", 4, 217196},
	{"CYWORD", 6, 217197},
	{"AMINOBENZOIC", 12, 217198},
	{"WINCVS", 6, 217199},
	{"MATHSCINET", 10, 217200},
	{"DPSS", 4, 217201},
	{"WARINER", 7, 217202},
	{"RELF", 4, 217203},
	{"ISILOX", 6, 217204},
	{"SUNCOOK", 7, 217205},
	{"KARUR", 5, 217206},
	{"AESCULAPIUS", 11, 217207},
	{"SKLENARIKOVA", 12, 217208},
	{"GANGWAYS", 8, 217209},
	{"ATTIKI", 6, 217210},
	{"VILAR", 5, 217211},
	{"FURBALL", 7, 217212},
	{"PITAL", 5, 217213},
	{"WINEDT", 6, 217214},
	{"PENTONVILLE", 11, 217215},
	{"DAISEY", 6, 217216},
	{"RESTRAUNT", 9, 217217},
	{"CAULKER", 7, 217218},
	{"PARIA", 5, 217219},
	{"FORMAIL", 7, 217220},
	{"EPPO", 4, 217221},
	{"TERZO", 5, 217222},
	{"CHARIOTEER", 10, 217223},
	{"CANARA", 6, 217224},
	{"PAPERED", 7, 217225},
	{"OTILDE", 6, 217226},
	{"DIMENTIONS", 10, 217227},
	{"LYCIA", 5, 217228},
	{"ARCON", 5, 217229},
	{"THORNABY", 8, 217230},
	{"BIMOTA", 6, 217231},
	{"YOEL", 4, 217232},
	{"RWANDANS", 8, 217233},
	{"KHIR", 4, 217234},
	{"NODESET", 7, 217235},
	{"COADMINISTRATION", 16, 217236},
	{"WAIMATE", 7, 217237},
	{"ODNR", 4, 217238},
	{"LOVEPUMP", 8, 217239},
	{"COLECTOMY", 9, 217240},
	{"DEWCHURCH", 9, 217241},
	{"XWRES", 5, 217242},
	{"DVDSHOP", 7, 217243},
	{"MICHAELCHURCH", 13, 217244},
	{"CCLI", 4, 217245},
	{"PORA", 4, 217246},
	{"CIVITA", 6, 217247},
	{"THORS", 5, 217248},
	{"LEARING", 7, 217249},
	{"INSTITUTIONALISM", 16, 217250},
	{"BARNER", 6, 217251},
	{"ZONV", 4, 217252},
	{"ZONJ", 4, 217253},
	{"ZACD", 4, 217254},
	{"XRUL", 4, 217255},
	{"XGAR", 4, 217256},
	{"XEAC", 4, 217257},
	{"WPAD", 4, 217258},
	{"VIFI", 4, 217259},
	{"VFIR", 4, 217260},
	{"UUME", 4, 217261},
	{"UMUA", 4, 217262},
	{"UKRO", 4, 217263},
	{"UIDU", 4, 217264},
	{"UDGU", 4, 217265},
	{"UBSV", 4, 217266},
	{"TYLY", 4, 217267},
	{"TUSY", 4, 217268},
	{"TOYG", 4, 217269},
	{"SNUK", 4, 217270},
	{"RYKY", 4, 217271},
	{"RPBO", 4, 217272},
	{"ROGC", 4, 217273},
	{"RMIW", 4, 217274},
	{"RCTE", 4, 217275},
	{"RAKG", 4, 217276},
	{"OYGL", 4, 217277},
	{"OTYW", 4, 217278},
	{"OPTM", 4, 217279},
	{"OCOQ", 4, 217280},
	{"NNRU", 4, 217281},
	{"MTUM", 4, 217282},
	{"MRUI", 4, 217283},
	{"MLAO", 4, 217284},
	{"LZQU", 4, 217285},
	{"LTYY", 4, 217286},
	{"KHUZ", 4, 217287},
	{"IOLY", 4, 217288},
	{"GVAU", 4, 217289},
	{"GPSN", 4, 217290},
	{"GOMR", 4, 217291},
	{"GHWY", 4, 217292},
	{"GEUK", 4, 217293},
	{"ETKR", 4, 217294},
	{"EPKR", 4, 217295},
	{"ELKM", 4, 217296},
	{"EEXB", 4, 217297},
	{"DZEB", 4, 217298},
	{"DZAG", 4, 217299},
	{"DAFC", 4, 217300},
	{"CRAA", 4, 217301},
	{"CIWE", 4, 217302},
	{"CHKH", 4, 217303},
	{"CFON", 4, 217304},
	{"BNEV", 4, 217305},
	{"BMCA", 4, 217306},
	{"AYDL", 4, 217307},
	{"AUKC", 4, 217308},
	{"AMTV", 4, 217309},
	{"PRIMUM", 6, 217310},
	{"OPPORTUNISTICALLY", 17, 217311},
	{"MEXIC", 5, 217312},
	{"CHISTMAS", 8, 217313},
	{"RUBYS", 5, 217314},
	{"CLAMBER", 7, 217315},
	{"VREME", 5, 217316},
	{"QUIJANO", 7, 217317},
	{"MECHE", 5, 217318},
	{"BREWMASTER", 10, 217319},
	{"MKIV", 4, 217320},
	{"HYPERSURFACES", 13, 217321},
	{"CALLWAVE", 8, 217322},
	{"GEOTRAC", 7, 217323},
	{"ADROITLY", 8, 217324},
	{"UFM", 3, 217325},
	{"RABBAH", 6, 217326},
	{"BBSPOT", 6, 217327},
	{"FUNBAGS", 7, 217328},
	{"FOOTMUFF", 8, 217329},
	{"ESTEVE", 6, 217330},
	{"CONVERSA", 8, 217331},
	{"BDSP", 4, 217332},
	{"SPINED", 6, 217333},
	{"KUCHLING", 8, 217334},
	{"EARLENE", 7, 217335},
	{"PSIVIDA", 7, 217336},
	{"LEININGER", 9, 217337},
	{"TESTAROSSA", 10, 217338},
	{"ALLDAY", 6, 217339},
	{"WWWPOST", 7, 217340},
	{"POPROCK", 7, 217341},
	{"SCHOB", 5, 217342},
	{"ADME", 4, 217343},
	{"PRIMAIRE", 8, 217344},
	{"STRONGBOW", 9, 217345},
	{"GLOOLE", 6, 217346},
	{"BRIF", 4, 217347},
	{"BILLERS", 7, 217348},
	{"TANUKI", 6, 217349},
	{"NAVID", 5, 217350},
	{"CYSTATIN", 8, 217351},
	{"BURB", 4, 217352},
	{"BINSWANGER", 10, 217353},
	{"BACTON", 6, 217354},
	{"FOIP", 4, 217355},
	{"PRONET", 6, 217356},
	{"FLATFORTY", 9, 217357},
	{"GUNSTON", 7, 217358},
	{"SOEMTHING", 9, 217359},
	{"GEOMANCY", 8, 217360},
	{"PATENTE", 7, 217361},
	{"OSTARA", 6, 217362},
	{"LEUCADIA", 8, 217363},
	{"KISHA", 5, 217364},
	{"HJELM", 5, 217365},
	{"DBK", 3, 217366},
	{"SABLON", 6, 217367},
	{"XSED", 4, 217368},
	{"WWWTHUMBNAIL", 12, 217369},
	{"VSKIP", 5, 217370},
	{"GAARA", 5, 217371},
	{"BLUECHIP", 8, 217372},
	{"OVENWARE", 8, 217373},
	{"AHLSTROM", 8, 217374},
	{"FISICO", 6, 217375},
	{"FERNE", 5, 217376},
	{"MATHBF", 6, 217377},
	{"DESCENTE", 8, 217378},
	{"FREDY", 5, 217379},
	{"ONLINEPHARMACY", 14, 217380},
	{"MEDIANEWS", 9, 217381},
	{"WDL", 3, 217382},
	{"PESQUISAS", 9, 217383},
	{"KATINA", 6, 217384},
	{"POLYSORBATE", 11, 217385},
	{"WORLDOFHOTELS", 13, 217386},
	{"TERRORCRAFT", 11, 217387},
	{"SUPERPOTENTIAL", 14, 217388},
	{"MAUK", 4, 217389},
	{"HTSUS", 5, 217390},
	{"FREENESS", 8, 217391},
	{"TRANSUBSTANTIATION", 18, 217392},
	{"PRAKTISCHE", 10, 217393},
	{"MINIGAME", 8, 217394},
	{"GYFFREDINOL", 11, 217395},
	{"ELECTRONEGATIVITY", 17, 217396},
	{"HOLTE", 5, 217397},
	{"BCEIO", 5, 217398},
	{"QUATUOR", 7, 217399},
	{"DZOGCHEN", 8, 217400},
	{"DISTRACTORS", 11, 217401},
	{"FIONN", 5, 217402},
	{"WOHNHEIM", 8, 217403},
	{"HALEKULANI", 10, 217404},
	{"GOLFMAGIC", 9, 217405},
	{"EMPREGO", 7, 217406},
	{"BLOUNTVILLE", 11, 217407},
	{"RANGIORA", 8, 217408},
	{"CLNP", 4, 217409},
	{"ASPLUND", 7, 217410},
	{"COENEN", 6, 217411},
	{"VISNJIC", 7, 217412},
	{"FEODOR", 6, 217413},
	{"PAPANDREOY", 10, 217414},
	{"KLINIKUM", 8, 217415},
	{"FREQUENCE", 9, 217416},
	{"FOLLWING", 8, 217417},
	{"COGEMA", 6, 217418},
	{"BRAGANZA", 8, 217419},
	{"ETROPOLE", 8, 217420},
	{"DJINDJIC", 8, 217421},
	{"AUKTIONEN", 9, 217422},
	{"REYK", 4, 217423},
	{"BROXBURN", 8, 217424},
	{"PARROTING", 9, 217425},
	{"SETLINECAP", 10, 217426},
	{"FLUVAL", 6, 217427},
	{"BIZZAR", 6, 217428},
	{"XNEST", 5, 217429},
	{"ETHNOBOTANICAL", 14, 217430},
	{"ALDERS", 6, 217431},
	{"TEENFIRST", 9, 217432},
	{"OTISVILLE", 9, 217433},
	{"EINDRINGEN", 10, 217434},
	{"PHOTOCAST", 9, 217435},
	{"NETSPLIT", 8, 217436},
	{"LOCALDIRECTOR", 13, 217437},
	{"SQUAB", 5, 217438},
	{"COWARNE", 7, 217439},
	{"KEVYN", 5, 217440},
	{"MITTAGONG", 9, 217441},
	{"HOGGART", 7, 217442},
	{"PPBV", 4, 217443},
	{"TWIKICONTRIBUTOR", 16, 217444},
	{"PILUS", 5, 217445},
	{"CONTIENEN", 9, 217446},
	{"ASSMANN", 7, 217447},
	{"SVMS", 4, 217448},
	{"GARTERBELTS", 11, 217449},
	{"VAHID", 5, 217450},
	{"LAYARD", 6, 217451},
	{"HOLLANDALE", 10, 217452},
	{"GARETTO", 7, 217453},
	{"DARKSTEEL", 9, 217454},
	{"TADLEY", 6, 217455},
	{"TACHE", 5, 217456},
	{"QTRLY", 5, 217457},
	{"PEHRSON", 7, 217458},
	{"GORON", 5, 217459},
	{"CUSINE", 6, 217460},
	{"NIKSIC", 6, 217461},
	{"GAMRS", 5, 217462},
	{"CAVER", 5, 217463},
	{"FASSTE", 6, 217464},
	{"CATASTROPHICALLY", 16, 217465},
	{"BROWSEABLE", 10, 217466},
	{"SPACEMAKER", 10, 217467},
	{"GIUSTI", 6, 217468},
	{"CPMS", 4, 217469},
	{"TOURISTINFORMATION", 18, 217470},
	{"ROSALINE", 8, 217471},
	{"PUNCHLINES", 10, 217472},
	{"GULLANE", 7, 217473},
	{"FREEFLOW", 8, 217474},
	{"BIEGE", 5, 217475},
	{"GAMSAT", 6, 217476},
	{"ZDAM", 4, 217477},
	{"YFOE", 4, 217478},
	{"YADW", 4, 217479},
	{"VAKC", 4, 217480},
	{"UWJO", 4, 217481},
	{"UVOR", 4, 217482},
	{"URNQ", 4, 217483},
	{"UOSQ", 4, 217484},
	{"UAYC", 4, 217485},
	{"TTLU", 4, 217486},
	{"TJRW", 4, 217487},
	{"SAXP", 4, 217488},
	{"SAVR", 4, 217489},
	{"RGUK", 4, 217490},
	{"PWRA", 4, 217491},
	{"POTJ", 4, 217492},
	{"PGAA", 4, 217493},
	{"NGLC", 4, 217494},
	{"JPER", 4, 217495},
	{"IIMU", 4, 217496},
	{"HPWI", 4, 217497},
	{"HMMG", 4, 217498},
	{"GSYD", 4, 217499},
	{"GIKI", 4, 217500},
	{"GEZO", 4, 217501},
	{"GBIE", 4, 217502},
	{"FYIE", 4, 217503},
	{"FHEX", 4, 217504},
	{"EZEG", 4, 217505},
	{"EJIR", 4, 217506},
	{"DFMA", 4, 217507},
	{"DDCL", 4, 217508},
	{"DCTR", 4, 217509},
	{"DAZH", 4, 217510},
	{"COWU", 4, 217511},
	{"CDPA", 4, 217512},
	{"CDBO", 4, 217513},
	{"BKAN", 4, 217514},
	{"AQIK", 4, 217515},
	{"ADKR", 4, 217516},
	{"ACJO", 4, 217517},
	{"PEACEVILLE", 10, 217518},
	{"NOSTDLIB", 8, 217519},
	{"MOURAD", 6, 217520},
	{"INITIALISING", 12, 217521},
	{"AVISION", 7, 217522},
	{"HELATH", 6, 217523},
	{"PSTEXT", 6, 217524},
	{"PFLUEGER", 8, 217525},
	{"KANDERSTEG", 10, 217526},
	{"SOGGIORNI", 9, 217527},
	{"PGHLIVE", 7, 217528},
	{"APELCO", 6, 217529},
	{"KLAYMAN", 7, 217530},
	{"FROOT", 5, 217531},
	{"COLLEGUE", 8, 217532},
	{"AGREP", 5, 217533},
	{"CRITCHLOW", 9, 217534},
	{"CHERRYH", 7, 217535},
	{"TEDSTONE", 8, 217536},
	{"FDLP", 4, 217537},
	{"CHESED", 6, 217538},
	{"UTILA", 5, 217539},
	{"SMBC", 4, 217540},
	{"POLIPHONIC", 10, 217541},
	{"TORANI", 6, 217542},
	{"EXTNAME", 7, 217543},
	{"TOPGUN", 6, 217544},
	{"FILETIME", 8, 217545},
	{"UNFLAPPABLE", 11, 217546},
	{"CRUMPETS", 8, 217547},
	{"SPAGETTI", 8, 217548},
	{"SKYROCKETS", 10, 217549},
	{"DIPLOPIA", 8, 217550},
	{"DEBOLT", 6, 217551},
	{"COMSUMER", 8, 217552},
	{"VASODILATORS", 12, 217553},
	{"UNFORMED", 8, 217554},
	{"NESTEA", 6, 217555},
	{"GORENSTEIN", 10, 217556},
	{"DUCATS", 6, 217557},
	{"WATCHFULNESS", 12, 217558},
	{"VELOC", 5, 217559},
	{"PORB", 4, 217560},
	{"INTERQUARTILE", 13, 217561},
	{"PUNTI", 5, 217562},
	{"KEDZIE", 6, 217563},
	{"HOMESIDE", 8, 217564},
	{"UHREN", 5, 217565},
	{"PLAGIARIZING", 12, 217566},
	{"KCK", 3, 217567},
	{"KATHERYN", 8, 217568},
	{"EMPYEMA", 7, 217569},
	{"MIRJANA", 7, 217570},
	{"LOPS", 4, 217571},
	{"APIACEAE", 8, 217572},
	{"INESCAPABLY", 11, 217573},
	{"BOUILLABAISSE", 13, 217574},
	{"ALETA", 5, 217575},
	{"MULTICRITERIA", 13, 217576},
	{"MARKOVICH", 9, 217577},
	{"GOTTES", 6, 217578},
	{"PANICO", 6, 217579},
	{"PAGENATION", 10, 217580},
	{"NATOMA", 6, 217581},
	{"DOLO", 4, 217582},
	{"POGGI", 5, 217583},
	{"KLEINES", 7, 217584},
	{"EMPEREUR", 8, 217585},
	{"HYPERINSULINEMIA", 16, 217586},
	{"DELTAV", 6, 217587},
	{"STICKFIGURE", 11, 217588},
	{"SOMETHIGN", 9, 217589},
	{"LOANSLOANS", 10, 217590},
	{"STEAMSHIPS", 10, 217591},
	{"SEMITONES", 9, 217592},
	{"SEISMICALLY", 11, 217593},
	{"EROTICALLY", 10, 217594},
	{"PRESCREENING", 12, 217595},
	{"AGMES", 5, 217596},
	{"DOOL", 4, 217597},
	{"PEZZI", 5, 217598},
	{"GOVTS", 5, 217599},
	{"BITFLUX", 7, 217600},
	{"MICROMOL", 8, 217601},
	{"AUCTIONEERING", 13, 217602},
	{"METRY", 5, 217603},
	{"BIELIZNA", 8, 217604},
	{"SCIAMACHY", 9, 217605},
	{"SUCCESFULL", 10, 217606},
	{"LUBICON", 7, 217607},
	{"JANZ", 4, 217608},
	{"TIVOS", 5, 217609},
	{"MEMOWARE", 8, 217610},
	{"DIREKTE", 7, 217611},
	{"ROSEANN", 7, 217612},
	{"TYPESTYLE", 9, 217613},
	{"SOULBURY", 8, 217614},
	{"SCHOOLINGS", 10, 217615},
	{"GRAYTON", 7, 217616},
	{"SPDY", 4, 217617},
	{"HVAD", 4, 217618},
	{"GUIDENCE", 8, 217619},
	{"TUNGUSKA", 8, 217620},
	{"PAREL", 5, 217621},
	{"MISSBRAUCHT", 11, 217622},
	{"CIME", 4, 217623},
	{"CHICKY", 6, 217624},
	{"HOTELHOTEL", 10, 217625},
	{"UNIVERSIADE", 11, 217626},
	{"NAZIONE", 7, 217627},
	{"SCHRIJVER", 9, 217628},
	{"PERLSTEIN", 9, 217629},
	{"PALANGA", 7, 217630},
	{"AUGGIE", 6, 217631},
	{"INSME", 5, 217632},
	{"BIOPROSPECTING", 14, 217633},
	{"HENEGHAN", 8, 217634},
	{"NAMELEN", 7, 217635},
	{"FILEBASE", 8, 217636},
	{"ERRC", 4, 217637},
	{"DOMBEY", 6, 217638},
	{"INSTITUCIONES", 13, 217639},
	{"BULGAR", 6, 217640},
	{"EGOTASTIC", 9, 217641},
	{"UPDO", 4, 217642},
	{"FIXTURESLIVE", 12, 217643},
	{"RUNN", 4, 217644},
	{"KOLDING", 7, 217645},
	{"JERROD", 6, 217646},
	{"IPIP", 4, 217647},
	{"SCANSNAP", 8, 217648},
	{"SARTAIN", 7, 217649},
	{"MEDIALLY", 8, 217650},
	{"DERZEIT", 7, 217651},
	{"ARGERICH", 8, 217652},
	{"LINGERI", 7, 217653},
	{"LACTUCA", 7, 217654},
	{"CRESTING", 8, 217655},
	{"KACKEN", 6, 217656},
	{"GSFONTS", 7, 217657},
	{"FLOOK", 5, 217658},
	{"KAWADA", 6, 217659},
	{"INFOFREE", 8, 217660},
	{"ANNOUNCEMENTLEARN", 17, 217661},
	{"SPARRER", 7, 217662},
	{"LOTERIA", 7, 217663},
	{"JELLICO", 7, 217664},
	{"APPARAT", 7, 217665},
	{"VIRTUEMART", 10, 217666},
	{"MAURINE", 7, 217667},
	{"ENGRAFTMENT", 11, 217668},
	{"EASTOVER", 8, 217669},
	{"ETRON", 5, 217670},
	{"DJD", 3, 217671},
	{"COMMENCEMENTS", 13, 217672},
	{"CNPQ", 4, 217673},
	{"IMPULSIVENESS", 13, 217674},
	{"GERBE", 5, 217675},
	{"BETDAQ", 6, 217676},
	{"BANGLORE", 8, 217677},
	{"LECAVALIER", 10, 217678},
	{"AMELIO", 6, 217679},
	{"WEBMASTERUK", 11, 217680},
	{"RUTTED", 6, 217681},
	{"RELIX", 5, 217682},
	{"FENNIMORE", 9, 217683},
	{"JUXTAPOSES", 10, 217684},
	{"CIRP", 4, 217685},
	{"RETRENCHED", 10, 217686},
	{"MEROMORPHIC", 11, 217687},
	{"HIDEYUKI", 8, 217688},
	{"DROZ", 4, 217689},
	{"STICKED", 7, 217690},
	{"MUCKRAKER", 9, 217691},
	{"IEITHOEDD", 9, 217692},
	{"POLYELECTROLYTE", 15, 217693},
	{"SUNDERED", 8, 217694},
	{"DECD", 4, 217695},
	{"ROMANTICO", 9, 217696},
	{"GODULIKE", 8, 217697},
	{"ECCLESIAE", 9, 217698},
	{"ZZOD", 4, 217699},
	{"ZIFO", 4, 217700},
	{"YIBA", 4, 217701},
	{"YGIS", 4, 217702},
	{"YENK", 4, 217703},
	{"XPAP", 4, 217704},
	{"UTUW", 4, 217705},
	{"UKKI", 4, 217706},
	{"UJOS", 4, 217707},
	{"UBOL", 4, 217708},
	{"UAYB", 4, 217709},
	{"TVOD", 4, 217710},
	{"TEKM", 4, 217711},
	{"RNNU", 4, 217712},
	{"RDIQ", 4, 217713},
	{"RCFR", 4, 217714},
	{"QCOU", 4, 217715},
	{"PYBY", 4, 217716},
	{"PPMI", 4, 217717},
	{"OWKR", 4, 217718},
	{"OVSW", 4, 217719},
	{"ONXC", 4, 217720},
	{"OGJU", 4, 217721},
	{"OFDP", 4, 217722},
	{"OCDA", 4, 217723},
	{"NFCI", 4, 217724},
	{"MUTL", 4, 217725},
	{"MLSP", 4, 217726},
	{"LYGY", 4, 217727},
	{"LSAJ", 4, 217728},
	{"LIKP", 4, 217729},
	{"LAPN", 4, 217730},
	{"KYYE", 4, 217731},
	{"KYAI", 4, 217732},
	{"KELG", 4, 217733},
	{"KCOH", 4, 217734},
	{"JUWO", 4, 217735},
	{"IYOR", 4, 217736},
	{"IOGL", 4, 217737},
	{"FEZO", 4, 217738},
	{"FBYU", 4, 217739},
	{"EPYG", 4, 217740},
	{"EMPM", 4, 217741},
	{"EFTQ", 4, 217742},
	{"DRDP", 4, 217743},
	{"DOZZ", 4, 217744},
	{"DMWI", 4, 217745},
	{"DKLO", 4, 217746},
	{"CYKN", 4, 217747},
	{"CONZ", 4, 217748},
	{"COAW", 4, 217749},
	{"CDAD", 4, 217750},
	{"BUGM", 4, 217751},
	{"BPSC", 4, 217752},
	{"BEYN", 4, 217753},
	{"BCUP", 4, 217754},
	{"AJDU", 4, 217755},
	{"ACGU", 4, 217756},
	{"VMB", 3, 217757},
	{"OKLAHOMANS", 10, 217758},
	{"PERLAS", 6, 217759},
	{"IRRETRIEVABLE", 13, 217760},
	{"GEOINFORMATICS", 14, 217761},
	{"BRIEVEN", 7, 217762},
	{"REPORTEDBY", 10, 217763},
	{"HORCH", 5, 217764},
	{"GALLOPADE", 9, 217765},
	{"ROGUISH", 7, 217766},
	{"NICOYA", 6, 217767},
	{"TENIR", 5, 217768},
	{"GOTHARD", 7, 217769},
	{"DESCUENTOS", 10, 217770},
	{"MATRIXX", 7, 217771},
	{"JOSPIN", 6, 217772},
	{"USLEEP", 6, 217773},
	{"BOOTMAKER", 9, 217774},
	{"SYLVESTERTHEKAT", 15, 217775},
	{"RENICK", 6, 217776},
	{"INTERCOOLERS", 12, 217777},
	{"LINDS", 5, 217778},
	{"FTSZ", 4, 217779},
	{"FLOORCOVERINGS", 14, 217780},
	{"ZILKER", 6, 217781},
	{"COERCIVITY", 10, 217782},
	{"TRIVIALIZE", 10, 217783},
	{"SPIKELET", 8, 217784},
	{"EARTHYEAR", 9, 217785},
	{"AUTUMNS", 7, 217786},
	{"SPRINGERS", 9, 217787},
	{"NONOXYNOL", 9, 217788},
	{"HINOKI", 6, 217789},
	{"EAGLEHAWK", 9, 217790},
	{"MAAND", 5, 217791},
	{"CIAMPI", 6, 217792},
	{"CONGENIC", 8, 217793},
	{"DUSTBURY", 8, 217794},
	{"INTERO", 6, 217795},
	{"ALEM", 4, 217796},
	{"STURGESS", 8, 217797},
	{"MPSF", 4, 217798},
	{"COMIENZA", 8, 217799},
	{"KNOLLWOOD", 9, 217800},
	{"INNOVATIVELY", 12, 217801},
	{"SOULIVE", 7, 217802},
	{"MUDDLING", 8, 217803},
	{"WHAKAPAPA", 9, 217804},
	{"ACCUS", 5, 217805},
	{"SKING", 5, 217806},
	{"FRITSCHI", 8, 217807},
	{"AREC", 4, 217808},
	{"OPENMAIL", 8, 217809},
	{"CHALKE", 6, 217810},
	{"PIVTURES", 8, 217811},
	{"SMCP", 4, 217812},
	{"SAFEHAVEN", 9, 217813},
	{"MADEJSKI", 8, 217814},
	{"CLIMATOLOGIST", 13, 217815},
	{"SECREST", 7, 217816},
	{"QIBLAH", 6, 217817},
	{"CONSISTANCY", 11, 217818},
	{"AKARI", 5, 217819},
	{"YALLINGUP", 9, 217820},
	{"GETCOMPONENTAT", 14, 217821},
	{"BELOV", 5, 217822},
	{"FATTIE", 6, 217823},
	{"BEART", 5, 217824},
	{"JAPANEES", 8, 217825},
	{"BROMAN", 6, 217826},
	{"KOOPMANS", 8, 217827},
	{"UVULA", 5, 217828},
	{"STRALSUND", 9, 217829},
	{"MAQUILADORAS", 12, 217830},
	{"ILHAM", 5, 217831},
	{"HADAMARDLP", 10, 217832},
	{"PALEOECOLOGY", 12, 217833},
	{"WESTLB", 6, 217834},
	{"LAURIA", 6, 217835},
	{"FARMBOY", 7, 217836},
	{"ASUNTOS", 7, 217837},
	{"LANDGRAF", 8, 217838},
	{"RAAGA", 5, 217839},
	{"COMPORTEMENT", 12, 217840},
	{"COMPIL", 6, 217841},
	{"ODINGER", 7, 217842},
	{"LARIAM", 6, 217843},
	{"JELLING", 7, 217844},
	{"TERRAS", 6, 217845},
	{"INFOSOFT", 8, 217846},
	{"BULLNOSE", 8, 217847},
	{"ZAPOROZHYE", 10, 217848},
	{"MEARA", 5, 217849},
	{"MINEO", 5, 217850},
	{"MCGIVERN", 8, 217851},
	{"HANZI", 5, 217852},
	{"TELEPHO", 7, 217853},
	{"RECKER", 6, 217854},
	{"MORBIDITIES", 11, 217855},
	{"CWSHREDDER", 10, 217856},
	{"ANGOON", 6, 217857},
	{"SPEEL", 5, 217858},
	{"RANUNCULACEAE", 13, 217859},
	{"OCUS", 4, 217860},
	{"ALENIA", 6, 217861},
	{"KAHLES", 6, 217862},
	{"RAPACITY", 8, 217863},
	{"MANUALMENTE", 11, 217864},
	{"EROTIKGESCHICHTEN", 17, 217865},
	{"UNDESIRABLES", 12, 217866},
	{"TRIBALLY", 8, 217867},
	{"EROTIX", 6, 217868},
	{"ELECTROMYOGRAPHIC", 17, 217869},
	{"XOONIPS", 7, 217870},
	{"NFSU", 4, 217871},
	{"JYVASKYLA", 9, 217872},
	{"HECHTER", 7, 217873},
	{"SICKEN", 6, 217874},
	{"PEROTTI", 7, 217875},
	{"EVISIONARTS", 11, 217876},
	{"SUPERMEN", 8, 217877},
	{"SHOPLIFTERS", 11, 217878},
	{"SCOMMESSE", 9, 217879},
	{"DEATHWING", 9, 217880},
	{"QUABBIN", 7, 217881},
	{"ECGD", 4, 217882},
	{"COMPOSITIONALITY", 16, 217883},
	{"VILES", 5, 217884},
	{"TOLGA", 5, 217885},
	{"TATUPU", 6, 217886},
	{"INTERMARKET", 11, 217887},
	{"ELOPEMENT", 9, 217888},
	{"COSMOLOGIES", 11, 217889},
	{"ANAMENETAI", 10, 217890},
	{"TOONAMI", 7, 217891},
	{"NJDOT", 5, 217892},
	{"TADD", 4, 217893},
	{"ARDENTE", 7, 217894},
	{"DSRC", 4, 217895},
	{"SEIFRIED", 8, 217896},
	{"DERIVATE", 8, 217897},
	{"PREH", 4, 217898},
	{"DIRSON", 6, 217899},
	{"HAIPHONG", 8, 217900},
	{"APPRX", 5, 217901},
	{"REPAINTS", 8, 217902},
	{"MYISAMCHK", 9, 217903},
	{"WINDLASSES", 10, 217904},
	{"PARVIFLORA", 10, 217905},
	{"HARMATTAN", 9, 217906},
	{"INVERTO", 7, 217907},
	{"OKKERVIL", 8, 217908},
	{"NEAME", 5, 217909},
	{"QUACKGRASS", 10, 217910},
	{"SWITEL", 6, 217911},
	{"MUZZLED", 7, 217912},
	{"DOBERMANS", 9, 217913},
	{"WORKE", 5, 217914},
	{"FROSINONE", 9, 217915},
	{"FOLLES", 6, 217916},
	{"CAMERO", 6, 217917},
	{"VARAS", 5, 217918},
	{"PALFFY", 6, 217919},
	{"HEADMASTERS", 11, 217920},
	{"SHEBEEST", 8, 217921},
	{"GMRP", 4, 217922},
	{"RIFTING", 7, 217923},
	{"NINETTE", 7, 217924},
	{"LOLITTA", 7, 217925},
	{"BEMOANS", 7, 217926},
	{"LYBIA", 5, 217927},
	{"COSMOCHIM", 9, 217928},
	{"ACCESSCONTROL", 13, 217929},
	{"GOBBI", 5, 217930},
	{"FPF", 3, 217931},
	{"WILLIN", 6, 217932},
	{"DIABETOLOGIA", 12, 217933},
	{"BESUCH", 6, 217934},
	{"SAIDI", 5, 217935},
	{"MONOSYLLABIC", 12, 217936},
	{"ZEXI", 4, 217937},
	{"ZBRA", 4, 217938},
	{"YTVP", 4, 217939},
	{"YJEL", 4, 217940},
	{"YAAP", 4, 217941},
	{"XISV", 4, 217942},
	{"WVES", 4, 217943},
	{"WJEF", 4, 217944},
	{"WDYO", 4, 217945},
	{"VTRI", 4, 217946},
	{"VSOL", 4, 217947},
	{"VLON", 4, 217948},
	{"URKT", 4, 217949},
	{"UNYU", 4, 217950},
	{"TVBA", 4, 217951},
	{"SJPM", 4, 217952},
	{"SCFL", 4, 217953},
	{"RRLE", 4, 217954},
	{"RPDF", 4, 217955},
	{"ROYV", 4, 217956},
	{"RGDU", 4, 217957},
	{"REMG", 4, 217958},
	{"RCKW", 4, 217959},
	{"QSCH", 4, 217960},
	{"PTKI", 4, 217961},
	{"OYAU", 4, 217962},
	{"OXPU", 4, 217963},
	{"OCHG", 4, 217964},
	{"NFHR", 4, 217965},
	{"MSUE", 4, 217966},
	{"MPSK", 4, 217967},
	{"MMCI", 4, 217968},
	{"LTTU", 4, 217969},
	{"LSHG", 4, 217970},
	{"LLCB", 4, 217971},
	{"LKOC", 4, 217972},
	{"KIFN", 4, 217973},
	{"KBIO", 4, 217974},
	{"KAUC", 4, 217975},
	{"KACK", 4, 217976},
	{"HIRG", 4, 217977},
	{"HBYV", 4, 217978},
	{"GHSJ", 4, 217979},
	{"GBCA", 4, 217980},
	{"FNHL", 4, 217981},
	{"FMBE", 4, 217982},
	{"EYKR", 4, 217983},
	{"DURM", 4, 217984},
	{"CUEU", 4, 217985},
	{"CENW", 4, 217986},
	{"CBOL", 4, 217987},
	{"AFZA", 4, 217988},
	{"AFJA", 4, 217989},
	{"ROVINJ", 6, 217990},
	{"GEOPHYSICAE", 11, 217991},
	{"TOODLES", 7, 217992},
	{"THANGKA", 7, 217993},
	{"POPED", 5, 217994},
	{"BLENNY", 6, 217995},
	{"EMRYS", 5, 217996},
	{"RUMMAGED", 8, 217997},
	{"ELIADE", 6, 217998},
	{"PEONS", 5, 217999},
	{"PATR", 4, 218000},
	{"HOSER", 5, 218001},
	{"FAUGHT", 6, 218002},
	{"WILKINSBURG", 11, 218003},
	{"TRAINA", 6, 218004},
	{"POPULARISED", 11, 218005},
	{"MICROPARTICLES", 14, 218006},
	{"BESTDRESSEDKIDS", 15, 218007},
	{"BUCHNERA", 8, 218008},
	{"TAIPAN", 6, 218009},
	{"PRTR", 4, 218010},
	{"JAMERSON", 8, 218011},
	{"EVANIER", 7, 218012},
	{"AUTOREGULATION", 14, 218013},
	{"MMPOG", 5, 218014},
	{"INCONTESTABLE", 13, 218015},
	{"CHAPULTEPEC", 11, 218016},
	{"BERR", 4, 218017},
	{"BARBARESCO", 10, 218018},
	{"FRITILLARIA", 11, 218019},
	{"REACHERS", 8, 218020},
	{"LANGUOR", 7, 218021},
	{"ISRAELS", 7, 218022},
	{"ECHINODERMATA", 13, 218023},
	{"HOSTIN", 6, 218024},
	{"FRIVOLITIES", 11, 218025},
	{"TAEGU", 5, 218026},
	{"PAPIO", 5, 218027},
	{"HEIKKINEN", 9, 218028},
	{"CATHE", 5, 218029},
	{"WSPD", 4, 218030},
	{"UOFC", 4, 218031},
	{"UBERNOSTRUM", 11, 218032},
	{"MUCKED", 6, 218033},
	{"MANTILLA", 8, 218034},
	{"CHILDPROOF", 10, 218035},
	{"SCHENKEL", 8, 218036},
	{"KAVAN", 5, 218037},
	{"MYOCLONIC", 9, 218038},
	{"KHEL", 4, 218039},
	{"ADENOID", 7, 218040},
	{"OSTRY", 5, 218041},
	{"LOCAT", 5, 218042},
	{"GLEMT", 5, 218043},
	{"CORNEUM", 7, 218044},
	{"BURDINE", 7, 218045},
	{"BALIS", 5, 218046},
	{"ORALITY", 7, 218047},
	{"NEDERLANDER", 11, 218048},
	{"SEARCCH", 7, 218049},
	{"SIDDELEY", 8, 218050},
	{"JOURNALED", 9, 218051},
	{"INSTANTE", 8, 218052},
	{"ATTBI", 5, 218053},
	{"PBDE", 4, 218054},
	{"MOOTSIES", 8, 218055},
	{"MADOX", 5, 218056},
	{"BEANTWOORDEN", 12, 218057},
	{"MANILVA", 7, 218058},
	{"HEBRAIC", 7, 218059},
	{"ALLDUMB", 7, 218060},
	{"SCANER", 6, 218061},
	{"EPOCHAL", 7, 218062},
	{"SHOPLIFTED", 10, 218063},
	{"RABKIN", 6, 218064},
	{"ICRAF", 5, 218065},
	{"CORRELATORS", 11, 218066},
	{"PROJETOS", 8, 218067},
	{"EASYRECOVERY", 12, 218068},
	{"VENTRILOQUISM", 13, 218069},
	{"SLOVENLY", 8, 218070},
	{"KETTERER", 8, 218071},
	{"HOARDINGS", 9, 218072},
	{"PAHOA", 5, 218073},
	{"AMBLED", 6, 218074},
	{"CONFEZIONE", 10, 218075},
	{"ERICACEAE", 9, 218076},
	{"HUGOTON", 7, 218077},
	{"AKEELAH", 7, 218078},
	{"FURBER", 6, 218079},
	{"CELEBRE", 7, 218080},
	{"NEWLETTERS", 10, 218081},
	{"HVIRTUAL", 8, 218082},
	{"TRANSLUCENCE", 12, 218083},
	{"CLEMENTINA", 10, 218084},
	{"NECESIDAD", 9, 218085},
	{"BIOCONDUCTOR", 12, 218086},
	{"UNFLAVORED", 10, 218087},
	{"MAHINDA", 7, 218088},
	{"HESITATIONS", 11, 218089},
	{"PHILLYBLOG", 10, 218090},
	{"JABBING", 7, 218091},
	{"ANALNI", 6, 218092},
	{"ACAL", 4, 218093},
	{"CALVIA", 6, 218094},
	{"CHARR", 5, 218095},
	{"PROTAGORAS", 10, 218096},
	{"OTTINGER", 8, 218097},
	{"MATHISEN", 8, 218098},
	{"RECKONER", 8, 218099},
	{"FORTISSIMO", 10, 218100},
	{"SAFC", 4, 218101},
	{"MILLIYET", 8, 218102},
	{"PILTDOWN", 8, 218103},
	{"MODOT", 5, 218104},
	{"FATWIRE", 7, 218105},
	{"MUNGE", 5, 218106},
	{"DREAMBOAT", 9, 218107},
	{"ASLIB", 5, 218108},
	{"NEMERLE", 7, 218109},
	{"SEREN", 5, 218110},
	{"SEARRCH", 7, 218111},
	{"GLYNDWR", 7, 218112},
	{"MONOCOT", 7, 218113},
	{"STANDARDCOLORS", 14, 218114},
	{"CURTAINED", 9, 218115},
	{"NAGUIB", 6, 218116},
	{"FOALING", 7, 218117},
	{"SVERDRUP", 8, 218118},
	{"OPENNING", 8, 218119},
	{"PURLOINED", 9, 218120},
	{"INFECTOR", 8, 218121},
	{"ANAVINI", 7, 218122},
	{"AFFI", 4, 218123},
	{"YGGDRASIL", 9, 218124},
	{"MINAYA", 6, 218125},
	{"USPRIVACY", 9, 218126},
	{"ELGAMAL", 7, 218127},
	{"MARCS", 5, 218128},
	{"PRESTEL", 7, 218129},
	{"KOUROU", 6, 218130},
	{"OATLEY", 6, 218131},
	{"LOUNGED", 7, 218132},
	{"VOLOGDA", 7, 218133},
	{"RANDLEMAN", 9, 218134},
	{"CLSC", 4, 218135},
	{"VINORELBINE", 11, 218136},
	{"MEDIASURFACE", 12, 218137},
	{"ISCC", 4, 218138},
	{"CONDTION", 8, 218139},
	{"SANJIVA", 7, 218140},
	{"NARACOORTE", 10, 218141},
	{"EURONEWS", 8, 218142},
	{"CMCC", 4, 218143},
	{"LEAMAN", 6, 218144},
	{"LONDEN", 6, 218145},
	{"CATALYSE", 8, 218146},
	{"BARNAUL", 7, 218147},
	{"AIRNESS", 7, 218148},
	{"CARTOONNETWORK", 14, 218149},
	{"ALDINGA", 7, 218150},
	{"TEKLYNX", 7, 218151},
	{"MANDUCA", 7, 218152},
	{"KOSUKE", 6, 218153},
	{"GURA", 4, 218154},
	{"EDRS", 4, 218155},
	{"PUTTE", 5, 218156},
	{"FUDGING", 7, 218157},
	{"CELERIAC", 8, 218158},
	{"BALLYMUN", 8, 218159},
	{"BAKERSVILLE", 11, 218160},
	{"KOLOREX", 7, 218161},
	{"ZIPE", 4, 218162},
	{"YVAP", 4, 218163},
	{"YPTD", 4, 218164},
	{"YNFR", 4, 218165},
	{"XSWE", 4, 218166},
	{"WOLP", 4, 218167},
	{"WEYW", 4, 218168},
	{"UVAD", 4, 218169},
	{"UCYM", 4, 218170},
	{"TPPA", 4, 218171},
	{"TGLY", 4, 218172},
	{"TDIB", 4, 218173},
	{"SYKO", 4, 218174},
	{"SPNF", 4, 218175},
	{"PRHA", 4, 218176},
	{"POSF", 4, 218177},
	{"OXSF", 4, 218178},
	{"NTZF", 4, 218179},
	{"NTRD", 4, 218180},
	{"NSBC", 4, 218181},
	{"MCVA", 4, 218182},
	{"LZOM", 4, 218183},
	{"LSYD", 4, 218184},
	{"LHOV", 4, 218185},
	{"GYPI", 4, 218186},
	{"GJUV", 4, 218187},
	{"FAKO", 4, 218188},
	{"EYEY", 4, 218189},
	{"EVYM", 4, 218190},
	{"EVBA", 4, 218191},
	{"EUVA", 4, 218192},
	{"ERPN", 4, 218193},
	{"ERJJ", 4, 218194},
	{"EMMP", 4, 218195},
	{"EFIZ", 4, 218196},
	{"EDJP", 4, 218197},
	{"DMKE", 4, 218198},
	{"DDIK", 4, 218199},
	{"BYEY", 4, 218200},
	{"BESV", 4, 218201},
	{"BCEW", 4, 218202},
	{"BBIC", 4, 218203},
	{"ASGD", 4, 218204},
	{"AGAJ", 4, 218205},
	{"ABSY", 4, 218206},
	{"IDLES", 5, 218207},
	{"HAZUS", 5, 218208},
	{"GIFTTREE", 8, 218209},
	{"ONLEY", 5, 218210},
	{"PREBINDING", 10, 218211},
	{"GREGKH", 6, 218212},
	{"POLINA", 6, 218213},
	{"OVERESTIMATING", 14, 218214},
	{"KRIX", 4, 218215},
	{"HOKES", 5, 218216},
	{"DIBASIC", 7, 218217},
	{"SORED", 5, 218218},
	{"OVERPROTECTED", 13, 218219},
	{"SOLERA", 6, 218220},
	{"TANTALIZE", 9, 218221},
	{"KURTAS", 6, 218222},
	{"GAMI", 4, 218223},
	{"STALINISTS", 10, 218224},
	{"PERLINA", 7, 218225},
	{"ELEKTRONIKA", 11, 218226},
	{"UNCOUNT", 7, 218227},
	{"BODYPRO", 7, 218228},
	{"VITAS", 5, 218229},
	{"OPTIMISES", 9, 218230},
	{"DEFF", 4, 218231},
	{"MANDRILL", 8, 218232},
	{"DMOS", 4, 218233},
	{"AFFILATES", 9, 218234},
	{"TEARSHEETS", 10, 218235},
	{"PLAUTUS", 7, 218236},
	{"EGGEN", 5, 218237},
	{"WYDAWNICTWO", 11, 218238},
	{"MOUGINS", 7, 218239},
	{"FREEDANCE", 9, 218240},
	{"PPCS", 4, 218241},
	{"MANICURING", 10, 218242},
	{"WILLOWBANK", 10, 218243},
	{"TALKY", 5, 218244},
	{"RUSTICS", 7, 218245},
	{"DECHERT", 7, 218246},
	{"TREEHOUSES", 10, 218247},
	{"STRIATIONS", 10, 218248},
	{"PROFUNDIDAD", 11, 218249},
	{"INETNUM", 7, 218250},
	{"INANITY", 7, 218251},
	{"HAIRCUTTING", 11, 218252},
	{"FSAPC", 5, 218253},
	{"CARLSTROM", 9, 218254},
	{"GEMEENTE", 8, 218255},
	{"MIHM", 4, 218256},
	{"GAMACHE", 7, 218257},
	{"CRISTINE", 8, 218258},
	{"HONEYMAN", 8, 218259},
	{"BASICISP", 8, 218260},
	{"WEISSER", 7, 218261},
	{"SOLINAS", 7, 218262},
	{"POBREZA", 7, 218263},
	{"AARNIO", 6, 218264},
	{"YURIKO", 6, 218265},
	{"INNOVATEK", 9, 218266},
	{"CHRS", 4, 218267},
	{"OSMOLARITY", 10, 218268},
	{"KOBA", 4, 218269},
	{"CONCLUSORY", 10, 218270},
	{"VICOR", 5, 218271},
	{"EMBAYMENT", 9, 218272},
	{"YFP", 3, 218273},
	{"MENTALITIES", 11, 218274},
	{"LIZENZEN", 8, 218275},
	{"KLANTENSERVICE", 14, 218276},
	{"INFANTILISM", 11, 218277},
	{"ATITLAN", 7, 218278},
	{"APPEARENCES", 11, 218279},
	{"AGMA", 4, 218280},
	{"PURPOSELESS", 11, 218281},
	{"HINSKE", 6, 218282},
	{"CAMPSIE", 7, 218283},
	{"TOPOTECAN", 9, 218284},
	{"MIYAUCHI", 8, 218285},
	{"GEFAEHRLICH", 11, 218286},
	{"PAINTBRUSHES", 12, 218287},
	{"GEDEON", 6, 218288},
	{"ENCOMPIX", 8, 218289},
	{"BRIVE", 5, 218290},
	{"FENFIRE", 7, 218291},
	{"LOOONG", 6, 218292},
	{"DUQUESA", 7, 218293},
	{"SHECKLEY", 8, 218294},
	{"JODRELL", 7, 218295},
	{"KERIN", 5, 218296},
	{"VISITES", 7, 218297},
	{"SKIRMISHERS", 11, 218298},
	{"MOVQ", 4, 218299},
	{"AGROECOLOGY", 11, 218300},
	{"ROCKARCH", 8, 218301},
	{"PEYER", 5, 218302},
	{"KEYPHRASE", 9, 218303},
	{"FUNTRIVIA", 9, 218304},
	{"SUMMAR", 6, 218305},
	{"SIFNOS", 6, 218306},
	{"PREFORK", 7, 218307},
	{"MSTU", 4, 218308},
	{"IXYS", 4, 218309},
	{"HYAPATIA", 8, 218310},
	{"TSUTSUI", 7, 218311},
	{"LIKENING", 8, 218312},
	{"BYTECODES", 9, 218313},
	{"OLMO", 4, 218314},
	{"ERSITY", 6, 218315},
	{"CONTEXTUALIZE", 13, 218316},
	{"VILLALON", 8, 218317},
	{"MOUNTFIELD", 10, 218318},
	{"ARTHA", 5, 218319},
	{"LEVERANCIERS", 12, 218320},
	{"HUNAIN", 6, 218321},
	{"COHF", 4, 218322},
	{"CALANDRA", 8, 218323},
	{"SPORTOWE", 8, 218324},
	{"SHORENSTEIN", 11, 218325},
	{"HYPOTONIC", 9, 218326},
	{"LANGMAP", 7, 218327},
	{"ENDOCARDIAL", 11, 218328},
	{"YSATIS", 6, 218329},
	{"MELDUNGEN", 9, 218330},
	{"CHANCEY", 7, 218331},
	{"SACAJAWEA", 9, 218332},
	{"GANLEY", 6, 218333},
	{"FRENCHVILLE", 11, 218334},
	{"SKIPTRACE", 9, 218335},
	{"HERSHMAN", 8, 218336},
	{"DRUMHEAD", 8, 218337},
	{"OBSTFELD", 8, 218338},
	{"SUPERVI", 7, 218339},
	{"GODESS", 6, 218340},
	{"DERSTANDING", 11, 218341},
	{"HEYDEN", 6, 218342},
	{"INTERPUBLIC", 11, 218343},
	{"AVIFAUNA", 8, 218344},
	{"DIFFERENTIABILITY", 17, 218345},
	{"HACKLEY", 7, 218346},
	{"VICTIMHOOD", 10, 218347},
	{"FUTT", 4, 218348},
	{"SARB", 4, 218349},
	{"GOBBLEDYGOOK", 12, 218350},
	{"EUROSTYLE", 9, 218351},
	{"DIGITALCAMERAS", 14, 218352},
	{"XDCARD", 6, 218353},
	{"ALTEREGO", 8, 218354},
	{"WEATHERHILL", 11, 218355},
	{"JERONIMO", 8, 218356},
	{"ADDUCTION", 9, 218357},
	{"CHESTERS", 8, 218358},
	{"CARRENTALS", 10, 218359},
	{"SEROTYPING", 10, 218360},
	{"OPTISCHE", 8, 218361},
	{"CEMBER", 6, 218362},
	{"ARGMAX", 6, 218363},
	{"PROPAFENONE", 11, 218364},
	{"FLINCHING", 9, 218365},
	{"CERTAINE", 8, 218366},
	{"SPANGENBERG", 11, 218367},
	{"DENIZLI", 7, 218368},
	{"BLISSFIELD", 10, 218369},
	{"AUTOPOWER", 9, 218370},
	{"WEIGTH", 6, 218371},
	{"CCTS", 4, 218372},
	{"VERLA", 5, 218373},
	{"TRUMPETERS", 10, 218374},
	{"KRATZER", 7, 218375},
	{"ADEILADU", 8, 218376},
	{"UNSHARED", 8, 218377},
	{"GOLAND", 6, 218378},
	{"MICROFLEX", 9, 218379},
	{"MICHIRU", 7, 218380},
	{"LOVITZ", 6, 218381},
	{"CZESTOCHOWA", 11, 218382},
	{"SEARCHH", 7, 218383},
	{"HAGOOD", 6, 218384},
	{"ELONG", 5, 218385},
	{"POEL", 4, 218386},
	{"DAYTRIPS", 8, 218387},
	{"ALVIERO", 7, 218388},
	{"ROODEPOORT", 10, 218389},
	{"DOSNT", 5, 218390},
	{"BRUNK", 5, 218391},
	{"ADASHIEL", 8, 218392},
	{"REKTAL", 6, 218393},
	{"CATECHISTS", 10, 218394},
	{"KATALOGE", 8, 218395},
	{"URBS", 4, 218396},
	{"PHPSHOP", 7, 218397},
	{"INGROUP", 7, 218398},
	{"MSIL", 4, 218399},
	{"LODA", 4, 218400},
	{"LAWRE", 5, 218401},
	{"IMMUNOPATHOLOGY", 15, 218402},
	{"ASSORT", 6, 218403},
	{"ARVINMERITOR", 12, 218404},
	{"ZROD", 4, 218405},
	{"ZPIC", 4, 218406},
	{"ZCEN", 4, 218407},
	{"YIMU", 4, 218408},
	{"YFAW", 4, 218409},
	{"YADK", 4, 218410},
	{"XIGL", 4, 218411},
	{"WWAC", 4, 218412},
	{"WADJ", 4, 218413},
	{"VBLA", 4, 218414},
	{"UTWW", 4, 218415},
	{"UETM", 4, 218416},
	{"UASF", 4, 218417},
	{"RTND", 4, 218418},
	{"RFOM", 4, 218419},
	{"RCYD", 4, 218420},
	{"RCFI", 4, 218421},
	{"QADD", 4, 218422},
	{"OPYG", 4, 218423},
	{"OIMU", 4, 218424},
	{"NCKW", 4, 218425},
	{"NADK", 4, 218426},
	{"MSMD", 4, 218427},
	{"LNBE", 4, 218428},
	{"LLRH", 4, 218429},
	{"KBID", 4, 218430},
	{"KAOL", 4, 218431},
	{"JRVI", 4, 218432},
	{"JAMF", 4, 218433},
	{"HJUV", 4, 218434},
	{"HAPW", 4, 218435},
	{"GZOM", 4, 218436},
	{"GPMA", 4, 218437},
	{"FWWE", 4, 218438},
	{"FMFR", 4, 218439},
	{"FGWA", 4, 218440},
	{"FAXP", 4, 218441},
	{"FAQI", 4, 218442},
	{"EROQ", 4, 218443},
	{"EPPN", 4, 218444},
	{"EBTG", 4, 218445},
	{"DYEH", 4, 218446},
	{"DUMY", 4, 218447},
	{"DTAW", 4, 218448},
	{"DSPC", 4, 218449},
	{"DPDA", 4, 218450},
	{"DLWI", 4, 218451},
	{"CICU", 4, 218452},
	{"BYWY", 4, 218453},
	{"BYPT", 4, 218454},
	{"BOLY", 4, 218455},
	{"AUPD", 4, 218456},
	{"AKSK", 4, 218457},
	{"AKQU", 4, 218458},
	{"AFSU", 4, 218459},
	{"AFSG", 4, 218460},
	{"ABSG", 4, 218461},
	{"JATWATER", 8, 218462},
	{"ROTONDO", 7, 218463},
	{"HUSSLE", 6, 218464},
	{"CZAS", 4, 218465},
	{"PICENO", 6, 218466},
	{"KLUTE", 5, 218467},
	{"CARRYALL", 8, 218468},
	{"MASTRUBATION", 12, 218469},
	{"DNRC", 4, 218470},
	{"COCYCLE", 7, 218471},
	{"CHIMAYO", 7, 218472},
	{"ALLAMA", 6, 218473},
	{"MARGALIT", 8, 218474},
	{"DRINAL", 6, 218475},
	{"PENDS", 5, 218476},
	{"LITRIX", 6, 218477},
	{"JEANRICHARD", 11, 218478},
	{"MICARDIS", 8, 218479},
	{"STARBAND", 8, 218480},
	{"PNRENDER", 8, 218481},
	{"JANEEN", 6, 218482},
	{"PEPLUM", 6, 218483},
	{"SWINGSET", 8, 218484},
	{"BIOTHERAPIES", 12, 218485},
	{"ABARTIG", 7, 218486},
	{"SUBM", 4, 218487},
	{"PHOSPHATIDYLCHOLINES", 20, 218488},
	{"KALEVALA", 8, 218489},
	{"TELKWA", 6, 218490},
	{"UNPARSED", 8, 218491},
	{"DISBELIEVED", 11, 218492},
	{"VISON", 5, 218493},
	{"MEDIAONE", 8, 218494},
	{"XTIDE", 5, 218495},
	{"NOSUMMARY", 9, 218496},
	{"LLAN", 4, 218497},
	{"TRICHUR", 7, 218498},
	{"HOORAH", 6, 218499},
	{"UNCARED", 7, 218500},
	{"GROSFELD", 8, 218501},
	{"DIMENSIONI", 10, 218502},
	{"ANDERES", 7, 218503},
	{"ISKANDAR", 8, 218504},
	{"SCHMELKE", 8, 218505},
	{"NXPK", 4, 218506},
	{"BOTSCHAFT", 9, 218507},
	{"VMR", 3, 218508},
	{"GAJDA", 5, 218509},
	{"MIRABELLI", 9, 218510},
	{"DEBNEY", 6, 218511},
	{"WUHN", 4, 218512},
	{"KELLAM", 6, 218513},
	{"HETEROTOPIC", 11, 218514},
	{"EUROBONDS", 9, 218515},
	{"ETRADE", 6, 218516},
	{"CONNE", 5, 218517},
	{"BABBLES", 7, 218518},
	{"CORBELL", 7, 218519},
	{"ADBLOC", 6, 218520},
	{"SYSKONNECT", 10, 218521},
	{"PRISED", 6, 218522},
	{"MONOCOQUE", 9, 218523},
	{"ZIELONA", 7, 218524},
	{"SUBLEVEL", 8, 218525},
	{"JOTTO", 5, 218526},
	{"FIBROMA", 7, 218527},
	{"MEDICSTUDENTJON", 15, 218528},
	{"TARTT", 5, 218529},
	{"PIXOLOGIC", 9, 218530},
	{"WELLKNOWN", 9, 218531},
	{"PICTUREX", 8, 218532},
	{"FORTUNO", 7, 218533},
	{"BLEWITT", 7, 218534},
	{"PGRN", 4, 218535},
	{"METALHEAD", 9, 218536},
	{"WICHTIGE", 8, 218537},
	{"VICCA", 5, 218538},
	{"ERWAN", 5, 218539},
	{"BIVALENT", 8, 218540},
	{"ILLER", 5, 218541},
	{"PROFUNDIS", 9, 218542},
	{"MULTIENZYME", 11, 218543},
	{"TABLELAND", 9, 218544},
	{"INTERSEGMENT", 12, 218545},
	{"SIMETHICONE", 11, 218546},
	{"LEIM", 4, 218547},
	{"KANGWON", 7, 218548},
	{"DOCFINDER", 9, 218549},
	{"SIPRI", 5, 218550},
	{"HUCKSTER", 8, 218551},
	{"TELEVISING", 10, 218552},
	{"PLAATSEN", 8, 218553},
	{"STAUBGOLD", 9, 218554},
	{"PANORAMICA", 10, 218555},
	{"KOSINSKI", 8, 218556},
	{"INFINI", 6, 218557},
	{"ATAQUE", 6, 218558},
	{"SCHAMHAARE", 10, 218559},
	{"MONKEE", 6, 218560},
	{"CROQUETTES", 10, 218561},
	{"DECORE", 6, 218562},
	{"LAMEZIA", 7, 218563},
	{"KGALAGADI", 9, 218564},
	{"SCHAPER", 7, 218565},
	{"HUFFER", 6, 218566},
	{"ETIHAD", 6, 218567},
	{"USFREEADS", 9, 218568},
	{"ROTJ", 4, 218569},
	{"GIULIETTA", 9, 218570},
	{"GLVC", 4, 218571},
	{"FIEFDOM", 7, 218572},
	{"THINKWIKI", 9, 218573},
	{"MOKI", 4, 218574},
	{"CDTOOL", 6, 218575},
	{"CUPIDO", 6, 218576},
	{"COMMISSIE", 9, 218577},
	{"SHINIGAMI", 9, 218578},
	{"MARCESCENS", 10, 218579},
	{"REEMA", 5, 218580},
	{"PHILADEPHIA", 11, 218581},
	{"HOLDUM", 6, 218582},
	{"NABARD", 6, 218583},
	{"MUSSELSHELL", 11, 218584},
	{"CROUCHER", 8, 218585},
	{"BORNEMARK", 9, 218586},
	{"UILLEANN", 8, 218587},
	{"KUTTER", 6, 218588},
	{"WRLD", 4, 218589},
	{"RAIMUNDO", 8, 218590},
	{"MCKITTRICK", 10, 218591},
	{"MAROKKO", 7, 218592},
	{"VILLOSA", 7, 218593},
	{"TREESTANDS", 10, 218594},
	{"DISPROVEN", 9, 218595},
	{"CLIBURN", 7, 218596},
	{"TITRATIONS", 10, 218597},
	{"RIEB", 4, 218598},
	{"REVILE", 6, 218599},
	{"NAPPI", 5, 218600},
	{"GEIRIAU", 7, 218601},
	{"UNSELFISHNESS", 13, 218602},
	{"CHANNON", 7, 218603},
	{"ESTERASES", 9, 218604},
	{"CODEZ", 5, 218605},
	{"BLETHYN", 7, 218606},
	{"SYCOPHANTS", 10, 218607},
	{"VEEDER", 6, 218608},
	{"UNDISTORTED", 11, 218609},
	{"TRUSTSEAL", 9, 218610},
	{"SUPL", 4, 218611},
	{"SYCOPHANT", 9, 218612},
	{"SICAV", 5, 218613},
	{"MUMMA", 5, 218614},
	{"BURROWED", 8, 218615},
	{"ZHIRINOVSKY", 11, 218616},
	{"FRATELLO", 8, 218617},
	{"MHSAA", 5, 218618},
	{"TINDALE", 7, 218619},
	{"TATCHELL", 8, 218620},
	{"HASINA", 6, 218621},
	{"GOODBY", 6, 218622},
	{"PRUSSIANS", 9, 218623},
	{"BUTTERCUPS", 10, 218624},
	{"HOMEGIRL", 8, 218625},
	{"PARESIS", 7, 218626},
	{"POREIA", 6, 218627},
	{"NOPC", 4, 218628},
	{"FOOTFALL", 8, 218629},
	{"WAHEED", 6, 218630},
	{"PPMS", 4, 218631},
	{"MANTOOTH", 8, 218632},
	{"DOKTORSPIELE", 12, 218633},
	{"MARMOTS", 7, 218634},
	{"ZZYC", 4, 218635},
	{"YTCH", 4, 218636},
	{"WVAW", 4, 218637},
	{"WKRI", 4, 218638},
	{"VBEF", 4, 218639},
	{"UVTH", 4, 218640},
	{"UORH", 4, 218641},
	{"UOMY", 4, 218642},
	{"UIMI", 4, 218643},
	{"UABD", 4, 218644},
	{"TAYG", 4, 218645},
	{"SMRU", 4, 218646},
	{"SHPK", 4, 218647},
	{"SGUP", 4, 218648},
	{"SGMB", 4, 218649},
	{"SDIB", 4, 218650},
	{"SBWI", 4, 218651},
	{"RZEP", 4, 218652},
	{"RTFK", 4, 218653},
	{"RPKN", 4, 218654},
	{"RNIW", 4, 218655},
	{"RIBW", 4, 218656},
	{"QIRA", 4, 218657},
	{"PSUD", 4, 218658},
	{"POMU", 4, 218659},
	{"PLOB", 4, 218660},
	{"OKGL", 4, 218661},
	{"NKMS", 4, 218662},
	{"NGCF", 4, 218663},
	{"MHZB", 4, 218664},
	{"MFEW", 4, 218665},
	{"LVAE", 4, 218666},
	{"LTEF", 4, 218667},
	{"LPHV", 4, 218668},
	{"LOMW", 4, 218669},
	{"LJOC", 4, 218670},
	{"LGAF", 4, 218671},
	{"LEZB", 4, 218672},
	{"LALH", 4, 218673},
	{"KYCI", 4, 218674},
	{"JRSM", 4, 218675},
	{"IFUJ", 4, 218676},
	{"IFUC", 4, 218677},
	{"HUIP", 4, 218678},
	{"HMSU", 4, 218679},
	{"HCOX", 4, 218680},
	{"GOSZ", 4, 218681},
	{"GMBA", 4, 218682},
	{"GHZO", 4, 218683},
	{"FTNM", 4, 218684},
	{"EYMR", 4, 218685},
	{"EPRR", 4, 218686},
	{"EFBL", 4, 218687},
	{"DUMR", 4, 218688},
	{"DPOG", 4, 218689},
	{"DNGU", 4, 218690},
	{"DFHA", 4, 218691},
	{"CPAU", 4, 218692},
	{"BUDC", 4, 218693},
	{"BFNM", 4, 218694},
	{"ALTJ", 4, 218695},
	{"AKIJ", 4, 218696},
	{"AHLC", 4, 218697},
	{"AGUG", 4, 218698},
	{"VALPOLICELLA", 12, 218699},
	{"DANILOV", 7, 218700},
	{"COMPUTOR", 8, 218701},
	{"BAGMAN", 6, 218702},
	{"WICHSE", 6, 218703},
	{"PALLA", 5, 218704},
	{"EGOIST", 6, 218705},
	{"ASTROCYTE", 9, 218706},
	{"YEAROLD", 7, 218707},
	{"XBD", 3, 218708},
	{"BEAUCHEMIN", 10, 218709},
	{"STAUDT", 6, 218710},
	{"INDOLOGY", 8, 218711},
	{"HELGASON", 8, 218712},
	{"GABO", 4, 218713},
	{"COWMAN", 6, 218714},
	{"LEDE", 4, 218715},
	{"CHOOSERS", 8, 218716},
	{"NEMCOVA", 7, 218717},
	{"PENASQUITOS", 11, 218718},
	{"HYFFORDDI", 9, 218719},
	{"GOOGLEIT", 8, 218720},
	{"ENVP", 4, 218721},
	{"CWNP", 4, 218722},
	{"AGENTSS", 7, 218723},
	{"GLOMINERALS", 11, 218724},
	{"ENTIAL", 6, 218725},
	{"BONUSSS", 7, 218726},
	{"QUADRAL", 7, 218727},
	{"NPAC", 4, 218728},
	{"MAXALT", 6, 218729},
	{"AZERA", 5, 218730},
	{"FORSMAN", 7, 218731},
	{"ACEASTA", 7, 218732},
	{"SCHOMBERG", 9, 218733},
	{"CESM", 4, 218734},
	{"RENTSMART", 9, 218735},
	{"REFRACTIONS", 11, 218736},
	{"MAHESHWARI", 10, 218737},
	{"SHERDS", 6, 218738},
	{"BLACKABY", 8, 218739},
	{"SOINTULA", 8, 218740},
	{"PETROGRAPHIC", 12, 218741},
	{"NANOOK", 6, 218742},
	{"LIBYANS", 7, 218743},
	{"GEROLD", 6, 218744},
	{"VUKOVAR", 7, 218745},
	{"ATENCION", 8, 218746},
	{"PLASA", 5, 218747},
	{"KATALOGU", 8, 218748},
	{"ANNELI", 6, 218749},
	{"PROSECCO", 8, 218750},
	{"MSGP", 4, 218751},
	{"DUKKHA", 6, 218752},
	{"SUPPLYS", 7, 218753},
	{"DEVALUING", 9, 218754},
	{"MILOSLAV", 8, 218755},
	{"BOSTONROTT", 10, 218756},
	{"FICKTE", 6, 218757},
	{"COCOANUT", 8, 218758},
	{"MYKLEBUST", 9, 218759},
	{"ARIB", 4, 218760},
	{"ONLINEAGENCY", 12, 218761},
	{"PHOTES", 6, 218762},
	{"EIKENBERRY", 10, 218763},
	{"CAJOLED", 7, 218764},
	{"YASSIR", 6, 218765},
	{"MOMETASONE", 10, 218766},
	{"DELMARK", 7, 218767},
	{"UNDERSTATES", 11, 218768},
	{"KOOLER", 6, 218769},
	{"KIRSTEIN", 8, 218770},
	{"INTERTEC", 8, 218771},
	{"BOYKO", 5, 218772},
	{"KHOJ", 4, 218773},
	{"ELLENWOOD", 9, 218774},
	{"SCHLECKEN", 9, 218775},
	{"NIBBANA", 7, 218776},
	{"EMOTES", 6, 218777},
	{"COPTS", 5, 218778},
	{"BEZIEHT", 7, 218779},
	{"AGNELLI", 7, 218780},
	{"SUREFIT", 7, 218781},
	{"SAUEREIEN", 9, 218782},
	{"PRESTITI", 8, 218783},
	{"PHENOTYPICALLY", 14, 218784},
	{"ONMINE", 6, 218785},
	{"LAVENHAM", 8, 218786},
	{"RIVERWAY", 8, 218787},
	{"DERAILING", 9, 218788},
	{"SUWA", 4, 218789},
	{"RYDEX", 5, 218790},
	{"RAPALLO", 7, 218791},
	{"ULTRALINGUA", 11, 218792},
	{"AESCULUS", 8, 218793},
	{"WILBARGER", 9, 218794},
	{"NEUROTICISM", 11, 218795},
	{"SUBLIMELY", 9, 218796},
	{"DESTRUCTIBLE", 12, 218797},
	{"ASTUTELY", 8, 218798},
	{"ISOKINETIC", 10, 218799},
	{"WIREFREE", 8, 218800},
	{"SINORHIZOBIUM", 13, 218801},
	{"SUNDEVILS", 9, 218802},
	{"RATORY", 6, 218803},
	{"MINUETS", 7, 218804},
	{"CARDUCCI", 8, 218805},
	{"PHILLIPINE", 10, 218806},
	{"MESENTERY", 9, 218807},
	{"KAISA", 5, 218808},
	{"DYSMORPHIC", 10, 218809},
	{"TIEPOLO", 7, 218810},
	{"SEDATING", 8, 218811},
	{"SCHULEN", 7, 218812},
	{"EYEKO", 5, 218813},
	{"TRIBUNES", 8, 218814},
	{"CENTON", 6, 218815},
	{"KRAAL", 5, 218816},
	{"TURKEL", 6, 218817},
	{"NUER", 4, 218818},
	{"GENEVIEW", 8, 218819},
	{"GDBADMIN", 8, 218820},
	{"XICOR", 5, 218821},
	{"MEILEN", 6, 218822},
	{"FILMINHOS", 9, 218823},
	{"BILLIKENS", 9, 218824},
	{"TEMAER", 6, 218825},
	{"PFERDEFICK", 10, 218826},
	{"CHAKRAVARTI", 11, 218827},
	{"BEISCHLAF", 9, 218828},
	{"GMIME", 5, 218829},
	{"EVENIN", 6, 218830},
	{"WHIZZED", 7, 218831},
	{"BLUDGEONED", 10, 218832},
	{"COMPATIBILTY", 12, 218833},
	{"WONGA", 5, 218834},
	{"SOCKED", 6, 218835},
	{"MERSIN", 6, 218836},
	{"SERWIS", 6, 218837},
	{"DUGOUTS", 7, 218838},
	{"STEINMANN", 9, 218839},
	{"GEDDY", 5, 218840},
	{"BIBENDUM", 8, 218841},
	{"VERGHESE", 8, 218842},
	{"RUPE", 4, 218843},
	{"FOZE", 4, 218844},
	{"CHIMIQUE", 8, 218845},
	{"GEETING", 7, 218846},
	{"DRITTE", 6, 218847},
	{"CRUISELINE", 10, 218848},
	{"CALCINOSIS", 10, 218849},
	{"TRAADOL", 7, 218850},
	{"HEITMAN", 7, 218851},
	{"GRINDROD", 8, 218852},
	{"CDDIS", 5, 218853},
	{"WIGGS", 5, 218854},
	{"SIFF", 4, 218855},
	{"JOHORE", 6, 218856},
	{"SLOSS", 5, 218857},
	{"NANOBOT", 7, 218858},
	{"CONNERLY", 8, 218859},
	{"TALITHA", 7, 218860},
	{"PDSA", 4, 218861},
	{"CORDIFOLIA", 10, 218862},
	{"MENTIONNED", 10, 218863},
	{"LANSON", 6, 218864},
	{"WESTDALE", 8, 218865},
	{"RWJ", 3, 218866},
	{"DEFEASIBLE", 10, 218867},
	{"ZYSP", 4, 218868},
	{"ZYDA", 4, 218869},
	{"ZAAC", 4, 218870},
	{"YMHA", 4, 218871},
	{"WYNS", 4, 218872},
	{"UJON", 4, 218873},
	{"UDTE", 4, 218874},
	{"TOXP", 4, 218875},
	{"TDEJ", 4, 218876},
	{"SWBA", 4, 218877},
	{"STCB", 4, 218878},
	{"RZOM", 4, 218879},
	{"RWUS", 4, 218880},
	{"RUMQ", 4, 218881},
	{"RODJ", 4, 218882},
	{"RLYZ", 4, 218883},
	{"RIBF", 4, 218884},
	{"PTCU", 4, 218885},
	{"PTCE", 4, 218886},
	{"PJEN", 4, 218887},
	{"OXAG", 4, 218888},
	{"OMYQ", 4, 218889},
	{"OMRR", 4, 218890},
	{"NZFE", 4, 218891},
	{"NFCP", 4, 218892},
	{"MGHO", 4, 218893},
	{"LYRY", 4, 218894},
	{"LCDP", 4, 218895},
	{"KUSN", 4, 218896},
	{"KTYR", 4, 218897},
	{"KIVO", 4, 218898},
	{"JSTY", 4, 218899},
	{"IMFW", 4, 218900},
	{"IKTR", 4, 218901},
	{"ESCW", 4, 218902},
	{"EOUF", 4, 218903},
	{"ELMV", 4, 218904},
	{"DTKE", 4, 218905},
	{"CFOX", 4, 218906},
	{"BSPH", 4, 218907},
	{"BOPL", 4, 218908},
	{"AXXA", 4, 218909},
	{"ATKG", 4, 218910},
	{"GAMEQ", 5, 218911},
	{"KRANE", 5, 218912},
	{"HALCROW", 7, 218913},
	{"STELLARIS", 9, 218914},
	{"CALON", 5, 218915},
	{"RELOADER", 8, 218916},
	{"LIPSTADT", 8, 218917},
	{"KUROSHIO", 8, 218918},
	{"SEMITONE", 8, 218919},
	{"SCRITTI", 7, 218920},
	{"SANGEET", 7, 218921},
	{"MARRIS", 6, 218922},
	{"CUSE", 4, 218923},
	{"SNOWCAT", 7, 218924},
	{"HSMAI", 5, 218925},
	{"HOOFER", 6, 218926},
	{"AIRINGS", 7, 218927},
	{"HAWKSWORTH", 10, 218928},
	{"CONTACTENOS", 11, 218929},
	{"DAZUKO", 6, 218930},
	{"IMMINGHAM", 9, 218931},
	{"EZGEAR", 6, 218932},
	{"OAKMAN", 6, 218933},
	{"GWILYM", 6, 218934},
	{"GOBER", 5, 218935},
	{"COMDIG", 6, 218936},
	{"GAZZETTA", 8, 218937},
	{"SEMIGLOSS", 9, 218938},
	{"MILKANDCOOKIES", 14, 218939},
	{"LMPG", 4, 218940},
	{"ALYSSUM", 7, 218941},
	{"MCFEE", 5, 218942},
	{"LADUKE", 6, 218943},
	{"AVULSION", 8, 218944},
	{"ACTIONTRIP", 10, 218945},
	{"RADB", 4, 218946},
	{"BANYAK", 6, 218947},
	{"TIGRAY", 6, 218948},
	{"MULTITUDINOUS", 13, 218949},
	{"DORSOLATERAL", 12, 218950},
	{"JAVELINS", 8, 218951},
	{"JUNEE", 5, 218952},
	{"ROTFLMAO", 8, 218953},
	{"AUDIOCZECH", 10, 218954},
	{"LINEVILLE", 9, 218955},
	{"PHUNG", 5, 218956},
	{"KNIETE", 6, 218957},
	{"FLYC", 4, 218958},
	{"TRIPLER", 7, 218959},
	{"SNORKLING", 9, 218960},
	{"JAMBANDS", 8, 218961},
	{"ARSCHFICKER", 11, 218962},
	{"ZINIK", 5, 218963},
	{"SUPRESSION", 10, 218964},
	{"MAZIN", 5, 218965},
	{"HANEKE", 6, 218966},
	{"DRIVEABILITY", 12, 218967},
	{"CRESOTECH", 9, 218968},
	{"AUSTON", 6, 218969},
	{"TETRADRACHM", 11, 218970},
	{"MAIREAD", 7, 218971},
	{"FISHHOOK", 8, 218972},
	{"WARDMAN", 7, 218973},
	{"SKIBO", 5, 218974},
	{"DPCH", 4, 218975},
	{"DEMETRI", 7, 218976},
	{"CARREER", 7, 218977},
	{"INKPEN", 6, 218978},
	{"KONITZ", 6, 218979},
	{"TROFEO", 6, 218980},
	{"JOBBING", 7, 218981},
	{"ADVERTORIALS", 12, 218982},
	{"OKAYED", 6, 218983},
	{"ZUCKTE", 6, 218984},
	{"FORECLOSING", 11, 218985},
	{"BTREES", 6, 218986},
	{"SUBJECTIVISM", 12, 218987},
	{"PERIS", 5, 218988},
	{"GRENZEN", 7, 218989},
	{"AGRIBIOLOGIA", 12, 218990},
	{"JUB", 3, 218991},
	{"SUBCHANNEL", 10, 218992},
	{"BLASTOCYSTS", 11, 218993},
	{"BIZZELL", 7, 218994},
	{"PUDERN", 6, 218995},
	{"MAGAZI", 6, 218996},
	{"LIBOBJC", 7, 218997},
	{"OWNLOADS", 8, 218998},
	{"WFB", 3, 218999},
	{"BINER", 5, 219000},
	{"MOUSEHOLE", 9, 219001},
	{"ATWAL", 5, 219002},
	{"GECODE", 6, 219003},
	{"DROGO", 5, 219004},
	{"GODSTONE", 8, 219005},
	{"STLTODAY", 8, 219006},
	{"RECOMPRESSION", 13, 219007},
	{"GWASTRAFF", 9, 219008},
	{"GELECKT", 7, 219009},
	{"PENOLOGY", 8, 219010},
	{"SHONEY", 6, 219011},
	{"PIETSCH", 7, 219012},
	{"TAMPAX", 6, 219013},
	{"GRESSONEY", 9, 219014},
	{"BDUS", 4, 219015},
	{"SAHARANPUR", 10, 219016},
	{"RECOMMENED", 10, 219017},
	{"MCCHORD", 7, 219018},
	{"PACINI", 6, 219019},
	{"THIOPHENE", 9, 219020},
	{"DWIN", 4, 219021},
	{"ELITLOPP", 8, 219022},
	{"PANKOW", 6, 219023},
	{"HORDERN", 7, 219024},
	{"PERVY", 5, 219025},
	{"STRATION", 8, 219026},
	{"BEJTLICH", 8, 219027},
	{"BEATIFIC", 8, 219028},
	{"AKEBONO", 7, 219029},
	{"MDNH", 4, 219030},
	{"TOLERANCING", 11, 219031},
	{"FULGHUM", 7, 219032},
	{"COOCH", 5, 219033},
	{"IOANNOU", 7, 219034},
	{"BACKINGS", 8, 219035},
	{"QUARTA", 6, 219036},
	{"VIRTUOSI", 8, 219037},
	{"TRAMAOL", 7, 219038},
	{"PROGNOSTICATION", 15, 219039},
	{"SNMPADMINSTRING", 15, 219040},
	{"METROPARKS", 10, 219041},
	{"LIBRSVG", 7, 219042},
	{"PRIMIDONE", 9, 219043},
	{"FARIES", 6, 219044},
	{"YRDH", 4, 219045},
	{"YMSP", 4, 219046},
	{"YGGD", 4, 219047},
	{"XCLE", 4, 219048},
	{"WUPU", 4, 219049},
	{"URKR", 4, 219050},
	{"UMLU", 4, 219051},
	{"UKOC", 4, 219052},
	{"UGAZ", 4, 219053},
	{"TVBO", 4, 219054},
	{"TEXR", 4, 219055},
	{"SYVO", 4, 219056},
	{"SUZH", 4, 219057},
	{"STKY", 4, 219058},
	{"SQLI", 4, 219059},
	{"SPMN", 4, 219060},
	{"SDWY", 4, 219061},
	{"RYLF", 4, 219062},
	{"RUSZ", 4, 219063},
	{"RPPE", 4, 219064},
	{"RHAJ", 4, 219065},
	{"RDSZ", 4, 219066},
	{"PTOX", 4, 219067},
	{"OVPE", 4, 219068},
	{"ORIQ", 4, 219069},
	{"NOKW", 4, 219070},
	{"NMIY", 4, 219071},
	{"MPOG", 4, 219072},
	{"MEGT", 4, 219073},
	{"MBWO", 4, 219074},
	{"LYMB", 4, 219075},
	{"LMKI", 4, 219076},
	{"LBTE", 4, 219077},
	{"LADK", 4, 219078},
	{"KDAW", 4, 219079},
	{"IIJU", 4, 219080},
	{"HZPR", 4, 219081},
	{"HRUV", 4, 219082},
	{"HNLU", 4, 219083},
	{"HMRA", 4, 219084},
	{"GNIR", 4, 219085},
	{"GFUC", 4, 219086},
	{"GBCO", 4, 219087},
	{"FSDU", 4, 219088},
	{"FPUZ", 4, 219089},
	{"FKHU", 4, 219090},
	{"FJAF", 4, 219091},
	{"EMTY", 4, 219092},
	{"EMLP", 4, 219093},
	{"ECVA", 4, 219094},
	{"DZEE", 4, 219095},
	{"BQUA", 4, 219096},
	{"BOLR", 4, 219097},
	{"BKEY", 4, 219098},
	{"AYLS", 4, 219099},
	{"AVVA", 4, 219100},
	{"AMDW", 4, 219101},
	{"ALPB", 4, 219102},
	{"SELLERSVILLE", 12, 219103},
	{"KOLAKOSKI", 9, 219104},
	{"READWRITE", 9, 219105},
	{"LOWN", 4, 219106},
	{"DOTTI", 5, 219107},
	{"CLUTTON", 7, 219108},
	{"BOIFROMTROY", 11, 219109},
	{"PCES", 4, 219110},
	{"JUWELEN", 7, 219111},
	{"EQUINIX", 7, 219112},
	{"BIGNESS", 7, 219113},
	{"AFDRUKKEN", 9, 219114},
	{"LYNMOUTH", 8, 219115},
	{"UNITTEST", 8, 219116},
	{"HENGELO", 7, 219117},
	{"ZBL", 3, 219118},
	{"SESSHOUMARU", 11, 219119},
	{"PLEXES", 6, 219120},
	{"JOBDIG", 6, 219121},
	{"EAGGF", 5, 219122},
	{"DONNIEBOY", 9, 219123},
	{"LEUKOPLAKIA", 11, 219124},
	{"KOMMANDO", 8, 219125},
	{"INNERSPRING", 11, 219126},
	{"ARATHI", 6, 219127},
	{"CAESARIAN", 9, 219128},
	{"HUALALAI", 8, 219129},
	{"ATREIDES", 8, 219130},
	{"DOCDB", 5, 219131},
	{"BRMU", 4, 219132},
	{"OKLAHOMAJOBLINK", 15, 219133},
	{"MASCOTTE", 8, 219134},
	{"LIPOVARIN", 9, 219135},
	{"SCIQUEST", 8, 219136},
	{"POPGADGET", 9, 219137},
	{"CHICHA", 6, 219138},
	{"JUREK", 5, 219139},
	{"JEVON", 5, 219140},
	{"BESAMUNG", 8, 219141},
	{"BEARPAW", 7, 219142},
	{"BOLLWORM", 8, 219143},
	{"TANZER", 6, 219144},
	{"CAMELFORD", 9, 219145},
	{"BABBIT", 6, 219146},
	{"ARTIFICIALITY", 13, 219147},
	{"CRESSI", 6, 219148},
	{"UNUMPROVIDENT", 13, 219149},
	{"OCMULGEE", 8, 219150},
	{"KJARTAN", 7, 219151},
	{"ENDOSOMAL", 9, 219152},
	{"THEOBROMINE", 11, 219153},
	{"FORTUITOUSLY", 12, 219154},
	{"INCENSES", 8, 219155},
	{"ANTONACCI", 9, 219156},
	{"IKARUGA", 7, 219157},
	{"FENERBAHCE", 10, 219158},
	{"PIZZERIAS", 9, 219159},
	{"NEWSTRACK", 9, 219160},
	{"LANGLAND", 8, 219161},
	{"OKTIBBEHA", 9, 219162},
	{"MORPHOL", 7, 219163},
	{"OVEREATERS", 10, 219164},
	{"FISCO", 5, 219165},
	{"VUOLE", 5, 219166},
	{"EJECULATION", 11, 219167},
	{"PARROTFISH", 10, 219168},
	{"TOTALIZING", 10, 219169},
	{"KWANGJU", 7, 219170},
	{"JEERING", 7, 219171},
	{"CONTRACTIBLE", 12, 219172},
	{"POPEIL", 6, 219173},
	{"GLYCANS", 7, 219174},
	{"PHOTOMICROGRAPHS", 16, 219175},
	{"YAMAOKA", 7, 219176},
	{"DCK", 3, 219177},
	{"BALGOWLAH", 9, 219178},
	{"MAASDAM", 7, 219179},
	{"FPTR", 4, 219180},
	{"SUBELEMENTS", 11, 219181},
	{"GANOLFAN", 8, 219182},
	{"COBBETT", 7, 219183},
	{"INTEGUMENT", 10, 219184},
	{"SEMTA", 5, 219185},
	{"PYRETHRINS", 10, 219186},
	{"OROFACIAL", 9, 219187},
	{"MORAND", 6, 219188},
	{"FLUTSCHI", 8, 219189},
	{"ASCENSIA", 8, 219190},
	{"TRUSTMARK", 9, 219191},
	{"SCHWEINEREIEN", 13, 219192},
	{"MALTREATED", 10, 219193},
	{"CHAPERON", 8, 219194},
	{"CONSORTS", 8, 219195},
	{"EUROPIAN", 8, 219196},
	{"ANIMATRONICS", 12, 219197},
	{"RECOMB", 6, 219198},
	{"PYCA", 4, 219199},
	{"MACHESNEY", 9, 219200},
	{"TOYMAKER", 8, 219201},
	{"LYSOSOME", 8, 219202},
	{"INTERVALE", 9, 219203},
	{"TEIDE", 5, 219204},
	{"NATTERING", 9, 219205},
	{"FACETING", 8, 219206},
	{"MIKESAPARTMENT", 14, 219207},
	{"LAKEMONT", 8, 219208},
	{"EMBEZZLING", 10, 219209},
	{"RIVISTE", 7, 219210},
	{"OBVIATING", 9, 219211},
	{"GWYBOD", 6, 219212},
	{"GASARAKI", 8, 219213},
	{"TIEDEMANN", 9, 219214},
	{"NEUROPOL", 8, 219215},
	{"ECOLOGIA", 8, 219216},
	{"DEMOLAY", 7, 219217},
	{"ROBUR", 5, 219218},
	{"PLAK", 4, 219219},
	{"HORNBERGER", 10, 219220},
	{"COVETING", 8, 219221},
	{"ACDBSYMBOLTABLE", 15, 219222},
	{"BUTEYKO", 7, 219223},
	{"MPRE", 4, 219224},
	{"JIMNY", 5, 219225},
	{"BETTERBIDDING", 13, 219226},
	{"STIMMEN", 7, 219227},
	{"LAMONICA", 8, 219228},
	{"UARS", 4, 219229},
	{"PRIESTER", 8, 219230},
	{"STONYBROOK", 10, 219231},
	{"POLYFONER", 9, 219232},
	{"OCTOPUSES", 9, 219233},
	{"TONLE", 5, 219234},
	{"LIPPY", 5, 219235},
	{"OGLING", 6, 219236},
	{"LIBVISUAL", 9, 219237},
	{"HIBIKI", 6, 219238},
	{"GOADS", 5, 219239},
	{"SPARKPLUG", 9, 219240},
	{"MASUD", 5, 219241},
	{"LEVISON", 7, 219242},
	{"MCUBED", 6, 219243},
	{"CHICKIE", 7, 219244},
	{"COSIGNER", 8, 219245},
	{"WARGAMER", 8, 219246},
	{"PAGENUMBER", 10, 219247},
	{"UGRAD", 5, 219248},
	{"SESSMENT", 8, 219249},
	{"EUMETSAT", 8, 219250},
	{"GOULDEN", 7, 219251},
	{"POSTKANTOOR", 11, 219252},
	{"COLOCALIZATION", 14, 219253},
	{"MUCKLE", 6, 219254},
	{"IXODES", 6, 219255},
	{"STREPTOZOTOCIN", 14, 219256},
	{"SEBAGAI", 7, 219257},
	{"GENESCO", 7, 219258},
	{"BREAKTHRU", 9, 219259},
	{"VERGETEN", 8, 219260},
	{"RESUMO", 6, 219261},
	{"FUCHSIAS", 8, 219262},
	{"FORNI", 5, 219263},
	{"DISCOTECA", 9, 219264},
	{"SEARCHUNO", 9, 219265},
	{"PEAKSPEAK", 9, 219266},
	{"MINDA", 5, 219267},
	{"JFG", 3, 219268},
	{"HENDREN", 7, 219269},
	{"ITCZ", 4, 219270},
	{"ESCUDERO", 8, 219271},
	{"CASPI", 5, 219272},
	{"ACCOMMO", 7, 219273},
	{"TOUTLE", 6, 219274},
	{"GAMEBATTLES", 11, 219275},
	{"BURLINGHAM", 10, 219276},
	{"ATROPHIED", 9, 219277},
	{"LEGALDAY", 8, 219278},
	{"CAUSER", 6, 219279},
	{"ELYSIA", 6, 219280},
	{"ZIUS", 4, 219281},
	{"ZEJE", 4, 219282},
	{"YVOR", 4, 219283},
	{"YOBU", 4, 219284},
	{"YITV", 4, 219285},
	{"YFOI", 4, 219286},
	{"YADY", 4, 219287},
	{"XDUE", 4, 219288},
	{"WWEO", 4, 219289},
	{"WOWM", 4, 219290},
	{"WCUO", 4, 219291},
	{"VVAR", 4, 219292},
	{"VIKW", 4, 219293},
	{"UTUI", 4, 219294},
	{"UGBL", 4, 219295},
	{"UFCO", 4, 219296},
	{"TZRA", 4, 219297},
	{"TSBC", 4, 219298},
	{"RYKH", 4, 219299},
	{"PSYF", 4, 219300},
	{"OHLB", 4, 219301},
	{"OAPF", 4, 219302},
	{"NLSQ", 4, 219303},
	{"LUGP", 4, 219304},
	{"LUFI", 4, 219305},
	{"LOAW", 4, 219306},
	{"LNAL", 4, 219307},
	{"LKHU", 4, 219308},
	{"KUHI", 4, 219309},
	{"KFAB", 4, 219310},
	{"IJKE", 4, 219311},
	{"HPWA", 4, 219312},
	{"HFAD", 4, 219313},
	{"HBAZ", 4, 219314},
	{"GSGL", 4, 219315},
	{"FRMO", 4, 219316},
	{"EWYT", 4, 219317},
	{"EGNR", 4, 219318},
	{"EFKI", 4, 219319},
	{"EELQ", 4, 219320},
	{"EEGB", 4, 219321},
	{"DPDE", 4, 219322},
	{"DKUD", 4, 219323},
	{"DCOZ", 4, 219324},
	{"COSJ", 4, 219325},
	{"CBCW", 4, 219326},
	{"AAPF", 4, 219327},
	{"GOOGLESEARCH", 12, 219328},
	{"XOVER", 5, 219329},
	{"RONDELL", 7, 219330},
	{"RETELLS", 7, 219331},
	{"MISCANTHUS", 10, 219332},
	{"HORSFALL", 8, 219333},
	{"MAXDATE", 7, 219334},
	{"BIZNET", 6, 219335},
	{"TWIRLS", 6, 219336},
	{"DELETEPAGE", 10, 219337},
	{"RESPECTER", 9, 219338},
	{"NONEYET", 7, 219339},
	{"BORNES", 6, 219340},
	{"MUJAHEDEEN", 10, 219341},
	{"MALAR", 5, 219342},
	{"CATHLAMET", 9, 219343},
	{"JIKA", 4, 219344},
	{"WLB", 3, 219345},
	{"BOLIVARES", 9, 219346},
	{"ARIANS", 6, 219347},
	{"NODULATION", 10, 219348},
	{"HOLOHAN", 7, 219349},
	{"BROMATE", 7, 219350},
	{"PUDDIN", 6, 219351},
	{"POKOLBIN", 8, 219352},
	{"LEAVENING", 9, 219353},
	{"SELANNE", 7, 219354},
	{"THEIVES", 7, 219355},
	{"QUARANTINING", 12, 219356},
	{"PHOTOMONTAGE", 12, 219357},
	{"MDBTOOLS", 8, 219358},
	{"KALAMAKI", 8, 219359},
	{"SAMANTA", 7, 219360},
	{"PYROLYTIC", 9, 219361},
	{"PROPTER", 7, 219362},
	{"UYTTERHOEVEN", 12, 219363},
	{"TECHNISCHEN", 11, 219364},
	{"STRATAGUS", 9, 219365},
	{"CASHOUT", 7, 219366},
	{"BUTTARS", 7, 219367},
	{"MUSCHISAFT", 10, 219368},
	{"ADACTIO", 7, 219369},
	{"RANDHAWA", 8, 219370},
	{"ROSER", 5, 219371},
	{"DIRECTORYM", 10, 219372},
	{"BENEFICIOS", 10, 219373},
	{"WIREBOUND", 9, 219374},
	{"RATZENBERGER", 12, 219375},
	{"LACTAMS", 7, 219376},
	{"CHURLISH", 8, 219377},
	{"CANTAB", 6, 219378},
	{"MUNDFICK", 8, 219379},
	{"ZANARDI", 7, 219380},
	{"NATIONSBANK", 11, 219381},
	{"IRREMOTE", 8, 219382},
	{"AEROQUIP", 8, 219383},
	{"YIFF", 4, 219384},
	{"FANTASIAS", 9, 219385},
	{"COUDERT", 7, 219386},
	{"TREASONABLE", 11, 219387},
	{"ORDENADORES", 11, 219388},
	{"MOEL", 4, 219389},
	{"REGISTRIERT", 11, 219390},
	{"OUTPERSONALS", 12, 219391},
	{"FRIONA", 6, 219392},
	{"FSEC", 4, 219393},
	{"THERMOSPHERE", 12, 219394},
	{"TARDIES", 7, 219395},
	{"STOWING", 7, 219396},
	{"SAXIFRAGE", 9, 219397},
	{"KALEN", 5, 219398},
	{"DEJEAN", 6, 219399},
	{"MARANO", 6, 219400},
	{"BREAN", 5, 219401},
	{"TALLERES", 8, 219402},
	{"GRAPHY", 6, 219403},
	{"SEBASTIANI", 10, 219404},
	{"HEMSWORTH", 9, 219405},
	{"DESALVO", 7, 219406},
	{"COMPAY", 6, 219407},
	{"PERCU", 5, 219408},
	{"GLOSSAIRE", 9, 219409},
	{"ANOMALOUSLY", 11, 219410},
	{"STEWARTSVILLE", 13, 219411},
	{"SHOLA", 5, 219412},
	{"JOBY", 4, 219413},
	{"CRANACH", 7, 219414},
	{"RCBS", 4, 219415},
	{"KOSCHI", 6, 219416},
	{"CULTUREKITCHEN", 14, 219417},
	{"NAUTIC", 6, 219418},
	{"MULTIMIX", 8, 219419},
	{"TAUPIN", 6, 219420},
	{"REFLECTOMETRY", 13, 219421},
	{"LYSH", 4, 219422},
	{"HELLAND", 7, 219423},
	{"BINTAN", 6, 219424},
	{"MAXPOWER", 8, 219425},
	{"DYSURIA", 7, 219426},
	{"TEENYS", 6, 219427},
	{"HEINONEN", 8, 219428},
	{"DOTEASY", 7, 219429},
	{"PERLOFF", 7, 219430},
	{"MICALLEF", 8, 219431},
	{"BALOON", 6, 219432},
	{"SHORTALL", 8, 219433},
	{"WARBLES", 7, 219434},
	{"VOTZENBILDER", 12, 219435},
	{"CELESTA", 7, 219436},
	{"SCHAMLIPPE", 10, 219437},
	{"IEDEREEN", 8, 219438},
	{"MULTIPOLAR", 10, 219439},
	{"MOOVIE", 6, 219440},
	{"RXU", 3, 219441},
	{"DEFNYDDIOL", 10, 219442},
	{"ANALSPIELE", 10, 219443},
	{"FOWLERS", 7, 219444},
	{"OPENUP", 6, 219445},
	{"NAPED", 5, 219446},
	{"CERNAN", 6, 219447},
	{"AUSTRALOPITHECUS", 16, 219448},
	{"TWINKLED", 8, 219449},
	{"TRANSOCEANIC", 12, 219450},
	{"BUSTO", 5, 219451},
	{"UJJAIN", 6, 219452},
	{"TRUDEN", 6, 219453},
	{"CCME", 4, 219454},
	{"PDKSH", 5, 219455},
	{"LYSYL", 5, 219456},
	{"HAFNERSM", 8, 219457},
	{"ESALEN", 6, 219458},
	{"FURNI", 5, 219459},
	{"TANDOOR", 7, 219460},
	{"PSSCHEMA", 8, 219461},
	{"LATECOMERS", 10, 219462},
	{"THREEPIO", 8, 219463},
	{"RECONNECTS", 10, 219464},
	{"PENTRE", 6, 219465},
	{"KAMBA", 5, 219466},
	{"SBAY", 4, 219467},
	{"WORKRITE", 8, 219468},
	{"SCHAL", 5, 219469},
	{"ERAWAN", 6, 219470},
	{"TWSP", 4, 219471},
	{"CHOLESTROL", 10, 219472},
	{"ANTRUM", 6, 219473},
	{"UNCP", 4, 219474},
	{"GOWANS", 6, 219475},
	{"WGR", 3, 219476},
	{"LINGENFELTER", 12, 219477},
	{"CHIDES", 6, 219478},
	{"SHINSHU", 7, 219479},
	{"IZQUIERDA", 9, 219480},
	{"BOZOS", 5, 219481},
	{"SVENGALI", 8, 219482},
	{"ALTAIC", 6, 219483},
	{"WHOOPED", 7, 219484},
	{"REFM", 4, 219485},
	{"UNLADEN", 7, 219486},
	{"OVULES", 6, 219487},
	{"HAUGHT", 6, 219488},
	{"DOROTHEE", 8, 219489},
	{"AXESSION", 8, 219490},
	{"BRITTLENESS", 11, 219491},
	{"EXISTENZ", 8, 219492},
	{"ZLAR", 4, 219493},
	{"ZARP", 4, 219494},
	{"YHUA", 4, 219495},
	{"XSEM", 4, 219496},
	{"XIRO", 4, 219497},
	{"WLLI", 4, 219498},
	{"WKVA", 4, 219499},
	{"WIDA", 4, 219500},
	{"WDSB", 4, 219501},
	{"WBAG", 4, 219502},
	{"VMIL", 4, 219503},
	{"VCRA", 4, 219504},
	{"TJUT", 4, 219505},
	{"THPG", 4, 219506},
	{"TBMW", 4, 219507},
	{"SQLA", 4, 219508},
	{"ROJR", 4, 219509},
	{"PIGU", 4, 219510},
	{"ORBJ", 4, 219511},
	{"OCOK", 4, 219512},
	{"NXPR", 4, 219513},
	{"NJOG", 4, 219514},
	{"MYRD", 4, 219515},
	{"MURN", 4, 219516},
	{"LTWR", 4, 219517},
	{"LPIK", 4, 219518},
	{"LLVS", 4, 219519},
	{"KUWI", 4, 219520},
	{"KNYA", 4, 219521},
	{"JAFR", 4, 219522},
	{"IVCH", 4, 219523},
	{"IULA", 4, 219524},
	{"ISYF", 4, 219525},
	{"INPF", 4, 219526},
	{"INKQ", 4, 219527},
	{"IJIG", 4, 219528},
	{"HPIZ", 4, 219529},
	{"HNJU", 4, 219530},
	{"GOUA", 4, 219531},
	{"GKAP", 4, 219532},
	{"GGAA", 4, 219533},
	{"EUVI", 4, 219534},
	{"EDPF", 4, 219535},
	{"EAMX", 4, 219536},
	{"DTVO", 4, 219537},
	{"DKHU", 4, 219538},
	{"CBAB", 4, 219539},
	{"BYNC", 4, 219540},
	{"BMRE", 4, 219541},
	{"AWPH", 4, 219542},
	{"ASFC", 4, 219543},
	{"AMDC", 4, 219544},
	{"AGHL", 4, 219545},
	{"HRLI", 4, 219546},
	{"XTPOINTER", 9, 219547},
	{"RESU", 4, 219548},
	{"BAGGERS", 7, 219549},
	{"STEPMANIA", 9, 219550},
	{"PREBIOTIC", 9, 219551},
	{"COLUCCI", 7, 219552},
	{"SPOONMAN", 8, 219553},
	{"CONDENS", 7, 219554},
	{"UNDERSTEER", 10, 219555},
	{"ALFEX", 5, 219556},
	{"ACTIONAL", 8, 219557},
	{"ENOVIA", 6, 219558},
	{"ORGANOCHLORINES", 15, 219559},
	{"GRAFICOS", 8, 219560},
	{"BAUDENS", 7, 219561},
	{"SWINDLED", 8, 219562},
	{"PNODE", 5, 219563},
	{"TORELLI", 7, 219564},
	{"SCARPE", 6, 219565},
	{"DXX", 3, 219566},
	{"DBSS", 4, 219567},
	{"MURPHREE", 8, 219568},
	{"JARRATT", 7, 219569},
	{"HAUPTNAVIGATION", 15, 219570},
	{"FITZGIBBONS", 11, 219571},
	{"EMAILIT", 7, 219572},
	{"IMMUTABILITY", 12, 219573},
	{"SPERMAGEIL", 10, 219574},
	{"ORBEA", 5, 219575},
	{"NATSU", 5, 219576},
	{"JWC", 3, 219577},
	{"TOMAC", 5, 219578},
	{"SOLVALLAS", 9, 219579},
	{"ROSEANNA", 8, 219580},
	{"RODERIC", 7, 219581},
	{"MACSHANE", 8, 219582},
	{"PHPADSNEW", 9, 219583},
	{"MPPE", 4, 219584},
	{"REMAPPED", 8, 219585},
	{"VASTA", 5, 219586},
	{"RESTAU", 6, 219587},
	{"COELLO", 6, 219588},
	{"BBURAGO", 7, 219589},
	{"BARKE", 5, 219590},
	{"TOBOGGANING", 11, 219591},
	{"NUNUVAT", 7, 219592},
	{"MAZZOLA", 7, 219593},
	{"CONURES", 7, 219594},
	{"SUBSETTING", 10, 219595},
	{"JAVON", 5, 219596},
	{"QUAFFING", 8, 219597},
	{"ARRAKIS", 7, 219598},
	{"TERAN", 5, 219599},
	{"PABB", 4, 219600},
	{"STILLORGAN", 10, 219601},
	{"ENTED", 5, 219602},
	{"NURSULTAN", 9, 219603},
	{"RHEMA", 5, 219604},
	{"GUTTERIDGE", 10, 219605},
	{"NNRPD", 5, 219606},
	{"FORTEZZA", 8, 219607},
	{"DKB", 3, 219608},
	{"ABBILDUNG", 9, 219609},
	{"WORLDPERKS", 10, 219610},
	{"ROSERUTH", 8, 219611},
	{"PORTRA", 6, 219612},
	{"PGX", 3, 219613},
	{"TRUXEDO", 7, 219614},
	{"MEGABUYS", 8, 219615},
	{"LEGALES", 7, 219616},
	{"CHECKIMAGE", 10, 219617},
	{"BAYE", 4, 219618},
	{"AURGASM", 7, 219619},
	{"METANAVIGATION", 14, 219620},
	{"SYSMETRIX", 9, 219621},
	{"ASPOSE", 6, 219622},
	{"PRIMATOLOGY", 11, 219623},
	{"OPENMATH", 8, 219624},
	{"LAMARTINE", 9, 219625},
	{"RIDICULES", 9, 219626},
	{"GUNDOG", 6, 219627},
	{"DUINE", 5, 219628},
	{"DIUM", 4, 219629},
	{"GAMAGE", 6, 219630},
	{"BEALES", 6, 219631},
	{"GUJ", 3, 219632},
	{"HULDAH", 6, 219633},
	{"YSABEL", 6, 219634},
	{"MBER", 4, 219635},
	{"TRANSGRESSING", 13, 219636},
	{"MUSJC", 5, 219637},
	{"YAHSHUA", 7, 219638},
	{"HYDROELECTRICITY", 16, 219639},
	{"EDDI", 4, 219640},
	{"PRITIKIN", 8, 219641},
	{"CHUGIAK", 7, 219642},
	{"CHIKAN", 6, 219643},
	{"WARKS", 5, 219644},
	{"EINFUEHREN", 10, 219645},
	{"DRAWDOWNS", 9, 219646},
	{"JAKA", 4, 219647},
	{"EMPERADOR", 9, 219648},
	{"COMMERICIAL", 11, 219649},
	{"ALPROSTADIL", 11, 219650},
	{"RUETER", 6, 219651},
	{"DERES", 5, 219652},
	{"PRIVATI", 7, 219653},
	{"IVIL", 4, 219654},
	{"SODERSTROM", 10, 219655},
	{"FICKSAU", 7, 219656},
	{"URETERS", 7, 219657},
	{"PRIDEFUL", 8, 219658},
	{"HYPNOTIZING", 11, 219659},
	{"STABILO", 7, 219660},
	{"LARTIGUE", 8, 219661},
	{"TEECH", 5, 219662},
	{"ASURE", 5, 219663},
	{"OUTSTR", 6, 219664},
	{"AHAUS", 5, 219665},
	{"WECHSEL", 7, 219666},
	{"RONK", 4, 219667},
	{"SYMBIO", 6, 219668},
	{"PROBABIL", 8, 219669},
	{"WSPA", 4, 219670},
	{"PROGETTAZIONE", 13, 219671},
	{"GROUTED", 7, 219672},
	{"GRACCHUS", 8, 219673},
	{"STREICHELT", 10, 219674},
	{"PEGMATITE", 9, 219675},
	{"USERPASSWORD", 12, 219676},
	{"TSUMURA", 7, 219677},
	{"LEVERHULME", 10, 219678},
	{"ICCF", 4, 219679},
	{"SUBSCRIBTION", 12, 219680},
	{"NUME", 4, 219681},
	{"CYMUNEDAU", 9, 219682},
	{"BLOCKLIST", 9, 219683},
	{"EDENVALE", 8, 219684},
	{"COMMUNIT", 8, 219685},
	{"TRAXLER", 7, 219686},
	{"SPORTER", 7, 219687},
	{"CONDES", 6, 219688},
	{"TETRIX", 6, 219689},
	{"TELERADIOLOGY", 13, 219690},
	{"LEGITIMISE", 10, 219691},
	{"BROSELEY", 8, 219692},
	{"ARTEAGA", 7, 219693},
	{"ALPINEAIRE", 10, 219694},
	{"SIDESTEPPING", 12, 219695},
	{"FOREWARDS", 9, 219696},
	{"FROTHER", 7, 219697},
	{"FORAMINIFERAL", 13, 219698},
	{"WIDEBODY", 8, 219699},
	{"UNDINE", 6, 219700},
	{"KOLLECTION", 10, 219701},
	{"ANDOUILLE", 9, 219702},
	{"DECIUS", 6, 219703},
	{"ANTIOQUIA", 9, 219704},
	{"EXTREAM", 7, 219705},
	{"CRIOLLO", 7, 219706},
	{"ARSCHFOTZE", 10, 219707},
	{"SHEEPLE", 7, 219708},
	{"HOMMEL", 6, 219709},
	{"FIGGEN", 6, 219710},
	{"BVW", 3, 219711},
	{"EGYPTAIR", 8, 219712},
	{"DEOXYURIDINE", 12, 219713},
	{"HOUSHOLD", 8, 219714},
	{"GIUDIZIO", 8, 219715},
	{"TIMOROUS", 8, 219716},
	{"VITABATH", 8, 219717},
	{"LAIRG", 5, 219718},
	{"ACRIDINE", 8, 219719},
	{"RECIPROCATION", 13, 219720},
	{"KINGTURTLE", 10, 219721},
	{"ATORS", 5, 219722},
	{"MASTERBUILT", 11, 219723},
	{"FULD", 4, 219724},
	{"SOEUR", 5, 219725},
	{"MALLACH", 7, 219726},
	{"GETCHILDREN", 11, 219727},
	{"YNNJ", 4, 219728},
	{"YCDS", 4, 219729},
	{"XORW", 4, 219730},
	{"WBOG", 4, 219731},
	{"UNND", 4, 219732},
	{"TIGW", 4, 219733},
	{"TCUC", 4, 219734},
	{"STML", 4, 219735},
	{"SOVU", 4, 219736},
	{"SFTM", 4, 219737},
	{"SBBA", 4, 219738},
	{"RMCB", 4, 219739},
	{"RLSQ", 4, 219740},
	{"PGWI", 4, 219741},
	{"OYDN", 4, 219742},
	{"NBUO", 4, 219743},
	{"MUDM", 4, 219744},
	{"MFAD", 4, 219745},
	{"LNAZ", 4, 219746},
	{"LIID", 4, 219747},
	{"LDDW", 4, 219748},
	{"JISL", 4, 219749},
	{"JAHV", 4, 219750},
	{"IBMD", 4, 219751},
	{"HPOD", 4, 219752},
	{"FDEX", 4, 219753},
	{"EHPR", 4, 219754},
	{"EDFD", 4, 219755},
	{"ECOJ", 4, 219756},
	{"DOTF", 4, 219757},
	{"DOAU", 4, 219758},
	{"DNEZ", 4, 219759},
	{"DCAJ", 4, 219760},
	{"CYED", 4, 219761},
	{"CIDN", 4, 219762},
	{"CHJR", 4, 219763},
	{"BPLU", 4, 219764},
	{"BAEV", 4, 219765},
	{"ANFP", 4, 219766},
	{"AABY", 4, 219767},
	{"SACHDEV", 7, 219768},
	{"EBRI", 4, 219769},
	{"RENDE", 5, 219770},
	{"GIGWISE", 7, 219771},
	{"ENCYCLOPEDIAPROVIDED", 20, 219772},
	{"SEMINOMA", 8, 219773},
	{"FREEWATER", 9, 219774},
	{"BIRDFORUM", 9, 219775},
	{"SOUCY", 5, 219776},
	{"PURCHACE", 8, 219777},
	{"HYBRIDITY", 9, 219778},
	{"ZEEKS", 5, 219779},
	{"TRIBESMAN", 9, 219780},
	{"SCHAUBERGER", 11, 219781},
	{"FILEOUTPUTSTREAM", 16, 219782},
	{"BUNDESANSTALT", 13, 219783},
	{"OHIOUSA", 7, 219784},
	{"REDANG", 6, 219785},
	{"TWIKIREGISTRATIONPUB", 20, 219786},
	{"ROSETTEN", 8, 219787},
	{"LIVEMOTION", 10, 219788},
	{"GESPREIZTE", 10, 219789},
	{"TRICHOTILLOMANIA", 16, 219790},
	{"COCKEYED", 8, 219791},
	{"ENSNARE", 7, 219792},
	{"BLONDIES", 8, 219793},
	{"UNIONISED", 9, 219794},
	{"THANKIES", 8, 219795},
	{"GEUS", 4, 219796},
	{"MEKHI", 5, 219797},
	{"HAYSVILLE", 9, 219798},
	{"LIZABETH", 8, 219799},
	{"GROUNDWATERS", 12, 219800},
	{"AXEMAN", 6, 219801},
	{"ROSSPORT", 8, 219802},
	{"NONPAREIL", 9, 219803},
	{"KORONA", 6, 219804},
	{"FISTEN", 6, 219805},
	{"VILLAMARTIN", 11, 219806},
	{"CINDA", 5, 219807},
	{"RXP", 3, 219808},
	{"CTLR", 4, 219809},
	{"HERBELIN", 8, 219810},
	{"BUSHS", 5, 219811},
	{"BACKSTAB", 8, 219812},
	{"TRAVLE", 6, 219813},
	{"PENSES", 6, 219814},
	{"ENSINO", 6, 219815},
	{"ANALMASSAGE", 11, 219816},
	{"WTHR", 4, 219817},
	{"SAMES", 5, 219818},
	{"GIORNALI", 8, 219819},
	{"CARDIACO", 8, 219820},
	{"AUREAL", 6, 219821},
	{"MTAB", 4, 219822},
	{"GROESSTE", 8, 219823},
	{"WEEKE", 5, 219824},
	{"QUADRICS", 8, 219825},
	{"JUJUBE", 6, 219826},
	{"SILVERLINK", 10, 219827},
	{"KILTIE", 6, 219828},
	{"DEADLINK", 8, 219829},
	{"SWOOPES", 7, 219830},
	{"JEANNOT", 7, 219831},
	{"XBEL", 4, 219832},
	{"CNIB", 4, 219833},
	{"BREKKE", 6, 219834},
	{"AKAIKE", 6, 219835},
	{"LSELECTRONIC", 12, 219836},
	{"LIEBESSTELLUNGEN", 16, 219837},
	{"ALCUNE", 6, 219838},
	{"VISCOMETER", 10, 219839},
	{"SUZYS", 5, 219840},
	{"JAMROCK", 7, 219841},
	{"ICWA", 4, 219842},
	{"FTTX", 4, 219843},
	{"EASTBROOK", 9, 219844},
	{"CATOR", 5, 219845},
	{"UNSPECTACULAR", 13, 219846},
	{"BETTINI", 7, 219847},
	{"FELSENSTEIN", 11, 219848},
	{"SALUDO", 6, 219849},
	{"SEAMER", 6, 219850},
	{"CSUSB", 5, 219851},
	{"ANALITA", 7, 219852},
	{"BOVARD", 6, 219853},
	{"PLANETCRAP", 10, 219854},
	{"GEOWISSENSCHAFTEN", 17, 219855},
	{"GTYPE", 5, 219856},
	{"RECOMMEDED", 10, 219857},
	{"PSYCHADELIC", 11, 219858},
	{"INFOREDESIGN", 12, 219859},
	{"KARTY", 5, 219860},
	{"SAUGTE", 6, 219861},
	{"MYP", 3, 219862},
	{"HORNIEST", 8, 219863},
	{"SPURTED", 7, 219864},
	{"CHATTERLEY", 10, 219865},
	{"UMBRAL", 6, 219866},
	{"TWYMAN", 6, 219867},
	{"MINCHO", 6, 219868},
	{"KENSIT", 6, 219869},
	{"EJIDO", 5, 219870},
	{"CLWMR", 5, 219871},
	{"CARATTERISTICHE", 15, 219872},
	{"QUARRELLED", 10, 219873},
	{"BEGGARLY", 8, 219874},
	{"ROSSET", 6, 219875},
	{"SUTURED", 7, 219876},
	{"KIME", 4, 219877},
	{"KEPNER", 6, 219878},
	{"DOSTI", 5, 219879},
	{"AUDIOCODES", 10, 219880},
	{"VIGRA", 5, 219881},
	{"POWERPLUGS", 10, 219882},
	{"AVELLA", 6, 219883},
	{"MENTIS", 6, 219884},
	{"BRAZOSPORT", 10, 219885},
	{"SLITHERED", 9, 219886},
	{"BILDERSERIEN", 12, 219887},
	{"HORNO", 5, 219888},
	{"FARIDA", 6, 219889},
	{"SUBORDINATING", 13, 219890},
	{"SCITEX", 6, 219891},
	{"LAUTERBACH", 10, 219892},
	{"DROEGE", 6, 219893},
	{"BOYSENBERRY", 11, 219894},
	{"RECOMMITTED", 11, 219895},
	{"MASSIERTE", 9, 219896},
	{"ARCHITECTES", 11, 219897},
	{"AARNET", 6, 219898},
	{"TIPPINGPOINT", 12, 219899},
	{"LOATHES", 7, 219900},
	{"INDIANSUMMER", 12, 219901},
	{"ETAGS", 5, 219902},
	{"SULFONE", 7, 219903},
	{"FETISHISTS", 10, 219904},
	{"ARSCHLOECHER", 12, 219905},
	{"EDMOORE", 7, 219906},
	{"WILDHORSE", 9, 219907},
	{"SOFTWRE", 7, 219908},
	{"TOURAN", 6, 219909},
	{"SQLCOMMAND", 10, 219910},
	{"SKOLNIK", 7, 219911},
	{"BBTOOLS", 7, 219912},
	{"NORBA", 5, 219913},
	{"BOBUX", 5, 219914},
	{"CIUTADELLA", 10, 219915},
	{"RIBOZYMES", 9, 219916},
	{"HECKSCHER", 9, 219917},
	{"ZUKOWSKI", 8, 219918},
	{"URATE", 5, 219919},
	{"NOVAROMA", 8, 219920},
	{"PARSIX", 6, 219921},
	{"FSHD", 4, 219922},
	{"THIBAUDEAU", 10, 219923},
	{"COMORS", 6, 219924},
	{"SURFWAX", 7, 219925},
	{"NONCONFORMANCE", 14, 219926},
	{"VUOTO", 5, 219927},
	{"RMW", 3, 219928},
	{"BLOXHAM", 7, 219929},
	{"TOUPEES", 7, 219930},
	{"PHOTOSHARE", 10, 219931},
	{"FTPMASTER", 9, 219932},
	{"PBMCS", 5, 219933},
	{"NOVIB", 5, 219934},
	{"MEYERING", 8, 219935},
	{"WHEEE", 5, 219936},
	{"ZOFI", 4, 219937},
	{"ZIOL", 4, 219938},
	{"ZINV", 4, 219939},
	{"ZERV", 4, 219940},
	{"ZATL", 4, 219941},
	{"YUCL", 4, 219942},
	{"WLEW", 4, 219943},
	{"WCWW", 4, 219944},
	{"VYVO", 4, 219945},
	{"VMEN", 4, 219946},
	{"UVLI", 4, 219947},
	{"TYOY", 4, 219948},
	{"RYLP", 4, 219949},
	{"RUYT", 4, 219950},
	{"RFPL", 4, 219951},
	{"RFAW", 4, 219952},
	{"QUUS", 4, 219953},
	{"PRSE", 4, 219954},
	{"POSM", 4, 219955},
	{"PILD", 4, 219956},
	{"OZOV", 4, 219957},
	{"OXSY", 4, 219958},
	{"OPIV", 4, 219959},
	{"OBZA", 4, 219960},
	{"NSDW", 4, 219961},
	{"NKUF", 4, 219962},
	{"NAPY", 4, 219963},
	{"MYAK", 4, 219964},
	{"MTYL", 4, 219965},
	{"MMOP", 4, 219966},
	{"MLTO", 4, 219967},
	{"KEPM", 4, 219968},
	{"JEDL", 4, 219969},
	{"IZAF", 4, 219970},
	{"IBMF", 4, 219971},
	{"GUOS", 4, 219972},
	{"GNPI", 4, 219973},
	{"GIDF", 4, 219974},
	{"GDEW", 4, 219975},
	{"FTEB", 4, 219976},
	{"FIVI", 4, 219977},
	{"FFAO", 4, 219978},
	{"EYZA", 4, 219979},
	{"EGVA", 4, 219980},
	{"ECDD", 4, 219981},
	{"DUNQ", 4, 219982},
	{"DKUC", 4, 219983},
	{"DFTO", 4, 219984},
	{"DFEC", 4, 219985},
	{"CJAZ", 4, 219986},
	{"CDSF", 4, 219987},
	{"CBAD", 4, 219988},
	{"BPWA", 4, 219989},
	{"BAOB", 4, 219990},
	{"AZHU", 4, 219991},
	{"APCE", 4, 219992},
	{"ALTK", 4, 219993},
	{"AJPR", 4, 219994},
	{"MUTINEERS", 9, 219995},
	{"LEFLUNOMIDE", 11, 219996},
	{"HOCHLADEN", 9, 219997},
	{"CISP", 4, 219998},
	{"EICOSANOIDS", 11, 219999},
	{"SCHWERT", 7, 220000},
	{"RETITLED", 8, 220001},
	{"BANDEN", 6, 220002},
	{"GAMBETTA", 8, 220003},
	{"SAUVEGARDER", 11, 220004},
	{"IMBALI", 6, 220005},
	{"GRAEF", 5, 220006},
	{"RAMMTE", 6, 220007},
	{"INSELN", 6, 220008},
	{"MONTER", 6, 220009},
	{"KEINER", 6, 220010},
	{"TYCOM", 5, 220011},
	{"BIOCARE", 7, 220012},
	{"CENIC", 5, 220013},
	{"ROSENWALD", 9, 220014},
	{"KUSA", 4, 220015},
	{"SURCO", 5, 220016},
	{"NIPIGON", 7, 220017},
	{"SUBSIDISATION", 13, 220018},
	{"OVERBOOKING", 11, 220019},
	{"FASCINATIONS", 12, 220020},
	{"BILLYBOB", 8, 220021},
	{"SUUM", 4, 220022},
	{"PHANTASIA", 9, 220023},
	{"LIPE", 4, 220024},
	{"EPILOBIUM", 9, 220025},
	{"CAULEY", 6, 220026},
	{"PETFINDER", 9, 220027},
	{"JENNESS", 7, 220028},
	{"BEALLSVILLE", 11, 220029},
	{"UNHESITATINGLY", 14, 220030},
	{"VIVERE", 6, 220031},
	{"KOCHARIAN", 9, 220032},
	{"INFESTING", 9, 220033},
	{"BINZ", 4, 220034},
	{"PRIEUR", 6, 220035},
	{"PICKTHALL", 9, 220036},
	{"TRADESPERSON", 12, 220037},
	{"MALLA", 5, 220038},
	{"CCSC", 4, 220039},
	{"BRANDL", 6, 220040},
	{"FINDON", 6, 220041},
	{"SERVLETCONTEXT", 14, 220042},
	{"BENEFIELD", 9, 220043},
	{"ZENGER", 6, 220044},
	{"SCADS", 5, 220045},
	{"LOOKBACK", 8, 220046},
	{"UNINTERRUPTABLE", 15, 220047},
	{"BRINSLEY", 8, 220048},
	{"RUFINO", 6, 220049},
	{"QUINNEY", 7, 220050},
	{"LABI", 4, 220051},
	{"HANDSHOWER", 10, 220052},
	{"ACERPOWER", 9, 220053},
	{"TILFORD", 7, 220054},
	{"TANGIERS", 8, 220055},
	{"OLEATE", 6, 220056},
	{"SHRIGLEY", 8, 220057},
	{"PICACHO", 7, 220058},
	{"BJERKE", 6, 220059},
	{"AHOCHAUDE", 9, 220060},
	{"TRAVELBLOGS", 11, 220061},
	{"KANEI", 5, 220062},
	{"ADVISEES", 8, 220063},
	{"UNCONFORMITY", 12, 220064},
	{"SPREIZTE", 8, 220065},
	{"LAMMA", 5, 220066},
	{"TREACHEROUSLY", 13, 220067},
	{"PISSTE", 6, 220068},
	{"MISSIONARSSTELLUNG", 18, 220069},
	{"TTFONTS", 7, 220070},
	{"ROYTON", 6, 220071},
	{"BRALEY", 6, 220072},
	{"THERMALON", 9, 220073},
	{"INVIT", 5, 220074},
	{"MEGNUT", 6, 220075},
	{"GUDMUNDSSON", 11, 220076},
	{"ALFIERI", 7, 220077},
	{"WIXVORLAGE", 10, 220078},
	{"SYNTACE", 7, 220079},
	{"RATHE", 5, 220080},
	{"KUPFFER", 7, 220081},
	{"JESPERSEN", 9, 220082},
	{"COLLUDING", 9, 220083},
	{"TRUNGPA", 7, 220084},
	{"PILATIES", 8, 220085},
	{"IFOC", 4, 220086},
	{"DLW", 3, 220087},
	{"AIGUILLE", 8, 220088},
	{"PROTEL", 6, 220089},
	{"CLAVINOVA", 9, 220090},
	{"DAVISVILLE", 10, 220091},
	{"AFCS", 4, 220092},
	{"JUAB", 4, 220093},
	{"FRATTINI", 8, 220094},
	{"DIASTOLE", 8, 220095},
	{"SURBL", 5, 220096},
	{"RVU", 3, 220097},
	{"MILBERG", 7, 220098},
	{"MANDIBLES", 9, 220099},
	{"HAUPTVERZEICHNISSE", 18, 220100},
	{"VEGSCIENCE", 10, 220101},
	{"NARAKU", 6, 220102},
	{"LOMU", 4, 220103},
	{"RIDICULOUSNESS", 14, 220104},
	{"NCRP", 4, 220105},
	{"CEFIC", 5, 220106},
	{"TRESCO", 6, 220107},
	{"VOMITS", 6, 220108},
	{"REALSERVER", 10, 220109},
	{"CUERPOS", 7, 220110},
	{"STAGEPASS", 9, 220111},
	{"RABS", 4, 220112},
	{"KLDP", 4, 220113},
	{"MATSUNO", 7, 220114},
	{"LUDLAM", 6, 220115},
	{"FORRESTON", 9, 220116},
	{"FAAC", 4, 220117},
	{"KUSANAGI", 8, 220118},
	{"HERRADURA", 9, 220119},
	{"SHURTLEFF", 9, 220120},
	{"ASSLICK", 7, 220121},
	{"PIPERIDINE", 10, 220122},
	{"KEGLEY", 6, 220123},
	{"GUBBINS", 7, 220124},
	{"CKR", 3, 220125},
	{"INTERTEK", 8, 220126},
	{"LEARNINGCHANNEL", 15, 220127},
	{"CHANGEOVERS", 11, 220128},
	{"AMMERMAN", 8, 220129},
	{"PRUS", 4, 220130},
	{"OSLEY", 5, 220131},
	{"JAHRESZEITEN", 12, 220132},
	{"BESTLEISTUNG", 12, 220133},
	{"ACELA", 5, 220134},
	{"BLATCHFORD", 10, 220135},
	{"JANKLOW", 7, 220136},
	{"HUDS", 4, 220137},
	{"MIKED", 5, 220138},
	{"LLAMAR", 6, 220139},
	{"BICARBONATES", 12, 220140},
	{"AYUDAR", 6, 220141},
	{"NOCONV", 6, 220142},
	{"NAUM", 4, 220143},
	{"KLAMMER", 7, 220144},
	{"MAKEMUSIC", 9, 220145},
	{"KIRGHIZIA", 9, 220146},
	{"ALBERTINI", 9, 220147},
	{"VARIOGRAM", 9, 220148},
	{"KYRO", 4, 220149},
	{"KPNO", 4, 220150},
	{"DVIPDFM", 7, 220151},
	{"XANTIA", 6, 220152},
	{"SKITTLE", 7, 220153},
	{"PIDTURES", 8, 220154},
	{"WHANGAMATA", 10, 220155},
	{"VOTABLE", 7, 220156},
	{"MACPAC", 6, 220157},
	{"KANNON", 6, 220158},
	{"ARIEH", 5, 220159},
	{"PSTWO", 5, 220160},
	{"DROYLSDEN", 9, 220161},
	{"XOOM", 4, 220162},
	{"SINEQUAN", 8, 220163},
	{"DRIVETRAINS", 11, 220164},
	{"OVATA", 5, 220165},
	{"AKIHIRO", 7, 220166},
	{"CONFIDENCIALIDAD", 16, 220167},
	{"TECHINCAL", 9, 220168},
	{"ONLIINE", 7, 220169},
	{"NORDEMAN", 8, 220170},
	{"ALLTHOUGH", 9, 220171},
	{"YMRF", 4, 220172},
	{"WWCR", 4, 220173},
	{"WSHR", 4, 220174},
	{"WOGG", 4, 220175},
	{"VYNE", 4, 220176},
	{"VEKY", 4, 220177},
	{"ULFM", 4, 220178},
	{"UCSH", 4, 220179},
	{"TVIP", 4, 220180},
	{"TAWD", 4, 220181},
	{"SFUZ", 4, 220182},
	{"SERQ", 4, 220183},
	{"RPWO", 4, 220184},
	{"RMUE", 4, 220185},
	{"RMIY", 4, 220186},
	{"RKZA", 4, 220187},
	{"PRPR", 4, 220188},
	{"PECW", 4, 220189},
	{"NJWH", 4, 220190},
	{"MTIB", 4, 220191},
	{"MSHY", 4, 220192},
	{"MPMD", 4, 220193},
	{"MMPE", 4, 220194},
	{"MCAG", 4, 220195},
	{"LJAL", 4, 220196},
	{"KZAN", 4, 220197},
	{"KYAH", 4, 220198},
	{"KMSE", 4, 220199},
	{"IMIU", 4, 220200},
	{"HULO", 4, 220201},
	{"GMRI", 4, 220202},
	{"GCUE", 4, 220203},
	{"FWEO", 4, 220204},
	{"FSGE", 4, 220205},
	{"FKAK", 4, 220206},
	{"DIFJ", 4, 220207},
	{"DAFY", 4, 220208},
	{"AVPR", 4, 220209},
	{"RHAGLENNI", 9, 220210},
	{"LATICS", 6, 220211},
	{"DEPRESSIONE", 11, 220212},
	{"AFORETHOUGHT", 12, 220213},
	{"TRAFFICK", 8, 220214},
	{"GANIS", 5, 220215},
	{"NONPARTICIPATING", 16, 220216},
	{"LOLLYPOP", 8, 220217},
	{"POPEYES", 7, 220218},
	{"VAINIO", 6, 220219},
	{"OPTIGOLD", 8, 220220},
	{"DRAGOS", 6, 220221},
	{"CADWALLADER", 11, 220222},
	{"LICONV", 6, 220223},
	{"FRAMATOME", 9, 220224},
	{"CRUCIANI", 8, 220225},
	{"KEOTA", 5, 220226},
	{"CEREBRI", 7, 220227},
	{"SILLIER", 7, 220228},
	{"SUBMARINERS", 11, 220229},
	{"REPAS", 5, 220230},
	{"COMANY", 6, 220231},
	{"BURRUM", 6, 220232},
	{"REEVALUATING", 12, 220233},
	{"PREPAREIMAGE", 12, 220234},
	{"LAMBLIA", 7, 220235},
	{"FYRA", 4, 220236},
	{"HOMEOTIC", 8, 220237},
	{"STARLINER", 9, 220238},
	{"ILMENAU", 7, 220239},
	{"GRATH", 5, 220240},
	{"HISAR", 5, 220241},
	{"DISENGAGING", 11, 220242},
	{"VERTICILLATA", 12, 220243},
	{"MGG", 3, 220244},
	{"HELIN", 5, 220245},
	{"CHUZZLE", 7, 220246},
	{"MWINDOW", 7, 220247},
	{"MBFILE", 6, 220248},
	{"PAYMATE", 7, 220249},
	{"JIBES", 5, 220250},
	{"SCHWENK", 7, 220251},
	{"FTGL", 4, 220252},
	{"ARBANASI", 8, 220253},
	{"UWEC", 4, 220254},
	{"LOAND", 5, 220255},
	{"GRAFLEX", 7, 220256},
	{"ALPHABETICALLYBY", 16, 220257},
	{"STONEMASON", 10, 220258},
	{"SMECTIC", 7, 220259},
	{"YTTERBIUM", 9, 220260},
	{"WOLFY", 5, 220261},
	{"WTTW", 4, 220262},
	{"SUPERTEENS", 10, 220263},
	{"FERD", 4, 220264},
	{"AYERST", 6, 220265},
	{"AKONA", 5, 220266},
	{"PERTHYNAS", 9, 220267},
	{"CONFLATE", 8, 220268},
	{"CELLCO", 6, 220269},
	{"VERWALTUNG", 10, 220270},
	{"HOLSCHUH", 8, 220271},
	{"GASOHOL", 7, 220272},
	{"YURTS", 5, 220273},
	{"NCARD", 5, 220274},
	{"KORAH", 5, 220275},
	{"HOTCAM", 6, 220276},
	{"DMSI", 4, 220277},
	{"TRAININ", 7, 220278},
	{"SMIDT", 5, 220279},
	{"SANDAKAN", 8, 220280},
	{"RANIL", 5, 220281},
	{"HENTSCHEL", 9, 220282},
	{"ELLINGER", 8, 220283},
	{"BOGARDE", 7, 220284},
	{"METAPROGRAMMING", 15, 220285},
	{"SAMPE", 5, 220286},
	{"HAVEBEEN", 8, 220287},
	{"CYTOLYTIC", 9, 220288},
	{"PRODUSE", 7, 220289},
	{"NETVANTA", 8, 220290},
	{"RPOS", 4, 220291},
	{"RAIR", 4, 220292},
	{"STASSEN", 7, 220293},
	{"COKIE", 5, 220294},
	{"BLEM", 4, 220295},
	{"LEITL", 5, 220296},
	{"XMLPARSER", 9, 220297},
	{"VEGSINGLES", 10, 220298},
	{"MULTICLASS", 10, 220299},
	{"XANTHUS", 7, 220300},
	{"SEMELE", 6, 220301},
	{"WATAN", 5, 220302},
	{"UNOFFICAL", 9, 220303},
	{"SHOSHONI", 8, 220304},
	{"DEOXYGUANOSINE", 14, 220305},
	{"CHANTERELLE", 11, 220306},
	{"RINTONES", 8, 220307},
	{"KIELCE", 6, 220308},
	{"GUCHARMAP", 9, 220309},
	{"TYLOON", 6, 220310},
	{"KALER", 5, 220311},
	{"PENCAM", 6, 220312},
	{"MACBOOKPRO", 10, 220313},
	{"APPELL", 6, 220314},
	{"AMYLASES", 8, 220315},
	{"DISCREDITS", 10, 220316},
	{"CPLC", 4, 220317},
	{"ALBIE", 5, 220318},
	{"YUB", 3, 220319},
	{"KHADIJA", 7, 220320},
	{"PROPRES", 7, 220321},
	{"DESKSIDE", 8, 220322},
	{"VELBA", 5, 220323},
	{"LETTERWINNERS", 13, 220324},
	{"HARDHEX", 7, 220325},
	{"FAMILYFUN", 9, 220326},
	{"DISASSOCIATED", 13, 220327},
	{"SHERM", 5, 220328},
	{"CAPALABA", 8, 220329},
	{"BACTERIURIA", 11, 220330},
	{"SEMISONIC", 9, 220331},
	{"PPRN", 4, 220332},
	{"MOPING", 6, 220333},
	{"POPTONES", 8, 220334},
	{"DAQING", 6, 220335},
	{"CULHANE", 7, 220336},
	{"WESTLY", 6, 220337},
	{"TEKENS", 6, 220338},
	{"MPEGLIB", 7, 220339},
	{"DAGWOOD", 7, 220340},
	{"SOURCEID", 8, 220341},
	{"PKGDIR", 6, 220342},
	{"PARTNUMBER", 10, 220343},
	{"PRICESCOPE", 10, 220344},
	{"AWAL", 4, 220345},
	{"PAPERWIGHT", 10, 220346},
	{"ASSINIBOIA", 10, 220347},
	{"TRUEBLOOD", 9, 220348},
	{"BELLARINE", 9, 220349},
	{"TITRATE", 7, 220350},
	{"TETER", 5, 220351},
	{"SNUGG", 5, 220352},
	{"BALDYGA", 7, 220353},
	{"FRIEZA", 6, 220354},
	{"SURMA", 5, 220355},
	{"SNETTERTON", 10, 220356},
	{"RACKMOUNTABLE", 13, 220357},
	{"INTIMSCHMUCK", 12, 220358},
	{"UNSCREWED", 9, 220359},
	{"KREISEN", 7, 220360},
	{"IWAKI", 5, 220361},
	{"BEARBEITET", 10, 220362},
	{"YTSK", 4, 220363},
	{"YAOW", 4, 220364},
	{"XWIC", 4, 220365},
	{"WWSH", 4, 220366},
	{"VVYC", 4, 220367},
	{"VKAT", 4, 220368},
	{"UINK", 4, 220369},
	{"UARU", 4, 220370},
	{"UAPL", 4, 220371},
	{"TUKO", 4, 220372},
	{"SZAW", 4, 220373},
	{"SYOK", 4, 220374},
	{"SYGU", 4, 220375},
	{"SKCR", 4, 220376},
	{"RSIU", 4, 220377},
	{"RRPA", 4, 220378},
	{"PNOL", 4, 220379},
	{"PIEK", 4, 220380},
	{"OYSQ", 4, 220381},
	{"OQUY", 4, 220382},
	{"NRIZ", 4, 220383},
	{"NJCO", 4, 220384},
	{"NGPB", 4, 220385},
	{"MZAM", 4, 220386},
	{"MLBO", 4, 220387},
	{"MKLE", 4, 220388},
	{"MHOG", 4, 220389},
	{"LVDC", 4, 220390},
	{"LNAK", 4, 220391},
	{"KROF", 4, 220392},
	{"JUNH", 4, 220393},
	{"JIAR", 4, 220394},
	{"IMUB", 4, 220395},
	{"HUWE", 4, 220396},
	{"HPCH", 4, 220397},
	{"HLLA", 4, 220398},
	{"HGPS", 4, 220399},
	{"GLLC", 4, 220400},
	{"FYGO", 4, 220401},
	{"FYDU", 4, 220402},
	{"FMTR", 4, 220403},
	{"FLAJ", 4, 220404},
	{"FAXF", 4, 220405},
	{"EQWE", 4, 220406},
	{"EPRD", 4, 220407},
	{"ENKW", 4, 220408},
	{"ELZQ", 4, 220409},
	{"DYAY", 4, 220410},
	{"DDYV", 4, 220411},
	{"CZEW", 4, 220412},
	{"CYLL", 4, 220413},
	{"ALCB", 4, 220414},
	{"SYNCHRONISM", 11, 220415},
	{"CONCRETENESS", 12, 220416},
	{"ATLANTIK", 8, 220417},
	{"GILYDD", 6, 220418},
	{"ZANDBERGEN", 10, 220419},
	{"GISPERT", 7, 220420},
	{"SETOBJECT", 9, 220421},
	{"MONTAR", 6, 220422},
	{"HUMIDIFIED", 10, 220423},
	{"OBVIATED", 8, 220424},
	{"CRETINS", 7, 220425},
	{"AXFORD", 6, 220426},
	{"UBLOG", 5, 220427},
	{"SHIZUKA", 7, 220428},
	{"ROUE", 4, 220429},
	{"KIWIPAGES", 9, 220430},
	{"ACIM", 4, 220431},
	{"SKAVEN", 6, 220432},
	{"ZIKR", 4, 220433},
	{"VAMPIRESS", 9, 220434},
	{"KINGPINS", 8, 220435},
	{"THIRTYTWO", 9, 220436},
	{"HASSLING", 8, 220437},
	{"MIMIO", 5, 220438},
	{"KLIPPEL", 7, 220439},
	{"ANDARE", 6, 220440},
	{"ENGDAHL", 7, 220441},
	{"SHUB", 4, 220442},
	{"SWITCHEROO", 10, 220443},
	{"CARNAP", 6, 220444},
	{"WOOKEY", 6, 220445},
	{"JUNIPERS", 8, 220446},
	{"OLIGOPOLISTIC", 13, 220447},
	{"MCANALLY", 8, 220448},
	{"DHOL", 4, 220449},
	{"CONTEXTUALIZATION", 17, 220450},
	{"ANNALISE", 8, 220451},
	{"TECHNOLOGIEN", 12, 220452},
	{"PRIMOSYS", 8, 220453},
	{"MONEYCENTRAL", 12, 220454},
	{"CURI", 4, 220455},
	{"ARCAND", 6, 220456},
	{"SHOWBOX", 7, 220457},
	{"HOENIG", 6, 220458},
	{"QUATTROPORTE", 12, 220459},
	{"KRACHT", 6, 220460},
	{"EASYDNS", 7, 220461},
	{"SALIMA", 6, 220462},
	{"MAGNES", 6, 220463},
	{"PAGINATE", 8, 220464},
	{"MERVEILLES", 10, 220465},
	{"FUERZAS", 7, 220466},
	{"DEVEN", 5, 220467},
	{"KLC", 3, 220468},
	{"DESOUZA", 7, 220469},
	{"COOKI", 5, 220470},
	{"OFFORD", 6, 220471},
	{"IMIC", 4, 220472},
	{"ESGR", 4, 220473},
	{"URBANSCOOTERS", 13, 220474},
	{"NEUSTIFT", 8, 220475},
	{"NETLEY", 6, 220476},
	{"MUIS", 4, 220477},
	{"CRISTALLO", 9, 220478},
	{"NIPDAU", 6, 220479},
	{"EXKL", 4, 220480},
	{"CHARITYCHANNEL", 14, 220481},
	{"MUNDINE", 7, 220482},
	{"TOLIVER", 7, 220483},
	{"STARTLOGIC", 10, 220484},
	{"LUNETTES", 8, 220485},
	{"TECHICAL", 8, 220486},
	{"ACTMON", 6, 220487},
	{"PIRANDELLO", 10, 220488},
	{"APOTEX", 6, 220489},
	{"SENTATIVES", 10, 220490},
	{"GIOCATTOLI", 10, 220491},
	{"MENUES", 6, 220492},
	{"WGIG", 4, 220493},
	{"SLATY", 5, 220494},
	{"SECURITYEXCEPTION", 17, 220495},
	{"SCHACTER", 8, 220496},
	{"NDEF", 4, 220497},
	{"EXISTENTIALLY", 13, 220498},
	{"LIGHTSOURCE", 11, 220499},
	{"JATROPHA", 8, 220500},
	{"MAXMARA", 7, 220501},
	{"MOBILEMESH", 10, 220502},
	{"BLARE", 5, 220503},
	{"NORODOM", 7, 220504},
	{"CORRIN", 6, 220505},
	{"CARBAMATES", 10, 220506},
	{"BEAUTI", 6, 220507},
	{"POOKA", 5, 220508},
	{"IXCS", 4, 220509},
	{"PHALEN", 6, 220510},
	{"KOSTYA", 6, 220511},
	{"SENSIBILISATION", 15, 220512},
	{"CELWAVE", 7, 220513},
	{"RADEMAKERS", 10, 220514},
	{"NETFRONT", 8, 220515},
	{"FUMIGANTS", 9, 220516},
	{"CORBIER", 7, 220517},
	{"BESSA", 5, 220518},
	{"WIDES", 5, 220519},
	{"MICU", 4, 220520},
	{"ATAZANAVIR", 10, 220521},
	{"EVIEWS", 6, 220522},
	{"CELEBRITE", 9, 220523},
	{"BORSTEN", 7, 220524},
	{"ADDENDUMS", 9, 220525},
	{"SZENT", 5, 220526},
	{"STEENS", 6, 220527},
	{"PRIGOGINE", 9, 220528},
	{"BLINX", 5, 220529},
	{"HISTORIQUES", 11, 220530},
	{"CURLIES", 7, 220531},
	{"ALLAMANDA", 9, 220532},
	{"THAKKAR", 7, 220533},
	{"TECNO", 5, 220534},
	{"NUMROWS", 7, 220535},
	{"SECONDI", 7, 220536},
	{"SCORP", 5, 220537},
	{"IPTRAF", 6, 220538},
	{"SOFAR", 5, 220539},
	{"OMNIVORES", 9, 220540},
	{"MORETHAN", 8, 220541},
	{"PITON", 5, 220542},
	{"MCCUBBIN", 8, 220543},
	{"EBICLUSTER", 10, 220544},
	{"COMEST", 6, 220545},
	{"BRITISHNESS", 11, 220546},
	{"ENDEMICS", 8, 220547},
	{"SEQUENTLY", 9, 220548},
	{"OMURA", 5, 220549},
	{"INTEGRAT", 8, 220550},
	{"ARVE", 4, 220551},
	{"ACADAMY", 7, 220552},
	{"SULLENLY", 8, 220553},
	{"ROZIER", 6, 220554},
	{"PRESCRIP", 8, 220555},
	{"MEDCYCLOPAEDIA", 14, 220556},
	{"MAQUINA", 7, 220557},
	{"RACHLIN", 7, 220558},
	{"MULLEY", 6, 220559},
	{"LOPRESTI", 8, 220560},
	{"INTELLEGENCE", 12, 220561},
	{"AMSL", 4, 220562},
	{"HESCHEL", 7, 220563},
	{"VERHALEN", 8, 220564},
	{"QUADRATS", 8, 220565},
	{"INFLAMMATIONS", 13, 220566},
	{"NICOLAU", 7, 220567},
	{"LANDWARE", 8, 220568},
	{"SHAMBALA", 8, 220569},
	{"PRAKTIKA", 8, 220570},
	{"MATHTYPE", 8, 220571},
	{"SUPERFI", 7, 220572},
	{"KURZE", 5, 220573},
	{"MCPL", 4, 220574},
	{"LAVERDA", 7, 220575},
	{"CAMSHOWS", 8, 220576},
	{"ASCHAFFENBURG", 13, 220577},
	{"BERTOLINI", 9, 220578},
	{"PLYCOUNT", 8, 220579},
	{"EVILLY", 6, 220580},
	{"SIAULIAI", 8, 220581},
	{"IVENS", 5, 220582},
	{"FUJICOLOR", 9, 220583},
	{"FASCO", 5, 220584},
	{"VARIAX", 6, 220585},
	{"REDMEN", 6, 220586},
	{"PNTR", 4, 220587},
	{"GMAPS", 5, 220588},
	{"NOICE", 5, 220589},
	{"PRENT", 5, 220590},
	{"BREASTBONE", 10, 220591},
	{"TEXTBF", 6, 220592},
	{"RICHELLE", 8, 220593},
	{"NATELY", 6, 220594},
	{"YPUF", 4, 220595},
	{"WURT", 4, 220596},
	{"WHAU", 4, 220597},
	{"WBOM", 4, 220598},
	{"UJAW", 4, 220599},
	{"TYEY", 4, 220600},
	{"TUTD", 4, 220601},
	{"SPFA", 4, 220602},
	{"RKPM", 4, 220603},
	{"PMHI", 4, 220604},
	{"OXSB", 4, 220605},
	{"ONVC", 4, 220606},
	{"OJIK", 4, 220607},
	{"ODRH", 4, 220608},
	{"MVEG", 4, 220609},
	{"MSUW", 4, 220610},
	{"MPYB", 4, 220611},
	{"MAEP", 4, 220612},
	{"LOZO", 4, 220613},
	{"LNEM", 4, 220614},
	{"LCDI", 4, 220615},
	{"KLIQ", 4, 220616},
	{"JUAT", 4, 220617},
	{"HAQW", 4, 220618},
	{"FYLI", 4, 220619},
	{"DAWD", 4, 220620},
	{"CDCT", 4, 220621},
	{"CDCR", 4, 220622},
	{"CCUI", 4, 220623},
	{"BEPP", 4, 220624},
	{"AOWU", 4, 220625},
	{"ACCB", 4, 220626},
	{"ACAJ", 4, 220627},
	{"IMLOGIC", 7, 220628},
	{"SOULIER", 7, 220629},
	{"IKEY", 4, 220630},
	{"GONADOTROPHIN", 13, 220631},
	{"MONDOVI", 7, 220632},
	{"BULLDOZE", 8, 220633},
	{"SIMLIAR", 7, 220634},
	{"ROSANA", 6, 220635},
	{"PEATY", 5, 220636},
	{"MAZUMDAR", 8, 220637},
	{"LIMAR", 5, 220638},
	{"BUCCLEUCH", 9, 220639},
	{"LAMBERTO", 8, 220640},
	{"DIAGRAMMER", 10, 220641},
	{"BADS", 4, 220642},
	{"WEATHERMEN", 10, 220643},
	{"STEWARDESSES", 12, 220644},
	{"GATIFLOXACIN", 12, 220645},
	{"BUSNESS", 7, 220646},
	{"VERIZONWIRELESS", 15, 220647},
	{"FPDS", 4, 220648},
	{"CREWDSON", 8, 220649},
	{"ENTHOUGHT", 9, 220650},
	{"ROSCH", 5, 220651},
	{"BUBB", 4, 220652},
	{"KLOSTERS", 8, 220653},
	{"YAWS", 4, 220654},
	{"HYBRIDA", 7, 220655},
	{"BIOORG", 6, 220656},
	{"RESERVERD", 9, 220657},
	{"LATVIJAS", 8, 220658},
	{"EXTAGEN", 7, 220659},
	{"WICKETT", 7, 220660},
	{"OPPRESSIONS", 11, 220661},
	{"ATTOR", 5, 220662},
	{"SWEETLAND", 9, 220663},
	{"KILBOURN", 8, 220664},
	{"SCIENTIF", 8, 220665},
	{"HARKENS", 7, 220666},
	{"POCASSET", 8, 220667},
	{"KASSAM", 6, 220668},
	{"HYPNOSE", 7, 220669},
	{"SHCOOL", 6, 220670},
	{"SOFTWIN", 7, 220671},
	{"PHYTOPATHOLOGICAL", 17, 220672},
	{"KCBT", 4, 220673},
	{"EOGHAN", 6, 220674},
	{"ORLIN", 5, 220675},
	{"CHLOROETHYL", 11, 220676},
	{"STEADIER", 8, 220677},
	{"NUTHATCHES", 10, 220678},
	{"HIDDE", 5, 220679},
	{"GEORGEOUS", 9, 220680},
	{"SHEEPSKINS", 10, 220681},
	{"CATEGORYID", 10, 220682},
	{"QOKS", 4, 220683},
	{"CLAMPETT", 8, 220684},
	{"WABS", 4, 220685},
	{"MIEDO", 5, 220686},
	{"KOPPELMAN", 9, 220687},
	{"TREBLED", 7, 220688},
	{"CROWOOD", 7, 220689},
	{"ANTIPASTI", 9, 220690},
	{"AIRLINSE", 8, 220691},
	{"RSBAC", 5, 220692},
	{"REBUTS", 6, 220693},
	{"WWWH", 4, 220694},
	{"SPLANCHNIC", 10, 220695},
	{"POPULISTS", 9, 220696},
	{"DEMURRED", 8, 220697},
	{"CONCILIATE", 10, 220698},
	{"CLAUSAL", 7, 220699},
	{"HYPOTHERMIC", 11, 220700},
	{"ECOSYS", 6, 220701},
	{"CRICKHOWELL", 11, 220702},
	{"RESISTENT", 9, 220703},
	{"CANYONVILLE", 11, 220704},
	{"DWAF", 4, 220705},
	{"VCAM", 4, 220706},
	{"CARTUCHOS", 9, 220707},
	{"SUBTROPICS", 10, 220708},
	{"SUPERLEAGUE", 11, 220709},
	{"PORTERO", 7, 220710},
	{"ABCDEFGH", 8, 220711},
	{"CLANCEY", 7, 220712},
	{"MOSAICISM", 9, 220713},
	{"MICROCEPHALY", 12, 220714},
	{"BLUFORD", 7, 220715},
	{"CONTENANT", 9, 220716},
	{"ATLANTIA", 8, 220717},
	{"REPATRIATING", 12, 220718},
	{"AMBAC", 5, 220719},
	{"VOGELSANG", 9, 220720},
	{"ICRM", 4, 220721},
	{"STUDD", 5, 220722},
	{"PIYUSH", 6, 220723},
	{"TRAORE", 6, 220724},
	{"OFFTAKE", 7, 220725},
	{"MOLO", 4, 220726},
	{"DITC", 4, 220727},
	{"DEREGISTERED", 12, 220728},
	{"RISPOSTA", 8, 220729},
	{"RADBOUD", 7, 220730},
	{"LINHAS", 6, 220731},
	{"CRYOSPHERE", 10, 220732},
	{"TYPHA", 5, 220733},
	{"EXPERIMENTALISTS", 16, 220734},
	{"NATIONAAL", 9, 220735},
	{"THORNBERRYS", 11, 220736},
	{"RANSOMED", 8, 220737},
	{"MOAPA", 5, 220738},
	{"MAGNIFICANT", 11, 220739},
	{"BANDSAWS", 8, 220740},
	{"SOBERS", 6, 220741},
	{"CELI", 4, 220742},
	{"ARGENTIERE", 10, 220743},
	{"ANTONOVICH", 10, 220744},
	{"ANHYDRITE", 9, 220745},
	{"ACCOUN", 6, 220746},
	{"JGRAPH", 6, 220747},
	{"CWRICWLWM", 9, 220748},
	{"RATCHETED", 9, 220749},
	{"INVESTINGREAL", 13, 220750},
	{"TASTATUR", 8, 220751},
	{"COFC", 4, 220752},
	{"TINDAL", 6, 220753},
	{"HILAND", 6, 220754},
	{"FUTUREWORKS", 11, 220755},
	{"BALTA", 5, 220756},
	{"PATTERDALE", 10, 220757},
	{"KURITA", 6, 220758},
	{"INFORMADO", 9, 220759},
	{"MIKIMOTO", 8, 220760},
	{"PETRONIUS", 9, 220761},
	{"PERFUMANIA", 10, 220762},
	{"HCCS", 4, 220763},
	{"ANTEPARTUM", 10, 220764},
	{"NULLIFIES", 9, 220765},
	{"SNAPP", 5, 220766},
	{"COLLEGAMENTO", 12, 220767},
	{"WOLFERT", 7, 220768},
	{"SCIRI", 5, 220769},
	{"MONOD", 5, 220770},
	{"UMART", 5, 220771},
	{"MUSOS", 5, 220772},
	{"SANDTIMER", 9, 220773},
	{"JUGENDHERBERGEN", 15, 220774},
	{"SCRUNCHED", 9, 220775},
	{"DICTED", 6, 220776},
	{"INETERNATIONAL", 14, 220777},
	{"DONNANT", 7, 220778},
	{"BEDCHAMBER", 10, 220779},
	{"HALKIN", 6, 220780},
	{"LIBICAL", 7, 220781},
	{"DBES", 4, 220782},
	{"SCOTTVILLE", 10, 220783},
	{"WWWVIDEO", 8, 220784},
	{"UNDERACTIVE", 11, 220785},
	{"FOOTNOTED", 9, 220786},
	{"PENTTI", 6, 220787},
	{"INVIS", 5, 220788},
	{"HAXX", 4, 220789},
	{"PPPOA", 5, 220790},
	{"CHEVALIERS", 10, 220791},
	{"MEHARRY", 7, 220792},
	{"KUZNETS", 7, 220793},
	{"YUBO", 4, 220794},
	{"YUAS", 4, 220795},
	{"YAKC", 4, 220796},
	{"XIFY", 4, 220797},
	{"XFUR", 4, 220798},
	{"WSEQ", 4, 220799},
	{"WOEU", 4, 220800},
	{"WIGF", 4, 220801},
	{"VOWN", 4, 220802},
	{"UXTE", 4, 220803},
	{"UMNN", 4, 220804},
	{"UFOA", 4, 220805},
	{"UEMC", 4, 220806},
	{"TPIV", 4, 220807},
	{"STLD", 4, 220808},
	{"SPBR", 4, 220809},
	{"SKGI", 4, 220810},
	{"RUSQ", 4, 220811},
	{"RBDA", 4, 220812},
	{"PTFL", 4, 220813},
	{"PTAJ", 4, 220814},
	{"PQUO", 4, 220815},
	{"PGIL", 4, 220816},
	{"PBLE", 4, 220817},
	{"PAEX", 4, 220818},
	{"OCUE", 4, 220819},
	{"OCDO", 4, 220820},
	{"MRUG", 4, 220821},
	{"MAGW", 4, 220822},
	{"LYOH", 4, 220823},
	{"LGAK", 4, 220824},
	{"LELH", 4, 220825},
	{"KZAI", 4, 220826},
	{"KUOR", 4, 220827},
	{"KSIK", 4, 220828},
	{"IUZH", 4, 220829},
	{"IKFR", 4, 220830},
	{"IGSG", 4, 220831},
	{"ICOY", 4, 220832},
	{"HYLY", 4, 220833},
	{"HMEP", 4, 220834},
	{"HEQW", 4, 220835},
	{"GVAT", 4, 220836},
	{"GBBC", 4, 220837},
	{"FUKI", 4, 220838},
	{"FFUJ", 4, 220839},
	{"EYMD", 4, 220840},
	{"EFGU", 4, 220841},
	{"EDFG", 4, 220842},
	{"EAMZ", 4, 220843},
	{"DLCH", 4, 220844},
	{"DGUJ", 4, 220845},
	{"BISQ", 4, 220846},
	{"AKYG", 4, 220847},
	{"ABBG", 4, 220848},
	{"VASSEUR", 7, 220849},
	{"CATOON", 6, 220850},
	{"CALLCENTER", 10, 220851},
	{"VIERI", 5, 220852},
	{"LACO", 4, 220853},
	{"HINDERAKER", 10, 220854},
	{"CSRA", 4, 220855},
	{"RIVERCENTER", 11, 220856},
	{"FREEDLAND", 9, 220857},
	{"BIGLIETTO", 9, 220858},
	{"XBC", 3, 220859},
	{"VALVED", 6, 220860},
	{"TANQUE", 6, 220861},
	{"CBSO", 4, 220862},
	{"SURENDETTEMENT", 14, 220863},
	{"VITALIY", 7, 220864},
	{"ZFC", 3, 220865},
	{"VPB", 3, 220866},
	{"ROBINHOOD", 9, 220867},
	{"LOVINGKINDNESS", 14, 220868},
	{"CRACKPOTS", 9, 220869},
	{"UNCONSTITUTIONALITY", 19, 220870},
	{"ENCUENTRAN", 10, 220871},
	{"THEODOLITE", 10, 220872},
	{"STARCHER", 8, 220873},
	{"FRIENDZ", 7, 220874},
	{"RTPMAP", 6, 220875},
	{"INJOY", 5, 220876},
	{"KROES", 5, 220877},
	{"USARE", 5, 220878},
	{"TAGUNG", 6, 220879},
	{"AUTORIZZAZIONE", 14, 220880},
	{"GODSEY", 6, 220881},
	{"FLORENTINO", 10, 220882},
	{"CENTENO", 7, 220883},
	{"AKEL", 4, 220884},
	{"MRREVIEWER", 10, 220885},
	{"MORELAW", 7, 220886},
	{"COCHITI", 7, 220887},
	{"DOWDING", 7, 220888},
	{"CHIMO", 5, 220889},
	{"AUFS", 4, 220890},
	{"DURIE", 5, 220891},
	{"SPECTROGRAMS", 12, 220892},
	{"RLEN", 4, 220893},
	{"OPENSLP", 7, 220894},
	{"OCTREE", 6, 220895},
	{"CALME", 5, 220896},
	{"BARRETTS", 8, 220897},
	{"REPROCESS", 9, 220898},
	{"PUBMEDID", 8, 220899},
	{"DCTP", 4, 220900},
	{"UNROUNDED", 9, 220901},
	{"PAWNSHOPS", 9, 220902},
	{"MAGH", 4, 220903},
	{"CUREZONE", 8, 220904},
	{"UPHOLSTERER", 11, 220905},
	{"UNVIABLE", 8, 220906},
	{"ROUGHS", 6, 220907},
	{"RANSPORTATION", 13, 220908},
	{"DEFEHR", 6, 220909},
	{"REQUESTFOCUS", 12, 220910},
	{"GORSUCH", 7, 220911},
	{"IMPUGN", 6, 220912},
	{"GASPE", 5, 220913},
	{"HIRSUTUM", 8, 220914},
	{"FREESOFTWARE", 12, 220915},
	{"APTIFY", 6, 220916},
	{"LEXIA", 5, 220917},
	{"KANESHIRO", 9, 220918},
	{"GOZADAS", 7, 220919},
	{"TROGGS", 6, 220920},
	{"POSTCONSUMER", 12, 220921},
	{"ASATRU", 6, 220922},
	{"SERVINT", 7, 220923},
	{"SERVERLESS", 10, 220924},
	{"JICAMA", 6, 220925},
	{"WWOR", 4, 220926},
	{"LOTD", 4, 220927},
	{"SWIR", 4, 220928},
	{"LTRIM", 5, 220929},
	{"HPGLVIEW", 8, 220930},
	{"WEBFODDER", 9, 220931},
	{"FICCI", 5, 220932},
	{"CASIOTONE", 9, 220933},
	{"POSTOP", 6, 220934},
	{"TESTINGS", 8, 220935},
	{"ROLX", 4, 220936},
	{"HOLTEK", 6, 220937},
	{"SCHWEINFURT", 11, 220938},
	{"LIBCLN", 6, 220939},
	{"TAUSSIG", 7, 220940},
	{"WILHELMI", 8, 220941},
	{"GREENY", 6, 220942},
	{"INTERCOMMUNICATION", 18, 220943},
	{"BUDOS", 5, 220944},
	{"BALLINASLOE", 11, 220945},
	{"COELACANTH", 10, 220946},
	{"DEFILER", 7, 220947},
	{"STEPHANY", 8, 220948},
	{"INTERCAMBIOS", 12, 220949},
	{"ARTEMUS", 7, 220950},
	{"VISP", 4, 220951},
	{"KRANJSKA", 8, 220952},
	{"INTESTACY", 9, 220953},
	{"UNSTIMULATED", 12, 220954},
	{"FRAGLUXE", 8, 220955},
	{"SANDBANKS", 9, 220956},
	{"REDHOT", 6, 220957},
	{"CONSTRUCTIBLE", 13, 220958},
	{"TATSU", 5, 220959},
	{"KENLY", 5, 220960},
	{"FLUTAMIDE", 9, 220961},
	{"DRAWLED", 7, 220962},
	{"CHROMODORIS", 11, 220963},
	{"MOBILIZATIONS", 13, 220964},
	{"DICARLO", 7, 220965},
	{"DEDRICK", 7, 220966},
	{"GEOGRAPHICA", 11, 220967},
	{"BELLARY", 7, 220968},
	{"NSIDER", 6, 220969},
	{"ASTROPHYSIQUE", 13, 220970},
	{"REDISTRIBUTES", 13, 220971},
	{"MGSO", 4, 220972},
	{"ENTWINE", 7, 220973},
	{"DIETE", 5, 220974},
	{"CHIAT", 5, 220975},
	{"MATRIARCHY", 10, 220976},
	{"TEAMHARMONY", 11, 220977},
	{"SECUNDARIA", 10, 220978},
	{"ALMIRANTE", 9, 220979},
	{"VOORHIS", 7, 220980},
	{"CHAF", 4, 220981},
	{"BOUD", 4, 220982},
	{"WENTZEL", 7, 220983},
	{"OCTOBERFEST", 11, 220984},
	{"NETCACHE", 8, 220985},
	{"ENJEUX", 6, 220986},
	{"EDESSA", 6, 220987},
	{"CPTV", 4, 220988},
	{"TRANSAMINASES", 13, 220989},
	{"SFUSD", 5, 220990},
	{"SANDIFORD", 9, 220991},
	{"AQUAGEN", 7, 220992},
	{"KONTAKTBOERSE", 13, 220993},
	{"ACCOUNTANCYAGE", 14, 220994},
	{"TRICLOSAN", 9, 220995},
	{"HERBERTSTRASSE", 14, 220996},
	{"RUHE", 4, 220997},
	{"MIDTRACK", 8, 220998},
	{"KOINS", 5, 220999},
	{"FLORINS", 7, 221000},
	{"EASTRIDGE", 9, 221001},
	{"COMMODITIZATION", 15, 221002},
	{"LAMBSQUARTERS", 13, 221003},
	{"IMFORMATION", 11, 221004},
	{"ASSIMILATES", 11, 221005},
	{"RAINIECLUB", 10, 221006},
	{"NEXENTA", 7, 221007},
	{"CRAPPING", 8, 221008},
	{"NETSTOREUSA", 11, 221009},
	{"TAPAN", 5, 221010},
	{"SYNEPHRINE", 10, 221011},
	{"JUGGIES", 7, 221012},
	{"DIPSET", 6, 221013},
	{"BORMIOLI", 8, 221014},
	{"WALDOBORO", 9, 221015},
	{"SOKOS", 5, 221016},
	{"YESNO", 5, 221017},
	{"KELVINATOR", 10, 221018},
	{"ELFA", 4, 221019},
	{"EINHEIT", 7, 221020},
	{"ZYSZ", 4, 221021},
	{"XIWH", 4, 221022},
	{"WDYS", 4, 221023},
	{"VOBE", 4, 221024},
	{"TZUC", 4, 221025},
	{"SULW", 4, 221026},
	{"SRPG", 4, 221027},
	{"SGYR", 4, 221028},
	{"RSKS", 4, 221029},
	{"RRUE", 4, 221030},
	{"RNDP", 4, 221031},
	{"RKZU", 4, 221032},
	{"RBAV", 4, 221033},
	{"QBEC", 4, 221034},
	{"PTSX", 4, 221035},
	{"PTGI", 4, 221036},
	{"POID", 4, 221037},
	{"PDUM", 4, 221038},
	{"OXEV", 4, 221039},
	{"OWAQ", 4, 221040},
	{"OVSD", 4, 221041},
	{"OIBM", 4, 221042},
	{"NDFY", 4, 221043},
	{"NCCT", 4, 221044},
	{"MVPR", 4, 221045},
	{"MAIP", 4, 221046},
	{"LOVC", 4, 221047},
	{"IGGW", 4, 221048},
	{"HBAM", 4, 221049},
	{"FOUA", 4, 221050},
	{"EPMR", 4, 221051},
	{"DUGH", 4, 221052},
	{"DNIB", 4, 221053},
	{"DHRE", 4, 221054},
	{"DEMH", 4, 221055},
	{"CZIN", 4, 221056},
	{"CIFR", 4, 221057},
	{"CDYS", 4, 221058},
	{"CDUA", 4, 221059},
	{"BYHM", 4, 221060},
	{"BOGN", 4, 221061},
	{"ANJP", 4, 221062},
	{"AJRO", 4, 221063},
	{"UNATTRIBUTED", 12, 221064},
	{"SHUBB", 5, 221065},
	{"SECHS", 5, 221066},
	{"ZAUN", 4, 221067},
	{"RSGB", 4, 221068},
	{"OVERLANDING", 11, 221069},
	{"HOMESTEADER", 11, 221070},
	{"HOLLOWING", 9, 221071},
	{"CHIAN", 5, 221072},
	{"TBNW", 4, 221073},
	{"PROTEI", 6, 221074},
	{"CLAREMORRIS", 11, 221075},
	{"SCHAMA", 6, 221076},
	{"MELLIN", 6, 221077},
	{"DORSALLY", 8, 221078},
	{"HEALTHC", 7, 221079},
	{"BOKKEN", 6, 221080},
	{"BAIXA", 5, 221081},
	{"COSTARICA", 9, 221082},
	{"TAKACS", 6, 221083},
	{"NONUTILITY", 10, 221084},
	{"MAINTANENCE", 11, 221085},
	{"NEOVA", 5, 221086},
	{"SHARKFISH", 9, 221087},
	{"GIERIGEN", 8, 221088},
	{"CTLIVE", 6, 221089},
	{"PENAEUS", 7, 221090},
	{"KOKA", 4, 221091},
	{"DOXIE", 5, 221092},
	{"AMERICANAIRLINES", 16, 221093},
	{"TURLOUGH", 8, 221094},
	{"QUATERMAIN", 10, 221095},
	{"PRODUKTY", 8, 221096},
	{"MUNTER", 6, 221097},
	{"KLEENEZE", 8, 221098},
	{"UCX", 3, 221099},
	{"TAGUS", 5, 221100},
	{"NOADWARE", 8, 221101},
	{"MAGDESIANS", 10, 221102},
	{"EOLIAN", 6, 221103},
	{"LYDIAN", 6, 221104},
	{"LUZHKOV", 7, 221105},
	{"ADVERTSING", 10, 221106},
	{"TEENEX", 6, 221107},
	{"SRMS", 4, 221108},
	{"ELEUTHERO", 9, 221109},
	{"UBICOMP", 7, 221110},
	{"EFFINGER", 8, 221111},
	{"ACYLATION", 9, 221112},
	{"POINTES", 7, 221113},
	{"MIDE", 4, 221114},
	{"IMMU", 4, 221115},
	{"PANOPTIC", 8, 221116},
	{"HUSUM", 5, 221117},
	{"KLEMENT", 7, 221118},
	{"HOLDAWAY", 8, 221119},
	{"REMEDIATING", 11, 221120},
	{"CIUDADELA", 9, 221121},
	{"HOMESTAKE", 9, 221122},
	{"DIVINYCELL", 10, 221123},
	{"JOOLZ", 5, 221124},
	{"HEISSESTE", 9, 221125},
	{"COUNTERSINK", 11, 221126},
	{"EHREN", 5, 221127},
	{"SWEETSER", 8, 221128},
	{"PANTOMIMES", 10, 221129},
	{"PAYES", 5, 221130},
	{"ZLATKO", 6, 221131},
	{"PROL", 4, 221132},
	{"OVERSHOOTING", 12, 221133},
	{"GREGS", 5, 221134},
	{"EPSPS", 5, 221135},
	{"CHNL", 4, 221136},
	{"ZILPHA", 6, 221137},
	{"LADRO", 5, 221138},
	{"INTERNALISED", 12, 221139},
	{"FOWLKES", 7, 221140},
	{"ENUGU", 5, 221141},
	{"MONGOLOID", 9, 221142},
	{"TEENAGERN", 9, 221143},
	{"SLATEC", 6, 221144},
	{"MYRTACEAE", 9, 221145},
	{"BARATARIA", 9, 221146},
	{"IBALL", 5, 221147},
	{"HEIDEMANN", 9, 221148},
	{"WINCHELSEA", 10, 221149},
	{"MAKASSAR", 8, 221150},
	{"GELA", 4, 221151},
	{"GENSYM", 6, 221152},
	{"MICHALIS", 8, 221153},
	{"HEASARC", 7, 221154},
	{"HEADEY", 6, 221155},
	{"ZUPKO", 5, 221156},
	{"SINTERKLAAS", 11, 221157},
	{"SERVIES", 7, 221158},
	{"KOPS", 4, 221159},
	{"EHEALTHY", 8, 221160},
	{"SWATTER", 7, 221161},
	{"JULICH", 6, 221162},
	{"CLERKED", 7, 221163},
	{"BLACKBUTT", 9, 221164},
	{"MATEWAN", 7, 221165},
	{"RUSSI", 5, 221166},
	{"DWELLINGHOUSE", 13, 221167},
	{"DEBITING", 8, 221168},
	{"CGWIKI", 6, 221169},
	{"NANYA", 5, 221170},
	{"RDW", 3, 221171},
	{"QCF", 3, 221172},
	{"DELFI", 5, 221173},
	{"BUCO", 4, 221174},
	{"TANYAS", 6, 221175},
	{"REMIS", 5, 221176},
	{"DEFEATISM", 9, 221177},
	{"ROMANIC", 7, 221178},
	{"CCRS", 4, 221179},
	{"SETAC", 5, 221180},
	{"TONALIN", 7, 221181},
	{"RITING", 6, 221182},
	{"HALEX", 5, 221183},
	{"BRAZILE", 7, 221184},
	{"ZICO", 4, 221185},
	{"DIFFEOMORPHISMS", 15, 221186},
	{"TOURNAGE", 8, 221187},
	{"PERGOLESI", 9, 221188},
	{"INPUTRICHTEXT", 13, 221189},
	{"NESSUSD", 7, 221190},
	{"ERMEY", 5, 221191},
	{"BLOODWORK", 9, 221192},
	{"DUNGAN", 6, 221193},
	{"GOLDBACH", 8, 221194},
	{"CITICASTERS", 11, 221195},
	{"RADANOVICH", 10, 221196},
	{"MAGIQUE", 7, 221197},
	{"CLUFF", 5, 221198},
	{"SOTRIES", 7, 221199},
	{"LOTFI", 5, 221200},
	{"RESCINDS", 8, 221201},
	{"DERREN", 6, 221202},
	{"GENOTYPED", 9, 221203},
	{"CITYPASS", 8, 221204},
	{"HEDGIE", 6, 221205},
	{"DEMASIADO", 9, 221206},
	{"CSWS", 4, 221207},
	{"BERO", 4, 221208},
	{"VOLAR", 5, 221209},
	{"VENTIONAL", 9, 221210},
	{"PHOSPHORIBOSYL", 14, 221211},
	{"NIVEAUX", 7, 221212},
	{"MOTHA", 5, 221213},
	{"LINARE", 6, 221214},
	{"WORLDCALL", 9, 221215},
	{"STARPYRE", 8, 221216},
	{"TABUTHEMA", 9, 221217},
	{"LAUNDERERS", 10, 221218},
	{"WINROCK", 7, 221219},
	{"YSZE", 4, 221220},
	{"YOSF", 4, 221221},
	{"YLYS", 4, 221222},
	{"XERM", 4, 221223},
	{"WWEJ", 4, 221224},
	{"WCAF", 4, 221225},
	{"WAXT", 4, 221226},
	{"UXBO", 4, 221227},
	{"ULUG", 4, 221228},
	{"UIZF", 4, 221229},
	{"SYIF", 4, 221230},
	{"SKEB", 4, 221231},
	{"SBCG", 4, 221232},
	{"RUUN", 4, 221233},
	{"RRWE", 4, 221234},
	{"RPNO", 4, 221235},
	{"OVEZ", 4, 221236},
	{"OMKM", 4, 221237},
	{"OFBJ", 4, 221238},
	{"NTLD", 4, 221239},
	{"NEZG", 4, 221240},
	{"MUTR", 4, 221241},
	{"MLCA", 4, 221242},
	{"MFHA", 4, 221243},
	{"LGEH", 4, 221244},
	{"LEZG", 4, 221245},
	{"JULP", 4, 221246},
	{"IRCY", 4, 221247},
	{"INRC", 4, 221248},
	{"INLC", 4, 221249},
	{"IECZ", 4, 221250},
	{"HZIM", 4, 221251},
	{"HWWW", 4, 221252},
	{"HLUB", 4, 221253},
	{"GTLA", 4, 221254},
	{"FYLA", 4, 221255},
	{"FWIZ", 4, 221256},
	{"FGOB", 4, 221257},
	{"FCLY", 4, 221258},
	{"EZYO", 4, 221259},
	{"EYMS", 4, 221260},
	{"ENLB", 4, 221261},
	{"DTUA", 4, 221262},
	{"DSCD", 4, 221263},
	{"DNWA", 4, 221264},
	{"COEB", 4, 221265},
	{"BTAM", 4, 221266},
	{"AUMP", 4, 221267},
	{"ARZW", 4, 221268},
	{"APMY", 4, 221269},
	{"ADHW", 4, 221270},
	{"UGRIC", 5, 221271},
	{"NSDAP", 5, 221272},
	{"ISINTRANSACTION", 15, 221273},
	{"FINITY", 6, 221274},
	{"IOCC", 4, 221275},
	{"THERMODYNAMICALLY", 17, 221276},
	{"KAGERO", 6, 221277},
	{"GOTGEAR", 7, 221278},
	{"ALTGR", 5, 221279},
	{"UNGERER", 7, 221280},
	{"TRAILWAYS", 9, 221281},
	{"ELECTRODISCOUNTS", 16, 221282},
	{"AXIOS", 5, 221283},
	{"DESTREHAN", 9, 221284},
	{"NASALINE", 8, 221285},
	{"MERGENT", 7, 221286},
	{"VELE", 4, 221287},
	{"LIGHTNINGPLUS", 13, 221288},
	{"IRBESARTAN", 10, 221289},
	{"EXCELERATOR", 11, 221290},
	{"WWWVERIZON", 10, 221291},
	{"MOUNTVILLE", 10, 221292},
	{"ALSTER", 6, 221293},
	{"SUBASTAS", 8, 221294},
	{"INTERSHIP", 9, 221295},
	{"BEIDERBECKE", 11, 221296},
	{"SCIRPUS", 7, 221297},
	{"IORIO", 5, 221298},
	{"NEOCLASSICISM", 13, 221299},
	{"BUGDEV", 6, 221300},
	{"EMAILCASH", 9, 221301},
	{"CYCLADIC", 8, 221302},
	{"BUTTERICK", 9, 221303},
	{"BORYS", 5, 221304},
	{"XERODERMA", 9, 221305},
	{"PURANAS", 7, 221306},
	{"POSTEXPOSURE", 12, 221307},
	{"CAVACO", 6, 221308},
	{"RATNAM", 6, 221309},
	{"PHARMATON", 9, 221310},
	{"IMPUTING", 8, 221311},
	{"HONEYEATER", 10, 221312},
	{"ZEIST", 5, 221313},
	{"VINNI", 5, 221314},
	{"SARENNA", 7, 221315},
	{"TITLEPAGE", 9, 221316},
	{"NEGLIGEE", 8, 221317},
	{"ENDOWING", 8, 221318},
	{"HAPLORHINI", 10, 221319},
	{"DELPHIC", 7, 221320},
	{"VILLOUS", 7, 221321},
	{"REMBER", 6, 221322},
	{"DMAP", 4, 221323},
	{"CICLOS", 6, 221324},
	{"PROTEK", 6, 221325},
	{"KAKURO", 6, 221326},
	{"GRETCH", 6, 221327},
	{"DESSIE", 6, 221328},
	{"SCHLEIERMACHER", 14, 221329},
	{"RESUSPEND", 9, 221330},
	{"GFXARTIST", 9, 221331},
	{"DEGAUSSING", 10, 221332},
	{"SCHONFELD", 9, 221333},
	{"MENOTTI", 7, 221334},
	{"SBEAN", 5, 221335},
	{"NOOKED", 6, 221336},
	{"GERLING", 7, 221337},
	{"EPEC", 4, 221338},
	{"PLOTUTILS", 9, 221339},
	{"CALLSIGNS", 9, 221340},
	{"HYPOMANIA", 9, 221341},
	{"STEIL", 5, 221342},
	{"SPANGLES", 8, 221343},
	{"PATHOGENETIC", 12, 221344},
	{"MINBARI", 7, 221345},
	{"FRANCISO", 8, 221346},
	{"ATILLA", 6, 221347},
	{"OUTERSPACE", 10, 221348},
	{"MAMMILLARIA", 11, 221349},
	{"COCKRINGS", 9, 221350},
	{"HOADLEY", 7, 221351},
	{"EHRHART", 7, 221352},
	{"UPLIFTS", 7, 221353},
	{"BIGHAM", 6, 221354},
	{"MENUET", 6, 221355},
	{"ISRC", 4, 221356},
	{"DEWR", 4, 221357},
	{"CYBERMATRIX", 11, 221358},
	{"SYBILLE", 7, 221359},
	{"LOUNSBURY", 9, 221360},
	{"BRIFYSGOL", 9, 221361},
	{"BEATNIKS", 8, 221362},
	{"KOIVU", 5, 221363},
	{"CONSTANTINOS", 12, 221364},
	{"CILS", 4, 221365},
	{"CARAMBA", 7, 221366},
	{"PUERPERIUM", 10, 221367},
	{"MARIEKE", 7, 221368},
	{"CHIRICAHUA", 10, 221369},
	{"BOEHMER", 7, 221370},
	{"BOBOLINK", 8, 221371},
	{"REDUNDANTLY", 11, 221372},
	{"CPLEX", 5, 221373},
	{"LONDONMONTHLY", 13, 221374},
	{"DOOF", 4, 221375},
	{"CRONACA", 7, 221376},
	{"CHALLIES", 8, 221377},
	{"CAROLYNE", 8, 221378},
	{"RHIANNA", 7, 221379},
	{"IRREG", 5, 221380},
	{"PETERKIN", 8, 221381},
	{"CRISTATUS", 9, 221382},
	{"DAWAH", 5, 221383},
	{"BRUXISM", 7, 221384},
	{"ATTACHFILE", 10, 221385},
	{"LIBCRYPTO", 9, 221386},
	{"BEATIN", 6, 221387},
	{"HOMEBOYS", 8, 221388},
	{"ARMER", 5, 221389},
	{"SIMPLEMENT", 10, 221390},
	{"TEKNIC", 6, 221391},
	{"QUICKJUMP", 9, 221392},
	{"LOPATE", 6, 221393},
	{"FIREBOY", 7, 221394},
	{"DEWALD", 6, 221395},
	{"ILIC", 4, 221396},
	{"CAVALLARO", 9, 221397},
	{"WOODSLANE", 9, 221398},
	{"TRANSGLUTAMINASE", 16, 221399},
	{"LIFEREA", 7, 221400},
	{"BACTERIORHODOPSIN", 17, 221401},
	{"POSTI", 5, 221402},
	{"KENTEX", 6, 221403},
	{"SLCC", 4, 221404},
	{"NOVANET", 7, 221405},
	{"DPPC", 4, 221406},
	{"GLUCANASE", 9, 221407},
	{"OZBEK", 5, 221408},
	{"FERRISBURG", 10, 221409},
	{"COMORES", 7, 221410},
	{"WOBENZYM", 8, 221411},
	{"SEITENFANG", 10, 221412},
	{"SABERHAGEN", 10, 221413},
	{"LICTURES", 8, 221414},
	{"SUPERCENTERS", 12, 221415},
	{"MOFF", 4, 221416},
	{"DALTRY", 6, 221417},
	{"SCAV", 4, 221418},
	{"MUJAHID", 7, 221419},
	{"BARRINO", 7, 221420},
	{"HORM", 4, 221421},
	{"HURRIYET", 8, 221422},
	{"GOVERNER", 8, 221423},
	{"AWEFUL", 6, 221424},
	{"MODALS", 6, 221425},
	{"QARADAWI", 8, 221426},
	{"NEUROINFORMATICS", 16, 221427},
	{"ERGODICITY", 10, 221428},
	{"BRANCHIAL", 9, 221429},
	{"DUTP", 4, 221430},
	{"BRILLANTE", 9, 221431},
	{"UDDERS", 6, 221432},
	{"FICKFREUDIGE", 12, 221433},
	{"BLUTO", 5, 221434},
	{"FREIFICK", 8, 221435},
	{"BPMS", 4, 221436},
	{"UTILIZZO", 8, 221437},
	{"ROMANOWSKI", 10, 221438},
	{"NCBS", 4, 221439},
	{"RENEGE", 6, 221440},
	{"MAURE", 5, 221441},
	{"MUSCULOSOS", 10, 221442},
	{"GRACCHI", 7, 221443},
	{"FORAGER", 7, 221444},
	{"SPANNERPARADIES", 15, 221445},
	{"MOUSEBLAST", 10, 221446},
	{"ANDROGYNY", 9, 221447},
	{"TERRYTOWN", 9, 221448},
	{"PEEPLIVE", 8, 221449},
	{"XDF", 3, 221450},
	{"UBIK", 4, 221451},
	{"TEENFLAT", 8, 221452},
	{"LMW", 3, 221453},
	{"KNITTERVOTZEN", 13, 221454},
	{"HICP", 4, 221455},
	{"NAGGED", 6, 221456},
	{"VCON", 4, 221457},
	{"HBSP", 4, 221458},
	{"CURTSINGER", 10, 221459},
	{"UBERGIZMO", 9, 221460},
	{"SERVIA", 6, 221461},
	{"LOVICK", 6, 221462},
	{"JOSTENS", 7, 221463},
	{"JEROMY", 6, 221464},
	{"DISUNION", 8, 221465},
	{"UNPOLARIZED", 11, 221466},
	{"TOPICMAPMAIL", 12, 221467},
	{"SPGM", 4, 221468},
	{"SHEPHERDESS", 11, 221469},
	{"PASSIONASIA", 11, 221470},
	{"LINGE", 5, 221471},
	{"CARDINGTON", 10, 221472},
	{"LANGAGES", 8, 221473},
	{"ENSDF", 5, 221474},
	{"SELJUK", 6, 221475},
	{"NUBIANS", 7, 221476},
	{"MAAZEL", 6, 221477},
	{"MARKERBOARDS", 12, 221478},
	{"GORIES", 6, 221479},
	{"PROTRACTORS", 11, 221480},
	{"MISTRESSE", 9, 221481},
	{"LABOURSTART", 11, 221482},
	{"HUARAZ", 6, 221483},
	{"VIEWSJAN", 8, 221484},
	{"CHAOZHOU", 8, 221485},
	{"CLAWFINGER", 10, 221486},
	{"STATISTICSSTATISTICS", 20, 221487},
	{"LUCHT", 5, 221488},
	{"ESTHETICIANS", 12, 221489},
	{"WIGAND", 6, 221490},
	{"LYONDELL", 8, 221491},
	{"HUSNEY", 6, 221492},
	{"ECOMSTATION", 11, 221493},
	{"ZSOU", 4, 221494},
	{"YUEF", 4, 221495},
	{"YNXA", 4, 221496},
	{"YMNI", 4, 221497},
	{"YGOK", 4, 221498},
	{"YEBI", 4, 221499},
	{"YAOU", 4, 221500},
	{"XISK", 4, 221501},
	{"XENC", 4, 221502},
	{"WWAD", 4, 221503},
	{"VYIT", 4, 221504},
	{"VAKE", 4, 221505},
	{"UOAC", 4, 221506},
	{"UKPE", 4, 221507},
	{"UKBO", 4, 221508},
	{"UBYB", 4, 221509},
	{"TJOD", 4, 221510},
	{"SUDR", 4, 221511},
	{"RUWO", 4, 221512},
	{"RFAG", 4, 221513},
	{"PSJE", 4, 221514},
	{"OMPW", 4, 221515},
	{"NZYT", 4, 221516},
	{"MMSL", 4, 221517},
	{"MJAK", 4, 221518},
	{"MHZT", 4, 221519},
	{"LMWR", 4, 221520},
	{"KRAR", 4, 221521},
	{"KIGN", 4, 221522},
	{"KEKH", 4, 221523},
	{"IZUS", 4, 221524},
	{"HUAK", 4, 221525},
	{"HRMI", 4, 221526},
	{"HDEX", 4, 221527},
	{"GZAC", 4, 221528},
	{"GURM", 4, 221529},
	{"GTUL", 4, 221530},
	{"FXRA", 4, 221531},
	{"FOXK", 4, 221532},
	{"FOBV", 4, 221533},
	{"FAXV", 4, 221534},
	{"EWDS", 4, 221535},
	{"DSRH", 4, 221536},
	{"DIYO", 4, 221537},
	{"COBG", 4, 221538},
	{"CADJ", 4, 221539},
	{"BEXE", 4, 221540},
	{"ANRV", 4, 221541},
	{"KGET", 4, 221542},
	{"WAUCHOPE", 8, 221543},
	{"PORSHE", 6, 221544},
	{"ERSION", 6, 221545},
	{"COSTUPDATE", 10, 221546},
	{"MARGU", 5, 221547},
	{"ARLINES", 7, 221548},
	{"TOPCAT", 6, 221549},
	{"BARDEEN", 7, 221550},
	{"SREM", 4, 221551},
	{"MIRAH", 5, 221552},
	{"MILNROW", 7, 221553},
	{"POWERWAVE", 9, 221554},
	{"NOVOLOG", 7, 221555},
	{"MANORVILLE", 10, 221556},
	{"LUMO", 4, 221557},
	{"EDBERG", 6, 221558},
	{"MODULATORY", 10, 221559},
	{"FLEM", 4, 221560},
	{"PHCS", 4, 221561},
	{"PARLAYED", 8, 221562},
	{"MASM", 4, 221563},
	{"CHOMHAIRLE", 10, 221564},
	{"SCEENSAVERS", 11, 221565},
	{"PLAXTON", 7, 221566},
	{"CHALFANT", 8, 221567},
	{"METATAG", 7, 221568},
	{"STANKO", 6, 221569},
	{"MILLHOUSE", 9, 221570},
	{"PLEMENT", 7, 221571},
	{"INFIELDERS", 10, 221572},
	{"WZZM", 4, 221573},
	{"SASSEN", 6, 221574},
	{"OPNET", 5, 221575},
	{"LWOP", 4, 221576},
	{"INTENSION", 9, 221577},
	{"CAMBOURNE", 9, 221578},
	{"BOXS", 4, 221579},
	{"AVRA", 4, 221580},
	{"TTAGETPARENT", 12, 221581},
	{"HERINGTON", 9, 221582},
	{"DIONISIO", 8, 221583},
	{"ACERBIS", 7, 221584},
	{"ENRICHMENTS", 11, 221585},
	{"DIMOV", 5, 221586},
	{"SAVIGNY", 7, 221587},
	{"INTUBATED", 9, 221588},
	{"GLYCATION", 9, 221589},
	{"VCB", 3, 221590},
	{"RUEFUL", 6, 221591},
	{"LARUAN", 6, 221592},
	{"BAJPAI", 6, 221593},
	{"AFCA", 4, 221594},
	{"SABEL", 5, 221595},
	{"FRANCONA", 8, 221596},
	{"CYCLOHEXYL", 10, 221597},
	{"TULEAR", 6, 221598},
	{"LCW", 3, 221599},
	{"TRICKIEST", 9, 221600},
	{"LIBASPELL", 9, 221601},
	{"KHANTY", 6, 221602},
	{"GATOGOMA", 8, 221603},
	{"BENGUELA", 8, 221604},
	{"XRAMP", 5, 221605},
	{"ESAFE", 5, 221606},
	{"DUNVEGAN", 8, 221607},
	{"AIRP", 4, 221608},
	{"TURVILLE", 8, 221609},
	{"TRABEL", 6, 221610},
	{"MIRABELLE", 9, 221611},
	{"CONCEPTO", 8, 221612},
	{"SMITHER", 7, 221613},
	{"DIWEDDARWYD", 11, 221614},
	{"CERTIFICA", 9, 221615},
	{"LAWA", 4, 221616},
	{"PLAYHUT", 7, 221617},
	{"FOLKMAN", 7, 221618},
	{"EXPERIE", 7, 221619},
	{"PLEASENCE", 9, 221620},
	{"FOLKSTON", 8, 221621},
	{"CROSSFIELD", 10, 221622},
	{"ARBOLES", 7, 221623},
	{"KHINTHAR", 8, 221624},
	{"BARRANCA", 8, 221625},
	{"ZORB", 4, 221626},
	{"MCGLONE", 7, 221627},
	{"RIDDIMS", 7, 221628},
	{"BASSENDEAN", 10, 221629},
	{"IMALL", 5, 221630},
	{"WINTEC", 6, 221631},
	{"RELIVES", 7, 221632},
	{"APRECIATE", 9, 221633},
	{"STRIK", 5, 221634},
	{"DATASTAY", 8, 221635},
	{"STERK", 5, 221636},
	{"SMUGNESS", 8, 221637},
	{"BUCILLA", 7, 221638},
	{"VAKIL", 5, 221639},
	{"COOLSAT", 7, 221640},
	{"CALIPARI", 8, 221641},
	{"BENOIST", 7, 221642},
	{"DHIMMITUDE", 10, 221643},
	{"AQUADUCT", 8, 221644},
	{"MOLENAAR", 8, 221645},
	{"NIVELES", 7, 221646},
	{"BURNINGMAN", 10, 221647},
	{"RAWNESS", 7, 221648},
	{"JUCHE", 5, 221649},
	{"BUNUEL", 6, 221650},
	{"WOMMA", 5, 221651},
	{"FORESEEABILITY", 14, 221652},
	{"CHRYSO", 6, 221653},
	{"ALDIE", 5, 221654},
	{"GAMBILL", 7, 221655},
	{"THEGASGIANT", 11, 221656},
	{"STOCKWATCH", 10, 221657},
	{"GRISHA", 6, 221658},
	{"CHLORAMINE", 10, 221659},
	{"CATEG", 5, 221660},
	{"WOLPE", 5, 221661},
	{"LAINGSBURG", 10, 221662},
	{"TRIDENTATA", 10, 221663},
	{"FORESTBURG", 10, 221664},
	{"LVG", 3, 221665},
	{"CYB", 3, 221666},
	{"ISTING", 6, 221667},
	{"GARLICKY", 8, 221668},
	{"TORNEI", 6, 221669},
	{"CEPHALON", 8, 221670},
	{"EPSP", 4, 221671},
	{"CQOUT", 5, 221672},
	{"MIHIR", 5, 221673},
	{"EWROPEAIDD", 10, 221674},
	{"ROSENBLUTH", 10, 221675},
	{"CAPIO", 5, 221676},
	{"SARAS", 5, 221677},
	{"FODEN", 5, 221678},
	{"FINGLAS", 7, 221679},
	{"THAYNE", 6, 221680},
	{"RECRUTEURS", 10, 221681},
	{"HOLMIUM", 7, 221682},
	{"COMPRALISTO", 11, 221683},
	{"YEMENITE", 8, 221684},
	{"NORDHOFF", 8, 221685},
	{"MUTATORS", 8, 221686},
	{"ZIDO", 4, 221687},
	{"YSTK", 4, 221688},
	{"YKHO", 4, 221689},
	{"YJIL", 4, 221690},
	{"XCAB", 4, 221691},
	{"WYNB", 4, 221692},
	{"WPED", 4, 221693},
	{"WNMR", 4, 221694},
	{"WHAK", 4, 221695},
	{"WAXC", 4, 221696},
	{"UEXI", 4, 221697},
	{"TSGD", 4, 221698},
	{"TEYM", 4, 221699},
	{"SXWI", 4, 221700},
	{"SPMP", 4, 221701},
	{"RPHU", 4, 221702},
	{"RMRF", 4, 221703},
	{"QUBI", 4, 221704},
	{"PUHA", 4, 221705},
	{"PAMR", 4, 221706},
	{"OURX", 4, 221707},
	{"OFXP", 4, 221708},
	{"OBAJ", 4, 221709},
	{"NPMP", 4, 221710},
	{"NIMJ", 4, 221711},
	{"NFAG", 4, 221712},
	{"NDBF", 4, 221713},
	{"MEIU", 4, 221714},
	{"LYRD", 4, 221715},
	{"LUPY", 4, 221716},
	{"JKUM", 4, 221717},
	{"JDFR", 4, 221718},
	{"IGAZ", 4, 221719},
	{"IARV", 4, 221720},
	{"GKUL", 4, 221721},
	{"GKOL", 4, 221722},
	{"FTYJ", 4, 221723},
	{"FKYR", 4, 221724},
	{"FGOM", 4, 221725},
	{"EURV", 4, 221726},
	{"ENRM", 4, 221727},
	{"EJWA", 4, 221728},
	{"DHYU", 4, 221729},
	{"DFIJ", 4, 221730},
	{"CUVI", 4, 221731},
	{"CRHY", 4, 221732},
	{"AZZV", 4, 221733},
	{"AZBO", 4, 221734},
	{"ASDV", 4, 221735},
	{"AJWH", 4, 221736},
	{"AGBL", 4, 221737},
	{"ZANUCK", 6, 221738},
	{"MECKEL", 6, 221739},
	{"ROSHOLT", 7, 221740},
	{"RICOLA", 6, 221741},
	{"PHCC", 4, 221742},
	{"LANDAY", 6, 221743},
	{"JOGGS", 5, 221744},
	{"GERTH", 5, 221745},
	{"BEYERS", 6, 221746},
	{"MINTUES", 7, 221747},
	{"ENDEMISM", 8, 221748},
	{"SECATEURS", 9, 221749},
	{"MICROCAP", 8, 221750},
	{"MELIE", 5, 221751},
	{"CUBIN", 5, 221752},
	{"SELLAR", 6, 221753},
	{"ROSSDALE", 8, 221754},
	{"ESPANOLES", 9, 221755},
	{"TRENDLINES", 10, 221756},
	{"SORC", 4, 221757},
	{"PSSY", 4, 221758},
	{"SWIMFAN", 7, 221759},
	{"HAYNESVILLE", 11, 221760},
	{"DDFPLUS", 7, 221761},
	{"SPYCE", 5, 221762},
	{"ACTIONSCRIPTS", 13, 221763},
	{"TOONGABBIE", 10, 221764},
	{"PIATTO", 6, 221765},
	{"UCLICK", 6, 221766},
	{"JASPERREPORTS", 13, 221767},
	{"KALBERMATTEN", 12, 221768},
	{"FORRO", 5, 221769},
	{"MASTUBATION", 11, 221770},
	{"FICT", 4, 221771},
	{"SIMONELLI", 9, 221772},
	{"KILDONAN", 8, 221773},
	{"HAHAHAHAHAHAHA", 14, 221774},
	{"WELLFORMED", 10, 221775},
	{"COLLIMATING", 11, 221776},
	{"EXPLOITIVE", 10, 221777},
	{"DINOTOPIA", 9, 221778},
	{"HETEROTRIMERIC", 14, 221779},
	{"TTCP", 4, 221780},
	{"HSLAB", 5, 221781},
	{"CAROLINENSIS", 12, 221782},
	{"KANTON", 6, 221783},
	{"RANTBLOG", 8, 221784},
	{"BCDS", 4, 221785},
	{"ZUCK", 4, 221786},
	{"DODANO", 6, 221787},
	{"AUTOGLASS", 9, 221788},
	{"ANTIFRAUD", 9, 221789},
	{"SPRITUAL", 8, 221790},
	{"UNBENDING", 9, 221791},
	{"SERENDIP", 8, 221792},
	{"COSUMNES", 8, 221793},
	{"ALMAS", 5, 221794},
	{"DEASON", 6, 221795},
	{"CINTIQ", 6, 221796},
	{"NEWSBOOK", 8, 221797},
	{"ESCIENCE", 8, 221798},
	{"LUKASHENKA", 10, 221799},
	{"FMSHRC", 6, 221800},
	{"EDMARK", 6, 221801},
	{"UTHSC", 5, 221802},
	{"MYANMA", 6, 221803},
	{"KOIL", 4, 221804},
	{"CDEX", 4, 221805},
	{"SHOVELHEAD", 10, 221806},
	{"CSUDH", 5, 221807},
	{"CONGREGATING", 12, 221808},
	{"FORNITURE", 9, 221809},
	{"CYMREIG", 7, 221810},
	{"OPTIN", 5, 221811},
	{"HIACE", 5, 221812},
	{"ALROSA", 6, 221813},
	{"IDEEN", 5, 221814},
	{"GUAYNABO", 8, 221815},
	{"FARBSTUDIE", 10, 221816},
	{"ECOLES", 6, 221817},
	{"MATTEA", 6, 221818},
	{"DATALOGGERS", 11, 221819},
	{"AUTOCLEAN", 9, 221820},
	{"TIMMERMANN", 10, 221821},
	{"BIRDKY", 6, 221822},
	{"SHIFFMAN", 8, 221823},
	{"ECHINOCOCCOSIS", 14, 221824},
	{"DISINTEGRIN", 11, 221825},
	{"DERIVATIONAL", 12, 221826},
	{"ANDERER", 7, 221827},
	{"MUSEA", 5, 221828},
	{"MADCAT", 6, 221829},
	{"ERMELO", 6, 221830},
	{"BRASSEUR", 8, 221831},
	{"ANTIPODE", 8, 221832},
	{"NRPB", 4, 221833},
	{"GRUNFELD", 8, 221834},
	{"KANJORSKI", 9, 221835},
	{"COMPUTERSPIELE", 14, 221836},
	{"ATTACHEMENTS", 12, 221837},
	{"ABERG", 5, 221838},
	{"NONCLINICAL", 11, 221839},
	{"CAPITEL", 7, 221840},
	{"CANINO", 6, 221841},
	{"MCCLANE", 7, 221842},
	{"CLAAS", 5, 221843},
	{"BYDDWCH", 7, 221844},
	{"NORTHCOAST", 10, 221845},
	{"GYNE", 4, 221846},
	{"EMBARRASMENT", 12, 221847},
	{"BABYCARE", 8, 221848},
	{"ROUSSKOV", 8, 221849},
	{"HARTLE", 6, 221850},
	{"CARBOXYMETHYL", 13, 221851},
	{"BEVILL", 6, 221852},
	{"ECMO", 4, 221853},
	{"BEISPIELE", 9, 221854},
	{"MARDIN", 6, 221855},
	{"SPECIED", 7, 221856},
	{"OKRENT", 6, 221857},
	{"LOCKIE", 6, 221858},
	{"HAYRIDES", 8, 221859},
	{"EGUIDES", 7, 221860},
	{"TAPELESS", 8, 221861},
	{"GREF", 4, 221862},
	{"NISKA", 5, 221863},
	{"TUDENTS", 7, 221864},
	{"TEDDIE", 6, 221865},
	{"PUMILA", 6, 221866},
	{"TROXELL", 7, 221867},
	{"TRANADOL", 8, 221868},
	{"SMAX", 4, 221869},
	{"HYPERTEXTUAL", 12, 221870},
	{"POLYFORM", 8, 221871},
	{"DIGNIFY", 7, 221872},
	{"CUSTARDS", 8, 221873},
	{"APPLICAT", 8, 221874},
	{"VALLELY", 7, 221875},
	{"LINKTYPE", 8, 221876},
	{"EQUINOCTIAL", 11, 221877},
	{"REBUTTING", 9, 221878},
	{"URETHANES", 9, 221879},
	{"MGLC", 4, 221880},
	{"HILLEBRAND", 10, 221881},
	{"GLATZER", 7, 221882},
	{"ABERAVON", 8, 221883},
	{"NONDIABETIC", 11, 221884},
	{"ASPERMONT", 9, 221885},
	{"MYPOINTS", 8, 221886},
	{"SCANSPYWARE", 11, 221887},
	{"RAILROADED", 10, 221888},
	{"LITEGLOW", 8, 221889},
	{"VELVETLEAF", 10, 221890},
	{"BROUSSEAU", 9, 221891},
	{"RESHUFFLING", 11, 221892},
	{"IFORCE", 6, 221893},
	{"GLOBEC", 6, 221894},
	{"DIEMS", 5, 221895},
	{"POTHOLDERS", 10, 221896},
	{"INVOLVMENT", 10, 221897},
	{"DORRIGO", 7, 221898},
	{"SKYWATCHER", 10, 221899},
	{"LOBECTOMY", 9, 221900},
	{"CONSTANTE", 9, 221901},
	{"VARUNA", 6, 221902},
	{"PASSERINES", 10, 221903},
	{"JUGEMENT", 8, 221904},
	{"WATERWATCH", 10, 221905},
	{"TREECE", 6, 221906},
	{"NAUTA", 5, 221907},
	{"ENCUENTROS", 10, 221908},
	{"KADO", 4, 221909},
	{"RTLINUX", 7, 221910},
	{"SWAGMAN", 7, 221911},
	{"SOROR", 5, 221912},
	{"ENOLOGY", 7, 221913},
	{"OILVOICE", 8, 221914},
	{"MOUTHY", 6, 221915},
	{"CONSOMMATEURS", 13, 221916},
	{"MONEYBROTHER", 12, 221917},
	{"LUNGREN", 7, 221918},
	{"HUMIDITIES", 10, 221919},
	{"AFSL", 4, 221920},
	{"SHARLA", 6, 221921},
	{"APOLLINAIRE", 11, 221922},
	{"UNFORMAT", 8, 221923},
	{"OPENOBEX", 8, 221924},
	{"ALLOCATABLE", 11, 221925},
	{"INHERITOR", 9, 221926},
	{"GINEVRA", 7, 221927},
	{"ERRORES", 7, 221928},
	{"ZZOH", 4, 221929},
	{"YDSI", 4, 221930},
	{"WOMM", 4, 221931},
	{"VPCO", 4, 221932},
	{"UDFE", 4, 221933},
	{"UANV", 4, 221934},
	{"TZCL", 4, 221935},
	{"TVUS", 4, 221936},
	{"TEUF", 4, 221937},
	{"SRFA", 4, 221938},
	{"SOKR", 4, 221939},
	{"RHMA", 4, 221940},
	{"RGWV", 4, 221941},
	{"RAVC", 4, 221942},
	{"PBOL", 4, 221943},
	{"OFPV", 4, 221944},
	{"NPWI", 4, 221945},
	{"NMPR", 4, 221946},
	{"NCCL", 4, 221947},
	{"MNIU", 4, 221948},
	{"LTKN", 4, 221949},
	{"LGMA", 4, 221950},
	{"LCHF", 4, 221951},
	{"KYKN", 4, 221952},
	{"KUAR", 4, 221953},
	{"KTVS", 4, 221954},
	{"KMUT", 4, 221955},
	{"IVYW", 4, 221956},
	{"IMFT", 4, 221957},
	{"IDZU", 4, 221958},
	{"IBAF", 4, 221959},
	{"GAJI", 4, 221960},
	{"FSUK", 4, 221961},
	{"FRYL", 4, 221962},
	{"FMRR", 4, 221963},
	{"FENP", 4, 221964},
	{"FEKN", 4, 221965},
	{"EVYR", 4, 221966},
	{"EVBU", 4, 221967},
	{"EKMP", 4, 221968},
	{"EDRL", 4, 221969},
	{"DYEF", 4, 221970},
	{"DBTO", 4, 221971},
	{"CUON", 4, 221972},
	{"AXEY", 4, 221973},
	{"AVDE", 4, 221974},
	{"AQFR", 4, 221975},
	{"ANYX", 4, 221976},
	{"AMDY", 4, 221977},
	{"ABFE", 4, 221978},
	{"WEIGHTWATCHERS", 14, 221979},
	{"RAPHSON", 7, 221980},
	{"TARRIED", 7, 221981},
	{"SUNLINE", 7, 221982},
	{"STATIK", 6, 221983},
	{"SERVICENAME", 11, 221984},
	{"GUIDENET", 8, 221985},
	{"GOJU", 4, 221986},
	{"DICKENSIAN", 10, 221987},
	{"CELTIX", 6, 221988},
	{"SUNTOUR", 7, 221989},
	{"REMORSELESS", 11, 221990},
	{"ENGLISHES", 9, 221991},
	{"HACKFORD", 8, 221992},
	{"DISPUTATIONS", 12, 221993},
	{"PRESTBURY", 9, 221994},
	{"EPOLL", 5, 221995},
	{"MILLIVOLT", 9, 221996},
	{"CODABAR", 7, 221997},
	{"TOKUNAGA", 8, 221998},
	{"ROWLANDSON", 10, 221999},
	{"QUERIDO", 7, 222000},
	{"BOARDIES", 8, 222001},
	{"PROCARBAZINE", 12, 222002},
	{"MORISSET", 8, 222003},
	{"VORREI", 6, 222004},
	{"ANNAMARIA", 9, 222005},
	{"GIAPPONE", 8, 222006},
	{"ENDTIMES", 8, 222007},
	{"AUTOPATCHER", 11, 222008},
	{"YARDMASTER", 10, 222009},
	{"AAGAARD", 7, 222010},
	{"NMED", 4, 222011},
	{"APENNINES", 9, 222012},
	{"GESEHEN", 7, 222013},
	{"REACTIVATING", 12, 222014},
	{"KESTNER", 7, 222015},
	{"GRATON", 6, 222016},
	{"DRYS", 4, 222017},
	{"WIKIHOME", 8, 222018},
	{"MINKOFF", 7, 222019},
	{"MACGUIRE", 8, 222020},
	{"GEFITINIB", 9, 222021},
	{"POWERLINK", 9, 222022},
	{"POSTET", 6, 222023},
	{"NUMBINGLY", 9, 222024},
	{"DORINDA", 7, 222025},
	{"ASHBERY", 7, 222026},
	{"TRENZ", 5, 222027},
	{"TARONGA", 7, 222028},
	{"RACI", 4, 222029},
	{"SERVUS", 6, 222030},
	{"REDCAT", 6, 222031},
	{"BWCA", 4, 222032},
	{"ACEREADER", 9, 222033},
	{"MEMBERSLIST", 11, 222034},
	{"FOZZIE", 6, 222035},
	{"SRORIES", 7, 222036},
	{"RITUXAN", 7, 222037},
	{"DOPP", 4, 222038},
	{"MAGCOM", 6, 222039},
	{"TERZA", 5, 222040},
	{"DALYELL", 7, 222041},
	{"BIGBROTHER", 10, 222042},
	{"PROPERTYLOOK", 12, 222043},
	{"BIENVENU", 8, 222044},
	{"DILE", 4, 222045},
	{"STIMU", 5, 222046},
	{"MEGATUFF", 8, 222047},
	{"KUNSTMUSEUM", 11, 222048},
	{"PRECI", 5, 222049},
	{"ARILINES", 8, 222050},
	{"LABEOUF", 7, 222051},
	{"CREN", 4, 222052},
	{"CALOGIC", 7, 222053},
	{"METALIZED", 9, 222054},
	{"VONK", 4, 222055},
	{"PREVISIONI", 10, 222056},
	{"GLENCAIRN", 9, 222057},
	{"FREDERICH", 9, 222058},
	{"MOAK", 4, 222059},
	{"BUSTAN", 6, 222060},
	{"UNDERACHIEVER", 13, 222061},
	{"CLIPBIN", 7, 222062},
	{"PARASOUND", 9, 222063},
	{"CITRONIC", 8, 222064},
	{"XVFB", 4, 222065},
	{"TARCEVA", 7, 222066},
	{"PARADI", 6, 222067},
	{"UNITRIN", 7, 222068},
	{"KRIKORIAN", 9, 222069},
	{"JRJ", 3, 222070},
	{"EXPLORION", 9, 222071},
	{"WIRKUNG", 7, 222072},
	{"HEYNE", 5, 222073},
	{"GLDOUBLE", 8, 222074},
	{"BASANT", 6, 222075},
	{"CHORDATES", 9, 222076},
	{"POTALA", 6, 222077},
	{"HEIZUNG", 7, 222078},
	{"RASTOGI", 7, 222079},
	{"PROTOCOLO", 9, 222080},
	{"LENGTHIER", 9, 222081},
	{"YOUTHBUILD", 10, 222082},
	{"ASKINS", 6, 222083},
	{"REDOUBTABLE", 11, 222084},
	{"GEZAV", 5, 222085},
	{"DENTAIRE", 8, 222086},
	{"RELEVANTE", 9, 222087},
	{"HARTEL", 6, 222088},
	{"TRACKSTAR", 9, 222089},
	{"CHARTERERS", 10, 222090},
	{"ADNESS", 6, 222091},
	{"VIRCHOW", 7, 222092},
	{"PONSON", 6, 222093},
	{"EAPOL", 5, 222094},
	{"BARRYS", 6, 222095},
	{"WURSTER", 7, 222096},
	{"SHOKAN", 6, 222097},
	{"DIMETHOATE", 10, 222098},
	{"ARAGO", 5, 222099},
	{"SYMMES", 6, 222100},
	{"SHAREWAREORDER", 14, 222101},
	{"GITTLEMAN", 9, 222102},
	{"DISPERSANTS", 11, 222103},
	{"BABICH", 6, 222104},
	{"ULTRAVISION", 11, 222105},
	{"INALA", 5, 222106},
	{"ATCHA", 5, 222107},
	{"PAULOS", 6, 222108},
	{"MATTHES", 7, 222109},
	{"INDIAGLITZ", 10, 222110},
	{"NARUC", 5, 222111},
	{"HAYHURST", 8, 222112},
	{"NAING", 5, 222113},
	{"MORPHUS", 7, 222114},
	{"SCUTTLING", 9, 222115},
	{"BABIE", 5, 222116},
	{"HERTER", 6, 222117},
	{"CORPORATISATION", 15, 222118},
	{"INTERESSANT", 11, 222119},
	{"CUK", 3, 222120},
	{"MINGE", 5, 222121},
	{"MEDITATIONAL", 12, 222122},
	{"LRL", 3, 222123},
	{"FLOWERGRAM", 10, 222124},
	{"GRAETZ", 6, 222125},
	{"BASTET", 6, 222126},
	{"VANILLIN", 8, 222127},
	{"LOWLIGHTS", 9, 222128},
	{"SHRIVASTAVA", 11, 222129},
	{"KOLKER", 6, 222130},
	{"HEADBUTT", 8, 222131},
	{"MCKLEIN", 7, 222132},
	{"BXXORG", 6, 222133},
	{"ROTHERMEL", 9, 222134},
	{"BAUEN", 5, 222135},
	{"NATATION", 8, 222136},
	{"INPUTLINE", 9, 222137},
	{"IDEXX", 5, 222138},
	{"PSSP", 4, 222139},
	{"VERGELIJK", 9, 222140},
	{"BIPLANES", 8, 222141},
	{"WIBAUX", 6, 222142},
	{"ANTECHAMBER", 11, 222143},
	{"LOADZA", 6, 222144},
	{"GMPS", 4, 222145},
	{"CROTONE", 7, 222146},
	{"TRINTECH", 8, 222147},
	{"STRADER", 7, 222148},
	{"EVADER", 6, 222149},
	{"SEASONABLE", 10, 222150},
	{"LONGDEN", 7, 222151},
	{"EVISCERATED", 11, 222152},
	{"YABLANITSA", 10, 222153},
	{"WALKLEY", 7, 222154},
	{"KNOPPMYTH", 9, 222155},
	{"AMARCORD", 8, 222156},
	{"WHEATCROFT", 10, 222157},
	{"PROGRAMMAZIONE", 14, 222158},
	{"DONTDIFF", 8, 222159},
	{"CLARISSE", 8, 222160},
	{"ZIFI", 4, 222161},
	{"ZHUN", 4, 222162},
	{"XSPI", 4, 222163},
	{"WUNP", 4, 222164},
	{"VHEL", 4, 222165},
	{"VAZO", 4, 222166},
	{"UZHU", 4, 222167},
	{"UZHN", 4, 222168},
	{"UMNY", 4, 222169},
	{"UENY", 4, 222170},
	{"TWUR", 4, 222171},
	{"SVOD", 4, 222172},
	{"SFUJ", 4, 222173},
	{"RJIT", 4, 222174},
	{"RAFD", 4, 222175},
	{"PYMU", 4, 222176},
	{"PILM", 4, 222177},
	{"OLZM", 4, 222178},
	{"NPMJ", 4, 222179},
	{"NGCZ", 4, 222180},
	{"NDHL", 4, 222181},
	{"MOEV", 4, 222182},
	{"MKIE", 4, 222183},
	{"MBYV", 4, 222184},
	{"MAHF", 4, 222185},
	{"LYYU", 4, 222186},
	{"LYSZ", 4, 222187},
	{"LJOL", 4, 222188},
	{"LIXR", 4, 222189},
	{"LIPY", 4, 222190},
	{"LCWI", 4, 222191},
	{"LCSI", 4, 222192},
	{"KMRS", 4, 222193},
	{"KBLI", 4, 222194},
	{"JISP", 4, 222195},
	{"JINL", 4, 222196},
	{"IODV", 4, 222197},
	{"HIBY", 4, 222198},
	{"HAPB", 4, 222199},
	{"GIFP", 4, 222200},
	{"FFTM", 4, 222201},
	{"EXOU", 4, 222202},
	{"EBYQ", 4, 222203},
	{"DTTR", 4, 222204},
	{"DPBS", 4, 222205},
	{"DIAQ", 4, 222206},
	{"CTEG", 4, 222207},
	{"CICW", 4, 222208},
	{"CFAV", 4, 222209},
	{"CEBC", 4, 222210},
	{"BOVS", 4, 222211},
	{"BJUL", 4, 222212},
	{"AZEU", 4, 222213},
	{"APCU", 4, 222214},
	{"TSARS", 5, 222215},
	{"CATUK", 5, 222216},
	{"BUGLOGS", 7, 222217},
	{"MOCHE", 5, 222218},
	{"TEATHER", 7, 222219},
	{"SPEEDBAR", 8, 222220},
	{"ZWICKY", 6, 222221},
	{"VIZQUEL", 7, 222222},
	{"TILTH", 5, 222223},
	{"MAKEPOVERTYHISTORY", 18, 222224},
	{"KIWA", 4, 222225},
	{"DERBYS", 6, 222226},
	{"TROLLEYBUS", 10, 222227},
	{"STEREOTYPICALLY", 15, 222228},
	{"PRABHAT", 7, 222229},
	{"REYMOND", 7, 222230},
	{"HERSTORY", 8, 222231},
	{"UNPLACED", 8, 222232},
	{"HAGEMEYER", 9, 222233},
	{"BOATBUILDERS", 12, 222234},
	{"FLEXEES", 7, 222235},
	{"HULLE", 5, 222236},
	{"SEDBERGH", 8, 222237},
	{"PHOTOINDUCED", 12, 222238},
	{"KIKU", 4, 222239},
	{"SUBJEKTIVE", 10, 222240},
	{"SNYMAN", 6, 222241},
	{"MATERIALIEN", 11, 222242},
	{"HEAVEY", 6, 222243},
	{"CKER", 4, 222244},
	{"SUZZ", 4, 222245},
	{"GRAZERS", 7, 222246},
	{"VXFS", 4, 222247},
	{"UNMAP", 5, 222248},
	{"RAYFIELD", 8, 222249},
	{"THOENY", 6, 222250},
	{"JUSTDEALS", 9, 222251},
	{"NATURTINT", 9, 222252},
	{"FILEHANDLEGCTEST", 16, 222253},
	{"COMPORTS", 8, 222254},
	{"CAPIZ", 5, 222255},
	{"ZVG", 3, 222256},
	{"ZJL", 3, 222257},
	{"XWK", 3, 222258},
	{"XWJ", 3, 222259},
	{"XQM", 3, 222260},
	{"VZK", 3, 222261},
	{"UWZ", 3, 222262},
	{"UQV", 3, 222263},
	{"QYF", 3, 222264},
	{"QKB", 3, 222265},
	{"JZV", 3, 222266},
	{"JVQ", 3, 222267},
	{"JJQ", 3, 222268},
	{"JFV", 3, 222269},
	{"FQQ", 3, 222270},
	{"DQK", 3, 222271},
	{"BGX", 3, 222272},
	{"AKURA", 5, 222273},
	{"TOFTE", 5, 222274},
	{"WORLDCLASS", 10, 222275},
	{"PLATINA", 7, 222276},
	{"OPENBOARDS", 10, 222277},
	{"DECOMPILATION", 13, 222278},
	{"ANIMADAS", 8, 222279},
	{"PDAPHONE", 8, 222280},
	{"FIORELLO", 8, 222281},
	{"EQUIPT", 6, 222282},
	{"CHERRI", 6, 222283},
	{"MERANT", 6, 222284},
	{"SEMIQUANTITATIVE", 16, 222285},
	{"PHOTOMOSAIC", 11, 222286},
	{"ANADIGICS", 9, 222287},
	{"RVF", 3, 222288},
	{"LABADIE", 7, 222289},
	{"AYHOO", 5, 222290},
	{"ANDEN", 5, 222291},
	{"SODBURY", 7, 222292},
	{"SELLO", 5, 222293},
	{"ROSUVASTATIN", 12, 222294},
	{"CORTECH", 7, 222295},
	{"SELCTION", 8, 222296},
	{"ECLER", 5, 222297},
	{"KNOTES", 6, 222298},
	{"FLAMMARION", 10, 222299},
	{"SYSTEMVERILOG", 13, 222300},
	{"POSSIBILTY", 10, 222301},
	{"GREENSBOROUGH", 13, 222302},
	{"TWIKISYSTEMREQUIREMENTS", 23, 222303},
	{"AIRCONDITIONERS", 15, 222304},
	{"LEVEQUE", 7, 222305},
	{"LARKHALL", 8, 222306},
	{"KARIE", 5, 222307},
	{"DIPSHIT", 7, 222308},
	{"USECS", 5, 222309},
	{"REBINDING", 9, 222310},
	{"INPHONIC", 8, 222311},
	{"HECKENBACH", 10, 222312},
	{"SHEKINAH", 8, 222313},
	{"GRIMACING", 9, 222314},
	{"FISCHEN", 7, 222315},
	{"BROADLEAVED", 11, 222316},
	{"SEABORN", 7, 222317},
	{"GAGAN", 5, 222318},
	{"EPONA", 5, 222319},
	{"BREAKY", 6, 222320},
	{"ATOMFILMS", 9, 222321},
	{"AOBJN", 5, 222322},
	{"RAIATEA", 7, 222323},
	{"MSNSEARCH", 9, 222324},
	{"ANTANDRUS", 9, 222325},
	{"TORNE", 5, 222326},
	{"GEVRIL", 6, 222327},
	{"BROADMEADOWS", 12, 222328},
	{"WIARTON", 7, 222329},
	{"RBGH", 4, 222330},
	{"JOCHEM", 6, 222331},
	{"GEROME", 6, 222332},
	{"SHANTZ", 6, 222333},
	{"VIANDE", 6, 222334},
	{"ECUS", 4, 222335},
	{"ROTUNDIFOLIA", 12, 222336},
	{"SPICEY", 6, 222337},
	{"FOORD", 5, 222338},
	{"DEGNAN", 6, 222339},
	{"CENTROMERIC", 11, 222340},
	{"BAGLIO", 6, 222341},
	{"MICRONAS", 8, 222342},
	{"IOSTREAM", 8, 222343},
	{"AQUASCUTUM", 10, 222344},
	{"STIDHAM", 7, 222345},
	{"OPIEANTHONY", 11, 222346},
	{"WLW", 3, 222347},
	{"TUFO", 4, 222348},
	{"RAVISH", 6, 222349},
	{"CORMS", 5, 222350},
	{"NERSHIP", 7, 222351},
	{"FRONTIERSMAN", 12, 222352},
	{"ALDERSGATE", 10, 222353},
	{"GLUTEUS", 7, 222354},
	{"UMBILICUS", 9, 222355},
	{"LETVAR", 6, 222356},
	{"GAMECAST", 8, 222357},
	{"DUBIOUSLY", 9, 222358},
	{"CELGENE", 7, 222359},
	{"LARSCOM", 7, 222360},
	{"FLUGEL", 6, 222361},
	{"HOGANSVILLE", 11, 222362},
	{"DESROCHES", 9, 222363},
	{"TITLO", 5, 222364},
	{"THESCRIPTS", 10, 222365},
	{"JEPH", 4, 222366},
	{"ZYVEX", 5, 222367},
	{"KUBBY", 5, 222368},
	{"BARKINGSIDE", 11, 222369},
	{"MUIRA", 5, 222370},
	{"REALEST", 7, 222371},
	{"METAPRESS", 9, 222372},
	{"WISPA", 5, 222373},
	{"OZTRAX", 6, 222374},
	{"TUDJMAN", 7, 222375},
	{"SCREENCAP", 9, 222376},
	{"HAGBERG", 7, 222377},
	{"CIPY", 4, 222378},
	{"RUNDSCHAU", 9, 222379},
	{"BATTLEMENT", 10, 222380},
	{"WINVNC", 6, 222381},
	{"FREEBASE", 8, 222382},
	{"ANGELWEAVE", 10, 222383},
	{"GEOGR", 5, 222384},
	{"CONTRACTURES", 12, 222385},
	{"MILLHONE", 8, 222386},
	{"BIALIK", 6, 222387},
	{"BAWABA", 6, 222388},
	{"KASSA", 5, 222389},
	{"PREPLOGIC", 9, 222390},
	{"ICLUBS", 6, 222391},
	{"GETLOCALE", 9, 222392},
	{"ATELECTASIS", 11, 222393},
	{"HOGLE", 5, 222394},
	{"LTJG", 4, 222395},
	{"GAMESTER", 8, 222396},
	{"REDEDICATION", 12, 222397},
	{"SILKWOOD", 8, 222398},
	{"SCEINCE", 7, 222399},
	{"MULTIVENDOR", 11, 222400},
	{"ITOUCH", 6, 222401},
	{"HARRAP", 6, 222402},
	{"DELIRIOUSLY", 11, 222403},
	{"PAUSCHALREISEN", 14, 222404},
	{"FAKULTET", 8, 222405},
	{"OLDTOOLS", 8, 222406},
	{"ALLENHURST", 10, 222407},
	{"MIZUKI", 6, 222408},
	{"SYLT", 4, 222409},
	{"LEAFHOPPER", 10, 222410},
	{"VOTOLATO", 8, 222411},
	{"BYWORD", 6, 222412},
	{"PRIJEDOR", 8, 222413},
	{"OSTEOMALACIA", 12, 222414},
	{"FANTAS", 6, 222415},
	{"ZYNO", 4, 222416},
	{"YLAO", 4, 222417},
	{"XYRE", 4, 222418},
	{"XERH", 4, 222419},
	{"WLRU", 4, 222420},
	{"UXSI", 4, 222421},
	{"UCRY", 4, 222422},
	{"RKAO", 4, 222423},
	{"RFPR", 4, 222424},
	{"RBEX", 4, 222425},
	{"PTOQ", 4, 222426},
	{"PPWE", 4, 222427},
	{"PPAE", 4, 222428},
	{"PHKE", 4, 222429},
	{"PFWA", 4, 222430},
	{"PBOM", 4, 222431},
	{"NTVD", 4, 222432},
	{"NRIR", 4, 222433},
	{"NMSM", 4, 222434},
	{"NDVT", 4, 222435},
	{"MEAZ", 4, 222436},
	{"LUAC", 4, 222437},
	{"KBIK", 4, 222438},
	{"JJON", 4, 222439},
	{"IFKO", 4, 222440},
	{"HYUG", 4, 222441},
	{"HWIZ", 4, 222442},
	{"GITQ", 4, 222443},
	{"GGOM", 4, 222444},
	{"GDUG", 4, 222445},
	{"FTKA", 4, 222446},
	{"FKOH", 4, 222447},
	{"EXKA", 4, 222448},
	{"EFDP", 4, 222449},
	{"DMSG", 4, 222450},
	{"DKUT", 4, 222451},
	{"BYFT", 4, 222452},
	{"BKEN", 4, 222453},
	{"ATKB", 4, 222454},
	{"AKIU", 4, 222455},
	{"SUBCAT", 6, 222456},
	{"SPHALERITE", 10, 222457},
	{"MEGAZONE", 8, 222458},
	{"ARIPIPRAZOLE", 12, 222459},
	{"APOB", 4, 222460},
	{"MUMBLINGS", 9, 222461},
	{"LODO", 4, 222462},
	{"CALCD", 5, 222463},
	{"ONRAMP", 6, 222464},
	{"HUMILIS", 7, 222465},
	{"BULLOUGH", 8, 222466},
	{"MEDITATORS", 10, 222467},
	{"DIESKAU", 7, 222468},
	{"ROIR", 4, 222469},
	{"KVL", 3, 222470},
	{"EXCEEDENCE", 10, 222471},
	{"BIBLIOTEKET", 11, 222472},
	{"DECELERATED", 11, 222473},
	{"TRUDEL", 6, 222474},
	{"CONFIGURAR", 10, 222475},
	{"SORG", 4, 222476},
	{"SHUTTERING", 10, 222477},
	{"REDONDA", 7, 222478},
	{"KINIT", 5, 222479},
	{"CPSSKINS", 8, 222480},
	{"VISHNY", 6, 222481},
	{"UMIT", 4, 222482},
	{"RENNE", 5, 222483},
	{"PRIEBE", 6, 222484},
	{"PONTIFICATING", 13, 222485},
	{"LATORRE", 7, 222486},
	{"HOLLOWEEN", 9, 222487},
	{"CLUNES", 6, 222488},
	{"GRCC", 4, 222489},
	{"REQUALIFICATION", 15, 222490},
	{"RAMU", 4, 222491},
	{"PEAC", 4, 222492},
	{"ACQUIR", 6, 222493},
	{"RADTECH", 7, 222494},
	{"ARROWE", 6, 222495},
	{"AEBISCHER", 9, 222496},
	{"LACERATING", 10, 222497},
	{"BURTONS", 7, 222498},
	{"WARDED", 6, 222499},
	{"STITUTION", 9, 222500},
	{"STYGIAN", 7, 222501},
	{"REALISTICS", 10, 222502},
	{"KARPLUS", 7, 222503},
	{"CHOUETTE", 8, 222504},
	{"ARCANTIS", 8, 222505},
	{"LUDWIGSBURG", 11, 222506},
	{"AUTORADIOGRAPHIC", 16, 222507},
	{"SONYS", 5, 222508},
	{"PLASMAPHERESIS", 14, 222509},
	{"CHEDULE", 7, 222510},
	{"PILER", 5, 222511},
	{"MCMENAMINS", 10, 222512},
	{"LASYK", 5, 222513},
	{"SHQIPTARE", 9, 222514},
	{"PETTS", 5, 222515},
	{"CYSTECTOMY", 10, 222516},
	{"ALTSHULER", 9, 222517},
	{"TRASER", 6, 222518},
	{"TAINER", 6, 222519},
	{"MACROALGAE", 10, 222520},
	{"GAYTON", 6, 222521},
	{"BAILO", 5, 222522},
	{"PETCHBURI", 9, 222523},
	{"UPPDATERAD", 10, 222524},
	{"REFERABLE", 9, 222525},
	{"DUNANT", 6, 222526},
	{"RAYVENESS", 9, 222527},
	{"LEINER", 6, 222528},
	{"INGRESO", 7, 222529},
	{"POMA", 4, 222530},
	{"SIMONETTI", 9, 222531},
	{"CHONDROSARCOMA", 14, 222532},
	{"RIGUEUR", 7, 222533},
	{"RAYMENT", 7, 222534},
	{"LOPID", 5, 222535},
	{"WALKERTEK", 9, 222536},
	{"FMK", 3, 222537},
	{"MJK", 3, 222538},
	{"MCNEEL", 6, 222539},
	{"BAHU", 4, 222540},
	{"SERVAL", 6, 222541},
	{"STURMAN", 7, 222542},
	{"JANGLING", 8, 222543},
	{"EQIUPMENT", 9, 222544},
	{"PARFOIS", 7, 222545},
	{"RESOL", 5, 222546},
	{"HAPPI", 5, 222547},
	{"SCONTATI", 8, 222548},
	{"ALDE", 4, 222549},
	{"VOTAR", 5, 222550},
	{"UNDERVOLTAGE", 12, 222551},
	{"TWISTIES", 8, 222552},
	{"HOOPESTON", 9, 222553},
	{"OUTDOORSMEN", 11, 222554},
	{"ETOILES", 7, 222555},
	{"PLAYSCHOOL", 10, 222556},
	{"COSTLESS", 8, 222557},
	{"WWWP", 4, 222558},
	{"CALIFORNIAS", 11, 222559},
	{"PLOTT", 5, 222560},
	{"DOLEFUL", 7, 222561},
	{"DROOLED", 7, 222562},
	{"SPILLMAN", 8, 222563},
	{"SPELLBINDER", 11, 222564},
	{"SEPARA", 6, 222565},
	{"PLATTSBURG", 10, 222566},
	{"DOMY", 4, 222567},
	{"WADESBORO", 9, 222568},
	{"ZNAJDZIESZ", 10, 222569},
	{"ZLATA", 5, 222570},
	{"RNGINTELT", 9, 222571},
	{"FRANCESA", 8, 222572},
	{"BLACKHAND", 9, 222573},
	{"MEDIAWATCH", 10, 222574},
	{"MANACCOM", 8, 222575},
	{"KESQ", 4, 222576},
	{"RIDGING", 7, 222577},
	{"DIRETORY", 8, 222578},
	{"PHOSPHOTRANSFERASES", 19, 222579},
	{"FREQUENTIE", 10, 222580},
	{"SKARE", 5, 222581},
	{"PEROUSE", 7, 222582},
	{"JOONE", 5, 222583},
	{"BAIZE", 5, 222584},
	{"URGENTE", 7, 222585},
	{"QMAILADMIN", 10, 222586},
	{"LANDAUR", 7, 222587},
	{"CANV", 4, 222588},
	{"XPRES", 5, 222589},
	{"TADWORTH", 8, 222590},
	{"UNDANG", 6, 222591},
	{"SAKUMA", 6, 222592},
	{"LIKELYHOOD", 10, 222593},
	{"FACTORYDIRECT", 13, 222594},
	{"ULUSABA", 7, 222595},
	{"PRESURE", 7, 222596},
	{"GASTHAUS", 8, 222597},
	{"STORTING", 8, 222598},
	{"OPDYKE", 6, 222599},
	{"TOPHAT", 6, 222600},
	{"SUDEEP", 6, 222601},
	{"ETHENE", 6, 222602},
	{"QUINTEN", 7, 222603},
	{"MEINDL", 6, 222604},
	{"SETBINCONTENT", 13, 222605},
	{"DALRY", 5, 222606},
	{"ACVS", 4, 222607},
	{"BOWMORE", 7, 222608},
	{"MCIDAS", 6, 222609},
	{"CCUX", 4, 222610},
	{"STRUMPF", 7, 222611},
	{"KILLARA", 7, 222612},
	{"DESIDERIO", 9, 222613},
	{"BOOMBASTIC", 10, 222614},
	{"POLYCLINIC", 10, 222615},
	{"FAUSTIAN", 8, 222616},
	{"SUPERIMPOSITION", 15, 222617},
	{"ORNATELY", 8, 222618},
	{"OFFICIELLE", 10, 222619},
	{"VIDCO", 5, 222620},
	{"OCTEL", 5, 222621},
	{"ISUB", 4, 222622},
	{"HYALURONATE", 11, 222623},
	{"DREADLOCK", 9, 222624},
	{"VERSIONID", 9, 222625},
	{"SIDERATION", 10, 222626},
	{"ICEFIELD", 8, 222627},
	{"ZEMS", 4, 222628},
	{"YVAT", 4, 222629},
	{"YIMW", 4, 222630},
	{"YGWY", 4, 222631},
	{"VDDR", 4, 222632},
	{"UYGU", 4, 222633},
	{"UAYR", 4, 222634},
	{"SGWI", 4, 222635},
	{"RRBA", 4, 222636},
	{"ROXP", 4, 222637},
	{"RDRT", 4, 222638},
	{"PWAV", 4, 222639},
	{"ONPW", 4, 222640},
	{"NUMU", 4, 222641},
	{"NOMW", 4, 222642},
	{"MRUP", 4, 222643},
	{"MPTN", 4, 222644},
	{"LTVT", 4, 222645},
	{"LPEM", 4, 222646},
	{"LIOJ", 4, 222647},
	{"LGHU", 4, 222648},
	{"LDAZ", 4, 222649},
	{"LCHC", 4, 222650},
	{"KZUC", 4, 222651},
	{"JRME", 4, 222652},
	{"IKSF", 4, 222653},
	{"HKAU", 4, 222654},
	{"GJAG", 4, 222655},
	{"GIUD", 4, 222656},
	{"GIFM", 4, 222657},
	{"FAAM", 4, 222658},
	{"EXYT", 4, 222659},
	{"ESDJ", 4, 222660},
	{"ERLH", 4, 222661},
	{"EDWS", 4, 222662},
	{"DOHL", 4, 222663},
	{"DOGJ", 4, 222664},
	{"BULC", 4, 222665},
	{"AZZJ", 4, 222666},
	{"AQWO", 4, 222667},
	{"AMOX", 4, 222668},
	{"ALCT", 4, 222669},
	{"AALK", 4, 222670},
	{"CREELEY", 7, 222671},
	{"VISUALWORKS", 11, 222672},
	{"DATAMODE", 8, 222673},
	{"BESIEGING", 9, 222674},
	{"NETVIZOR", 8, 222675},
	{"BLOODWORTH", 10, 222676},
	{"BELSEN", 6, 222677},
	{"SAENGER", 7, 222678},
	{"PEENING", 7, 222679},
	{"KONAN", 5, 222680},
	{"BLAGUES", 7, 222681},
	{"GENINFO", 7, 222682},
	{"SHREWDNESS", 10, 222683},
	{"SABOURIN", 8, 222684},
	{"POLECAT", 7, 222685},
	{"JRD", 3, 222686},
	{"SPOKED", 6, 222687},
	{"SODOKU", 6, 222688},
	{"INTERSTICES", 11, 222689},
	{"TARLAC", 6, 222690},
	{"LEEDERVILLE", 11, 222691},
	{"VOHRA", 5, 222692},
	{"LLAI", 4, 222693},
	{"GLORIETA", 8, 222694},
	{"SCHEIBE", 7, 222695},
	{"COLORIZATION", 12, 222696},
	{"TANNEHILL", 9, 222697},
	{"SKICKA", 6, 222698},
	{"LIBRESOURCE", 11, 222699},
	{"FAZEM", 5, 222700},
	{"CANVASSES", 9, 222701},
	{"TRACTABILITY", 12, 222702},
	{"WAKABAYASHI", 11, 222703},
	{"THEOL", 5, 222704},
	{"FESTPLATTEN", 11, 222705},
	{"GOFYN", 5, 222706},
	{"ELUCIDATES", 10, 222707},
	{"YAKUTIA", 7, 222708},
	{"GREYWOOD", 8, 222709},
	{"GRANITA", 7, 222710},
	{"GARGAN", 6, 222711},
	{"MAYST", 5, 222712},
	{"WITHDRAWEL", 10, 222713},
	{"THUMPERS", 8, 222714},
	{"LATHA", 5, 222715},
	{"IGNATIAN", 8, 222716},
	{"UMAA", 4, 222717},
	{"SIGNIFIERS", 10, 222718},
	{"KCD", 3, 222719},
	{"BAGCHI", 6, 222720},
	{"PAUPERIS", 8, 222721},
	{"PARTO", 5, 222722},
	{"FANTINI", 7, 222723},
	{"JUSTICIABLE", 11, 222724},
	{"MARUNOUCHI", 10, 222725},
	{"LADAINIAN", 9, 222726},
	{"BASSOONS", 8, 222727},
	{"VERPLANK", 8, 222728},
	{"SPITI", 5, 222729},
	{"LONGHAUL", 8, 222730},
	{"ARNER", 5, 222731},
	{"LUSTIGE", 7, 222732},
	{"ERFARINGER", 10, 222733},
	{"DUNKER", 6, 222734},
	{"CHUONG", 6, 222735},
	{"GEOSERVER", 9, 222736},
	{"BOZEN", 5, 222737},
	{"UMWA", 4, 222738},
	{"STEUERN", 7, 222739},
	{"SNAZAROO", 8, 222740},
	{"DELUISE", 7, 222741},
	{"REDLINING", 9, 222742},
	{"FIRMEN", 6, 222743},
	{"CLEMENTON", 9, 222744},
	{"CAPUA", 5, 222745},
	{"ALAVI", 5, 222746},
	{"CHUQ", 4, 222747},
	{"LINGAM", 6, 222748},
	{"HARLING", 7, 222749},
	{"ARCHIT", 6, 222750},
	{"PARRIED", 7, 222751},
	{"DICER", 5, 222752},
	{"STEVEC", 6, 222753},
	{"POLLENCA", 8, 222754},
	{"MASCULINO", 9, 222755},
	{"FORMUL", 6, 222756},
	{"MMITCHEL", 8, 222757},
	{"BRASILE", 7, 222758},
	{"BOULDING", 8, 222759},
	{"CLASSMARK", 9, 222760},
	{"AGENZIE", 7, 222761},
	{"MONOIDS", 7, 222762},
	{"CASU", 4, 222763},
	{"SMOLKA", 6, 222764},
	{"JGB", 3, 222765},
	{"YONEDA", 6, 222766},
	{"SKINMEDICA", 10, 222767},
	{"RHAMNUS", 7, 222768},
	{"GAKE", 4, 222769},
	{"SERIFS", 6, 222770},
	{"ERATOSTHENES", 12, 222771},
	{"DEMANDA", 7, 222772},
	{"VORLON", 6, 222773},
	{"PONYTAILS", 9, 222774},
	{"DIPROPIONATE", 12, 222775},
	{"FMOL", 4, 222776},
	{"CARPOINT", 8, 222777},
	{"HEADNOTE", 8, 222778},
	{"SAMOSA", 6, 222779},
	{"PRINCIPIOS", 10, 222780},
	{"LENNI", 5, 222781},
	{"MICRORNA", 8, 222782},
	{"MAHANA", 6, 222783},
	{"GAMWS", 5, 222784},
	{"ANACHRONISMS", 12, 222785},
	{"LEGASPI", 7, 222786},
	{"CHASEZ", 6, 222787},
	{"BOVINES", 7, 222788},
	{"DISEMBARKING", 12, 222789},
	{"PSYCHIATRIE", 11, 222790},
	{"EASEIT", 6, 222791},
	{"REDZ", 4, 222792},
	{"RECENTI", 7, 222793},
	{"ESOPS", 5, 222794},
	{"ZLOO", 4, 222795},
	{"INTERNETWORKS", 13, 222796},
	{"VEENDAM", 7, 222797},
	{"SPDR", 4, 222798},
	{"HINESBURG", 9, 222799},
	{"AMSC", 4, 222800},
	{"TALPA", 5, 222801},
	{"REALLLY", 7, 222802},
	{"MULTILINGUE", 11, 222803},
	{"BURBRIDGE", 9, 222804},
	{"BOBSTER", 7, 222805},
	{"TAKAI", 5, 222806},
	{"ORTHOTOPIC", 10, 222807},
	{"ANTISPASMODIC", 13, 222808},
	{"BEEHIVES", 8, 222809},
	{"PHONENUMBER", 11, 222810},
	{"APRO", 4, 222811},
	{"KOUROSH", 7, 222812},
	{"ELBOWED", 7, 222813},
	{"DOGLEG", 6, 222814},
	{"NICKSON", 7, 222815},
	{"LYRAE", 5, 222816},
	{"COLORIMETRY", 11, 222817},
	{"TRIAMTERENE", 11, 222818},
	{"KOMPATIBLE", 10, 222819},
	{"HONGRIE", 7, 222820},
	{"REHERSAL", 8, 222821},
	{"IFROG", 5, 222822},
	{"LEETON", 6, 222823},
	{"HERPS", 5, 222824},
	{"EPITONIC", 8, 222825},
	{"LITTLEBOROUGH", 13, 222826},
	{"SHUG", 4, 222827},
	{"ISOGENIC", 8, 222828},
	{"SUCHBEGRIFFE", 12, 222829},
	{"NETDIRECTOR", 11, 222830},
	{"VENGANZA", 8, 222831},
	{"TURBOFAN", 8, 222832},
	{"NERDIER", 7, 222833},
	{"EWERS", 5, 222834},
	{"TONGUING", 8, 222835},
	{"SCATTEROMETER", 13, 222836},
	{"BUHR", 4, 222837},
	{"PICNICWARE", 10, 222838},
	{"HAIRDOS", 7, 222839},
	{"EVEYTHING", 9, 222840},
	{"CAPIROSSI", 9, 222841},
	{"GOLDMARK", 8, 222842},
	{"DUALIST", 7, 222843},
	{"BENUTZUNG", 9, 222844},
	{"HOBSBAWM", 8, 222845},
	{"ZZSC", 4, 222846},
	{"ZULF", 4, 222847},
	{"ZLOT", 4, 222848},
	{"ZAIM", 4, 222849},
	{"YIBR", 4, 222850},
	{"YFOW", 4, 222851},
	{"YBIU", 4, 222852},
	{"WWDO", 4, 222853},
	{"WMYL", 4, 222854},
	{"WIMJ", 4, 222855},
	{"WAGT", 4, 222856},
	{"VAZH", 4, 222857},
	{"UTDW", 4, 222858},
	{"URDV", 4, 222859},
	{"UNIY", 4, 222860},
	{"TFMA", 4, 222861},
	{"TDRK", 4, 222862},
	{"SZEG", 4, 222863},
	{"SRWI", 4, 222864},
	{"RUGV", 4, 222865},
	{"ROKT", 4, 222866},
	{"RCFL", 4, 222867},
	{"OMNG", 4, 222868},
	{"NYNG", 4, 222869},
	{"NVSM", 4, 222870},
	{"NIKF", 4, 222871},
	{"LIUD", 4, 222872},
	{"LBSE", 4, 222873},
	{"KEGY", 4, 222874},
	{"KEGH", 4, 222875},
	{"JRWO", 4, 222876},
	{"JONV", 4, 222877},
	{"JIOF", 4, 222878},
	{"JESK", 4, 222879},
	{"ILUX", 4, 222880},
	{"IBWI", 4, 222881},
	{"HUBH", 4, 222882},
	{"GPEG", 4, 222883},
	{"GAWF", 4, 222884},
	{"FOLM", 4, 222885},
	{"FMTW", 4, 222886},
	{"FLWE", 4, 222887},
	{"EDXE", 4, 222888},
	{"EDQI", 4, 222889},
	{"DURW", 4, 222890},
	{"DNCC", 4, 222891},
	{"DHMA", 4, 222892},
	{"DCIM", 4, 222893},
	{"BOUF", 4, 222894},
	{"BDUI", 4, 222895},
	{"AXYM", 4, 222896},
	{"ARXW", 4, 222897},
	{"SYMETRIX", 8, 222898},
	{"SUPERSTRUCTURES", 15, 222899},
	{"DACEY", 5, 222900},
	{"NONSMOKER", 9, 222901},
	{"CHANNELL", 8, 222902},
	{"CATCHIN", 7, 222903},
	{"ZAHLUNG", 7, 222904},
	{"MGMNT", 5, 222905},
	{"WHOOZIT", 7, 222906},
	{"STRONGS", 7, 222907},
	{"WOOLFOLK", 8, 222908},
	{"DLMS", 4, 222909},
	{"SITEFREE", 8, 222910},
	{"RINGEL", 6, 222911},
	{"CYBERSPORTS", 11, 222912},
	{"MCBRATNEY", 9, 222913},
	{"LANDSCHAFT", 10, 222914},
	{"KEATLEY", 7, 222915},
	{"GOLISANO", 8, 222916},
	{"ATTUNEMENTS", 11, 222917},
	{"ARTHRALGIA", 10, 222918},
	{"ANATOLIY", 8, 222919},
	{"GOLLEM", 6, 222920},
	{"AMRICAN", 7, 222921},
	{"SKIPNAV", 7, 222922},
	{"DRIZZT", 6, 222923},
	{"PROXIE", 6, 222924},
	{"PIXELVIEW", 9, 222925},
	{"CUSO", 4, 222926},
	{"CONCHAS", 7, 222927},
	{"THERMOSTATICALLY", 16, 222928},
	{"DELIAS", 6, 222929},
	{"CYFANSWM", 8, 222930},
	{"FURZE", 5, 222931},
	{"LAPLACELIM", 10, 222932},
	{"KUBERT", 6, 222933},
	{"KARISHMA", 8, 222934},
	{"IARLINES", 8, 222935},
	{"USSY", 4, 222936},
	{"MISCONCEIVED", 12, 222937},
	{"LAFORTUNE", 9, 222938},
	{"CANDLEMAS", 9, 222939},
	{"OEDOLION", 8, 222940},
	{"CITYRAG", 7, 222941},
	{"SEICENTO", 8, 222942},
	{"GUSTAVSON", 9, 222943},
	{"FLATOW", 6, 222944},
	{"UNDECIDABILITY", 14, 222945},
	{"TRANZANDO", 9, 222946},
	{"JAMM", 4, 222947},
	{"OMNITRON", 8, 222948},
	{"GUANA", 5, 222949},
	{"NEIGHBOURLY", 11, 222950},
	{"ONLINNE", 7, 222951},
	{"RECOURSES", 9, 222952},
	{"PANJIM", 6, 222953},
	{"SAUNDERSON", 10, 222954},
	{"PERIANTH", 8, 222955},
	{"VENERA", 6, 222956},
	{"ALEMBIC", 7, 222957},
	{"CPTED", 5, 222958},
	{"WIKISPECIES", 11, 222959},
	{"SEMIRAMIS", 9, 222960},
	{"SPETSNAZ", 8, 222961},
	{"DOMINICUS", 9, 222962},
	{"DARKWOOD", 8, 222963},
	{"NAMETONE", 8, 222964},
	{"TVGASM", 6, 222965},
	{"SAMBAL", 6, 222966},
	{"HARNACK", 7, 222967},
	{"CALAS", 5, 222968},
	{"MAKALU", 6, 222969},
	{"INGLENOOK", 9, 222970},
	{"UBIQUINOL", 9, 222971},
	{"GLOBL", 5, 222972},
	{"CABINETMAKERS", 13, 222973},
	{"NRPA", 4, 222974},
	{"CREEPSHOW", 9, 222975},
	{"ACIPENSER", 9, 222976},
	{"OROGENIC", 8, 222977},
	{"MAITE", 5, 222978},
	{"NSWC", 4, 222979},
	{"KARDINAL", 8, 222980},
	{"SHITHEAD", 8, 222981},
	{"GETPREFERREDSIZE", 16, 222982},
	{"DAHRENDORF", 10, 222983},
	{"MTCR", 4, 222984},
	{"GWTP", 4, 222985},
	{"FDLE", 4, 222986},
	{"SENDERO", 7, 222987},
	{"DEIFICATION", 11, 222988},
	{"CWK", 3, 222989},
	{"KUWABARA", 8, 222990},
	{"POLYTECHNICAL", 13, 222991},
	{"EVERNHAM", 8, 222992},
	{"COMUNIDADE", 10, 222993},
	{"VENDE", 5, 222994},
	{"SENSITIVENESS", 13, 222995},
	{"ALANG", 5, 222996},
	{"GELESEN", 7, 222997},
	{"XSELECT", 7, 222998},
	{"GUARNIERI", 9, 222999},
	{"RUSTAM", 6, 223000},
	{"REMAINDERED", 11, 223001},
	{"INFILTRATORS", 12, 223002},
	{"ROVIGO", 6, 223003},
	{"KANAK", 5, 223004},
	{"REDSHANK", 8, 223005},
	{"INCHS", 5, 223006},
	{"TOREY", 5, 223007},
	{"BORTH", 5, 223008},
	{"BLAZAR", 6, 223009},
	{"BOZE", 4, 223010},
	{"KAMERAS", 7, 223011},
	{"GASCONY", 7, 223012},
	{"PAWNED", 6, 223013},
	{"CULTIST", 7, 223014},
	{"WIKITEXT", 8, 223015},
	{"JANANDRE", 8, 223016},
	{"CHAMAECYPARIS", 13, 223017},
	{"BACP", 4, 223018},
	{"KORET", 5, 223019},
	{"POLYLOGARITHMS", 14, 223020},
	{"PLEXIS", 6, 223021},
	{"FALES", 5, 223022},
	{"GALVANISE", 9, 223023},
	{"MEMORIAMS", 9, 223024},
	{"AUTOTRACE", 9, 223025},
	{"STYLEGALA", 9, 223026},
	{"MANCELONA", 9, 223027},
	{"HYDATID", 7, 223028},
	{"POLARIZABILITY", 14, 223029},
	{"LIESL", 5, 223030},
	{"OXYBENZONE", 10, 223031},
	{"HEFCW", 5, 223032},
	{"AMERICAM", 8, 223033},
	{"COMMUTATORS", 11, 223034},
	{"HEYBRIDGE", 9, 223035},
	{"BORU", 4, 223036},
	{"VERHUUR", 7, 223037},
	{"SADAR", 5, 223038},
	{"MILACA", 6, 223039},
	{"PORTARLINGTON", 13, 223040},
	{"TITULAIRE", 9, 223041},
	{"SQWEBMAIL", 9, 223042},
	{"EHEALTHFORUM", 12, 223043},
	{"CARPENTARIA", 11, 223044},
	{"OVERPROTECTIVE", 14, 223045},
	{"WUXGA", 5, 223046},
	{"SUBGRID", 7, 223047},
	{"RELEASEES", 9, 223048},
	{"POTLUCKS", 8, 223049},
	{"OUTEN", 5, 223050},
	{"CLIMALITE", 9, 223051},
	{"REEFMASTER", 10, 223052},
	{"HENNINGS", 8, 223053},
	{"ICCAT", 5, 223054},
	{"PARAGUI", 7, 223055},
	{"COEX", 4, 223056},
	{"ZOGA", 4, 223057},
	{"ZLAU", 4, 223058},
	{"ZADM", 4, 223059},
	{"YOPH", 4, 223060},
	{"YMOY", 4, 223061},
	{"YIMC", 4, 223062},
	{"WWSC", 4, 223063},
	{"VOKO", 4, 223064},
	{"VIVS", 4, 223065},
	{"UYBI", 4, 223066},
	{"UUCH", 4, 223067},
	{"UKSM", 4, 223068},
	{"UDJA", 4, 223069},
	{"TJMA", 4, 223070},
	{"RUWJ", 4, 223071},
	{"ROVH", 4, 223072},
	{"RFAH", 4, 223073},
	{"RAIJ", 4, 223074},
	{"QBBR", 4, 223075},
	{"PIBU", 4, 223076},
	{"OUZM", 4, 223077},
	{"OHRB", 4, 223078},
	{"NZAU", 4, 223079},
	{"NWOF", 4, 223080},
	{"NVYT", 4, 223081},
	{"NDDF", 4, 223082},
	{"NCBR", 4, 223083},
	{"MLUX", 4, 223084},
	{"LVEK", 4, 223085},
	{"LGHM", 4, 223086},
	{"LDAQ", 4, 223087},
	{"ICCW", 4, 223088},
	{"HUKT", 4, 223089},
	{"GDPD", 4, 223090},
	{"GBEV", 4, 223091},
	{"EVKA", 4, 223092},
	{"EPDC", 4, 223093},
	{"EGSK", 4, 223094},
	{"DKOI", 4, 223095},
	{"COPF", 4, 223096},
	{"CMUC", 4, 223097},
	{"CESZ", 4, 223098},
	{"TEDFORD", 7, 223099},
	{"STAFFEL", 7, 223100},
	{"BUNKIE", 6, 223101},
	{"SUPERHEROINE", 12, 223102},
	{"OAKY", 4, 223103},
	{"KSCO", 4, 223104},
	{"TUBOS", 5, 223105},
	{"HARTT", 5, 223106},
	{"CRACKDOWNS", 10, 223107},
	{"MENDICANT", 9, 223108},
	{"RAYNA", 5, 223109},
	{"TMCP", 4, 223110},
	{"EXIGENCES", 9, 223111},
	{"ZONELABS", 8, 223112},
	{"WEDO", 4, 223113},
	{"LANGLANDS", 9, 223114},
	{"KUROGANE", 8, 223115},
	{"SCHOOLWEAR", 10, 223116},
	{"PHENTERM", 8, 223117},
	{"KEEPETH", 7, 223118},
	{"BUCKETSIZE", 10, 223119},
	{"FRIZ", 4, 223120},
	{"DIGGORY", 7, 223121},
	{"AIRLINEE", 8, 223122},
	{"SEMLER", 6, 223123},
	{"RETREATMENT", 11, 223124},
	{"PROJECTIONDESIGN", 16, 223125},
	{"DOSKOCIL", 8, 223126},
	{"SYNGENEIC", 9, 223127},
	{"SDDR", 4, 223128},
	{"SOUTHPOINT", 10, 223129},
	{"SAMPA", 5, 223130},
	{"LYSON", 5, 223131},
	{"LOLETA", 6, 223132},
	{"GLUFOSINATE", 11, 223133},
	{"DOCTORAT", 8, 223134},
	{"PICHU", 5, 223135},
	{"MAXAMAN", 7, 223136},
	{"WIRTSCHAFTS", 11, 223137},
	{"BERTANI", 7, 223138},
	{"THREEPENNY", 10, 223139},
	{"RAZZIE", 6, 223140},
	{"PROFILIN", 8, 223141},
	{"EISIAU", 6, 223142},
	{"MISREPORTING", 12, 223143},
	{"INTERTEXTUALITY", 15, 223144},
	{"TTAINSERTFIRSTCHILD", 19, 223145},
	{"DIFFUSECOLOR", 12, 223146},
	{"TOURTURE", 8, 223147},
	{"TALLEYRAND", 10, 223148},
	{"MODCE", 5, 223149},
	{"MENEM", 5, 223150},
	{"CHARISM", 7, 223151},
	{"AMDA", 4, 223152},
	{"HORES", 5, 223153},
	{"HABITUELLEMENT", 14, 223154},
	{"CAVERNOSA", 9, 223155},
	{"DITHERED", 8, 223156},
	{"TOURVILLE", 9, 223157},
	{"RELATIFS", 8, 223158},
	{"DANLOS", 6, 223159},
	{"AUSTINIST", 9, 223160},
	{"THERMITE", 8, 223161},
	{"TANDARD", 7, 223162},
	{"FORUMSFORUMS", 12, 223163},
	{"DISEGNO", 7, 223164},
	{"ALGARROBO", 9, 223165},
	{"MUNDARING", 9, 223166},
	{"MUNSINGWEAR", 11, 223167},
	{"MERCHANDI", 9, 223168},
	{"DIGIMODE", 8, 223169},
	{"WECC", 4, 223170},
	{"MUKTI", 5, 223171},
	{"KOLLEKTION", 10, 223172},
	{"AILINES", 7, 223173},
	{"TRANSWESTERN", 12, 223174},
	{"SHMOLY", 6, 223175},
	{"BEGINNEN", 8, 223176},
	{"FAROES", 6, 223177},
	{"DYMA", 4, 223178},
	{"DISGAEA", 7, 223179},
	{"BRANDTSON", 9, 223180},
	{"BACKWEB", 7, 223181},
	{"LOANSTORE", 9, 223182},
	{"VINDT", 5, 223183},
	{"SEMPLICE", 8, 223184},
	{"SETUPTOOLS", 10, 223185},
	{"RANDLES", 7, 223186},
	{"NEWY", 4, 223187},
	{"DILLS", 5, 223188},
	{"PUSA", 4, 223189},
	{"HABERLER", 8, 223190},
	{"GIDDINESS", 9, 223191},
	{"WONINGBOUW", 10, 223192},
	{"GEBRUIKEN", 9, 223193},
	{"CAMRYN", 6, 223194},
	{"AUMENTAR", 8, 223195},
	{"RUEIL", 5, 223196},
	{"QUAYE", 5, 223197},
	{"FEAL", 4, 223198},
	{"MEANINGFULNESS", 14, 223199},
	{"KIDO", 4, 223200},
	{"VERENIGD", 8, 223201},
	{"RDFUNDING", 9, 223202},
	{"METOLACHLOR", 11, 223203},
	{"LAURISTON", 9, 223204},
	{"DOMANDA", 7, 223205},
	{"BELTZ", 5, 223206},
	{"TELEKOMMUNIKATION", 17, 223207},
	{"OSSETIAN", 8, 223208},
	{"HORAIRES", 8, 223209},
	{"FIMBRIAE", 8, 223210},
	{"DALBEATTIE", 10, 223211},
	{"CINCVS", 6, 223212},
	{"ALISAL", 6, 223213},
	{"DIAND", 5, 223214},
	{"WEEZY", 5, 223215},
	{"WARDERS", 7, 223216},
	{"EGGHEADCAFE", 11, 223217},
	{"EHRLICHIOSIS", 12, 223218},
	{"DURRANI", 7, 223219},
	{"WHENS", 5, 223220},
	{"PANJAB", 6, 223221},
	{"MSFS", 4, 223222},
	{"CBNRM", 5, 223223},
	{"RPCVS", 5, 223224},
	{"KDFW", 4, 223225},
	{"INOLTRE", 7, 223226},
	{"COMMENSAL", 9, 223227},
	{"VICNET", 6, 223228},
	{"SPOTJOCKEY", 10, 223229},
	{"RKC", 3, 223230},
	{"PHOTOCHROMIC", 12, 223231},
	{"OVERPAYING", 10, 223232},
	{"SUICIDIO", 8, 223233},
	{"MOTTOLA", 7, 223234},
	{"UKWW", 4, 223235},
	{"LANDSEER", 8, 223236},
	{"ANTIQUARK", 9, 223237},
	{"EDGELEY", 7, 223238},
	{"ANTISMOKING", 11, 223239},
	{"GEEKLIST", 8, 223240},
	{"HOUGANG", 7, 223241},
	{"DAMPENERS", 9, 223242},
	{"CHURCHGOERS", 11, 223243},
	{"ARTISTFACTS", 11, 223244},
	{"UNIBODY", 7, 223245},
	{"SAMOCHODY", 9, 223246},
	{"OOSTERHUIS", 10, 223247},
	{"UZODINMA", 8, 223248},
	{"SPACEDAILY", 10, 223249},
	{"ARNAB", 5, 223250},
	{"UNITAL", 6, 223251},
	{"WDCC", 4, 223252},
	{"PODERE", 6, 223253},
	{"LENTH", 5, 223254},
	{"CHARRIOL", 8, 223255},
	{"XTENSA", 6, 223256},
	{"LYDE", 4, 223257},
	{"ROYLCO", 6, 223258},
	{"HELLMOUTH", 9, 223259},
	{"LAMPADA", 7, 223260},
	{"HYDROLYSATE", 11, 223261},
	{"GLANCY", 6, 223262},
	{"FALOUTSOS", 9, 223263},
	{"PLAYSUITS", 9, 223264},
	{"PICTHRES", 8, 223265},
	{"MEYERBEER", 9, 223266},
	{"FINDSPOT", 8, 223267},
	{"CMAA", 4, 223268},
	{"PASTER", 6, 223269},
	{"MUSICNET", 8, 223270},
	{"HEIDER", 6, 223271},
	{"BTEV", 4, 223272},
	{"VIMAGEDIMENSION", 15, 223273},
	{"DETWILER", 8, 223274},
	{"DEADSY", 6, 223275},
	{"UHTC", 4, 223276},
	{"SAMUDRA", 7, 223277},
	{"RETRIBUTIVE", 11, 223278},
	{"GAKES", 5, 223279},
	{"TREB", 4, 223280},
	{"FIREWALLED", 10, 223281},
	{"ARGOMENTI", 9, 223282},
	{"SATOMI", 6, 223283},
	{"PHOTOGRAPHICALLY", 16, 223284},
	{"WOOSLEY", 7, 223285},
	{"AZEEZ", 5, 223286},
	{"PHOINDEX", 8, 223287},
	{"HANLY", 5, 223288},
	{"MIAL", 4, 223289},
	{"GUMBET", 6, 223290},
	{"YTEF", 4, 223291},
	{"YCTH", 4, 223292},
	{"XEMA", 4, 223293},
	{"WSIW", 4, 223294},
	{"WRUB", 4, 223295},
	{"WEBY", 4, 223296},
	{"VOBL", 4, 223297},
	{"UTYV", 4, 223298},
	{"UOND", 4, 223299},
	{"UIVI", 4, 223300},
	{"TBLV", 4, 223301},
	{"SYMU", 4, 223302},
	{"SWCO", 4, 223303},
	{"SIPM", 4, 223304},
	{"SDRL", 4, 223305},
	{"RZIS", 4, 223306},
	{"RUGN", 4, 223307},
	{"RUAB", 4, 223308},
	{"RRSF", 4, 223309},
	{"RFUJ", 4, 223310},
	{"RBIJ", 4, 223311},
	{"RAZM", 4, 223312},
	{"PSYP", 4, 223313},
	{"PMIF", 4, 223314},
	{"PEEF", 4, 223315},
	{"OXCE", 4, 223316},
	{"ORPJ", 4, 223317},
	{"ONRF", 4, 223318},
	{"OMPB", 4, 223319},
	{"OKIY", 4, 223320},
	{"NUPJ", 4, 223321},
	{"NPDG", 4, 223322},
	{"MOKH", 4, 223323},
	{"MEOG", 4, 223324},
	{"MBIH", 4, 223325},
	{"LUTU", 4, 223326},
	{"LLZI", 4, 223327},
	{"LKPL", 4, 223328},
	{"LGEC", 4, 223329},
	{"KUKS", 4, 223330},
	{"JUPT", 4, 223331},
	{"IVBE", 4, 223332},
	{"IMRS", 4, 223333},
	{"IJIC", 4, 223334},
	{"GWIM", 4, 223335},
	{"GABH", 4, 223336},
	{"FZAL", 4, 223337},
	{"FHAK", 4, 223338},
	{"FAFS", 4, 223339},
	{"EVYH", 4, 223340},
	{"EVIF", 4, 223341},
	{"EKMW", 4, 223342},
	{"EGMP", 4, 223343},
	{"DJWI", 4, 223344},
	{"DBOP", 4, 223345},
	{"CZEM", 4, 223346},
	{"BTSF", 4, 223347},
	{"BLOH", 4, 223348},
	{"BKNI", 4, 223349},
	{"THEALE", 6, 223350},
	{"TELERECORDER", 12, 223351},
	{"COMMUNICATIO", 12, 223352},
	{"TAXALMANAC", 10, 223353},
	{"KARREN", 6, 223354},
	{"DCSCRIPTS", 9, 223355},
	{"ARVENSE", 7, 223356},
	{"CESSOR", 6, 223357},
	{"BAUMGART", 8, 223358},
	{"BAMBURGH", 8, 223359},
	{"NAIRU", 5, 223360},
	{"GERKEN", 6, 223361},
	{"RYAZAN", 6, 223362},
	{"PURNIMA", 7, 223363},
	{"WALKTHRU", 8, 223364},
	{"RUACH", 5, 223365},
	{"PYRRHUS", 7, 223366},
	{"ONEOFTHEMILLIONS", 16, 223367},
	{"DIABOLOS", 8, 223368},
	{"MENTOS", 6, 223369},
	{"TULAROSA", 8, 223370},
	{"DIFFE", 5, 223371},
	{"THOROUGHGOING", 13, 223372},
	{"JFET", 4, 223373},
	{"KBTOYS", 6, 223374},
	{"BOROONDARA", 10, 223375},
	{"HEAVISIDE", 9, 223376},
	{"SIMKINS", 7, 223377},
	{"PLANN", 5, 223378},
	{"DUTTY", 5, 223379},
	{"HAPGOOD", 7, 223380},
	{"MARIOTTI", 8, 223381},
	{"KEENA", 5, 223382},
	{"LEARMOUTH", 9, 223383},
	{"VAMES", 5, 223384},
	{"TELECOURSES", 11, 223385},
	{"STRAIGHTLINE", 12, 223386},
	{"ROARKE", 6, 223387},
	{"RAYSIDE", 7, 223388},
	{"TITCHFIELD", 10, 223389},
	{"WEBCHANGESALERT", 15, 223390},
	{"MARSTONS", 8, 223391},
	{"COLING", 6, 223392},
	{"CINDERALLA", 10, 223393},
	{"CHIAMATE", 8, 223394},
	{"THERAP", 6, 223395},
	{"WFQ", 3, 223396},
	{"MARN", 4, 223397},
	{"COCALO", 6, 223398},
	{"TICIPATE", 8, 223399},
	{"SHODAN", 6, 223400},
	{"SBUF", 4, 223401},
	{"NICARDIPINE", 11, 223402},
	{"DOWNREGULATED", 13, 223403},
	{"CANG", 4, 223404},
	{"UNIGOL", 6, 223405},
	{"LOLL", 4, 223406},
	{"FLAGON", 6, 223407},
	{"CELLUCCI", 8, 223408},
	{"JANNY", 5, 223409},
	{"VERTICILLIUM", 12, 223410},
	{"MACROBLOCKS", 11, 223411},
	{"DUBINSKY", 8, 223412},
	{"CASAGRANDE", 10, 223413},
	{"PEGINTERFERON", 13, 223414},
	{"HUNNIES", 7, 223415},
	{"RHODOCHROSITE", 13, 223416},
	{"DISAP", 5, 223417},
	{"ELBO", 4, 223418},
	{"DIAMANTES", 9, 223419},
	{"CYNTHERIA", 9, 223420},
	{"CARROLLWOOD", 11, 223421},
	{"MONEYPENNY", 10, 223422},
	{"WIENERS", 7, 223423},
	{"ROOLS", 5, 223424},
	{"INFORMATI", 9, 223425},
	{"FLOO", 4, 223426},
	{"JAITLEY", 7, 223427},
	{"HETEROJUNCTION", 14, 223428},
	{"WORMY", 5, 223429},
	{"THERMOPHYSICAL", 14, 223430},
	{"SORBED", 6, 223431},
	{"PONYS", 5, 223432},
	{"SHOTOKU", 7, 223433},
	{"MAWDSLEY", 8, 223434},
	{"YMCHWILIO", 9, 223435},
	{"LIGGES", 6, 223436},
	{"BERNAYS", 7, 223437},
	{"TRADUIT", 7, 223438},
	{"PARTAGEZ", 8, 223439},
	{"NROTC", 5, 223440},
	{"CRISSCROSSED", 12, 223441},
	{"INTERPUNK", 9, 223442},
	{"CHIDREN", 7, 223443},
	{"TANGENCY", 8, 223444},
	{"NCRR", 4, 223445},
	{"ZOOSCAPE", 8, 223446},
	{"SERVICEWISE", 11, 223447},
	{"OBJECTIFIED", 11, 223448},
	{"FORMAGGIO", 9, 223449},
	{"CASTUS", 6, 223450},
	{"WYNONA", 6, 223451},
	{"WORKKEYS", 8, 223452},
	{"WINKWORTH", 9, 223453},
	{"NAMIKI", 6, 223454},
	{"BYZANCE", 7, 223455},
	{"JURISDIC", 8, 223456},
	{"BEAULY", 6, 223457},
	{"IRIURE", 6, 223458},
	{"POWERDESIGNER", 13, 223459},
	{"LEIGHT", 6, 223460},
	{"BLOGGERCON", 10, 223461},
	{"SUBTAG", 6, 223462},
	{"INNERE", 6, 223463},
	{"CRITES", 6, 223464},
	{"ARCTOSTAPHYLOS", 14, 223465},
	{"SERGT", 5, 223466},
	{"REMORTGAGING", 12, 223467},
	{"NASTRO", 6, 223468},
	{"ALATA", 5, 223469},
	{"BUP", 3, 223470},
	{"WOBEGON", 7, 223471},
	{"SHOSTAK", 7, 223472},
	{"ELAHI", 5, 223473},
	{"ACTAS", 5, 223474},
	{"GAULE", 5, 223475},
	{"DICAMBA", 7, 223476},
	{"LIBIA", 5, 223477},
	{"INSTL", 5, 223478},
	{"PACAP", 5, 223479},
	{"SYBR", 4, 223480},
	{"SCATTERSHOT", 11, 223481},
	{"QUEBRADA", 8, 223482},
	{"CONTRATS", 8, 223483},
	{"BALLACHULISH", 12, 223484},
	{"PILEDRIVER", 10, 223485},
	{"BLUEDOT", 7, 223486},
	{"TREELANG", 8, 223487},
	{"GESTE", 5, 223488},
	{"DTCC", 4, 223489},
	{"RHAG", 4, 223490},
	{"HEALERPAGES", 11, 223491},
	{"SPHEROIDS", 9, 223492},
	{"GZMES", 5, 223493},
	{"DELHAIZE", 8, 223494},
	{"WORDSTAR", 8, 223495},
	{"OCTANT", 6, 223496},
	{"JESSA", 5, 223497},
	{"DIVERTICULAR", 12, 223498},
	{"CYNARA", 6, 223499},
	{"ZEROCONF", 8, 223500},
	{"DEMIURGE", 8, 223501},
	{"PILATO", 6, 223502},
	{"DHFR", 4, 223503},
	{"CLONIC", 6, 223504},
	{"VERILUX", 7, 223505},
	{"PERSONALISING", 13, 223506},
	{"DATIN", 5, 223507},
	{"UGLIES", 6, 223508},
	{"HAWAIIANA", 9, 223509},
	{"SHELDEN", 7, 223510},
	{"MVIE", 4, 223511},
	{"JANAKI", 6, 223512},
	{"ELSWORTH", 8, 223513},
	{"ARNESEN", 7, 223514},
	{"ROSEVEAR", 8, 223515},
	{"PLLS", 4, 223516},
	{"OSTROFF", 7, 223517},
	{"PHOTOCATHODE", 12, 223518},
	{"CONCOMITANTS", 12, 223519},
	{"BAREFOOTED", 10, 223520},
	{"BACKSTRETCH", 11, 223521},
	{"ABWOMENSWITCH", 13, 223522},
	{"WARMONGERING", 12, 223523},
	{"CHATTERED", 9, 223524},
	{"ZIJA", 4, 223525},
	{"YRDE", 4, 223526},
	{"YBAF", 4, 223527},
	{"WWDA", 4, 223528},
	{"WURL", 4, 223529},
	{"UXOP", 4, 223530},
	{"UTLB", 4, 223531},
	{"URKB", 4, 223532},
	{"UNVO", 4, 223533},
	{"UHAK", 4, 223534},
	{"UAGU", 4, 223535},
	{"TSMM", 4, 223536},
	{"TPFI", 4, 223537},
	{"SVED", 4, 223538},
	{"SRSP", 4, 223539},
	{"RSJR", 4, 223540},
	{"RBCR", 4, 223541},
	{"PNAV", 4, 223542},
	{"OLIJ", 4, 223543},
	{"NTZC", 4, 223544},
	{"NRUC", 4, 223545},
	{"NPAF", 4, 223546},
	{"NJEV", 4, 223547},
	{"NAFB", 4, 223548},
	{"MMYU", 4, 223549},
	{"MHEY", 4, 223550},
	{"LUMV", 4, 223551},
	{"LPLY", 4, 223552},
	{"LJIG", 4, 223553},
	{"JRDE", 4, 223554},
	{"IRNC", 4, 223555},
	{"IKAJ", 4, 223556},
	{"IEGM", 4, 223557},
	{"HWYC", 4, 223558},
	{"HSWR", 4, 223559},
	{"GWIE", 4, 223560},
	{"GUNY", 4, 223561},
	{"GRTC", 4, 223562},
	{"GOVL", 4, 223563},
	{"GDPB", 4, 223564},
	{"FWOE", 4, 223565},
	{"FJIH", 4, 223566},
	{"FHBO", 4, 223567},
	{"EUFI", 4, 223568},
	{"EMCW", 4, 223569},
	{"EKOG", 4, 223570},
	{"DGAA", 4, 223571},
	{"DBST", 4, 223572},
	{"CLUH", 4, 223573},
	{"CCFI", 4, 223574},
	{"ABPL", 4, 223575},
	{"SUPERIMPOSING", 13, 223576},
	{"PHOTOGR", 7, 223577},
	{"DIALOGO", 7, 223578},
	{"PARACHUTIST", 11, 223579},
	{"KATZENBACH", 10, 223580},
	{"CASTERBRIDGE", 12, 223581},
	{"BRANIFF", 7, 223582},
	{"WHITINSVILLE", 12, 223583},
	{"MALING", 6, 223584},
	{"COFNODION", 9, 223585},
	{"TECHGENIX", 9, 223586},
	{"GROOMBRIDGE", 11, 223587},
	{"EXPLORA", 7, 223588},
	{"CLERESTORY", 10, 223589},
	{"SATTERWHITE", 11, 223590},
	{"BRETZ", 5, 223591},
	{"UNIVERSITYOF", 12, 223592},
	{"HERSETH", 7, 223593},
	{"GAJES", 5, 223594},
	{"SULFOTRANSFERASE", 16, 223595},
	{"PRINIVIL", 8, 223596},
	{"FUSCUS", 6, 223597},
	{"HANNING", 7, 223598},
	{"GUNSLINGERS", 11, 223599},
	{"CIDERS", 6, 223600},
	{"KDESKTOP", 8, 223601},
	{"GRANITEWARE", 11, 223602},
	{"FLECAINIDE", 10, 223603},
	{"ABRAHAMSEN", 10, 223604},
	{"PARAGONS", 8, 223605},
	{"DAYER", 5, 223606},
	{"EDITO", 5, 223607},
	{"CADBURYS", 8, 223608},
	{"FURNITUREBUZZ", 13, 223609},
	{"COLELLA", 7, 223610},
	{"WURTZ", 5, 223611},
	{"GRIFTER", 7, 223612},
	{"CTED", 4, 223613},
	{"WHOLEFOOD", 9, 223614},
	{"CREM", 4, 223615},
	{"SNAITH", 6, 223616},
	{"TEERS", 5, 223617},
	{"TRENDSETTING", 12, 223618},
	{"VERDEAN", 7, 223619},
	{"MAADI", 5, 223620},
	{"ELECTRUM", 8, 223621},
	{"DISCORDIAN", 10, 223622},
	{"ARMILLARY", 9, 223623},
	{"BIANNUALLY", 10, 223624},
	{"WJZ", 3, 223625},
	{"TRIADIC", 7, 223626},
	{"EVERLIFE", 8, 223627},
	{"HORSING", 7, 223628},
	{"LEORAM", 6, 223629},
	{"RYM", 3, 223630},
	{"SMITEWORKS", 10, 223631},
	{"OVERHUNG", 8, 223632},
	{"OPENEDGE", 8, 223633},
	{"BLOGRING", 8, 223634},
	{"EPIDIDYMAL", 10, 223635},
	{"MCQUARRIE", 9, 223636},
	{"KOMORI", 6, 223637},
	{"WSBPEL", 6, 223638},
	{"SLANK", 5, 223639},
	{"JIBJAB", 6, 223640},
	{"DEMORALIZATION", 14, 223641},
	{"CERROS", 6, 223642},
	{"WWWB", 4, 223643},
	{"CONTESTABILITY", 14, 223644},
	{"STEERER", 7, 223645},
	{"FAEROESE", 8, 223646},
	{"ADHIKARI", 8, 223647},
	{"POSTCOM", 7, 223648},
	{"AIRLIES", 7, 223649},
	{"LONLINESS", 9, 223650},
	{"IDLH", 4, 223651},
	{"KILLJOY", 7, 223652},
	{"CYPERMETHRIN", 12, 223653},
	{"COSETTE", 7, 223654},
	{"BOOCOOPALABRE", 13, 223655},
	{"MORISHITA", 9, 223656},
	{"MILIA", 5, 223657},
	{"DRAGSTERS", 9, 223658},
	{"ABKIT", 5, 223659},
	{"WIMSEY", 6, 223660},
	{"TVAD", 4, 223661},
	{"EECUE", 5, 223662},
	{"PAGLIACCI", 9, 223663},
	{"NETZTEIL", 8, 223664},
	{"JDATASTORE", 10, 223665},
	{"SULPH", 5, 223666},
	{"THREADWATCH", 11, 223667},
	{"LOOPERS", 7, 223668},
	{"CONTAGIOSUM", 11, 223669},
	{"PEBBLY", 6, 223670},
	{"FOREFATHER", 10, 223671},
	{"MAGATA", 6, 223672},
	{"AETERNA", 7, 223673},
	{"REBATED", 7, 223674},
	{"SIMULCASTING", 12, 223675},
	{"DIGICHAT", 8, 223676},
	{"BASET", 5, 223677},
	{"REVELATOR", 9, 223678},
	{"GIBERNAU", 8, 223679},
	{"SUNWAYS", 7, 223680},
	{"LOOTS", 5, 223681},
	{"DEVENISH", 8, 223682},
	{"UNREVEALED", 10, 223683},
	{"ISLAMO", 6, 223684},
	{"CARBOFURAN", 10, 223685},
	{"HYDES", 5, 223686},
	{"MCRD", 4, 223687},
	{"IBERICA", 7, 223688},
	{"ATTORI", 6, 223689},
	{"SPRIGGAN", 8, 223690},
	{"KNWO", 4, 223691},
	{"SIMMEL", 6, 223692},
	{"MATELASSE", 9, 223693},
	{"EXTRAITS", 8, 223694},
	{"SERVIN", 6, 223695},
	{"BANZHAF", 7, 223696},
	{"WIGTOWN", 7, 223697},
	{"RISKLESS", 8, 223698},
	{"PRTG", 4, 223699},
	{"GORFFENNAF", 10, 223700},
	{"PEPP", 4, 223701},
	{"ELAD", 4, 223702},
	{"CLERCQ", 6, 223703},
	{"SHINRA", 6, 223704},
	{"STELLAN", 7, 223705},
	{"GRADUATESCHOOL", 14, 223706},
	{"BATERIAS", 8, 223707},
	{"CHIRONOMIDAE", 12, 223708},
	{"MOSLER", 6, 223709},
	{"MARCIAL", 7, 223710},
	{"INTROVERTS", 10, 223711},
	{"DESCENDER", 9, 223712},
	{"AMARANTE", 8, 223713},
	{"DULVERTON", 9, 223714},
	{"SPINMASTER", 10, 223715},
	{"STRIGHT", 7, 223716},
	{"PRYME", 5, 223717},
	{"PELTZ", 5, 223718},
	{"HALD", 4, 223719},
	{"TRICHLOROACETIC", 15, 223720},
	{"ISTRUZIONI", 10, 223721},
	{"AYATOLLAHS", 10, 223722},
	{"ABASHED", 7, 223723},
	{"LUBEC", 5, 223724},
	{"BOCAGE", 6, 223725},
	{"PLUNKED", 7, 223726},
	{"PERLS", 5, 223727},
	{"NUBRA", 5, 223728},
	{"MATTITUCK", 9, 223729},
	{"CARBOY", 6, 223730},
	{"SAMME", 5, 223731},
	{"ECAL", 4, 223732},
	{"NAPTR", 5, 223733},
	{"KEYSHAWN", 8, 223734},
	{"AURELIAN", 8, 223735},
	{"KERRIDGE", 8, 223736},
	{"DENNI", 5, 223737},
	{"SACRISTY", 8, 223738},
	{"RAWLE", 5, 223739},
	{"KALRA", 5, 223740},
	{"HEARTAGRAM", 10, 223741},
	{"ANOUNCEMENTS", 12, 223742},
	{"YMGM", 4, 223743},
	{"YMAV", 4, 223744},
	{"YDHE", 4, 223745},
	{"XGON", 4, 223746},
	{"WOEY", 4, 223747},
	{"WLEX", 4, 223748},
	{"WEAW", 4, 223749},
	{"VVYI", 4, 223750},
	{"VIRD", 4, 223751},
	{"URFH", 4, 223752},
	{"TWMA", 4, 223753},
	{"RKTY", 4, 223754},
	{"RGCR", 4, 223755},
	{"QISD", 4, 223756},
	{"PCMO", 4, 223757},
	{"PBUN", 4, 223758},
	{"OWZA", 4, 223759},
	{"ORXM", 4, 223760},
	{"ONWL", 4, 223761},
	{"OFSZ", 4, 223762},
	{"ODRC", 4, 223763},
	{"NYMD", 4, 223764},
	{"NTBP", 4, 223765},
	{"NKYG", 4, 223766},
	{"NJIF", 4, 223767},
	{"NGUF", 4, 223768},
	{"NDPK", 4, 223769},
	{"MZAC", 4, 223770},
	{"MOWT", 4, 223771},
	{"MORZ", 4, 223772},
	{"MDOZ", 4, 223773},
	{"KSRS", 4, 223774},
	{"KHOC", 4, 223775},
	{"IVLA", 4, 223776},
	{"IBNK", 4, 223777},
	{"HUGF", 4, 223778},
	{"HMAF", 4, 223779},
	{"HLOL", 4, 223780},
	{"HLFR", 4, 223781},
	{"GRYV", 4, 223782},
	{"GJOC", 4, 223783},
	{"FYIF", 4, 223784},
	{"FHOK", 4, 223785},
	{"FEOD", 4, 223786},
	{"FAQA", 4, 223787},
	{"EDTG", 4, 223788},
	{"ECEX", 4, 223789},
	{"CGAU", 4, 223790},
	{"CDPW", 4, 223791},
	{"CAKN", 4, 223792},
	{"BBOL", 4, 223793},
	{"ATGD", 4, 223794},
	{"ARVU", 4, 223795},
	{"ALPN", 4, 223796},
	{"VERHELST", 8, 223797},
	{"RADION", 6, 223798},
	{"LORAC", 5, 223799},
	{"KRAVCHENKO", 10, 223800},
	{"MAYI", 4, 223801},
	{"STAUDINGER", 10, 223802},
	{"SINDROME", 8, 223803},
	{"CHARITABLY", 10, 223804},
	{"SYMBIOTICS", 10, 223805},
	{"JOKA", 4, 223806},
	{"GQMES", 5, 223807},
	{"TRUELIFE", 8, 223808},
	{"MONOPHONICS", 11, 223809},
	{"DECIDIO", 7, 223810},
	{"KINDLER", 7, 223811},
	{"QUADTREE", 8, 223812},
	{"GATX", 4, 223813},
	{"OPPERMAN", 8, 223814},
	{"MYHEADLINES", 11, 223815},
	{"BOUTONS", 7, 223816},
	{"BILDUNTERSCHRIFT", 16, 223817},
	{"SODERGREN", 9, 223818},
	{"JBPM", 4, 223819},
	{"FLAMEWAR", 8, 223820},
	{"TURNAGE", 7, 223821},
	{"SOJOURNS", 8, 223822},
	{"RELAFEN", 7, 223823},
	{"CROSSER", 7, 223824},
	{"SAMSCO", 6, 223825},
	{"GFXCHECKER", 10, 223826},
	{"DRAGONREALMS", 12, 223827},
	{"INTERESADO", 10, 223828},
	{"PRATENSE", 8, 223829},
	{"STEDELIJK", 9, 223830},
	{"FOLLE", 5, 223831},
	{"POSITVE", 7, 223832},
	{"NETLOGON", 8, 223833},
	{"BONIOR", 6, 223834},
	{"GUIT", 4, 223835},
	{"GEZA", 4, 223836},
	{"WEBSTATISTIK", 12, 223837},
	{"POLYLINES", 9, 223838},
	{"MODAN", 5, 223839},
	{"WATTER", 6, 223840},
	{"PREORDAINED", 11, 223841},
	{"TORTICOLLIS", 11, 223842},
	{"SIMPLYDAMON", 11, 223843},
	{"SIMILARS", 8, 223844},
	{"LEMNIGAUSS", 10, 223845},
	{"NUDGEE", 6, 223846},
	{"GRESLEY", 7, 223847},
	{"MYFRIENDSHOTMOM", 15, 223848},
	{"HEATSHRINK", 10, 223849},
	{"CONNECTI", 8, 223850},
	{"APTED", 5, 223851},
	{"SERVPROXYALL", 12, 223852},
	{"POSTINSTALL", 11, 223853},
	{"JOSQUIN", 7, 223854},
	{"BELLOTTI", 8, 223855},
	{"METAVERSE", 9, 223856},
	{"ADMCITY", 7, 223857},
	{"REGIONALES", 10, 223858},
	{"PITTCON", 7, 223859},
	{"EMLA", 4, 223860},
	{"WENONA", 6, 223861},
	{"SEABORG", 7, 223862},
	{"GREYBULL", 8, 223863},
	{"RATEMORTGAGE", 12, 223864},
	{"PALAEARCTIC", 11, 223865},
	{"NANFA", 5, 223866},
	{"LENINA", 6, 223867},
	{"CPGTHEMES", 9, 223868},
	{"SUGARBEET", 9, 223869},
	{"MECHANICA", 9, 223870},
	{"MARADNS", 7, 223871},
	{"RBAY", 4, 223872},
	{"VANOZA", 6, 223873},
	{"OFFERER", 7, 223874},
	{"LOUANN", 6, 223875},
	{"INSTANTIT", 9, 223876},
	{"CILIATES", 8, 223877},
	{"MATROIDS", 8, 223878},
	{"RUSSIN", 6, 223879},
	{"FLEXNER", 7, 223880},
	{"EMBALMER", 8, 223881},
	{"CANTED", 6, 223882},
	{"AMNESIC", 7, 223883},
	{"THERMACAM", 9, 223884},
	{"SIPHO", 5, 223885},
	{"ANJUNA", 6, 223886},
	{"REFILE", 6, 223887},
	{"VIETRI", 6, 223888},
	{"LONGCASE", 8, 223889},
	{"LINZER", 6, 223890},
	{"OMNITEL", 7, 223891},
	{"GOFISH", 6, 223892},
	{"WANGI", 5, 223893},
	{"TINGLES", 7, 223894},
	{"JUCAUSHII", 9, 223895},
	{"HORIBA", 6, 223896},
	{"BROODED", 7, 223897},
	{"APLF", 4, 223898},
	{"KANWAR", 6, 223899},
	{"DENDROGRAM", 10, 223900},
	{"SPACEWATCH", 10, 223901},
	{"GAMB", 4, 223902},
	{"SLUMLORDS", 9, 223903},
	{"BABYGIRL", 8, 223904},
	{"NOURI", 5, 223905},
	{"KRISTYN", 7, 223906},
	{"FIGI", 4, 223907},
	{"MARCATO", 7, 223908},
	{"TERMOS", 6, 223909},
	{"HOTFROG", 7, 223910},
	{"SYNONYMOUSLY", 12, 223911},
	{"INTELLISEEK", 11, 223912},
	{"GMAE", 4, 223913},
	{"ARWYDDO", 7, 223914},
	{"RSRB", 4, 223915},
	{"GETOUTPUT", 9, 223916},
	{"ALAVA", 5, 223917},
	{"ISOLATIONS", 10, 223918},
	{"INTERESTINGNESS", 15, 223919},
	{"INVESTOPEDIA", 12, 223920},
	{"DLAMINI", 7, 223921},
	{"SHOWPAGE", 8, 223922},
	{"ISOMETRIES", 10, 223923},
	{"PICHIA", 6, 223924},
	{"RQUOTE", 6, 223925},
	{"STARTET", 7, 223926},
	{"MERRICKS", 8, 223927},
	{"JASIG", 5, 223928},
	{"ELSMORE", 7, 223929},
	{"CARLOTA", 7, 223930},
	{"PRIVILEDGES", 11, 223931},
	{"LEISHMAN", 8, 223932},
	{"ZENAS", 5, 223933},
	{"BARBARO", 7, 223934},
	{"SCHOOLFORGE", 11, 223935},
	{"ORICK", 5, 223936},
	{"LEUBA", 5, 223937},
	{"GAMSS", 5, 223938},
	{"DEMARCUS", 8, 223939},
	{"ARRO", 4, 223940},
	{"RANKER", 6, 223941},
	{"GAWAINE", 7, 223942},
	{"CARYA", 5, 223943},
	{"SYLVANUS", 8, 223944},
	{"OPPERTUNITY", 11, 223945},
	{"EVILNESS", 8, 223946},
	{"DEFNYDDWYR", 10, 223947},
	{"PRAIRIEVILLE", 12, 223948},
	{"RYXI", 4, 223949},
	{"RUSCHA", 6, 223950},
	{"FOETUSES", 8, 223951},
	{"BACKTRACKS", 10, 223952},
	{"GIOIE", 5, 223953},
	{"COGGIN", 6, 223954},
	{"MYPC", 4, 223955},
	{"SUSHUBH", 7, 223956},
	{"TEATER", 6, 223957},
	{"SPESE", 5, 223958},
	{"IDAPA", 5, 223959},
	{"CINEMATECH", 10, 223960},
	{"HOLLYHOCKS", 10, 223961},
	{"FEASTER", 7, 223962},
	{"EPIZOOTIC", 9, 223963},
	{"DIBIASE", 7, 223964},
	{"TREEPAD", 7, 223965},
	{"WINNIFRED", 9, 223966},
	{"PATEN", 5, 223967},
	{"HUSKERLUG", 9, 223968},
	{"COMMUNICANTS", 12, 223969},
	{"INTERDATA", 9, 223970},
	{"STAGFLATION", 11, 223971},
	{"CURIOSA", 7, 223972},
	{"ANDALECHECKOUT", 14, 223973},
	{"CANNULATION", 11, 223974},
	{"GNUSERV", 7, 223975},
	{"ESTRACE", 7, 223976},
	{"DUVALIER", 8, 223977},
	{"TERMPAPER", 9, 223978},
	{"SIDESWIPE", 9, 223979},
	{"ZIMMERLI", 8, 223980},
	{"BARLING", 7, 223981},
	{"GUTER", 5, 223982},
	{"GAMDS", 5, 223983},
	{"DANDIES", 7, 223984},
	{"ZEFL", 4, 223985},
	{"YIWH", 4, 223986},
	{"YEMS", 4, 223987},
	{"XWEA", 4, 223988},
	{"XMOO", 4, 223989},
	{"XICB", 4, 223990},
	{"UYRO", 4, 223991},
	{"UMOH", 4, 223992},
	{"TPCI", 4, 223993},
	{"TKAK", 4, 223994},
	{"TIDM", 4, 223995},
	{"THDM", 4, 223996},
	{"SKVI", 4, 223997},
	{"SFAG", 4, 223998},
	{"RSFS", 4, 223999},
	{"ROWQ", 4, 224000},
	{"OYUM", 4, 224001},
	{"NXWI", 4, 224002},
	{"MODT", 4, 224003},
	{"MNIX", 4, 224004},
	{"LOHU", 4, 224005},
	{"LNFI", 4, 224006},
	{"LIUR", 4, 224007},
	{"KSUD", 4, 224008},
	{"KOIR", 4, 224009},
	{"KIOK", 4, 224010},
	{"KELN", 4, 224011},
	{"JIWI", 4, 224012},
	{"JIBH", 4, 224013},
	{"IKPO", 4, 224014},
	{"IKIY", 4, 224015},
	{"HJIL", 4, 224016},
	{"HIWR", 4, 224017},
	{"GAYU", 4, 224018},
	{"EWKR", 4, 224019},
	{"ESZU", 4, 224020},
	{"EPKO", 4, 224021},
	{"EPKN", 4, 224022},
	{"DWIA", 4, 224023},
	{"DMLA", 4, 224024},
	{"COXD", 4, 224025},
	{"CKAX", 4, 224026},
	{"CILJ", 4, 224027},
	{"BBSN", 4, 224028},
	{"AYPT", 4, 224029},
	{"APPG", 4, 224030},
	{"AICV", 4, 224031},
	{"LARGEPRINT", 10, 224032},
	{"MULCHED", 7, 224033},
	{"INTERJECTING", 12, 224034},
	{"CAFCASS", 7, 224035},
	{"ATTRAVERSO", 10, 224036},
	{"STREETZ", 7, 224037},
	{"SOROPTIMIST", 11, 224038},
	{"TECHNOCRACY", 11, 224039},
	{"KWIKSET", 7, 224040},
	{"BURIAN", 6, 224041},
	{"USCGC", 5, 224042},
	{"QASSAM", 6, 224043},
	{"MOUETTE", 7, 224044},
	{"CENSURA", 7, 224045},
	{"GUATAMELA", 9, 224046},
	{"DONOFRIO", 8, 224047},
	{"AMDEPBACKSLASH", 14, 224048},
	{"XTRAORDINARY", 12, 224049},
	{"STRANGLETHORN", 13, 224050},
	{"BRIDLEWAY", 9, 224051},
	{"INGR", 4, 224052},
	{"ELESSAR", 7, 224053},
	{"ALLONES", 7, 224054},
	{"DEFELICE", 8, 224055},
	{"SANGEETA", 8, 224056},
	{"MINIBARS", 8, 224057},
	{"IDISPATCH", 9, 224058},
	{"KAPER", 5, 224059},
	{"BIRDWATCHER", 11, 224060},
	{"RLEX", 4, 224061},
	{"KREMPASKY", 9, 224062},
	{"DENDRIMER", 9, 224063},
	{"TEARJERKER", 10, 224064},
	{"PREMODERN", 9, 224065},
	{"TWINSANITY", 10, 224066},
	{"STRIAE", 6, 224067},
	{"POKERVIDEO", 10, 224068},
	{"PAPILLONS", 9, 224069},
	{"BODYKITS", 8, 224070},
	{"AIRLNES", 7, 224071},
	{"DOWNIEVILLE", 11, 224072},
	{"ORACULAR", 8, 224073},
	{"PENSHURST", 9, 224074},
	{"SIDEBANDS", 9, 224075},
	{"AITOC", 5, 224076},
	{"NRSG", 4, 224077},
	{"APFEL", 5, 224078},
	{"ELECTRONICO", 11, 224079},
	{"ASTRONOMISCHE", 13, 224080},
	{"KHAYELITSHA", 11, 224081},
	{"AQUARELLE", 9, 224082},
	{"GWMES", 5, 224083},
	{"TECHNOCRAT", 10, 224084},
	{"SWIFTWATER", 10, 224085},
	{"MONHEIT", 7, 224086},
	{"WESTAFF", 7, 224087},
	{"JESICA", 6, 224088},
	{"NIASPAN", 7, 224089},
	{"PENSEES", 7, 224090},
	{"RMIN", 4, 224091},
	{"MIENTKIEWICZ", 12, 224092},
	{"ROSELL", 6, 224093},
	{"KIDDLE", 6, 224094},
	{"BREMOND", 7, 224095},
	{"IMAGIX", 6, 224096},
	{"CONECTORES", 10, 224097},
	{"RDFWEB", 6, 224098},
	{"LEMELSON", 8, 224099},
	{"KANADE", 6, 224100},
	{"UNDEFENDED", 10, 224101},
	{"HAGEMANN", 8, 224102},
	{"HETEROSTRUCTURE", 15, 224103},
	{"CROFTING", 8, 224104},
	{"PERATURES", 9, 224105},
	{"CAPPO", 5, 224106},
	{"AKADEMA", 7, 224107},
	{"LOCKHEART", 9, 224108},
	{"SHADBOLT", 8, 224109},
	{"BSCS", 4, 224110},
	{"TRANSFERRABLE", 13, 224111},
	{"IRRECOVERABLE", 13, 224112},
	{"STEIERMARK", 10, 224113},
	{"PEOPLEFIRST", 11, 224114},
	{"PRTC", 4, 224115},
	{"NEHRING", 7, 224116},
	{"HIBBEN", 6, 224117},
	{"PELAYO", 6, 224118},
	{"TAKEMOTO", 8, 224119},
	{"PARAN", 5, 224120},
	{"JUJUTSU", 7, 224121},
	{"GORDOS", 6, 224122},
	{"NAVISITE", 8, 224123},
	{"KIPPAH", 6, 224124},
	{"VASCHE", 6, 224125},
	{"OPENSHAW", 8, 224126},
	{"DUMAGUETE", 9, 224127},
	{"DISTRIBUTEUR", 12, 224128},
	{"DONDUP", 6, 224129},
	{"UNSP", 4, 224130},
	{"MVIES", 5, 224131},
	{"KURTI", 5, 224132},
	{"MICANOPY", 8, 224133},
	{"LECTEURS", 8, 224134},
	{"CHACHI", 6, 224135},
	{"SERAIL", 6, 224136},
	{"OLETA", 5, 224137},
	{"HFMA", 4, 224138},
	{"REFUGIUM", 8, 224139},
	{"INGENUE", 7, 224140},
	{"VYTAUTAS", 8, 224141},
	{"JYTTE", 5, 224142},
	{"RENTSLICER", 10, 224143},
	{"PORCELAINS", 10, 224144},
	{"PLISHED", 7, 224145},
	{"WWWC", 4, 224146},
	{"XAMPLE", 6, 224147},
	{"OVARIECTOMY", 11, 224148},
	{"GOERTZ", 6, 224149},
	{"COLOMB", 6, 224150},
	{"DOBS", 4, 224151},
	{"SEVOFLURANE", 11, 224152},
	{"PANTSUIT", 8, 224153},
	{"JIMBOB", 6, 224154},
	{"AIRLIENS", 8, 224155},
	{"ADAPTIONS", 9, 224156},
	{"KLEID", 5, 224157},
	{"CTCS", 4, 224158},
	{"MMCPLUS", 7, 224159},
	{"DRUMKIT", 7, 224160},
	{"CHANDRASEKARAN", 14, 224161},
	{"CCSID", 5, 224162},
	{"REIMPLEMENT", 11, 224163},
	{"BOLLI", 5, 224164},
	{"MAXING", 6, 224165},
	{"JUNCOS", 6, 224166},
	{"MKF", 3, 224167},
	{"GLEEMAN", 7, 224168},
	{"HIDETOSHI", 9, 224169},
	{"FBVIEW", 6, 224170},
	{"EUHR", 4, 224171},
	{"CURTILAGE", 9, 224172},
	{"WWWD", 4, 224173},
	{"HEYERDAHL", 9, 224174},
	{"HALLUX", 6, 224175},
	{"DOXY", 4, 224176},
	{"WWWM", 4, 224177},
	{"SECULARIZED", 11, 224178},
	{"SWOBODA", 7, 224179},
	{"MAPZ", 4, 224180},
	{"MAHANOY", 7, 224181},
	{"TRAMITE", 7, 224182},
	{"RAJAT", 5, 224183},
	{"PYCFUNCTION", 11, 224184},
	{"BACKCLOTH", 9, 224185},
	{"CHOCOLATEY", 10, 224186},
	{"ZHDA", 4, 224187},
	{"YRDD", 4, 224188},
	{"YEEX", 4, 224189},
	{"XOFV", 4, 224190},
	{"XJUM", 4, 224191},
	{"WWYO", 4, 224192},
	{"WEGL", 4, 224193},
	{"WCOT", 4, 224194},
	{"WAUB", 4, 224195},
	{"UYOT", 4, 224196},
	{"UOIL", 4, 224197},
	{"ULOH", 4, 224198},
	{"TMUI", 4, 224199},
	{"SMHZ", 4, 224200},
	{"RPAE", 4, 224201},
	{"RGJA", 4, 224202},
	{"RBFI", 4, 224203},
	{"PRNE", 4, 224204},
	{"OCWE", 4, 224205},
	{"NZIC", 4, 224206},
	{"NEUW", 4, 224207},
	{"LBIZ", 4, 224208},
	{"JUNF", 4, 224209},
	{"JONZ", 4, 224210},
	{"JAZA", 4, 224211},
	{"IVOB", 4, 224212},
	{"IUYA", 4, 224213},
	{"IEMF", 4, 224214},
	{"HRHP", 4, 224215},
	{"HEZY", 4, 224216},
	{"GRAK", 4, 224217},
	{"GGSG", 4, 224218},
	{"FOGD", 4, 224219},
	{"FJUB", 4, 224220},
	{"EZSW", 4, 224221},
	{"ERFW", 4, 224222},
	{"DJOO", 4, 224223},
	{"CZUR", 4, 224224},
	{"CHUV", 4, 224225},
	{"BTLA", 4, 224226},
	{"BSEG", 4, 224227},
	{"OLSZTYN", 7, 224228},
	{"HENRICUS", 8, 224229},
	{"TIMBERLANE", 10, 224230},
	{"DUDEN", 5, 224231},
	{"CSTB", 4, 224232},
	{"ANNETTA", 7, 224233},
	{"UNIDROIT", 8, 224234},
	{"HUMORISTS", 9, 224235},
	{"ENILNO", 6, 224236},
	{"VIVELLE", 7, 224237},
	{"QUENYA", 6, 224238},
	{"PICTURRS", 8, 224239},
	{"OLDNAME", 7, 224240},
	{"INTERNATIONL", 12, 224241},
	{"EXCEPTIONALITIES", 16, 224242},
	{"MANAKIN", 7, 224243},
	{"ARMENTROUT", 10, 224244},
	{"UNITIES", 7, 224245},
	{"DEYRNAS", 7, 224246},
	{"ASHBURNER", 9, 224247},
	{"SHORTZ", 6, 224248},
	{"JSERVER", 7, 224249},
	{"SKYPAINTER", 10, 224250},
	{"ECGS", 4, 224251},
	{"PAPIERS", 7, 224252},
	{"IGPX", 4, 224253},
	{"KORACH", 6, 224254},
	{"ISOCYANATES", 11, 224255},
	{"MDDEV", 5, 224256},
	{"MCMASTERS", 9, 224257},
	{"LIBDVDREAD", 10, 224258},
	{"SYRUS", 5, 224259},
	{"BUEHRLE", 7, 224260},
	{"LUPITA", 6, 224261},
	{"SATISFYINGLY", 12, 224262},
	{"HEWIT", 5, 224263},
	{"PAVLOS", 6, 224264},
	{"SHARQ", 5, 224265},
	{"BEDEVILED", 9, 224266},
	{"SILTS", 5, 224267},
	{"DELLUMS", 7, 224268},
	{"CHAW", 4, 224269},
	{"CIRCLIP", 7, 224270},
	{"FRIEDER", 7, 224271},
	{"ADJA", 4, 224272},
	{"MYELOCYTIC", 10, 224273},
	{"METALANGUAGE", 12, 224274},
	{"TRACKAGE", 8, 224275},
	{"SCHLOSSBERG", 11, 224276},
	{"GREYSON", 7, 224277},
	{"FERRYTO", 7, 224278},
	{"ELECTONIC", 9, 224279},
	{"ORTHOPHOTOS", 11, 224280},
	{"DWB", 3, 224281},
	{"AMBERJACK", 9, 224282},
	{"COLORESCIENCE", 13, 224283},
	{"ARCSIN", 6, 224284},
	{"PATTANI", 7, 224285},
	{"OUTSHINES", 9, 224286},
	{"MDBS", 4, 224287},
	{"GENWORTH", 8, 224288},
	{"FEDERICI", 8, 224289},
	{"ESPANOLAS", 9, 224290},
	{"EQUILIBRIO", 10, 224291},
	{"EPRO", 4, 224292},
	{"DATALOGGERRECORD", 16, 224293},
	{"CHARADRIIFORMES", 15, 224294},
	{"RAKISH", 6, 224295},
	{"PSORT", 5, 224296},
	{"COMPUTERTRAINING", 16, 224297},
	{"ROBLE", 5, 224298},
	{"EFFERVESCENCE", 13, 224299},
	{"OXACILLIN", 9, 224300},
	{"FLUSHCOUNT", 10, 224301},
	{"PSYCHOPHARMACOL", 15, 224302},
	{"DATP", 4, 224303},
	{"COLOMBIANO", 10, 224304},
	{"ADENOIDS", 8, 224305},
	{"MYJAVASERVER", 12, 224306},
	{"KOJA", 4, 224307},
	{"CLUTTERBUSTERS", 14, 224308},
	{"CHAMBERTIN", 10, 224309},
	{"AENGUS", 6, 224310},
	{"RESECTIONS", 10, 224311},
	{"ENTHALTEN", 9, 224312},
	{"DEHISCENCE", 10, 224313},
	{"BHPHOTOVIDEO", 12, 224314},
	{"LCLS", 4, 224315},
	{"STARBURSTS", 10, 224316},
	{"GOORIN", 6, 224317},
	{"BEKEKEN", 7, 224318},
	{"TORTOR", 6, 224319},
	{"FLASHPOINTS", 11, 224320},
	{"EKKEHARD", 8, 224321},
	{"RHYMER", 6, 224322},
	{"TATUAJES", 8, 224323},
	{"CAINES", 6, 224324},
	{"HALEYVILLE", 10, 224325},
	{"GILLUM", 6, 224326},
	{"SCAVENGED", 9, 224327},
	{"EXPERIENC", 9, 224328},
	{"CHORIOCARCINOMA", 15, 224329},
	{"MARYWOOD", 8, 224330},
	{"MIZNER", 6, 224331},
	{"ONELINERS", 9, 224332},
	{"PSYD", 4, 224333},
	{"DIALOUT", 7, 224334},
	{"SOLSUITE", 8, 224335},
	{"THEPLANET", 9, 224336},
	{"FINANCIERA", 10, 224337},
	{"UNWORTHINESS", 12, 224338},
	{"SCRUNCHIES", 10, 224339},
	{"ISAIAS", 6, 224340},
	{"GERGIEV", 7, 224341},
	{"MAPFILE", 7, 224342},
	{"WKND", 4, 224343},
	{"SAUCEDO", 7, 224344},
	{"COOLSAVINGS", 11, 224345},
	{"ARREAR", 6, 224346},
	{"AIRINES", 7, 224347},
	{"WIFELOVERS", 10, 224348},
	{"WBK", 3, 224349},
	{"PANGRAM", 7, 224350},
	{"PROVENCHER", 10, 224351},
	{"PINDOLOL", 8, 224352},
	{"BUCKTON", 7, 224353},
	{"ARKAN", 5, 224354},
	{"SENGERS", 7, 224355},
	{"OLDDKGRAY", 9, 224356},
	{"OHMYNEWS", 8, 224357},
	{"NONSTORE", 8, 224358},
	{"BKF", 3, 224359},
	{"SHINMUN", 7, 224360},
	{"FNIL", 4, 224361},
	{"UROLOGICALS", 11, 224362},
	{"APPROXIMA", 9, 224363},
	{"TRIMIX", 6, 224364},
	{"SPARX", 5, 224365},
	{"FHCRC", 5, 224366},
	{"REVELLE", 7, 224367},
	{"PEPTONE", 7, 224368},
	{"LIGERIE", 7, 224369},
	{"PROMOT", 6, 224370},
	{"ROIDS", 5, 224371},
	{"LVTTL", 5, 224372},
	{"UWG", 3, 224373},
	{"KIRSTENBOSCH", 12, 224374},
	{"BLOCKTYPE", 9, 224375},
	{"UNRACED", 7, 224376},
	{"PROVIRAL", 8, 224377},
	{"CYTOMAX", 7, 224378},
	{"PORTAS", 6, 224379},
	{"LIBDB", 5, 224380},
	{"TUUM", 4, 224381},
	{"SMACKOVER", 9, 224382},
	{"PINCHERS", 8, 224383},
	{"FERRETING", 9, 224384},
	{"DEHLI", 5, 224385},
	{"ATLETISMO", 9, 224386},
	{"MACALUSO", 8, 224387},
	{"CIRCULARID", 10, 224388},
	{"TYRRHENIAN", 10, 224389},
	{"MICRONAUTS", 10, 224390},
	{"NRICH", 5, 224391},
	{"MORAINES", 8, 224392},
	{"DORRIT", 6, 224393},
	{"UNFLAGGING", 10, 224394},
	{"SITEADVISOR", 11, 224395},
	{"JOCHUM", 6, 224396},
	{"ANNIVERSAY", 10, 224397},
	{"SUMBUCKETERRORS", 15, 224398},
	{"GEOR", 4, 224399},
	{"BUCKETERRORS", 12, 224400},
	{"ZOBA", 4, 224401},
	{"ZADU", 4, 224402},
	{"ZACL", 4, 224403},
	{"YMRI", 4, 224404},
	{"XONK", 4, 224405},
	{"WUPQ", 4, 224406},
	{"UZUR", 4, 224407},
	{"TDLO", 4, 224408},
	{"SPFE", 4, 224409},
	{"SDRK", 4, 224410},
	{"RDMM", 4, 224411},
	{"QICH", 4, 224412},
	{"POSD", 4, 224413},
	{"ORQI", 4, 224414},
	{"NSWU", 4, 224415},
	{"NKYN", 4, 224416},
	{"NGLP", 4, 224417},
	{"MSEU", 4, 224418},
	{"MRZE", 4, 224419},
	{"MDDE", 4, 224420},
	{"LROP", 4, 224421},
	{"LEBD", 4, 224422},
	{"LDEJ", 4, 224423},
	{"LBAZ", 4, 224424},
	{"KKEA", 4, 224425},
	{"INYK", 4, 224426},
	{"IMKR", 4, 224427},
	{"GUYV", 4, 224428},
	{"GLOL", 4, 224429},
	{"GIZZ", 4, 224430},
	{"GAOP", 4, 224431},
	{"FKRU", 4, 224432},
	{"FIXD", 4, 224433},
	{"FFSJ", 4, 224434},
	{"FAEC", 4, 224435},
	{"EXYP", 4, 224436},
	{"EUMJ", 4, 224437},
	{"ERCJ", 4, 224438},
	{"EPRT", 4, 224439},
	{"DTVE", 4, 224440},
	{"CEZE", 4, 224441},
	{"CAIU", 4, 224442},
	{"CAIK", 4, 224443},
	{"BVIC", 4, 224444},
	{"BJUP", 4, 224445},
	{"AXFU", 4, 224446},
	{"ABKA", 4, 224447},
	{"COMMUNITYGUIDE", 14, 224448},
	{"ISACTIVE", 8, 224449},
	{"WUR", 3, 224450},
	{"MACQUARRIE", 10, 224451},
	{"ADIPOSITY", 9, 224452},
	{"FOSSEY", 6, 224453},
	{"VECHTEN", 7, 224454},
	{"WELLEMENTS", 10, 224455},
	{"SAFEHARBOR", 10, 224456},
	{"GITANO", 6, 224457},
	{"ENGELSE", 7, 224458},
	{"CARNETS", 7, 224459},
	{"SUBITEMS", 8, 224460},
	{"KIFER", 5, 224461},
	{"LARYNGECTOMY", 12, 224462},
	{"LYUDMILA", 8, 224463},
	{"BBSM", 4, 224464},
	{"DOGWOODS", 8, 224465},
	{"CELES", 5, 224466},
	{"ADRODDIADAU", 11, 224467},
	{"ASTRINGENTS", 11, 224468},
	{"DFV", 3, 224469},
	{"CHUBBUCK", 8, 224470},
	{"WESTERVELT", 10, 224471},
	{"USAIR", 5, 224472},
	{"MSACIDEAS", 9, 224473},
	{"TOBACCONISTS", 12, 224474},
	{"COUSINEAU", 9, 224475},
	{"ADDYSGU", 7, 224476},
	{"COLLECTIVIZATION", 16, 224477},
	{"BLASKO", 6, 224478},
	{"BEHEALTHY", 9, 224479},
	{"PENDRIVE", 8, 224480},
	{"HARROWS", 7, 224481},
	{"POLITIE", 7, 224482},
	{"MIDIMAN", 7, 224483},
	{"CORROBORATIVE", 13, 224484},
	{"EDITBY", 6, 224485},
	{"ANUL", 4, 224486},
	{"PINSTRIPING", 11, 224487},
	{"PEDROSA", 7, 224488},
	{"ARTDOTCOM", 9, 224489},
	{"SITUATES", 8, 224490},
	{"RUFFO", 5, 224491},
	{"RECCOMENDATIONS", 15, 224492},
	{"MENKES", 6, 224493},
	{"BELSHAZZAR", 10, 224494},
	{"TRARY", 5, 224495},
	{"ROUGEMONT", 9, 224496},
	{"KUNDENBEWERTUNG", 15, 224497},
	{"XFP", 3, 224498},
	{"NEYMAN", 6, 224499},
	{"MAJELLA", 7, 224500},
	{"VOORDELIG", 9, 224501},
	{"HEALTHCONNECTIONS", 17, 224502},
	{"JANBERG", 7, 224503},
	{"LATUS", 5, 224504},
	{"DEME", 4, 224505},
	{"RUSNET", 6, 224506},
	{"ATSUGI", 6, 224507},
	{"EJACULATORY", 11, 224508},
	{"ODDMENTS", 8, 224509},
	{"YERMO", 5, 224510},
	{"COPERTO", 7, 224511},
	{"SLEATOR", 7, 224512},
	{"BOHAN", 5, 224513},
	{"YERS", 4, 224514},
	{"SMETS", 5, 224515},
	{"GALATA", 6, 224516},
	{"GODI", 4, 224517},
	{"MSNHOTMAIL", 10, 224518},
	{"LAPDOG", 6, 224519},
	{"LORENZI", 7, 224520},
	{"KALIFORNIA", 10, 224521},
	{"CONSPECTUS", 10, 224522},
	{"CASTELLINI", 10, 224523},
	{"AZZURRI", 7, 224524},
	{"PUNNING", 7, 224525},
	{"ENYCLOPEDIA", 11, 224526},
	{"DEPOR", 5, 224527},
	{"RENTALO", 7, 224528},
	{"NIETHER", 7, 224529},
	{"LUEBECK", 7, 224530},
	{"DIANI", 5, 224531},
	{"UBYSSEY", 7, 224532},
	{"PICTUREC", 8, 224533},
	{"DISPONIBILIDAD", 14, 224534},
	{"CROSSBREEDING", 13, 224535},
	{"ANTIMETABOLITES", 15, 224536},
	{"NONNY", 5, 224537},
	{"BROVAZ", 6, 224538},
	{"KOMME", 5, 224539},
	{"SWFS", 4, 224540},
	{"NRMT", 4, 224541},
	{"LOGICTOOLS", 10, 224542},
	{"HOROLOGICAL", 11, 224543},
	{"RTLT", 4, 224544},
	{"MCALEER", 7, 224545},
	{"LANTZVILLE", 10, 224546},
	{"HOSHIARPUR", 10, 224547},
	{"NICKPAGE", 8, 224548},
	{"NEWENT", 6, 224549},
	{"KORTEN", 6, 224550},
	{"CYBERCROP", 9, 224551},
	{"ADDICTINGGAMES", 14, 224552},
	{"ENDOMORPHISM", 12, 224553},
	{"REDWATER", 8, 224554},
	{"DAVIA", 5, 224555},
	{"RAINFALLS", 9, 224556},
	{"OCCULTATIONS", 12, 224557},
	{"KORAT", 5, 224558},
	{"HEGDE", 5, 224559},
	{"EDELMANN", 8, 224560},
	{"DEFLATORS", 9, 224561},
	{"CLAESSENS", 9, 224562},
	{"TUFA", 4, 224563},
	{"CARBONLIB", 9, 224564},
	{"ALLEON", 6, 224565},
	{"PRIVATISING", 11, 224566},
	{"ANNUUM", 6, 224567},
	{"NAMIE", 5, 224568},
	{"FRUVOUS", 7, 224569},
	{"PREDHEL", 7, 224570},
	{"DEPTARTMENT", 11, 224571},
	{"ERKAN", 5, 224572},
	{"PARKTON", 7, 224573},
	{"DLIBDIR", 7, 224574},
	{"GERBEN", 6, 224575},
	{"DISSOCIATES", 11, 224576},
	{"VIVAMUS", 7, 224577},
	{"MOVISE", 6, 224578},
	{"TLTP", 4, 224579},
	{"LEAKER", 6, 224580},
	{"ABSCONDED", 9, 224581},
	{"WORKSURFACE", 11, 224582},
	{"WAIHOPAI", 8, 224583},
	{"SANITARIAN", 10, 224584},
	{"NEWSHIPS", 8, 224585},
	{"BASEURL", 7, 224586},
	{"SLWK", 4, 224587},
	{"NECESARY", 8, 224588},
	{"NADOLOL", 7, 224589},
	{"ICMOTORS", 8, 224590},
	{"ERROTIC", 7, 224591},
	{"SFMOMA", 6, 224592},
	{"PORTSTEWART", 11, 224593},
	{"CONDELL", 7, 224594},
	{"STEINHAUER", 10, 224595},
	{"SEAVEY", 6, 224596},
	{"RIDPATH", 7, 224597},
	{"CHOONS", 6, 224598},
	{"SCOTTOLINE", 10, 224599},
	{"BOSSON", 6, 224600},
	{"BRYANTS", 7, 224601},
	{"PUCKERING", 9, 224602},
	{"WAWONA", 6, 224603},
	{"PERIODISMO", 10, 224604},
	{"MEMLETICS", 9, 224605},
	{"KOSSE", 5, 224606},
	{"ITSMWATCH", 9, 224607},
	{"FEMINISMS", 9, 224608},
	{"DODSWORTH", 9, 224609},
	{"SYMPATHISERS", 12, 224610},
	{"WOLVIX", 6, 224611},
	{"RUFFLING", 8, 224612},
	{"FINJAN", 6, 224613},
	{"PHOTOMICROGRAPH", 15, 224614},
	{"NEGAUNEE", 8, 224615},
	{"EUKARYOTE", 9, 224616},
	{"CONTENENTE", 10, 224617},
	{"TRAVELMAX", 9, 224618},
	{"SKOV", 4, 224619},
	{"MELBER", 6, 224620},
	{"BLOBBY", 6, 224621},
	{"BARZILAY", 8, 224622},
	{"LIBDBD", 6, 224623},
	{"SONOCO", 6, 224624},
	{"MINDWARE", 8, 224625},
	{"ZYPA", 4, 224626},
	{"YBIP", 4, 224627},
	{"XIMM", 4, 224628},
	{"WYNO", 4, 224629},
	{"WWLE", 4, 224630},
	{"WKMO", 4, 224631},
	{"WAPD", 4, 224632},
	{"UYAV", 4, 224633},
	{"UVIO", 4, 224634},
	{"UGUT", 4, 224635},
	{"UGBI", 4, 224636},
	{"UCAG", 4, 224637},
	{"TUNJ", 4, 224638},
	{"SZKA", 4, 224639},
	{"STMB", 4, 224640},
	{"RUOR", 4, 224641},
	{"RPAJ", 4, 224642},
	{"RIMK", 4, 224643},
	{"RGQU", 4, 224644},
	{"RBJR", 4, 224645},
	{"PPGO", 4, 224646},
	{"PNCA", 4, 224647},
	{"PHDW", 4, 224648},
	{"OWPM", 4, 224649},
	{"NWOB", 4, 224650},
	{"NKRS", 4, 224651},
	{"MRII", 4, 224652},
	{"MOBH", 4, 224653},
	{"MMNO", 4, 224654},
	{"MKUM", 4, 224655},
	{"MKAD", 4, 224656},
	{"MHZW", 4, 224657},
	{"MHEJ", 4, 224658},
	{"LUNU", 4, 224659},
	{"KDEI", 4, 224660},
	{"JUNJ", 4, 224661},
	{"JAXS", 4, 224662},
	{"IZSC", 4, 224663},
	{"HSDP", 4, 224664},
	{"HRBE", 4, 224665},
	{"GUOR", 4, 224666},
	{"GLYY", 4, 224667},
	{"GJEO", 4, 224668},
	{"GAUA", 4, 224669},
	{"GAPD", 4, 224670},
	{"FEMR", 4, 224671},
	{"EYPS", 4, 224672},
	{"ENLP", 4, 224673},
	{"EHDM", 4, 224674},
	{"ECFT", 4, 224675},
	{"EBMD", 4, 224676},
	{"DVSA", 4, 224677},
	{"CRRE", 4, 224678},
	{"CFST", 4, 224679},
	{"CDAU", 4, 224680},
	{"BPUR", 4, 224681},
	{"BNPR", 4, 224682},
	{"BIEV", 4, 224683},
	{"BCGO", 4, 224684},
	{"AXDU", 4, 224685},
	{"APBL", 4, 224686},
	{"AKUU", 4, 224687},
	{"AKHB", 4, 224688},
	{"ACBC", 4, 224689},
	{"GAWKING", 7, 224690},
	{"CGAT", 4, 224691},
	{"TREXLER", 7, 224692},
	{"HILAR", 5, 224693},
	{"PRISTINEWILDERNESS", 18, 224694},
	{"POPLOG", 6, 224695},
	{"NONPERFORMANCE", 14, 224696},
	{"BODYGLIDE", 9, 224697},
	{"WOHLERS", 7, 224698},
	{"LOCALTALK", 9, 224699},
	{"OFFICEWORLD", 11, 224700},
	{"MATHCAL", 7, 224701},
	{"DIORITE", 7, 224702},
	{"SPINPOINT", 9, 224703},
	{"FIELDTYPET", 10, 224704},
	{"ANACAPRI", 8, 224705},
	{"GALAXIAN", 8, 224706},
	{"AGAVI", 5, 224707},
	{"IFRIC", 5, 224708},
	{"GHERKIN", 7, 224709},
	{"DISABLEDPLUGINS", 15, 224710},
	{"ADEFOVIR", 8, 224711},
	{"QUIROS", 6, 224712},
	{"ICTV", 4, 224713},
	{"REQUIS", 6, 224714},
	{"PROBER", 6, 224715},
	{"MAUNSELL", 8, 224716},
	{"GAPKIDS", 7, 224717},
	{"BREALEY", 7, 224718},
	{"PERFORATUM", 10, 224719},
	{"HARDIHOOD", 9, 224720},
	{"ADVECTIVE", 9, 224721},
	{"ROTHCHILD", 9, 224722},
	{"GUNDAGAI", 8, 224723},
	{"GANKUTSUOU", 10, 224724},
	{"CRITICWATCH", 11, 224725},
	{"CRAIOVA", 7, 224726},
	{"COOLTECH", 8, 224727},
	{"RIVALDO", 7, 224728},
	{"BLAGDON", 7, 224729},
	{"WENDOUREE", 9, 224730},
	{"MULTIMED", 8, 224731},
	{"MANEESH", 7, 224732},
	{"PUROMYCIN", 9, 224733},
	{"ALDEA", 5, 224734},
	{"MAPVIEW", 7, 224735},
	{"FILMPJES", 8, 224736},
	{"DROSOPH", 7, 224737},
	{"VILAINE", 7, 224738},
	{"RETINYL", 7, 224739},
	{"NANDY", 5, 224740},
	{"ACICLOVIR", 9, 224741},
	{"SWISSMAR", 8, 224742},
	{"LICENS", 6, 224743},
	{"BROEKER", 7, 224744},
	{"CLIATH", 6, 224745},
	{"ROUSTABOUT", 10, 224746},
	{"NIGHTCRAWLERS", 13, 224747},
	{"FREEMANTLE", 10, 224748},
	{"ARTEDIAM", 8, 224749},
	{"USEGOOD", 7, 224750},
	{"POWERPOP", 8, 224751},
	{"KIRALY", 6, 224752},
	{"HYKSOS", 6, 224753},
	{"CAJOLING", 8, 224754},
	{"PORPHYROMONAS", 13, 224755},
	{"GPSMART", 7, 224756},
	{"TASSLE", 6, 224757},
	{"KRAUSER", 7, 224758},
	{"IRONMONGER", 10, 224759},
	{"LANDCOVER", 9, 224760},
	{"FLAMMABLES", 10, 224761},
	{"APAX", 4, 224762},
	{"HURAIRA", 7, 224763},
	{"ISLAMOFASCISM", 13, 224764},
	{"EINSENDEN", 9, 224765},
	{"CIPOLLA", 7, 224766},
	{"BOUGIE", 6, 224767},
	{"LONGTAIL", 8, 224768},
	{"FUNKFX", 6, 224769},
	{"FANTE", 5, 224770},
	{"FACIST", 6, 224771},
	{"DROE", 4, 224772},
	{"AIRCREWS", 8, 224773},
	{"TYPESCRIPTS", 11, 224774},
	{"RHYNO", 5, 224775},
	{"BEREZIN", 7, 224776},
	{"ACHETEZ", 7, 224777},
	{"SURIGAO", 7, 224778},
	{"SIPB", 4, 224779},
	{"GENERALISING", 12, 224780},
	{"DALVEY", 6, 224781},
	{"QUASHING", 8, 224782},
	{"EDDIEBAUER", 10, 224783},
	{"BIOELECTROMAGNETICS", 19, 224784},
	{"MUZNY", 5, 224785},
	{"LINEBERGER", 10, 224786},
	{"WEBMOTIF", 8, 224787},
	{"PASLEY", 6, 224788},
	{"BANDLER", 7, 224789},
	{"LEERBURG", 8, 224790},
	{"KIDNAPING", 9, 224791},
	{"SYNPLICITY", 10, 224792},
	{"DADDR", 5, 224793},
	{"TABLISHED", 9, 224794},
	{"ROUYN", 5, 224795},
	{"RESTARAUNTS", 11, 224796},
	{"OADM", 4, 224797},
	{"SILKEBORG", 9, 224798},
	{"SUPERDAT", 8, 224799},
	{"MEDKNOW", 7, 224800},
	{"EGLWYS", 6, 224801},
	{"THUC", 4, 224802},
	{"GREGORI", 7, 224803},
	{"COLEGE", 6, 224804},
	{"KTVU", 4, 224805},
	{"KAROKE", 6, 224806},
	{"CITYFEETLOCAL", 13, 224807},
	{"UNRISD", 6, 224808},
	{"GOVINDAN", 8, 224809},
	{"BAZZ", 4, 224810},
	{"OVERRIDEN", 9, 224811},
	{"CHERCHEURS", 10, 224812},
	{"UNPEELED", 8, 224813},
	{"GOODTIME", 8, 224814},
	{"DESEA", 5, 224815},
	{"NOWEB", 5, 224816},
	{"RECURSO", 7, 224817},
	{"GSAC", 4, 224818},
	{"CURIUS", 6, 224819},
	{"WHATMORE", 8, 224820},
	{"INTERE", 6, 224821},
	{"TERMINO", 7, 224822},
	{"MODCB", 5, 224823},
	{"IBUTTON", 7, 224824},
	{"HYALURONIDASE", 13, 224825},
	{"GALW", 4, 224826},
	{"CITIMORTGAGE", 12, 224827},
	{"TABLEWIDTH", 10, 224828},
	{"ALDICARB", 8, 224829},
	{"MISQUOTING", 10, 224830},
	{"GRUBMAN", 7, 224831},
	{"DELPHINIUMS", 11, 224832},
	{"USTICE", 6, 224833},
	{"SATIONS", 7, 224834},
	{"METACREATIONS", 13, 224835},
	{"HEGER", 5, 224836},
	{"ROBIC", 5, 224837},
	{"PROKEITAI", 9, 224838},
	{"MARTENSITIC", 11, 224839},
	{"GRILLI", 6, 224840},
	{"NEMATOLOGY", 10, 224841},
	{"KEAY", 4, 224842},
	{"ESSAYISTS", 9, 224843},
	{"OVERHOLT", 8, 224844},
	{"MADINAT", 7, 224845},
	{"LADWP", 5, 224846},
	{"SUCHET", 6, 224847},
	{"SIWIS", 5, 224848},
	{"ORIGINALY", 9, 224849},
	{"MNPASS", 6, 224850},
	{"ONSIDE", 6, 224851},
	{"MIKLI", 5, 224852},
	{"CALLETH", 7, 224853},
	{"BJM", 3, 224854},
	{"SAITOH", 6, 224855},
	{"TARTARUGA", 9, 224856},
	{"RECCOMMENDED", 12, 224857},
	{"MCELWEE", 7, 224858},
	{"GLADY", 5, 224859},
	{"DYTEK", 5, 224860},
	{"ANDL", 4, 224861},
	{"YMRJ", 4, 224862},
	{"YGNA", 4, 224863},
	{"YECK", 4, 224864},
	{"VSGE", 4, 224865},
	{"VOSK", 4, 224866},
	{"VBUS", 4, 224867},
	{"UZAI", 4, 224868},
	{"USDY", 4, 224869},
	{"UPDY", 4, 224870},
	{"UFIM", 4, 224871},
	{"UDIY", 4, 224872},
	{"TYIP", 4, 224873},
	{"TTQU", 4, 224874},
	{"TPUG", 4, 224875},
	{"TOKK", 4, 224876},
	{"TMFO", 4, 224877},
	{"SWEX", 4, 224878},
	{"SPDO", 4, 224879},
	{"SFYE", 4, 224880},
	{"SDCH", 4, 224881},
	{"RFFE", 4, 224882},
	{"POYA", 4, 224883},
	{"PMPL", 4, 224884},
	{"PIGP", 4, 224885},
	{"OWMS", 4, 224886},
	{"OLUE", 4, 224887},
	{"OLMJ", 4, 224888},
	{"OHLF", 4, 224889},
	{"NUXV", 4, 224890},
	{"NPSP", 4, 224891},
	{"MMTA", 4, 224892},
	{"MBNO", 4, 224893},
	{"LLNY", 4, 224894},
	{"LKSJ", 4, 224895},
	{"LCSO", 4, 224896},
	{"LAZQ", 4, 224897},
	{"KSHY", 4, 224898},
	{"KIGH", 4, 224899},
	{"IDOY", 4, 224900},
	{"ICTQ", 4, 224901},
	{"ICMD", 4, 224902},
	{"GUPK", 4, 224903},
	{"GUCI", 4, 224904},
	{"GOWU", 4, 224905},
	{"FSTW", 4, 224906},
	{"EQUU", 4, 224907},
	{"ECDB", 4, 224908},
	{"DQAT", 4, 224909},
	{"CMCO", 4, 224910},
	{"BICV", 4, 224911},
	{"APWR", 4, 224912},
	{"AMNM", 4, 224913},
	{"VIRACEPT", 8, 224914},
	{"BARBEQUED", 9, 224915},
	{"KENNAMETAL", 10, 224916},
	{"GREENNESS", 9, 224917},
	{"MOVY", 4, 224918},
	{"BEDSTRAW", 8, 224919},
	{"RECUERDOS", 9, 224920},
	{"PSYCHICALLY", 11, 224921},
	{"PREAMBLES", 9, 224922},
	{"GROUNDCOVERS", 12, 224923},
	{"STRATEGAETHAU", 13, 224924},
	{"PENSON", 6, 224925},
	{"GALERIEN", 8, 224926},
	{"CICC", 4, 224927},
	{"GIOP", 4, 224928},
	{"BEYONDUNREAL", 12, 224929},
	{"SCHODACK", 8, 224930},
	{"CENTENARIO", 10, 224931},
	{"RECRIMINATION", 13, 224932},
	{"PRESE", 5, 224933},
	{"LIBCOMMONS", 10, 224934},
	{"HASSAM", 6, 224935},
	{"CYPHERPUNKS", 11, 224936},
	{"CINDERBLOCK", 11, 224937},
	{"MISBRANDED", 10, 224938},
	{"GOFYNION", 8, 224939},
	{"AHRIMAN", 7, 224940},
	{"VENKMAN", 7, 224941},
	{"FRANKI", 6, 224942},
	{"ANTARTIC", 8, 224943},
	{"PHYSIKALISCHES", 14, 224944},
	{"BASKED", 6, 224945},
	{"VARNUM", 6, 224946},
	{"MARATHA", 7, 224947},
	{"REVERBERATES", 12, 224948},
	{"READBACK", 8, 224949},
	{"BENKO", 5, 224950},
	{"OSTERLEY", 8, 224951},
	{"XHOST", 5, 224952},
	{"THATCHING", 9, 224953},
	{"KALEDEN", 7, 224954},
	{"DIGITAAL", 8, 224955},
	{"REASSIGNMENTS", 13, 224956},
	{"SLPA", 4, 224957},
	{"NIGHTIES", 8, 224958},
	{"EMBARRASSMENTS", 14, 224959},
	{"SPHENOID", 8, 224960},
	{"ELMOS", 5, 224961},
	{"THYROTOXICOSIS", 14, 224962},
	{"DLU", 3, 224963},
	{"AUREOLE", 7, 224964},
	{"SOAPCLIENT", 10, 224965},
	{"MUZEUM", 6, 224966},
	{"TELECEL", 7, 224967},
	{"NAYLAND", 7, 224968},
	{"ATTALLA", 7, 224969},
	{"ULOG", 4, 224970},
	{"DISGUSTS", 8, 224971},
	{"EMULATORE", 9, 224972},
	{"LUNDBECK", 8, 224973},
	{"FBX", 3, 224974},
	{"BANKRUPTING", 11, 224975},
	{"DEHAAN", 6, 224976},
	{"NOMBREUSES", 10, 224977},
	{"KONZ", 4, 224978},
	{"KASAHARA", 8, 224979},
	{"INNBUNDET", 9, 224980},
	{"SWORDSEARCHER", 13, 224981},
	{"MACCARTHY", 9, 224982},
	{"MABANK", 6, 224983},
	{"INTERNETINTERNET", 16, 224984},
	{"HAKEN", 5, 224985},
	{"LARAINE", 7, 224986},
	{"VHCS", 4, 224987},
	{"PEDIDOS", 7, 224988},
	{"LODGINGAIRPORTS", 15, 224989},
	{"KIDWELLY", 8, 224990},
	{"RHYMNEY", 7, 224991},
	{"INCRA", 5, 224992},
	{"TIDEN", 5, 224993},
	{"ERGASIAS", 8, 224994},
	{"NEWMAC", 6, 224995},
	{"CAMPIN", 6, 224996},
	{"MEDIATRIX", 9, 224997},
	{"HAYSBERT", 8, 224998},
	{"PERSONELL", 9, 224999},
	{"FERMAGH", 7, 225000},
	{"PLEOMAX", 7, 225001},
	{"WHATPC", 6, 225002},
	{"EYEHATEGOD", 10, 225003},
	{"TRBRDRB", 7, 225004},
	{"SLEDGING", 8, 225005},
	{"PLATIAL", 7, 225006},
	{"MURCOF", 6, 225007},
	{"GRECE", 5, 225008},
	{"FISTULAE", 8, 225009},
	{"CAPCO", 5, 225010},
	{"HAJEK", 5, 225011},
	{"EMEND", 5, 225012},
	{"IGITUR", 6, 225013},
	{"CLOACA", 6, 225014},
	{"PIMM", 4, 225015},
	{"KELNER", 6, 225016},
	{"IRIDESCENCE", 11, 225017},
	{"FUSTER", 6, 225018},
	{"OBATA", 5, 225019},
	{"MOFFIT", 6, 225020},
	{"SHUTT", 5, 225021},
	{"JAIRO", 5, 225022},
	{"MARZI", 5, 225023},
	{"VASSILY", 7, 225024},
	{"PALLISTER", 9, 225025},
	{"BIZNIZ", 6, 225026},
	{"TOONZ", 5, 225027},
	{"HAMBRICK", 8, 225028},
	{"UNSANCTIONED", 12, 225029},
	{"ZIPRASIDONE", 11, 225030},
	{"WWWG", 4, 225031},
	{"CHEATBOOK", 9, 225032},
	{"TRUNCATULA", 10, 225033},
	{"GOLPE", 5, 225034},
	{"PHYSOSTIGMINE", 13, 225035},
	{"TENDERLOINS", 11, 225036},
	{"SILVO", 5, 225037},
	{"ROSSFORD", 8, 225038},
	{"COGNISANCE", 10, 225039},
	{"MAJEUR", 6, 225040},
	{"DARGAVILLE", 10, 225041},
	{"MACEACHERN", 10, 225042},
	{"FOOTMEN", 7, 225043},
	{"CULTURALISM", 11, 225044},
	{"URBANITES", 9, 225045},
	{"MCMORAN", 7, 225046},
	{"TWERE", 5, 225047},
	{"MANNINGTREE", 11, 225048},
	{"IDENTIFIABILITY", 15, 225049},
	{"GULBRANDSEN", 11, 225050},
	{"DENENBERG", 9, 225051},
	{"PENRY", 5, 225052},
	{"RECOILS", 7, 225053},
	{"CORON", 5, 225054},
	{"LEAVY", 5, 225055},
	{"EXCEPTS", 7, 225056},
	{"DIVERSOS", 8, 225057},
	{"COOKSVILLE", 10, 225058},
	{"TIKHONOV", 8, 225059},
	{"PROMULGATES", 11, 225060},
	{"SOFTPICKS", 9, 225061},
	{"AILRINES", 8, 225062},
	{"ZASUKHIN", 8, 225063},
	{"DEEPING", 7, 225064},
	{"CHEATINGDOME", 12, 225065},
	{"VIRASORO", 8, 225066},
	{"PLAYWORK", 8, 225067},
	{"COLLINGTON", 10, 225068},
	{"CERULOPLASMIN", 13, 225069},
	{"YMCO", 4, 225070},
	{"YKNA", 4, 225071},
	{"WWFW", 4, 225072},
	{"WLBY", 4, 225073},
	{"WDYA", 4, 225074},
	{"VYEA", 4, 225075},
	{"VBOR", 4, 225076},
	{"UZAL", 4, 225077},
	{"URUV", 4, 225078},
	{"TVEJ", 4, 225079},
	{"TSXC", 4, 225080},
	{"TEKC", 4, 225081},
	{"SRUE", 4, 225082},
	{"SPXI", 4, 225083},
	{"RSPD", 4, 225084},
	{"RBUE", 4, 225085},
	{"QMAN", 4, 225086},
	{"PXIN", 4, 225087},
	{"PAJU", 4, 225088},
	{"OWAX", 4, 225089},
	{"NMOP", 4, 225090},
	{"NGFM", 4, 225091},
	{"MODC", 4, 225092},
	{"MEDX", 4, 225093},
	{"MBEO", 4, 225094},
	{"LZWA", 4, 225095},
	{"LOXE", 4, 225096},
	{"KKES", 4, 225097},
	{"KAGL", 4, 225098},
	{"IFTJ", 4, 225099},
	{"HVIK", 4, 225100},
	{"HSGU", 4, 225101},
	{"HPDE", 4, 225102},
	{"HIUF", 4, 225103},
	{"HAPK", 4, 225104},
	{"FFYN", 4, 225105},
	{"EVCI", 4, 225106},
	{"EPML", 4, 225107},
	{"DOHW", 4, 225108},
	{"DIGW", 4, 225109},
	{"CRHE", 4, 225110},
	{"CODL", 4, 225111},
	{"BTBA", 4, 225112},
	{"AVPA", 4, 225113},
	{"ASQB", 4, 225114},
	{"ALWY", 4, 225115},
	{"MORUS", 5, 225116},
	{"CARENCRO", 8, 225117},
	{"XWINDOW", 7, 225118},
	{"PARKGATE", 8, 225119},
	{"GUELL", 5, 225120},
	{"DOBBIE", 6, 225121},
	{"AIRILNES", 8, 225122},
	{"TROUSERSUITS", 12, 225123},
	{"ETIME", 5, 225124},
	{"AKCESORIA", 9, 225125},
	{"MUTOH", 5, 225126},
	{"JCOM", 4, 225127},
	{"ASSANTE", 7, 225128},
	{"SWISSMEMORY", 11, 225129},
	{"SECURITYLEVEL", 13, 225130},
	{"PWV", 3, 225131},
	{"DOLLEY", 6, 225132},
	{"CAUCA", 5, 225133},
	{"ROLLINSFORD", 11, 225134},
	{"OPENLINK", 8, 225135},
	{"KEESE", 5, 225136},
	{"GRAVINA", 7, 225137},
	{"RACECARS", 8, 225138},
	{"PALMDOC", 7, 225139},
	{"FLYTE", 5, 225140},
	{"LIBERT", 6, 225141},
	{"INTERCAL", 8, 225142},
	{"ALPHACRAZESHOPPING", 18, 225143},
	{"VRL", 3, 225144},
	{"KERTESZ", 7, 225145},
	{"ESPAOL", 6, 225146},
	{"BALLPLAYER", 10, 225147},
	{"KISHOR", 6, 225148},
	{"ENOURMOUS", 9, 225149},
	{"TANGS", 5, 225150},
	{"QUADRUPEDS", 10, 225151},
	{"COMMNET", 7, 225152},
	{"TEULU", 5, 225153},
	{"KIDSTON", 7, 225154},
	{"ZOOROPA", 7, 225155},
	{"HETLAND", 7, 225156},
	{"INSTALACIONES", 13, 225157},
	{"GRUTTER", 7, 225158},
	{"MAAX", 4, 225159},
	{"ERCS", 4, 225160},
	{"HUFFAKER", 8, 225161},
	{"DISMORE", 7, 225162},
	{"ONEPAGES", 8, 225163},
	{"LLEN", 4, 225164},
	{"KLMS", 4, 225165},
	{"BURNETH", 7, 225166},
	{"MANZINI", 7, 225167},
	{"LOIR", 4, 225168},
	{"SEABEES", 7, 225169},
	{"TOGOLESE", 8, 225170},
	{"PROPIETARIOS", 12, 225171},
	{"LEVOLOR", 7, 225172},
	{"GOODINGS", 8, 225173},
	{"ESPONSE", 7, 225174},
	{"OLYPHANT", 8, 225175},
	{"ASCALON", 7, 225176},
	{"WEBBOOK", 7, 225177},
	{"BLAQUE", 6, 225178},
	{"DAUS", 4, 225179},
	{"CULTY", 5, 225180},
	{"TIAHRT", 6, 225181},
	{"SFPS", 4, 225182},
	{"FERROFLUID", 10, 225183},
	{"EVALUACIONES", 12, 225184},
	{"MANOTICK", 8, 225185},
	{"FELGI", 5, 225186},
	{"BRAMER", 6, 225187},
	{"AUTOANTIGENS", 12, 225188},
	{"NURSEDI", 7, 225189},
	{"MONTAYOIM", 9, 225190},
	{"NEOUSLY", 7, 225191},
	{"NACHA", 5, 225192},
	{"EMBOUCHURE", 10, 225193},
	{"SUONO", 5, 225194},
	{"SENASTE", 7, 225195},
	{"RIGIDA", 6, 225196},
	{"REPRESENTANTES", 14, 225197},
	{"BEWAILED", 8, 225198},
	{"ARMATURES", 9, 225199},
	{"VERTLINE", 8, 225200},
	{"STARHOTEL", 9, 225201},
	{"LOESSER", 7, 225202},
	{"KYON", 4, 225203},
	{"CLUSION", 7, 225204},
	{"SORBY", 5, 225205},
	{"MORPURGO", 8, 225206},
	{"DELINSKY", 8, 225207},
	{"BUTTONBOOGIE", 12, 225208},
	{"AIRLINED", 8, 225209},
	{"DERF", 4, 225210},
	{"STRATHPINE", 10, 225211},
	{"JEFFERSONTOWN", 13, 225212},
	{"EVENTOBJECT", 11, 225213},
	{"CCSI", 4, 225214},
	{"NYER", 4, 225215},
	{"TRANSPOSITIONS", 14, 225216},
	{"EXTERNOS", 8, 225217},
	{"WWWJ", 4, 225218},
	{"NATHANS", 7, 225219},
	{"GOBOS", 5, 225220},
	{"SERANGOON", 9, 225221},
	{"BLACKBOOK", 9, 225222},
	{"PZL", 3, 225223},
	{"NAIMAN", 6, 225224},
	{"LEVAMISOLE", 10, 225225},
	{"DULT", 4, 225226},
	{"CLAIRVAUX", 9, 225227},
	{"ERLENMEYER", 10, 225228},
	{"CHARTERIS", 9, 225229},
	{"JWB", 3, 225230},
	{"HYPERDIC", 8, 225231},
	{"TRBRDRR", 7, 225232},
	{"MORCEAUX", 8, 225233},
	{"ROUGHENED", 9, 225234},
	{"LGUS", 4, 225235},
	{"GOLFBALL", 8, 225236},
	{"BOOF", 4, 225237},
	{"SUNCREST", 8, 225238},
	{"KELSALL", 7, 225239},
	{"LEGGING", 7, 225240},
	{"GEWOON", 6, 225241},
	{"ULTRASONOGRAPHIC", 16, 225242},
	{"SOFTWOODS", 9, 225243},
	{"MASSHEALTH", 10, 225244},
	{"TROPI", 5, 225245},
	{"KELLAWAY", 8, 225246},
	{"GORGING", 7, 225247},
	{"UMAT", 4, 225248},
	{"SANDBARS", 8, 225249},
	{"KITCHENALIA", 11, 225250},
	{"ARHUS", 5, 225251},
	{"DECRYPTOR", 9, 225252},
	{"CAHORS", 6, 225253},
	{"SPALLING", 8, 225254},
	{"LOGOBEE", 7, 225255},
	{"CHINNOR", 7, 225256},
	{"BISACODYL", 9, 225257},
	{"KNAUS", 5, 225258},
	{"FIREPITS", 8, 225259},
	{"EPOPLE", 6, 225260},
	{"CHIHUAHUAN", 10, 225261},
	{"TURNOVO", 7, 225262},
	{"VANADATE", 8, 225263},
	{"KOBY", 4, 225264},
	{"IMPIANTI", 8, 225265},
	{"DIAMONDSAFE", 11, 225266},
	{"ADVT", 4, 225267},
	{"THINKETH", 8, 225268},
	{"WIERSMA", 7, 225269},
	{"TECHMARK", 8, 225270},
	{"EVOLUTIONISM", 12, 225271},
	{"GUIMOND", 7, 225272},
	{"THOUGHTLESSLY", 13, 225273},
	{"SYMBOLIST", 9, 225274},
	{"MISSENDEN", 9, 225275},
	{"PYROMANIAC", 10, 225276},
	{"HOPMAN", 6, 225277},
	{"LIIGA", 5, 225278},
	{"GAYLOR", 6, 225279},
	{"CISTICOLA", 9, 225280},
	{"PULSIPHER", 9, 225281},
	{"BAIXO", 5, 225282},
	{"EGYPTOLOGIST", 12, 225283},
	{"TRODE", 5, 225284},
	{"TESSLER", 7, 225285},
	{"DIPEPTIDASE", 11, 225286},
	{"CHRESTUS", 8, 225287},
	{"CHOPE", 5, 225288},
	{"CHIOU", 5, 225289},
	{"SPINOLOGISTS", 12, 225290},
	{"COMPUCASE", 9, 225291},
	{"MTWTHF", 6, 225292},
	{"MARIMEKKO", 9, 225293},
	{"APACHECON", 9, 225294},
	{"VANDALIZE", 9, 225295},
	{"POUNCING", 8, 225296},
	{"LUMPEN", 6, 225297},
	{"INNISFIL", 8, 225298},
	{"ENGELMAN", 8, 225299},
	{"DALLWITZ", 8, 225300},
	{"TICKETEXCHANGE", 14, 225301},
	{"GELERNTER", 9, 225302},
	{"DEPUTE", 6, 225303},
	{"SOLUTI", 6, 225304},
	{"KATHYISTHESHIZ", 14, 225305},
	{"OKUR", 4, 225306},
	{"TRBRDRL", 7, 225307},
	{"CEDEFOP", 7, 225308},
	{"PLASTICINE", 10, 225309},
	{"BESTEHT", 7, 225310},
	{"RETURNE", 7, 225311},
	{"EASYNOTE", 8, 225312},
	{"GIESEN", 6, 225313},
	{"KRONENBERG", 10, 225314},
	{"ZOLD", 4, 225315},
	{"YMSW", 4, 225316},
	{"YDYL", 4, 225317},
	{"XTBL", 4, 225318},
	{"WOIF", 4, 225319},
	{"WNWV", 4, 225320},
	{"UODS", 4, 225321},
	{"UCIP", 4, 225322},
	{"UCIG", 4, 225323},
	{"UBPI", 4, 225324},
	{"TKOF", 4, 225325},
	{"RVAJ", 4, 225326},
	{"QAFG", 4, 225327},
	{"OPUZ", 4, 225328},
	{"OMVP", 4, 225329},
	{"OFLH", 4, 225330},
	{"NTWW", 4, 225331},
	{"MSSQ", 4, 225332},
	{"LMVO", 4, 225333},
	{"LEVW", 4, 225334},
	{"KOTK", 4, 225335},
	{"KIDJ", 4, 225336},
	{"IOCM", 4, 225337},
	{"HUAU", 4, 225338},
	{"HOPY", 4, 225339},
	{"HDMO", 4, 225340},
	{"HAUW", 4, 225341},
	{"FTJE", 4, 225342},
	{"FGTR", 4, 225343},
	{"ELAQ", 4, 225344},
	{"EKMN", 4, 225345},
	{"EGGG", 4, 225346},
	{"EDXM", 4, 225347},
	{"EBTY", 4, 225348},
	{"EBGR", 4, 225349},
	{"DUBN", 4, 225350},
	{"DRPI", 4, 225351},
	{"DNDE", 4, 225352},
	{"CYRS", 4, 225353},
	{"CUAU", 4, 225354},
	{"CHKY", 4, 225355},
	{"BOUZ", 4, 225356},
	{"BMSS", 4, 225357},
	{"BGER", 4, 225358},
	{"AWVO", 4, 225359},
	{"AWJE", 4, 225360},
	{"AUNV", 4, 225361},
	{"AUNK", 4, 225362},
	{"APMT", 4, 225363},
	{"AGYR", 4, 225364},
	{"AFYD", 4, 225365},
	{"BRAINTRUST", 10, 225366},
	{"AUSMUS", 6, 225367},
	{"VIVIENDAS", 9, 225368},
	{"IDILOGIC", 8, 225369},
	{"SAVOURS", 7, 225370},
	{"OURENSE", 7, 225371},
	{"MUSKS", 5, 225372},
	{"LEISTON", 7, 225373},
	{"KEYFILE", 7, 225374},
	{"SHIRANUI", 8, 225375},
	{"POINTSIZE", 9, 225376},
	{"PAGODE", 6, 225377},
	{"METATHESIS", 10, 225378},
	{"SUNSAIL", 7, 225379},
	{"SNAKEHEAD", 9, 225380},
	{"MANSARD", 7, 225381},
	{"BADCREDIT", 9, 225382},
	{"WILLUNGA", 8, 225383},
	{"PHOTOCHEM", 9, 225384},
	{"DEMAGOGUERY", 11, 225385},
	{"ARTFORMS", 8, 225386},
	{"SIMILKAMEEN", 11, 225387},
	{"PERIODONTIST", 12, 225388},
	{"GARANTIS", 8, 225389},
	{"HUNTINGTIN", 10, 225390},
	{"BASELOAD", 8, 225391},
	{"VOLUNTARIOS", 11, 225392},
	{"SUTOR", 5, 225393},
	{"PTER", 4, 225394},
	{"KYALAMI", 7, 225395},
	{"BUCKO", 5, 225396},
	{"TANSLEY", 7, 225397},
	{"ATTWELL", 7, 225398},
	{"TESKE", 5, 225399},
	{"CONCORSI", 8, 225400},
	{"UNICE", 5, 225401},
	{"CALLERY", 7, 225402},
	{"RBOC", 4, 225403},
	{"MULDROW", 7, 225404},
	{"KUZMA", 5, 225405},
	{"HARDINSBURG", 11, 225406},
	{"FORCEMENT", 9, 225407},
	{"SHAEFFER", 8, 225408},
	{"GOGLES", 6, 225409},
	{"WELLFIELD", 9, 225410},
	{"WAJDA", 5, 225411},
	{"BULWARKS", 8, 225412},
	{"VOESTALPINE", 11, 225413},
	{"THOTLOCALACTIONS", 16, 225414},
	{"FILIPPINI", 9, 225415},
	{"SIMONCOX", 8, 225416},
	{"ROOTSCHAT", 9, 225417},
	{"KUTNER", 6, 225418},
	{"CINOAN", 6, 225419},
	{"BIOGRAPH", 8, 225420},
	{"ARAMITH", 7, 225421},
	{"OPENWETWARE", 11, 225422},
	{"BLYE", 4, 225423},
	{"TARIFFED", 8, 225424},
	{"MASIMO", 6, 225425},
	{"AVATARIST", 9, 225426},
	{"YAHOOGRO", 8, 225427},
	{"LEVERTON", 8, 225428},
	{"LEDGEWOOD", 9, 225429},
	{"SKIVE", 5, 225430},
	{"POLKINGHORNE", 12, 225431},
	{"MOCKAPETRIS", 11, 225432},
	{"PLANIT", 6, 225433},
	{"LUBERON", 7, 225434},
	{"CLODS", 5, 225435},
	{"ARTEX", 5, 225436},
	{"HAVDALAH", 8, 225437},
	{"AIRLNIES", 8, 225438},
	{"SOSPENDERS", 10, 225439},
	{"ICEQ", 4, 225440},
	{"ARFEROL", 7, 225441},
	{"WARANTY", 7, 225442},
	{"FORTHRIGHTLY", 12, 225443},
	{"BLAGG", 5, 225444},
	{"BSED", 4, 225445},
	{"TRBRDRT", 7, 225446},
	{"BOXALL", 6, 225447},
	{"HEXYL", 5, 225448},
	{"MAORIS", 6, 225449},
	{"MANTLED", 7, 225450},
	{"FORMALISING", 11, 225451},
	{"CLSA", 4, 225452},
	{"SHINNECOCK", 10, 225453},
	{"ENCOURAGEMENTS", 14, 225454},
	{"AISLAMIENTO", 11, 225455},
	{"WHACKER", 7, 225456},
	{"GLAW", 4, 225457},
	{"RMAS", 4, 225458},
	{"WAIKANAE", 8, 225459},
	{"ORTGAGE", 7, 225460},
	{"DISSIMILARITIES", 15, 225461},
	{"CONFORMALLY", 11, 225462},
	{"CEPTOR", 6, 225463},
	{"UNFAITHFULNESS", 14, 225464},
	{"FACTORIZED", 10, 225465},
	{"LOWCHEN", 7, 225466},
	{"GLOBALISE", 9, 225467},
	{"VALERIANA", 9, 225468},
	{"UHURA", 5, 225469},
	{"SKEPTICALLY", 11, 225470},
	{"SHEPWAY", 7, 225471},
	{"FENIAN", 6, 225472},
	{"BICOL", 5, 225473},
	{"ICONPACKAGER", 12, 225474},
	{"ZANAMIVIR", 9, 225475},
	{"PERMISSABLE", 11, 225476},
	{"PROLEX", 6, 225477},
	{"FACETTED", 8, 225478},
	{"DISORIENT", 9, 225479},
	{"ANANSIE", 7, 225480},
	{"VERHEUGEN", 9, 225481},
	{"PORH", 4, 225482},
	{"CUXHAVEN", 8, 225483},
	{"CULBERT", 7, 225484},
	{"ULED", 4, 225485},
	{"SCIENE", 6, 225486},
	{"MADRYN", 6, 225487},
	{"ILLITE", 6, 225488},
	{"MEZZOTINT", 9, 225489},
	{"CLANGERS", 8, 225490},
	{"OVERPOWERS", 10, 225491},
	{"WDIFF", 5, 225492},
	{"GAMR", 4, 225493},
	{"DOBRE", 5, 225494},
	{"CORNETTE", 8, 225495},
	{"COMPTABLE", 9, 225496},
	{"SUTERA", 6, 225497},
	{"STARLESS", 8, 225498},
	{"COURGETTE", 9, 225499},
	{"NOESIS", 6, 225500},
	{"BOTEN", 5, 225501},
	{"SCHRIEVER", 9, 225502},
	{"PAPADAKIS", 9, 225503},
	{"COBRAM", 6, 225504},
	{"VANUIT", 6, 225505},
	{"UNLOADER", 8, 225506},
	{"THETIC", 6, 225507},
	{"EATETH", 6, 225508},
	{"BEDRAGGLED", 10, 225509},
	{"CHIFFRES", 8, 225510},
	{"CARINAE", 7, 225511},
	{"SPRADLEY", 8, 225512},
	{"HAMAMELIS", 9, 225513},
	{"UCW", 3, 225514},
	{"SAHRA", 5, 225515},
	{"PINERO", 6, 225516},
	{"INNOPAC", 7, 225517},
	{"LEAKTAG", 7, 225518},
	{"READIER", 7, 225519},
	{"CRYSTALBRITE", 12, 225520},
	{"MERCAPTOPURINE", 14, 225521},
	{"INERADICABLE", 12, 225522},
	{"HANDOFFS", 8, 225523},
	{"OLIVAS", 6, 225524},
	{"FLOES", 5, 225525},
	{"RONGJI", 6, 225526},
	{"GHEORGHIU", 9, 225527},
	{"VTKINDENT", 9, 225528},
	{"STEADYING", 9, 225529},
	{"ELETTER", 7, 225530},
	{"GLUCOTROL", 9, 225531},
	{"FURAZOLIDONE", 12, 225532},
	{"VSNPRINTF", 9, 225533},
	{"IPUTILS", 7, 225534},
	{"RAMORUM", 7, 225535},
	{"OKIES", 5, 225536},
	{"NYDIA", 5, 225537},
	{"ERODIBLE", 8, 225538},
	{"BRAZILIA", 8, 225539},
	{"KENTE", 5, 225540},
	{"INNLEGG", 7, 225541},
	{"WEIER", 5, 225542},
	{"ELINK", 5, 225543},
	{"ZPUT", 4, 225544},
	{"XATL", 4, 225545},
	{"WNZO", 4, 225546},
	{"UGHX", 4, 225547},
	{"TVTU", 4, 225548},
	{"TTUK", 4, 225549},
	{"TFWA", 4, 225550},
	{"TBCO", 4, 225551},
	{"SURW", 4, 225552},
	{"SUKS", 4, 225553},
	{"RYNR", 4, 225554},
	{"RPOA", 4, 225555},
	{"RICQ", 4, 225556},
	{"RBIU", 4, 225557},
	{"RAUW", 4, 225558},
	{"QBCH", 4, 225559},
	{"OVCI", 4, 225560},
	{"OKUO", 4, 225561},
	{"ODTV", 4, 225562},
	{"MUCA", 4, 225563},
	{"MSYL", 4, 225564},
	{"LUGM", 4, 225565},
	{"LKEW", 4, 225566},
	{"LBSP", 4, 225567},
	{"KOFZ", 4, 225568},
	{"KHAF", 4, 225569},
	{"JYAS", 4, 225570},
	{"JUCH", 4, 225571},
	{"HNPU", 4, 225572},
	{"HFAW", 4, 225573},
	{"HEGV", 4, 225574},
	{"HDCH", 4, 225575},
	{"GMBU", 4, 225576},
	{"GHIU", 4, 225577},
	{"FURH", 4, 225578},
	{"FIXY", 4, 225579},
	{"FGAG", 4, 225580},
	{"EUAL", 4, 225581},
	{"EGHU", 4, 225582},
	{"EDGD", 4, 225583},
	{"ECGR", 4, 225584},
	{"DUKH", 4, 225585},
	{"DMCO", 4, 225586},
	{"DCTE", 4, 225587},
	{"BUCE", 4, 225588},
	{"ASUV", 4, 225589},
	{"ASGW", 4, 225590},
	{"AMYJ", 4, 225591},
	{"AFSR", 4, 225592},
	{"KYDEX", 5, 225593},
	{"BRUEL", 5, 225594},
	{"FONTANELLE", 10, 225595},
	{"FLACO", 5, 225596},
	{"TIMPANOGOS", 10, 225597},
	{"AWSAT", 5, 225598},
	{"GEESH", 5, 225599},
	{"AUTOMATICITY", 12, 225600},
	{"SIMULTA", 7, 225601},
	{"RETURNCODE", 10, 225602},
	{"BUSWELL", 7, 225603},
	{"SHAREPRICE", 10, 225604},
	{"ICESCR", 6, 225605},
	{"CLARKIA", 7, 225606},
	{"CAREYTC", 7, 225607},
	{"PLENARIES", 9, 225608},
	{"CATSEYE", 7, 225609},
	{"PIELKE", 6, 225610},
	{"ANTILL", 6, 225611},
	{"ADJOURNMENTS", 12, 225612},
	{"UNHOOKED", 8, 225613},
	{"PPW", 3, 225614},
	{"ANENCEPHALY", 11, 225615},
	{"UNIMAGINABLY", 12, 225616},
	{"UDK", 3, 225617},
	{"JINGHUI", 7, 225618},
	{"DUKESTT", 7, 225619},
	{"BULLEY", 6, 225620},
	{"COWERED", 7, 225621},
	{"SHYING", 6, 225622},
	{"MONSEIGNEUR", 11, 225623},
	{"CARABINIERI", 11, 225624},
	{"FILMFARE", 8, 225625},
	{"DEFINITLEY", 10, 225626},
	{"SINDI", 5, 225627},
	{"PATMAN", 6, 225628},
	{"PROFESSIONELLE", 14, 225629},
	{"MAPSMALL", 8, 225630},
	{"SECRETAGOGUE", 12, 225631},
	{"LRIC", 4, 225632},
	{"KOIVISTO", 8, 225633},
	{"SUPERNET", 8, 225634},
	{"CITYRAIL", 8, 225635},
	{"CASTERTON", 9, 225636},
	{"BLACKMOOR", 9, 225637},
	{"GROTTE", 6, 225638},
	{"SCIENTISM", 9, 225639},
	{"RAVENOUSLY", 10, 225640},
	{"HIPOTECA", 8, 225641},
	{"GOITRE", 6, 225642},
	{"VERSCHILLENDE", 13, 225643},
	{"THREATSENTRY", 12, 225644},
	{"LIPAN", 5, 225645},
	{"LANGEBAAN", 9, 225646},
	{"AVONMOUTH", 9, 225647},
	{"PEAKER", 6, 225648},
	{"AMAC", 4, 225649},
	{"YDIM", 4, 225650},
	{"BLUEYEZ", 7, 225651},
	{"WORDPROCESSING", 14, 225652},
	{"SANDWHICH", 9, 225653},
	{"USSERY", 6, 225654},
	{"PLUIE", 5, 225655},
	{"LICIA", 5, 225656},
	{"CITEMENT", 8, 225657},
	{"HABERMANN", 9, 225658},
	{"KREMMLING", 9, 225659},
	{"DEFIC", 5, 225660},
	{"THRESHHOLD", 10, 225661},
	{"TEMPORADA", 9, 225662},
	{"MEASURMENTS", 11, 225663},
	{"GROPIUS", 7, 225664},
	{"BOGL", 4, 225665},
	{"RAZORFISH", 9, 225666},
	{"CREAL", 5, 225667},
	{"ZERBE", 5, 225668},
	{"JAXEN", 5, 225669},
	{"PLUTOCRACY", 10, 225670},
	{"DISPASSIONATELY", 15, 225671},
	{"SUNDEW", 6, 225672},
	{"METABOLOMICS", 12, 225673},
	{"DOMICILIO", 9, 225674},
	{"BROOKLAWN", 9, 225675},
	{"UNREV", 5, 225676},
	{"TECHARENA", 9, 225677},
	{"RENGA", 5, 225678},
	{"PARANEOPLASTIC", 14, 225679},
	{"MIRAR", 5, 225680},
	{"ANGLICIZED", 10, 225681},
	{"WEIGHBRIDGE", 11, 225682},
	{"TOMATILLO", 9, 225683},
	{"SCSC", 4, 225684},
	{"IMPROVISERS", 11, 225685},
	{"HURSTBOURNE", 11, 225686},
	{"TRAKKER", 7, 225687},
	{"LLYWELYN", 8, 225688},
	{"WEBCRAWLERS", 11, 225689},
	{"VANLINES", 8, 225690},
	{"TENCY", 5, 225691},
	{"PRIMOBOLAN", 10, 225692},
	{"PFLEGER", 7, 225693},
	{"MOBILIZER", 9, 225694},
	{"UNDELETION", 10, 225695},
	{"KOMPAS", 6, 225696},
	{"WRITTLE", 7, 225697},
	{"FRACKVILLE", 10, 225698},
	{"MATON", 5, 225699},
	{"XYLOCAINE", 9, 225700},
	{"REHABBING", 9, 225701},
	{"PRIZEWINNER", 11, 225702},
	{"PRIBILOF", 8, 225703},
	{"MAKED", 5, 225704},
	{"KLAASSEN", 8, 225705},
	{"ALLEYN", 6, 225706},
	{"VICCO", 5, 225707},
	{"KLP", 3, 225708},
	{"CORPORATECOMS", 13, 225709},
	{"TABULATES", 9, 225710},
	{"SOMMA", 5, 225711},
	{"HYPERBILIRUBINEMIA", 18, 225712},
	{"COUNTERFACTUALS", 15, 225713},
	{"COMPOUNDERS", 11, 225714},
	{"ORDINATIONS", 11, 225715},
	{"WISECO", 6, 225716},
	{"SANPF", 5, 225717},
	{"BUBBLEWRAP", 10, 225718},
	{"PRELINK", 7, 225719},
	{"MORVAN", 6, 225720},
	{"KADAITCHA", 9, 225721},
	{"HEADHUNTING", 11, 225722},
	{"FSIZE", 5, 225723},
	{"ANNIBYNNOL", 10, 225724},
	{"ALLINSON", 8, 225725},
	{"DETAILERS", 9, 225726},
	{"BOLER", 5, 225727},
	{"SUBDIAL", 7, 225728},
	{"WINDRUSH", 8, 225729},
	{"TORQUEMADA", 10, 225730},
	{"RTRIM", 5, 225731},
	{"HOLEN", 5, 225732},
	{"GUIDEHOME", 9, 225733},
	{"FINAID", 6, 225734},
	{"HILARIO", 7, 225735},
	{"RHAM", 4, 225736},
	{"CUTWORM", 7, 225737},
	{"EDGIER", 6, 225738},
	{"AIDSCHANNEL", 11, 225739},
	{"WYTRYSKI", 8, 225740},
	{"CCEF", 4, 225741},
	{"BRRR", 4, 225742},
	{"AMARILLAS", 9, 225743},
	{"MCMURPHY", 8, 225744},
	{"SLACKEN", 7, 225745},
	{"PASSOLINI", 9, 225746},
	{"KHADI", 5, 225747},
	{"FABRICIO", 8, 225748},
	{"ENKEI", 5, 225749},
	{"STANWAY", 7, 225750},
	{"NAVNET", 6, 225751},
	{"ERWISE", 6, 225752},
	{"BIAGI", 5, 225753},
	{"DIAZO", 5, 225754},
	{"SAADIQ", 6, 225755},
	{"OATMAN", 6, 225756},
	{"INSTRON", 7, 225757},
	{"HANDELMAN", 9, 225758},
	{"WANGARI", 7, 225759},
	{"LEAPER", 6, 225760},
	{"LANDESBANK", 10, 225761},
	{"DONORSCHOOSE", 12, 225762},
	{"UKAI", 4, 225763},
	{"CYPRIEN", 7, 225764},
	{"DISGORGE", 8, 225765},
	{"BORDERMANAGER", 13, 225766},
	{"VILLAGEWARE", 11, 225767},
	{"STARTSIDE", 9, 225768},
	{"CINCINNATUS", 11, 225769},
	{"TEAGARDEN", 9, 225770},
	{"EUTHANIZE", 9, 225771},
	{"YACK", 4, 225772},
	{"MILIEUX", 7, 225773},
	{"REFERENCIAS", 11, 225774},
	{"LORICA", 6, 225775},
	{"DETERMINACY", 11, 225776},
	{"NEWSEMPLOYMENT", 14, 225777},
	{"CADDESI", 7, 225778},
	{"OPENIPMI", 8, 225779},
	{"STRICKLIN", 9, 225780},
	{"MACGRAW", 7, 225781},
	{"ZUME", 4, 225782},
	{"YSWU", 4, 225783},
	{"YLTC", 4, 225784},
	{"YLDA", 4, 225785},
	{"YEZI", 4, 225786},
	{"YDHO", 4, 225787},
	{"XIEB", 4, 225788},
	{"WRYI", 4, 225789},
	{"WLFR", 4, 225790},
	{"WJEN", 4, 225791},
	{"WFIX", 4, 225792},
	{"WDGO", 4, 225793},
	{"VATD", 4, 225794},
	{"UYOL", 4, 225795},
	{"UELZ", 4, 225796},
	{"TSXB", 4, 225797},
	{"TGWI", 4, 225798},
	{"TCUE", 4, 225799},
	{"RTIQ", 4, 225800},
	{"RIRW", 4, 225801},
	{"RFDE", 4, 225802},
	{"OXRU", 4, 225803},
	{"ONUG", 4, 225804},
	{"NRDE", 4, 225805},
	{"NRCO", 4, 225806},
	{"MSMR", 4, 225807},
	{"MPNI", 4, 225808},
	{"MMSM", 4, 225809},
	{"MAPN", 4, 225810},
	{"LVAO", 4, 225811},
	{"LOSY", 4, 225812},
	{"LIRV", 4, 225813},
	{"KHSW", 4, 225814},
	{"KENQ", 4, 225815},
	{"IVVY", 4, 225816},
	{"HRUC", 4, 225817},
	{"HJOL", 4, 225818},
	{"HDUI", 4, 225819},
	{"HDEU", 4, 225820},
	{"FLGR", 4, 225821},
	{"FIGR", 4, 225822},
	{"ESVY", 4, 225823},
	{"ENWW", 4, 225824},
	{"ENMB", 4, 225825},
	{"ELUE", 4, 225826},
	{"CTUL", 4, 225827},
	{"CPIR", 4, 225828},
	{"BOFU", 4, 225829},
	{"BFTO", 4, 225830},
	{"ATDM", 4, 225831},
	{"APPPLE", 6, 225832},
	{"MICROWARE", 9, 225833},
	{"IFDEFS", 6, 225834},
	{"PHILANDERING", 12, 225835},
	{"BOOBOO", 6, 225836},
	{"IPAR", 4, 225837},
	{"DISRUPTERS", 10, 225838},
	{"CIBASOFT", 8, 225839},
	{"DAISHI", 6, 225840},
	{"ATHYN", 5, 225841},
	{"TOMCATS", 7, 225842},
	{"INDEMNIFIES", 11, 225843},
	{"BIOMOBY", 7, 225844},
	{"SERVIETTES", 10, 225845},
	{"HILLERY", 7, 225846},
	{"CABLINGD", 8, 225847},
	{"UNPROTECT", 9, 225848},
	{"PARMELEE", 8, 225849},
	{"VALLOIRE", 8, 225850},
	{"COVELO", 6, 225851},
	{"BUFP", 4, 225852},
	{"KARBON", 6, 225853},
	{"INFURIATES", 10, 225854},
	{"SHIMODA", 7, 225855},
	{"HARTIG", 6, 225856},
	{"ESCOTT", 6, 225857},
	{"FOLKLORIST", 10, 225858},
	{"BASENJIS", 8, 225859},
	{"ALDEBARAN", 9, 225860},
	{"NORWEIGAN", 9, 225861},
	{"AHYF", 4, 225862},
	{"DIMMICK", 7, 225863},
	{"VITRONECTIN", 11, 225864},
	{"MEDIACULTURE", 12, 225865},
	{"GOALSCORERS", 11, 225866},
	{"CLIS", 4, 225867},
	{"ROSSON", 6, 225868},
	{"KELOID", 6, 225869},
	{"MISPRONOUNCED", 13, 225870},
	{"COROJO", 6, 225871},
	{"WARRE", 5, 225872},
	{"MACRONIX", 8, 225873},
	{"HERSHEYS", 8, 225874},
	{"FILMLOOP", 8, 225875},
	{"ROULETE", 7, 225876},
	{"PPSCHEMA", 8, 225877},
	{"CAMN", 4, 225878},
	{"AVANTAGES", 9, 225879},
	{"SOMEBODIES", 10, 225880},
	{"NEVERWHERE", 10, 225881},
	{"CAMKII", 6, 225882},
	{"BISECT", 6, 225883},
	{"WALLIE", 6, 225884},
	{"SOYER", 5, 225885},
	{"MEDO", 4, 225886},
	{"MANSUN", 6, 225887},
	{"KINDOF", 6, 225888},
	{"KANTNER", 7, 225889},
	{"SHABANA", 7, 225890},
	{"MEMA", 4, 225891},
	{"SECURITIZATIONS", 15, 225892},
	{"RUSSIAS", 7, 225893},
	{"SKELLINGTON", 11, 225894},
	{"HYACINTHUS", 10, 225895},
	{"DUGUAY", 6, 225896},
	{"CHOOSELAW", 9, 225897},
	{"AGRANULOCYTOSIS", 15, 225898},
	{"COPAKE", 6, 225899},
	{"BRUSHSTROKE", 11, 225900},
	{"QUAILTY", 7, 225901},
	{"NETMEDIA", 8, 225902},
	{"MSBOXA", 6, 225903},
	{"CLAMOURING", 10, 225904},
	{"FINALIZER", 9, 225905},
	{"CAFFINE", 7, 225906},
	{"TROUPER", 7, 225907},
	{"HOSTALS", 7, 225908},
	{"CLEARSTREAM", 11, 225909},
	{"ONCALL", 6, 225910},
	{"OFEX", 4, 225911},
	{"DISCIPLING", 10, 225912},
	{"HECKMONDWIKE", 12, 225913},
	{"ATTAINDER", 9, 225914},
	{"PHILOMEL", 8, 225915},
	{"MSNBCCOM", 8, 225916},
	{"GARTENBERG", 10, 225917},
	{"CADI", 4, 225918},
	{"SWERVEDRIVER", 12, 225919},
	{"NABUCCO", 7, 225920},
	{"GURSKY", 6, 225921},
	{"BOECK", 5, 225922},
	{"BAILOUTS", 8, 225923},
	{"AFVS", 4, 225924},
	{"RESEEDING", 9, 225925},
	{"AXIOHM", 6, 225926},
	{"FUNFAIR", 7, 225927},
	{"NETWINDER", 9, 225928},
	{"PRINTVIEW", 9, 225929},
	{"NONRELATIVISTIC", 15, 225930},
	{"ANOYING", 7, 225931},
	{"SNIJDERS", 8, 225932},
	{"CANDIDATS", 9, 225933},
	{"CAMPEONATO", 10, 225934},
	{"ASTUDIAETHAU", 12, 225935},
	{"WUYI", 4, 225936},
	{"JANKOVIC", 8, 225937},
	{"BEACHBODY", 9, 225938},
	{"PETROGRAPHY", 11, 225939},
	{"ISTRA", 5, 225940},
	{"FITOUT", 6, 225941},
	{"FAMIS", 5, 225942},
	{"POWERSCHOOL", 11, 225943},
	{"DYNAMIS", 7, 225944},
	{"TWILLINGATE", 11, 225945},
	{"KRAAI", 5, 225946},
	{"QNIL", 4, 225947},
	{"INCHCAPE", 8, 225948},
	{"TELUK", 5, 225949},
	{"SUNTIME", 7, 225950},
	{"CIVICA", 6, 225951},
	{"IDINA", 5, 225952},
	{"BLAN", 4, 225953},
	{"PATRONYMIC", 10, 225954},
	{"FOLLOWETH", 9, 225955},
	{"SUMISA", 6, 225956},
	{"IGAL", 4, 225957},
	{"FEDERMAN", 8, 225958},
	{"MEITNER", 7, 225959},
	{"VIROLOGIST", 10, 225960},
	{"HOTPOT", 6, 225961},
	{"VRINDAVAN", 9, 225962},
	{"POME", 4, 225963},
	{"FREDE", 5, 225964},
	{"DUFY", 4, 225965},
	{"DEKO", 4, 225966},
	{"CROSSIN", 7, 225967},
	{"NOVAGEN", 7, 225968},
	{"COMMUNING", 9, 225969},
	{"HSIZE", 5, 225970},
	{"MATALA", 6, 225971},
	{"ILIAMNA", 7, 225972},
	{"MARGARETTA", 10, 225973},
	{"FRANCHIZE", 9, 225974},
	{"PORON", 5, 225975},
	{"GAETAN", 6, 225976},
	{"BETALING", 8, 225977},
	{"PHSP", 4, 225978},
	{"NGINEERING", 10, 225979},
	{"FORETREX", 8, 225980},
	{"POTTERSVILLE", 12, 225981},
	{"DEMIS", 5, 225982},
	{"YUSL", 4, 225983},
	{"WUSP", 4, 225984},
	{"WNPS", 4, 225985},
	{"WFON", 4, 225986},
	{"VALQ", 4, 225987},
	{"TVEB", 4, 225988},
	{"TUVI", 4, 225989},
	{"TUDB", 4, 225990},
	{"TPBI", 4, 225991},
	{"SUYU", 4, 225992},
	{"SKJU", 4, 225993},
	{"SKJE", 4, 225994},
	{"SJRI", 4, 225995},
	{"SCEB", 4, 225996},
	{"RRIY", 4, 225997},
	{"RPPT", 4, 225998},
	{"RLEK", 4, 225999},
	{"RARJ", 4, 226000},
	{"QINW", 4, 226001},
	{"PCUP", 4, 226002},
	{"ORRR", 4, 226003},
	{"OMRG", 4, 226004},
	{"OGGT", 4, 226005},
	{"OEYV", 4, 226006},
	{"OEML", 4, 226007},
	{"NGSZ", 4, 226008},
	{"MSNY", 4, 226009},
	{"MOAF", 4, 226010},
	{"MFTT", 4, 226011},
	{"LJRA", 4, 226012},
	{"LDZA", 4, 226013},
	{"LCOY", 4, 226014},
	{"KMOH", 4, 226015},
	{"JRAD", 4, 226016},
	{"IMBC", 4, 226017},
	{"IDIY", 4, 226018},
	{"GOVF", 4, 226019},
	{"FMAF", 4, 226020},
	{"FEBN", 4, 226021},
	{"EXSW", 4, 226022},
	{"ETDG", 4, 226023},
	{"EFMR", 4, 226024},
	{"EABK", 4, 226025},
	{"CTHY", 4, 226026},
	{"CBYB", 4, 226027},
	{"BYNF", 4, 226028},
	{"BODM", 4, 226029},
	{"ANXU", 4, 226030},
	{"ALPW", 4, 226031},
	{"SOWNLOADS", 9, 226032},
	{"ASAKAWA", 7, 226033},
	{"CEDER", 5, 226034},
	{"BRADWAY", 7, 226035},
	{"CALTHORPE", 9, 226036},
	{"ASOBI", 5, 226037},
	{"PRETERIST", 9, 226038},
	{"OLDUVAI", 7, 226039},
	{"VARIFRANK", 9, 226040},
	{"SBEC", 4, 226041},
	{"KORANIC", 7, 226042},
	{"ESPIRITO", 8, 226043},
	{"RECONSIDERS", 11, 226044},
	{"MISCHIEVOUSLY", 13, 226045},
	{"COERULEUS", 9, 226046},
	{"AYUNTAMIENTO", 12, 226047},
	{"SALESTARGET", 11, 226048},
	{"MOUSY", 5, 226049},
	{"COMMUNISTIC", 11, 226050},
	{"HILLARYS", 8, 226051},
	{"GAJE", 4, 226052},
	{"BERTONI", 7, 226053},
	{"ASAPS", 5, 226054},
	{"SCRUTINEER", 10, 226055},
	{"PEACEHAVEN", 10, 226056},
	{"DONOTS", 6, 226057},
	{"COOVER", 6, 226058},
	{"AUDIOGRAM", 9, 226059},
	{"URBERVILLES", 11, 226060},
	{"KETAN", 5, 226061},
	{"ILLICITLY", 9, 226062},
	{"MABEE", 5, 226063},
	{"WORDTRANS", 9, 226064},
	{"DEWORMING", 9, 226065},
	{"COLLY", 5, 226066},
	{"TORTORA", 7, 226067},
	{"XYLANASE", 8, 226068},
	{"XANTECH", 7, 226069},
	{"MIKEGRB", 7, 226070},
	{"MARKETWIRE", 10, 226071},
	{"WINCHMORE", 9, 226072},
	{"PLOWRIGHT", 9, 226073},
	{"KSWAPD", 6, 226074},
	{"ICZM", 4, 226075},
	{"HRBATY", 6, 226076},
	{"ARIKI", 5, 226077},
	{"ANTIMEDIA", 9, 226078},
	{"NONDECREASING", 13, 226079},
	{"HDFS", 4, 226080},
	{"HOEFER", 6, 226081},
	{"HARDDISKS", 9, 226082},
	{"BANERJI", 7, 226083},
	{"SOULJA", 6, 226084},
	{"THRAWN", 6, 226085},
	{"LUIT", 4, 226086},
	{"LAMPREYS", 8, 226087},
	{"WCON", 4, 226088},
	{"SLIVERED", 8, 226089},
	{"MEURSAULT", 9, 226090},
	{"ACEMOGLU", 8, 226091},
	{"PLASTIDS", 8, 226092},
	{"TAVAREZ", 7, 226093},
	{"SWIVELLING", 10, 226094},
	{"KIAROSTAMI", 10, 226095},
	{"CHENGDE", 7, 226096},
	{"BOONIE", 6, 226097},
	{"STEREOLITHOGRAPHY", 17, 226098},
	{"PHEMTERMINE", 11, 226099},
	{"DLQ", 3, 226100},
	{"ANDRIUS", 7, 226101},
	{"NFCA", 4, 226102},
	{"DALGLISH", 8, 226103},
	{"BLEPHARITIS", 11, 226104},
	{"EXTRACURRICULARS", 16, 226105},
	{"SRICHTER", 8, 226106},
	{"LOOGOOTEE", 9, 226107},
	{"UNMIL", 5, 226108},
	{"ROMANTIQUE", 10, 226109},
	{"JEZEL", 5, 226110},
	{"ICAD", 4, 226111},
	{"IMMUNOFLUORESCENT", 17, 226112},
	{"GRAFITI", 7, 226113},
	{"SORLIN", 6, 226114},
	{"INFOTIQUE", 9, 226115},
	{"ICLOCK", 6, 226116},
	{"TREFFER", 7, 226117},
	{"JONGENS", 7, 226118},
	{"WARBLOG", 7, 226119},
	{"RISPONDI", 8, 226120},
	{"LUCASI", 6, 226121},
	{"RAILPASS", 8, 226122},
	{"DEFRAGMENTING", 13, 226123},
	{"ROCARD", 6, 226124},
	{"RIVERVALE", 9, 226125},
	{"RECONOCIMIENTO", 14, 226126},
	{"PROGRAMABLE", 11, 226127},
	{"MCLEESE", 7, 226128},
	{"NOWDAYS", 7, 226129},
	{"MEMOIRES", 8, 226130},
	{"GELATION", 8, 226131},
	{"FMY", 3, 226132},
	{"FUTIAN", 6, 226133},
	{"TELEPORTING", 11, 226134},
	{"LARKFIELD", 9, 226135},
	{"HARAV", 5, 226136},
	{"NEXTRA", 6, 226137},
	{"UPENDED", 7, 226138},
	{"SUSMAN", 6, 226139},
	{"LENSTRA", 7, 226140},
	{"DOCNAME", 7, 226141},
	{"BWB", 3, 226142},
	{"BOPHUT", 6, 226143},
	{"TRUCTURE", 8, 226144},
	{"WALDHEIM", 8, 226145},
	{"ECOR", 4, 226146},
	{"SEPHARDIM", 9, 226147},
	{"SPINNA", 6, 226148},
	{"ELETRONIC", 9, 226149},
	{"CCIA", 4, 226150},
	{"MEDSTAR", 7, 226151},
	{"ITCRA", 5, 226152},
	{"GASKETING", 9, 226153},
	{"GWELL", 5, 226154},
	{"FOWNLOADS", 9, 226155},
	{"SYSNAME", 7, 226156},
	{"COOLGARDIE", 10, 226157},
	{"GETFIELD", 8, 226158},
	{"RRIF", 4, 226159},
	{"SENGOKU", 7, 226160},
	{"MAJUS", 5, 226161},
	{"KUNTZE", 6, 226162},
	{"FILEMON", 7, 226163},
	{"AIRLINEA", 8, 226164},
	{"LIBCLASS", 8, 226165},
	{"DYESTUFF", 8, 226166},
	{"MICROGLOBE", 10, 226167},
	{"DOGA", 4, 226168},
	{"UNBEATABLESALE", 14, 226169},
	{"NICOMACHEAN", 11, 226170},
	{"KROEKER", 7, 226171},
	{"CHURCHWIDE", 10, 226172},
	{"ZWEITEN", 7, 226173},
	{"RIRS", 4, 226174},
	{"DRUGGIE", 7, 226175},
	{"DARSTELLER", 10, 226176},
	{"PROJECTEN", 9, 226177},
	{"METACARPAL", 10, 226178},
	{"LLES", 4, 226179},
	{"CHASTISING", 10, 226180},
	{"AYANAMI", 7, 226181},
	{"PREEMPTING", 10, 226182},
	{"JAHRESTAGUNG", 12, 226183},
	{"AUTOSENSING", 11, 226184},
	{"WEBIMMUNE", 9, 226185},
	{"RIEGLE", 6, 226186},
	{"EXBYTE", 6, 226187},
	{"WAVEY", 5, 226188},
	{"UNDERREPRESENTATION", 19, 226189},
	{"TAPLEY", 6, 226190},
	{"PSEUDOSCALAR", 12, 226191},
	{"SHARROCK", 8, 226192},
	{"EEBOO", 5, 226193},
	{"AIRLINEW", 8, 226194},
	{"SPECTABILIS", 11, 226195},
	{"POLITIKHS", 9, 226196},
	{"ADMONISHMENT", 12, 226197},
	{"MASTERMINDING", 13, 226198},
	{"KAMAU", 5, 226199},
	{"TRUSTOR", 7, 226200},
	{"SHARKANSKY", 10, 226201},
	{"SOTELO", 6, 226202},
	{"ROCKSTARS", 9, 226203},
	{"PIRIN", 5, 226204},
	{"SPATZ", 5, 226205},
	{"ELECTRIBE", 9, 226206},
	{"MICRODRIVES", 11, 226207},
	{"BEIGNETS", 8, 226208},
	{"VVD", 3, 226209},
	{"MULTIPLYLOGO", 12, 226210},
	{"KILLORGLIN", 10, 226211},
	{"OVERSCAN", 8, 226212},
	{"NEORAL", 6, 226213},
	{"REATTA", 6, 226214},
	{"MOUVEMENTS", 10, 226215},
	{"JOBMANAGER", 10, 226216},
	{"ACCRED", 6, 226217},
	{"SCHOONMAKER", 11, 226218},
	{"CHATHAOIRLEACH", 14, 226219},
	{"PICAFORT", 8, 226220},
	{"CONGRESSPERSON", 14, 226221},
	{"APPROPRIATORS", 13, 226222},
	{"ZUWA", 4, 226223},
	{"ZIBE", 4, 226224},
	{"YUTC", 4, 226225},
	{"YUPE", 4, 226226},
	{"YOHW", 4, 226227},
	{"YGAE", 4, 226228},
	{"YDMO", 4, 226229},
	{"YDEJ", 4, 226230},
	{"XKEN", 4, 226231},
	{"XAMF", 4, 226232},
	{"WEYD", 4, 226233},
	{"WBYF", 4, 226234},
	{"UZUB", 4, 226235},
	{"UPUY", 4, 226236},
	{"UOFW", 4, 226237},
	{"UASD", 4, 226238},
	{"TMIF", 4, 226239},
	{"SYAU", 4, 226240},
	{"SBOF", 4, 226241},
	{"RLAE", 4, 226242},
	{"RFAA", 4, 226243},
	{"RDKY", 4, 226244},
	{"RBCE", 4, 226245},
	{"PMVI", 4, 226246},
	{"PCOI", 4, 226247},
	{"OVPL", 4, 226248},
	{"OMLL", 4, 226249},
	{"OCSF", 4, 226250},
	{"NURM", 4, 226251},
	{"NRIY", 4, 226252},
	{"NMEU", 4, 226253},
	{"MBBC", 4, 226254},
	{"LURL", 4, 226255},
	{"LHIJ", 4, 226256},
	{"LEVM", 4, 226257},
	{"LEBN", 4, 226258},
	{"LDIX", 4, 226259},
	{"JBLI", 4, 226260},
	{"IWED", 4, 226261},
	{"ISKJ", 4, 226262},
	{"HMSV", 4, 226263},
	{"HLSB", 4, 226264},
	{"HCYL", 4, 226265},
	{"GCBS", 4, 226266},
	{"FVAG", 4, 226267},
	{"FTMC", 4, 226268},
	{"FEUL", 4, 226269},
	{"FEAV", 4, 226270},
	{"EXJA", 4, 226271},
	{"EUDR", 4, 226272},
	{"ENBP", 4, 226273},
	{"EKEF", 4, 226274},
	{"ECWW", 4, 226275},
	{"DFSU", 4, 226276},
	{"BIOV", 4, 226277},
	{"BCGL", 4, 226278},
	{"BBAK", 4, 226279},
	{"ATGB", 4, 226280},
	{"POFN", 4, 226281},
	{"EXFOLIATES", 10, 226282},
	{"EQUEST", 6, 226283},
	{"DERISIVELY", 10, 226284},
	{"PROVISIONER", 11, 226285},
	{"FRANKRIKE", 9, 226286},
	{"BESTELLT", 8, 226287},
	{"HEDERA", 6, 226288},
	{"SUPERLUMINAL", 12, 226289},
	{"LOPPED", 6, 226290},
	{"LIEBERTHAL", 10, 226291},
	{"BOSPORUS", 8, 226292},
	{"MEMBR", 5, 226293},
	{"KOHLRABI", 8, 226294},
	{"DERWOOD", 7, 226295},
	{"DOUBLERS", 8, 226296},
	{"MSOFFICE", 8, 226297},
	{"POLARISING", 10, 226298},
	{"CULLINANE", 9, 226299},
	{"THORUGH", 7, 226300},
	{"SUBVERSIVES", 11, 226301},
	{"HCUP", 4, 226302},
	{"FELONIOUSLY", 11, 226303},
	{"TRANSCENDCOMPLIANCE", 19, 226304},
	{"OLIGARCH", 8, 226305},
	{"SPOLIATION", 10, 226306},
	{"MCNICHOLAS", 10, 226307},
	{"ARNHEIM", 7, 226308},
	{"PHILMORE", 8, 226309},
	{"MARABLE", 7, 226310},
	{"KSYMOOPS", 8, 226311},
	{"KHALIDI", 7, 226312},
	{"MSUB", 4, 226313},
	{"BERNY", 5, 226314},
	{"NANGA", 5, 226315},
	{"UNSENTIMENTAL", 13, 226316},
	{"BEDDINGS", 8, 226317},
	{"SAUTEE", 6, 226318},
	{"ENTHALPIES", 10, 226319},
	{"VIEDOS", 6, 226320},
	{"SINGLEHANDEDLY", 14, 226321},
	{"SCRUNCH", 7, 226322},
	{"RODES", 5, 226323},
	{"PLEASANTNESS", 12, 226324},
	{"SECRETA", 7, 226325},
	{"RADOSH", 6, 226326},
	{"BENSONSWORLD", 12, 226327},
	{"REAGANITE", 9, 226328},
	{"PENNYWHISTLE", 12, 226329},
	{"DWWW", 4, 226330},
	{"MAKEBA", 6, 226331},
	{"TOMATE", 6, 226332},
	{"SENDMSG", 7, 226333},
	{"COMNET", 6, 226334},
	{"SETCOUNTER", 10, 226335},
	{"ARKKO", 5, 226336},
	{"UNDERPLATE", 10, 226337},
	{"ONLINEE", 7, 226338},
	{"MEILLEURE", 9, 226339},
	{"BUMBERSHOOT", 11, 226340},
	{"DOGFOOD", 7, 226341},
	{"CAPACI", 6, 226342},
	{"STEALIN", 7, 226343},
	{"OVERTONS", 8, 226344},
	{"LOSMAN", 6, 226345},
	{"VILLANI", 7, 226346},
	{"OPENRUN", 7, 226347},
	{"KALAHEO", 7, 226348},
	{"ABERTILLERY", 11, 226349},
	{"ICRI", 4, 226350},
	{"VOITH", 5, 226351},
	{"TALU", 4, 226352},
	{"JUGO", 4, 226353},
	{"TERMINABLE", 10, 226354},
	{"KRUSADER", 8, 226355},
	{"GCGGG", 5, 226356},
	{"BIZON", 5, 226357},
	{"POWERMACS", 9, 226358},
	{"KNEDEEP", 7, 226359},
	{"COLUMNA", 7, 226360},
	{"ATLFAST", 7, 226361},
	{"ANTHURIUMS", 10, 226362},
	{"RECONVEYANCE", 12, 226363},
	{"PREBBLE", 7, 226364},
	{"MONTRER", 7, 226365},
	{"MAWHINNEY", 9, 226366},
	{"FIXUPS", 6, 226367},
	{"CAPABLANCA", 10, 226368},
	{"VENKATARAMAN", 12, 226369},
	{"MEDIATEK", 8, 226370},
	{"RIEHLE", 6, 226371},
	{"PHOSPHORESCENCE", 15, 226372},
	{"NTRIP", 5, 226373},
	{"FIRESTAR", 8, 226374},
	{"MASSER", 6, 226375},
	{"ERMILOV", 7, 226376},
	{"PRIMAROLO", 9, 226377},
	{"DONLON", 6, 226378},
	{"CONSOLODATION", 13, 226379},
	{"TESTINGCODE", 11, 226380},
	{"KLOOT", 5, 226381},
	{"INVOLV", 6, 226382},
	{"SETFOCUS", 8, 226383},
	{"GRAUPNER", 8, 226384},
	{"BRUGGEMAN", 9, 226385},
	{"INFAMOUSLY", 10, 226386},
	{"BOUNDRY", 7, 226387},
	{"BETCOM", 6, 226388},
	{"BALLADEER", 9, 226389},
	{"SHEARERS", 8, 226390},
	{"POMERANIANS", 11, 226391},
	{"RINGNECK", 8, 226392},
	{"DERG", 4, 226393},
	{"ECML", 4, 226394},
	{"WUNZHANG", 8, 226395},
	{"SABELLA", 7, 226396},
	{"MACFORMAT", 9, 226397},
	{"HARKS", 5, 226398},
	{"DIRIGIBLE", 9, 226399},
	{"MINNEOLA", 8, 226400},
	{"COPEIA", 6, 226401},
	{"BIKESFORSALE", 12, 226402},
	{"DEVGALAXY", 9, 226403},
	{"MCCOYS", 6, 226404},
	{"CULTURALE", 9, 226405},
	{"GEOGRA", 6, 226406},
	{"NEGOZI", 6, 226407},
	{"UCCNET", 6, 226408},
	{"DOMINICAL", 9, 226409},
	{"CARRABELLE", 10, 226410},
	{"ZYDONE", 6, 226411},
	{"UNAIRED", 7, 226412},
	{"NASSIF", 6, 226413},
	{"MCQUAY", 6, 226414},
	{"GOBLINX", 7, 226415},
	{"SCINTILLATORS", 13, 226416},
	{"RUSO", 4, 226417},
	{"REGRIND", 7, 226418},
	{"HANDLEIDING", 11, 226419},
	{"DABA", 4, 226420},
	{"ZUREK", 5, 226421},
	{"DIONYSIAN", 9, 226422},
	{"CPERL", 5, 226423},
	{"BUREAUTIQUE", 11, 226424},
	{"NASREEN", 7, 226425},
	{"JANDL", 5, 226426},
	{"FROGG", 5, 226427},
	{"SITEMGR", 7, 226428},
	{"SELBYVILLE", 10, 226429},
	{"IKLAN", 5, 226430},
	{"COLLING", 7, 226431},
	{"TEXSHARE", 8, 226432},
	{"SALVELINUS", 10, 226433},
	{"RCSC", 4, 226434},
	{"EMPFEHLUNG", 10, 226435},
	{"SHIRAISHI", 9, 226436},
	{"RISIKO", 6, 226437},
	{"ARCURI", 6, 226438},
	{"MUGGINGS", 8, 226439},
	{"MILLIONEN", 9, 226440},
	{"LUMISCOPE", 9, 226441},
	{"LINKMEISTER", 11, 226442},
	{"GOLGO", 5, 226443},
	{"CONEMAUGH", 9, 226444},
	{"LUSTILY", 7, 226445},
	{"HARGITAY", 8, 226446},
	{"CUID", 4, 226447},
	{"DCDS", 4, 226448},
	{"CERAMBYCIDAE", 12, 226449},
	{"WEBSHARE", 8, 226450},
	{"UNOPS", 5, 226451},
	{"MADDENINGLY", 11, 226452},
	{"BAKEHOUSE", 9, 226453},
	{"INTERNAP", 8, 226454},
	{"UNDERARMOUR", 11, 226455},
	{"BARNHOUSE", 9, 226456},
	{"MINDLEADERS", 11, 226457},
	{"BIERMANN", 8, 226458},
	{"AVANTAGE", 8, 226459},
	{"VONNIE", 6, 226460},
	{"TRILLIN", 7, 226461},
	{"HRROI", 5, 226462},
	{"AEWEBWORKS", 10, 226463},
	{"DOMKSED", 7, 226464},
	{"SKINFOLD", 8, 226465},
	{"ABESTWEB", 8, 226466},
	{"SHALINI", 7, 226467},
	{"NISSL", 5, 226468},
	{"NHSDA", 5, 226469},
	{"DIFERENCIA", 10, 226470},
	{"UNLEARNING", 10, 226471},
	{"UNDEFINE", 8, 226472},
	{"MUNUVIANA", 9, 226473},
	{"LUXURIA", 7, 226474},
	{"CONGREVE", 8, 226475},
	{"ACTUALIZADOS", 12, 226476},
	{"SLINGERLAND", 11, 226477},
	{"MLRS", 4, 226478},
	{"NAGV", 4, 226479},
	{"CHQT", 4, 226480},
	{"RODRICK", 7, 226481},
	{"CENTERPIN", 9, 226482},
	{"VIRONMENTAL", 11, 226483},
	{"TBNID", 5, 226484},
	{"SBBOOL", 6, 226485},
	{"PUTONGHUA", 9, 226486},
	{"BULLINGER", 9, 226487},
	{"ALSTONVILLE", 11, 226488},
	{"TRAINI", 6, 226489},
	{"ZOSP", 4, 226490},
	{"YIMD", 4, 226491},
	{"YGAA", 4, 226492},
	{"YEYA", 4, 226493},
	{"YDJU", 4, 226494},
	{"WWSU", 4, 226495},
	{"WIAL", 4, 226496},
	{"VSPI", 4, 226497},
	{"USYY", 4, 226498},
	{"UFHA", 4, 226499},
	{"UDNA", 4, 226500},
	{"TOUX", 4, 226501},
	{"TMUE", 4, 226502},
	{"SYID", 4, 226503},
	{"SREZ", 4, 226504},
	{"SBSP", 4, 226505},
	{"RRSM", 4, 226506},
	{"RIOY", 4, 226507},
	{"RDTV", 4, 226508},
	{"PUCI", 4, 226509},
	{"PGHA", 4, 226510},
	{"PGAB", 4, 226511},
	{"ONMV", 4, 226512},
	{"OKYI", 4, 226513},
	{"NXOF", 4, 226514},
	{"NVYI", 4, 226515},
	{"MJOL", 4, 226516},
	{"LPJU", 4, 226517},
	{"LMIF", 4, 226518},
	{"LCET", 4, 226519},
	{"KRUI", 4, 226520},
	{"KOKK", 4, 226521},
	{"KMAA", 4, 226522},
	{"GYHU", 4, 226523},
	{"GGHI", 4, 226524},
	{"GDOV", 4, 226525},
	{"GBHU", 4, 226526},
	{"GAGW", 4, 226527},
	{"EWDC", 4, 226528},
	{"EVVA", 4, 226529},
	{"ERYZ", 4, 226530},
	{"EDMF", 4, 226531},
	{"DYAA", 4, 226532},
	{"DIRN", 4, 226533},
	{"CZKO", 4, 226534},
	{"CYAW", 4, 226535},
	{"CSYE", 4, 226536},
	{"CPPR", 4, 226537},
	{"CPON", 4, 226538},
	{"BMIX", 4, 226539},
	{"BJPA", 4, 226540},
	{"AURH", 4, 226541},
	{"AUAC", 4, 226542},
	{"AFUZ", 4, 226543},
	{"AEUL", 4, 226544},
	{"POLITECNICA", 11, 226545},
	{"AVINGER", 7, 226546},
	{"PYROMETER", 9, 226547},
	{"INSKIP", 6, 226548},
	{"FMHA", 4, 226549},
	{"LICATION", 8, 226550},
	{"TECHWHACK", 9, 226551},
	{"GUJRAT", 6, 226552},
	{"COZZENS", 7, 226553},
	{"REVISTED", 8, 226554},
	{"GEVAERT", 7, 226555},
	{"BOGERT", 6, 226556},
	{"ZONER", 5, 226557},
	{"HADD", 4, 226558},
	{"SCOTIAMCLEOD", 12, 226559},
	{"MULTIBASE", 9, 226560},
	{"PREVIEWBACKGROUND", 17, 226561},
	{"SEEBACH", 7, 226562},
	{"RICHLER", 7, 226563},
	{"PENSTONE", 8, 226564},
	{"UPOV", 4, 226565},
	{"TACHIKARA", 9, 226566},
	{"MATR", 4, 226567},
	{"SUAMICO", 7, 226568},
	{"STRATES", 7, 226569},
	{"CHESTERLAND", 11, 226570},
	{"SCALISE", 7, 226571},
	{"LINEARITIES", 11, 226572},
	{"IMPEDENCE", 9, 226573},
	{"REGISTROS", 9, 226574},
	{"OUNG", 4, 226575},
	{"SELDOVIA", 8, 226576},
	{"RENTBUY", 7, 226577},
	{"FDATA", 5, 226578},
	{"NEPTUNIUM", 9, 226579},
	{"ACTERNA", 7, 226580},
	{"CAVION", 6, 226581},
	{"ZAYAS", 5, 226582},
	{"PARTITURAS", 10, 226583},
	{"DOKL", 4, 226584},
	{"ACTUALL", 7, 226585},
	{"ETZION", 6, 226586},
	{"DJP", 3, 226587},
	{"IDENTIFI", 8, 226588},
	{"TELITHROMYCIN", 13, 226589},
	{"OPENCAST", 8, 226590},
	{"DATALINKS", 9, 226591},
	{"REEFERS", 7, 226592},
	{"BALACLAVAS", 10, 226593},
	{"INCARCERATE", 11, 226594},
	{"SQUIDTAILD", 10, 226595},
	{"SANTUARIO", 9, 226596},
	{"HELFAND", 7, 226597},
	{"ENIRO", 5, 226598},
	{"WRNTY", 5, 226599},
	{"ENTRAL", 6, 226600},
	{"RITESH", 6, 226601},
	{"BIMETAL", 7, 226602},
	{"ARIZA", 5, 226603},
	{"MUNIS", 5, 226604},
	{"MAPCAR", 6, 226605},
	{"NEUROPATHOL", 11, 226606},
	{"JELLYBEANS", 10, 226607},
	{"HASKEL", 6, 226608},
	{"WINNS", 5, 226609},
	{"NATRACARE", 9, 226610},
	{"AIDERS", 6, 226611},
	{"TELEPATH", 8, 226612},
	{"MULTIDIRECTIONAL", 16, 226613},
	{"MLTON", 5, 226614},
	{"LOGGHE", 6, 226615},
	{"SPARGO", 6, 226616},
	{"SCRATCHERS", 10, 226617},
	{"SHNIAD", 6, 226618},
	{"PHENOCRYSTS", 11, 226619},
	{"SIXFOLD", 7, 226620},
	{"ANACS", 5, 226621},
	{"PANCHROMATIC", 12, 226622},
	{"BLOGHI", 6, 226623},
	{"THYLAKOID", 9, 226624},
	{"BICC", 4, 226625},
	{"PREVENTIVO", 10, 226626},
	{"GENTIANA", 8, 226627},
	{"BLUEWAY", 7, 226628},
	{"UKULELES", 8, 226629},
	{"TORREZ", 6, 226630},
	{"PEDAGOGICALLY", 13, 226631},
	{"CAMPTOTHECIN", 12, 226632},
	{"GISTS", 5, 226633},
	{"CLANWILLIAM", 11, 226634},
	{"CASHIERING", 10, 226635},
	{"BAGNA", 5, 226636},
	{"FANGIO", 6, 226637},
	{"SWAMPING", 8, 226638},
	{"HOSTAPD", 7, 226639},
	{"CHIODO", 6, 226640},
	{"YAMES", 5, 226641},
	{"WINEGLASS", 9, 226642},
	{"TRIJICON", 8, 226643},
	{"NDPS", 4, 226644},
	{"EMPS", 4, 226645},
	{"DYSCALCULIA", 11, 226646},
	{"CJAT", 4, 226647},
	{"APARTAMENT", 10, 226648},
	{"SENTARA", 7, 226649},
	{"CWLTH", 5, 226650},
	{"CLUBFOOT", 8, 226651},
	{"UNCHAIN", 7, 226652},
	{"DUBOST", 6, 226653},
	{"ANTEDILUVIAN", 12, 226654},
	{"CPIC", 4, 226655},
	{"ACETABULUM", 10, 226656},
	{"ENFORA", 6, 226657},
	{"BERNADOTTE", 10, 226658},
	{"TILNEY", 6, 226659},
	{"REALMEGA", 8, 226660},
	{"RBX", 3, 226661},
	{"MACDV", 5, 226662},
	{"INDETDETDESCR", 13, 226663},
	{"CONVEYANCERS", 12, 226664},
	{"YPPEDIA", 7, 226665},
	{"RITUALIZED", 10, 226666},
	{"NARROWBOAT", 10, 226667},
	{"KHNL", 4, 226668},
	{"NRIC", 4, 226669},
	{"FOULDS", 6, 226670},
	{"RUMOURMAN", 9, 226671},
	{"ROKY", 4, 226672},
	{"UBLAS", 5, 226673},
	{"FRICKING", 8, 226674},
	{"MALENESS", 8, 226675},
	{"YDYNT", 5, 226676},
	{"MERSHON", 7, 226677},
	{"MABURAHO", 8, 226678},
	{"CONSTANZA", 9, 226679},
	{"PUCHONG", 7, 226680},
	{"IRRELIGIOUS", 11, 226681},
	{"DEBRIEFINGS", 11, 226682},
	{"UNDISBURSED", 11, 226683},
	{"GILB", 4, 226684},
	{"BONDHOLDER", 10, 226685},
	{"VINDICATING", 11, 226686},
	{"ANAYLSIS", 8, 226687},
	{"SIOUXLAND", 9, 226688},
	{"POMORTZEFF", 10, 226689},
	{"NETHERL", 7, 226690},
	{"OBJETO", 6, 226691},
	{"MACIVER", 7, 226692},
	{"SUGGES", 6, 226693},
	{"ROTHAMSTED", 10, 226694},
	{"MBU", 3, 226695},
	{"PYROPHOSPHATASE", 15, 226696},
	{"PARATYPE", 8, 226697},
	{"LOTRIMIN", 8, 226698},
	{"HITCHHIKE", 9, 226699},
	{"BLACKWING", 9, 226700},
	{"SEABEE", 6, 226701},
	{"OTOSCOPES", 9, 226702},
	{"LOOPTROOP", 9, 226703},
	{"KWANDO", 6, 226704},
	{"BZR", 3, 226705},
	{"ANEGADA", 7, 226706},
	{"PVRBLOG", 7, 226707},
	{"POWERNOW", 8, 226708},
	{"WALIBI", 6, 226709},
	{"MEYERCO", 7, 226710},
	{"DEBITO", 6, 226711},
	{"CIBLE", 5, 226712},
	{"ZRAD", 4, 226713},
	{"ZOAL", 4, 226714},
	{"ZAPH", 4, 226715},
	{"YMPE", 4, 226716},
	{"YLEQ", 4, 226717},
	{"WHAB", 4, 226718},
	{"WDAF", 4, 226719},
	{"VWAN", 4, 226720},
	{"USVS", 4, 226721},
	{"UPKO", 4, 226722},
	{"UIOR", 4, 226723},
	{"UIMO", 4, 226724},
	{"UFTE", 4, 226725},
	{"UDGY", 4, 226726},
	{"UBTG", 4, 226727},
	{"TZRI", 4, 226728},
	{"TDRG", 4, 226729},
	{"TBYQ", 4, 226730},
	{"STBB", 4, 226731},
	{"SIRY", 4, 226732},
	{"RZSA", 4, 226733},
	{"PPDO", 4, 226734},
	{"PEZP", 4, 226735},
	{"OYVA", 4, 226736},
	{"OVLO", 4, 226737},
	{"OFLP", 4, 226738},
	{"OCSU", 4, 226739},
	{"NVIP", 4, 226740},
	{"NPCH", 4, 226741},
	{"NIDW", 4, 226742},
	{"MNLA", 4, 226743},
	{"LSLR", 4, 226744},
	{"LLUZ", 4, 226745},
	{"LKAV", 4, 226746},
	{"KUMS", 4, 226747},
	{"KAZH", 4, 226748},
	{"IRUZ", 4, 226749},
	{"IDYH", 4, 226750},
	{"ICTZ", 4, 226751},
	{"GYUT", 4, 226752},
	{"GSUV", 4, 226753},
	{"EJOM", 4, 226754},
	{"DPSU", 4, 226755},
	{"CPUW", 4, 226756},
	{"CBLI", 4, 226757},
	{"BEKK", 4, 226758},
	{"AGHB", 4, 226759},
	{"GETATTRIBUTES", 13, 226760},
	{"DINGUS", 6, 226761},
	{"COOLFM", 6, 226762},
	{"CHORION", 7, 226763},
	{"GRIDWALL", 8, 226764},
	{"TRELAWNEY", 9, 226765},
	{"VERKHOVNA", 9, 226766},
	{"BXHEIGHT", 8, 226767},
	{"BEAUBIEN", 8, 226768},
	{"SANDINO", 7, 226769},
	{"HYDROXYPHENYL", 13, 226770},
	{"PANCALDI", 8, 226771},
	{"MAECHLER", 8, 226772},
	{"STERBA", 6, 226773},
	{"PROTECTO", 8, 226774},
	{"ONKEN", 5, 226775},
	{"HEYL", 4, 226776},
	{"SVANTE", 6, 226777},
	{"SAKTI", 5, 226778},
	{"NATUREDLY", 9, 226779},
	{"HOTGROUP", 8, 226780},
	{"GOHAH", 5, 226781},
	{"DOWNTIMES", 9, 226782},
	{"LONWORKS", 8, 226783},
	{"BEFO", 4, 226784},
	{"ALMY", 4, 226785},
	{"WWWHOTMAILCOM", 13, 226786},
	{"ASCETICS", 8, 226787},
	{"CREUSE", 6, 226788},
	{"TAPATIO", 7, 226789},
	{"NEPHITES", 8, 226790},
	{"FIORILLO", 8, 226791},
	{"OENOLOGY", 8, 226792},
	{"SCORNS", 6, 226793},
	{"PELUDOS", 7, 226794},
	{"NACION", 6, 226795},
	{"LAGGARD", 7, 226796},
	{"BARCHETTA", 9, 226797},
	{"RKM", 3, 226798},
	{"GRIMA", 5, 226799},
	{"BEANY", 5, 226800},
	{"WINCKLER", 8, 226801},
	{"HIRSCHBIEGEL", 12, 226802},
	{"GOVERNMEN", 9, 226803},
	{"LINEOX", 6, 226804},
	{"LEBED", 5, 226805},
	{"GIGAFAST", 8, 226806},
	{"TIVOTOGO", 8, 226807},
	{"PORTANCE", 8, 226808},
	{"WINWORD", 7, 226809},
	{"VUES", 4, 226810},
	{"SABATER", 7, 226811},
	{"IDER", 4, 226812},
	{"DOMEINREGISTRATIE", 17, 226813},
	{"WOLRD", 5, 226814},
	{"VALMIKI", 7, 226815},
	{"AMYLOSE", 7, 226816},
	{"WALCZAK", 7, 226817},
	{"SELLWOOD", 8, 226818},
	{"PICTUEES", 8, 226819},
	{"RIJSWIJK", 8, 226820},
	{"BACCI", 5, 226821},
	{"RAFER", 5, 226822},
	{"CORWEN", 6, 226823},
	{"MELLOTT", 7, 226824},
	{"JZKY", 4, 226825},
	{"FULGIDUS", 8, 226826},
	{"TRACTIVE", 8, 226827},
	{"OGEMAW", 6, 226828},
	{"JADIS", 5, 226829},
	{"HURTLE", 6, 226830},
	{"GCHQ", 4, 226831},
	{"CHARGEUR", 8, 226832},
	{"BOSIBL", 6, 226833},
	{"BLOCKHEADS", 10, 226834},
	{"SIEGELMAN", 9, 226835},
	{"PYRAMIDE", 8, 226836},
	{"INTERHEMISPHERIC", 16, 226837},
	{"INSECTES", 8, 226838},
	{"ABIQUIU", 7, 226839},
	{"NORTHS", 6, 226840},
	{"PLRN", 4, 226841},
	{"ONLINF", 6, 226842},
	{"ENDOPHTHALMITIS", 15, 226843},
	{"SEJNOWSKI", 9, 226844},
	{"HOTONLINE", 9, 226845},
	{"GURUNG", 6, 226846},
	{"OKLAHOME", 8, 226847},
	{"SADDENING", 9, 226848},
	{"KASHUBIAN", 9, 226849},
	{"BEARINGTON", 10, 226850},
	{"PCOL", 4, 226851},
	{"OBSCURATION", 11, 226852},
	{"MCALPIN", 7, 226853},
	{"LOCURI", 6, 226854},
	{"TAKEDOWNS", 9, 226855},
	{"LLENA", 5, 226856},
	{"HONKERS", 7, 226857},
	{"MICHALE", 7, 226858},
	{"MEERS", 5, 226859},
	{"UMICH", 5, 226860},
	{"ODIERESIS", 9, 226861},
	{"MATCHFACTS", 10, 226862},
	{"SHORESIDE", 9, 226863},
	{"MALCONTENTS", 11, 226864},
	{"KIKYO", 5, 226865},
	{"FUX", 3, 226866},
	{"GRAPHITTI", 9, 226867},
	{"DWANE", 5, 226868},
	{"COSEQUIN", 8, 226869},
	{"CHOYS", 5, 226870},
	{"ALKALIES", 8, 226871},
	{"DOGGER", 6, 226872},
	{"NITZSCHIA", 9, 226873},
	{"HINDBRAIN", 9, 226874},
	{"CASTILLEJA", 10, 226875},
	{"WILLAMINA", 9, 226876},
	{"WHACKO", 6, 226877},
	{"GREENGROCER", 11, 226878},
	{"ISAVETRAVEL", 11, 226879},
	{"GENTES", 6, 226880},
	{"FORSTNER", 8, 226881},
	{"DITKO", 5, 226882},
	{"LIRI", 4, 226883},
	{"JKONTHERUN", 10, 226884},
	{"SMARTMONTOOLS", 13, 226885},
	{"RICHENS", 7, 226886},
	{"SCHOLASTICISM", 13, 226887},
	{"SASKPOWER", 9, 226888},
	{"INTERIMS", 8, 226889},
	{"VUK", 3, 226890},
	{"MULTIPARAMETER", 14, 226891},
	{"PASSACAGLIA", 11, 226892},
	{"MAILHOT", 7, 226893},
	{"FOYE", 4, 226894},
	{"DFKI", 4, 226895},
	{"RIKO", 4, 226896},
	{"RASHGUARDS", 10, 226897},
	{"HUITEMA", 7, 226898},
	{"ASIMO", 5, 226899},
	{"SABINAL", 7, 226900},
	{"GUSMAO", 6, 226901},
	{"ENVTL", 5, 226902},
	{"ZURCHER", 7, 226903},
	{"COMPTROLLERSHIP", 15, 226904},
	{"CHZT", 4, 226905},
	{"PHOTOGRA", 8, 226906},
	{"TURNMILLS", 9, 226907},
	{"SEANNA", 6, 226908},
	{"OSTERREICHISCHE", 15, 226909},
	{"NANOPOROUS", 10, 226910},
	{"LONEWACKO", 9, 226911},
	{"CORNELIO", 8, 226912},
	{"IDSOCIETY", 9, 226913},
	{"MICROONDAS", 10, 226914},
	{"EXTREMIS", 8, 226915},
	{"XAPPACK", 7, 226916},
	{"HYPHAL", 6, 226917},
	{"ENTRAINING", 10, 226918},
	{"ADJUNCTION", 10, 226919},
	{"TRAMSDOL", 8, 226920},
	{"SEYON", 5, 226921},
	{"REGE", 4, 226922},
	{"LIBARTS", 7, 226923},
	{"YABOOT", 6, 226924},
	{"SATINS", 6, 226925},
	{"ORIENTATE", 9, 226926},
	{"GESHI", 5, 226927},
	{"ENDOSOME", 8, 226928},
	{"EBUSY", 5, 226929},
	{"HALLY", 5, 226930},
	{"MISCALCULATIONS", 15, 226931},
	{"EFFEMINACY", 10, 226932},
	{"DANSER", 6, 226933},
	{"UNMINDFUL", 9, 226934},
	{"REGIONALIZED", 12, 226935},
	{"BPOS", 4, 226936},
	{"AIRSTRIPS", 9, 226937},
	{"SCHMELING", 9, 226938},
	{"FFLAGS", 6, 226939},
	{"TELEOST", 7, 226940},
	{"MIRNAS", 6, 226941},
	{"SILICONVALLEY", 13, 226942},
	{"KEMEROVO", 8, 226943},
	{"BAZILLION", 9, 226944},
	{"FREELOADERS", 11, 226945},
	{"SPORTIVO", 8, 226946},
	{"CURRE", 5, 226947},
	{"ARANLUC", 7, 226948},
	{"VASSALBORO", 10, 226949},
	{"SISLER", 6, 226950},
	{"NORMALISING", 11, 226951},
	{"MAGNETOHYDRODYNAMICS", 20, 226952},
	{"HUGGLES", 7, 226953},
	{"SANDEL", 6, 226954},
	{"CULLOM", 6, 226955},
	{"BARNDOOR", 8, 226956},
	{"TODDLE", 6, 226957},
	{"KAZAAA", 6, 226958},
	{"COPPERY", 7, 226959},
	{"NORDHAUS", 8, 226960},
	{"MACKAYE", 7, 226961},
	{"LLANFAIR", 8, 226962},
	{"ZZYH", 4, 226963},
	{"ZZIF", 4, 226964},
	{"ZSMO", 4, 226965},
	{"ZDOU", 4, 226966},
	{"YPPA", 4, 226967},
	{"YIML", 4, 226968},
	{"YGUM", 4, 226969},
	{"YEAF", 4, 226970},
	{"YDEK", 4, 226971},
	{"XPUT", 4, 226972},
	{"WUSW", 4, 226973},
	{"VIOD", 4, 226974},
	{"URRJ", 4, 226975},
	{"UKHR", 4, 226976},
	{"UFCF", 4, 226977},
	{"UENV", 4, 226978},
	{"UEIW", 4, 226979},
	{"TYOM", 4, 226980},
	{"TVME", 4, 226981},
	{"TMPE", 4, 226982},
	{"TKHZ", 4, 226983},
	{"TGWA", 4, 226984},
	{"TGIU", 4, 226985},
	{"SYCU", 4, 226986},
	{"STVW", 4, 226987},
	{"SPYH", 4, 226988},
	{"SKSV", 4, 226989},
	{"SBIF", 4, 226990},
	{"SAGB", 4, 226991},
	{"SAFW", 4, 226992},
	{"RZLI", 4, 226993},
	{"RJPM", 4, 226994},
	{"REBM", 4, 226995},
	{"PPIU", 4, 226996},
	{"PAUR", 4, 226997},
	{"OVSR", 4, 226998},
	{"OUKW", 4, 226999},
	{"OTUG", 4, 227000},
	{"OILK", 4, 227001},
	{"NMRF", 4, 227002},
	{"LMMC", 4, 227003},
	{"LKCI", 4, 227004},
	{"LEYZ", 4, 227005},
	{"LBPA", 4, 227006},
	{"IEKL", 4, 227007},
	{"HOGB", 4, 227008},
	{"HMRP", 4, 227009},
	{"GMRA", 4, 227010},
	{"GGMI", 4, 227011},
	{"FRAO", 4, 227012},
	{"FFYG", 4, 227013},
	{"EWBS", 4, 227014},
	{"ESRM", 4, 227015},
	{"ENGQ", 4, 227016},
	{"EGUD", 4, 227017},
	{"DUTS", 4, 227018},
	{"DUCR", 4, 227019},
	{"DOIP", 4, 227020},
	{"DMII", 4, 227021},
	{"DJID", 4, 227022},
	{"CBYH", 4, 227023},
	{"BUSJ", 4, 227024},
	{"BEYP", 4, 227025},
	{"BCER", 4, 227026},
	{"ATPD", 4, 227027},
	{"ASLC", 4, 227028},
	{"ANZC", 4, 227029},
	{"AKYU", 4, 227030},
	{"AARF", 4, 227031},
	{"PHENTIRMINE", 11, 227032},
	{"RECOMENDADOS", 12, 227033},
	{"AUTOMATTIC", 10, 227034},
	{"PPRO", 4, 227035},
	{"CERCOPITHECUS", 13, 227036},
	{"TRACERPLUS", 10, 227037},
	{"ROYERSFORD", 10, 227038},
	{"BALAI", 5, 227039},
	{"VESELY", 6, 227040},
	{"REGULAMIN", 9, 227041},
	{"AGNET", 5, 227042},
	{"WATERWHEEL", 10, 227043},
	{"THORLOS", 7, 227044},
	{"PRESENTATIONSERVER", 18, 227045},
	{"OLANDER", 7, 227046},
	{"WHTTP", 5, 227047},
	{"NEWSCIENTIST", 12, 227048},
	{"INTERPRE", 8, 227049},
	{"AMIDASE", 7, 227050},
	{"PALLIUM", 7, 227051},
	{"SAREK", 5, 227052},
	{"ISTANA", 6, 227053},
	{"GLENFIDDICH", 11, 227054},
	{"MYCORRHIZAE", 11, 227055},
	{"TEXTIEL", 7, 227056},
	{"CERAMIST", 8, 227057},
	{"RACHAT", 6, 227058},
	{"OFFROADING", 10, 227059},
	{"KINGSBERRY", 10, 227060},
	{"CABALA", 6, 227061},
	{"WILDBLUE", 8, 227062},
	{"ORTAK", 5, 227063},
	{"GOSWELL", 7, 227064},
	{"GODWOT", 6, 227065},
	{"KELA", 4, 227066},
	{"CANNIBALISTIC", 13, 227067},
	{"STOPDESIGN", 10, 227068},
	{"BECO", 4, 227069},
	{"EXPEC", 5, 227070},
	{"INDESCRIBABLY", 13, 227071},
	{"HYDROLYZING", 11, 227072},
	{"SHEPARDS", 8, 227073},
	{"IRECTORY", 8, 227074},
	{"BIZEUROPE", 9, 227075},
	{"TECHNIEK", 8, 227076},
	{"HINGING", 7, 227077},
	{"GUILLOTINES", 11, 227078},
	{"FERRYHILL", 9, 227079},
	{"ENCUENTRAS", 10, 227080},
	{"GIMPY", 5, 227081},
	{"NOMINA", 6, 227082},
	{"LINEOUT", 7, 227083},
	{"MASONTOWN", 9, 227084},
	{"GUFFAW", 6, 227085},
	{"ECHEVARRIA", 10, 227086},
	{"AKULIVIK", 8, 227087},
	{"UNRUFFLED", 9, 227088},
	{"TYWYN", 5, 227089},
	{"FRANSEN", 7, 227090},
	{"BECHTOLD", 8, 227091},
	{"ROTHERY", 7, 227092},
	{"ELECTROPHOTOGRAPHIC", 19, 227093},
	{"CROMFORD", 8, 227094},
	{"NONCOMBUSTIBLE", 14, 227095},
	{"JEDD", 4, 227096},
	{"GASTROENTEROLOGICAL", 19, 227097},
	{"KALAS", 5, 227098},
	{"ARCHITETTI", 10, 227099},
	{"BERMINGHAM", 10, 227100},
	{"PSYCOLOQUY", 10, 227101},
	{"PARAFFINS", 9, 227102},
	{"MOONPHASE", 9, 227103},
	{"COPAC", 5, 227104},
	{"INCLINING", 9, 227105},
	{"AQUELLOS", 8, 227106},
	{"ZATTEVRIENDEN", 13, 227107},
	{"WESCHLER", 8, 227108},
	{"TAPPIN", 6, 227109},
	{"NAPOLEONS", 9, 227110},
	{"DISEMPOWERED", 12, 227111},
	{"NAMESTI", 7, 227112},
	{"ASHMEAD", 7, 227113},
	{"NEWLEY", 6, 227114},
	{"BOLZ", 4, 227115},
	{"SCRUNCHIE", 9, 227116},
	{"XDRIVE", 6, 227117},
	{"SKYLINK", 7, 227118},
	{"IZTURIS", 7, 227119},
	{"MALORIE", 7, 227120},
	{"MADHAVA", 7, 227121},
	{"AKELEY", 6, 227122},
	{"LEVINS", 6, 227123},
	{"GETUID", 6, 227124},
	{"COPPERSMITH", 11, 227125},
	{"SALIL", 5, 227126},
	{"IOLAUS", 6, 227127},
	{"ECONOMAIDD", 10, 227128},
	{"ATTANASIO", 9, 227129},
	{"STACHOWIAK", 10, 227130},
	{"CUSANO", 6, 227131},
	{"XDIFF", 5, 227132},
	{"DOGP", 4, 227133},
	{"AZOV", 4, 227134},
	{"VISUALIZERS", 11, 227135},
	{"GUICE", 5, 227136},
	{"LUTSEN", 6, 227137},
	{"ROHLOFF", 7, 227138},
	{"PLANETRECRUIT", 13, 227139},
	{"ORUDIS", 6, 227140},
	{"KREIDLER", 8, 227141},
	{"KANAKA", 6, 227142},
	{"GWILLIMBURY", 11, 227143},
	{"FINCASTLE", 9, 227144},
	{"LYRC", 4, 227145},
	{"WILLIAMTOWN", 11, 227146},
	{"CARNEYS", 7, 227147},
	{"RAJNEESH", 8, 227148},
	{"PRINTSTREAM", 11, 227149},
	{"MAKERFIELD", 10, 227150},
	{"REEMPLOYED", 10, 227151},
	{"ENCON", 5, 227152},
	{"ANAESTHETIZED", 13, 227153},
	{"NEXIMAGING", 10, 227154},
	{"ACEROLA", 7, 227155},
	{"PICTURWS", 8, 227156},
	{"INCOMMING", 9, 227157},
	{"GUNNELL", 7, 227158},
	{"HUIZINGA", 8, 227159},
	{"CUAT", 4, 227160},
	{"ANIMOSITIES", 11, 227161},
	{"WAXWINGS", 8, 227162},
	{"JEEBUS", 6, 227163},
	{"CYAT", 4, 227164},
	{"MMOGS", 5, 227165},
	{"BIOMECH", 7, 227166},
	{"OMBUDSGOD", 9, 227167},
	{"STUCTURE", 8, 227168},
	{"MUGGERIDGE", 10, 227169},
	{"LINGA", 5, 227170},
	{"SUPERSERVER", 11, 227171},
	{"BACKGOUND", 9, 227172},
	{"OPENBOX", 7, 227173},
	{"ENCOURAGER", 10, 227174},
	{"TAGFACTS", 8, 227175},
	{"RAGTOP", 6, 227176},
	{"BOONSBORO", 9, 227177},
	{"BENGHAZI", 8, 227178},
	{"VISED", 5, 227179},
	{"CANAJOHARIE", 11, 227180},
	{"VELIKOVSKY", 10, 227181},
	{"DICHLOROETHYLENE", 16, 227182},
	{"USACITYLINK", 11, 227183},
	{"UNICITY", 7, 227184},
	{"PROVENANT", 9, 227185},
	{"HYZAAR", 6, 227186},
	{"DROST", 5, 227187},
	{"ANTLERED", 8, 227188},
	{"WEBMAP", 6, 227189},
	{"SPROAT", 6, 227190},
	{"HANDTOOLED", 10, 227191},
	{"PILFERED", 8, 227192},
	{"AFSHAR", 6, 227193},
	{"MAINEVILLE", 10, 227194},
	{"BLASINGAME", 10, 227195},
	{"ZIGS", 4, 227196},
	{"ZADS", 4, 227197},
	{"YUFO", 4, 227198},
	{"YDTA", 4, 227199},
	{"YCAH", 4, 227200},
	{"YARP", 4, 227201},
	{"XIRA", 4, 227202},
	{"XIFO", 4, 227203},
	{"WMYW", 4, 227204},
	{"VAFE", 4, 227205},
	{"UPAQ", 4, 227206},
	{"UOEX", 4, 227207},
	{"UKVI", 4, 227208},
	{"UIRW", 4, 227209},
	{"TMOP", 4, 227210},
	{"TAPB", 4, 227211},
	{"STLC", 4, 227212},
	{"RZET", 4, 227213},
	{"RUZF", 4, 227214},
	{"RSQB", 4, 227215},
	{"RRSL", 4, 227216},
	{"RPEU", 4, 227217},
	{"RODK", 4, 227218},
	{"RDNC", 4, 227219},
	{"RCIM", 4, 227220},
	{"RAUK", 4, 227221},
	{"RAPV", 4, 227222},
	{"PNRE", 4, 227223},
	{"PEZM", 4, 227224},
	{"PBAY", 4, 227225},
	{"OXTU", 4, 227226},
	{"OPSQ", 4, 227227},
	{"OLSZ", 4, 227228},
	{"OGEX", 4, 227229},
	{"NSLL", 4, 227230},
	{"NLJU", 4, 227231},
	{"NJAU", 4, 227232},
	{"MTVP", 4, 227233},
	{"MBPO", 4, 227234},
	{"LTKA", 4, 227235},
	{"KKUM", 4, 227236},
	{"KGRU", 4, 227237},
	{"JPLA", 4, 227238},
	{"JISF", 4, 227239},
	{"JINY", 4, 227240},
	{"JFIN", 4, 227241},
	{"IUPO", 4, 227242},
	{"IKFA", 4, 227243},
	{"ICZT", 4, 227244},
	{"HMRO", 4, 227245},
	{"HMAZ", 4, 227246},
	{"GAOK", 4, 227247},
	{"GAOD", 4, 227248},
	{"FYTA", 4, 227249},
	{"FIFS", 4, 227250},
	{"EWMD", 4, 227251},
	{"ERLW", 4, 227252},
	{"ERKJ", 4, 227253},
	{"EELZ", 4, 227254},
	{"DVRA", 4, 227255},
	{"DTPR", 4, 227256},
	{"DLTG", 4, 227257},
	{"CUDO", 4, 227258},
	{"CMPI", 4, 227259},
	{"BUDT", 4, 227260},
	{"BFTN", 4, 227261},
	{"AYPS", 4, 227262},
	{"AVKO", 4, 227263},
	{"AMMG", 4, 227264},
	{"AMCT", 4, 227265},
	{"BORSARI", 7, 227266},
	{"CORRIVEAU", 9, 227267},
	{"COLN", 4, 227268},
	{"MARYSE", 6, 227269},
	{"MONENSIN", 8, 227270},
	{"ANDREOLI", 8, 227271},
	{"OSNABRUCK", 9, 227272},
	{"INURED", 6, 227273},
	{"TACKLER", 7, 227274},
	{"BATTERYS", 8, 227275},
	{"UKATTRACTION", 12, 227276},
	{"PARDONING", 9, 227277},
	{"MALLEI", 6, 227278},
	{"IMPRES", 6, 227279},
	{"PEDRINI", 7, 227280},
	{"HFILE", 5, 227281},
	{"TELEKINETIC", 11, 227282},
	{"TBPC", 4, 227283},
	{"CCSM", 4, 227284},
	{"WESHALB", 7, 227285},
	{"MASAKAZU", 8, 227286},
	{"HELLING", 7, 227287},
	{"CYTOMETER", 9, 227288},
	{"UTORRENT", 8, 227289},
	{"LACASSE", 7, 227290},
	{"COWSLIP", 7, 227291},
	{"SOMIT", 5, 227292},
	{"HFTP", 4, 227293},
	{"ECONOMOU", 8, 227294},
	{"FAMSI", 5, 227295},
	{"POLYGYNY", 8, 227296},
	{"EPROP", 5, 227297},
	{"ARKOPHARMA", 10, 227298},
	{"MEEMS", 5, 227299},
	{"AYHEM", 5, 227300},
	{"INTOXICANT", 10, 227301},
	{"AOSHIMA", 7, 227302},
	{"SILVERIO", 8, 227303},
	{"PERIO", 5, 227304},
	{"GBU", 3, 227305},
	{"THESTREET", 9, 227306},
	{"CLANN", 5, 227307},
	{"CONOCE", 6, 227308},
	{"PHENSTER", 8, 227309},
	{"INTERDITE", 9, 227310},
	{"NETIRON", 7, 227311},
	{"BLACKMER", 8, 227312},
	{"SHINBUN", 7, 227313},
	{"MOTARD", 6, 227314},
	{"MEDIVH", 6, 227315},
	{"BHAKTAPUR", 9, 227316},
	{"NAVARONE", 8, 227317},
	{"CHKROOTKIT", 10, 227318},
	{"PALAEOECOLOGY", 13, 227319},
	{"NETHOTELS", 9, 227320},
	{"GLUINT", 6, 227321},
	{"GMCS", 4, 227322},
	{"PREROUTING", 10, 227323},
	{"ENOTECA", 7, 227324},
	{"DEWISWCH", 8, 227325},
	{"BUTY", 4, 227326},
	{"RIDGEDALE", 9, 227327},
	{"THORNEY", 7, 227328},
	{"NUDIBRANCHS", 11, 227329},
	{"GIORGIONE", 9, 227330},
	{"BELMONDO", 8, 227331},
	{"UIDELINES", 9, 227332},
	{"RIKARD", 6, 227333},
	{"CANTAR", 6, 227334},
	{"ANMELDELSE", 10, 227335},
	{"SUPERNATURALLY", 14, 227336},
	{"REARFOOT", 8, 227337},
	{"ORGNOTE", 7, 227338},
	{"CONECTAR", 8, 227339},
	{"MCPHILLIPS", 10, 227340},
	{"BLOOMSDAY", 9, 227341},
	{"HAWKINSON", 9, 227342},
	{"DREAMWALKER", 11, 227343},
	{"SEELIG", 6, 227344},
	{"GUAYMAS", 7, 227345},
	{"FEEDTHROUGH", 11, 227346},
	{"VATAN", 5, 227347},
	{"TRANSECTION", 11, 227348},
	{"SQLPLUS", 7, 227349},
	{"MCGLINCHEY", 10, 227350},
	{"DIWA", 4, 227351},
	{"HUGI", 4, 227352},
	{"PIMAGE", 6, 227353},
	{"RAMEKIN", 7, 227354},
	{"ORALUX", 6, 227355},
	{"GRAVITATIONALLY", 15, 227356},
	{"COMPUTERIZE", 11, 227357},
	{"YQUEM", 5, 227358},
	{"SCINECE", 7, 227359},
	{"DEMOLISHES", 10, 227360},
	{"ALLWOOD", 7, 227361},
	{"PEQUANNOCK", 10, 227362},
	{"ALBERGUE", 8, 227363},
	{"KEAGGY", 6, 227364},
	{"BIOBEHAVIORAL", 13, 227365},
	{"WALLPLATE", 9, 227366},
	{"SCARILY", 7, 227367},
	{"HEYDON", 6, 227368},
	{"CONSU", 5, 227369},
	{"SOCIOECONOMICS", 14, 227370},
	{"LIZZA", 5, 227371},
	{"INNERVATED", 10, 227372},
	{"BASKETT", 7, 227373},
	{"CRAFTINESS", 10, 227374},
	{"AGRIFOOD", 8, 227375},
	{"RIFFE", 5, 227376},
	{"BELLYDANCING", 12, 227377},
	{"MCAFE", 5, 227378},
	{"MARKETINGS", 10, 227379},
	{"KARISSA", 7, 227380},
	{"JAFFAR", 6, 227381},
	{"DADELAND", 8, 227382},
	{"BEARLY", 6, 227383},
	{"XRAYS", 5, 227384},
	{"RETUR", 5, 227385},
	{"LIBERTADOR", 10, 227386},
	{"DREF", 4, 227387},
	{"AVOLEDO", 7, 227388},
	{"REBUKING", 8, 227389},
	{"OWERS", 5, 227390},
	{"URLAUBSBILDER", 13, 227391},
	{"SUNSTOVE", 8, 227392},
	{"PERCEPTIBLY", 11, 227393},
	{"FWF", 3, 227394},
	{"CIERTO", 6, 227395},
	{"REFLECTOMETER", 13, 227396},
	{"MXF", 3, 227397},
	{"TERRANES", 8, 227398},
	{"LAMBA", 5, 227399},
	{"PLOURDE", 7, 227400},
	{"VITIATED", 8, 227401},
	{"SOUNDSTICKS", 11, 227402},
	{"MELTWATER", 9, 227403},
	{"WIZENED", 7, 227404},
	{"ISOTC", 5, 227405},
	{"TRAMADIL", 8, 227406},
	{"FREQUEN", 7, 227407},
	{"CHUDLEIGH", 9, 227408},
	{"YANKERS", 7, 227409},
	{"CALLICUT", 8, 227410},
	{"TEXSTAR", 7, 227411},
	{"AMEICAN", 7, 227412},
	{"INCULATA", 8, 227413},
	{"OUSING", 6, 227414},
	{"BOJE", 4, 227415},
	{"WINTERED", 8, 227416},
	{"GAMMEL", 6, 227417},
	{"COMIQUE", 7, 227418},
	{"TRBRDRH", 7, 227419},
	{"SILKSTONE", 9, 227420},
	{"AGDE", 4, 227421},
	{"VARAD", 5, 227422},
	{"WOLSTENCROFT", 12, 227423},
	{"OPERATIONALIZATION", 18, 227424},
	{"ARVN", 4, 227425},
	{"WEKIVA", 6, 227426},
	{"METROBUS", 8, 227427},
	{"PLACECARDS", 10, 227428},
	{"CLUEDO", 6, 227429},
	{"SYMPATHIZING", 12, 227430},
	{"BEZIEHUNGEN", 11, 227431},
	{"PHOTOCATALYTIC", 14, 227432},
	{"NUMERATE", 8, 227433},
	{"VERTMARKETS", 11, 227434},
	{"TURTLEBACK", 10, 227435},
	{"CABORN", 6, 227436},
	{"TOWNSMAN", 8, 227437},
	{"PEVENSIE", 8, 227438},
	{"FRUS", 4, 227439},
	{"DOYOUROWNSITE", 13, 227440},
	{"CATASAUQUA", 10, 227441},
	{"OEOPLE", 6, 227442},
	{"STRATEGIS", 9, 227443},
	{"AIRLINEZ", 8, 227444},
	{"INDENTIFICATION", 15, 227445},
	{"HINDHEAD", 8, 227446},
	{"BERTHED", 7, 227447},
	{"NUTZUNG", 7, 227448},
	{"ABBETT", 6, 227449},
	{"VIGGEN", 6, 227450},
	{"UNSUBSTITUTED", 13, 227451},
	{"YYUR", 4, 227452},
	{"YYIP", 4, 227453},
	{"YSND", 4, 227454},
	{"YDAZ", 4, 227455},
	{"WWAM", 4, 227456},
	{"WKCO", 4, 227457},
	{"VSPH", 4, 227458},
	{"VPVO", 4, 227459},
	{"VOSF", 4, 227460},
	{"VEJJ", 4, 227461},
	{"UZAT", 4, 227462},
	{"UYAU", 4, 227463},
	{"UVST", 4, 227464},
	{"UOPP", 4, 227465},
	{"UONJ", 4, 227466},
	{"SADG", 4, 227467},
	{"RIKV", 4, 227468},
	{"RECW", 4, 227469},
	{"RCWO", 4, 227470},
	{"PLAH", 4, 227471},
	{"PELK", 4, 227472},
	{"PBED", 4, 227473},
	{"OIRG", 4, 227474},
	{"NSCF", 4, 227475},
	{"NPCI", 4, 227476},
	{"NOMM", 4, 227477},
	{"MPUZ", 4, 227478},
	{"MIMN", 4, 227479},
	{"LEZP", 4, 227480},
	{"KYJA", 4, 227481},
	{"KYAK", 4, 227482},
	{"KSKU", 4, 227483},
	{"KMCI", 4, 227484},
	{"IAYU", 4, 227485},
	{"HZAM", 4, 227486},
	{"GKRE", 4, 227487},
	{"FNIM", 4, 227488},
	{"FKIB", 4, 227489},
	{"EFGL", 4, 227490},
	{"DRIQ", 4, 227491},
	{"DPYT", 4, 227492},
	{"DNVI", 4, 227493},
	{"DNGA", 4, 227494},
	{"DIFK", 4, 227495},
	{"CYYE", 4, 227496},
	{"CKZI", 4, 227497},
	{"CHLL", 4, 227498},
	{"CCIG", 4, 227499},
	{"BCBY", 4, 227500},
	{"BBFO", 4, 227501},
	{"APJE", 4, 227502},
	{"ALCN", 4, 227503},
	{"AKMS", 4, 227504},
	{"AGKA", 4, 227505},
	{"MUDCAT", 6, 227506},
	{"LARMOUR", 7, 227507},
	{"STIFEL", 6, 227508},
	{"MILMAN", 6, 227509},
	{"UNDERLY", 7, 227510},
	{"SPIELWAREN", 10, 227511},
	{"SALTAIRE", 8, 227512},
	{"JAPANE", 6, 227513},
	{"ASSULT", 6, 227514},
	{"SCRATCHINGS", 11, 227515},
	{"REHAU", 5, 227516},
	{"ECOMMENDATIONS", 14, 227517},
	{"VIDPRO", 6, 227518},
	{"SPOTTS", 6, 227519},
	{"DUCCIO", 6, 227520},
	{"DENTSU", 6, 227521},
	{"KJB", 3, 227522},
	{"FORADIL", 7, 227523},
	{"SAARBRUECKEN", 12, 227524},
	{"MEMEGEN", 7, 227525},
	{"TSUSHIMA", 8, 227526},
	{"POLEGATE", 8, 227527},
	{"NONLIVING", 9, 227528},
	{"TALKUSERS", 9, 227529},
	{"NCOLS", 5, 227530},
	{"SHUJI", 5, 227531},
	{"LISKA", 5, 227532},
	{"CRYSTALLIZES", 12, 227533},
	{"SYNCRUDE", 8, 227534},
	{"SMECTITE", 8, 227535},
	{"PHACELIA", 8, 227536},
	{"DENISOV", 7, 227537},
	{"CIRCULAIRE", 10, 227538},
	{"PLAYSUIT", 8, 227539},
	{"LIGUSTRUM", 9, 227540},
	{"UDGIVER", 7, 227541},
	{"PRINCIPALSHIP", 13, 227542},
	{"PICGURES", 8, 227543},
	{"MPACK", 5, 227544},
	{"FLORK", 5, 227545},
	{"CONTINUER", 9, 227546},
	{"PARNES", 6, 227547},
	{"ANHARMONIC", 10, 227548},
	{"MEDAK", 5, 227549},
	{"OPENGIS", 7, 227550},
	{"BOLDIN", 6, 227551},
	{"SUITWATCH", 9, 227552},
	{"SUBCLAUSES", 10, 227553},
	{"PROPHASE", 8, 227554},
	{"WHIMSIES", 8, 227555},
	{"KLIPPER", 7, 227556},
	{"GRETING", 7, 227557},
	{"GORGED", 6, 227558},
	{"MILDNESS", 8, 227559},
	{"GROVETOWN", 9, 227560},
	{"BARTLETTS", 9, 227561},
	{"PYRA", 4, 227562},
	{"KOGAWA", 6, 227563},
	{"HHLD", 4, 227564},
	{"ACUARELA", 8, 227565},
	{"LUCKLESS", 8, 227566},
	{"DOONAN", 6, 227567},
	{"ALIZED", 6, 227568},
	{"WEBSHELL", 8, 227569},
	{"MICROPHYSICS", 12, 227570},
	{"KINES", 5, 227571},
	{"ARABIS", 6, 227572},
	{"TABC", 4, 227573},
	{"MONOSACCHARIDES", 15, 227574},
	{"BBLACKMOOR", 10, 227575},
	{"MAECENAS", 8, 227576},
	{"CARACTERES", 10, 227577},
	{"ZINEDINE", 8, 227578},
	{"REPLAYABILITY", 13, 227579},
	{"JAKALOPE", 8, 227580},
	{"GATORZ", 6, 227581},
	{"WARRANDYTE", 10, 227582},
	{"PIXELATION", 10, 227583},
	{"FOTHERINGHAM", 12, 227584},
	{"STAIKOS", 7, 227585},
	{"HURRA", 5, 227586},
	{"DECORAT", 7, 227587},
	{"KATIKATI", 8, 227588},
	{"DIVULGA", 7, 227589},
	{"PRINCETONIAN", 12, 227590},
	{"ALLBAUGH", 8, 227591},
	{"USERCONTROL", 11, 227592},
	{"SANDEMAN", 8, 227593},
	{"PEANUTBUTTER", 12, 227594},
	{"NIJINSKY", 8, 227595},
	{"KRABBE", 6, 227596},
	{"EZCODES", 7, 227597},
	{"TEMPIO", 6, 227598},
	{"MRAC", 4, 227599},
	{"VOIDOIDS", 8, 227600},
	{"SUBMANIFOLDS", 12, 227601},
	{"OSSUARY", 7, 227602},
	{"MAYUR", 5, 227603},
	{"NECKING", 7, 227604},
	{"MEGAS", 5, 227605},
	{"HYPOTONIA", 9, 227606},
	{"USDOC", 5, 227607},
	{"PHONATHON", 9, 227608},
	{"NOCACHE", 7, 227609},
	{"GROES", 5, 227610},
	{"BELSKY", 6, 227611},
	{"SILVRETTA", 9, 227612},
	{"HOSUE", 5, 227613},
	{"EZER", 4, 227614},
	{"CYBERPORT", 9, 227615},
	{"BACKACHES", 9, 227616},
	{"AMPHION", 7, 227617},
	{"ZENTRALE", 8, 227618},
	{"FALLOFF", 7, 227619},
	{"PALU", 4, 227620},
	{"BRISKETAI", 9, 227621},
	{"QUINQUENNIAL", 12, 227622},
	{"OVERBECK", 8, 227623},
	{"STREIFF", 7, 227624},
	{"MUCINS", 6, 227625},
	{"MCCREE", 6, 227626},
	{"GOFFE", 5, 227627},
	{"ANISM", 5, 227628},
	{"STORISE", 7, 227629},
	{"SRTP", 4, 227630},
	{"AIRLINETICKETS", 14, 227631},
	{"SZILVIA", 7, 227632},
	{"PICTA", 5, 227633},
	{"PHOTOMASK", 9, 227634},
	{"ETHEREXPRESS", 12, 227635},
	{"COARSEGOLD", 10, 227636},
	{"CHALLEN", 7, 227637},
	{"FROGMORE", 8, 227638},
	{"ANDREYCHUK", 10, 227639},
	{"INFICON", 7, 227640},
	{"ODEGAARD", 8, 227641},
	{"ISOTECH", 7, 227642},
	{"STAMPFER", 8, 227643},
	{"MUSTERS", 7, 227644},
	{"IGNALINA", 8, 227645},
	{"BRAUNTON", 8, 227646},
	{"HARRIOT", 7, 227647},
	{"BOHRER", 6, 227648},
	{"ZINNER", 6, 227649},
	{"METALWORLD", 10, 227650},
	{"SICENCE", 7, 227651},
	{"FEMININ", 7, 227652},
	{"WAIPIO", 6, 227653},
	{"RENFIELD", 8, 227654},
	{"COSTAIN", 7, 227655},
	{"MIKKELSON", 9, 227656},
	{"DETTAGLIO", 9, 227657},
	{"BAJAS", 5, 227658},
	{"GUNWALE", 7, 227659},
	{"GOMME", 5, 227660},
	{"PICTUFES", 8, 227661},
	{"DAYAK", 5, 227662},
	{"XTRAMSN", 7, 227663},
	{"AFACERI", 7, 227664},
	{"PRIDEAUX", 8, 227665},
	{"BOOKMARKEN", 10, 227666},
	{"YANIK", 5, 227667},
	{"VIZION", 6, 227668},
	{"SHIELA", 6, 227669},
	{"EMPLACEMENTS", 12, 227670},
	{"SCHRAGE", 7, 227671},
	{"LEFFINGWELL", 11, 227672},
	{"HARRON", 6, 227673},
	{"BLYDE", 5, 227674},
	{"JRCS", 4, 227675},
	{"HISTRIONICS", 11, 227676},
	{"FUSOBACTERIUM", 13, 227677},
	{"AUDIOMASTERMIND", 15, 227678},
	{"GLUTAMATERGIC", 13, 227679},
	{"AGONIZE", 7, 227680},
	{"VITALIS", 7, 227681},
	{"SOUNDTECH", 9, 227682},
	{"PREAUTHORIZED", 13, 227683},
	{"FLOPPER", 7, 227684},
	{"DEDUCTS", 7, 227685},
	{"PICTJRES", 8, 227686},
	{"HELGOLAND", 9, 227687},
	{"SUGARCUBES", 10, 227688},
	{"KABE", 4, 227689},
	{"GNINRUTER", 9, 227690},
	{"EATURES", 7, 227691},
	{"CAMAGUEY", 8, 227692},
	{"SENTRAL", 7, 227693},
	{"MELVINDALE", 10, 227694},
	{"SWATTED", 7, 227695},
	{"ONCOGENESIS", 11, 227696},
	{"JAWAHAR", 7, 227697},
	{"INDIGESTIBLE", 12, 227698},
	{"FGP", 3, 227699},
	{"SORBUS", 6, 227700},
	{"DURI", 4, 227701},
	{"DOUGHS", 6, 227702},
	{"APHRA", 5, 227703},
	{"VIAG", 4, 227704},
	{"HAUGLAND", 8, 227705},
	{"ZYOS", 4, 227706},
	{"YUTE", 4, 227707},
	{"YOPU", 4, 227708},
	{"YCEJ", 4, 227709},
	{"XGOE", 4, 227710},
	{"WNCY", 4, 227711},
	{"VYAM", 4, 227712},
	{"UHOF", 4, 227713},
	{"UBVO", 4, 227714},
	{"SPPL", 4, 227715},
	{"SBMO", 4, 227716},
	{"RTPP", 4, 227717},
	{"RPCC", 4, 227718},
	{"REXD", 4, 227719},
	{"PDFD", 4, 227720},
	{"PCCH", 4, 227721},
	{"OWYR", 4, 227722},
	{"OGHZ", 4, 227723},
	{"NRNB", 4, 227724},
	{"NOYC", 4, 227725},
	{"NJEM", 4, 227726},
	{"MRYS", 4, 227727},
	{"KIBY", 4, 227728},
	{"JAHB", 4, 227729},
	{"GTUC", 4, 227730},
	{"GRDI", 4, 227731},
	{"GNOK", 4, 227732},
	{"GGPS", 4, 227733},
	{"FYUK", 4, 227734},
	{"FYDO", 4, 227735},
	{"FSYP", 4, 227736},
	{"FIZI", 4, 227737},
	{"FIXR", 4, 227738},
	{"EVTU", 4, 227739},
	{"ENML", 4, 227740},
	{"ECVI", 4, 227741},
	{"DSAQ", 4, 227742},
	{"DRZA", 4, 227743},
	{"DEVP", 4, 227744},
	{"DCNO", 4, 227745},
	{"DBIF", 4, 227746},
	{"BYDH", 4, 227747},
	{"BSGI", 4, 227748},
	{"AWQU", 4, 227749},
	{"APCT", 4, 227750},
	{"GAMEFISH", 8, 227751},
	{"JOWL", 4, 227752},
	{"OPRUIMING", 9, 227753},
	{"NAUGLE", 6, 227754},
	{"NROP", 4, 227755},
	{"LORDOSIS", 8, 227756},
	{"DISCHI", 6, 227757},
	{"COFRESTRU", 9, 227758},
	{"BOOTE", 5, 227759},
	{"MCLINTOCK", 9, 227760},
	{"ARTRITIS", 8, 227761},
	{"XMSR", 4, 227762},
	{"TRANSPORTAT", 11, 227763},
	{"AIRLINEX", 8, 227764},
	{"NIBLETT", 7, 227765},
	{"STORCK", 6, 227766},
	{"ATORIES", 7, 227767},
	{"ALFRISTON", 9, 227768},
	{"LEZBO", 5, 227769},
	{"DEFOCUS", 7, 227770},
	{"BATHHOUSES", 10, 227771},
	{"INVITO", 6, 227772},
	{"FISHERFOLK", 10, 227773},
	{"BANKFULL", 8, 227774},
	{"VARNISHING", 10, 227775},
	{"SELEZIONE", 9, 227776},
	{"MUSICTORY", 9, 227777},
	{"PRINZESSIN", 10, 227778},
	{"GOODGOOD", 8, 227779},
	{"CATAWISSA", 9, 227780},
	{"KINGMAKER", 9, 227781},
	{"GETCOMPONENT", 12, 227782},
	{"PROCINFO", 8, 227783},
	{"CONVERTITORE", 12, 227784},
	{"DREB", 4, 227785},
	{"PLAYWEAR", 8, 227786},
	{"TICKELL", 7, 227787},
	{"UNCLOSED", 8, 227788},
	{"ROMARE", 6, 227789},
	{"CENTERPORT", 10, 227790},
	{"KENAF", 5, 227791},
	{"FANATICALLY", 11, 227792},
	{"RABEN", 5, 227793},
	{"DOPT", 4, 227794},
	{"WARTEN", 6, 227795},
	{"COFIELD", 7, 227796},
	{"NORTHEY", 7, 227797},
	{"STIKINE", 7, 227798},
	{"SINROD", 6, 227799},
	{"INSTED", 6, 227800},
	{"SIDELIGHT", 9, 227801},
	{"GREK", 4, 227802},
	{"RIXON", 5, 227803},
	{"CPOS", 4, 227804},
	{"BRIARCLIFFE", 11, 227805},
	{"CLERKING", 8, 227806},
	{"ARNONE", 6, 227807},
	{"ZELMAN", 6, 227808},
	{"SANITISED", 9, 227809},
	{"MALLINSON", 9, 227810},
	{"DAOUST", 6, 227811},
	{"ASTILBE", 7, 227812},
	{"UITSIG", 6, 227813},
	{"POMORSKIE", 9, 227814},
	{"OPENBOOT", 8, 227815},
	{"FLASHOVER", 9, 227816},
	{"TROGLODYTE", 10, 227817},
	{"TERU", 4, 227818},
	{"PREGANCY", 8, 227819},
	{"JAGADISH", 8, 227820},
	{"MAGGETTE", 8, 227821},
	{"CARABIDAE", 9, 227822},
	{"EPETRA", 6, 227823},
	{"DORTHY", 6, 227824},
	{"KRAS", 4, 227825},
	{"BINALTECH", 9, 227826},
	{"ATTAINERS", 9, 227827},
	{"PICTURSS", 8, 227828},
	{"DANNENBERG", 10, 227829},
	{"GILBREATH", 9, 227830},
	{"EMSP", 4, 227831},
	{"CAUSAS", 6, 227832},
	{"CAULOBACTER", 11, 227833},
	{"ARNEY", 5, 227834},
	{"STORMBREAKER", 12, 227835},
	{"TIMBERWOLF", 10, 227836},
	{"AUDETTE", 7, 227837},
	{"FETICHE", 7, 227838},
	{"CTIONS", 6, 227839},
	{"PHANEROZOIC", 11, 227840},
	{"INCLOSURE", 9, 227841},
	{"REDCATS", 7, 227842},
	{"NIMUE", 5, 227843},
	{"MULTISPORTS", 11, 227844},
	{"VOLUPTUOUSNESS", 14, 227845},
	{"SALARIO", 7, 227846},
	{"INACTIVATES", 11, 227847},
	{"PISOTV", 6, 227848},
	{"EBAC", 4, 227849},
	{"REDBOARD", 8, 227850},
	{"MARTONE", 7, 227851},
	{"HIFONICS", 8, 227852},
	{"WATCHLISTS", 10, 227853},
	{"MBIRA", 5, 227854},
	{"COLLINGSWORTH", 13, 227855},
	{"TICALLY", 7, 227856},
	{"REGINOX", 7, 227857},
	{"COVING", 6, 227858},
	{"WYC", 3, 227859},
	{"HYDROXYLAMINE", 13, 227860},
	{"RODDER", 6, 227861},
	{"IMAGETOIMAGEFILTER", 18, 227862},
	{"EZPOST", 6, 227863},
	{"HEMANGIOMAS", 11, 227864},
	{"DARM", 4, 227865},
	{"PWOPLE", 6, 227866},
	{"LABORDE", 7, 227867},
	{"RECURSIONS", 10, 227868},
	{"REPLAT", 6, 227869},
	{"PRODRUG", 7, 227870},
	{"CLINOPYROXENE", 13, 227871},
	{"AHVAZ", 5, 227872},
	{"SHBG", 4, 227873},
	{"PKCTURES", 8, 227874},
	{"HAFTUNGSAUSSCHLUSS", 18, 227875},
	{"FUDDY", 5, 227876},
	{"CASSOWARY", 9, 227877},
	{"JLU", 3, 227878},
	{"DOWNLOADABLES", 13, 227879},
	{"APVMA", 5, 227880},
	{"SOLIDE", 6, 227881},
	{"RZR", 3, 227882},
	{"PAROXYSM", 8, 227883},
	{"NEHRA", 5, 227884},
	{"BUFSIZ", 6, 227885},
	{"THILL", 5, 227886},
	{"SABUDA", 6, 227887},
	{"AFRICANISM", 10, 227888},
	{"MERCHANDIZE", 11, 227889},
	{"FSEOG", 5, 227890},
	{"CONSTRUIRE", 10, 227891},
	{"PETROLATUM", 10, 227892},
	{"FLIK", 4, 227893},
	{"CARTH", 5, 227894},
	{"READTOPICTEXT", 13, 227895},
	{"MALONDIALDEHYDE", 15, 227896},
	{"LOVLEY", 6, 227897},
	{"SINUSOID", 8, 227898},
	{"MINGAMMA", 8, 227899},
	{"ANGUAGE", 7, 227900},
	{"MSPH", 4, 227901},
	{"PANWA", 5, 227902},
	{"TRANSCONDUCTANCE", 16, 227903},
	{"TAHARA", 6, 227904},
	{"SHULTS", 6, 227905},
	{"HIMC", 4, 227906},
	{"APOCOLYPSE", 10, 227907},
	{"EDUCATIONEDUCATION", 18, 227908},
	{"BHADRA", 6, 227909},
	{"JOBSUCHE", 8, 227910},
	{"DELLL", 5, 227911},
	{"WRITELY", 7, 227912},
	{"POWERSAVE", 9, 227913},
	{"MACULATUM", 9, 227914},
	{"MEESTER", 7, 227915},
	{"EACCES", 6, 227916},
	{"HERMIA", 6, 227917},
	{"ELSEY", 5, 227918},
	{"YULIYA", 6, 227919},
	{"TCPAGENT", 8, 227920},
	{"LYDEN", 5, 227921},
	{"BILLICK", 7, 227922},
	{"WWWCOM", 6, 227923},
	{"URLICHS", 7, 227924},
	{"PANGA", 5, 227925},
	{"MCNICHOL", 8, 227926},
	{"YPMC", 4, 227927},
	{"YNFA", 4, 227928},
	{"YKOH", 4, 227929},
	{"YIPP", 4, 227930},
	{"YEUP", 4, 227931},
	{"XYMA", 4, 227932},
	{"WWPO", 4, 227933},
	{"USMD", 4, 227934},
	{"UKCE", 4, 227935},
	{"TVPI", 4, 227936},
	{"TMSB", 4, 227937},
	{"TEKP", 4, 227938},
	{"TCFB", 4, 227939},
	{"SKEK", 4, 227940},
	{"SKEF", 4, 227941},
	{"SBNG", 4, 227942},
	{"SAPY", 4, 227943},
	{"SAKK", 4, 227944},
	{"RWEO", 4, 227945},
	{"RIVK", 4, 227946},
	{"RIDK", 4, 227947},
	{"REJR", 4, 227948},
	{"PSHR", 4, 227949},
	{"OYCU", 4, 227950},
	{"OGHR", 4, 227951},
	{"NTZL", 4, 227952},
	{"NSPD", 4, 227953},
	{"NJIB", 4, 227954},
	{"NGNL", 4, 227955},
	{"NEMW", 4, 227956},
	{"MCED", 4, 227957},
	{"MBIU", 4, 227958},
	{"LPHK", 4, 227959},
	{"LOMN", 4, 227960},
	{"LGAC", 4, 227961},
	{"KSND", 4, 227962},
	{"KPLO", 4, 227963},
	{"KEEQ", 4, 227964},
	{"IKZE", 4, 227965},
	{"HYTW", 4, 227966},
	{"HMBE", 4, 227967},
	{"HLIU", 4, 227968},
	{"HKRU", 4, 227969},
	{"GGID", 4, 227970},
	{"GAEF", 4, 227971},
	{"FNAW", 4, 227972},
	{"ESGW", 4, 227973},
	{"EDMZ", 4, 227974},
	{"EAVC", 4, 227975},
	{"DSMP", 4, 227976},
	{"DKIF", 4, 227977},
	{"DKAF", 4, 227978},
	{"CBNS", 4, 227979},
	{"BRGE", 4, 227980},
	{"BOEF", 4, 227981},
	{"BAMT", 4, 227982},
	{"AIRZ", 4, 227983},
	{"AGMC", 4, 227984},
	{"AAMW", 4, 227985},
	{"SAXMATT", 7, 227986},
	{"PETRILLO", 8, 227987},
	{"PEIPLE", 6, 227988},
	{"MELILLO", 7, 227989},
	{"LUGGAGES", 8, 227990},
	{"JAKKI", 5, 227991},
	{"HAYING", 6, 227992},
	{"GAMBRINUS", 9, 227993},
	{"GALING", 6, 227994},
	{"VALLARIO", 8, 227995},
	{"MAXWELLS", 8, 227996},
	{"CYANOBACTERIUM", 14, 227997},
	{"WHETTED", 7, 227998},
	{"UMBACH", 6, 227999},
	{"MCCREERY", 8, 228000},
	{"KILI", 4, 228001},
	{"SIDESTREET", 10, 228002},
	{"SERAGLIO", 8, 228003},
	{"FASCIATUS", 9, 228004},
	{"DANGLERS", 8, 228005},
	{"VEXTRA", 6, 228006},
	{"FUNKER", 6, 228007},
	{"CLUP", 4, 228008},
	{"LEAVENS", 7, 228009},
	{"CHRISTOFF", 9, 228010},
	{"AMBYSTOMA", 9, 228011},
	{"WHITAKERS", 9, 228012},
	{"TOPOISOMERASES", 14, 228013},
	{"NTENKTAS", 8, 228014},
	{"FWLOGWATCH", 10, 228015},
	{"BUZGATE", 7, 228016},
	{"NORDLUND", 8, 228017},
	{"GREENLAKE", 9, 228018},
	{"DISHPRONTO", 10, 228019},
	{"SPIM", 4, 228020},
	{"LEHEY", 5, 228021},
	{"ALAMAT", 6, 228022},
	{"UNDEREXPOSED", 12, 228023},
	{"PORJ", 4, 228024},
	{"HECKLERS", 8, 228025},
	{"CARIOUS", 7, 228026},
	{"CRIBBING", 8, 228027},
	{"BOESCH", 6, 228028},
	{"JONASSEN", 8, 228029},
	{"FACTEURS", 8, 228030},
	{"PHOBL", 5, 228031},
	{"PHILONEIST", 10, 228032},
	{"WBM", 3, 228033},
	{"SCOURGES", 8, 228034},
	{"PASTORIS", 8, 228035},
	{"HETEROCYCLES", 12, 228036},
	{"PREMIUMPREMIUM", 14, 228037},
	{"SMOORENBURG", 11, 228038},
	{"HANDWARMER", 10, 228039},
	{"ESPASA", 6, 228040},
	{"DEDEKIND", 8, 228041},
	{"PKRN", 4, 228042},
	{"MICROMANAGEMENT", 15, 228043},
	{"FEHBP", 5, 228044},
	{"YPOYRGEIO", 9, 228045},
	{"PROSTHODONTISTS", 15, 228046},
	{"CESSFULLY", 9, 228047},
	{"MALTITOL", 8, 228048},
	{"EDWARDES", 8, 228049},
	{"BIZERTE", 7, 228050},
	{"ACCESSIONED", 11, 228051},
	{"PICFURES", 8, 228052},
	{"KDOT", 4, 228053},
	{"WERTS", 5, 228054},
	{"TRIBONACCI", 10, 228055},
	{"SINGLESOURCE", 12, 228056},
	{"KAINIC", 6, 228057},
	{"LUGOFF", 6, 228058},
	{"LIBERDADE", 9, 228059},
	{"HERZIG", 6, 228060},
	{"HAJDUK", 6, 228061},
	{"PEMISCOT", 8, 228062},
	{"INING", 5, 228063},
	{"BALUCH", 6, 228064},
	{"TRBRDRV", 7, 228065},
	{"CORRODING", 9, 228066},
	{"PICTURDS", 8, 228067},
	{"MAEKAWA", 7, 228068},
	{"EMIC", 4, 228069},
	{"OBLIGATOIRE", 11, 228070},
	{"DBMSS", 5, 228071},
	{"BEREANS", 7, 228072},
	{"RACTICE", 7, 228073},
	{"LINSLEY", 7, 228074},
	{"CHROMATOGRAPHS", 14, 228075},
	{"REGISTRERA", 10, 228076},
	{"FPCT", 4, 228077},
	{"ZULUBABY", 8, 228078},
	{"ZWICKER", 7, 228079},
	{"REKEYING", 8, 228080},
	{"NONCITIZEN", 10, 228081},
	{"STALAGMITES", 11, 228082},
	{"ORBITA", 6, 228083},
	{"SCREECHES", 9, 228084},
	{"MAQUINARIA", 10, 228085},
	{"ILRI", 4, 228086},
	{"ICECUBE", 7, 228087},
	{"CORONETS", 8, 228088},
	{"QUENCHES", 8, 228089},
	{"EMSL", 4, 228090},
	{"PIKETON", 7, 228091},
	{"OUTSCORING", 10, 228092},
	{"TELECASTING", 11, 228093},
	{"KAPPFINDER", 10, 228094},
	{"FUNDAMENT", 9, 228095},
	{"SOUVLAKI", 8, 228096},
	{"NOERROR", 7, 228097},
	{"COLLISIONLESS", 13, 228098},
	{"SOCIALTEXT", 10, 228099},
	{"PGES", 4, 228100},
	{"AFCEA", 5, 228101},
	{"PAGEA", 5, 228102},
	{"ESTATEREAL", 10, 228103},
	{"BELEID", 6, 228104},
	{"WGU", 3, 228105},
	{"THWACK", 6, 228106},
	{"PROVOSTS", 8, 228107},
	{"MYSERVER", 8, 228108},
	{"NOHUP", 5, 228109},
	{"TRIGGERFISH", 11, 228110},
	{"QUARTERM", 8, 228111},
	{"PINEVIEW", 8, 228112},
	{"PLAITING", 8, 228113},
	{"WAREHOUSEMAN", 12, 228114},
	{"GRODIN", 6, 228115},
	{"DOHME", 5, 228116},
	{"ATTRIBUTESET", 12, 228117},
	{"NITWIT", 6, 228118},
	{"GWANDALAN", 9, 228119},
	{"ZONKER", 6, 228120},
	{"PZEV", 4, 228121},
	{"PENDRY", 6, 228122},
	{"MAGNETEK", 8, 228123},
	{"KELTOSE", 7, 228124},
	{"HETTON", 6, 228125},
	{"DWINDLES", 8, 228126},
	{"SCQF", 4, 228127},
	{"THEYARE", 7, 228128},
	{"ZIUA", 4, 228129},
	{"PIFTURES", 8, 228130},
	{"MDLUG", 5, 228131},
	{"DOBYNS", 6, 228132},
	{"KRUDER", 6, 228133},
	{"IMPALING", 8, 228134},
	{"MJF", 3, 228135},
	{"MITTER", 6, 228136},
	{"CASEWORKS", 9, 228137},
	{"MALHAM", 6, 228138},
	{"LUMIDEE", 7, 228139},
	{"ENGELEN", 7, 228140},
	{"SPOOKINESS", 10, 228141},
	{"RUSKIE", 6, 228142},
	{"PUERARIA", 8, 228143},
	{"PHARMACEUTICA", 13, 228144},
	{"MEINERS", 7, 228145},
	{"TESTMART", 8, 228146},
	{"VETRI", 5, 228147},
	{"MICROPAYMENT", 12, 228148},
	{"CASSOULET", 9, 228149},
	{"APRN", 4, 228150},
	{"TOCOL", 5, 228151},
	{"MOLER", 5, 228152},
	{"LANDVIK", 7, 228153},
	{"ATASTEOFTWIKI", 13, 228154},
	{"LEJOS", 5, 228155},
	{"NETPOKER", 8, 228156},
	{"PIGOT", 5, 228157},
	{"ESPIRIT", 7, 228158},
	{"ENCINAL", 7, 228159},
	{"COMETA", 6, 228160},
	{"TRIFARI", 7, 228161},
	{"OURY", 4, 228162},
	{"CHRUCH", 6, 228163},
	{"TEXTIT", 6, 228164},
	{"GRIGORIEV", 9, 228165},
	{"MERES", 5, 228166},
	{"MAGALI", 6, 228167},
	{"COUETTE", 7, 228168},
	{"WORDTHEQUE", 10, 228169},
	{"TABARI", 6, 228170},
	{"MCGRORY", 7, 228171},
	{"LEADETH", 7, 228172},
	{"GELCAPS", 7, 228173},
	{"AENEUS", 6, 228174},
	{"CARRING", 7, 228175},
	{"AVAULT", 6, 228176},
	{"SOUPE", 5, 228177},
	{"SHARPDEVELOP", 12, 228178},
	{"MAMUT", 5, 228179},
	{"ALLOUEZ", 7, 228180},
	{"ERBEN", 5, 228181},
	{"MARLYS", 6, 228182},
	{"FARAGO", 6, 228183},
	{"BONIS", 5, 228184},
	{"WARNG", 5, 228185},
	{"ANNERLEY", 8, 228186},
	{"THORITY", 7, 228187},
	{"KATAKLYSM", 9, 228188},
	{"KAIYODO", 7, 228189},
	{"HUDE", 4, 228190},
	{"AZSHARA", 7, 228191},
	{"THEORETICIAN", 12, 228192},
	{"HUSKISSON", 9, 228193},
	{"ANACAPA", 7, 228194},
	{"DAVIDIC", 7, 228195},
	{"INHALTSVERZEICHNIS", 18, 228196},
	{"FLOWSCAN", 8, 228197},
	{"FINDCOMPONENTAT", 15, 228198},
	{"ELLIPSOMETRY", 12, 228199},
	{"BASEFLOW", 8, 228200},
	{"PJCTURES", 8, 228201},
	{"MONTON", 6, 228202},
	{"SINISTRA", 8, 228203},
	{"PREZZY", 6, 228204},
	{"JONGEN", 6, 228205},
	{"NETLIB", 6, 228206},
	{"GOMADIC", 7, 228207},
	{"AFTERWORDS", 10, 228208},
	{"SUBTERM", 7, 228209},
	{"DILBECK", 7, 228210},
	{"IPPF", 4, 228211},
	{"SCROUNGING", 10, 228212},
	{"SCOTISH", 7, 228213},
	{"INTERCEUTICALS", 14, 228214},
	{"ZYBI", 4, 228215},
	{"ZAAF", 4, 228216},
	{"YOAL", 4, 228217},
	{"YMIY", 4, 228218},
	{"XGUN", 4, 228219},
	{"XBYC", 4, 228220},
	{"WYLA", 4, 228221},
	{"WSYA", 4, 228222},
	{"WROG", 4, 228223},
	{"WPIS", 4, 228224},
	{"WEGH", 4, 228225},
	{"UTTK", 4, 228226},
	{"UGAU", 4, 228227},
	{"UCTQ", 4, 228228},
	{"TZOW", 4, 228229},
	{"SEYY", 4, 228230},
	{"SCMT", 4, 228231},
	{"RYIB", 4, 228232},
	{"RMOJ", 4, 228233},
	{"RJRO", 4, 228234},
	{"RIZR", 4, 228235},
	{"PRYT", 4, 228236},
	{"PMDR", 4, 228237},
	{"PIRT", 4, 228238},
	{"PDCO", 4, 228239},
	{"PCAI", 4, 228240},
	{"OZYH", 4, 228241},
	{"OUPQ", 4, 228242},
	{"OFWT", 4, 228243},
	{"NBPS", 4, 228244},
	{"NAYM", 4, 228245},
	{"MTID", 4, 228246},
	{"MOSY", 4, 228247},
	{"LIXL", 4, 228248},
	{"KLDQ", 4, 228249},
	{"JUIS", 4, 228250},
	{"JUBO", 4, 228251},
	{"JFRO", 4, 228252},
	{"GUTB", 4, 228253},
	{"FREX", 4, 228254},
	{"FMMO", 4, 228255},
	{"FCBR", 4, 228256},
	{"ETYZ", 4, 228257},
	{"EBSM", 4, 228258},
	{"DRPM", 4, 228259},
	{"DOXD", 4, 228260},
	{"DBIM", 4, 228261},
	{"CMUN", 4, 228262},
	{"CLUA", 4, 228263},
	{"CDBU", 4, 228264},
	{"BSHU", 4, 228265},
	{"BSAU", 4, 228266},
	{"BOIM", 4, 228267},
	{"BHBA", 4, 228268},
	{"ATPW", 4, 228269},
	{"ALUH", 4, 228270},
	{"AKGL", 4, 228271},
	{"AEBL", 4, 228272},
	{"NPTF", 4, 228273},
	{"LITIG", 5, 228274},
	{"GRANITOVO", 9, 228275},
	{"SDTC", 4, 228276},
	{"MODERNISTIC", 11, 228277},
	{"GALITZINE", 9, 228278},
	{"TRSMADOL", 8, 228279},
	{"NCIPHER", 7, 228280},
	{"SCIFINDER", 9, 228281},
	{"HIROFUMI", 8, 228282},
	{"ENWSHS", 6, 228283},
	{"COLORFORMS", 10, 228284},
	{"REPOSSESED", 10, 228285},
	{"QAMAR", 5, 228286},
	{"GROTTY", 6, 228287},
	{"TIPLER", 6, 228288},
	{"MMTV", 4, 228289},
	{"THEISS", 6, 228290},
	{"MICROWAVING", 11, 228291},
	{"KIRIUM", 6, 228292},
	{"BRANCATO", 8, 228293},
	{"JENETT", 6, 228294},
	{"GALLIVAN", 8, 228295},
	{"MAGNETI", 7, 228296},
	{"TOMKAT", 6, 228297},
	{"ICECAP", 6, 228298},
	{"SHAKESPEARIAN", 13, 228299},
	{"EISENMANN", 9, 228300},
	{"FISSIONABLE", 11, 228301},
	{"ANCY", 4, 228302},
	{"SELFMADE", 8, 228303},
	{"DEWDROP", 7, 228304},
	{"KFL", 3, 228305},
	{"INAPPROPRIATENESS", 17, 228306},
	{"FAVFORUMS", 9, 228307},
	{"BELIEVIN", 8, 228308},
	{"WOBBLERS", 8, 228309},
	{"WIECZOREK", 9, 228310},
	{"SQUAMATA", 8, 228311},
	{"SANMINA", 7, 228312},
	{"STEFANSSON", 10, 228313},
	{"SKIPPACK", 8, 228314},
	{"GUILTILY", 8, 228315},
	{"PUNTLAND", 8, 228316},
	{"MALVACEAE", 9, 228317},
	{"CLICKTHROUGH", 12, 228318},
	{"CLASSING", 8, 228319},
	{"TRITONS", 7, 228320},
	{"UXMAL", 5, 228321},
	{"RETROS", 6, 228322},
	{"NEUROTENSIN", 11, 228323},
	{"LYMPHOTROPIC", 12, 228324},
	{"BAUGHER", 7, 228325},
	{"RANDAZZO", 8, 228326},
	{"NAILHEAD", 8, 228327},
	{"EMERGENZA", 9, 228328},
	{"MOSKAU", 6, 228329},
	{"LITVAK", 6, 228330},
	{"DUALSHOCK", 9, 228331},
	{"SAGITARIUS", 10, 228332},
	{"HUFFED", 6, 228333},
	{"SWIZZ", 5, 228334},
	{"SLAVERS", 7, 228335},
	{"FREEDOMLINK", 11, 228336},
	{"TURNCOAT", 8, 228337},
	{"YIPEE", 5, 228338},
	{"QTDIR", 5, 228339},
	{"NONESTERIFIED", 13, 228340},
	{"DORSI", 5, 228341},
	{"SOMERDALE", 9, 228342},
	{"SABIA", 5, 228343},
	{"BRATMOBILE", 10, 228344},
	{"STOPCOCK", 8, 228345},
	{"DIFFUSIONS", 10, 228346},
	{"CERTINA", 7, 228347},
	{"NEWNODE", 7, 228348},
	{"MORPHEU", 7, 228349},
	{"SOLITARIO", 9, 228350},
	{"KANGRA", 6, 228351},
	{"CONVERTMOVIE", 12, 228352},
	{"LANDRITH", 8, 228353},
	{"COMMVAULT", 9, 228354},
	{"RUBRIEK", 7, 228355},
	{"KLAUSMEIER", 10, 228356},
	{"DISENTANGLING", 13, 228357},
	{"WAPDA", 5, 228358},
	{"SUCKO", 5, 228359},
	{"PERIODICO", 9, 228360},
	{"POLIE", 5, 228361},
	{"TESSMAN", 7, 228362},
	{"PLATAFORMAS", 11, 228363},
	{"NARD", 4, 228364},
	{"KIPPOT", 6, 228365},
	{"KASSEBAUM", 9, 228366},
	{"JURMALA", 7, 228367},
	{"APPELT", 6, 228368},
	{"ANNELIDA", 8, 228369},
	{"WHITBOURNE", 10, 228370},
	{"BERRYESSA", 9, 228371},
	{"SANATH", 6, 228372},
	{"MIPL", 4, 228373},
	{"CARSE", 5, 228374},
	{"BSMI", 4, 228375},
	{"ATLANT", 6, 228376},
	{"ANTAGONIZING", 12, 228377},
	{"MUB", 3, 228378},
	{"GURCHARAN", 9, 228379},
	{"ENOCHIAN", 8, 228380},
	{"TUNKU", 5, 228381},
	{"SSRL", 4, 228382},
	{"SCOTTISHPOWER", 13, 228383},
	{"RAFALE", 6, 228384},
	{"AIRTEX", 6, 228385},
	{"TREATER", 7, 228386},
	{"PERCEIVER", 9, 228387},
	{"IOANNIDIS", 9, 228388},
	{"REGISTRATE", 10, 228389},
	{"ILLSLEY", 7, 228390},
	{"SACKETS", 7, 228391},
	{"JAPN", 4, 228392},
	{"HITBOX", 6, 228393},
	{"COURTRIGHT", 10, 228394},
	{"PROGRAMER", 9, 228395},
	{"HOUNSOU", 7, 228396},
	{"LONGSUFFERING", 13, 228397},
	{"LABWINDOWS", 10, 228398},
	{"DRIVABLE", 8, 228399},
	{"PHAEDO", 6, 228400},
	{"PELLEY", 6, 228401},
	{"LEMO", 4, 228402},
	{"CATCHWORD", 9, 228403},
	{"PAVLA", 5, 228404},
	{"PARKASH", 7, 228405},
	{"VERBINDUNGEN", 12, 228406},
	{"KULM", 4, 228407},
	{"DCHS", 4, 228408},
	{"LOUNGIN", 7, 228409},
	{"LINKNET", 7, 228410},
	{"HUMPY", 5, 228411},
	{"CYMER", 5, 228412},
	{"ADVENTUS", 8, 228413},
	{"TEICHER", 7, 228414},
	{"BIOMET", 6, 228415},
	{"SUSPENCE", 8, 228416},
	{"MOHAMMADI", 9, 228417},
	{"WINCHCOMBE", 10, 228418},
	{"TEASPOONFULS", 12, 228419},
	{"MUGLO", 5, 228420},
	{"LAEMMLI", 7, 228421},
	{"ABELA", 5, 228422},
	{"PROCRASTINATORS", 15, 228423},
	{"PICX", 4, 228424},
	{"KELLERMANN", 10, 228425},
	{"IRFA", 4, 228426},
	{"BALLICOM", 8, 228427},
	{"POWN", 4, 228428},
	{"MCHF", 4, 228429},
	{"ESIASON", 7, 228430},
	{"KASIM", 5, 228431},
	{"SILKK", 5, 228432},
	{"AURALLY", 7, 228433},
	{"TETRACHLORODIBENZO", 18, 228434},
	{"QAIM", 4, 228435},
	{"NUCCI", 5, 228436},
	{"NFSMW", 5, 228437},
	{"SEEHERSQUIRT", 12, 228438},
	{"GRELL", 5, 228439},
	{"SHARPLESS", 9, 228440},
	{"ORNELLA", 7, 228441},
	{"KLEM", 4, 228442},
	{"COTTMAN", 7, 228443},
	{"ASSISTENTI", 10, 228444},
	{"MODELKA", 7, 228445},
	{"HERMINE", 7, 228446},
	{"MMSN", 4, 228447},
	{"GENERALY", 8, 228448},
	{"CERATO", 6, 228449},
	{"NOTETAKERS", 10, 228450},
	{"WIDEFIELD", 9, 228451},
	{"VRLA", 4, 228452},
	{"HANKIE", 6, 228453},
	{"TEAMCENTER", 10, 228454},
	{"SMITHIES", 8, 228455},
	{"MCGRAIL", 7, 228456},
	{"KETTEMAN", 8, 228457},
	{"SASLAUTHD", 9, 228458},
	{"ZBEI", 4, 228459},
	{"YMSN", 4, 228460},
	{"YMMI", 4, 228461},
	{"YFBI", 4, 228462},
	{"YCAO", 4, 228463},
	{"WNDW", 4, 228464},
	{"VURE", 4, 228465},
	{"VPHI", 4, 228466},
	{"VCIN", 4, 228467},
	{"USPM", 4, 228468},
	{"UBOX", 4, 228469},
	{"TSBB", 4, 228470},
	{"SBIM", 4, 228471},
	{"RGYJ", 4, 228472},
	{"RCDO", 4, 228473},
	{"PUAS", 4, 228474},
	{"PMYA", 4, 228475},
	{"OFHK", 4, 228476},
	{"NTUY", 4, 228477},
	{"NKBP", 4, 228478},
	{"NGMF", 4, 228479},
	{"NGHK", 4, 228480},
	{"NCGO", 4, 228481},
	{"MMWE", 4, 228482},
	{"MGAP", 4, 228483},
	{"MEYT", 4, 228484},
	{"MDOF", 4, 228485},
	{"MDEW", 4, 228486},
	{"LYMT", 4, 228487},
	{"LNSP", 4, 228488},
	{"JRSE", 4, 228489},
	{"JENW", 4, 228490},
	{"HJAG", 4, 228491},
	{"GYUD", 4, 228492},
	{"GYTI", 4, 228493},
	{"GTPE", 4, 228494},
	{"GJIG", 4, 228495},
	{"FSEY", 4, 228496},
	{"FRMA", 4, 228497},
	{"FRIJ", 4, 228498},
	{"FOWO", 4, 228499},
	{"FOMO", 4, 228500},
	{"FKOD", 4, 228501},
	{"DRDB", 4, 228502},
	{"DOGV", 4, 228503},
	{"DKHE", 4, 228504},
	{"DDYU", 4, 228505},
	{"DAXT", 4, 228506},
	{"AVFO", 4, 228507},
	{"APOZ", 4, 228508},
	{"LAMPUNG", 7, 228509},
	{"UNSTRETCHED", 11, 228510},
	{"RATEMYPROFESSORS", 16, 228511},
	{"MODELKI", 7, 228512},
	{"BUNGS", 5, 228513},
	{"ACQUAINTING", 11, 228514},
	{"BUCHHANDLUNG", 12, 228515},
	{"ARTIFICIELLE", 12, 228516},
	{"WEIGHER", 7, 228517},
	{"STORMIE", 7, 228518},
	{"SHOEDINI", 8, 228519},
	{"IMHOF", 5, 228520},
	{"SHITLESS", 8, 228521},
	{"SCHONBERG", 9, 228522},
	{"AUTHENTICATIONS", 15, 228523},
	{"CCRMA", 5, 228524},
	{"NCSY", 4, 228525},
	{"KRASH", 5, 228526},
	{"HYPERCAPNIA", 11, 228527},
	{"ROADWARRIOR", 11, 228528},
	{"VERAGE", 6, 228529},
	{"NORDIQUES", 9, 228530},
	{"LEARNABLE", 9, 228531},
	{"ARKADIA", 7, 228532},
	{"TROXLER", 7, 228533},
	{"POVICH", 6, 228534},
	{"MKDOC", 5, 228535},
	{"TWITTERING", 10, 228536},
	{"SCHLITT", 7, 228537},
	{"OERTEL", 6, 228538},
	{"CODIE", 5, 228539},
	{"TIERGARTEN", 10, 228540},
	{"SAIZEN", 6, 228541},
	{"ORDINA", 6, 228542},
	{"MAFFIA", 6, 228543},
	{"JUNIPERO", 8, 228544},
	{"SILVERPOP", 9, 228545},
	{"WISERADVISOR", 12, 228546},
	{"SCUPPER", 7, 228547},
	{"CWIDTH", 6, 228548},
	{"YELTON", 6, 228549},
	{"HAMLETT", 7, 228550},
	{"CUCURBITA", 9, 228551},
	{"CHANGSHU", 8, 228552},
	{"QUANTIAN", 8, 228553},
	{"OORD", 4, 228554},
	{"MELH", 4, 228555},
	{"INSKEEP", 7, 228556},
	{"EPIPOLAR", 8, 228557},
	{"TREATM", 6, 228558},
	{"GULZAR", 6, 228559},
	{"DATASECURE", 10, 228560},
	{"ANELKA", 6, 228561},
	{"CAMPOLO", 7, 228562},
	{"REPAVING", 8, 228563},
	{"ROOSE", 5, 228564},
	{"ORBITED", 7, 228565},
	{"DIRECTAMENTE", 12, 228566},
	{"HEVESI", 6, 228567},
	{"CROWNSVILLE", 11, 228568},
	{"PATCHBAY", 8, 228569},
	{"AUDIOMETER", 10, 228570},
	{"PIXELBRIGHT", 11, 228571},
	{"GAMERDAD", 8, 228572},
	{"CTORS", 5, 228573},
	{"EMASCULATED", 11, 228574},
	{"DINESEN", 7, 228575},
	{"ARIRANG", 7, 228576},
	{"INHALES", 7, 228577},
	{"LYMPHATICS", 10, 228578},
	{"ADLINGTON", 9, 228579},
	{"WOODFLOOR", 9, 228580},
	{"RESERCH", 7, 228581},
	{"COMMENTSPOST", 12, 228582},
	{"IFTIKHAR", 8, 228583},
	{"UHLMANN", 7, 228584},
	{"NAMSE", 5, 228585},
	{"BROTHS", 6, 228586},
	{"WENDIGO", 7, 228587},
	{"SHROVE", 6, 228588},
	{"LANDISVILLE", 11, 228589},
	{"GOVENMENT", 9, 228590},
	{"ECAUSE", 6, 228591},
	{"DISENFRANCHISE", 14, 228592},
	{"SMALLMAN", 8, 228593},
	{"KEYBO", 5, 228594},
	{"BEMBO", 5, 228595},
	{"PINACEAE", 8, 228596},
	{"ABBS", 4, 228597},
	{"STRIXADERM", 10, 228598},
	{"DZISIAJ", 7, 228599},
	{"TASSIN", 6, 228600},
	{"SEBASTES", 8, 228601},
	{"ARWAIN", 6, 228602},
	{"NEWEDN", 6, 228603},
	{"CALIFORNICUS", 12, 228604},
	{"ARWEINIAD", 9, 228605},
	{"ZIMBABAWE", 9, 228606},
	{"BAUX", 4, 228607},
	{"MGU", 3, 228608},
	{"ACHIVED", 7, 228609},
	{"SHOPRITE", 8, 228610},
	{"HESELTINE", 9, 228611},
	{"DEVGAN", 6, 228612},
	{"CERIAS", 6, 228613},
	{"ALLOZYME", 8, 228614},
	{"AUGURS", 6, 228615},
	{"ADMIRINGLY", 10, 228616},
	{"KNAUER", 6, 228617},
	{"INGLETON", 8, 228618},
	{"EISEMAN", 7, 228619},
	{"AROD", 4, 228620},
	{"CINEREUS", 8, 228621},
	{"STAUROSPORINE", 13, 228622},
	{"LITNET", 6, 228623},
	{"JPF", 3, 228624},
	{"ILLUMINE", 8, 228625},
	{"PECES", 5, 228626},
	{"MIDSPAN", 7, 228627},
	{"IMADA", 5, 228628},
	{"MALGORZATA", 10, 228629},
	{"WRATHER", 7, 228630},
	{"NATIONALIZE", 11, 228631},
	{"LJB", 3, 228632},
	{"SAIGA", 5, 228633},
	{"AFOY", 4, 228634},
	{"SELTEN", 6, 228635},
	{"SALESWOMAN", 10, 228636},
	{"EPISKECH", 8, 228637},
	{"KALIL", 5, 228638},
	{"MASACCIO", 8, 228639},
	{"LECTRONIC", 9, 228640},
	{"AWFULNESS", 9, 228641},
	{"PHOTOPHOBIA", 11, 228642},
	{"PECHINEY", 8, 228643},
	{"NOKESVILLE", 10, 228644},
	{"STREETLIFE", 10, 228645},
	{"PERSPECTIVA", 11, 228646},
	{"TRACADIE", 8, 228647},
	{"SLACKED", 7, 228648},
	{"PRIMEBIN", 8, 228649},
	{"MYOD", 4, 228650},
	{"BONDHUS", 7, 228651},
	{"POLPERRO", 8, 228652},
	{"POOPREPORT", 10, 228653},
	{"PALET", 5, 228654},
	{"OVERFLIGHTS", 11, 228655},
	{"AUTOLOADERS", 11, 228656},
	{"MANNSVILLE", 10, 228657},
	{"INNERSCAN", 9, 228658},
	{"MOVINGLY", 8, 228659},
	{"LOLIT", 5, 228660},
	{"COWNLOADS", 9, 228661},
	{"ENCAMP", 6, 228662},
	{"REPRISED", 8, 228663},
	{"FREEXP", 6, 228664},
	{"WIREPLAY", 8, 228665},
	{"TAVERNITI", 9, 228666},
	{"HENCEFORWARD", 12, 228667},
	{"EADING", 6, 228668},
	{"BMDO", 4, 228669},
	{"SCALPED", 7, 228670},
	{"HOLZMANN", 8, 228671},
	{"FRUSTUM", 7, 228672},
	{"CFRE", 4, 228673},
	{"INTERESANTE", 11, 228674},
	{"TRIGO", 5, 228675},
	{"QUEENSTON", 9, 228676},
	{"RICER", 5, 228677},
	{"MONTHLONG", 9, 228678},
	{"WOMANIZING", 10, 228679},
	{"HUDDLING", 8, 228680},
	{"CONTOOCOOK", 10, 228681},
	{"PELOTAS", 7, 228682},
	{"TAUTOLOGICAL", 12, 228683},
	{"IGNAZIO", 7, 228684},
	{"GAUGER", 6, 228685},
	{"HTMW", 4, 228686},
	{"COFAB", 5, 228687},
	{"SYNTHELABO", 10, 228688},
	{"ERFOLG", 6, 228689},
	{"ALLOWABILITY", 12, 228690},
	{"LTCC", 4, 228691},
	{"REWRITERS", 9, 228692},
	{"COMBATED", 8, 228693},
	{"MRJ", 3, 228694},
	{"HOGLUND", 7, 228695},
	{"PIGGLY", 6, 228696},
	{"PARESTHESIA", 11, 228697},
	{"CULTIVO", 7, 228698},
	{"CAPITOLO", 8, 228699},
	{"PECATONICA", 10, 228700},
	{"ALVINA", 6, 228701},
	{"ZIJE", 4, 228702},
	{"YKEH", 4, 228703},
	{"XUSH", 4, 228704},
	{"XREQ", 4, 228705},
	{"XMSA", 4, 228706},
	{"WSUT", 4, 228707},
	{"WDVD", 4, 228708},
	{"VVYS", 4, 228709},
	{"VLER", 4, 228710},
	{"VIRC", 4, 228711},
	{"VIPL", 4, 228712},
	{"UYDA", 4, 228713},
	{"UXMO", 4, 228714},
	{"UTMT", 4, 228715},
	{"UOTY", 4, 228716},
	{"TZLO", 4, 228717},
	{"TLYZ", 4, 228718},
	{"TAVM", 4, 228719},
	{"SUPQ", 4, 228720},
	{"RZOE", 4, 228721},
	{"RUDS", 4, 228722},
	{"RUAD", 4, 228723},
	{"RMUI", 4, 228724},
	{"RMSQ", 4, 228725},
	{"RJOG", 4, 228726},
	{"RIJS", 4, 228727},
	{"RGVO", 4, 228728},
	{"RGSN", 4, 228729},
	{"RAEK", 4, 228730},
	{"ONFF", 4, 228731},
	{"OGIW", 4, 228732},
	{"NOVK", 4, 228733},
	{"NMPI", 4, 228734},
	{"NGVL", 4, 228735},
	{"NDNV", 4, 228736},
	{"NAZM", 4, 228737},
	{"MAGT", 4, 228738},
	{"LQAS", 4, 228739},
	{"LEVR", 4, 228740},
	{"KGTO", 4, 228741},
	{"JUKS", 4, 228742},
	{"IWAG", 4, 228743},
	{"HUZA", 4, 228744},
	{"HAKB", 4, 228745},
	{"GUSJ", 4, 228746},
	{"GDOP", 4, 228747},
	{"FFGL", 4, 228748},
	{"EYND", 4, 228749},
	{"EJFK", 4, 228750},
	{"DLWA", 4, 228751},
	{"CODB", 4, 228752},
	{"CHLT", 4, 228753},
	{"CEZI", 4, 228754},
	{"AFSB", 4, 228755},
	{"AFCP", 4, 228756},
	{"ABYY", 4, 228757},
	{"WEXNER", 6, 228758},
	{"CETANE", 6, 228759},
	{"TIPPAH", 6, 228760},
	{"UNCORRUPTED", 11, 228761},
	{"SKARHEAD", 8, 228762},
	{"SABOL", 5, 228763},
	{"PIEVE", 5, 228764},
	{"CMDLNE", 6, 228765},
	{"ADDALL", 6, 228766},
	{"GALECTIN", 8, 228767},
	{"CANAM", 5, 228768},
	{"NEWSLOG", 7, 228769},
	{"ARTSJOURNAL", 11, 228770},
	{"KELLOG", 6, 228771},
	{"TONGEREN", 8, 228772},
	{"HARTWOOD", 8, 228773},
	{"GUAYANA", 7, 228774},
	{"ACTIVEROLES", 11, 228775},
	{"UPHPU", 5, 228776},
	{"FOURWAYS", 8, 228777},
	{"AIRLINEC", 8, 228778},
	{"VISCLOSKY", 9, 228779},
	{"NETWORKCOM", 10, 228780},
	{"EVINCES", 7, 228781},
	{"DWAN", 4, 228782},
	{"MCGUINESS", 9, 228783},
	{"PCODE", 5, 228784},
	{"HARJO", 5, 228785},
	{"ZONK", 4, 228786},
	{"PEDICURISTS", 11, 228787},
	{"CHAUNCY", 7, 228788},
	{"STEVEDORE", 9, 228789},
	{"PARASITIZED", 11, 228790},
	{"KHAWAJA", 7, 228791},
	{"CAERNARVON", 10, 228792},
	{"UNEMP", 5, 228793},
	{"TOCAR", 5, 228794},
	{"LEEVES", 6, 228795},
	{"JINGOISTIC", 10, 228796},
	{"DIFICULT", 8, 228797},
	{"BUTTONHOLES", 11, 228798},
	{"MUTOMBO", 7, 228799},
	{"INTERPOLATES", 12, 228800},
	{"DUELISTS", 8, 228801},
	{"COMPARACION", 11, 228802},
	{"UNFERTILIZED", 12, 228803},
	{"BARCROFT", 8, 228804},
	{"NAVIDATA", 8, 228805},
	{"HWNNW", 5, 228806},
	{"PRESBYTERS", 10, 228807},
	{"DROZD", 5, 228808},
	{"TOYNAMI", 7, 228809},
	{"BEERDOM", 7, 228810},
	{"BANGALOW", 8, 228811},
	{"INTERDIMENSIONAL", 16, 228812},
	{"INTELLECTUELLE", 14, 228813},
	{"BELGUIM", 7, 228814},
	{"ARGINASE", 8, 228815},
	{"VENTANAS", 8, 228816},
	{"SLINGERS", 8, 228817},
	{"RANKTARD", 8, 228818},
	{"PRESIDENTAL", 11, 228819},
	{"METASCORES", 10, 228820},
	{"FAIG", 4, 228821},
	{"CPDN", 4, 228822},
	{"BEAUPREZ", 8, 228823},
	{"DOTNETJUNKIES", 13, 228824},
	{"RACCOMANDO", 10, 228825},
	{"ISFULLOFCRAP", 12, 228826},
	{"SABBATINI", 9, 228827},
	{"SKIMS", 5, 228828},
	{"MARGRETHE", 9, 228829},
	{"NOVELAS", 7, 228830},
	{"NOBEYAMA", 8, 228831},
	{"SUBCLASSED", 10, 228832},
	{"SHAWNE", 6, 228833},
	{"MEDICINALLY", 11, 228834},
	{"FUV", 3, 228835},
	{"ERICS", 5, 228836},
	{"SOMESUCH", 8, 228837},
	{"SMOOTHY", 7, 228838},
	{"CATALOUGE", 9, 228839},
	{"ROCKLIFFE", 9, 228840},
	{"POWESHIEK", 9, 228841},
	{"MORBIUS", 7, 228842},
	{"SINERGIE", 8, 228843},
	{"MOBE", 4, 228844},
	{"JENNETTE", 8, 228845},
	{"ROEDY", 5, 228846},
	{"MELODRAMAS", 10, 228847},
	{"BLAMEBUSH", 9, 228848},
	{"AMRYWIAETH", 10, 228849},
	{"SELLES", 6, 228850},
	{"LUNGFISH", 8, 228851},
	{"GRAYSTON", 8, 228852},
	{"ERSTES", 6, 228853},
	{"TUTUS", 5, 228854},
	{"AFOSR", 5, 228855},
	{"WUTS", 4, 228856},
	{"JUSSIEU", 7, 228857},
	{"ARMETALE", 8, 228858},
	{"REDLICH", 7, 228859},
	{"KEREM", 5, 228860},
	{"PROBANDS", 8, 228861},
	{"CHAPO", 5, 228862},
	{"WERNHER", 7, 228863},
	{"MOLDFLOW", 8, 228864},
	{"DIWYDIANT", 9, 228865},
	{"ILSLEY", 6, 228866},
	{"PMAKE", 5, 228867},
	{"ATLANTEANS", 10, 228868},
	{"GKB", 3, 228869},
	{"PAKUMA", 6, 228870},
	{"TREVILLE", 8, 228871},
	{"FREDRICKS", 9, 228872},
	{"ATCM", 4, 228873},
	{"PASSWORDED", 10, 228874},
	{"CHUPADAS", 8, 228875},
	{"TTBB", 4, 228876},
	{"MERCHANDISES", 12, 228877},
	{"GRIDER", 6, 228878},
	{"CORELLA", 7, 228879},
	{"LONGCILS", 8, 228880},
	{"VETERINARIA", 11, 228881},
	{"LAEGER", 6, 228882},
	{"ESSIG", 5, 228883},
	{"EVREUX", 6, 228884},
	{"RYLEY", 5, 228885},
	{"FENSKE", 6, 228886},
	{"FANIA", 5, 228887},
	{"WAKUNAGA", 8, 228888},
	{"PAMBAZUKA", 9, 228889},
	{"ANTABUSE", 8, 228890},
	{"WEYERS", 6, 228891},
	{"TURNBUCKLES", 11, 228892},
	{"HEISEI", 6, 228893},
	{"GEWINNEN", 8, 228894},
	{"LAIL", 4, 228895},
	{"DEPUTED", 7, 228896},
	{"BFARBER", 7, 228897},
	{"CLAMBERING", 10, 228898},
	{"BOUTONNIERE", 11, 228899},
	{"BONEME", 6, 228900},
	{"ISDC", 4, 228901},
	{"FACIALE", 7, 228902},
	{"DSTBLOCK", 8, 228903},
	{"BECKERT", 7, 228904},
	{"PLACITAS", 8, 228905},
	{"MANETTI", 7, 228906},
	{"FLESHTONE", 9, 228907},
	{"WISHBONES", 9, 228908},
	{"KROW", 4, 228909},
	{"ETHODS", 6, 228910},
	{"COMBR", 5, 228911},
	{"TERRORISMO", 10, 228912},
	{"SURPLICE", 8, 228913},
	{"GBMS", 4, 228914},
	{"KROFT", 5, 228915},
	{"SILLYBONN", 9, 228916},
	{"SABIC", 5, 228917},
	{"PEEPSHOWS", 9, 228918},
	{"NEWFILE", 7, 228919},
	{"FACTITIOUS", 10, 228920},
	{"WEIHAI", 6, 228921},
	{"STRIVINGS", 9, 228922},
	{"POSESS", 6, 228923},
	{"GLOBIGERINA", 11, 228924},
	{"EXPOSEDFIELD", 12, 228925},
	{"LAGARDE", 7, 228926},
	{"GLITCHY", 7, 228927},
	{"CONVOCATIONS", 12, 228928},
	{"HEYWORTH", 8, 228929},
	{"DOSBARTH", 8, 228930},
	{"PHASOR", 6, 228931},
	{"FITFULLY", 8, 228932},
	{"PRIVACYEXCHANGE", 15, 228933},
	{"KOMMUNE", 7, 228934},
	{"IOAPIC", 6, 228935},
	{"REARM", 5, 228936},
	{"RECHANNEL", 9, 228937},
	{"NOBILI", 6, 228938},
	{"HALTERNECK", 10, 228939},
	{"WHITEHORN", 9, 228940},
	{"COMYN", 5, 228941},
	{"CHANCY", 6, 228942},
	{"BORELLI", 7, 228943},
	{"EBOR", 4, 228944},
	{"DAMODARAN", 9, 228945},
	{"WWWHOT", 6, 228946},
	{"SUPERINTERFACES", 15, 228947},
	{"SPORTBACK", 9, 228948},
	{"SIMSOM", 6, 228949},
	{"SCANDINOVA", 10, 228950},
	{"VOLTEXX", 7, 228951},
	{"IMMINENCE", 9, 228952},
	{"POSTIE", 6, 228953},
	{"OROGEN", 6, 228954},
	{"GILDEA", 6, 228955},
	{"FREEN", 5, 228956},
	{"MARMO", 5, 228957},
	{"ITACHI", 6, 228958},
	{"RELEASI", 7, 228959},
	{"VREDE", 5, 228960},
	{"DECIMATING", 10, 228961},
	{"BEACHS", 6, 228962},
	{"ASCANIO", 7, 228963},
	{"ZYWE", 4, 228964},
	{"YUMP", 4, 228965},
	{"XELP", 4, 228966},
	{"WRMA", 4, 228967},
	{"WRDE", 4, 228968},
	{"VETK", 4, 228969},
	{"VDPR", 4, 228970},
	{"UWME", 4, 228971},
	{"UMOO", 4, 228972},
	{"UGFL", 4, 228973},
	{"TMLW", 4, 228974},
	{"TIRB", 4, 228975},
	{"TCLY", 4, 228976},
	{"STKL", 4, 228977},
	{"SPAJ", 4, 228978},
	{"RROK", 4, 228979},
	{"RPEH", 4, 228980},
	{"RNTM", 4, 228981},
	{"RIKG", 4, 228982},
	{"RBDO", 4, 228983},
	{"OEMR", 4, 228984},
	{"NMCO", 4, 228985},
	{"NFFA", 4, 228986},
	{"NCJA", 4, 228987},
	{"LVST", 4, 228988},
	{"LNFO", 4, 228989},
	{"JIRG", 4, 228990},
	{"ISBB", 4, 228991},
	{"INVR", 4, 228992},
	{"INRF", 4, 228993},
	{"IMBP", 4, 228994},
	{"HIUR", 4, 228995},
	{"GTCA", 4, 228996},
	{"GMSF", 4, 228997},
	{"FMBR", 4, 228998},
	{"ERJT", 4, 228999},
	{"EORZ", 4, 229000},
	{"EDHC", 4, 229001},
	{"DWUL", 4, 229002},
	{"DPSH", 4, 229003},
	{"DMWA", 4, 229004},
	{"DAOB", 4, 229005},
	{"CHZI", 4, 229006},
	{"CELG", 4, 229007},
	{"BHPK", 4, 229008},
	{"AZEY", 4, 229009},
	{"ALGP", 4, 229010},
	{"AILQ", 4, 229011},
	{"ADRH", 4, 229012},
	{"CONINE", 6, 229013},
	{"PERISHES", 8, 229014},
	{"NICOLAAS", 8, 229015},
	{"AMENA", 5, 229016},
	{"TRIFOCAL", 8, 229017},
	{"SPORTSCENE", 10, 229018},
	{"SIGNETMARINE", 12, 229019},
	{"SHANKILL", 8, 229020},
	{"GEBHART", 7, 229021},
	{"COOLPLAYER", 10, 229022},
	{"SOSDG", 5, 229023},
	{"REINOUT", 7, 229024},
	{"HOLDFAST", 8, 229025},
	{"ONCLE", 5, 229026},
	{"AUSTINS", 7, 229027},
	{"TERMINOS", 8, 229028},
	{"ISOFIX", 6, 229029},
	{"BAUWESEN", 8, 229030},
	{"WAKELEY", 7, 229031},
	{"NEUROPSYCHOLOGIST", 17, 229032},
	{"PRIVADAS", 8, 229033},
	{"DARWINIST", 9, 229034},
	{"OTAVALO", 7, 229035},
	{"ANNESS", 6, 229036},
	{"SARRIS", 6, 229037},
	{"NUTRITI", 7, 229038},
	{"LAISSE", 6, 229039},
	{"KIPNIS", 6, 229040},
	{"UNWATCHABLE", 11, 229041},
	{"BRATHWAITE", 10, 229042},
	{"TTANEWELEMENT", 13, 229043},
	{"NAMLOOK", 7, 229044},
	{"CABER", 5, 229045},
	{"BLANCHES", 8, 229046},
	{"ATERIALS", 8, 229047},
	{"NOKYA", 5, 229048},
	{"MIREK", 5, 229049},
	{"DIGIGRAM", 8, 229050},
	{"ONGARO", 6, 229051},
	{"BOSTONS", 7, 229052},
	{"VIEILLES", 8, 229053},
	{"SKULKING", 8, 229054},
	{"MYSUPERSALES", 12, 229055},
	{"RATIONALISING", 13, 229056},
	{"ETOUFFEE", 8, 229057},
	{"VOISEY", 6, 229058},
	{"GIRLING", 7, 229059},
	{"FOWLIE", 6, 229060},
	{"THRELKELD", 9, 229061},
	{"NAURA", 5, 229062},
	{"ILOKO", 5, 229063},
	{"BOLLEN", 6, 229064},
	{"ADVENTUR", 8, 229065},
	{"TAKAKI", 6, 229066},
	{"MAGINNIS", 8, 229067},
	{"FLAVEL", 6, 229068},
	{"FACTORES", 8, 229069},
	{"EMBRAPA", 7, 229070},
	{"WIKISANDBOX", 11, 229071},
	{"MULTIGRADE", 10, 229072},
	{"RCODE", 5, 229073},
	{"LYNNDIE", 7, 229074},
	{"WINELEGEND", 10, 229075},
	{"EAKER", 5, 229076},
	{"WILTERN", 7, 229077},
	{"PILLBUGS", 8, 229078},
	{"SHEDIAC", 7, 229079},
	{"MOUNTPOINT", 10, 229080},
	{"LIFEBRIDGE", 10, 229081},
	{"HEMPZ", 5, 229082},
	{"BRAGGIN", 7, 229083},
	{"STELLING", 8, 229084},
	{"SPLENOCYTES", 11, 229085},
	{"SONGHUA", 7, 229086},
	{"SCANA", 5, 229087},
	{"SLATHERED", 9, 229088},
	{"MARQUI", 6, 229089},
	{"DEMUR", 5, 229090},
	{"JEROD", 5, 229091},
	{"HICKLING", 8, 229092},
	{"AFSPC", 5, 229093},
	{"BEACHBALL", 9, 229094},
	{"CWSP", 4, 229095},
	{"PREFILLED", 9, 229096},
	{"DECUS", 5, 229097},
	{"QLABEL", 6, 229098},
	{"PLOEG", 5, 229099},
	{"FIZIKA", 6, 229100},
	{"HERBRAND", 8, 229101},
	{"GOLOVIN", 7, 229102},
	{"UBV", 3, 229103},
	{"PRAVETS", 7, 229104},
	{"BELLVUE", 7, 229105},
	{"ARDLEIGH", 8, 229106},
	{"ROSATO", 6, 229107},
	{"LEIXLIP", 7, 229108},
	{"FIREANT", 7, 229109},
	{"SLOPER", 6, 229110},
	{"SINUSOIDS", 9, 229111},
	{"MICKE", 5, 229112},
	{"GRAVIDANZA", 10, 229113},
	{"DIMETHYLAMINE", 13, 229114},
	{"STOCKINETTE", 11, 229115},
	{"FAEGRE", 6, 229116},
	{"ZARISKI", 7, 229117},
	{"PTYS", 4, 229118},
	{"WESTRA", 6, 229119},
	{"MONSTROUSLY", 11, 229120},
	{"CEFNOGAETH", 10, 229121},
	{"TACTICK", 7, 229122},
	{"RINER", 5, 229123},
	{"WGK", 3, 229124},
	{"POKERHTTP", 9, 229125},
	{"AGRIUM", 6, 229126},
	{"ESPANHOL", 8, 229127},
	{"CHWT", 4, 229128},
	{"BERGNER", 7, 229129},
	{"JERMAN", 6, 229130},
	{"GANDHIAN", 8, 229131},
	{"COMMUNICANT", 11, 229132},
	{"ANISSA", 6, 229133},
	{"WISECRACKING", 12, 229134},
	{"IMPOSTS", 7, 229135},
	{"PROFESSEURS", 11, 229136},
	{"LARIO", 5, 229137},
	{"DUPIN", 5, 229138},
	{"DOWSETT", 7, 229139},
	{"SPATHIPHYLLUM", 13, 229140},
	{"GOUVEIA", 7, 229141},
	{"BUTTERFLYS", 10, 229142},
	{"TARBES", 6, 229143},
	{"OVERO", 5, 229144},
	{"JAYARAMAN", 9, 229145},
	{"ECHOLINK", 8, 229146},
	{"SARASVATI", 9, 229147},
	{"HURLBERT", 8, 229148},
	{"DANTZLER", 8, 229149},
	{"WILLOWICK", 9, 229150},
	{"MATCHTECH", 9, 229151},
	{"POLIFONICOS", 11, 229152},
	{"HARTEMINK", 9, 229153},
	{"PROBABILISTICALLY", 17, 229154},
	{"AMDANOM", 7, 229155},
	{"LOMMEL", 6, 229156},
	{"JARD", 4, 229157},
	{"SHUSHAN", 7, 229158},
	{"NEOWAVE", 7, 229159},
	{"EMBARASS", 8, 229160},
	{"COULON", 6, 229161},
	{"PROPHETICALLY", 13, 229162},
	{"EQUIWORLD", 9, 229163},
	{"ACTAULLY", 8, 229164},
	{"POLYFONISET", 11, 229165},
	{"USFILTER", 8, 229166},
	{"RAFFLED", 7, 229167},
	{"NEUTRALISATION", 14, 229168},
	{"NGBK", 4, 229169},
	{"ANAKOINWSH", 10, 229170},
	{"AMORA", 5, 229171},
	{"VANGUARDIA", 10, 229172},
	{"DIWEDDARAF", 10, 229173},
	{"LISHMENT", 8, 229174},
	{"CURETON", 7, 229175},
	{"QUIRKINESS", 10, 229176},
	{"RESETTER", 8, 229177},
	{"DUXTON", 6, 229178},
	{"BIZBEN", 6, 229179},
	{"GURKHAS", 7, 229180},
	{"BRIGADA", 7, 229181},
	{"POWERNN", 7, 229182},
	{"ROYALTEK", 8, 229183},
	{"JANSCH", 6, 229184},
	{"MXD", 3, 229185},
	{"FUGACITY", 8, 229186},
	{"ESCOFFIER", 9, 229187},
	{"NOWAKOWSKI", 10, 229188},
	{"MORGAGNI", 8, 229189},
	{"OMADA", 5, 229190},
	{"LATTIMER", 8, 229191},
	{"FMLN", 4, 229192},
	{"ZEYAD", 5, 229193},
	{"VIREAD", 6, 229194},
	{"SOCIOL", 6, 229195},
	{"PEOPKE", 6, 229196},
	{"MONTANANS", 9, 229197},
	{"BLUGIRL", 7, 229198},
	{"AUTORECONF", 10, 229199},
	{"PMRA", 4, 229200},
	{"APRENDIZAJE", 11, 229201},
	{"MUJHE", 5, 229202},
	{"GAAL", 4, 229203},
	{"KEHLER", 6, 229204},
	{"WHIGHAM", 7, 229205},
	{"TULELAKE", 8, 229206},
	{"PUBLIKATION", 11, 229207},
	{"DIAPHANOUS", 10, 229208},
	{"BACTROBAN", 9, 229209},
	{"MUNTEN", 6, 229210},
	{"FLEXTIME", 8, 229211},
	{"LEVERED", 7, 229212},
	{"HSDB", 4, 229213},
	{"PHOTOPRINT", 10, 229214},
	{"WILDTANGENT", 11, 229215},
	{"VOLLMANN", 8, 229216},
	{"SYMUD", 5, 229217},
	{"EGMOND", 6, 229218},
	{"DEALEY", 6, 229219},
	{"BACKCROSS", 9, 229220},
	{"ZUIS", 4, 229221},
	{"ZCAP", 4, 229222},
	{"YCKO", 4, 229223},
	{"XIVO", 4, 229224},
	{"WWSP", 4, 229225},
	{"WWPE", 4, 229226},
	{"WKON", 4, 229227},
	{"UYEO", 4, 229228},
	{"USYU", 4, 229229},
	{"UNYS", 4, 229230},
	{"TYRY", 4, 229231},
	{"TLLD", 4, 229232},
	{"SZEC", 4, 229233},
	{"SWLA", 4, 229234},
	{"SVPO", 4, 229235},
	{"SLCD", 4, 229236},
	{"SCSM", 4, 229237},
	{"PYAM", 4, 229238},
	{"PAYJ", 4, 229239},
	{"OWOD", 4, 229240},
	{"OSXW", 4, 229241},
	{"OCML", 4, 229242},
	{"NRRE", 4, 229243},
	{"NRFC", 4, 229244},
	{"NDXP", 4, 229245},
	{"LNED", 4, 229246},
	{"LNBC", 4, 229247},
	{"LIYI", 4, 229248},
	{"KYLU", 4, 229249},
	{"KUAB", 4, 229250},
	{"KTIV", 4, 229251},
	{"KOUI", 4, 229252},
	{"KIKY", 4, 229253},
	{"JGRA", 4, 229254},
	{"IEUC", 4, 229255},
	{"HEUU", 4, 229256},
	{"GUMD", 4, 229257},
	{"GUIW", 4, 229258},
	{"FMFO", 4, 229259},
	{"FJOL", 4, 229260},
	{"ERLG", 4, 229261},
	{"EMMT", 4, 229262},
	{"EDXP", 4, 229263},
	{"EDQB", 4, 229264},
	{"EDPJ", 4, 229265},
	{"EDKC", 4, 229266},
	{"EBHP", 4, 229267},
	{"DLCA", 4, 229268},
	{"CBHA", 4, 229269},
	{"BHUG", 4, 229270},
	{"AJDE", 4, 229271},
	{"TRIENNIUM", 9, 229272},
	{"THEODOSIA", 9, 229273},
	{"KRAG", 4, 229274},
	{"BILLINGSHURST", 13, 229275},
	{"DOKO", 4, 229276},
	{"COLOME", 6, 229277},
	{"TSORIES", 7, 229278},
	{"STUDYFINDER", 11, 229279},
	{"NANAB", 5, 229280},
	{"YANEZ", 5, 229281},
	{"SOSENDERS", 9, 229282},
	{"SEINDAL", 7, 229283},
	{"ADDRS", 5, 229284},
	{"WEBKATALOG", 10, 229285},
	{"ONITORING", 9, 229286},
	{"JLR", 3, 229287},
	{"GREYLISTING", 11, 229288},
	{"PCURRENTAB", 10, 229289},
	{"NOACH", 5, 229290},
	{"LIGAS", 5, 229291},
	{"KEYINFO", 7, 229292},
	{"SPAZZ", 5, 229293},
	{"MOTEN", 5, 229294},
	{"ISNAR", 5, 229295},
	{"HUMACAO", 7, 229296},
	{"TOPSTYLE", 8, 229297},
	{"RESPIRONICS", 11, 229298},
	{"HARWIN", 6, 229299},
	{"BUIDLING", 8, 229300},
	{"WAGGED", 6, 229301},
	{"SUFFIXED", 8, 229302},
	{"RUBBERISED", 10, 229303},
	{"POLLIO", 6, 229304},
	{"FALAISE", 7, 229305},
	{"AURANTIUM", 9, 229306},
	{"MSESSION", 8, 229307},
	{"RIOG", 4, 229308},
	{"REMBRANDTS", 10, 229309},
	{"BOOKHOME", 8, 229310},
	{"BARCH", 5, 229311},
	{"APACHEDS", 8, 229312},
	{"AANBOD", 6, 229313},
	{"DOKEOS", 6, 229314},
	{"CARDREADER", 10, 229315},
	{"PITSEA", 6, 229316},
	{"CLEANIN", 7, 229317},
	{"ZEITRAUM", 8, 229318},
	{"SIGNIFICADO", 11, 229319},
	{"GOREAN", 6, 229320},
	{"FROHLICH", 8, 229321},
	{"SERVICEPOWER", 12, 229322},
	{"NEWCITY", 7, 229323},
	{"ROXANN", 6, 229324},
	{"MOTHERLOAD", 10, 229325},
	{"KACHEMAK", 8, 229326},
	{"EXTRAVAGANTE", 12, 229327},
	{"AMCS", 4, 229328},
	{"NACHR", 5, 229329},
	{"FIENDISHLY", 10, 229330},
	{"UNIQUEID", 8, 229331},
	{"MORPHES", 7, 229332},
	{"PLATOS", 6, 229333},
	{"DEXTOR", 6, 229334},
	{"COPPERMAN", 9, 229335},
	{"RHOMBIC", 7, 229336},
	{"BLITZEN", 7, 229337},
	{"ANSHAN", 6, 229338},
	{"XETEX", 5, 229339},
	{"DANTRONICS", 10, 229340},
	{"WENAUS", 6, 229341},
	{"SCIECE", 6, 229342},
	{"RELEARNING", 10, 229343},
	{"NETPANZER", 9, 229344},
	{"BURGLARIZED", 11, 229345},
	{"BRUCKMAN", 8, 229346},
	{"SHITEATERS", 10, 229347},
	{"ENTERPRISESTORAGEFORUM", 22, 229348},
	{"PLATFORMING", 11, 229349},
	{"MUZZLELOADERS", 13, 229350},
	{"IMMORTALISED", 12, 229351},
	{"MICEGAMES", 9, 229352},
	{"AGMS", 4, 229353},
	{"WEBCLIENT", 9, 229354},
	{"SPRUCING", 8, 229355},
	{"ORTHOPEDIST", 11, 229356},
	{"MEDOR", 5, 229357},
	{"GONIOMETER", 10, 229358},
	{"APARECE", 7, 229359},
	{"DWELE", 5, 229360},
	{"GARRAN", 6, 229361},
	{"AREVALO", 7, 229362},
	{"ARISH", 5, 229363},
	{"STRICTA", 7, 229364},
	{"ILISTEN", 7, 229365},
	{"DIPLOMARBEIT", 12, 229366},
	{"EQUALISE", 8, 229367},
	{"DEBTAGS", 7, 229368},
	{"VILKA", 5, 229369},
	{"PUMKIN", 6, 229370},
	{"ESMF", 4, 229371},
	{"KIERLAND", 8, 229372},
	{"COMMANDEER", 10, 229373},
	{"AVPS", 4, 229374},
	{"APPLESHARE", 10, 229375},
	{"PEBEO", 5, 229376},
	{"JDIKE", 5, 229377},
	{"FIAIF", 5, 229378},
	{"ELLERBECK", 9, 229379},
	{"VAREPSILON", 10, 229380},
	{"AUTOSPEED", 9, 229381},
	{"REEDED", 6, 229382},
	{"NANANGO", 7, 229383},
	{"SYSRQ", 5, 229384},
	{"ROSSELLA", 8, 229385},
	{"REACTIVITIES", 12, 229386},
	{"IMAGIPLAY", 9, 229387},
	{"HALONS", 6, 229388},
	{"DSPU", 4, 229389},
	{"CBCN", 4, 229390},
	{"ROSENKRANZ", 10, 229391},
	{"MALINI", 6, 229392},
	{"HAGINO", 6, 229393},
	{"EXTRAGEAR", 9, 229394},
	{"ANGULATION", 10, 229395},
	{"SIROTABLOG", 10, 229396},
	{"MINDEF", 6, 229397},
	{"BLAAUWBERG", 10, 229398},
	{"LICATA", 6, 229399},
	{"DAILYBUILD", 10, 229400},
	{"HARRER", 6, 229401},
	{"COOLO", 5, 229402},
	{"SUBGENRES", 9, 229403},
	{"PORTSLADE", 9, 229404},
	{"NCPC", 4, 229405},
	{"INFELD", 6, 229406},
	{"BLAINVILLE", 10, 229407},
	{"SHINSEKI", 8, 229408},
	{"VIDEOCD", 7, 229409},
	{"BALUSTER", 8, 229410},
	{"TICHENOR", 8, 229411},
	{"LATKI", 5, 229412},
	{"HAUSSLER", 8, 229413},
	{"PERADVENTURE", 12, 229414},
	{"LADYWOOD", 8, 229415},
	{"FLCI", 4, 229416},
	{"RHIENI", 6, 229417},
	{"GATIONS", 7, 229418},
	{"BRMC", 4, 229419},
	{"PSYCHOBABBLE", 12, 229420},
	{"LPVOID", 6, 229421},
	{"ZYGO", 4, 229422},
	{"TOKAMAKS", 8, 229423},
	{"METZELER", 8, 229424},
	{"ACATS", 5, 229425},
	{"SYMTAB", 6, 229426},
	{"SPERMICIDAL", 11, 229427},
	{"SAFETYNET", 9, 229428},
	{"MORIENTES", 9, 229429},
	{"MEGHA", 5, 229430},
	{"HEUSTON", 7, 229431},
	{"VEGWEB", 6, 229432},
	{"HDHP", 4, 229433},
	{"SFTWARE", 7, 229434},
	{"FAILE", 5, 229435},
	{"XOWNLOADS", 9, 229436},
	{"MEWITHOUTYOU", 12, 229437},
	{"GIBLE", 5, 229438},
	{"DRKVENGER", 9, 229439},
	{"BUGET", 5, 229440},
	{"KRITI", 5, 229441},
	{"FACEP", 5, 229442},
	{"SCHIPUL", 7, 229443},
	{"LADI", 4, 229444},
	{"COPAYS", 6, 229445},
	{"BACKSTREETS", 11, 229446},
	{"STOCKTAKE", 9, 229447},
	{"SURMOUNTING", 11, 229448},
	{"ORIGINA", 7, 229449},
	{"EARWIG", 6, 229450},
	{"BETTLES", 7, 229451},
	{"COMPOSTABLE", 11, 229452},
	{"RADIOLOCATION", 13, 229453},
	{"RSSRSS", 6, 229454},
	{"SATYRS", 6, 229455},
	{"REZILLOS", 8, 229456},
	{"NEUKIRCHEN", 10, 229457},
	{"SIRACH", 6, 229458},
	{"OPTIMO", 6, 229459},
	{"MINITER", 7, 229460},
	{"IJTIHAD", 7, 229461},
	{"SWATTING", 8, 229462},
	{"BOOKSPRODUCT", 12, 229463},
	{"ALIGATOR", 8, 229464},
	{"PEMPHIGOID", 10, 229465},
	{"CONSPECIFIC", 11, 229466},
	{"HANSBERRY", 9, 229467},
	{"VORICONAZOLE", 12, 229468},
	{"OUTREACHES", 10, 229469},
	{"ARACHNOPHOBIA", 13, 229470},
	{"BIALA", 5, 229471},
	{"VAPRO", 5, 229472},
	{"KINKAID", 7, 229473},
	{"KDWP", 4, 229474},
	{"HALLYDAY", 8, 229475},
	{"BIOREGIONAL", 11, 229476},
	{"SPACELIKE", 9, 229477},
	{"SOLEAS", 6, 229478},
	{"OMMENDED", 8, 229479},
	{"MQX", 3, 229480},
	{"INVIERNO", 8, 229481},
	{"GRANDSIRE", 9, 229482},
	{"FELICITAS", 9, 229483},
	{"ETHYLENEDIAMINE", 15, 229484},
	{"ELASTICALLY", 11, 229485},
	{"BOOKLAND", 8, 229486},
	{"SUBMERSIBLES", 12, 229487},
	{"MILKA", 5, 229488},
	{"EVASIONS", 8, 229489},
	{"EEBAY", 5, 229490},
	{"METING", 6, 229491},
	{"BIOCOMPUTING", 12, 229492},
	{"HALTWHISTLE", 11, 229493},
	{"POSTVILLE", 9, 229494},
	{"FOSSELLA", 8, 229495},
	{"CORNU", 5, 229496},
	{"ZPRI", 4, 229497},
	{"YDRH", 4, 229498},
	{"WYEL", 4, 229499},
	{"VPET", 4, 229500},
	{"VAAG", 4, 229501},
	{"UYIM", 4, 229502},
	{"URCC", 4, 229503},
	{"UODH", 4, 229504},
	{"UHOR", 4, 229505},
	{"TYLS", 4, 229506},
	{"TTKU", 4, 229507},
	{"RPBR", 4, 229508},
	{"RLKE", 4, 229509},
	{"RDCY", 4, 229510},
	{"PUNH", 4, 229511},
	{"PTOZ", 4, 229512},
	{"OPGL", 4, 229513},
	{"ONWG", 4, 229514},
	{"ONUF", 4, 229515},
	{"OKOJ", 4, 229516},
	{"OFLV", 4, 229517},
	{"OBBT", 4, 229518},
	{"NVIJ", 4, 229519},
	{"NICZ", 4, 229520},
	{"NFMR", 4, 229521},
	{"MWAC", 4, 229522},
	{"MAMF", 4, 229523},
	{"LUXW", 4, 229524},
	{"LSZA", 4, 229525},
	{"LSGY", 4, 229526},
	{"LJUG", 4, 229527},
	{"KAYG", 4, 229528},
	{"HCUN", 4, 229529},
	{"GMCN", 4, 229530},
	{"GEZI", 4, 229531},
	{"GDHA", 4, 229532},
	{"GATQ", 4, 229533},
	{"FMYU", 4, 229534},
	{"FLOH", 4, 229535},
	{"FJED", 4, 229536},
	{"EXOB", 4, 229537},
	{"EVUV", 4, 229538},
	{"ERJH", 4, 229539},
	{"EMGS", 4, 229540},
	{"DZIS", 4, 229541},
	{"DOEC", 4, 229542},
	{"DMFO", 4, 229543},
	{"DKIB", 4, 229544},
	{"DIOY", 4, 229545},
	{"DBEZ", 4, 229546},
	{"DAQD", 4, 229547},
	{"CNOL", 4, 229548},
	{"BAKL", 4, 229549},
	{"AYRY", 4, 229550},
	{"SHOREY", 6, 229551},
	{"GROUPSETS", 9, 229552},
	{"TOWELING", 8, 229553},
	{"SUDOKO", 6, 229554},
	{"BOSSERT", 7, 229555},
	{"VOLVOS", 6, 229556},
	{"RUYTER", 6, 229557},
	{"OVITZ", 5, 229558},
	{"MAPILAB", 7, 229559},
	{"AUTHTYPE", 8, 229560},
	{"WEBSTUFF", 8, 229561},
	{"SPECULATIVELY", 13, 229562},
	{"WASTEGATE", 9, 229563},
	{"LYCAN", 5, 229564},
	{"NOUSE", 5, 229565},
	{"LINHA", 5, 229566},
	{"PPX", 3, 229567},
	{"EOWNLOADS", 9, 229568},
	{"LUMBERED", 8, 229569},
	{"HANGUPS", 7, 229570},
	{"DESERIALIZATION", 15, 229571},
	{"CORTEGE", 7, 229572},
	{"WAVETEK", 7, 229573},
	{"SOLDEIRS", 8, 229574},
	{"PALLAVI", 7, 229575},
	{"GAMEDATE", 8, 229576},
	{"AUTOLYSIS", 9, 229577},
	{"PREQ", 4, 229578},
	{"PACOLET", 7, 229579},
	{"MAGISTERS", 9, 229580},
	{"CARCIERI", 8, 229581},
	{"GEOTECHNICS", 11, 229582},
	{"FILMAFFINITY", 12, 229583},
	{"ROWNUM", 6, 229584},
	{"ARIGATO", 7, 229585},
	{"ALBIAN", 6, 229586},
	{"SLIGHTY", 7, 229587},
	{"OPTEK", 5, 229588},
	{"DIAMAGNETIC", 11, 229589},
	{"CHUBAIS", 7, 229590},
	{"THOTICON", 8, 229591},
	{"RIFA", 4, 229592},
	{"GORKHAPATRA", 11, 229593},
	{"BETHANIA", 8, 229594},
	{"SEGAP", 5, 229595},
	{"FERNHURST", 9, 229596},
	{"LINDERMAN", 9, 229597},
	{"ABCIXIMAB", 9, 229598},
	{"TEAIRRA", 7, 229599},
	{"SLAVONIA", 8, 229600},
	{"CURRIN", 6, 229601},
	{"CALLPATH", 8, 229602},
	{"APRSD", 5, 229603},
	{"ZZIPLIB", 7, 229604},
	{"SERICE", 6, 229605},
	{"MANHANDLED", 10, 229606},
	{"KIDSTUFF", 8, 229607},
	{"JEAGLEN", 7, 229608},
	{"AMRA", 4, 229609},
	{"QUANTLIB", 8, 229610},
	{"KINGSMEN", 8, 229611},
	{"BREV", 4, 229612},
	{"RAPIDEMENT", 10, 229613},
	{"RADICALIZED", 11, 229614},
	{"PORVOO", 6, 229615},
	{"MHMR", 4, 229616},
	{"LAHOOD", 6, 229617},
	{"WATARU", 6, 229618},
	{"MAKEDONIA", 9, 229619},
	{"JAZZWISE", 8, 229620},
	{"FOSSTON", 7, 229621},
	{"ENCTYPE", 7, 229622},
	{"RIDGETOWN", 9, 229623},
	{"INCWM", 5, 229624},
	{"BOPPIN", 6, 229625},
	{"WOEXP", 5, 229626},
	{"DISPOSTO", 8, 229627},
	{"KPFLEMING", 9, 229628},
	{"CONMEBOL", 8, 229629},
	{"CHLOROMETHYL", 12, 229630},
	{"SARATXAGA", 9, 229631},
	{"COUNTENANCES", 12, 229632},
	{"LIPLINER", 8, 229633},
	{"TWEB", 4, 229634},
	{"PATTE", 5, 229635},
	{"COLSTRIP", 8, 229636},
	{"BEHOLDS", 7, 229637},
	{"WWWHOTMAIL", 10, 229638},
	{"MIETE", 5, 229639},
	{"MCCLARY", 7, 229640},
	{"IKKOKU", 6, 229641},
	{"ROLLATOR", 8, 229642},
	{"PROPLUS", 7, 229643},
	{"HITTERSALL", 10, 229644},
	{"CONTRADISTINCTION", 17, 229645},
	{"BAZEMORE", 8, 229646},
	{"ADEWALE", 7, 229647},
	{"SCAMPERING", 10, 229648},
	{"LLORO", 5, 229649},
	{"AKADEMII", 8, 229650},
	{"NEELAM", 6, 229651},
	{"GORDIMER", 8, 229652},
	{"TOURNA", 6, 229653},
	{"ATTYS", 5, 229654},
	{"WEEDSPORT", 9, 229655},
	{"HEDDEN", 6, 229656},
	{"ANDREESSEN", 10, 229657},
	{"KADI", 4, 229658},
	{"AZONETWORK", 10, 229659},
	{"WAGAR", 5, 229660},
	{"TERPENE", 7, 229661},
	{"GERED", 5, 229662},
	{"WARDOUR", 7, 229663},
	{"WINDOWSINSTALLCOOKBOOK", 22, 229664},
	{"GENEALOGIE", 10, 229665},
	{"SUDOCS", 6, 229666},
	{"ALVEAR", 6, 229667},
	{"XRV", 3, 229668},
	{"SAINTED", 7, 229669},
	{"MEDER", 5, 229670},
	{"BASTER", 6, 229671},
	{"PERIVASCULAR", 12, 229672},
	{"PEEDEE", 6, 229673},
	{"INCLUSIVELY", 11, 229674},
	{"AUSTINVILLE", 11, 229675},
	{"MINIJACK", 8, 229676},
	{"KORNBERG", 8, 229677},
	{"HANKYU", 6, 229678},
	{"MANORIAL", 8, 229679},
	{"JECFA", 5, 229680},
	{"FERRUCCIO", 9, 229681},
	{"WORKPAPERS", 10, 229682},
	{"KOPPERS", 7, 229683},
	{"KETTLEBELLS", 11, 229684},
	{"INGLORIOUS", 10, 229685},
	{"GATTIS", 6, 229686},
	{"CONTRARIO", 9, 229687},
	{"DIVID", 5, 229688},
	{"HAMMERMILL", 10, 229689},
	{"PENNISETUM", 10, 229690},
	{"CONSPICUITY", 11, 229691},
	{"ARMATA", 6, 229692},
	{"WHEREAT", 7, 229693},
	{"MCNISH", 6, 229694},
	{"ELECTA", 6, 229695},
	{"TETOVO", 6, 229696},
	{"SIGLE", 5, 229697},
	{"NONAPPROPRIATED", 15, 229698},
	{"GARANTIA", 8, 229699},
	{"RAGHURAM", 8, 229700},
	{"OBIETTIVI", 9, 229701},
	{"JOLO", 4, 229702},
	{"BOOKCLOSEOUTS", 13, 229703},
	{"CARBINOXAMINE", 13, 229704},
	{"CHILCOTT", 8, 229705},
	{"REMOVABLY", 9, 229706},
	{"NEVADO", 6, 229707},
	{"KMOD", 4, 229708},
	{"ONOFF", 5, 229709},
	{"NEWSIZE", 7, 229710},
	{"DAEDELUS", 8, 229711},
	{"PRIMEGRID", 9, 229712},
	{"LECHLADE", 8, 229713},
	{"INTERBREEDING", 13, 229714},
	{"ACIER", 5, 229715},
	{"FIBBER", 6, 229716},
	{"PERSONNELTODAY", 14, 229717},
	{"NUCE", 4, 229718},
	{"FLAVESCENS", 10, 229719},
	{"GEARHEADS", 9, 229720},
	{"MARGINATA", 9, 229721},
	{"LIBVIPS", 7, 229722},
	{"GLUEING", 7, 229723},
	{"ONBODY", 6, 229724},
	{"AFFTON", 6, 229725},
	{"MCGRANE", 7, 229726},
	{"DISCUTER", 8, 229727},
	{"ULTRASUEDE", 10, 229728},
	{"PERPETUITIES", 12, 229729},
	{"MEMEX", 5, 229730},
	{"FARRUGIA", 8, 229731},
	{"KRATON", 6, 229732},
	{"PORG", 4, 229733},
	{"MCTEAGUE", 8, 229734},
	{"PRANDTL", 7, 229735},
	{"MENAFN", 6, 229736},
	{"ZPUB", 4, 229737},
	{"YTHL", 4, 229738},
	{"YJOD", 4, 229739},
	{"VOME", 4, 229740},
	{"VOLY", 4, 229741},
	{"VEEW", 4, 229742},
	{"VADR", 4, 229743},
	{"UNKJ", 4, 229744},
	{"UFEI", 4, 229745},
	{"TEXX", 4, 229746},
	{"TCDA", 4, 229747},
	{"TBSD", 4, 229748},
	{"SSRD", 4, 229749},
	{"SGYP", 4, 229750},
	{"RUKM", 4, 229751},
	{"RTCT", 4, 229752},
	{"RPGF", 4, 229753},
	{"PDWI", 4, 229754},
	{"OXSM", 4, 229755},
	{"OPPP", 4, 229756},
	{"OFPK", 4, 229757},
	{"NQUR", 4, 229758},
	{"NIKD", 4, 229759},
	{"MWIE", 4, 229760},
	{"MMAV", 4, 229761},
	{"LVDB", 4, 229762},
	{"LNGA", 4, 229763},
	{"LBAV", 4, 229764},
	{"LAYZ", 4, 229765},
	{"KMHS", 4, 229766},
	{"KHIZ", 4, 229767},
	{"KGAP", 4, 229768},
	{"IPOB", 4, 229769},
	{"HNLL", 4, 229770},
	{"HLPR", 4, 229771},
	{"HKKI", 4, 229772},
	{"HGOP", 4, 229773},
	{"GHMS", 4, 229774},
	{"FTEG", 4, 229775},
	{"FRSI", 4, 229776},
	{"ELND", 4, 229777},
	{"DZEK", 4, 229778},
	{"DPMC", 4, 229779},
	{"CWAI", 4, 229780},
	{"BIFY", 4, 229781},
	{"BEYG", 4, 229782},
	{"AVWH", 4, 229783},
	{"AMYU", 4, 229784},
	{"OPTOCOUPLER", 11, 229785},
	{"MONITOARE", 9, 229786},
	{"NALC", 4, 229787},
	{"MUNIER", 6, 229788},
	{"NEITZEL", 7, 229789},
	{"FLIGHTSEEING", 12, 229790},
	{"SHOREA", 6, 229791},
	{"CHROMOSPHERIC", 13, 229792},
	{"DSMC", 4, 229793},
	{"TENEBRAE", 8, 229794},
	{"ROVOS", 5, 229795},
	{"NORMALIZER", 10, 229796},
	{"LEAUGE", 6, 229797},
	{"JERZ", 4, 229798},
	{"GOOGLIE", 7, 229799},
	{"IMIQUIMOD", 9, 229800},
	{"GRAVEOLENS", 10, 229801},
	{"MYFUTURE", 8, 229802},
	{"GOODBODY", 8, 229803},
	{"FAIRUZA", 7, 229804},
	{"NORTHCOM", 8, 229805},
	{"MONDOR", 6, 229806},
	{"DUITSE", 6, 229807},
	{"IMAGEWORKS", 10, 229808},
	{"WINDEMERE", 9, 229809},
	{"INVAR", 5, 229810},
	{"COMMERCIALISING", 15, 229811},
	{"RISSE", 5, 229812},
	{"KRAKOWSKI", 9, 229813},
	{"FEYRER", 6, 229814},
	{"AMOY", 4, 229815},
	{"DIVINERS", 8, 229816},
	{"BIDENS", 6, 229817},
	{"CHARLOTTA", 9, 229818},
	{"BISHAN", 6, 229819},
	{"ANAFEREI", 8, 229820},
	{"NDCS", 4, 229821},
	{"CELANDINE", 9, 229822},
	{"SKYTRONIC", 9, 229823},
	{"PHOTOSTAMPS", 11, 229824},
	{"MARSHMAN", 8, 229825},
	{"CSAK", 4, 229826},
	{"LUNDS", 5, 229827},
	{"DANGO", 5, 229828},
	{"RESYNCED", 8, 229829},
	{"DEFRAYED", 8, 229830},
	{"BECUSE", 6, 229831},
	{"HOUSEBUILDING", 13, 229832},
	{"DTORIES", 7, 229833},
	{"BEUTEL", 6, 229834},
	{"VEURE", 5, 229835},
	{"TELECOMUNICATIONS", 17, 229836},
	{"SKATALITES", 10, 229837},
	{"SERBAN", 6, 229838},
	{"LOVEROCK", 8, 229839},
	{"IRREDUCIBLY", 11, 229840},
	{"INCREASETH", 10, 229841},
	{"CLAYFIELD", 9, 229842},
	{"NUTRIBASE", 9, 229843},
	{"KIRCHEN", 7, 229844},
	{"MERRYTHOUGHT", 12, 229845},
	{"INGRESSO", 8, 229846},
	{"FUMIGATED", 9, 229847},
	{"TOTTERIDGE", 10, 229848},
	{"ANIMOWANE", 9, 229849},
	{"SLPS", 4, 229850},
	{"GSME", 4, 229851},
	{"QUINELLA", 8, 229852},
	{"ELEAZER", 7, 229853},
	{"ATTAL", 5, 229854},
	{"PELPLE", 6, 229855},
	{"MONOPLANE", 9, 229856},
	{"JEBCO", 5, 229857},
	{"HUALAPAI", 8, 229858},
	{"ETTIQUETTE", 10, 229859},
	{"KAUM", 4, 229860},
	{"GILLE", 5, 229861},
	{"SCRENSAVERS", 11, 229862},
	{"OVERTAXED", 9, 229863},
	{"FUTUROS", 7, 229864},
	{"REAPPOINT", 9, 229865},
	{"TYPESTYLER", 10, 229866},
	{"FONTWARE", 8, 229867},
	{"TROUVEREZ", 9, 229868},
	{"TANSU", 5, 229869},
	{"POSITIVO", 8, 229870},
	{"MOONFLOWER", 10, 229871},
	{"MELQUI", 6, 229872},
	{"RECOGNIZABLY", 12, 229873},
	{"REPUDIATING", 11, 229874},
	{"PROAUDIO", 8, 229875},
	{"VILLIAGE", 8, 229876},
	{"KOCSIS", 6, 229877},
	{"HEYDRICH", 8, 229878},
	{"CMCS", 4, 229879},
	{"CARESSA", 7, 229880},
	{"PRIMARE", 7, 229881},
	{"KASAL", 5, 229882},
	{"HOLESHOT", 8, 229883},
	{"SUPERPRO", 8, 229884},
	{"STIRIES", 7, 229885},
	{"SEMIPRO", 7, 229886},
	{"PFSENSE", 7, 229887},
	{"DICALCIUM", 9, 229888},
	{"BICHES", 6, 229889},
	{"HAZELHURST", 10, 229890},
	{"FFEP", 4, 229891},
	{"BARSUK", 6, 229892},
	{"USROWING", 8, 229893},
	{"CANYONEERING", 12, 229894},
	{"DALIDA", 6, 229895},
	{"PRESNELL", 8, 229896},
	{"XREPORTER", 9, 229897},
	{"PRAX", 4, 229898},
	{"LOGOSETS", 8, 229899},
	{"THALE", 5, 229900},
	{"MEDWATCH", 8, 229901},
	{"EBBAY", 5, 229902},
	{"CAROLINIANA", 11, 229903},
	{"TREMELY", 7, 229904},
	{"MANUREWA", 8, 229905},
	{"BIMMER", 6, 229906},
	{"VELTRI", 6, 229907},
	{"SCHOTTENSTEIN", 13, 229908},
	{"FREDDI", 6, 229909},
	{"AUTOLOADING", 11, 229910},
	{"SIXTOO", 6, 229911},
	{"CUIT", 4, 229912},
	{"CHONE", 5, 229913},
	{"ALEXZ", 5, 229914},
	{"RATKO", 5, 229915},
	{"CANCAN", 6, 229916},
	{"INSUPPORTABLE", 13, 229917},
	{"BRAHIM", 6, 229918},
	{"AAARGH", 6, 229919},
	{"UNDERUTILIZATION", 16, 229920},
	{"TAWANA", 6, 229921},
	{"SUNDOWNERS", 10, 229922},
	{"FUSILLI", 7, 229923},
	{"AGRONOMISTS", 11, 229924},
	{"KIDSGROVE", 9, 229925},
	{"ARITHMETICS", 11, 229926},
	{"WOMWN", 5, 229927},
	{"RASCO", 5, 229928},
	{"PERMENANT", 9, 229929},
	{"CAROLLA", 7, 229930},
	{"SWADES", 6, 229931},
	{"MOULTONBORO", 11, 229932},
	{"STROHM", 6, 229933},
	{"CHARLEE", 7, 229934},
	{"TXGENWEB", 8, 229935},
	{"TRAVL", 5, 229936},
	{"RECOMMANDER", 11, 229937},
	{"COFIDIS", 7, 229938},
	{"CHURCHILLS", 10, 229939},
	{"AMERICN", 7, 229940},
	{"UNITEDLINUX", 11, 229941},
	{"REIFEN", 6, 229942},
	{"GASTROCNEMIUS", 13, 229943},
	{"FLSHING", 7, 229944},
	{"ILLINOISE", 9, 229945},
	{"ILLICH", 6, 229946},
	{"PERSONER", 8, 229947},
	{"PDBSUM", 6, 229948},
	{"CATWEAZLE", 9, 229949},
	{"INSCAPE", 7, 229950},
	{"PRNO", 4, 229951},
	{"VTAC", 4, 229952},
	{"SMCS", 4, 229953},
	{"WHORF", 5, 229954},
	{"BAYANIHAN", 9, 229955},
	{"PAINSWICK", 9, 229956},
	{"LUVIN", 5, 229957},
	{"PRODN", 5, 229958},
	{"DPSCH", 5, 229959},
	{"GORECKI", 7, 229960},
	{"DOROTA", 6, 229961},
	{"UNDISGUISED", 11, 229962},
	{"SCIENCENET", 10, 229963},
	{"PIANI", 5, 229964},
	{"HISSAR", 6, 229965},
	{"WITHNAIL", 8, 229966},
	{"TAGLE", 5, 229967},
	{"RECOLOR", 7, 229968},
	{"KALEV", 5, 229969},
	{"FIELDTRIPS", 10, 229970},
	{"SYMBOLISING", 11, 229971},
	{"VILLALBA", 8, 229972},
	{"METISGEN", 8, 229973},
	{"JPNIC", 5, 229974},
	{"ZZIH", 4, 229975},
	{"ZOIL", 4, 229976},
	{"ZODA", 4, 229977},
	{"ZLEE", 4, 229978},
	{"ZBLU", 4, 229979},
	{"YCID", 4, 229980},
	{"XLEO", 4, 229981},
	{"WVIT", 4, 229982},
	{"VWEN", 4, 229983},
	{"VRAS", 4, 229984},
	{"VCTO", 4, 229985},
	{"URBM", 4, 229986},
	{"UFON", 4, 229987},
	{"UBOB", 4, 229988},
	{"TJRS", 4, 229989},
	{"THDD", 4, 229990},
	{"SGOK", 4, 229991},
	{"RSMM", 4, 229992},
	{"RNZO", 4, 229993},
	{"RKUH", 4, 229994},
	{"REBP", 4, 229995},
	{"PWAG", 4, 229996},
	{"PMYD", 4, 229997},
	{"PKYL", 4, 229998},
	{"OFUV", 4, 229999},
	{"OFHW", 4, 230000},
	{"NZUM", 4, 230001},
	{"NDVM", 4, 230002},
	{"NCSB", 4, 230003},
	{"MEZC", 4, 230004},
	{"LKOB", 4, 230005},
	{"LGUD", 4, 230006},
	{"LFKE", 4, 230007},
	{"LFFW", 4, 230008},
	{"LETX", 4, 230009},
	{"KMLA", 4, 230010},
	{"IXGI", 4, 230011},
	{"IROJ", 4, 230012},
	{"ILAX", 4, 230013},
	{"HLSM", 4, 230014},
	{"GYMP", 4, 230015},
	{"GVIV", 4, 230016},
	{"GIAV", 4, 230017},
	{"FOBI", 4, 230018},
	{"FNUE", 4, 230019},
	{"EWOX", 4, 230020},
	{"EVUS", 4, 230021},
	{"EMNP", 4, 230022},
	{"EDLM", 4, 230023},
	{"ECMU", 4, 230024},
	{"DYRH", 4, 230025},
	{"DKIO", 4, 230026},
	{"DFSO", 4, 230027},
	{"CRTH", 4, 230028},
	{"COOU", 4, 230029},
	{"CKNY", 4, 230030},
	{"CFCO", 4, 230031},
	{"BTLI", 4, 230032},
	{"BMWW", 4, 230033},
	{"BKEL", 4, 230034},
	{"BFLE", 4, 230035},
	{"BBUB", 4, 230036},
	{"BBBE", 4, 230037},
	{"AHUP", 4, 230038},
	{"STOCKQUOTES", 11, 230039},
	{"SNASW", 5, 230040},
	{"LUMIQUEST", 9, 230041},
	{"TRUNNION", 8, 230042},
	{"SHITHOLE", 8, 230043},
	{"KIRSH", 5, 230044},
	{"INFORMATIZATION", 15, 230045},
	{"SOLDOUT", 7, 230046},
	{"SOCIALISTA", 10, 230047},
	{"HOTMAILS", 8, 230048},
	{"COREZYN", 7, 230049},
	{"LURCHES", 7, 230050},
	{"POLITIX", 7, 230051},
	{"NTFP", 4, 230052},
	{"HARNISH", 7, 230053},
	{"GITOMER", 7, 230054},
	{"DRUMROLL", 8, 230055},
	{"BECQUEREL", 9, 230056},
	{"STORMTRACKER", 12, 230057},
	{"ROMULO", 6, 230058},
	{"AUTOSHOW", 8, 230059},
	{"PHSC", 4, 230060},
	{"PERFECTDISK", 11, 230061},
	{"MENDIETA", 8, 230062},
	{"ADULTERESS", 10, 230063},
	{"ADRIATICO", 9, 230064},
	{"MICROMECHANICAL", 15, 230065},
	{"JACOBSSON", 9, 230066},
	{"AUSTRIAMICROSYSTEMS", 19, 230067},
	{"SYNTAGMA", 8, 230068},
	{"SHINOZAKI", 9, 230069},
	{"GASTROPARESIS", 13, 230070},
	{"BYM", 3, 230071},
	{"INGIN", 5, 230072},
	{"IBROX", 5, 230073},
	{"SUGI", 4, 230074},
	{"DORNBRACHT", 10, 230075},
	{"DECIDUA", 7, 230076},
	{"NEWF", 4, 230077},
	{"HENLEYS", 7, 230078},
	{"AURELIE", 7, 230079},
	{"AUTOCHTHONOUS", 13, 230080},
	{"TRUSTIVE", 8, 230081},
	{"SEGAR", 5, 230082},
	{"DISCERNS", 8, 230083},
	{"TENDERIZER", 10, 230084},
	{"OREBRO", 6, 230085},
	{"BOOKCLUBS", 9, 230086},
	{"PULSADO", 7, 230087},
	{"HABIBIE", 7, 230088},
	{"TRAVELDRIVE", 11, 230089},
	{"LOGW", 4, 230090},
	{"QUAEDA", 6, 230091},
	{"OSTEOLOGY", 9, 230092},
	{"HALLING", 7, 230093},
	{"BUXTEHUDE", 9, 230094},
	{"SACTOWN", 7, 230095},
	{"ITALK", 5, 230096},
	{"BOLEROS", 7, 230097},
	{"AHONEN", 6, 230098},
	{"TFTPD", 5, 230099},
	{"UNVESTED", 8, 230100},
	{"SONNING", 7, 230101},
	{"TANTUM", 6, 230102},
	{"FARVEBILLEDER", 13, 230103},
	{"CHICLANA", 8, 230104},
	{"AIRSHED", 7, 230105},
	{"RANDALLS", 8, 230106},
	{"GLADBACH", 8, 230107},
	{"FINANS", 6, 230108},
	{"DBGSS", 5, 230109},
	{"ALTAMENTE", 9, 230110},
	{"ALLERGENICITY", 13, 230111},
	{"SADER", 5, 230112},
	{"GAMAY", 5, 230113},
	{"DARIUSH", 7, 230114},
	{"OMEGAS", 6, 230115},
	{"HYER", 4, 230116},
	{"GNATSWEB", 8, 230117},
	{"FORMBUILDER", 11, 230118},
	{"UNINET", 6, 230119},
	{"OPENRPG", 7, 230120},
	{"NORDQUIST", 9, 230121},
	{"MINOA", 5, 230122},
	{"LINKZ", 5, 230123},
	{"EUROPHYSICS", 11, 230124},
	{"CONVATEC", 8, 230125},
	{"SQUAWKS", 7, 230126},
	{"SILKWORMS", 9, 230127},
	{"XQL", 3, 230128},
	{"KINESYS", 7, 230129},
	{"USBL", 4, 230130},
	{"SURGEARREST", 11, 230131},
	{"KURNOOL", 7, 230132},
	{"JUDEN", 5, 230133},
	{"FYTD", 4, 230134},
	{"BISMILLAH", 9, 230135},
	{"WPVI", 4, 230136},
	{"TROWA", 5, 230137},
	{"SYNCHILLA", 9, 230138},
	{"LOBAR", 5, 230139},
	{"GUISHED", 7, 230140},
	{"GAMEGEEK", 8, 230141},
	{"RETROGRESSION", 13, 230142},
	{"MOBICOM", 7, 230143},
	{"SHADOWBLADE", 11, 230144},
	{"GRIFTERS", 8, 230145},
	{"ULVER", 5, 230146},
	{"SPLASHCAM", 9, 230147},
	{"FRESHENS", 8, 230148},
	{"KASSEN", 6, 230149},
	{"VOCALISE", 8, 230150},
	{"GQVIEW", 6, 230151},
	{"PIRASTRO", 8, 230152},
	{"DISINTERRED", 11, 230153},
	{"SPARKASSE", 9, 230154},
	{"ELAZAR", 6, 230155},
	{"DEWING", 6, 230156},
	{"DEARNE", 6, 230157},
	{"BNEW", 4, 230158},
	{"ACEEE", 5, 230159},
	{"QUAKERISM", 9, 230160},
	{"OTTERMAN", 8, 230161},
	{"MAHABALIPURAM", 13, 230162},
	{"MACAROON", 8, 230163},
	{"GALLAI", 6, 230164},
	{"ORBACUS", 7, 230165},
	{"SCULTHORPE", 10, 230166},
	{"TRAVELL", 7, 230167},
	{"FANYLION", 8, 230168},
	{"ELCOMSOFT", 9, 230169},
	{"JAKOBSSON", 9, 230170},
	{"ADOLECENTES", 11, 230171},
	{"SYNDICALIST", 11, 230172},
	{"CVW", 3, 230173},
	{"BINGER", 6, 230174},
	{"BARANGAYS", 9, 230175},
	{"MULTIWAVELENGTH", 15, 230176},
	{"SIMEONE", 7, 230177},
	{"NORDGREN", 8, 230178},
	{"BINX", 4, 230179},
	{"DEADEN", 6, 230180},
	{"VICTIME", 7, 230181},
	{"MYNYDD", 6, 230182},
	{"MIZZ", 4, 230183},
	{"NONSYMMETRIC", 12, 230184},
	{"SIKKERHET", 9, 230185},
	{"SPONGING", 8, 230186},
	{"MAXWELLIAN", 10, 230187},
	{"BRAHMI", 6, 230188},
	{"WARNICK", 7, 230189},
	{"INSTINET", 8, 230190},
	{"ZXV", 3, 230191},
	{"ZVF", 3, 230192},
	{"YFQ", 3, 230193},
	{"XZR", 3, 230194},
	{"XGZ", 3, 230195},
	{"XFJ", 3, 230196},
	{"VMQ", 3, 230197},
	{"UQK", 3, 230198},
	{"UJZ", 3, 230199},
	{"RQJ", 3, 230200},
	{"QYR", 3, 230201},
	{"QPG", 3, 230202},
	{"QGW", 3, 230203},
	{"QCV", 3, 230204},
	{"PJZ", 3, 230205},
	{"MZQ", 3, 230206},
	{"LXQ", 3, 230207},
	{"LJQ", 3, 230208},
	{"JXY", 3, 230209},
	{"JQW", 3, 230210},
	{"GXQ", 3, 230211},
	{"FJQ", 3, 230212},
	{"CQJ", 3, 230213},
	{"CJQ", 3, 230214},
	{"UNALLOYED", 9, 230215},
	{"STOROES", 7, 230216},
	{"PIDE", 4, 230217},
	{"FERROMAGNETISM", 14, 230218},
	{"BIRDOS", 6, 230219},
	{"VERNIA", 6, 230220},
	{"POPOVA", 6, 230221},
	{"HETEROPHYLLA", 12, 230222},
	{"HATHERSAGE", 10, 230223},
	{"OSAWA", 5, 230224},
	{"LATTERMAN", 9, 230225},
	{"HAIDIAN", 7, 230226},
	{"GAMESMASTER", 11, 230227},
	{"ADCC", 4, 230228},
	{"NOREV", 5, 230229},
	{"MANNERLY", 8, 230230},
	{"HEPSERA", 7, 230231},
	{"TWANGY", 6, 230232},
	{"EBANKING", 8, 230233},
	{"DOCUTECH", 8, 230234},
	{"TEMOZOLOMIDE", 12, 230235},
	{"MILAB", 5, 230236},
	{"JONTY", 5, 230237},
	{"BLOHM", 5, 230238},
	{"MAWK", 4, 230239},
	{"GODINA", 6, 230240},
	{"VARGAONENINTH", 13, 230241},
	{"KEXEC", 5, 230242},
	{"FARTSY", 6, 230243},
	{"CHAPTERED", 9, 230244},
	{"SMOLIN", 6, 230245},
	{"MUDGUARD", 8, 230246},
	{"LIBGFORTRAN", 11, 230247},
	{"LACTALBUMIN", 11, 230248},
	{"KELLEYBLUEBOOK", 14, 230249},
	{"GAMESURGE", 9, 230250},
	{"CYSTEINES", 9, 230251},
	{"AMORGOS", 7, 230252},
	{"RIDD", 4, 230253},
	{"GCUBE", 5, 230254},
	{"GAMW", 4, 230255},
	{"FREMANTLEMEDIA", 14, 230256},
	{"SAMMIES", 7, 230257},
	{"AVCO", 4, 230258},
	{"MEGGIE", 6, 230259},
	{"JACEN", 5, 230260},
	{"ROWNLOADS", 9, 230261},
	{"LAONS", 5, 230262},
	{"USERPAGE", 8, 230263},
	{"IDENTIFONT", 10, 230264},
	{"ECATALOG", 8, 230265},
	{"RYBKA", 5, 230266},
	{"OVULE", 5, 230267},
	{"ACAMPO", 6, 230268},
	{"VENIAL", 6, 230269},
	{"AICTE", 5, 230270},
	{"WIDGER", 6, 230271},
	{"SCRAPYARD", 9, 230272},
	{"GRISELDA", 8, 230273},
	{"KASKADE", 7, 230274},
	{"INDISCIPLINE", 12, 230275},
	{"HANSOM", 6, 230276},
	{"YZEP", 4, 230277},
	{"YMSM", 4, 230278},
	{"YIMF", 4, 230279},
	{"YGIM", 4, 230280},
	{"WWGA", 4, 230281},
	{"WLHO", 4, 230282},
	{"WENX", 4, 230283},
	{"WBYO", 4, 230284},
	{"VYSL", 4, 230285},
	{"VSIM", 4, 230286},
	{"VMED", 4, 230287},
	{"UGPU", 4, 230288},
	{"TLBA", 4, 230289},
	{"TDUV", 4, 230290},
	{"SWWA", 4, 230291},
	{"RTCB", 4, 230292},
	{"RRJE", 4, 230293},
	{"RPMB", 4, 230294},
	{"RNCY", 4, 230295},
	{"RMOK", 4, 230296},
	{"RFUD", 4, 230297},
	{"QBRA", 4, 230298},
	{"PCIV", 4, 230299},
	{"PCEM", 4, 230300},
	{"PBYK", 4, 230301},
	{"OMRL", 4, 230302},
	{"OMDH", 4, 230303},
	{"OFNJ", 4, 230304},
	{"NOUY", 4, 230305},
	{"NGXR", 4, 230306},
	{"NEGB", 4, 230307},
	{"MWWI", 4, 230308},
	{"MWCH", 4, 230309},
	{"MMRM", 4, 230310},
	{"MHZI", 4, 230311},
	{"MFTL", 4, 230312},
	{"LUIA", 4, 230313},
	{"LNHL", 4, 230314},
	{"LIIG", 4, 230315},
	{"LEUA", 4, 230316},
	{"LBWH", 4, 230317},
	{"KACS", 4, 230318},
	{"JUJI", 4, 230319},
	{"IJIF", 4, 230320},
	{"HPEG", 4, 230321},
	{"GVEI", 4, 230322},
	{"GGEI", 4, 230323},
	{"GGAO", 4, 230324},
	{"GBTH", 4, 230325},
	{"FTVC", 4, 230326},
	{"FGNO", 4, 230327},
	{"FADW", 4, 230328},
	{"EWCB", 4, 230329},
	{"EFYA", 4, 230330},
	{"EFFZ", 4, 230331},
	{"DSLT", 4, 230332},
	{"DMNI", 4, 230333},
	{"DHRO", 4, 230334},
	{"DFST", 4, 230335},
	{"DAGW", 4, 230336},
	{"CUEJ", 4, 230337},
	{"CPHR", 4, 230338},
	{"CIIC", 4, 230339},
	{"CAFB", 4, 230340},
	{"BPUL", 4, 230341},
	{"BOYV", 4, 230342},
	{"BOEU", 4, 230343},
	{"BCEI", 4, 230344},
	{"ALQI", 4, 230345},
	{"WONDERWOMAN", 11, 230346},
	{"BREAKETH", 8, 230347},
	{"NONCHALANCE", 11, 230348},
	{"BONSER", 6, 230349},
	{"JOHAR", 5, 230350},
	{"STEAMPOWER", 10, 230351},
	{"ORCHIDEE", 8, 230352},
	{"PENTAMETER", 10, 230353},
	{"FRAPPER", 7, 230354},
	{"STAYONLINE", 10, 230355},
	{"DIMMOCK", 7, 230356},
	{"XNULL", 5, 230357},
	{"WORKPLANS", 9, 230358},
	{"VHTF", 4, 230359},
	{"VALBONNE", 8, 230360},
	{"FISCHMAN", 8, 230361},
	{"EARTHDAWN", 9, 230362},
	{"CRYSTALLISED", 12, 230363},
	{"KILNER", 6, 230364},
	{"CENTAR", 6, 230365},
	{"RESORTE", 7, 230366},
	{"PENGUICON", 9, 230367},
	{"MRIN", 4, 230368},
	{"RACKETEER", 9, 230369},
	{"DENCY", 5, 230370},
	{"BAUMOL", 6, 230371},
	{"SABIR", 5, 230372},
	{"NORTHBORO", 9, 230373},
	{"INDASH", 6, 230374},
	{"WINDBAG", 7, 230375},
	{"MAJER", 5, 230376},
	{"EMULADORES", 10, 230377},
	{"BARGED", 6, 230378},
	{"NKVD", 4, 230379},
	{"LAMETER", 7, 230380},
	{"STYNE", 5, 230381},
	{"HOTELCHATTER", 12, 230382},
	{"BOARDINGS", 9, 230383},
	{"BLOODSTAINS", 11, 230384},
	{"ALENT", 5, 230385},
	{"HEPHAESTUS", 10, 230386},
	{"AIRPOT", 6, 230387},
	{"CYGNI", 5, 230388},
	{"CAPELIN", 7, 230389},
	{"WORKTABLE", 9, 230390},
	{"PECA", 4, 230391},
	{"PAGEWIDTH", 9, 230392},
	{"NOXUBEE", 7, 230393},
	{"ZIMAGE", 6, 230394},
	{"SHATZ", 5, 230395},
	{"PIMOZIDE", 8, 230396},
	{"NEDCOR", 6, 230397},
	{"KAIFENG", 7, 230398},
	{"ICODE", 5, 230399},
	{"BIRKEN", 6, 230400},
	{"NORBU", 5, 230401},
	{"LOGGIN", 6, 230402},
	{"FACISM", 6, 230403},
	{"BROMODEOXYURIDINE", 17, 230404},
	{"XMLELEMENT", 10, 230405},
	{"TERFENADINE", 11, 230406},
	{"OBJE", 4, 230407},
	{"MALAYO", 6, 230408},
	{"RENYIPARKING", 12, 230409},
	{"QDC", 3, 230410},
	{"HADLOW", 6, 230411},
	{"ACROCEPHALUS", 12, 230412},
	{"TACTEL", 6, 230413},
	{"HORSFIELD", 9, 230414},
	{"DIDJA", 5, 230415},
	{"SNIVELY", 7, 230416},
	{"CONSEGUIR", 9, 230417},
	{"CALLOUSLY", 9, 230418},
	{"BIOTYPE", 7, 230419},
	{"VOMBAT", 6, 230420},
	{"REAPPOINTMENTS", 14, 230421},
	{"BALLYBUNION", 11, 230422},
	{"HOPPS", 5, 230423},
	{"GFLOPS", 6, 230424},
	{"ALPERS", 6, 230425},
	{"IUBMB", 5, 230426},
	{"BMPSTRING", 9, 230427},
	{"REGARDE", 7, 230428},
	{"AMOUREUX", 8, 230429},
	{"RATVILLE", 8, 230430},
	{"OXENFORD", 8, 230431},
	{"KATSUHIRO", 9, 230432},
	{"WIDEOUT", 7, 230433},
	{"RETRANSMITS", 11, 230434},
	{"INTERFRATERNITY", 15, 230435},
	{"FIDM", 4, 230436},
	{"CAMPAIN", 7, 230437},
	{"ASTROCYTOMAS", 12, 230438},
	{"WARRINER", 8, 230439},
	{"CYPRESSES", 9, 230440},
	{"FIBEROPTICS", 11, 230441},
	{"BOGO", 4, 230442},
	{"SEATDATA", 8, 230443},
	{"RIGHTER", 7, 230444},
	{"HENRIKSSON", 10, 230445},
	{"FUNDOPLICATION", 14, 230446},
	{"KAEDE", 5, 230447},
	{"FOGGERS", 7, 230448},
	{"DYSARTHRIA", 10, 230449},
	{"DIEDERICH", 9, 230450},
	{"SHIFNAL", 7, 230451},
	{"MICROSOFTCOM", 12, 230452},
	{"RESOUNDINGLY", 12, 230453},
	{"ENSBERG", 7, 230454},
	{"DOUBTLESSLY", 11, 230455},
	{"TECHDEPOT", 9, 230456},
	{"METHIONYL", 9, 230457},
	{"VASILIEV", 8, 230458},
	{"RECIDIVIST", 10, 230459},
	{"KIKAIDER", 8, 230460},
	{"PINETUM", 7, 230461},
	{"HAMEAU", 6, 230462},
	{"BKC", 3, 230463},
	{"BELLIARD", 8, 230464},
	{"MOONBOUNCE", 10, 230465},
	{"MEATHEAD", 8, 230466},
	{"JLY", 3, 230467},
	{"GEORGESON", 9, 230468},
	{"DIGIAL", 6, 230469},
	{"BUBBLERS", 8, 230470},
	{"PHRYGIAN", 8, 230471},
	{"NLSP", 4, 230472},
	{"LAMED", 5, 230473},
	{"KEARSE", 6, 230474},
	{"INTERUPT", 8, 230475},
	{"BENGTSON", 8, 230476},
	{"TOLLEF", 6, 230477},
	{"MULTICOATED", 11, 230478},
	{"TCBY", 4, 230479},
	{"WWV", 3, 230480},
	{"MAKINEN", 7, 230481},
	{"ACOMPLIA", 8, 230482},
	{"DELIVERYWARE", 12, 230483},
	{"CLIPAR", 6, 230484},
	{"RFACTOR", 7, 230485},
	{"LAMPHOLDER", 10, 230486},
	{"PRESIDEN", 8, 230487},
	{"WATERER", 7, 230488},
	{"LYCOPODIUM", 10, 230489},
	{"GEDICHTEN", 9, 230490},
	{"BIVVY", 5, 230491},
	{"SMPEG", 5, 230492},
	{"REPOLARIZATION", 14, 230493},
	{"PRESSPASS", 9, 230494},
	{"UTOPIANISM", 10, 230495},
	{"CRUZAN", 6, 230496},
	{"SEVENTIETH", 10, 230497},
	{"POSTHUMUS", 9, 230498},
	{"DSSP", 4, 230499},
	{"CONSTRUCTIONISM", 15, 230500},
	{"TOPLEY", 6, 230501},
	{"GSUB", 4, 230502},
	{"VETTORI", 7, 230503},
	{"HORCRUX", 7, 230504},
	{"QUESTIONERS", 11, 230505},
	{"OPPDATERT", 9, 230506},
	{"BUNKHOUSES", 10, 230507},
	{"NATANZ", 6, 230508},
	{"LIVESAY", 7, 230509},
	{"IFCC", 4, 230510},
	{"CONSIGNORS", 10, 230511},
	{"MIXTE", 5, 230512},
	{"LOCKARD", 7, 230513},
	{"GRANNIS", 7, 230514},
	{"ZINESTER", 8, 230515},
	{"WORKINGMAN", 10, 230516},
	{"SCOFFING", 8, 230517},
	{"GARAK", 5, 230518},
	{"DJIMON", 6, 230519},
	{"HULKS", 5, 230520},
	{"CRYPTOGRAMS", 11, 230521},
	{"BUSHWACKA", 9, 230522},
	{"SPOORWEGEN", 10, 230523},
	{"REHEARSES", 9, 230524},
	{"ACULEATUS", 9, 230525},
	{"MEJORAR", 7, 230526},
	{"DMTF", 4, 230527},
	{"MERAUDER", 8, 230528},
	{"LONGCUT", 7, 230529},
	{"CRUGER", 6, 230530},
	{"HUAHINE", 7, 230531},
	{"HALBERSTADT", 11, 230532},
	{"STRASBERG", 9, 230533},
	{"SETKEY", 6, 230534},
	{"REALCOM", 7, 230535},
	{"CUADRO", 6, 230536},
	{"STORUES", 7, 230537},
	{"SPRINGERVILLE", 13, 230538},
	{"MSACCESS", 8, 230539},
	{"BEERFLY", 7, 230540},
	{"RELACION", 8, 230541},
	{"LANESBOROUGH", 12, 230542},
	{"FABENS", 6, 230543},
	{"ENSLOW", 6, 230544},
	{"ELLICOTTVILLE", 13, 230545},
	{"SERRATE", 7, 230546},
	{"RISPARMIO", 9, 230547},
	{"PEOPPE", 6, 230548},
	{"GRADD", 5, 230549},
	{"DOBRINISHTE", 11, 230550},
	{"JRW", 3, 230551},
	{"ECPS", 4, 230552},
	{"NEUROPSYCHOLOGIA", 16, 230553},
	{"HINOTE", 6, 230554},
	{"BROCKET", 7, 230555},
	{"SAUVAGES", 8, 230556},
	{"GIAM", 4, 230557},
	{"GOPALAN", 7, 230558},
	{"FINDSOMEONE", 11, 230559},
	{"SJSAS", 5, 230560},
	{"PEOPOE", 6, 230561},
	{"MICROFORMAT", 11, 230562},
	{"CKUT", 4, 230563},
	{"BRCKO", 5, 230564},
	{"MAUSOLEUMS", 10, 230565},
	{"DODDER", 6, 230566},
	{"KOSKY", 5, 230567},
	{"FUJIOKA", 7, 230568},
	{"EGIZIO", 6, 230569},
	{"DISCARDABLE", 11, 230570},
	{"YACOUB", 6, 230571},
	{"ROWSER", 6, 230572},
	{"OVERREACH", 9, 230573},
	{"FURAMA", 6, 230574},
	{"WISECRACKS", 10, 230575},
	{"PIGGING", 7, 230576},
	{"LERN", 4, 230577},
	{"LEOPLE", 6, 230578},
	{"ZTRU", 4, 230579},
	{"ZETW", 4, 230580},
	{"YNBI", 4, 230581},
	{"YLLY", 4, 230582},
	{"WYNI", 4, 230583},
	{"WOWC", 4, 230584},
	{"VUEH", 4, 230585},
	{"UORF", 4, 230586},
	{"UKOP", 4, 230587},
	{"TYBC", 4, 230588},
	{"TEXG", 4, 230589},
	{"TBMO", 4, 230590},
	{"SMMW", 4, 230591},
	{"SIFK", 4, 230592},
	{"SHDM", 4, 230593},
	{"SBPR", 4, 230594},
	{"RDDW", 4, 230595},
	{"PEKN", 4, 230596},
	{"OZDE", 4, 230597},
	{"NZOU", 4, 230598},
	{"NYNF", 4, 230599},
	{"NKIJ", 4, 230600},
	{"NJID", 4, 230601},
	{"NCUC", 4, 230602},
	{"MOFZ", 4, 230603},
	{"MLIO", 4, 230604},
	{"MHUB", 4, 230605},
	{"LMJE", 4, 230606},
	{"LDEK", 4, 230607},
	{"KNEB", 4, 230608},
	{"KIAK", 4, 230609},
	{"KFEW", 4, 230610},
	{"KDUM", 4, 230611},
	{"JUER", 4, 230612},
	{"JAHC", 4, 230613},
	{"IZPR", 4, 230614},
	{"IZPA", 4, 230615},
	{"HEZG", 4, 230616},
	{"GDRM", 4, 230617},
	{"FMMI", 4, 230618},
	{"EYDJ", 4, 230619},
	{"EXJR", 4, 230620},
	{"ENWC", 4, 230621},
	{"EIWW", 4, 230622},
	{"EDGC", 4, 230623},
	{"DXML", 4, 230624},
	{"DVEM", 4, 230625},
	{"BWAI", 4, 230626},
	{"BUWH", 4, 230627},
	{"BJPS", 4, 230628},
	{"AYJR", 4, 230629},
	{"AUCY", 4, 230630},
	{"AFLF", 4, 230631},
	{"YSBYTY", 6, 230632},
	{"LLANWRTYD", 9, 230633},
	{"LARREA", 6, 230634},
	{"MONOHULL", 8, 230635},
	{"BREEDE", 6, 230636},
	{"WYNNS", 5, 230637},
	{"QUICHES", 7, 230638},
	{"ENTRUSTS", 8, 230639},
	{"SQUISHING", 9, 230640},
	{"RUMINATING", 10, 230641},
	{"PRENATALLY", 10, 230642},
	{"HEPATOMEGALY", 12, 230643},
	{"RISSER", 6, 230644},
	{"LAWLAH", 6, 230645},
	{"BRITMOVIE", 9, 230646},
	{"PREBEN", 6, 230647},
	{"MALADJUSTED", 11, 230648},
	{"PEFECT", 6, 230649},
	{"NORTHFORK", 9, 230650},
	{"MICROELECTRODE", 14, 230651},
	{"MAISVOCE", 8, 230652},
	{"CAPRINE", 7, 230653},
	{"PSOPLE", 6, 230654},
	{"TOULMIN", 7, 230655},
	{"TICETS", 6, 230656},
	{"TESCH", 5, 230657},
	{"INCLINOMETER", 12, 230658},
	{"HONORIUS", 8, 230659},
	{"FURTHUR", 7, 230660},
	{"FORTUNECITY", 11, 230661},
	{"EFFEKT", 6, 230662},
	{"EBISU", 5, 230663},
	{"CCRN", 4, 230664},
	{"TEMPLESTOWE", 11, 230665},
	{"CHIUSANO", 8, 230666},
	{"WELLSPRINGS", 11, 230667},
	{"MEDIATELY", 9, 230668},
	{"HARUKO", 6, 230669},
	{"STILLINGER", 10, 230670},
	{"KODI", 4, 230671},
	{"ROMANEK", 7, 230672},
	{"NMSQT", 5, 230673},
	{"ARAKAN", 6, 230674},
	{"LAVORARE", 8, 230675},
	{"UNCREATED", 9, 230676},
	{"GLENDENING", 10, 230677},
	{"TELEP", 5, 230678},
	{"EBAYAUCTIONS", 12, 230679},
	{"TULSE", 5, 230680},
	{"MURKAMI", 7, 230681},
	{"ABJURED", 7, 230682},
	{"TRICKER", 7, 230683},
	{"CYSYLLTIAD", 10, 230684},
	{"PHENTERMIE", 10, 230685},
	{"MANSTON", 7, 230686},
	{"HOBBYCRAFT", 10, 230687},
	{"JACOBIN", 7, 230688},
	{"HEHEHEHEHE", 10, 230689},
	{"EPISTASIS", 9, 230690},
	{"CATECHIN", 8, 230691},
	{"EARSETS", 7, 230692},
	{"BOMBPROOF", 9, 230693},
	{"VIMRC", 5, 230694},
	{"MODJO", 5, 230695},
	{"DIALYZED", 8, 230696},
	{"COMMUNIQUER", 11, 230697},
	{"CATEGORIZATIONS", 15, 230698},
	{"MCCLUSKY", 8, 230699},
	{"DXDY", 4, 230700},
	{"TISDALL", 7, 230701},
	{"TEMKIN", 6, 230702},
	{"GILLIGANS", 9, 230703},
	{"DIVERSEY", 8, 230704},
	{"BOTCAZOU", 8, 230705},
	{"MIFID", 5, 230706},
	{"CUCARACHA", 9, 230707},
	{"BADAMI", 6, 230708},
	{"LSUS", 4, 230709},
	{"LEMPER", 6, 230710},
	{"WMW", 3, 230711},
	{"INTERPRETEN", 11, 230712},
	{"PRIZEWINNERS", 12, 230713},
	{"EUROPEENNE", 10, 230714},
	{"SURVEX", 6, 230715},
	{"QUOTEL", 6, 230716},
	{"PDOPLE", 6, 230717},
	{"MATHEMAT", 8, 230718},
	{"ALTHUSSER", 9, 230719},
	{"WEDGING", 7, 230720},
	{"BAXENDALE", 9, 230721},
	{"QUIRKE", 6, 230722},
	{"SYNERGIE", 8, 230723},
	{"NFLX", 4, 230724},
	{"HYPERGEAR", 9, 230725},
	{"GRATUITTELECHARGER", 18, 230726},
	{"TRIPUG", 6, 230727},
	{"SERDES", 6, 230728},
	{"CONSTRICTIVE", 12, 230729},
	{"CHLOROTHALONIL", 14, 230730},
	{"STIFFED", 7, 230731},
	{"MOHONK", 6, 230732},
	{"AGME", 4, 230733},
	{"PRIODOL", 7, 230734},
	{"TITLEACTION", 11, 230735},
	{"JIMENO", 6, 230736},
	{"FABULA", 6, 230737},
	{"BRAUNWALD", 9, 230738},
	{"CONTINUANCES", 12, 230739},
	{"SEKULA", 6, 230740},
	{"DEJEVSKY", 8, 230741},
	{"BOKSBURG", 8, 230742},
	{"TAKEMURA", 8, 230743},
	{"PALMERI", 7, 230744},
	{"KANTA", 5, 230745},
	{"STORIRS", 7, 230746},
	{"PROFICIENTLY", 12, 230747},
	{"LIBERE", 6, 230748},
	{"FLORIDAN", 8, 230749},
	{"VASCONCELLOS", 12, 230750},
	{"TONASKET", 8, 230751},
	{"PAPPLION", 8, 230752},
	{"DOSFSTOOLS", 10, 230753},
	{"MEADOWSWEET", 11, 230754},
	{"VIDIX", 5, 230755},
	{"PROPAGANDHI", 11, 230756},
	{"TENNY", 5, 230757},
	{"SCHROON", 7, 230758},
	{"MOGS", 4, 230759},
	{"BBFL", 4, 230760},
	{"PLAYDOUGH", 9, 230761},
	{"ANSWERSTHATWORK", 15, 230762},
	{"CONTEMPORANEO", 13, 230763},
	{"ACTERS", 6, 230764},
	{"POINTBASE", 9, 230765},
	{"INSINCERITY", 11, 230766},
	{"CRTL", 4, 230767},
	{"SCARBORO", 8, 230768},
	{"RUBBERWOOD", 10, 230769},
	{"QUYEN", 5, 230770},
	{"ACLJ", 4, 230771},
	{"PROTVINO", 8, 230772},
	{"HECKUVA", 7, 230773},
	{"MIRUS", 5, 230774},
	{"FUNKTIONIERT", 12, 230775},
	{"BITRIOT", 7, 230776},
	{"YAAHOO", 6, 230777},
	{"STRUAN", 6, 230778},
	{"RICHVILLE", 9, 230779},
	{"LUDMILLA", 8, 230780},
	{"XLIFF", 5, 230781},
	{"FANFAN", 6, 230782},
	{"BAYMEADOWS", 10, 230783},
	{"ALPHASHOP", 9, 230784},
	{"OUARZAZATE", 10, 230785},
	{"ISCRIVITI", 9, 230786},
	{"ENVIROHEALTH", 12, 230787},
	{"SHINAI", 6, 230788},
	{"PRIES", 5, 230789},
	{"POKEWEED", 8, 230790},
	{"SIMGEAR", 7, 230791},
	{"GALETON", 7, 230792},
	{"DELPH", 5, 230793},
	{"RAJAS", 5, 230794},
	{"SUPRAX", 6, 230795},
	{"SAMOYEDS", 8, 230796},
	{"PWNC", 4, 230797},
	{"MARCION", 7, 230798},
	{"ASKJEVES", 8, 230799},
	{"TUXTLA", 6, 230800},
	{"REGISTREREN", 11, 230801},
	{"MYTOP", 5, 230802},
	{"JASEN", 5, 230803},
	{"AIRLIMES", 8, 230804},
	{"SHOPBUSINESS", 12, 230805},
	{"MICROELECTRODES", 15, 230806},
	{"BIOPHAN", 7, 230807},
	{"SHOPFITTING", 11, 230808},
	{"MACHAN", 6, 230809},
	{"HOOHOBBERS", 10, 230810},
	{"BELMOPAN", 8, 230811},
	{"MARKOU", 6, 230812},
	{"DIOSCOREA", 9, 230813},
	{"SKALD", 5, 230814},
	{"SHEPHERDED", 10, 230815},
	{"NEGATIVA", 8, 230816},
	{"DESTROYIT", 9, 230817},
	{"VMF", 3, 230818},
	{"RAPPOPORT", 9, 230819},
	{"PAGEX", 5, 230820},
	{"ARMITRON", 8, 230821},
	{"WYNNSTER", 8, 230822},
	{"VOGL", 4, 230823},
	{"ERYSIPELAS", 10, 230824},
	{"USAG", 4, 230825},
	{"BUDAK", 5, 230826},
	{"KYNE", 4, 230827},
	{"SKILTON", 7, 230828},
	{"ROUSSET", 7, 230829},
	{"ORELLANA", 8, 230830},
	{"DOUBLEREAL", 10, 230831},
	{"DARRICK", 7, 230832},
	{"BUGSCOPE", 8, 230833},
	{"FKD", 3, 230834},
	{"ZLON", 4, 230835},
	{"YELK", 4, 230836},
	{"XERP", 4, 230837},
	{"WYIN", 4, 230838},
	{"VKAR", 4, 230839},
	{"URRT", 4, 230840},
	{"UNXI", 4, 230841},
	{"SUGD", 4, 230842},
	{"SCSR", 4, 230843},
	{"RIIU", 4, 230844},
	{"RAVR", 4, 230845},
	{"PLST", 4, 230846},
	{"PHDC", 4, 230847},
	{"PDUO", 4, 230848},
	{"OWFC", 4, 230849},
	{"ORUU", 4, 230850},
	{"NPGO", 4, 230851},
	{"NFUZ", 4, 230852},
	{"NAKP", 4, 230853},
	{"MVPV", 4, 230854},
	{"MUFO", 4, 230855},
	{"LLCF", 4, 230856},
	{"LDGY", 4, 230857},
	{"KZET", 4, 230858},
	{"KRIA", 4, 230859},
	{"KAMW", 4, 230860},
	{"IFEZ", 4, 230861},
	{"GMLA", 4, 230862},
	{"GFOG", 4, 230863},
	{"FVIJ", 4, 230864},
	{"FCEC", 4, 230865},
	{"FAWL", 4, 230866},
	{"ETMF", 4, 230867},
	{"ENZM", 4, 230868},
	{"ENZB", 4, 230869},
	{"EMPB", 4, 230870},
	{"EBBD", 4, 230871},
	{"DYIW", 4, 230872},
	{"DARQ", 4, 230873},
	{"CTVW", 4, 230874},
	{"BUYJ", 4, 230875},
	{"BECG", 4, 230876},
	{"ATZD", 4, 230877},
	{"APBS", 4, 230878},
	{"ALYJ", 4, 230879},
	{"PLASTISOL", 9, 230880},
	{"NEVERSOFT", 9, 230881},
	{"NEUROSMITH", 10, 230882},
	{"THURGAU", 7, 230883},
	{"PERSECUTOR", 10, 230884},
	{"SECURITYTRACKER", 15, 230885},
	{"OKEFENOKEE", 10, 230886},
	{"CUPRIC", 6, 230887},
	{"CHILDEN", 7, 230888},
	{"VALETTA", 7, 230889},
	{"SLOBBER", 7, 230890},
	{"MANOEUVRABILITY", 15, 230891},
	{"PIPEFITTER", 10, 230892},
	{"COITAL", 6, 230893},
	{"BOOYAH", 6, 230894},
	{"WINNI", 5, 230895},
	{"ARTESYN", 7, 230896},
	{"CLASSIF", 7, 230897},
	{"EDNET", 5, 230898},
	{"VANTA", 5, 230899},
	{"TIMELIKE", 8, 230900},
	{"WARLICK", 7, 230901},
	{"REINECKE", 8, 230902},
	{"NPACI", 5, 230903},
	{"YAZZ", 4, 230904},
	{"AGUADA", 6, 230905},
	{"YNETNEWS", 8, 230906},
	{"MONOCDE", 7, 230907},
	{"WALLDORF", 8, 230908},
	{"ULG", 3, 230909},
	{"COMPSOC", 7, 230910},
	{"INTERPOLATOR", 12, 230911},
	{"DEMY", 4, 230912},
	{"DAUG", 4, 230913},
	{"SEELAND", 7, 230914},
	{"ALCH", 4, 230915},
	{"PROPOLENE", 9, 230916},
	{"DGAR", 4, 230917},
	{"NEWBURN", 7, 230918},
	{"MANESS", 6, 230919},
	{"LREF", 4, 230920},
	{"RIGINAL", 7, 230921},
	{"EPOCRATES", 9, 230922},
	{"BROZ", 4, 230923},
	{"ALMES", 5, 230924},
	{"RHETTINGER", 10, 230925},
	{"HUMIRA", 6, 230926},
	{"TZVI", 4, 230927},
	{"QUILCHENA", 9, 230928},
	{"DESIGNFIRMS", 11, 230929},
	{"STRIATUS", 8, 230930},
	{"TRATADO", 7, 230931},
	{"KTVO", 4, 230932},
	{"CICMA", 5, 230933},
	{"STEMMEN", 7, 230934},
	{"PERIODIZATION", 13, 230935},
	{"DEESE", 5, 230936},
	{"CATECHINS", 9, 230937},
	{"PUGLISI", 7, 230938},
	{"CANAS", 5, 230939},
	{"LIPART", 6, 230940},
	{"LYNUXWORKS", 10, 230941},
	{"JAGANNATHAN", 11, 230942},
	{"DICHTER", 7, 230943},
	{"CURDIR", 6, 230944},
	{"TREIS", 5, 230945},
	{"CHEIKH", 6, 230946},
	{"YRD", 3, 230947},
	{"QUEZADA", 7, 230948},
	{"YADKINVILLE", 11, 230949},
	{"STRAITJACKETS", 13, 230950},
	{"QMUC", 4, 230951},
	{"OPPERMANN", 9, 230952},
	{"HILTZ", 5, 230953},
	{"MONTOURSVILLE", 13, 230954},
	{"ETCHELLS", 8, 230955},
	{"EDGEMOOR", 8, 230956},
	{"CAPSULATUS", 10, 230957},
	{"AWWAL", 5, 230958},
	{"EQUINA", 6, 230959},
	{"CLOCHES", 7, 230960},
	{"RAJARAM", 7, 230961},
	{"DIVERSEN", 8, 230962},
	{"TEMENOS", 7, 230963},
	{"EBAYY", 5, 230964},
	{"CARLOSPIAD", 10, 230965},
	{"SKERRIES", 8, 230966},
	{"BANJARA", 7, 230967},
	{"DESCIPTION", 10, 230968},
	{"GFB", 3, 230969},
	{"FRANCESTOWN", 11, 230970},
	{"EARDLEY", 7, 230971},
	{"WATERLOGGING", 12, 230972},
	{"RELATIV", 7, 230973},
	{"REBEKA", 6, 230974},
	{"PARSHAH", 7, 230975},
	{"UNPROBLEMATIC", 13, 230976},
	{"GBGM", 4, 230977},
	{"FAUCETDIRECT", 12, 230978},
	{"REGRADING", 9, 230979},
	{"CONSENTRY", 9, 230980},
	{"MOSKOW", 6, 230981},
	{"FROSTPROOF", 10, 230982},
	{"ASKMEFI", 7, 230983},
	{"CAPSA", 5, 230984},
	{"MDNR", 4, 230985},
	{"LANDHOLDER", 10, 230986},
	{"SVENSEN", 7, 230987},
	{"PENTAGRAMS", 10, 230988},
	{"AYLSHAM", 7, 230989},
	{"WKBT", 4, 230990},
	{"TWIDTH", 6, 230991},
	{"TGCGC", 5, 230992},
	{"PARMENTIER", 10, 230993},
	{"NOREPLACE", 9, 230994},
	{"KUNDU", 5, 230995},
	{"CALLEA", 6, 230996},
	{"BITTING", 7, 230997},
	{"HRISTO", 6, 230998},
	{"GLUCOKINASE", 11, 230999},
	{"SHAYARI", 7, 231000},
	{"CHLOROBIUM", 10, 231001},
	{"MYRDAL", 6, 231002},
	{"FREQUENZE", 9, 231003},
	{"ARGYRIS", 7, 231004},
	{"FERNALDS", 8, 231005},
	{"POLITES", 7, 231006},
	{"HURLY", 5, 231007},
	{"GLOBALINK", 9, 231008},
	{"MORPHUES", 8, 231009},
	{"TRONCO", 6, 231010},
	{"REMARQUES", 9, 231011},
	{"PAGEZ", 5, 231012},
	{"HUTCHENCE", 9, 231013},
	{"HEROMACHINE", 11, 231014},
	{"CLEATED", 7, 231015},
	{"ANITRA", 6, 231016},
	{"MOUW", 4, 231017},
	{"PRIMEIRA", 8, 231018},
	{"FLUOROPOLYMERS", 14, 231019},
	{"BASSANI", 7, 231020},
	{"SALPETER", 8, 231021},
	{"PHYSICALISM", 11, 231022},
	{"INTOLERANCES", 12, 231023},
	{"DAUTRIVE", 8, 231024},
	{"BARADEI", 7, 231025},
	{"SKIABLE", 7, 231026},
	{"PMTU", 4, 231027},
	{"KACHINAS", 8, 231028},
	{"CREVASSES", 9, 231029},
	{"ACCOKEEK", 8, 231030},
	{"ZXVF", 4, 231031},
	{"MENDIOLA", 8, 231032},
	{"MAXIMUN", 7, 231033},
	{"VBK", 3, 231034},
	{"SEING", 5, 231035},
	{"SCHILLIX", 8, 231036},
	{"SATCH", 5, 231037},
	{"MARKKP", 6, 231038},
	{"PEKPLE", 6, 231039},
	{"MACTAN", 6, 231040},
	{"JABBOUR", 7, 231041},
	{"ENSTROM", 7, 231042},
	{"PROEXTENDER", 11, 231043},
	{"SQAUD", 5, 231044},
	{"WISCO", 5, 231045},
	{"PAPASAN", 7, 231046},
	{"TAPINGS", 7, 231047},
	{"NOAUTO", 6, 231048},
	{"NABUMETONE", 10, 231049},
	{"ELECTRODEPOSITION", 17, 231050},
	{"CLATRONIC", 9, 231051},
	{"EAVESDROPPERS", 13, 231052},
	{"CHURCHLAND", 10, 231053},
	{"BLUHM", 5, 231054},
	{"EELLS", 5, 231055},
	{"CLEANEX", 7, 231056},
	{"TRAUTMAN", 8, 231057},
	{"SINGEN", 6, 231058},
	{"LIBERALISING", 12, 231059},
	{"DELTEC", 6, 231060},
	{"BYARD", 5, 231061},
	{"FERRICK", 7, 231062},
	{"VIDEOCAMERAACCESSORY", 20, 231063},
	{"UNVENTED", 8, 231064},
	{"NORFORK", 7, 231065},
	{"YVEK", 4, 231066},
	{"YRDC", 4, 231067},
	{"YJRI", 4, 231068},
	{"XPHA", 4, 231069},
	{"WPAV", 4, 231070},
	{"WLMO", 4, 231071},
	{"WDSG", 4, 231072},
	{"UZZH", 4, 231073},
	{"UWAM", 4, 231074},
	{"USDV", 4, 231075},
	{"UDIH", 4, 231076},
	{"TVIM", 4, 231077},
	{"TMRN", 4, 231078},
	{"TKRY", 4, 231079},
	{"THRP", 4, 231080},
	{"SJRT", 4, 231081},
	{"RTUD", 4, 231082},
	{"RPGO", 4, 231083},
	{"RBUO", 4, 231084},
	{"QBCO", 4, 231085},
	{"PRWA", 4, 231086},
	{"PMYL", 4, 231087},
	{"OVCL", 4, 231088},
	{"OGSV", 4, 231089},
	{"MTDN", 4, 231090},
	{"MDEI", 4, 231091},
	{"LOEP", 4, 231092},
	{"LBPL", 4, 231093},
	{"KBOF", 4, 231094},
	{"ITZU", 4, 231095},
	{"ILAZ", 4, 231096},
	{"IGNQ", 4, 231097},
	{"HRYO", 4, 231098},
	{"HRYD", 4, 231099},
	{"HOGP", 4, 231100},
	{"HMAV", 4, 231101},
	{"GGYN", 4, 231102},
	{"GECM", 4, 231103},
	{"FWRT", 4, 231104},
	{"FKST", 4, 231105},
	{"FENZ", 4, 231106},
	{"EECD", 4, 231107},
	{"DJSH", 4, 231108},
	{"DEDX", 4, 231109},
	{"DCEB", 4, 231110},
	{"CKND", 4, 231111},
	{"CADH", 4, 231112},
	{"AIFW", 4, 231113},
	{"NECROMANCERS", 12, 231114},
	{"KHER", 4, 231115},
	{"ONEOF", 5, 231116},
	{"LEBAR", 5, 231117},
	{"PAGEQ", 5, 231118},
	{"EMFS", 4, 231119},
	{"BUNTER", 6, 231120},
	{"POVEY", 5, 231121},
	{"GOTTMAN", 7, 231122},
	{"EJEFRASE", 8, 231123},
	{"EBAAY", 5, 231124},
	{"COMBEST", 7, 231125},
	{"BISULFITE", 9, 231126},
	{"AMERICARES", 10, 231127},
	{"SALU", 4, 231128},
	{"HAKON", 5, 231129},
	{"BURGHER", 7, 231130},
	{"AGHION", 6, 231131},
	{"KABO", 4, 231132},
	{"CAPPLET", 7, 231133},
	{"TRAVELSALE", 10, 231134},
	{"LOYALE", 6, 231135},
	{"DORNBUSCH", 9, 231136},
	{"FERNER", 6, 231137},
	{"FCFS", 4, 231138},
	{"SMOKEPING", 9, 231139},
	{"MOOSA", 5, 231140},
	{"LACQUERWARE", 11, 231141},
	{"ARCHRIVAL", 9, 231142},
	{"KIELTY", 6, 231143},
	{"FISHE", 5, 231144},
	{"DASANI", 6, 231145},
	{"SILICIC", 7, 231146},
	{"HERDMAN", 7, 231147},
	{"BOBROW", 6, 231148},
	{"BETHALTO", 8, 231149},
	{"UNSTAINED", 9, 231150},
	{"FOOMS", 5, 231151},
	{"BRINKERHOFF", 11, 231152},
	{"STAHLER", 7, 231153},
	{"TWINPRIME", 9, 231154},
	{"SYBARI", 6, 231155},
	{"GRAINNE", 7, 231156},
	{"GALLY", 5, 231157},
	{"EYRW", 4, 231158},
	{"COWBELLS", 8, 231159},
	{"GMFBUILD", 8, 231160},
	{"CARELLA", 7, 231161},
	{"PARCOURS", 8, 231162},
	{"INTRALUMINAL", 12, 231163},
	{"HDRS", 4, 231164},
	{"PLOUFFE", 7, 231165},
	{"DANETTE", 7, 231166},
	{"NAGANT", 6, 231167},
	{"LOVESONG", 8, 231168},
	{"COLLETION", 9, 231169},
	{"CHOQUETTE", 9, 231170},
	{"CHARGEMENT", 10, 231171},
	{"TALISMA", 7, 231172},
	{"POTENCIA", 8, 231173},
	{"XBB", 3, 231174},
	{"VERLAUF", 7, 231175},
	{"SHILLA", 6, 231176},
	{"LOKING", 6, 231177},
	{"UDIFF", 5, 231178},
	{"MOTHBALLS", 9, 231179},
	{"DEANDRE", 7, 231180},
	{"MONKEYFILTER", 12, 231181},
	{"MAPW", 4, 231182},
	{"GULPIN", 6, 231183},
	{"DRYAS", 5, 231184},
	{"PROIECT", 7, 231185},
	{"ARTICOLE", 8, 231186},
	{"CALLISTA", 8, 231187},
	{"HUGHLEY", 7, 231188},
	{"PILSENER", 8, 231189},
	{"ODGERS", 6, 231190},
	{"WARKENTIN", 9, 231191},
	{"OTORGO", 6, 231192},
	{"LONGLIFE", 8, 231193},
	{"EXFOLIATOR", 10, 231194},
	{"PHALARIS", 8, 231195},
	{"AMIDOTRANSFERASE", 16, 231196},
	{"RUINATION", 9, 231197},
	{"DEITZ", 5, 231198},
	{"AIRLINEQ", 8, 231199},
	{"SORTIERT", 8, 231200},
	{"SMTPSVC", 7, 231201},
	{"PERSI", 5, 231202},
	{"STELLENSUCHE", 12, 231203},
	{"GTCO", 4, 231204},
	{"LABLTK", 6, 231205},
	{"EWWWW", 5, 231206},
	{"ANNOUNCMENT", 11, 231207},
	{"MEDIAPRO", 8, 231208},
	{"TOXTETH", 7, 231209},
	{"METROHM", 7, 231210},
	{"SINGLEY", 7, 231211},
	{"SEMINIFEROUS", 12, 231212},
	{"PROGRESSIVITY", 13, 231213},
	{"XMLHTTP", 7, 231214},
	{"BIRGITTE", 8, 231215},
	{"WASTIN", 6, 231216},
	{"INTERCOASTAL", 12, 231217},
	{"GIOVANNINI", 10, 231218},
	{"SUBGRANTS", 9, 231219},
	{"EVISCERATE", 10, 231220},
	{"DRAGONAIR", 9, 231221},
	{"MOSIX", 5, 231222},
	{"SETLINEJOIN", 11, 231223},
	{"PLYOMETRIC", 10, 231224},
	{"NYHETSBREV", 10, 231225},
	{"MONOCLE", 7, 231226},
	{"MANNINEN", 8, 231227},
	{"LETZTES", 7, 231228},
	{"CONGENITA", 9, 231229},
	{"UNSERIALIZE", 11, 231230},
	{"FREEOLA", 7, 231231},
	{"DOBY", 4, 231232},
	{"PHIBES", 6, 231233},
	{"OUSLEY", 6, 231234},
	{"LDPC", 4, 231235},
	{"JEOPARDISING", 12, 231236},
	{"BURNETII", 8, 231237},
	{"SUPERSTARDOM", 12, 231238},
	{"GOOGELE", 7, 231239},
	{"BUFFEREDIMAGE", 13, 231240},
	{"WERSJI", 6, 231241},
	{"ESTEVES", 7, 231242},
	{"VPF", 3, 231243},
	{"SPYWAREGUARD", 12, 231244},
	{"GUARDER", 7, 231245},
	{"UNPHYSICAL", 10, 231246},
	{"CMZ", 3, 231247},
	{"ADAPTADORES", 11, 231248},
	{"LEMPERT", 7, 231249},
	{"MASSANUTTEN", 11, 231250},
	{"UNFLINCHINGLY", 13, 231251},
	{"KIRRIBILLI", 10, 231252},
	{"OCKENDON", 8, 231253},
	{"HKUL", 4, 231254},
	{"CASODEX", 7, 231255},
	{"ALTAVITA", 8, 231256},
	{"STATUDOL", 8, 231257},
	{"ORASURE", 7, 231258},
	{"MAPICS", 6, 231259},
	{"FROMKIN", 7, 231260},
	{"UNDYED", 6, 231261},
	{"TOKAREV", 7, 231262},
	{"ERMITA", 6, 231263},
	{"JONGEJAN", 8, 231264},
	{"CHIASM", 6, 231265},
	{"ACIDO", 5, 231266},
	{"STYLEPARK", 9, 231267},
	{"NUNGWI", 6, 231268},
	{"MONOPOLIZING", 12, 231269},
	{"DRAGONSLAYER", 12, 231270},
	{"WARDLOW", 7, 231271},
	{"METROGEL", 8, 231272},
	{"SUBSISTED", 9, 231273},
	{"FATAR", 5, 231274},
	{"TEJEDA", 6, 231275},
	{"PICTUREQ", 8, 231276},
	{"SPICULE", 7, 231277},
	{"JOBLING", 7, 231278},
	{"ENGENEERING", 11, 231279},
	{"FULLPATH", 8, 231280},
	{"SWITH", 5, 231281},
	{"LAPPER", 6, 231282},
	{"TALWAR", 6, 231283},
	{"BRONCHOGENIC", 12, 231284},
	{"STRUZAN", 7, 231285},
	{"TOOTIE", 6, 231286},
	{"PIERREPONT", 10, 231287},
	{"MAULS", 5, 231288},
	{"EGIPTO", 6, 231289},
	{"DEGRADATIONS", 12, 231290},
	{"TABORI", 6, 231291},
	{"WILLFULNESS", 11, 231292},
	{"DERMADOCTOR", 11, 231293},
	{"COURTIN", 7, 231294},
	{"SOCIOS", 6, 231295},
	{"MEANIES", 7, 231296},
	{"ANASTOMOSES", 11, 231297},
	{"SCULLCAP", 8, 231298},
	{"VOCALIC", 7, 231299},
	{"MARIAE", 6, 231300},
	{"FINNIS", 6, 231301},
	{"CSRD", 4, 231302},
	{"GELSCRUBS", 9, 231303},
	{"YDIERESIS", 9, 231304},
	{"NYERERE", 7, 231305},
	{"NOTAIRE", 7, 231306},
	{"SALONICA", 8, 231307},
	{"GLOBEINVESTORGOLD", 17, 231308},
	{"ZYDI", 4, 231309},
	{"ZELG", 4, 231310},
	{"ZDER", 4, 231311},
	{"ZANJ", 4, 231312},
	{"XLAU", 4, 231313},
	{"WNHY", 4, 231314},
	{"WCRY", 4, 231315},
	{"VBAR", 4, 231316},
	{"UJIH", 4, 231317},
	{"TMCB", 4, 231318},
	{"TDAK", 4, 231319},
	{"RCYG", 4, 231320},
	{"QFTM", 4, 231321},
	{"PKAS", 4, 231322},
	{"OFXS", 4, 231323},
	{"NGQA", 4, 231324},
	{"NEXL", 4, 231325},
	{"MOBC", 4, 231326},
	{"MMOW", 4, 231327},
	{"MAPG", 4, 231328},
	{"LNSW", 4, 231329},
	{"LNPR", 4, 231330},
	{"LCIC", 4, 231331},
	{"KKAB", 4, 231332},
	{"JIWO", 4, 231333},
	{"IVKO", 4, 231334},
	{"ICYJ", 4, 231335},
	{"HJRA", 4, 231336},
	{"GMRO", 4, 231337},
	{"GGEW", 4, 231338},
	{"FUZB", 4, 231339},
	{"FUHA", 4, 231340},
	{"FRYC", 4, 231341},
	{"EZJU", 4, 231342},
	{"ESZY", 4, 231343},
	{"EMTC", 4, 231344},
	{"EJDE", 4, 231345},
	{"EIFK", 4, 231346},
	{"DUKT", 4, 231347},
	{"DOBN", 4, 231348},
	{"DGOK", 4, 231349},
	{"DFDO", 4, 231350},
	{"CTVP", 4, 231351},
	{"CLTH", 4, 231352},
	{"CKEQ", 4, 231353},
	{"CBIK", 4, 231354},
	{"BYWW", 4, 231355},
	{"BYRC", 4, 231356},
	{"BTTR", 4, 231357},
	{"AZYK", 4, 231358},
	{"ATWB", 4, 231359},
	{"AHLF", 4, 231360},
	{"PYTHONPATH", 10, 231361},
	{"MYKOLA", 6, 231362},
	{"ECDYSONE", 8, 231363},
	{"BATSE", 5, 231364},
	{"OFFY", 4, 231365},
	{"GUINEE", 6, 231366},
	{"EFFETTI", 7, 231367},
	{"DURACK", 6, 231368},
	{"ARKADIUSZ", 9, 231369},
	{"WWWEBAYCOM", 10, 231370},
	{"SWAMPLAND", 9, 231371},
	{"CALCINATION", 11, 231372},
	{"XBIZ", 4, 231373},
	{"ROCKE", 5, 231374},
	{"FRONTRUNNERS", 12, 231375},
	{"CRIMS", 5, 231376},
	{"TAMEN", 5, 231377},
	{"JOEP", 4, 231378},
	{"FMOUT", 5, 231379},
	{"EMSLEY", 6, 231380},
	{"DABBLES", 7, 231381},
	{"EMATE", 5, 231382},
	{"DECEITS", 7, 231383},
	{"LAIMS", 5, 231384},
	{"KILLY", 5, 231385},
	{"DESERTNET", 9, 231386},
	{"GLUCOMETER", 10, 231387},
	{"CIOFFI", 6, 231388},
	{"SAPONIN", 7, 231389},
	{"BAUDIN", 6, 231390},
	{"RIBBENTROP", 10, 231391},
	{"NRTIS", 5, 231392},
	{"EDEF", 4, 231393},
	{"ARRR", 4, 231394},
	{"TOPDOG", 6, 231395},
	{"POLICER", 7, 231396},
	{"PAGEW", 5, 231397},
	{"INTERNODES", 10, 231398},
	{"RUPTURING", 9, 231399},
	{"KESSELS", 7, 231400},
	{"ENTRO", 5, 231401},
	{"CREX", 4, 231402},
	{"PHILIPPOUSSIS", 13, 231403},
	{"GLOBEFUND", 9, 231404},
	{"THEODICY", 8, 231405},
	{"EXPEDA", 6, 231406},
	{"APGES", 5, 231407},
	{"IFRCS", 5, 231408},
	{"PRACTICALLYNETWORKED", 20, 231409},
	{"SONGER", 6, 231410},
	{"MONTROSS", 8, 231411},
	{"DATAROW", 7, 231412},
	{"USATODAYCOM", 11, 231413},
	{"STEPHANO", 8, 231414},
	{"EDGINGTON", 9, 231415},
	{"CANTI", 5, 231416},
	{"BADRINATH", 9, 231417},
	{"OBJECTFORKEY", 12, 231418},
	{"KILLOUGH", 8, 231419},
	{"HIERDIE", 7, 231420},
	{"GRANULOCYTIC", 12, 231421},
	{"DGND", 4, 231422},
	{"THUNDERHAWK", 11, 231423},
	{"MARLATT", 7, 231424},
	{"CYCUSZKI", 8, 231425},
	{"ASCARON", 7, 231426},
	{"JOHNSONBURG", 11, 231427},
	{"CIVITATE", 8, 231428},
	{"OPALINE", 7, 231429},
	{"LCRYPTO", 7, 231430},
	{"SURPRIZED", 9, 231431},
	{"USCITA", 6, 231432},
	{"MADCHEN", 7, 231433},
	{"LAPAGLIA", 8, 231434},
	{"ELECTROKINETIC", 14, 231435},
	{"ROCKLEY", 7, 231436},
	{"LOBLAW", 6, 231437},
	{"CTTEE", 5, 231438},
	{"REHOBOAM", 8, 231439},
	{"KROMER", 6, 231440},
	{"HALPRIN", 7, 231441},
	{"HALOWEEN", 8, 231442},
	{"MODENAME", 8, 231443},
	{"HONESTECH", 9, 231444},
	{"UTILITYBANK", 11, 231445},
	{"PALLETIZING", 11, 231446},
	{"BONETTI", 7, 231447},
	{"STPRIES", 7, 231448},
	{"RISCO", 5, 231449},
	{"OBEID", 5, 231450},
	{"BOURDAIS", 8, 231451},
	{"DRAKOS", 6, 231452},
	{"CREDS", 5, 231453},
	{"ICLASSIFIEDS", 12, 231454},
	{"BAJORAN", 7, 231455},
	{"NOVEMEBER", 9, 231456},
	{"TISCHLER", 8, 231457},
	{"HAUKE", 5, 231458},
	{"DOGME", 5, 231459},
	{"BROODMARES", 10, 231460},
	{"ANGELIA", 7, 231461},
	{"CETAPHIL", 8, 231462},
	{"MANIFYING", 9, 231463},
	{"MIETTINEN", 9, 231464},
	{"RICERCARE", 9, 231465},
	{"EIGTH", 5, 231466},
	{"WURFL", 5, 231467},
	{"SUHRKAMP", 8, 231468},
	{"PRESRIPTION", 11, 231469},
	{"BERLINA", 7, 231470},
	{"PAGSE", 5, 231471},
	{"IJMUIDEN", 8, 231472},
	{"ALLAGASH", 8, 231473},
	{"STAMPATO", 8, 231474},
	{"FROMME", 6, 231475},
	{"FORRESTERS", 10, 231476},
	{"DEPUTATIONS", 11, 231477},
	{"TOGAMI", 6, 231478},
	{"HARTSOCK", 8, 231479},
	{"GENNADIY", 8, 231480},
	{"GEKA", 4, 231481},
	{"VITTON", 6, 231482},
	{"INTERMARRIED", 12, 231483},
	{"CROYLE", 6, 231484},
	{"SATUR", 5, 231485},
	{"HOMERVILLE", 10, 231486},
	{"UCAN", 4, 231487},
	{"ACSW", 4, 231488},
	{"DAAP", 4, 231489},
	{"ACCEP", 5, 231490},
	{"TREKING", 7, 231491},
	{"THORIN", 6, 231492},
	{"PRACTIC", 7, 231493},
	{"LASERPOD", 8, 231494},
	{"BRESTNITSA", 10, 231495},
	{"ANOTHERSITE", 11, 231496},
	{"MERLINS", 7, 231497},
	{"INTERSPECT", 10, 231498},
	{"FULPMES", 7, 231499},
	{"FORMATTIME", 10, 231500},
	{"ARKIVMUSIC", 10, 231501},
	{"RINGLETS", 8, 231502},
	{"ESQL", 4, 231503},
	{"WTAMU", 5, 231504},
	{"PUCHASE", 7, 231505},
	{"NDEP", 4, 231506},
	{"SPATIALNEWS", 11, 231507},
	{"KAPHA", 5, 231508},
	{"BOHL", 4, 231509},
	{"TAFSIR", 6, 231510},
	{"BOOVAL", 6, 231511},
	{"JAPANWHORES", 11, 231512},
	{"PALYNOLOGY", 10, 231513},
	{"CASTAGNA", 8, 231514},
	{"SPORTSNETWORK", 13, 231515},
	{"FANFEST", 7, 231516},
	{"CIMI", 4, 231517},
	{"TOTARA", 6, 231518},
	{"INCAR", 5, 231519},
	{"DIGITALHOTBUY", 13, 231520},
	{"COOPERAGE", 9, 231521},
	{"WHENU", 5, 231522},
	{"COXHED", 6, 231523},
	{"TROELS", 6, 231524},
	{"CSBS", 4, 231525},
	{"TELESEMINARS", 12, 231526},
	{"UNCLOTHED", 9, 231527},
	{"QUANTITATE", 10, 231528},
	{"GRANS", 5, 231529},
	{"FRIANT", 6, 231530},
	{"NARROWCASTING", 13, 231531},
	{"IMPERSONATIONS", 14, 231532},
	{"EMENTS", 6, 231533},
	{"MUKLUK", 6, 231534},
	{"RETOURNE", 8, 231535},
	{"AIRLINRS", 8, 231536},
	{"SCOURGED", 8, 231537},
	{"PACKAGENAME", 11, 231538},
	{"MORISOT", 7, 231539},
	{"MALLICK", 7, 231540},
	{"COMMISSIONE", 11, 231541},
	{"BESLEY", 6, 231542},
	{"PLETHYSMOGRAPHY", 15, 231543},
	{"DORSALIS", 8, 231544},
	{"REIDER", 6, 231545},
	{"MISUNDERSTANDS", 14, 231546},
	{"VERYAN", 6, 231547},
	{"SURVIVALS", 9, 231548},
	{"CANARDS", 7, 231549},
	{"SCHIZANDRA", 10, 231550},
	{"PETKOV", 6, 231551},
	{"FARN", 4, 231552},
	{"CNTF", 4, 231553},
	{"BLACKHALL", 9, 231554},
	{"SNOCROSS", 8, 231555},
	{"PPTA", 4, 231556},
	{"BILKO", 5, 231557},
	{"BEASIALITY", 10, 231558},
	{"BALESTRA", 8, 231559},
	{"ZXSP", 4, 231560},
	{"YTVT", 4, 231561},
	{"YPDF", 4, 231562},
	{"YPAB", 4, 231563},
	{"YJPM", 4, 231564},
	{"XYHA", 4, 231565},
	{"WWBI", 4, 231566},
	{"WBYW", 4, 231567},
	{"VAMU", 4, 231568},
	{"UXNO", 4, 231569},
	{"UTMF", 4, 231570},
	{"UPIH", 4, 231571},
	{"UJIC", 4, 231572},
	{"TDRW", 4, 231573},
	{"SECV", 4, 231574},
	{"SCAJ", 4, 231575},
	{"SAKW", 4, 231576},
	{"RZUL", 4, 231577},
	{"RPYL", 4, 231578},
	{"ROAU", 4, 231579},
	{"RDRW", 4, 231580},
	{"RAKF", 4, 231581},
	{"QIKU", 4, 231582},
	{"PYOL", 4, 231583},
	{"PJAZ", 4, 231584},
	{"PFUT", 4, 231585},
	{"OMRK", 4, 231586},
	{"OCMO", 4, 231587},
	{"NJRH", 4, 231588},
	{"MVPB", 4, 231589},
	{"MPYC", 4, 231590},
	{"MPKA", 4, 231591},
	{"MGEE", 4, 231592},
	{"MEWT", 4, 231593},
	{"LZEB", 4, 231594},
	{"LOIM", 4, 231595},
	{"LMTV", 4, 231596},
	{"LLOZ", 4, 231597},
	{"LFEH", 4, 231598},
	{"KUKR", 4, 231599},
	{"KOPU", 4, 231600},
	{"KNAG", 4, 231601},
	{"KMRO", 4, 231602},
	{"KKAW", 4, 231603},
	{"IOUP", 4, 231604},
	{"IMDY", 4, 231605},
	{"IFIJ", 4, 231606},
	{"GFIA", 4, 231607},
	{"FMRD", 4, 231608},
	{"FIFR", 4, 231609},
	{"FETD", 4, 231610},
	{"FDUF", 4, 231611},
	{"ELGN", 4, 231612},
	{"DSEK", 4, 231613},
	{"DMBO", 4, 231614},
	{"DCIP", 4, 231615},
	{"BECY", 4, 231616},
	{"BBDE", 4, 231617},
	{"AXGO", 4, 231618},
	{"ANVU", 4, 231619},
	{"ADTD", 4, 231620},
	{"WRONGDOINGS", 11, 231621},
	{"UNDERGROUNDING", 14, 231622},
	{"KASURI", 6, 231623},
	{"FOLKSTONE", 9, 231624},
	{"SOFTWAE", 7, 231625},
	{"CALLEJA", 7, 231626},
	{"REEDUCATION", 11, 231627},
	{"CHIAYI", 6, 231628},
	{"MERG", 4, 231629},
	{"MERCADOLIBRE", 12, 231630},
	{"CUNNAN", 6, 231631},
	{"CATHERWOOD", 10, 231632},
	{"UPDA", 4, 231633},
	{"SPYBOTS", 7, 231634},
	{"ECRMGUIDE", 9, 231635},
	{"WWWEBAY", 7, 231636},
	{"REINVIGORATING", 14, 231637},
	{"PORTALI", 7, 231638},
	{"ADEMAS", 6, 231639},
	{"SGMLTOOLS", 9, 231640},
	{"MOLLIFY", 7, 231641},
	{"BOYLHS", 6, 231642},
	{"SALZER", 6, 231643},
	{"KINGLAKE", 8, 231644},
	{"STUDIARE", 8, 231645},
	{"MUTUALISM", 9, 231646},
	{"KUBLA", 5, 231647},
	{"ANVARI", 6, 231648},
	{"CYNOMOLGUS", 10, 231649},
	{"COMMONWEALTHS", 13, 231650},
	{"SNOWBERRY", 9, 231651},
	{"RWG", 3, 231652},
	{"SUNSYSTEMS", 10, 231653},
	{"PRACTICANDO", 11, 231654},
	{"NOTWIST", 7, 231655},
	{"CRANCH", 6, 231656},
	{"BULKED", 6, 231657},
	{"IYANLA", 6, 231658},
	{"BIRTHPLACES", 11, 231659},
	{"UPLINKFAST", 10, 231660},
	{"SHOUTCASTS", 10, 231661},
	{"HEELEY", 6, 231662},
	{"ANWAY", 5, 231663},
	{"SUBTENDED", 9, 231664},
	{"MCGUIRK", 7, 231665},
	{"CAPULIN", 7, 231666},
	{"VERDIN", 6, 231667},
	{"GREEING", 7, 231668},
	{"ECCLECTIC", 9, 231669},
	{"RATTLESCRIPT", 12, 231670},
	{"PERVASIVELY", 11, 231671},
	{"RYOGA", 5, 231672},
	{"BLOCKADING", 10, 231673},
	{"BABRI", 5, 231674},
	{"TUMBLIN", 7, 231675},
	{"NCMEC", 5, 231676},
	{"MAROLD", 6, 231677},
	{"PERFO", 5, 231678},
	{"LANGNER", 7, 231679},
	{"BESTBEWERTETEN", 14, 231680},
	{"SYSTEMHOME", 10, 231681},
	{"NETBUS", 6, 231682},
	{"ENCRUSTATION", 12, 231683},
	{"TOLEX", 5, 231684},
	{"NETSCAPECOM", 11, 231685},
	{"SIBBALD", 7, 231686},
	{"PRESSIONE", 9, 231687},
	{"SPRUCED", 7, 231688},
	{"ROUKEMA", 7, 231689},
	{"PARTHENIUM", 10, 231690},
	{"PAINEWEBBER", 11, 231691},
	{"DISULFIDES", 10, 231692},
	{"CREENSAVERS", 11, 231693},
	{"BERNASCONI", 10, 231694},
	{"TENAYA", 6, 231695},
	{"PROTHERO", 8, 231696},
	{"FOBDOWN", 7, 231697},
	{"GARGANTUA", 9, 231698},
	{"KEPCO", 5, 231699},
	{"COUGHT", 6, 231700},
	{"WATES", 5, 231701},
	{"CATEGORYSTORES", 14, 231702},
	{"BUIDING", 7, 231703},
	{"VOLTMETERS", 10, 231704},
	{"VALLEYFIELD", 11, 231705},
	{"PAREO", 5, 231706},
	{"FORCINGS", 8, 231707},
	{"CASEINATE", 9, 231708},
	{"SUBSTI", 6, 231709},
	{"SHAKSPEARE", 10, 231710},
	{"CACTACEAE", 9, 231711},
	{"ACNES", 5, 231712},
	{"SCHUYLERVILLE", 13, 231713},
	{"MOLTKE", 6, 231714},
	{"WWIII", 5, 231715},
	{"REAPPROPRIATION", 15, 231716},
	{"XXTH", 4, 231717},
	{"TWISP", 5, 231718},
	{"TIDDLYWIKI", 10, 231719},
	{"NETMOVIES", 9, 231720},
	{"MICROBREW", 9, 231721},
	{"NEDLLOYD", 8, 231722},
	{"MICROSFT", 8, 231723},
	{"MARELLI", 7, 231724},
	{"TEENIEMOVIES", 12, 231725},
	{"BRINTEY", 7, 231726},
	{"FOSSEN", 6, 231727},
	{"TKDESK", 6, 231728},
	{"STEXT", 5, 231729},
	{"BEDLINER", 8, 231730},
	{"DAGBLADET", 9, 231731},
	{"SODOMITE", 8, 231732},
	{"LIBRETT", 7, 231733},
	{"TEIJIN", 6, 231734},
	{"FITZWATER", 9, 231735},
	{"DANDENONGS", 10, 231736},
	{"CANGGU", 6, 231737},
	{"LATONA", 6, 231738},
	{"THESAME", 7, 231739},
	{"QUIRING", 7, 231740},
	{"MOTWANI", 7, 231741},
	{"DOZOIS", 6, 231742},
	{"SUNSOURCE", 9, 231743},
	{"TRIUMPHING", 10, 231744},
	{"PIGMENTOSUM", 11, 231745},
	{"FLOREAT", 7, 231746},
	{"ARONOFSKY", 9, 231747},
	{"CERVERA", 7, 231748},
	{"BITFIELDS", 9, 231749},
	{"GRIFFE", 6, 231750},
	{"AFRIC", 5, 231751},
	{"ZEDD", 4, 231752},
	{"GREETIG", 7, 231753},
	{"MESTA", 5, 231754},
	{"DROSTE", 6, 231755},
	{"CARQ", 4, 231756},
	{"BEAMINSTER", 10, 231757},
	{"BONSPIEL", 8, 231758},
	{"AITLINES", 8, 231759},
	{"UHMW", 4, 231760},
	{"HAILSTONES", 10, 231761},
	{"FFRR", 4, 231762},
	{"ETIWANDA", 8, 231763},
	{"WILLGOTO", 8, 231764},
	{"NATREN", 6, 231765},
	{"LIGULA", 6, 231766},
	{"COMPARITIVE", 11, 231767},
	{"SALITA", 6, 231768},
	{"ECSTASIES", 9, 231769},
	{"DEBRIEFED", 9, 231770},
	{"ABNEXT", 6, 231771},
	{"STARION", 7, 231772},
	{"EXTRACRANIAL", 12, 231773},
	{"DIATHERMY", 9, 231774},
	{"FERROR", 6, 231775},
	{"PLATY", 5, 231776},
	{"PPRC", 4, 231777},
	{"NODDER", 6, 231778},
	{"CONFERE", 7, 231779},
	{"EDUCATIONALISTS", 15, 231780},
	{"SLURRING", 8, 231781},
	{"MALLEUS", 7, 231782},
	{"DERGE", 5, 231783},
	{"CANARI", 6, 231784},
	{"ALISE", 5, 231785},
	{"MOULTING", 8, 231786},
	{"SHKORPILOVTSI", 13, 231787},
	{"KOSHLAND", 8, 231788},
	{"HTERT", 5, 231789},
	{"ENTERPRISENETWORKINGPLANET", 26, 231790},
	{"CANNAREGIO", 10, 231791},
	{"PALAEOZOIC", 10, 231792},
	{"ENGELSKA", 8, 231793},
	{"CHIPPERFIELD", 12, 231794},
	{"TELESAT", 7, 231795},
	{"EYRWPAIKHS", 10, 231796},
	{"WALRUSES", 8, 231797},
	{"CONVERSATIONALIST", 17, 231798},
	{"BIKEPARTSUSA", 12, 231799},
	{"BERLINO", 7, 231800},
	{"OILMAN", 6, 231801},
	{"OVERGROW", 8, 231802},
	{"STAERK", 6, 231803},
	{"RENDS", 5, 231804},
	{"MAURYA", 6, 231805},
	{"EUROPASS", 8, 231806},
	{"EMALL", 5, 231807},
	{"DIFFERIN", 8, 231808},
	{"BUSYBODY", 8, 231809},
	{"BRECONSHIRE", 11, 231810},
	{"FAGG", 4, 231811},
	{"REPURPOSED", 10, 231812},
	{"GREETIMG", 8, 231813},
	{"CINCHED", 7, 231814},
	{"RMBS", 4, 231815},
	{"DPDM", 4, 231816},
	{"UNPOPULATED", 11, 231817},
	{"CHEUK", 5, 231818},
	{"ROCHELEAU", 9, 231819},
	{"AQUARISTS", 9, 231820},
	{"NUZZLED", 7, 231821},
	{"MDIV", 4, 231822},
	{"ZSPI", 4, 231823},
	{"YDAF", 4, 231824},
	{"XGUI", 4, 231825},
	{"WWDI", 4, 231826},
	{"WIWH", 4, 231827},
	{"VSAC", 4, 231828},
	{"VLIV", 4, 231829},
	{"VIGR", 4, 231830},
	{"UFIA", 4, 231831},
	{"UEDK", 4, 231832},
	{"UBQU", 4, 231833},
	{"TSWW", 4, 231834},
	{"TIPY", 4, 231835},
	{"TEXD", 4, 231836},
	{"TDRL", 4, 231837},
	{"SZUM", 4, 231838},
	{"SOGD", 4, 231839},
	{"SDNB", 4, 231840},
	{"RPIV", 4, 231841},
	{"RKIH", 4, 231842},
	{"RHPM", 4, 231843},
	{"OMXI", 4, 231844},
	{"OEBY", 4, 231845},
	{"NOUX", 4, 231846},
	{"NOKM", 4, 231847},
	{"NKUK", 4, 231848},
	{"NDLW", 4, 231849},
	{"MTLA", 4, 231850},
	{"MPHP", 4, 231851},
	{"MEMT", 4, 231852},
	{"LUGD", 4, 231853},
	{"LLIY", 4, 231854},
	{"LLHD", 4, 231855},
	{"LBOZ", 4, 231856},
	{"KIIM", 4, 231857},
	{"IZDI", 4, 231858},
	{"IZCH", 4, 231859},
	{"IAKC", 4, 231860},
	{"HUTP", 4, 231861},
	{"HLSP", 4, 231862},
	{"GRAO", 4, 231863},
	{"GAPY", 4, 231864},
	{"FFOK", 4, 231865},
	{"EPPW", 4, 231866},
	{"DMEJ", 4, 231867},
	{"DAPG", 4, 231868},
	{"CHKL", 4, 231869},
	{"CGAG", 4, 231870},
	{"CENL", 4, 231871},
	{"BUAS", 4, 231872},
	{"BILH", 4, 231873},
	{"ATYG", 4, 231874},
	{"ALRD", 4, 231875},
	{"CADACO", 6, 231876},
	{"CELLCEPT", 8, 231877},
	{"ADVIS", 5, 231878},
	{"WATERFRONTS", 11, 231879},
	{"GERMONLINE", 10, 231880},
	{"UNIDISC", 7, 231881},
	{"FREJUS", 6, 231882},
	{"CUVETTES", 8, 231883},
	{"VARARGS", 7, 231884},
	{"WWWORBITZ", 9, 231885},
	{"LGG", 3, 231886},
	{"FMIS", 4, 231887},
	{"DAGNEY", 6, 231888},
	{"CHINOISERIE", 11, 231889},
	{"BERROW", 6, 231890},
	{"CEDERHOLM", 9, 231891},
	{"CASSELTON", 9, 231892},
	{"ALREDEDOR", 9, 231893},
	{"MEDIACTIVE", 10, 231894},
	{"ORNER", 5, 231895},
	{"CIFIAL", 6, 231896},
	{"NACAC", 5, 231897},
	{"EYEON", 5, 231898},
	{"BRATCHER", 8, 231899},
	{"ALLWORTH", 8, 231900},
	{"PENETANGUISHENE", 15, 231901},
	{"MEGG", 4, 231902},
	{"IDRISI", 6, 231903},
	{"REEP", 4, 231904},
	{"JERICO", 6, 231905},
	{"IGNOREPERMISSIONS", 17, 231906},
	{"CHRISTMASS", 10, 231907},
	{"CROPP", 5, 231908},
	{"THALGO", 6, 231909},
	{"RIGHTARROW", 10, 231910},
	{"BUDDHI", 6, 231911},
	{"SRNC", 4, 231912},
	{"SMELTZER", 8, 231913},
	{"DOSIMETRIC", 10, 231914},
	{"AIRKINES", 8, 231915},
	{"THOROWGOOD", 10, 231916},
	{"BEACHTEN", 8, 231917},
	{"KIBBLES", 7, 231918},
	{"FRECUENTES", 10, 231919},
	{"TREEGR", 6, 231920},
	{"SCHADOW", 7, 231921},
	{"STELLARVUE", 10, 231922},
	{"KRONSTADT", 9, 231923},
	{"KIGHT", 5, 231924},
	{"BIBLIOGRAFIA", 12, 231925},
	{"WINCUSTOMIZE", 12, 231926},
	{"MINIMAP", 7, 231927},
	{"DIHYDROXYVITAMIN", 16, 231928},
	{"CZARNE", 6, 231929},
	{"AIELINES", 8, 231930},
	{"CHERNIN", 7, 231931},
	{"RIJKSUNIVERSITEIT", 17, 231932},
	{"MAPQUESTCOM", 11, 231933},
	{"TOESTEL", 7, 231934},
	{"PORRITT", 7, 231935},
	{"MYOTT", 5, 231936},
	{"DISTANZ", 7, 231937},
	{"CHENA", 5, 231938},
	{"BELAND", 6, 231939},
	{"WAIBEL", 6, 231940},
	{"LMNO", 4, 231941},
	{"BILDEN", 6, 231942},
	{"SAROUK", 6, 231943},
	{"VARO", 4, 231944},
	{"FILMATI", 7, 231945},
	{"AIRLINWS", 8, 231946},
	{"WIGGERS", 7, 231947},
	{"MISSAUKEE", 9, 231948},
	{"AUROMERE", 8, 231949},
	{"JOPSY", 5, 231950},
	{"ATIYAH", 6, 231951},
	{"SUPERSPRINT", 11, 231952},
	{"LASTOLITE", 9, 231953},
	{"THERMOMECHANICAL", 16, 231954},
	{"ALGAR", 5, 231955},
	{"SCULPTS", 7, 231956},
	{"THIENSVILLE", 11, 231957},
	{"SWISHING", 8, 231958},
	{"BEDCLOTHES", 10, 231959},
	{"LIFETEC", 7, 231960},
	{"WATCHBAND", 9, 231961},
	{"TRIBBLES", 8, 231962},
	{"TRAVELERSINTOUCH", 16, 231963},
	{"RUMELHART", 9, 231964},
	{"PUNC", 4, 231965},
	{"PERILLA", 7, 231966},
	{"SATYAGRAHA", 10, 231967},
	{"PADDESTOEL", 10, 231968},
	{"HOMATROPINE", 11, 231969},
	{"SZENTENDRE", 10, 231970},
	{"KROPF", 5, 231971},
	{"GOLFCOURSE", 10, 231972},
	{"MUDDLEFTPD", 10, 231973},
	{"MECHANI", 7, 231974},
	{"STOCKMANN", 9, 231975},
	{"PRODUCTSMORE", 12, 231976},
	{"PRESSURIZE", 10, 231977},
	{"FAOR", 4, 231978},
	{"COASTWISE", 9, 231979},
	{"TRUING", 6, 231980},
	{"SHEEZYART", 9, 231981},
	{"PRETY", 5, 231982},
	{"DAVAL", 5, 231983},
	{"SULFADIAZINE", 12, 231984},
	{"SIMCOX", 6, 231985},
	{"FUJIKAWA", 8, 231986},
	{"CUSTOMWEATHER", 13, 231987},
	{"ASIRA", 5, 231988},
	{"EUGENES", 7, 231989},
	{"PREVOD", 6, 231990},
	{"LEATHERWORK", 11, 231991},
	{"LASERLIGHT", 10, 231992},
	{"IMPERTINENCE", 12, 231993},
	{"TOFFEES", 7, 231994},
	{"LIBRETTI", 8, 231995},
	{"MCTS", 4, 231996},
	{"KOENIGSEGG", 10, 231997},
	{"FLORESTA", 8, 231998},
	{"EXPLICITE", 9, 231999},
	{"COMMISSARIES", 12, 232000},
	{"APANI", 5, 232001},
	{"ALLSVENSKAN", 11, 232002},
	{"RUITER", 6, 232003},
	{"ASMX", 4, 232004},
	{"WESTAMPTON", 10, 232005},
	{"ENERGIS", 7, 232006},
	{"BOHLS", 5, 232007},
	{"SETVAR", 6, 232008},
	{"HOLDTIME", 8, 232009},
	{"FLOY", 4, 232010},
	{"CARLBERG", 8, 232011},
	{"BLOODSUCKING", 12, 232012},
	{"MONEYWEB", 8, 232013},
	{"JANSONS", 7, 232014},
	{"DHAM", 4, 232015},
	{"STORMIN", 7, 232016},
	{"ROPOSED", 7, 232017},
	{"RAHSAAN", 7, 232018},
	{"ZILA", 4, 232019},
	{"SWAPMEET", 8, 232020},
	{"JCG", 3, 232021},
	{"SIRLINES", 8, 232022},
	{"INSTANTMESSAGINGPLANET", 22, 232023},
	{"GOONDIWINDI", 11, 232024},
	{"COCOBOLO", 8, 232025},
	{"TAXPAYING", 9, 232026},
	{"SHARPES", 7, 232027},
	{"ALVERSON", 8, 232028},
	{"SPLEENS", 7, 232029},
	{"WWWCHAT", 7, 232030},
	{"FLASHYBRID", 10, 232031},
	{"EVERSLEY", 8, 232032},
	{"CISUM", 5, 232033},
	{"ZAKON", 5, 232034},
	{"EGUCHI", 6, 232035},
	{"EGGY", 4, 232036},
	{"OAGES", 5, 232037},
	{"MEDIALOUNGE", 11, 232038},
	{"LANGUIDLY", 9, 232039},
	{"PARKLIFE", 8, 232040},
	{"PERROTTA", 8, 232041},
	{"LOWBOY", 6, 232042},
	{"FINLANDE", 8, 232043},
	{"DISPITE", 7, 232044},
	{"CALFORNIA", 9, 232045},
	{"ACCUPUNCTURE", 12, 232046},
	{"UMMER", 5, 232047},
	{"MOMENCE", 7, 232048},
	{"GERRISH", 7, 232049},
	{"ESPERANDO", 9, 232050},
	{"CAPITOLE", 8, 232051},
	{"URATION", 7, 232052},
	{"SEGEV", 5, 232053},
	{"SEDULOUSLY", 10, 232054},
	{"FREEFREE", 8, 232055},
	{"DENILIQUIN", 10, 232056},
	{"NASTEL", 6, 232057},
	{"MALABO", 6, 232058},
	{"BRILLO", 6, 232059},
	{"INTERISLAND", 11, 232060},
	{"RENOVASCULAR", 12, 232061},
	{"RAMBONE", 7, 232062},
	{"MSUM", 4, 232063},
	{"LIONSGATE", 9, 232064},
	{"AJUSTE", 6, 232065},
	{"STIPENDIARY", 11, 232066},
	{"NEOPETSCOM", 10, 232067},
	{"BOETTGER", 8, 232068},
	{"VTOL", 4, 232069},
	{"UDV", 3, 232070},
	{"PREUN", 5, 232071},
	{"STRUG", 5, 232072},
	{"HYPERGRAPHS", 11, 232073},
	{"ETUSIVU", 7, 232074},
	{"AURLINES", 8, 232075},
	{"XPOSTFACTO", 10, 232076},
	{"NEMEA", 5, 232077},
	{"IMMUNODOMINANT", 14, 232078},
	{"BREADBOX", 8, 232079},
	{"AMERICAINE", 10, 232080},
	{"BISBAL", 6, 232081},
	{"TOLLES", 6, 232082},
	{"JSURVEY", 7, 232083},
	{"EARWORM", 7, 232084},
	{"SCARABS", 7, 232085},
	{"CHRISTOLOGICAL", 14, 232086},
	{"ZOUB", 4, 232087},
	{"ZELR", 4, 232088},
	{"YNAJ", 4, 232089},
	{"YDRW", 4, 232090},
	{"YAEV", 4, 232091},
	{"XOGE", 4, 232092},
	{"XNEX", 4, 232093},
	{"UYKE", 4, 232094},
	{"UYEL", 4, 232095},
	{"URBP", 4, 232096},
	{"TUBH", 4, 232097},
	{"TSCP", 4, 232098},
	{"TCYJ", 4, 232099},
	{"TCFA", 4, 232100},
	{"TBAZ", 4, 232101},
	{"SSLL", 4, 232102},
	{"SSBC", 4, 232103},
	{"RMRJ", 4, 232104},
	{"RLBS", 4, 232105},
	{"RHAF", 4, 232106},
	{"PMIR", 4, 232107},
	{"PICJ", 4, 232108},
	{"OUWM", 4, 232109},
	{"OUKT", 4, 232110},
	{"OSCY", 4, 232111},
	{"OJOD", 4, 232112},
	{"OCBE", 4, 232113},
	{"NOMR", 4, 232114},
	{"NEPW", 4, 232115},
	{"LODW", 4, 232116},
	{"LAKB", 4, 232117},
	{"JARH", 4, 232118},
	{"INUV", 4, 232119},
	{"HYSY", 4, 232120},
	{"HNUL", 4, 232121},
	{"GYOS", 4, 232122},
	{"GWIP", 4, 232123},
	{"GSTD", 4, 232124},
	{"GHDH", 4, 232125},
	{"FKAG", 4, 232126},
	{"FCUI", 4, 232127},
	{"FAAF", 4, 232128},
	{"EIMV", 4, 232129},
	{"EGWY", 4, 232130},
	{"EDWC", 4, 232131},
	{"BPOF", 4, 232132},
	{"BEPS", 4, 232133},
	{"ATJC", 4, 232134},
	{"AQBA", 4, 232135},
	{"ALUO", 4, 232136},
	{"TOBOGGANS", 9, 232137},
	{"HYPERVISOR", 10, 232138},
	{"CCOP", 4, 232139},
	{"AQUIN", 5, 232140},
	{"ISPRIME", 7, 232141},
	{"WITTEKIND", 9, 232142},
	{"TRACKTION", 9, 232143},
	{"BMIBABY", 7, 232144},
	{"TURKLE", 6, 232145},
	{"RAOD", 4, 232146},
	{"ANUSHARAJI", 10, 232147},
	{"MSNCHAT", 7, 232148},
	{"TWIKIWEBSTABLE", 14, 232149},
	{"TREVA", 5, 232150},
	{"TOUCHIN", 7, 232151},
	{"JUSTENE", 7, 232152},
	{"SYCK", 4, 232153},
	{"DESPRES", 7, 232154},
	{"ALERTA", 6, 232155},
	{"FAKR", 4, 232156},
	{"DELACRUZ", 8, 232157},
	{"AORLINES", 8, 232158},
	{"MEGASITES", 9, 232159},
	{"ISLETON", 7, 232160},
	{"EMPANGENI", 9, 232161},
	{"KLANGBAD", 8, 232162},
	{"GLENTORAN", 9, 232163},
	{"PROFESSIO", 9, 232164},
	{"VORACIOUSLY", 11, 232165},
	{"ARICLE", 6, 232166},
	{"TRUDELL", 7, 232167},
	{"PHARMACOECONOMICS", 17, 232168},
	{"METAFIND", 8, 232169},
	{"LYSAGHT", 7, 232170},
	{"DUGONGS", 7, 232171},
	{"CSME", 4, 232172},
	{"AFFA", 4, 232173},
	{"SUSHMA", 6, 232174},
	{"GENERI", 6, 232175},
	{"DIKU", 4, 232176},
	{"AIRLIBES", 8, 232177},
	{"HYPERTRIGLYCERIDEMIA", 20, 232178},
	{"METCO", 5, 232179},
	{"NISHINO", 7, 232180},
	{"UNEMPLOYABLE", 12, 232181},
	{"ROMITA", 6, 232182},
	{"FATPORT", 7, 232183},
	{"BOFF", 4, 232184},
	{"SYNDR", 5, 232185},
	{"HIWASSEE", 8, 232186},
	{"GLUTAMATES", 10, 232187},
	{"ELPOEP", 6, 232188},
	{"AUDIWORLD", 9, 232189},
	{"GOOGLECA", 8, 232190},
	{"ECOMOG", 6, 232191},
	{"WHITEHEADS", 10, 232192},
	{"VIACK", 5, 232193},
	{"SANDEN", 6, 232194},
	{"INTERNATINAL", 12, 232195},
	{"VENNE", 5, 232196},
	{"LUPU", 4, 232197},
	{"LESLI", 5, 232198},
	{"LEUMI", 5, 232199},
	{"KIMM", 4, 232200},
	{"STIPPLED", 8, 232201},
	{"JAPONES", 7, 232202},
	{"AISLERIOT", 9, 232203},
	{"NCDA", 4, 232204},
	{"EXERPT", 6, 232205},
	{"CROSSMEMBER", 11, 232206},
	{"CROAZIA", 7, 232207},
	{"ANTIPERSPIRANTS", 15, 232208},
	{"UTHOR", 5, 232209},
	{"SYMMETRICOM", 11, 232210},
	{"ORISTANO", 8, 232211},
	{"MARRAS", 6, 232212},
	{"BURBACH", 7, 232213},
	{"WARDE", 5, 232214},
	{"STRUCTIONS", 10, 232215},
	{"CAPITATA", 8, 232216},
	{"ARTICLING", 9, 232217},
	{"ONBIDDER", 8, 232218},
	{"SOLARWINDS", 10, 232219},
	{"SEMBAWANG", 9, 232220},
	{"HOOTMAIL", 8, 232221},
	{"AAPD", 4, 232222},
	{"TELEVISIONE", 11, 232223},
	{"TRANQUILIZING", 13, 232224},
	{"LAMPPOSTS", 9, 232225},
	{"FREEDOMWORKS", 12, 232226},
	{"DARGIS", 6, 232227},
	{"HEMOPTYSIS", 10, 232228},
	{"GREATCIRCLE", 11, 232229},
	{"FERMENTERS", 10, 232230},
	{"DAIDO", 5, 232231},
	{"BLECKLEY", 8, 232232},
	{"BEGRUDGINGLY", 12, 232233},
	{"UDFS", 4, 232234},
	{"SPADERS", 7, 232235},
	{"SHAYAN", 6, 232236},
	{"MANOVA", 6, 232237},
	{"COVEL", 5, 232238},
	{"OGLINE", 6, 232239},
	{"COMSYS", 6, 232240},
	{"BCMATH", 6, 232241},
	{"ANENEWS", 7, 232242},
	{"UNDERWRITES", 11, 232243},
	{"HUNDT", 5, 232244},
	{"CAMPOBASSO", 10, 232245},
	{"GRIMACES", 8, 232246},
	{"WEATHERCOM", 10, 232247},
	{"LARYNGOLOGY", 11, 232248},
	{"BULKELEY", 8, 232249},
	{"EPCOR", 5, 232250},
	{"LEWONTIN", 8, 232251},
	{"NEGER", 5, 232252},
	{"KUMC", 4, 232253},
	{"JOAL", 4, 232254},
	{"ANNUNZIATA", 10, 232255},
	{"STEINERT", 8, 232256},
	{"PRECLEARANCE", 12, 232257},
	{"DURACION", 8, 232258},
	{"APPLICATIONSCHEDULE", 19, 232259},
	{"VOLNEY", 6, 232260},
	{"NMDP", 4, 232261},
	{"HOGWOOD", 7, 232262},
	{"RECRE", 5, 232263},
	{"DUCH", 4, 232264},
	{"ODDYSEE", 7, 232265},
	{"CCYYMMDD", 8, 232266},
	{"VAHL", 4, 232267},
	{"NOVASTOR", 8, 232268},
	{"BADGERING", 9, 232269},
	{"STORET", 6, 232270},
	{"MEDIASCAN", 9, 232271},
	{"QPOS", 4, 232272},
	{"LOFTIEST", 8, 232273},
	{"FLAPPERS", 8, 232274},
	{"ALTAVIST", 8, 232275},
	{"TABLECOL", 8, 232276},
	{"ISURANCE", 8, 232277},
	{"BRASSTOWN", 9, 232278},
	{"BRANDISH", 8, 232279},
	{"BISECTS", 7, 232280},
	{"SURFPOINT", 9, 232281},
	{"DECEMBRE", 8, 232282},
	{"WWWAOLCOM", 9, 232283},
	{"NAVIA", 5, 232284},
	{"IEMMA", 5, 232285},
	{"DOOMBEN", 7, 232286},
	{"BIRKHOFF", 8, 232287},
	{"BINSIZE", 7, 232288},
	{"SPEZIELLE", 9, 232289},
	{"TOPWRITE", 8, 232290},
	{"OSITION", 7, 232291},
	{"BASTON", 6, 232292},
	{"CATFOOD", 7, 232293},
	{"WYDAWCA", 7, 232294},
	{"LEGATES", 7, 232295},
	{"JARECKI", 7, 232296},
	{"PHPPGADMIN", 10, 232297},
	{"DONNAY", 6, 232298},
	{"AUTOANTIBODY", 12, 232299},
	{"DUMBILL", 7, 232300},
	{"WHITEWASHING", 12, 232301},
	{"KUTS", 4, 232302},
	{"FEMMINA", 7, 232303},
	{"LENDL", 5, 232304},
	{"MIDC", 4, 232305},
	{"CERRAR", 6, 232306},
	{"HOUSESTAFF", 10, 232307},
	{"AUTOWITCH", 9, 232308},
	{"XFD", 3, 232309},
	{"RESPAWNED", 9, 232310},
	{"BORDERLINES", 11, 232311},
	{"RUTE", 4, 232312},
	{"COPYRIGHTING", 12, 232313},
	{"BACKJOY", 7, 232314},
	{"NLOM", 4, 232315},
	{"MANRIQUE", 8, 232316},
	{"TURER", 5, 232317},
	{"MCKEES", 6, 232318},
	{"FUNGOIDES", 9, 232319},
	{"DAVION", 6, 232320},
	{"BDDS", 4, 232321},
	{"REIMPORTATION", 13, 232322},
	{"OSTWALD", 7, 232323},
	{"MIRENA", 6, 232324},
	{"EMCS", 4, 232325},
	{"OPTIMIERT", 9, 232326},
	{"BIOTENE", 7, 232327},
	{"BIOM", 4, 232328},
	{"BEARDY", 6, 232329},
	{"REETING", 7, 232330},
	{"BROCTON", 7, 232331},
	{"WOWWIKI", 7, 232332},
	{"LIBGSASL", 8, 232333},
	{"MASSMUTUAL", 10, 232334},
	{"ALLWORDS", 8, 232335},
	{"RWSIA", 5, 232336},
	{"LATERALIZATION", 14, 232337},
	{"BCITY", 5, 232338},
	{"TRIALED", 7, 232339},
	{"CROTALUS", 8, 232340},
	{"SHEHZAD", 7, 232341},
	{"APSL", 4, 232342},
	{"STOEIES", 7, 232343},
	{"RECOMMENCED", 11, 232344},
	{"OBSTRUCTIONIST", 14, 232345},
	{"APLASIA", 7, 232346},
	{"UNDERGROUNDS", 12, 232347},
	{"RANCHEROS", 9, 232348},
	{"INACTIONS", 9, 232349},
	{"CHASSELL", 8, 232350},
	{"BRESSER", 7, 232351},
	{"WWWCARTOON", 10, 232352},
	{"MYM", 3, 232353},
	{"KOVALENKO", 9, 232354},
	{"TOPICZ", 6, 232355},
	{"NEUROPATHOLOGICAL", 17, 232356},
	{"MCAFEEE", 7, 232357},
	{"ILLUSTRA", 8, 232358},
	{"DETOURED", 8, 232359},
	{"ZOWS", 4, 232360},
	{"YYUB", 4, 232361},
	{"YKOP", 4, 232362},
	{"YCOK", 4, 232363},
	{"YCIC", 4, 232364},
	{"XERD", 4, 232365},
	{"WLSM", 4, 232366},
	{"VPUR", 4, 232367},
	{"UIZC", 4, 232368},
	{"UIRH", 4, 232369},
	{"UBJO", 4, 232370},
	{"TYNJ", 4, 232371},
	{"TABM", 4, 232372},
	{"SZOL", 4, 232373},
	{"SLFO", 4, 232374},
	{"SDHC", 4, 232375},
	{"QMAR", 4, 232376},
	{"PHBI", 4, 232377},
	{"OKKN", 4, 232378},
	{"ODIX", 4, 232379},
	{"NGDD", 4, 232380},
	{"NCYQ", 4, 232381},
	{"NAVC", 4, 232382},
	{"MVAU", 4, 232383},
	{"MOLK", 4, 232384},
	{"MLYH", 4, 232385},
	{"MKOW", 4, 232386},
	{"MAKL", 4, 232387},
	{"LSLY", 4, 232388},
	{"LRER", 4, 232389},
	{"LHUA", 4, 232390},
	{"LCDM", 4, 232391},
	{"IZZU", 4, 232392},
	{"ISVP", 4, 232393},
	{"IDYR", 4, 232394},
	{"HLPA", 4, 232395},
	{"HKAW", 4, 232396},
	{"HDYS", 4, 232397},
	{"FMRG", 4, 232398},
	{"FLID", 4, 232399},
	{"EXAX", 4, 232400},
	{"ESDD", 4, 232401},
	{"DTLE", 4, 232402},
	{"DROJ", 4, 232403},
	{"DRDU", 4, 232404},
	{"DNPR", 4, 232405},
	{"DFEY", 4, 232406},
	{"DAPW", 4, 232407},
	{"CTVF", 4, 232408},
	{"CSSL", 4, 232409},
	{"CIDG", 4, 232410},
	{"BYSV", 4, 232411},
	{"BVIL", 4, 232412},
	{"BMMA", 4, 232413},
	{"BLIF", 4, 232414},
	{"AQSC", 4, 232415},
	{"STUHL", 5, 232416},
	{"ICLEI", 5, 232417},
	{"AZIMUT", 6, 232418},
	{"TALIGN", 6, 232419},
	{"PYRROLIDONE", 11, 232420},
	{"KONIGSBERG", 10, 232421},
	{"DPUG", 4, 232422},
	{"CARTOOONNETWORK", 15, 232423},
	{"PESCH", 5, 232424},
	{"CENTERFIRE", 10, 232425},
	{"XBOXES", 6, 232426},
	{"ENTEX", 5, 232427},
	{"DALU", 4, 232428},
	{"CIRCUITREE", 10, 232429},
	{"BIBLIOTHEKEN", 12, 232430},
	{"ALTAVIS", 7, 232431},
	{"STEPPARENTS", 11, 232432},
	{"AMVETS", 6, 232433},
	{"SPANAIR", 7, 232434},
	{"VALLIER", 7, 232435},
	{"POCHI", 5, 232436},
	{"PECIALLY", 8, 232437},
	{"LADYMAN", 7, 232438},
	{"VANCES", 6, 232439},
	{"UFPJ", 4, 232440},
	{"OPERATIVO", 9, 232441},
	{"KETTLEMAN", 9, 232442},
	{"ISOMERISM", 9, 232443},
	{"EPINEPHELUS", 11, 232444},
	{"CACCC", 5, 232445},
	{"DIBUTYL", 7, 232446},
	{"UNPARALLED", 10, 232447},
	{"PARHAU", 6, 232448},
	{"NAKORN", 6, 232449},
	{"LUTRA", 5, 232450},
	{"CYPRINUS", 8, 232451},
	{"BERLINGER", 9, 232452},
	{"REALLIFE", 8, 232453},
	{"PREPUBERTAL", 11, 232454},
	{"GALLICA", 7, 232455},
	{"RINDERPEST", 10, 232456},
	{"GTXC", 4, 232457},
	{"CARROSSERIE", 11, 232458},
	{"RAILROADIANA", 12, 232459},
	{"RIESE", 5, 232460},
	{"PORTFIELD", 9, 232461},
	{"POPKEN", 6, 232462},
	{"MONTINI", 7, 232463},
	{"NEWORLEANS", 10, 232464},
	{"DEPOPULATED", 11, 232465},
	{"SANTAREM", 8, 232466},
	{"GLASNEVIN", 9, 232467},
	{"VAMPYR", 6, 232468},
	{"NEWFS", 5, 232469},
	{"JUBAK", 5, 232470},
	{"BELUX", 5, 232471},
	{"TRAVES", 6, 232472},
	{"FLEABANE", 8, 232473},
	{"ALBERTINIA", 10, 232474},
	{"VIDEOHELP", 9, 232475},
	{"JABIL", 5, 232476},
	{"TARAH", 5, 232477},
	{"NEWSFIRE", 8, 232478},
	{"GHAURI", 6, 232479},
	{"EDUN", 4, 232480},
	{"NOVAPDF", 7, 232481},
	{"COCKAYNE", 8, 232482},
	{"LAYDEN", 6, 232483},
	{"GOCOM", 5, 232484},
	{"DAEMEN", 6, 232485},
	{"SCHENLEY", 8, 232486},
	{"FIRMICUTES", 10, 232487},
	{"ELEK", 4, 232488},
	{"CRUDDY", 6, 232489},
	{"TRAVCOA", 7, 232490},
	{"HOTNUDES", 8, 232491},
	{"ACTINOMYCETES", 13, 232492},
	{"INVERKEITHING", 13, 232493},
	{"STORKES", 7, 232494},
	{"TAGINE", 6, 232495},
	{"SILOXANE", 8, 232496},
	{"SCIECNE", 7, 232497},
	{"PIANS", 5, 232498},
	{"OVULATORY", 9, 232499},
	{"WWWMICROSOFTCOM", 15, 232500},
	{"PSTRING", 7, 232501},
	{"INTERESTIN", 10, 232502},
	{"FERNBANK", 8, 232503},
	{"DELMER", 6, 232504},
	{"ENWSH", 5, 232505},
	{"VEMBER", 6, 232506},
	{"MEBLE", 5, 232507},
	{"HOLONET", 7, 232508},
	{"HIGUERA", 7, 232509},
	{"DOZOR", 5, 232510},
	{"COLU", 4, 232511},
	{"BRIGETTE", 8, 232512},
	{"SWEETNEY", 8, 232513},
	{"MISCUES", 7, 232514},
	{"ECLIPS", 6, 232515},
	{"RACHEAL", 7, 232516},
	{"PHOTOSHOPPING", 13, 232517},
	{"ICSD", 4, 232518},
	{"GERYON", 6, 232519},
	{"DIERK", 5, 232520},
	{"PAULSBORO", 9, 232521},
	{"NEKOOSA", 7, 232522},
	{"BRIMMER", 7, 232523},
	{"UPRAISED", 8, 232524},
	{"ZUZU", 4, 232525},
	{"WWWDELL", 7, 232526},
	{"WHABAM", 6, 232527},
	{"SHITAKE", 7, 232528},
	{"OFFICALS", 8, 232529},
	{"WATERSTONES", 11, 232530},
	{"RIADABILLBOARD", 14, 232531},
	{"CORVARA", 7, 232532},
	{"MCNERNEY", 8, 232533},
	{"ALLENDER", 8, 232534},
	{"ERRRR", 5, 232535},
	{"LAWREN", 6, 232536},
	{"KORBAN", 6, 232537},
	{"WIRLINES", 8, 232538},
	{"HEADSHOPS", 9, 232539},
	{"FORMEN", 6, 232540},
	{"TENDENTIOUS", 11, 232541},
	{"RECESSIONAL", 11, 232542},
	{"CONICS", 6, 232543},
	{"SCREENSAVES", 11, 232544},
	{"CODEPRO", 7, 232545},
	{"ONYCHOMYCOSIS", 13, 232546},
	{"NOBLECOM", 8, 232547},
	{"FLYCOM", 6, 232548},
	{"EPID", 4, 232549},
	{"WORKADAY", 8, 232550},
	{"SITECOPY", 8, 232551},
	{"ROMANZA", 7, 232552},
	{"IRANMANIA", 9, 232553},
	{"FILLIN", 6, 232554},
	{"NANAKO", 6, 232555},
	{"XTORIES", 7, 232556},
	{"TABLEBREAK", 10, 232557},
	{"GEOMETRIE", 9, 232558},
	{"CRATERING", 9, 232559},
	{"BACKSIDES", 9, 232560},
	{"KVARNER", 7, 232561},
	{"HOLDAYS", 7, 232562},
	{"DIFFICULTLY", 11, 232563},
	{"BELS", 4, 232564},
	{"TENNSCO", 7, 232565},
	{"PFENNING", 8, 232566},
	{"HUCKLEBERRIES", 13, 232567},
	{"VIDETTE", 7, 232568},
	{"ROUNDWORM", 9, 232569},
	{"IRLINE", 6, 232570},
	{"AFSD", 4, 232571},
	{"TABBORD", 7, 232572},
	{"ROOTSY", 6, 232573},
	{"ROBOTNIK", 8, 232574},
	{"ORGANDY", 7, 232575},
	{"DIVORCEES", 9, 232576},
	{"BERNARDINE", 10, 232577},
	{"DEMETHYLATION", 13, 232578},
	{"BAZOOKAS", 8, 232579},
	{"OONLINE", 7, 232580},
	{"KIDCARE", 7, 232581},
	{"WHEREUNTO", 9, 232582},
	{"QUIKSCAT", 8, 232583},
	{"MARTENSITE", 10, 232584},
	{"KPFT", 4, 232585},
	{"GALVANISING", 11, 232586},
	{"CELLPAD", 7, 232587},
	{"WELBUTRIN", 9, 232588},
	{"MAMODO", 6, 232589},
	{"BOXLEY", 6, 232590},
	{"VOLEIBOL", 8, 232591},
	{"RTCM", 4, 232592},
	{"BANKCOM", 7, 232593},
	{"BAKERLOO", 8, 232594},
	{"RIZWAN", 6, 232595},
	{"PILC", 4, 232596},
	{"GROUPOID", 8, 232597},
	{"EURONET", 7, 232598},
	{"SHOCKWAVECOM", 12, 232599},
	{"MCBETH", 6, 232600},
	{"COMPHEALTH", 10, 232601},
	{"ORBITZCOM", 9, 232602},
	{"IMGALIGN", 8, 232603},
	{"FUSTE", 5, 232604},
	{"ZIRLINES", 8, 232605},
	{"TRAFFICS", 8, 232606},
	{"TOXICOLOGIC", 11, 232607},
	{"MOJICA", 6, 232608},
	{"XPKGWEDGE", 9, 232609},
	{"SOAPSTAR", 8, 232610},
	{"FIRELINE", 8, 232611},
	{"CELLSPA", 7, 232612},
	{"YMDDIRIEDOLAETH", 15, 232613},
	{"SAMLING", 7, 232614},
	{"FUIT", 4, 232615},
	{"REQUI", 5, 232616},
	{"HOTMAILL", 8, 232617},
	{"DODGEBLOGIUM", 12, 232618},
	{"LICHTBLAU", 9, 232619},
	{"LIBCAMEL", 8, 232620},
	{"WAITT", 5, 232621},
	{"SACCHETTI", 9, 232622},
	{"MAHARAJI", 8, 232623},
	{"TRIAZOLE", 8, 232624},
	{"SAMUAL", 6, 232625},
	{"NONCONVEX", 9, 232626},
	{"PINETOWN", 8, 232627},
	{"PARDES", 6, 232628},
	{"FABRICATES", 10, 232629},
	{"CLAIRES", 7, 232630},
	{"WWWTEEN", 7, 232631},
	{"SMAK", 4, 232632},
	{"DARY", 4, 232633},
	{"CRUISEROYAL", 11, 232634},
	{"LAMPOONS", 8, 232635},
	{"LINCH", 5, 232636},
	{"WWWDISNEY", 9, 232637},
	{"AIRLINDS", 8, 232638},
	{"TAPPET", 6, 232639},
	{"SURVEIL", 7, 232640},
	{"VORST", 5, 232641},
	{"CTPP", 4, 232642},
	{"ZSMA", 4, 232643},
	{"ZSAR", 4, 232644},
	{"ZMIE", 4, 232645},
	{"YDJO", 4, 232646},
	{"YAKB", 4, 232647},
	{"XMAL", 4, 232648},
	{"XASY", 4, 232649},
	{"WNEB", 4, 232650},
	{"VVYP", 4, 232651},
	{"UZTO", 4, 232652},
	{"UYVI", 4, 232653},
	{"UYNH", 4, 232654},
	{"UOJU", 4, 232655},
	{"UMKU", 4, 232656},
	{"UKOK", 4, 232657},
	{"TUAF", 4, 232658},
	{"TSGY", 4, 232659},
	{"SKMR", 4, 232660},
	{"RPUG", 4, 232661},
	{"RKMR", 4, 232662},
	{"PURJ", 4, 232663},
	{"PUNW", 4, 232664},
	{"POKD", 4, 232665},
	{"PIEV", 4, 232666},
	{"OZWH", 4, 232667},
	{"OLUF", 4, 232668},
	{"OJUP", 4, 232669},
	{"OFRF", 4, 232670},
	{"NZBA", 4, 232671},
	{"MYUM", 4, 232672},
	{"MUPN", 4, 232673},
	{"MMME", 4, 232674},
	{"MIKS", 4, 232675},
	{"MDAH", 4, 232676},
	{"LZEA", 4, 232677},
	{"LZAI", 4, 232678},
	{"LOMT", 4, 232679},
	{"LNYS", 4, 232680},
	{"LADZ", 4, 232681},
	{"KRHO", 4, 232682},
	{"JEZE", 4, 232683},
	{"IBOB", 4, 232684},
	{"HDWE", 4, 232685},
	{"GXUN", 4, 232686},
	{"GNBL", 4, 232687},
	{"FZUR", 4, 232688},
	{"FSUA", 4, 232689},
	{"FRHA", 4, 232690},
	{"FMRK", 4, 232691},
	{"EUGO", 4, 232692},
	{"EKEK", 4, 232693},
	{"DZOL", 4, 232694},
	{"DEXJ", 4, 232695},
	{"CPOU", 4, 232696},
	{"CFTO", 4, 232697},
	{"BUHI", 4, 232698},
	{"BMWE", 4, 232699},
	{"AUZI", 4, 232700},
	{"AOCU", 4, 232701},
	{"AMGH", 4, 232702},
	{"TABLEBGCOLOR", 12, 232703},
	{"SMASHERS", 8, 232704},
	{"ORDAINING", 9, 232705},
	{"BEAG", 4, 232706},
	{"ENJOYABLY", 9, 232707},
	{"AVALUE", 6, 232708},
	{"UKYO", 4, 232709},
	{"RELEX", 5, 232710},
	{"MSNGAMES", 8, 232711},
	{"KIDDOPOTAMUS", 12, 232712},
	{"DSCF", 4, 232713},
	{"ASKJEEVS", 8, 232714},
	{"FRINGILLA", 9, 232715},
	{"TIMKO", 5, 232716},
	{"RUBIKS", 6, 232717},
	{"LUEPKE", 6, 232718},
	{"FARODP", 6, 232719},
	{"CNETCOM", 7, 232720},
	{"BENDON", 6, 232721},
	{"UNFRUITFUL", 10, 232722},
	{"NAWAL", 5, 232723},
	{"FRAVEL", 6, 232724},
	{"BLEKINGE", 8, 232725},
	{"AIRLIHES", 8, 232726},
	{"PALEOCEANOGRAPHY", 16, 232727},
	{"NAMOR", 5, 232728},
	{"KHORASAN", 8, 232729},
	{"FOURNIS", 7, 232730},
	{"MESSI", 5, 232731},
	{"HBOC", 4, 232732},
	{"BONCZA", 6, 232733},
	{"BEWERBERDATENBANK", 17, 232734},
	{"ABUELA", 6, 232735},
	{"REPENTIGNY", 10, 232736},
	{"FERG", 4, 232737},
	{"CHILHOWIE", 9, 232738},
	{"ARBOL", 5, 232739},
	{"NICOLOSI", 8, 232740},
	{"NITISH", 6, 232741},
	{"LOQUAT", 6, 232742},
	{"ISOPODA", 7, 232743},
	{"CONCEITS", 8, 232744},
	{"SYLPH", 5, 232745},
	{"HARSHAW", 7, 232746},
	{"FOTOWEDSTRIJD", 13, 232747},
	{"ILUKA", 5, 232748},
	{"RAHLVES", 7, 232749},
	{"MACMICE", 7, 232750},
	{"INGUSH", 6, 232751},
	{"ESTAING", 7, 232752},
	{"AKRLINES", 8, 232753},
	{"PUKALANI", 8, 232754},
	{"NECROPHAGIA", 11, 232755},
	{"FILEPIPE", 8, 232756},
	{"WWWIRSGOV", 9, 232757},
	{"MOSTERT", 7, 232758},
	{"MEGGIESOFT", 10, 232759},
	{"BANTEAY", 7, 232760},
	{"COMMNUNITY", 10, 232761},
	{"COLORVIEW", 9, 232762},
	{"BEANSPROUT", 10, 232763},
	{"STRUMMED", 8, 232764},
	{"KACIE", 5, 232765},
	{"SHRIVELLED", 10, 232766},
	{"ERDA", 4, 232767},
	{"AVAILABITY", 10, 232768},
	{"ANTHROPOMORPHISM", 16, 232769},
	{"SEVERA", 6, 232770},
	{"MOIES", 5, 232771},
	{"CLUBB", 5, 232772},
	{"RICKO", 5, 232773},
	{"MAXWEBPORTAL", 12, 232774},
	{"COMPLETECARE", 12, 232775},
	{"CARUTHERSVILLE", 14, 232776},
	{"MSNGAMINGZONE", 13, 232777},
	{"GESCHENK", 8, 232778},
	{"AIRLINSS", 8, 232779},
	{"QDRO", 4, 232780},
	{"JESTING", 7, 232781},
	{"SIRK", 4, 232782},
	{"FAHMY", 5, 232783},
	{"CLINGAN", 7, 232784},
	{"VERSICHERUNGEN", 14, 232785},
	{"VARISTORS", 9, 232786},
	{"ENTERO", 6, 232787},
	{"PGB", 3, 232788},
	{"FISCHERI", 8, 232789},
	{"CARTHIK", 7, 232790},
	{"SANDSTORMS", 10, 232791},
	{"GETCHELL", 8, 232792},
	{"MULTIHULLS", 10, 232793},
	{"AIFLINES", 8, 232794},
	{"ORDERPHENTERMINE", 16, 232795},
	{"DELET", 5, 232796},
	{"LIFEFITNESS", 11, 232797},
	{"GRIDPORTLETS", 12, 232798},
	{"SADAAM", 6, 232799},
	{"RPW", 3, 232800},
	{"WHITECAP", 8, 232801},
	{"HYMNE", 5, 232802},
	{"FOURNIES", 8, 232803},
	{"VINAL", 5, 232804},
	{"VICROADS", 8, 232805},
	{"LEIBLER", 7, 232806},
	{"HYLEXIN", 7, 232807},
	{"ESCRIMA", 7, 232808},
	{"BIERLOW", 7, 232809},
	{"TREBLES", 7, 232810},
	{"TECLA", 5, 232811},
	{"POGN", 4, 232812},
	{"TABLEBRCOL", 10, 232813},
	{"NAKADA", 6, 232814},
	{"INCLUYENDO", 10, 232815},
	{"BURGLED", 7, 232816},
	{"BESTELLING", 10, 232817},
	{"GASSAWAY", 8, 232818},
	{"DANWEI", 6, 232819},
	{"BEGRIFF", 7, 232820},
	{"MATYAS", 6, 232821},
	{"HAGOPIAN", 8, 232822},
	{"EVANGELISATION", 14, 232823},
	{"DELTAIC", 7, 232824},
	{"AIROINES", 8, 232825},
	{"ICTERUS", 7, 232826},
	{"ADHOUSE", 7, 232827},
	{"KINKEAD", 7, 232828},
	{"DANESH", 6, 232829},
	{"BRUEN", 5, 232830},
	{"POLYSOMNOGRAPHY", 15, 232831},
	{"MORPHEUZ", 8, 232832},
	{"CLANSMAN", 8, 232833},
	{"YARED", 5, 232834},
	{"NURSERYMEN", 10, 232835},
	{"MEBENDAZOLE", 11, 232836},
	{"MASJIDS", 7, 232837},
	{"FERREE", 6, 232838},
	{"TOWNIE", 6, 232839},
	{"STORMRAGE", 9, 232840},
	{"RORAIMA", 7, 232841},
	{"EYEMOUTH", 8, 232842},
	{"COMPARISIONS", 12, 232843},
	{"APRIA", 5, 232844},
	{"AIRPINES", 8, 232845},
	{"KOPENHAGEN", 10, 232846},
	{"AIRLIJES", 8, 232847},
	{"TARCHER", 7, 232848},
	{"SCREENSVERS", 11, 232849},
	{"LYNOTT", 6, 232850},
	{"ERFAHRUNG", 9, 232851},
	{"BGCOLORPANEL", 12, 232852},
	{"PHOTOID", 7, 232853},
	{"LACOUR", 6, 232854},
	{"KOTJZE", 6, 232855},
	{"CVALIGN", 7, 232856},
	{"AJRLINES", 8, 232857},
	{"TENDRIL", 7, 232858},
	{"QUOQUE", 6, 232859},
	{"OECDDIRECT", 10, 232860},
	{"DESYREL", 7, 232861},
	{"TRINET", 6, 232862},
	{"PAKULA", 6, 232863},
	{"DOOKS", 5, 232864},
	{"PNEUMONIC", 9, 232865},
	{"LITHERLAND", 10, 232866},
	{"DANGLER", 7, 232867},
	{"PICKTON", 7, 232868},
	{"DORSCH", 6, 232869},
	{"MODICA", 6, 232870},
	{"LEBLOND", 7, 232871},
	{"DOGPILES", 8, 232872},
	{"OPOLY", 5, 232873},
	{"PRODRUGS", 8, 232874},
	{"HOUES", 5, 232875},
	{"NIBIRU", 6, 232876},
	{"MCCAIG", 6, 232877},
	{"DROGUES", 7, 232878},
	{"SENSITISED", 10, 232879},
	{"TRANSHUMAN", 10, 232880},
	{"SGMA", 4, 232881},
	{"FIEBER", 6, 232882},
	{"COMPUCESSORY", 12, 232883},
	{"ALTAVISTACOM", 12, 232884},
	{"NEEDVILLE", 9, 232885},
	{"IMMULITE", 8, 232886},
	{"RUSHEN", 6, 232887},
	{"LIBECASOUND", 11, 232888},
	{"LYNES", 5, 232889},
	{"RIEBEEK", 7, 232890},
	{"MISCELLENEOUS", 13, 232891},
	{"QLINK", 5, 232892},
	{"PECVD", 5, 232893},
	{"PARDEW", 6, 232894},
	{"PACITY", 6, 232895},
	{"JSCROLLPANE", 11, 232896},
	{"SEAMEO", 6, 232897},
	{"HOTTMAIL", 8, 232898},
	{"ASKJEEVESKIDS", 13, 232899},
	{"TWIZEL", 6, 232900},
	{"JORDO", 5, 232901},
	{"CONFIGURER", 10, 232902},
	{"CAPITIS", 7, 232903},
	{"RAVENA", 6, 232904},
	{"CLANGS", 6, 232905},
	{"ATTNET", 6, 232906},
	{"WWWFORD", 7, 232907},
	{"SCREENSVAERS", 12, 232908},
	{"HATEMONGERS", 11, 232909},
	{"FOTOGALERIE", 11, 232910},
	{"PHENTERMINEDIET", 15, 232911},
	{"UNSHAKEABLE", 11, 232912},
	{"FINDWHAT", 8, 232913},
	{"FEBR", 4, 232914},
	{"KYPRIANOU", 9, 232915},
	{"FRIEDREICH", 10, 232916},
	{"NUBBY", 5, 232917},
	{"KYOKAI", 6, 232918},
	{"BLUEHYPPO", 9, 232919},
	{"SMOLLETT", 8, 232920},
	{"PUTASOLUTIONS", 13, 232921},
	{"FIRN", 4, 232922},
	{"SILICIDE", 8, 232923},
	{"WALLCLOCK", 9, 232924},
	{"REPRESSORS", 10, 232925},
	{"HARPIES", 7, 232926},
	{"SCHOTTENHEIMER", 14, 232927},
	{"MISQUOTE", 8, 232928},
	{"BACKSTAMP", 9, 232929},
	{"FMIRROR", 7, 232930},
	{"FIDH", 4, 232931},
	{"SYMPORTER", 9, 232932},
	{"JEANA", 5, 232933},
	{"IRCAM", 5, 232934},
	{"SMIF", 4, 232935},
	{"CONDIE", 6, 232936},
	{"CHAMBLY", 7, 232937},
	{"TESCOS", 6, 232938},
	{"SULLUM", 6, 232939},
	{"ICNIRP", 6, 232940},
	{"GARDENBUDDIES", 13, 232941},
	{"FIENBERG", 8, 232942},
	{"DAVECOM", 7, 232943},
	{"BALTZ", 5, 232944},
	{"YSUV", 4, 232945},
	{"YRWH", 4, 232946},
	{"XXEU", 4, 232947},
	{"WYDI", 4, 232948},
	{"WLLE", 4, 232949},
	{"WFCH", 4, 232950},
	{"USOG", 4, 232951},
	{"URJI", 4, 232952},
	{"UQUB", 4, 232953},
	{"UATM", 4, 232954},
	{"UAKU", 4, 232955},
	{"TOWV", 4, 232956},
	{"TEZR", 4, 232957},
	{"STJR", 4, 232958},
	{"SPSM", 4, 232959},
	{"SMBL", 4, 232960},
	{"RVAH", 4, 232961},
	{"RTYQ", 4, 232962},
	{"RRUK", 4, 232963},
	{"RQAN", 4, 232964},
	{"RPCB", 4, 232965},
	{"RLKA", 4, 232966},
	{"QINV", 4, 232967},
	{"PSGL", 4, 232968},
	{"PEPY", 4, 232969},
	{"OZOW", 4, 232970},
	{"OKYU", 4, 232971},
	{"OFOJ", 4, 232972},
	{"NYUI", 4, 232973},
	{"NGRN", 4, 232974},
	{"MPGC", 4, 232975},
	{"MDUA", 4, 232976},
	{"MAAY", 4, 232977},
	{"LSAX", 4, 232978},
	{"LKIP", 4, 232979},
	{"LBLV", 4, 232980},
	{"KYHU", 4, 232981},
	{"KOOC", 4, 232982},
	{"IXAW", 4, 232983},
	{"GMSW", 4, 232984},
	{"GJAW", 4, 232985},
	{"GIDH", 4, 232986},
	{"GHYM", 4, 232987},
	{"FDAE", 4, 232988},
	{"ERUZ", 4, 232989},
	{"ENVU", 4, 232990},
	{"EMXI", 4, 232991},
	{"CVEY", 4, 232992},
	{"CPWA", 4, 232993},
	{"CODH", 4, 232994},
	{"BMTH", 4, 232995},
	{"BETJ", 4, 232996},
	{"AMUW", 4, 232997},
	{"ALYK", 4, 232998},
	{"ALGM", 4, 232999},
	{"AKCU", 4, 233000},
	{"POLARA", 6, 233001},
	{"MSNNEWS", 7, 233002},
	{"NARELLE", 7, 233003},
	{"HNPCC", 5, 233004},
	{"CYBERATHLETE", 12, 233005},
	{"NEWSVINE", 8, 233006},
	{"HINTERGRUNDBILDER", 17, 233007},
	{"GREENACRE", 9, 233008},
	{"COLLAZO", 7, 233009},
	{"LINKDB", 6, 233010},
	{"CONSP", 5, 233011},
	{"OKAMI", 5, 233012},
	{"LUPINS", 6, 233013},
	{"CHACKO", 6, 233014},
	{"PLEVNA", 6, 233015},
	{"FRACCI", 6, 233016},
	{"SICHEL", 6, 233017},
	{"PROCESSINGTALK", 14, 233018},
	{"JEFFY", 5, 233019},
	{"FIDANZA", 7, 233020},
	{"NORLIN", 6, 233021},
	{"MCCLAY", 6, 233022},
	{"ZAMAWIAM", 8, 233023},
	{"LAHINCH", 7, 233024},
	{"DAYES", 5, 233025},
	{"STRIPLINE", 9, 233026},
	{"DEVITA", 6, 233027},
	{"CENIS", 5, 233028},
	{"WATERBUCK", 9, 233029},
	{"VICTIMLESS", 10, 233030},
	{"WWWREAL", 7, 233031},
	{"KROG", 4, 233032},
	{"GEROGE", 6, 233033},
	{"FASTE", 5, 233034},
	{"ASKCOM", 6, 233035},
	{"PURUSHA", 7, 233036},
	{"EFFECTUATED", 11, 233037},
	{"WWWDELLCOM", 10, 233038},
	{"TOEPFER", 7, 233039},
	{"ASCHE", 5, 233040},
	{"SCHLEIFER", 9, 233041},
	{"CHIPEWYAN", 9, 233042},
	{"NOTAMS", 6, 233043},
	{"CAAP", 4, 233044},
	{"SURVEILANCE", 11, 233045},
	{"PAPERY", 6, 233046},
	{"ETRY", 4, 233047},
	{"SPLOID", 6, 233048},
	{"SAKYA", 5, 233049},
	{"NORMANDALE", 10, 233050},
	{"HONKED", 6, 233051},
	{"ENTENDU", 7, 233052},
	{"ACCRETIONS", 10, 233053},
	{"TRANSTHORACIC", 13, 233054},
	{"JAVAD", 5, 233055},
	{"BRASSED", 7, 233056},
	{"INTERCESSIONS", 13, 233057},
	{"EUROPHOBIA", 10, 233058},
	{"ONLINEANTIVIRUS", 15, 233059},
	{"HAGEE", 5, 233060},
	{"CSIENCE", 7, 233061},
	{"WWWBANKOFAMERICA", 16, 233062},
	{"SORP", 4, 233063},
	{"REDWORK", 7, 233064},
	{"JYVE", 4, 233065},
	{"TRAVEI", 6, 233066},
	{"SOKOLOW", 7, 233067},
	{"GLENDENNING", 11, 233068},
	{"CRANOR", 6, 233069},
	{"ATOMIQUE", 8, 233070},
	{"FONTI", 5, 233071},
	{"AUDIOCOURSES", 12, 233072},
	{"USEFOR", 6, 233073},
	{"ODILON", 6, 233074},
	{"LUNDIS", 6, 233075},
	{"FRANCHITTI", 10, 233076},
	{"HPCOM", 5, 233077},
	{"DMOZORG", 7, 233078},
	{"BARDOLPH", 8, 233079},
	{"NISHIKI", 7, 233080},
	{"ELAINA", 6, 233081},
	{"BLOCKMAP", 8, 233082},
	{"SCEC", 4, 233083},
	{"PELLUCIDA", 9, 233084},
	{"ERCOLE", 6, 233085},
	{"ATHRO", 5, 233086},
	{"KITTYS", 6, 233087},
	{"INDES", 5, 233088},
	{"IMPAKT", 6, 233089},
	{"GEOSYNTHETIC", 12, 233090},
	{"NUBE", 4, 233091},
	{"MATEMATIK", 9, 233092},
	{"LEECHBURG", 9, 233093},
	{"HINTERGRUND", 11, 233094},
	{"DEPERSONALIZATION", 17, 233095},
	{"HAMMAD", 6, 233096},
	{"DESPOILING", 10, 233097},
	{"WWWRAMBLERRU", 12, 233098},
	{"CLUBHOTEL", 9, 233099},
	{"ASSUM", 5, 233100},
	{"SSRULE", 6, 233101},
	{"DEKEL", 5, 233102},
	{"DCTC", 4, 233103},
	{"XERYUS", 6, 233104},
	{"TOBACCONIST", 11, 233105},
	{"POWERPRO", 8, 233106},
	{"PASCH", 5, 233107},
	{"KEUR", 4, 233108},
	{"MOTOGRATER", 10, 233109},
	{"UHMWPE", 6, 233110},
	{"THEAETETUS", 10, 233111},
	{"GEOCITIESCOM", 12, 233112},
	{"MILIUS", 6, 233113},
	{"ICCD", 4, 233114},
	{"BJECTIVES", 9, 233115},
	{"ASKJEVS", 7, 233116},
	{"MESHWORK", 8, 233117},
	{"SKYPEOUT", 8, 233118},
	{"QNAMES", 6, 233119},
	{"KUNSTENAARS", 11, 233120},
	{"URINETOWN", 9, 233121},
	{"MASTHEADS", 9, 233122},
	{"BEARETH", 7, 233123},
	{"WESTERNIZATION", 14, 233124},
	{"ORIOL", 5, 233125},
	{"MCDB", 4, 233126},
	{"HOPYARD", 7, 233127},
	{"VERKRIJGBARE", 12, 233128},
	{"CHANUKA", 7, 233129},
	{"CARRUM", 6, 233130},
	{"SHAWNIE", 7, 233131},
	{"HOTMAILOM", 9, 233132},
	{"HYTIME", 6, 233133},
	{"DATAFEED", 8, 233134},
	{"XMLFREE", 7, 233135},
	{"WWWCARTOONNETWORK", 17, 233136},
	{"OPTICALLYNETWORKED", 18, 233137},
	{"WASANAETHAU", 11, 233138},
	{"TZANEEN", 7, 233139},
	{"REALEASE", 8, 233140},
	{"MOSSI", 5, 233141},
	{"FRZ", 3, 233142},
	{"DULOXETINE", 10, 233143},
	{"VIDEOLIB", 8, 233144},
	{"JUBILEES", 8, 233145},
	{"EBUY", 4, 233146},
	{"ZLP", 3, 233147},
	{"ZKM", 3, 233148},
	{"VIDIKRON", 8, 233149},
	{"VENIS", 5, 233150},
	{"RUNDATA", 7, 233151},
	{"JANY", 4, 233152},
	{"GOOOGLES", 8, 233153},
	{"PRAVO", 5, 233154},
	{"EGISTER", 7, 233155},
	{"TRILOGIES", 9, 233156},
	{"HUNCOM", 6, 233157},
	{"ETHELBERT", 9, 233158},
	{"PICTURESS", 9, 233159},
	{"PARNEVIK", 8, 233160},
	{"UNDERPERFORMED", 14, 233161},
	{"REISSUING", 9, 233162},
	{"SORBETS", 7, 233163},
	{"SCREESAVERS", 11, 233164},
	{"NOWLAN", 6, 233165},
	{"PULSATILLA", 10, 233166},
	{"MAPQUESST", 9, 233167},
	{"KOOPJE", 6, 233168},
	{"FIPSE", 5, 233169},
	{"DIGGENS", 7, 233170},
	{"CIOUS", 5, 233171},
	{"FIELDNAMESPACE", 14, 233172},
	{"KIRKTON", 7, 233173},
	{"FLIPPHONE", 9, 233174},
	{"INVENTAIRE", 10, 233175},
	{"DOUNLOAD", 8, 233176},
	{"CARTOONNNETWORK", 15, 233177},
	{"DIVERSA", 7, 233178},
	{"DENNARD", 7, 233179},
	{"SLEIGHS", 7, 233180},
	{"MURGATROYD", 10, 233181},
	{"EBBA", 4, 233182},
	{"SREEN", 5, 233183},
	{"PENSIERO", 8, 233184},
	{"COLOURINGS", 10, 233185},
	{"CIPART", 6, 233186},
	{"FLDS", 4, 233187},
	{"DSTOOL", 6, 233188},
	{"SPYS", 4, 233189},
	{"MAXIMIN", 7, 233190},
	{"DMY", 3, 233191},
	{"MORTGAGS", 8, 233192},
	{"AUCTIONBYTES", 12, 233193},
	{"NITHSDALE", 9, 233194},
	{"COHERE", 6, 233195},
	{"WWWAMAZON", 9, 233196},
	{"NAFISI", 6, 233197},
	{"PARKNET", 7, 233198},
	{"ALESUND", 7, 233199},
	{"GOOGGLES", 8, 233200},
	{"MOUSEMOVE", 9, 233201},
	{"KNORKATOR", 9, 233202},
	{"HUMEROUS", 8, 233203},
	{"CHARLAINE", 9, 233204},
	{"BITLORD", 7, 233205},
	{"RIGZONE", 7, 233206},
	{"QUANGO", 6, 233207},
	{"HOLDRS", 6, 233208},
	{"VOLKMER", 7, 233209},
	{"KPRESENTER", 10, 233210},
	{"HARCOURTS", 9, 233211},
	{"WASAT", 5, 233212},
	{"DPRINTF", 7, 233213},
	{"METHERINGHAM", 12, 233214},
	{"GREENHITHE", 10, 233215},
	{"EKER", 4, 233216},
	{"EBAYING", 7, 233217},
	{"LICENTIOUSNESS", 14, 233218},
	{"STEINLEN", 8, 233219},
	{"SITESCORE", 9, 233220},
	{"YAHP", 4, 233221},
	{"YAAG", 4, 233222},
	{"WDOD", 4, 233223},
	{"VOOF", 4, 233224},
	{"VLAU", 4, 233225},
	{"VIBH", 4, 233226},
	{"UXTR", 4, 233227},
	{"UVAG", 4, 233228},
	{"UOFD", 4, 233229},
	{"UNNM", 4, 233230},
	{"UHWA", 4, 233231},
	{"UDOJ", 4, 233232},
	{"UAAC", 4, 233233},
	{"TYLD", 4, 233234},
	{"TKUT", 4, 233235},
	{"TDRH", 4, 233236},
	{"SDUI", 4, 233237},
	{"PMTE", 4, 233238},
	{"PAKN", 4, 233239},
	{"ORGK", 4, 233240},
	{"OFYP", 4, 233241},
	{"ODEZ", 4, 233242},
	{"NODL", 4, 233243},
	{"NDWP", 4, 233244},
	{"NDVF", 4, 233245},
	{"NCKH", 4, 233246},
	{"MWIK", 4, 233247},
	{"MUHS", 4, 233248},
	{"MOUG", 4, 233249},
	{"MMSF", 4, 233250},
	{"LUSZ", 4, 233251},
	{"LIKB", 4, 233252},
	{"LFII", 4, 233253},
	{"LELK", 4, 233254},
	{"LBNE", 4, 233255},
	{"KOVN", 4, 233256},
	{"HPBR", 4, 233257},
	{"HBPA", 4, 233258},
	{"GMDO", 4, 233259},
	{"GIPU", 4, 233260},
	{"GFOE", 4, 233261},
	{"GAIC", 4, 233262},
	{"GAEG", 4, 233263},
	{"FIAV", 4, 233264},
	{"EXYC", 4, 233265},
	{"ESZC", 4, 233266},
	{"EDWT", 4, 233267},
	{"DPMN", 4, 233268},
	{"DELZ", 4, 233269},
	{"DBHO", 4, 233270},
	{"COHU", 4, 233271},
	{"BMCK", 4, 233272},
	{"BFUL", 4, 233273},
	{"BEKM", 4, 233274},
	{"ASWU", 4, 233275},
	{"AHMY", 4, 233276},
	{"NOAILLES", 8, 233277},
	{"LIARD", 5, 233278},
	{"INTEGRIFOLIA", 12, 233279},
	{"GRANTSMANSHIP", 13, 233280},
	{"TIMIKES", 7, 233281},
	{"MODESITT", 8, 233282},
	{"NEUMARK", 7, 233283},
	{"MOUNTD", 6, 233284},
	{"MILBY", 5, 233285},
	{"ALVIE", 5, 233286},
	{"TRADENET", 8, 233287},
	{"LABARBERA", 9, 233288},
	{"CIRCS", 5, 233289},
	{"MARKERT", 7, 233290},
	{"IUGG", 4, 233291},
	{"ISFDB", 5, 233292},
	{"GYMART", 6, 233293},
	{"FLEETBOSTON", 11, 233294},
	{"CARADOC", 7, 233295},
	{"WECKER", 6, 233296},
	{"SIFR", 4, 233297},
	{"RISPETTO", 8, 233298},
	{"INSTRUMENTALLY", 14, 233299},
	{"DISRESPECTING", 13, 233300},
	{"PADE", 4, 233301},
	{"BOTCOM", 6, 233302},
	{"INTERTECH", 9, 233303},
	{"PUNNED", 6, 233304},
	{"APPLECOM", 8, 233305},
	{"WWWJOBSEARCH", 12, 233306},
	{"STERANKO", 8, 233307},
	{"INFARCTS", 8, 233308},
	{"CONFORMERS", 10, 233309},
	{"MARLI", 5, 233310},
	{"KOLLOQUIUM", 10, 233311},
	{"ERRORLEVEL", 10, 233312},
	{"BLACKMANS", 9, 233313},
	{"TRADELEADS", 10, 233314},
	{"WWWMSNCOM", 9, 233315},
	{"WWWASKJEEVES", 12, 233316},
	{"SNCC", 4, 233317},
	{"OCEANIAN", 8, 233318},
	{"IMPLI", 5, 233319},
	{"HEITOR", 6, 233320},
	{"GLYTONE", 7, 233321},
	{"WITHERNSEA", 10, 233322},
	{"JURIDIQUES", 10, 233323},
	{"LOCATIONFREE", 12, 233324},
	{"ELINCHROM", 9, 233325},
	{"ASEEK", 5, 233326},
	{"ARIDITY", 7, 233327},
	{"REVITALIZER", 11, 233328},
	{"KASAMA", 6, 233329},
	{"CAVENDER", 8, 233330},
	{"TGGCA", 5, 233331},
	{"PERCEP", 6, 233332},
	{"EFILM", 5, 233333},
	{"CHROMODYNAMICS", 14, 233334},
	{"PARABRAT", 8, 233335},
	{"MAPQU", 5, 233336},
	{"TECHART", 7, 233337},
	{"DSTOOLTK", 8, 233338},
	{"SPLINED", 7, 233339},
	{"SALVOS", 6, 233340},
	{"TELLA", 5, 233341},
	{"QIRLINES", 8, 233342},
	{"KENDLE", 6, 233343},
	{"GHISLAIN", 8, 233344},
	{"HANECAK", 7, 233345},
	{"FORENAMES", 9, 233346},
	{"SCALITO", 7, 233347},
	{"CLEARSWIFT", 10, 233348},
	{"ARLETA", 6, 233349},
	{"ZPASS", 5, 233350},
	{"UMAYYAD", 7, 233351},
	{"MOSTEL", 6, 233352},
	{"MOISHE", 6, 233353},
	{"DCIENCE", 7, 233354},
	{"UREN", 4, 233355},
	{"APIENTRY", 8, 233356},
	{"WILTEL", 6, 233357},
	{"CROTALARIA", 10, 233358},
	{"VERIZONNET", 10, 233359},
	{"INCOMPREHENSION", 15, 233360},
	{"CORBITT", 7, 233361},
	{"UNSHAKEN", 8, 233362},
	{"UNCODED", 7, 233363},
	{"AMPHUR", 6, 233364},
	{"SECULARISATION", 14, 233365},
	{"MESNIL", 6, 233366},
	{"ROUMANIE", 8, 233367},
	{"PANAMERICANA", 12, 233368},
	{"HEXEDIT", 7, 233369},
	{"PUDDY", 5, 233370},
	{"PRICACY", 7, 233371},
	{"TREYNOR", 7, 233372},
	{"SAVINI", 6, 233373},
	{"GLUCANS", 7, 233374},
	{"CREEDON", 7, 233375},
	{"CCHR", 4, 233376},
	{"TURNERSVILLE", 12, 233377},
	{"EXEMPEL", 7, 233378},
	{"MITOS", 5, 233379},
	{"SHEPLER", 7, 233380},
	{"PUNEET", 6, 233381},
	{"DEBENHAM", 8, 233382},
	{"HANAUMA", 7, 233383},
	{"AVIALABLE", 9, 233384},
	{"SUBARRAY", 8, 233385},
	{"NEFESH", 6, 233386},
	{"GYGAX", 5, 233387},
	{"FURUYA", 6, 233388},
	{"ERATURE", 7, 233389},
	{"BORRACHAS", 9, 233390},
	{"SOLDNER", 7, 233391},
	{"MASUK", 5, 233392},
	{"LIGGINS", 7, 233393},
	{"KPRC", 4, 233394},
	{"GIORNATA", 8, 233395},
	{"BROCKHAUS", 9, 233396},
	{"TKERNEL", 7, 233397},
	{"MEHMOOD", 7, 233398},
	{"HAMLIB", 6, 233399},
	{"DIGITIMES", 9, 233400},
	{"ACIENCE", 7, 233401},
	{"EDENTULOUS", 10, 233402},
	{"ROLLERCOASTERS", 14, 233403},
	{"PAWHUSKA", 8, 233404},
	{"FLOWSERVE", 9, 233405},
	{"DIVERTERS", 9, 233406},
	{"STUMPING", 8, 233407},
	{"HANNOSCH", 8, 233408},
	{"ENGLISHWOMAN", 12, 233409},
	{"KOPERSGIDS", 10, 233410},
	{"BASHI", 5, 233411},
	{"ZIMM", 4, 233412},
	{"TUMBNAIL", 8, 233413},
	{"MARSHAK", 7, 233414},
	{"GREATWALL", 9, 233415},
	{"AMARONE", 7, 233416},
	{"FAHNE", 5, 233417},
	{"PANTIN", 6, 233418},
	{"MORPEUS", 7, 233419},
	{"MALIZIA", 7, 233420},
	{"INSTRUMENTPRO", 13, 233421},
	{"GARDENIAS", 9, 233422},
	{"LIMPLY", 6, 233423},
	{"FUELCELL", 8, 233424},
	{"FRAGARIA", 8, 233425},
	{"CORPSOURCE", 10, 233426},
	{"PUCES", 5, 233427},
	{"CANTLEY", 7, 233428},
	{"SAFINA", 6, 233429},
	{"RINGHOTEL", 9, 233430},
	{"QUADBAND", 8, 233431},
	{"DOSHA", 5, 233432},
	{"PROLIXIN", 8, 233433},
	{"BECKNER", 7, 233434},
	{"CARICO", 6, 233435},
	{"FUSIO", 5, 233436},
	{"DIHYDROPYRIDINE", 15, 233437},
	{"CLIMAXING", 9, 233438},
	{"AZONANO", 7, 233439},
	{"LANING", 6, 233440},
	{"IREL", 4, 233441},
	{"VERIZONCOM", 10, 233442},
	{"CHAFFINCH", 9, 233443},
	{"LOCALSYSTEM", 11, 233444},
	{"KARM", 4, 233445},
	{"FERTIGATION", 11, 233446},
	{"HEMOLYMPH", 9, 233447},
	{"GREETNG", 7, 233448},
	{"AUTOMALL", 8, 233449},
	{"SYVERSON", 8, 233450},
	{"REPHRASING", 10, 233451},
	{"POUNDAGE", 8, 233452},
	{"GLYMED", 6, 233453},
	{"WILHELMINE", 10, 233454},
	{"CHRISTE", 7, 233455},
	{"BARBIECOM", 9, 233456},
	{"UDHCPC", 6, 233457},
	{"MATEOS", 6, 233458},
	{"LOINCLOTH", 9, 233459},
	{"ASHLIE", 6, 233460},
	{"BLACKLETTER", 11, 233461},
	{"PEIXES", 6, 233462},
	{"GWENDOLINE", 10, 233463},
	{"DHCD", 4, 233464},
	{"OFFICIELLES", 11, 233465},
	{"MULTILINEAR", 11, 233466},
	{"EKLOGES", 7, 233467},
	{"WESITE", 6, 233468},
	{"MUTIARA", 7, 233469},
	{"MUSSA", 5, 233470},
	{"LOVERIDGE", 9, 233471},
	{"CAHUILLA", 8, 233472},
	{"COMMENTA", 8, 233473},
	{"BOOKMARKSCOM", 12, 233474},
	{"LUNCHTIMES", 10, 233475},
	{"RESUBMITTING", 12, 233476},
	{"IMMOBILISED", 11, 233477},
	{"IDFA", 4, 233478},
	{"ICDDR", 5, 233479},
	{"MADRASA", 7, 233480},
	{"BEDSHEET", 8, 233481},
	{"RADOSLAV", 8, 233482},
	{"SCIENEC", 7, 233483},
	{"HEREWARD", 8, 233484},
	{"SUKHDEEP", 8, 233485},
	{"SEMILLAS", 8, 233486},
	{"MARCHON", 7, 233487},
	{"COENZYMES", 9, 233488},
	{"UNSCORED", 8, 233489},
	{"PLAINSMAN", 9, 233490},
	{"INTELIGENT", 10, 233491},
	{"FELV", 4, 233492},
	{"PROTOKOLL", 9, 233493},
	{"OMNET", 5, 233494},
	{"KOHNO", 5, 233495},
	{"GOOGELS", 7, 233496},
	{"RACICOT", 7, 233497},
	{"WWWRTLDE", 8, 233498},
	{"MURRAYVILLE", 11, 233499},
	{"GASPARINI", 9, 233500},
	{"NYTIMESCOM", 10, 233501},
	{"JSEM", 4, 233502},
	{"GEOPRIV", 7, 233503},
	{"YKUL", 4, 233504},
	{"XNIG", 4, 233505},
	{"WLEI", 4, 233506},
	{"UONF", 4, 233507},
	{"UKCI", 4, 233508},
	{"UFWA", 4, 233509},
	{"TRND", 4, 233510},
	{"TNYU", 4, 233511},
	{"TIVU", 4, 233512},
	{"SPIQ", 4, 233513},
	{"SBNL", 4, 233514},
	{"RTJR", 4, 233515},
	{"RKYD", 4, 233516},
	{"PKHA", 4, 233517},
	{"PIWE", 4, 233518},
	{"NZMI", 4, 233519},
	{"NROF", 4, 233520},
	{"NREK", 4, 233521},
	{"NFCO", 4, 233522},
	{"MTOX", 4, 233523},
	{"MGLI", 4, 233524},
	{"MBFA", 4, 233525},
	{"LSZE", 4, 233526},
	{"LNGE", 4, 233527},
	{"KYTU", 4, 233528},
	{"JRPR", 4, 233529},
	{"IVYI", 4, 233530},
	{"IBEU", 4, 233531},
	{"IABB", 4, 233532},
	{"HPOF", 4, 233533},
	{"HELX", 4, 233534},
	{"HCIG", 4, 233535},
	{"GPEC", 4, 233536},
	{"FYTE", 4, 233537},
	{"FOSM", 4, 233538},
	{"FJHA", 4, 233539},
	{"CQUB", 4, 233540},
	{"COTD", 4, 233541},
	{"CMDI", 4, 233542},
	{"AVSU", 4, 233543},
	{"AHQU", 4, 233544},
	{"ADGH", 4, 233545},
	{"ILISYS", 6, 233546},
	{"FAIF", 4, 233547},
	{"COMBINATORY", 11, 233548},
	{"CLEARONE", 8, 233549},
	{"SAFESITE", 8, 233550},
	{"AHASUERUS", 9, 233551},
	{"WWWBOOK", 7, 233552},
	{"CLAMD", 5, 233553},
	{"CENTAL", 6, 233554},
	{"WRITEBACKS", 10, 233555},
	{"WATERMASYSK", 11, 233556},
	{"SEEMANN", 7, 233557},
	{"ADISTAR", 7, 233558},
	{"REKALL", 6, 233559},
	{"PYTHIAN", 7, 233560},
	{"METONYMY", 8, 233561},
	{"WWWAMAZONCOM", 12, 233562},
	{"ONLINEBILL", 10, 233563},
	{"MONTINE", 7, 233564},
	{"CONBOY", 6, 233565},
	{"COMPASSED", 9, 233566},
	{"CHARCUTERIE", 11, 233567},
	{"COMIXFAN", 8, 233568},
	{"PIDDLE", 6, 233569},
	{"FALLSBURG", 9, 233570},
	{"CROOKE", 6, 233571},
	{"BAGSHAW", 7, 233572},
	{"LIVRARIA", 8, 233573},
	{"CREATIV", 7, 233574},
	{"COUCHMAN", 8, 233575},
	{"VUESCAN", 7, 233576},
	{"GFOA", 4, 233577},
	{"NUNDA", 5, 233578},
	{"HHOTMAIL", 8, 233579},
	{"JBAIRD", 6, 233580},
	{"ZEESHAN", 7, 233581},
	{"WWWFANFICTIONNET", 16, 233582},
	{"PHIGHT", 6, 233583},
	{"OUIMET", 6, 233584},
	{"INFORMIEREN", 11, 233585},
	{"BANKRUPTS", 9, 233586},
	{"APRT", 4, 233587},
	{"TALLS", 5, 233588},
	{"DRITZ", 5, 233589},
	{"ARKLE", 5, 233590},
	{"WWWDOWNLOAD", 11, 233591},
	{"EXPEREINCE", 10, 233592},
	{"AZURA", 5, 233593},
	{"WOODCREEK", 9, 233594},
	{"SIBERT", 6, 233595},
	{"AMPHOE", 6, 233596},
	{"THEORIZES", 9, 233597},
	{"KELDER", 6, 233598},
	{"JOHNEDWARD", 10, 233599},
	{"CORDANI", 7, 233600},
	{"BLANCHING", 9, 233601},
	{"WWWOPMGOV", 9, 233602},
	{"STUBER", 6, 233603},
	{"WWWASK", 6, 233604},
	{"TRENCHARD", 9, 233605},
	{"TEXTWIDTH", 9, 233606},
	{"HABLANDO", 8, 233607},
	{"BIRKELAND", 9, 233608},
	{"WWWGO", 5, 233609},
	{"STECHER", 7, 233610},
	{"LOVIES", 6, 233611},
	{"LIFESPANS", 9, 233612},
	{"CATLEY", 6, 233613},
	{"ZAUBERFLOTE", 11, 233614},
	{"PRIVS", 5, 233615},
	{"LUSKE", 5, 233616},
	{"JEEVESCOM", 9, 233617},
	{"SERAC", 5, 233618},
	{"RKD", 3, 233619},
	{"MONROY", 6, 233620},
	{"WWWMOVIES", 9, 233621},
	{"BULKPAQ", 7, 233622},
	{"ANAEMIC", 7, 233623},
	{"POSTALLY", 8, 233624},
	{"HARLESS", 7, 233625},
	{"BUCKCHERRY", 10, 233626},
	{"TISHREI", 7, 233627},
	{"SHRIMPTON", 9, 233628},
	{"RABIDLY", 7, 233629},
	{"KEONG", 5, 233630},
	{"TRAVERSALS", 10, 233631},
	{"MAILFRONTIER", 12, 233632},
	{"LRIS", 4, 233633},
	{"GOOLES", 6, 233634},
	{"BAFTAS", 6, 233635},
	{"WWWLYCOSCOM", 11, 233636},
	{"KODOCHA", 7, 233637},
	{"FAWZI", 5, 233638},
	{"EUGLENA", 7, 233639},
	{"CYBERTECH", 9, 233640},
	{"SACHI", 5, 233641},
	{"KERMADEC", 8, 233642},
	{"HOTMMAIL", 8, 233643},
	{"HOTMAAIL", 8, 233644},
	{"DEBERRY", 7, 233645},
	{"HOTMAIIL", 8, 233646},
	{"PIRONET", 7, 233647},
	{"MCLEODUSA", 9, 233648},
	{"FREETING", 8, 233649},
	{"ALLMOVIEPORTAL", 14, 233650},
	{"COOOL", 5, 233651},
	{"CHIMINEA", 8, 233652},
	{"ANGLOFILE", 9, 233653},
	{"SETUPSX", 7, 233654},
	{"LUNDHOLM", 8, 233655},
	{"AFIR", 4, 233656},
	{"UNSETTLE", 8, 233657},
	{"TRANSNISTRIA", 12, 233658},
	{"POSTMEN", 7, 233659},
	{"IVILLIAGE", 9, 233660},
	{"GRIZZARD", 8, 233661},
	{"ENDOCERVICAL", 12, 233662},
	{"SNOWDROPS", 9, 233663},
	{"GAMEMASTERY", 11, 233664},
	{"HOLING", 6, 233665},
	{"CINEWORLD", 9, 233666},
	{"BANDH", 5, 233667},
	{"ALGIS", 5, 233668},
	{"ADVANSYS", 8, 233669},
	{"WWWBBCCOUK", 10, 233670},
	{"STARTPOS", 8, 233671},
	{"PROCONSUL", 9, 233672},
	{"NONTHERMAL", 10, 233673},
	{"IMDBCOM", 7, 233674},
	{"DEXTRANS", 8, 233675},
	{"ALGREN", 6, 233676},
	{"KOBS", 4, 233677},
	{"WWWSOUTHWEST", 12, 233678},
	{"PHAL", 4, 233679},
	{"SNELLEN", 7, 233680},
	{"REDUPLICATION", 13, 233681},
	{"POGOCOM", 7, 233682},
	{"OHCOM", 5, 233683},
	{"MAURITZ", 7, 233684},
	{"HUSON", 5, 233685},
	{"COARSEST", 8, 233686},
	{"WWWOVERTURECOM", 14, 233687},
	{"DUNSHEE", 7, 233688},
	{"ATTBICOM", 8, 233689},
	{"ALLSITES", 8, 233690},
	{"OVERPRODUCED", 12, 233691},
	{"KEAAU", 5, 233692},
	{"JENSEITS", 8, 233693},
	{"KAHANI", 6, 233694},
	{"APCA", 4, 233695},
	{"NMPFT", 5, 233696},
	{"ELISSON", 7, 233697},
	{"WAREHOUSED", 10, 233698},
	{"TOMBO", 5, 233699},
	{"MINIUM", 6, 233700},
	{"GLOBOCOM", 8, 233701},
	{"ALBUMINURIA", 11, 233702},
	{"WWWLOTTERY", 10, 233703},
	{"METALINK", 8, 233704},
	{"WWWGEOCITIES", 12, 233705},
	{"PENDLEBURY", 10, 233706},
	{"CORBEN", 6, 233707},
	{"ROHNER", 6, 233708},
	{"ECIENCE", 7, 233709},
	{"RASHED", 6, 233710},
	{"DIMFELD", 7, 233711},
	{"DEFENSIN", 8, 233712},
	{"PIPERIDINES", 11, 233713},
	{"SMAR", 4, 233714},
	{"BRELAND", 7, 233715},
	{"UNANI", 5, 233716},
	{"LYCOSCOM", 8, 233717},
	{"CARPARKING", 10, 233718},
	{"BEDWORLD", 8, 233719},
	{"WWWROTTEN", 9, 233720},
	{"VYOM", 4, 233721},
	{"TROCAR", 6, 233722},
	{"ICTAP", 5, 233723},
	{"GELBART", 7, 233724},
	{"WWWKIDS", 7, 233725},
	{"WOORD", 5, 233726},
	{"PHOTOMICROGRAPHY", 16, 233727},
	{"NCLS", 4, 233728},
	{"CHALAYAN", 8, 233729},
	{"WWWALTAVISTACOM", 15, 233730},
	{"SUPERLIGA", 9, 233731},
	{"SAFFIRE", 7, 233732},
	{"REALMCOM", 8, 233733},
	{"OGIER", 5, 233734},
	{"NITZE", 5, 233735},
	{"WWWASKCOM", 9, 233736},
	{"SPEARGUNS", 9, 233737},
	{"SIDESCAN", 8, 233738},
	{"CLITICS", 7, 233739},
	{"XCIENCE", 7, 233740},
	{"WWWJENNIFER", 11, 233741},
	{"STROMLO", 7, 233742},
	{"STORIWS", 7, 233743},
	{"SANITARIA", 9, 233744},
	{"SAFRI", 5, 233745},
	{"FORESTLANDS", 11, 233746},
	{"VIEWCART", 8, 233747},
	{"KAZAACOM", 8, 233748},
	{"ESPOSIZIONE", 11, 233749},
	{"RIVATE", 6, 233750},
	{"RHYMESAYERS", 11, 233751},
	{"WWWBARBIE", 9, 233752},
	{"REFURBS", 7, 233753},
	{"IPSP", 4, 233754},
	{"ENGAGINGLY", 10, 233755},
	{"ALTAVIZSLA", 10, 233756},
	{"POIVRE", 6, 233757},
	{"PICCI", 5, 233758},
	{"MAILCRYPT", 9, 233759},
	{"GROEBNER", 8, 233760},
	{"BIOFREEZE", 9, 233761},
	{"AMYS", 4, 233762},
	{"IWONCOM", 7, 233763},
	{"GRRETING", 8, 233764},
	{"PINGUIN", 7, 233765},
	{"HUSHCOM", 7, 233766},
	{"GOOGELCOM", 9, 233767},
	{"SGPC", 4, 233768},
	{"GENTILITY", 9, 233769},
	{"WWWPBSORG", 9, 233770},
	{"WWWCNNCOM", 9, 233771},
	{"WWWAT", 5, 233772},
	{"SCIFICOM", 8, 233773},
	{"MERCHANTVILLE", 13, 233774},
	{"ELIPTICAL", 9, 233775},
	{"DELAHUNTY", 9, 233776},
	{"BAILEYVILLE", 11, 233777},
	{"WHISKAS", 7, 233778},
	{"WWWEXPEDIA", 10, 233779},
	{"WOWCOM", 6, 233780},
	{"METACRAWLERCOM", 14, 233781},
	{"WEAP", 4, 233782},
	{"REMAXCOM", 8, 233783},
	{"PALMINTERI", 10, 233784},
	{"NOTEPAPER", 9, 233785},
	{"WBCOM", 5, 233786},
	{"SPORTSSAY", 9, 233787},
	{"ONETPL", 6, 233788},
	{"BUILDE", 6, 233789},
	{"WWWMICROSOFT", 12, 233790},
	{"WWWBARNES", 9, 233791},
	{"NEARSIGHTED", 11, 233792},
	{"FALCHI", 6, 233793},
	{"DOISNEAU", 8, 233794},
	{"ASSIZES", 7, 233795},
	{"WWWFAFSAEDGOV", 13, 233796},
	{"UNBIBLICAL", 10, 233797},
	{"SPODOPTERA", 10, 233798},
	{"SPEARSCOM", 9, 233799},
	{"LAUDATORY", 9, 233800},
	{"DECLINERS", 9, 233801},
	{"WWWFOX", 6, 233802},
	{"UTION", 5, 233803},
	{"UFR", 3, 233804},
	{"MCAFEECOM", 9, 233805},
	{"DANGEREUSES", 11, 233806},
	{"CHEQUAMEGON", 11, 233807},
	{"ALTAVI", 6, 233808},
	{"POPFILE", 7, 233809},
	{"MEHLVILLE", 9, 233810},
	{"ASKJIVES", 8, 233811},
	{"ASKJEEEVES", 10, 233812},
	{"BARREIRO", 8, 233813},
	{"PALAZZOLO", 9, 233814},
	{"WWWMAPQUEST", 11, 233815},
	{"THIOPENTAL", 10, 233816},
	{"HOTMAILLCOM", 11, 233817},
	{"CHIPMAKERS", 10, 233818},
	{"BRUNETT", 7, 233819},
	{"ROMEOCOM", 8, 233820},
	{"WWWEBAYCA", 9, 233821},
	{"TRIPPLANNER", 11, 233822},
	{"SHIER", 5, 233823},
	{"KOBELCO", 7, 233824},
	{"FACIALED", 8, 233825},
	{"DEVELOPMENTWEB", 14, 233826},
	{"INFORMATIVO", 11, 233827},
	{"OVERTURECOM", 11, 233828},
	{"BRONROTT", 8, 233829},
	{"ASKJEE", 6, 233830},
	{"WWWDOGPILECOM", 13, 233831},
	{"WWWBRITNEY", 10, 233832},
	{"WEINGART", 8, 233833},
	{"MUDSLINGING", 11, 233834},
	{"LAMINITIS", 9, 233835},
	{"GLADNEY", 7, 233836},
	{"NGANG", 5, 233837},
	{"METACRAW", 8, 233838},
	{"WWWNETSCAPECOM", 14, 233839},
	{"DATAPRO", 7, 233840},
	{"YKAW", 4, 233841},
	{"YDSS", 4, 233842},
	{"YAUM", 4, 233843},
	{"XYLE", 4, 233844},
	{"WOPS", 4, 233845},
	{"VPOR", 4, 233846},
	{"UUKK", 4, 233847},
	{"UNNL", 4, 233848},
	{"UGMU", 4, 233849},
	{"TUAB", 4, 233850},
	{"TKNU", 4, 233851},
	{"TEXL", 4, 233852},
	{"STDP", 4, 233853},
	{"RRRA", 4, 233854},
	{"RKUA", 4, 233855},
	{"RIZP", 4, 233856},
	{"RFDI", 4, 233857},
	{"OVUN", 4, 233858},
	{"OBOJ", 4, 233859},
	{"NUBL", 4, 233860},
	{"NGKS", 4, 233861},
	{"MUPU", 4, 233862},
	{"MTVR", 4, 233863},
	{"MGIG", 4, 233864},
	{"MCNN", 4, 233865},
	{"MAEK", 4, 233866},
	{"LEUZ", 4, 233867},
	{"KUIT", 4, 233868},
	{"KMAB", 4, 233869},
	{"JAOR", 4, 233870},
	{"IKVE", 4, 233871},
	{"HJAD", 4, 233872},
	{"GSMR", 4, 233873},
	{"GPOM", 4, 233874},
	{"GMUI", 4, 233875},
	{"GHPM", 4, 233876},
	{"GBTO", 4, 233877},
	{"GAEW", 4, 233878},
	{"FYBA", 4, 233879},
	{"FLME", 4, 233880},
	{"FIPU", 4, 233881},
	{"EYOY", 4, 233882},
	{"EWXM", 4, 233883},
	{"EPMH", 4, 233884},
	{"EHRD", 4, 233885},
	{"EBRC", 4, 233886},
	{"DTBO", 4, 233887},
	{"DRIR", 4, 233888},
	{"DPMD", 4, 233889},
	{"DPIQ", 4, 233890},
	{"DMOK", 4, 233891},
	{"DJCA", 4, 233892},
	{"CRWA", 4, 233893},
	{"CODT", 4, 233894},
	{"BISJ", 4, 233895},
	{"BCAI", 4, 233896},
	{"WWWEBAYCOUK", 11, 233897},
	{"URSINE", 6, 233898},
	{"XDAII", 5, 233899},
	{"WWWMOBILEDE", 11, 233900},
	{"STREAMYX", 8, 233901},
	{"PHENOTYPING", 11, 233902},
	{"WWWSONY", 7, 233903},
	{"WWWKAZAA", 8, 233904},
	{"WWWGOOGLEDE", 11, 233905},
	{"RULECOM", 7, 233906},
	{"DEDICATO", 8, 233907},
	{"CILIATED", 8, 233908},
	{"BECAUS", 6, 233909},
	{"ALTAVESTA", 9, 233910},
	{"RIISE", 5, 233911},
	{"LOPEZCOM", 8, 233912},
	{"LANSLEY", 7, 233913},
	{"GOTMAIL", 7, 233914},
	{"FUNKED", 6, 233915},
	{"FFLINT", 6, 233916},
	{"CONSUMIDOR", 10, 233917},
	{"FILESTORE", 9, 233918},
	{"EMBRUN", 6, 233919},
	{"EASTNOR", 7, 233920},
	{"CHEMWEB", 7, 233921},
	{"TEOMACOM", 8, 233922},
	{"SANTRY", 6, 233923},
	{"MAPQUIST", 8, 233924},
	{"EXPERTO", 7, 233925},
	{"ASKJEEVEES", 10, 233926},
	{"WWWIMDBCOM", 10, 233927},
	{"WWWBINGO", 8, 233928},
	{"WWWATTNET", 9, 233929},
	{"FIMS", 4, 233930},
	{"CANTICLES", 9, 233931},
	{"POTTERCOM", 9, 233932},
	{"WWWSEZNAMCZ", 11, 233933},
	{"WWWRICHARDS", 11, 233934},
	{"WWWDRAGONBALL", 13, 233935},
	{"WWWDAUMNET", 10, 233936},
	{"WWWCAPITALONE", 13, 233937},
	{"WWWASKCOUK", 10, 233938},
	{"WWWAIRCANADACA", 14, 233939},
	{"ROIZEN", 6, 233940},
	{"PENDENS", 7, 233941},
	{"KRUNG", 5, 233942},
	{"EAECIENCY", 9, 233943},
	{"YELLSINGER", 10, 233944},
	{"WWWAUTOTRADERCOUK", 17, 233945},
	{"UPROARCOM", 9, 233946},
	{"JGOFS", 5, 233947},
	{"IAYOO", 5, 233948},
	{"FRESERVER", 9, 233949},
	{"FMAX", 4, 233950},
	{"DEVONS", 6, 233951},
	{"ASKJEEVESFORKIDS", 16, 233952},
	{"WWWSEARSCA", 10, 233953},
	{"WWWPOGO", 7, 233954},
	{"WWWEXCITE", 9, 233955},
	{"WWWBELLSOUTHNET", 15, 233956},
	{"WWWATTBICOM", 11, 233957},
	{"RIGHTISTS", 9, 233958},
	{"PORTUPGRADE", 11, 233959},
	{"ETRONICSCOM", 11, 233960},
	{"DESENZANO", 9, 233961},
	{"XIKAR", 5, 233962},
	{"WWWGOOGLECOUK", 13, 233963},
	{"WWNETSCAPE", 10, 233964},
	{"WASHINGTONPOSRCOM", 17, 233965},
	{"TOSHIHIKO", 9, 233966},
	{"HOLTVILLE", 9, 233967},
	{"FREESERVERCOM", 13, 233968},
	{"FREEESERVER", 11, 233969},
	{"EGUARDCOM", 9, 233970},
	{"WWWSTARTPAGINANL", 16, 233971},
	{"WWWKAZAACOM", 11, 233972},
	{"WWWFUTURE", 9, 233973},
	{"WWWABNAMRONL", 12, 233974},
	{"EZPEDIACOM", 10, 233975},
	{"WWWSSAGOV", 9, 233976},
	{"WWWAKSJEEVESCOM", 15, 233977},
	{"JANCE", 5, 233978},
	{"BRIGHTWATER", 11, 233979},
	{"AZHOO", 5, 233980},
	{"ATTTBI", 6, 233981},
	{"WWWPBSKIDSORG", 13, 233982},
	{"WWWJA", 5, 233983},
	{"WWWHARRY", 8, 233984},
	{"WWWATOGOVAU", 11, 233985},
	{"WWWASKJEEVESCOUK", 16, 233986},
	{"WWWASKJEEVESCC", 14, 233987},
	{"WWWARWROCPL", 11, 233988},
	{"WWWANWBNL", 9, 233989},
	{"WWWAIRMILESCA", 13, 233990},
	{"WWWAGUIUCEDU", 12, 233991},
	{"TEOMAA", 6, 233992},
	{"TAMBON", 6, 233993},
	{"KINGHAM", 7, 233994},
	{"INFOSPACECOM", 12, 233995},
	{"GOOGOSCH", 8, 233996},
	{"DZORG", 5, 233997},
	{"DSLREWARDS", 10, 233998},
	{"BONZICOM", 8, 233999},
	{"ASJJEEVESCOM", 12, 234000},
	{"WWWGOOGLEFR", 11, 234001},
	{"WWWGOOGLECA", 11, 234002},
	{"ACSR", 4, 234003},
	{"WWWREALCOM", 10, 234004},
	{"WWWDISCOVERY", 12, 234005},
	{"STOPLIGHTS", 10, 234006},
	{"MORPHEUSCOM", 11, 234007},
	{"ASLJEAVES", 9, 234008},
	{"ASKJEWESASKJEEV", 15, 234009},
	{"ASKJEEBS", 8, 234010},
	{"ALLSPORT", 8, 234011},
	{"XGEN", 4, 234012},
	{"WWWSTARWARSCOM", 14, 234013},
	{"WWWONETPL", 9, 234014},
	{"WWWEBAYDE", 9, 234015},
	{"MAPQUR", 6, 234016},
	{"BRIDGEABLE", 10, 234017},
	{"ADCRAFT", 7, 234018},
	{"WWWHSBCCOUK", 11, 234019},
	{"WWWGOCOM", 8, 234020},
	{"WWWCAIXAGOVBR", 13, 234021},
	{"LYSENKO", 7, 234022},
	{"WWWSMSAC", 8, 234023},
	{"WWWJOBCENTREPLUSGOVUK", 21, 234024},
	{"WWWJEN", 6, 234025},
	{"WWWIG", 5, 234026},
	{"WWWHUSH", 7, 234027},
	{"WWWGLOBOCOM", 11, 234028},
	{"WWWGLOBO", 8, 234029},
	{"WWWCCASFR", 9, 234030},
	{"DIHYDROCHLORIDE", 15, 234031},
	{"DATARESOURCES", 13, 234032},
	{"WWWRIGHTMOVECOUK", 16, 234033},
	{"WWWREMAX", 8, 234034},
	{"WWWLIL", 6, 234035},
	{"WWWLDSORG", 9, 234036},
	{"WWWIBANKBARCLAYSCOUK", 20, 234037},
	{"WWWFRIENDSREUNITEDCOUK", 22, 234038},
	{"RORI", 4, 234039},
	{"PLECOPTERA", 10, 234040},
	{"HARDLINER", 9, 234041},
	{"DEVIC", 5, 234042},
	{"BERCHET", 7, 234043},
	{"WWWSCIFI", 8, 234044},
	{"WWWMETACRAWLERCOM", 17, 234045},
	{"WWWINSUSDOJGOV", 14, 234046},
	{"WWWGOOGLENL", 11, 234047},
	{"WWWGOOGLEIT", 11, 234048},
	{"WWWFAMILYCA", 11, 234049},
	{"WWWDIGIMON", 10, 234050},
	{"SUGGESTIVELY", 12, 234051},
	{"WWWSYMPATICOCA", 14, 234052},
	{"WWWREDWAYORG", 12, 234053},
	{"WWWLABORSTATENYUS", 17, 234054},
	{"WWWIWONCOM", 10, 234055},
	{"WWWIWON", 7, 234056},
	{"WWWFUNDANL", 10, 234057},
	{"WWWFAFSAGOV", 11, 234058},
	{"WWWEARTHLINKNET", 15, 234059},
	{"TAIEX", 5, 234060},
	{"WWWSQUIRTORG", 12, 234061},
	{"WWWIUBEDU", 9, 234062},
	{"WWWINFOSPACECOM", 15, 234063},
	{"WWWILSENL", 9, 234064},
	{"WWWHOTMAILCOUK", 14, 234065},
	{"WWWGMXDE", 8, 234066},
	{"WWWFGTSCAIXAGOVBR", 17, 234067},
	{"WWWFAMILYSEARCHORG", 18, 234068},
	{"WWWESTUPROSREAISCATC", 20, 234069},
	{"WWWESTRUPOSREAISCATC", 20, 234070},
	{"WWWDMVCAGOV", 11, 234071},
	{"THENK", 5, 234072},
	{"SCREENSAVESR", 12, 234073},
	{"WWWSTATEPAUS", 12, 234074},
	{"WWWSCIFICOM", 11, 234075},
	{"WWWLYCOSCOUK", 12, 234076},
	{"WWWLITEROTICA", 13, 234077},
	{"WWWLIBEROIT", 11, 234078},
	{"WWWKRO", 6, 234079},
	{"WWWISKONHR", 10, 234080},
	{"WWWINGR", 7, 234081},
	{"WWWGOMNETEG", 11, 234082},
	{"WWWGOGPILE", 10, 234083},
	{"WWWRABOBANKNL", 13, 234084},
	{"WWWMSNCOUK", 10, 234085},
	{"WWWMARKTPLAATSNL", 16, 234086},
	{"WWWJUBIIDK", 10, 234087},
	{"WWWHOTMAILCO", 12, 234088},
	{"WWWHALIFAXCOUK", 14, 234089},
	{"WWWGOOGLES", 10, 234090},
	{"WWWEDDCAGOV", 11, 234091},
	{"RHODONITE", 9, 234092},
	{"RESERVIEREN", 11, 234093},
	{"ETORIES", 7, 234094},
	{"DIRECTIVO", 9, 234095},
	{"ZINCO", 5, 234096},
	{"WWWONELT", 8, 234097},
	{"WWWLYCOSDE", 10, 234098},
	{"WWWINTERIAPL", 12, 234099},
	{"WWWINSGOV", 9, 234100},
	{"WWWINGOV", 8, 234101},
	{"WWWIINFOSPACE", 13, 234102},
	{"WWWDMVGOV", 9, 234103},
	{"WWWDLISTATEPAUS", 15, 234104},
	{"WWWREMAXCOM", 11, 234105},
	{"WWWPROIBIDASFRST", 16, 234106},
	{"WWWMSNCA", 8, 234107},
	{"WWWMLSCA", 8, 234108},
	{"WWWLUNARSTORMSE", 15, 234109},
	{"WWWJOYCEMEYERORG", 16, 234110},
	{"WWWJOS", 6, 234111},
	{"WWWJOBBANKGCCA", 14, 234112},
	{"WWWIOLIT", 8, 234113},
	{"WWWINGDIRECTCA", 14, 234114},
	{"WWWHOTBOT", 9, 234115},
	{"WWWEASTENDERSCOUK", 17, 234116},
	{"WWWEAMCETAPNICIN", 16, 234117},
	{"PUNCO", 5, 234118},
	{"FENSEL", 6, 234119},
	{"WWWROTTENCO", 11, 234120},
	{"WWWRECEITAFEDERALGOVBR", 22, 234121},
	{"WWWRECEITAFAZENDAGOVBR", 22, 234122},
	{"WWWPORTALEDURO", 14, 234123},
	{"WWWORANGEFR", 11, 234124},
	{"WWWOFIRDK", 9, 234125},
	{"WWWMORPHEUS", 11, 234126},
	{"WWWMEBGOVTR", 11, 234127},
	{"WWWLYCOSNL", 10, 234128},
	{"CYTOKININ", 9, 234129},
	{"WWWONTARIOCA", 12, 234130},
	{"WWWONEC", 7, 234131},
	{"WWWOLGCLOTTERIESCA", 18, 234132},
	{"WWWOLGANET", 10, 234133},
	{"WWWOCEANFREENET", 15, 234134},
	{"WWWKOHLSCOM", 11, 234135},
	{"WWWKOHL", 7, 234136},
	{"WWWKACHINGOCONZ", 15, 234137},
	{"WWWKAARTENHUISNL", 16, 234138},
	{"WWWJUMPYIT", 10, 234139},
	{"WWWJOHNSTON", 11, 234140},
	{"WWWJOBSEARCHGOVAU", 17, 234141},
	{"WWWJAMBONLINEORG", 16, 234142},
	{"ZCIENCE", 7, 234143},
	{"WWWOSYMGOVTR", 12, 234144},
	{"WWWOSAPGOVONCA", 14, 234145},
	{"WWWOSAPCA", 9, 234146},
	{"WWWORANGECOUK", 13, 234147},
	{"WWWKQEDORG", 10, 234148},
	{"WWWKPNNL", 8, 234149},
	{"WHANT", 5, 234150},
	{"WALLLPAPER", 10, 234151},
	{"POLYORB", 7, 234152},
	{"ONGOSSAMER", 10, 234153},
	{"INFOSYNC", 8, 234154},
	{"IGRAFX", 6, 234155},
	{"YOSHIZAWA", 9, 234156},
	{"CHEAPIE", 7, 234157},
	{"SILVERMIST", 10, 234158},
	{"SERUE", 5, 234159},
	{"ICRS", 4, 234160},
	{"FICATIONS", 9, 234161},
	{"BUTTERBUR", 9, 234162},
	{"ALTAY", 5, 234163},
	{"UNIVERSTY", 9, 234164},
	{"LIEM", 4, 234165},
	{"CEDAREDGE", 9, 234166},
	{"TALEB", 5, 234167},
	{"QUADRUPED", 9, 234168},
	{"CLARI", 5, 234169},
	{"HEMOLYSIN", 9, 234170},
	{"ORDERBUCH", 9, 234171},
	{"JERED", 5, 234172},
	{"INNOV", 5, 234173},
	{"DENBLAN", 7, 234174},
	{"ARVOSTELUT", 10, 234175},
	{"PBLOCK", 6, 234176},
	{"GATSBYS", 7, 234177},
	{"GURATION", 8, 234178},
	{"DOWLER", 6, 234179},
	{"MAMO", 4, 234180},
	{"JODEE", 5, 234181},
	{"BITWEAVER", 9, 234182},
	{"VALORI", 6, 234183},
	{"PAURA", 5, 234184},
	{"LAURAS", 6, 234185},
	{"MACCAST", 7, 234186},
	{"FJR", 3, 234187},
	{"WOOSH", 5, 234188},
	{"HONOURABLY", 10, 234189},
	{"BUNKY", 5, 234190},
	{"BUNDORAN", 8, 234191},
	{"STAYNER", 7, 234192},
	{"LIZETTE", 7, 234193},
	{"INSBESONDERE", 12, 234194},
	{"DONCHA", 6, 234195},
	{"WTORIES", 7, 234196},
	{"SHIREEN", 7, 234197},
	{"BROONZY", 7, 234198},
	{"TAGUBA", 6, 234199},
	{"BEHERIT", 7, 234200},
	{"POLIFONICE", 10, 234201},
	{"PAVEY", 5, 234202},
	{"MAILAND", 7, 234203},
	{"NGAIO", 5, 234204},
	{"NFCC", 4, 234205},
	{"NOUGH", 5, 234206},
	{"MCGOWEN", 7, 234207},
	{"BALTES", 6, 234208},
	{"RAUCHEN", 7, 234209},
	{"GLAUCUS", 7, 234210},
	{"TECHCALENDAR", 12, 234211},
	{"FSNET", 5, 234212},
	{"GETLIVE", 7, 234213},
	{"WCIENCE", 7, 234214},
	{"TALLIN", 6, 234215},
	{"FRENCHS", 7, 234216},
	{"UNEXPLOITED", 11, 234217},
	{"PRID", 4, 234218},
	{"MAPQ", 4, 234219},
	{"BROADALBIN", 10, 234220},
	{"BENON", 5, 234221},
	{"GRASSMANN", 9, 234222},
	{"DOLLARDAYS", 10, 234223},
	{"CHIVALRIC", 9, 234224},
	{"HOTELLING", 9, 234225},
	{"EDIRNE", 6, 234226},
	{"SIMPLEBITS", 10, 234227},
	{"PUEDAN", 6, 234228},
	{"ALDENHAM", 8, 234229},
	{"NONCONTIGUOUS", 13, 234230},
	{"HELGI", 5, 234231},
	{"DISPLAYTAG", 10, 234232},
	{"DISKY", 5, 234233},
	{"KIRALIK", 7, 234234},
	{"CONTACTMUSIC", 12, 234235},
	{"PERCHA", 6, 234236},
	{"CHARLEEN", 8, 234237},
	{"SOTOMAYOR", 9, 234238},
	{"LOKAAL", 6, 234239},
	{"TRICHLORIDE", 11, 234240},
	{"ROESLER", 7, 234241},
	{"NIBELUNGEN", 10, 234242},
	{"NANANANAH", 9, 234243},
	{"HYPNOTISED", 10, 234244},
	{"CLOAKER", 7, 234245},
	{"APPLEJACK", 9, 234246},
	{"MCDAID", 6, 234247},
	{"PAWPRINTS", 9, 234248},
	{"LINGRIE", 7, 234249},
	{"COUSENS", 7, 234250},
	{"EARLIMART", 9, 234251},
	{"BOLAS", 5, 234252},
	{"TREETING", 8, 234253},
	{"SONDRIO", 7, 234254},
	{"RIVERIA", 7, 234255},
	{"LAVISTA", 7, 234256},
	{"EQUILIB", 7, 234257},
	{"BILASPUR", 8, 234258},
	{"ATHEROGENIC", 11, 234259},
	{"ARCHITECTUAL", 12, 234260},
	{"STULTS", 6, 234261},
	{"SCIEMCE", 7, 234262},
	{"KITY", 4, 234263},
	{"LURCHER", 7, 234264},
	{"LABRADOODLES", 12, 234265},
	{"HEYYY", 5, 234266},
	{"DORKI", 5, 234267},
	{"DIRMNGR", 7, 234268},
	{"TIPPMAN", 7, 234269},
	{"PLUGED", 6, 234270},
	{"COJA", 4, 234271},
	{"UNCHECKING", 10, 234272},
	{"EMERGIC", 7, 234273},
	{"CAMPAG", 6, 234274},
	{"DEKSTOP", 7, 234275},
	{"STRTOUL", 7, 234276},
	{"HISTIOCYTIC", 11, 234277},
	{"MORHPEUS", 8, 234278},
	{"HAUSHALT", 8, 234279},
	{"DIPHTHONGS", 10, 234280},
	{"APPUYEZ", 7, 234281},
	{"USATA", 5, 234282},
	{"OPENFILE", 8, 234283},
	{"MORANBAH", 8, 234284},
	{"HELSERIF", 8, 234285},
	{"ANTONUCCI", 9, 234286},
	{"ZSCE", 4, 234287},
	{"ZAPE", 4, 234288},
	{"YYAK", 4, 234289},
	{"YOYA", 4, 234290},
	{"YNFI", 4, 234291},
	{"YMOP", 4, 234292},
	{"XUSB", 4, 234293},
	{"WDLI", 4, 234294},
	{"VYAP", 4, 234295},
	{"TVFA", 4, 234296},
	{"TSDV", 4, 234297},
	{"TJFK", 4, 234298},
	{"TAKB", 4, 234299},
	{"SPPP", 4, 234300},
	{"RYJB", 4, 234301},
	{"RCAJ", 4, 234302},
	{"PKRI", 4, 234303},
	{"PETV", 4, 234304},
	{"PDIK", 4, 234305},
	{"PCAA", 4, 234306},
	{"OTMD", 4, 234307},
	{"ONXF", 4, 234308},
	{"OBYZ", 4, 234309},
	{"NVAP", 4, 234310},
	{"MPIZ", 4, 234311},
	{"MNEP", 4, 234312},
	{"MIKR", 4, 234313},
	{"MGWA", 4, 234314},
	{"MDEU", 4, 234315},
	{"LPSJ", 4, 234316},
	{"LHIF", 4, 234317},
	{"LEWL", 4, 234318},
	{"LAXF", 4, 234319},
	{"ICUB", 4, 234320},
	{"ICAX", 4, 234321},
	{"HODK", 4, 234322},
	{"GUII", 4, 234323},
	{"GUAJ", 4, 234324},
	{"GMOW", 4, 234325},
	{"GIMT", 4, 234326},
	{"GBOP", 4, 234327},
	{"FPIM", 4, 234328},
	{"EXSF", 4, 234329},
	{"EXKO", 4, 234330},
	{"EXEY", 4, 234331},
	{"ERFH", 4, 234332},
	{"EKQU", 4, 234333},
	{"EEXG", 4, 234334},
	{"DYIR", 4, 234335},
	{"DJSP", 4, 234336},
	{"CUWI", 4, 234337},
	{"CUTK", 4, 234338},
	{"CGEH", 4, 234339},
	{"CCAE", 4, 234340},
	{"CAGG", 4, 234341},
	{"BVIE", 4, 234342},
	{"BOLM", 4, 234343},
	{"BNPO", 4, 234344},
	{"ATKP", 4, 234345},
	{"AFUD", 4, 234346},
	{"DEREF", 5, 234347},
	{"COEXISTED", 9, 234348},
	{"WARDROP", 7, 234349},
	{"HIRSI", 5, 234350},
	{"DJR", 3, 234351},
	{"WOMANKIND", 9, 234352},
	{"VELVA", 5, 234353},
	{"TZEDEK", 6, 234354},
	{"KPD", 3, 234355},
	{"XANDRIA", 7, 234356},
	{"SARNATH", 7, 234357},
	{"GROUNDSPEAK", 11, 234358},
	{"CONFORMER", 9, 234359},
	{"ANHINGA", 7, 234360},
	{"KAPPLER", 7, 234361},
	{"GENERICITY", 10, 234362},
	{"SYORIES", 7, 234363},
	{"SHAWTY", 6, 234364},
	{"PROXIBID", 8, 234365},
	{"WAHANOL", 7, 234366},
	{"SUBSECS", 7, 234367},
	{"GRIGSON", 7, 234368},
	{"DESAY", 5, 234369},
	{"TRIVVIES", 8, 234370},
	{"NITER", 5, 234371},
	{"DANDAR", 6, 234372},
	{"BERLAND", 7, 234373},
	{"BACKUPPC", 8, 234374},
	{"HELLP", 5, 234375},
	{"TICKETTRIANGLE", 14, 234376},
	{"NANTON", 6, 234377},
	{"GOBOX", 5, 234378},
	{"EVISION", 7, 234379},
	{"RECREATIONALLY", 14, 234380},
	{"PAGWS", 5, 234381},
	{"BOSQUET", 7, 234382},
	{"COGNIS", 6, 234383},
	{"CHERIAN", 7, 234384},
	{"STRENG", 6, 234385},
	{"RIPUNCH", 7, 234386},
	{"MONIKERS", 8, 234387},
	{"INSERITO", 8, 234388},
	{"DININGGROCERY", 13, 234389},
	{"CILPART", 7, 234390},
	{"PICTUGES", 8, 234391},
	{"PAGEC", 5, 234392},
	{"CRUCIFEROUS", 11, 234393},
	{"CROSSTRAINER", 12, 234394},
	{"YYLEX", 5, 234395},
	{"PYXIS", 5, 234396},
	{"HALYARDS", 8, 234397},
	{"SKALPEL", 7, 234398},
	{"SELB", 4, 234399},
	{"PROKEIMENOY", 11, 234400},
	{"FEESTEN", 7, 234401},
	{"ANAHIM", 6, 234402},
	{"MARSHALLESE", 11, 234403},
	{"ASPECTRATIO", 11, 234404},
	{"KREAM", 5, 234405},
	{"GOMBE", 5, 234406},
	{"UNISOURCE", 9, 234407},
	{"MOPHEUS", 7, 234408},
	{"DESCRIPCION", 11, 234409},
	{"PSGES", 5, 234410},
	{"EUROVOC", 7, 234411},
	{"CORMICK", 7, 234412},
	{"REINFORCERS", 11, 234413},
	{"MERREDIN", 8, 234414},
	{"ENTIFIC", 7, 234415},
	{"CAPPELLETTI", 11, 234416},
	{"MISSON", 6, 234417},
	{"SCIRNCE", 7, 234418},
	{"MASANOBU", 8, 234419},
	{"FULVIA", 6, 234420},
	{"DELIMA", 6, 234421},
	{"CODEPENDENT", 11, 234422},
	{"CEFS", 4, 234423},
	{"CAPEHART", 8, 234424},
	{"ROWSON", 6, 234425},
	{"PROPULSID", 9, 234426},
	{"STATHIS", 7, 234427},
	{"BLUG", 4, 234428},
	{"PROVISOS", 8, 234429},
	{"BRUCES", 6, 234430},
	{"BARRANCO", 8, 234431},
	{"THOMSONFLY", 10, 234432},
	{"CHEAPACCOMMODATION", 18, 234433},
	{"LABELLA", 7, 234434},
	{"SANCTORUM", 9, 234435},
	{"WHIDDEN", 7, 234436},
	{"FLOWERBEDS", 10, 234437},
	{"FIIG", 4, 234438},
	{"ELECTROCHROMIC", 14, 234439},
	{"GALANOS", 7, 234440},
	{"SELM", 4, 234441},
	{"KVP", 3, 234442},
	{"TAURASI", 7, 234443},
	{"PENKNIFE", 8, 234444},
	{"PROVEEDOR", 9, 234445},
	{"PEACOAT", 7, 234446},
	{"MONCLOVA", 8, 234447},
	{"HAZARA", 6, 234448},
	{"HAMBLEDON", 9, 234449},
	{"DBSM", 4, 234450},
	{"POOLERS", 7, 234451},
	{"HIGHBACK", 8, 234452},
	{"ESCAN", 5, 234453},
	{"PHOTOBIOL", 9, 234454},
	{"LEZARD", 6, 234455},
	{"BURKESVILLE", 11, 234456},
	{"MYOMETRIUM", 10, 234457},
	{"DIPLOMATES", 10, 234458},
	{"VAPNIK", 6, 234459},
	{"MICRORNAS", 9, 234460},
	{"CLASSIFI", 8, 234461},
	{"CARCINOGENITY", 13, 234462},
	{"ASSTRAFFICCOM", 13, 234463},
	{"COPYIST", 7, 234464},
	{"BIOCATALYSIS", 12, 234465},
	{"ZTORIES", 7, 234466},
	{"LOGLINE", 7, 234467},
	{"HSMP", 4, 234468},
	{"ENIGE", 5, 234469},
	{"JAMIAT", 6, 234470},
	{"DEGS", 4, 234471},
	{"COISAS", 6, 234472},
	{"SCOBIE", 6, 234473},
	{"OFSP", 4, 234474},
	{"NOVAYA", 6, 234475},
	{"HELLIWELL", 9, 234476},
	{"KAMIOKANDE", 10, 234477},
	{"LAUTOKA", 7, 234478},
	{"HUISGENOOT", 10, 234479},
	{"NETBOTZ", 7, 234480},
	{"INEWS", 5, 234481},
	{"XINING", 6, 234482},
	{"MELANIA", 7, 234483},
	{"HIDTA", 5, 234484},
	{"BREETING", 8, 234485},
	{"EADEM", 5, 234486},
	{"ANDALUCIAN", 10, 234487},
	{"TIMELEFT", 8, 234488},
	{"FRAYN", 5, 234489},
	{"WSSC", 4, 234490},
	{"MONMORE", 7, 234491},
	{"DIVISIONE", 9, 234492},
	{"TUNESIA", 7, 234493},
	{"LUNNEY", 6, 234494},
	{"PERYLENE", 8, 234495},
	{"PEROU", 5, 234496},
	{"LUNGHEZZA", 9, 234497},
	{"IEPER", 5, 234498},
	{"HEJDUK", 6, 234499},
	{"EMOND", 5, 234500},
	{"WATCHET", 7, 234501},
	{"PORTNAME", 8, 234502},
	{"PETRUCHIO", 9, 234503},
	{"ANALNY", 6, 234504},
	{"GRETEING", 8, 234505},
	{"BRADBURN", 8, 234506},
	{"AMARDEEP", 8, 234507},
	{"BSPS", 4, 234508},
	{"BOLLY", 5, 234509},
	{"INDENTIFIED", 11, 234510},
	{"PINSCHERS", 9, 234511},
	{"NEALY", 5, 234512},
	{"NILLUMBIK", 9, 234513},
	{"INTIATIVE", 9, 234514},
	{"DECISIONMAKER", 13, 234515},
	{"KAABA", 5, 234516},
	{"POTRAI", 6, 234517},
	{"FLUSHMOUNT", 10, 234518},
	{"BURBY", 5, 234519},
	{"PRYD", 4, 234520},
	{"NVIRONMENT", 10, 234521},
	{"LUEDERS", 7, 234522},
	{"SBLIVE", 6, 234523},
	{"MASEKELA", 8, 234524},
	{"JOYAL", 5, 234525},
	{"HOTELY", 6, 234526},
	{"CALED", 5, 234527},
	{"ROFUG", 5, 234528},
	{"GRUNDTVIG", 9, 234529},
	{"EXCITECOM", 9, 234530},
	{"CECAL", 5, 234531},
	{"BELLARE", 7, 234532},
	{"ASTRONOMICO", 11, 234533},
	{"SLIMES", 6, 234534},
	{"SHETLANDS", 9, 234535},
	{"ROUNDTRIPS", 10, 234536},
	{"DWNLOADS", 8, 234537},
	{"PEARED", 6, 234538},
	{"AUTOMORPHIC", 11, 234539},
	{"SWANSTONE", 9, 234540},
	{"BHUPATHI", 8, 234541},
	{"OHLIN", 5, 234542},
	{"SCREN", 5, 234543},
	{"MICHALEK", 8, 234544},
	{"ENTWICKELT", 10, 234545},
	{"LITORAL", 7, 234546},
	{"OFAST", 5, 234547},
	{"HURFORD", 7, 234548},
	{"AVIONIC", 7, 234549},
	{"WATERBLOCK", 10, 234550},
	{"SOLEMNIZED", 10, 234551},
	{"XPR", 3, 234552},
	{"SYLUM", 5, 234553},
	{"PALPITATION", 11, 234554},
	{"DIXIELANDJAZZ", 13, 234555},
	{"STOREE", 6, 234556},
	{"HAUGHTILY", 9, 234557},
	{"VBM", 3, 234558},
	{"VALENTINIAN", 11, 234559},
	{"DIFFUSELY", 9, 234560},
	{"BALKANIZATION", 13, 234561},
	{"YZAP", 4, 234562},
	{"YYAV", 4, 234563},
	{"YSAJ", 4, 234564},
	{"YOIC", 4, 234565},
	{"XUSC", 4, 234566},
	{"XIAR", 4, 234567},
	{"WULT", 4, 234568},
	{"WIDL", 4, 234569},
	{"VTOU", 4, 234570},
	{"VRID", 4, 234571},
	{"VIGG", 4, 234572},
	{"VFLA", 4, 234573},
	{"VEKS", 4, 234574},
	{"UPMR", 4, 234575},
	{"UNNG", 4, 234576},
	{"UCTK", 4, 234577},
	{"TYCD", 4, 234578},
	{"SZEB", 4, 234579},
	{"SSRB", 4, 234580},
	{"SOML", 4, 234581},
	{"RUYE", 4, 234582},
	{"RAXW", 4, 234583},
	{"PYEO", 4, 234584},
	{"PUAA", 4, 234585},
	{"PRFI", 4, 234586},
	{"ORRF", 4, 234587},
	{"OFXB", 4, 234588},
	{"OFMV", 4, 234589},
	{"OFFZ", 4, 234590},
	{"NNUK", 4, 234591},
	{"MZIN", 4, 234592},
	{"LYML", 4, 234593},
	{"LOLU", 4, 234594},
	{"KPEY", 4, 234595},
	{"KHLI", 4, 234596},
	{"KEKL", 4, 234597},
	{"IWAV", 4, 234598},
	{"INRP", 4, 234599},
	{"ILKG", 4, 234600},
	{"HULY", 4, 234601},
	{"HKMI", 4, 234602},
	{"GCHL", 4, 234603},
	{"FOXU", 4, 234604},
	{"FLOK", 4, 234605},
	{"FBAE", 4, 234606},
	{"EZDU", 4, 234607},
	{"EERZ", 4, 234608},
	{"DUAC", 4, 234609},
	{"DTDA", 4, 234610},
	{"CWWO", 4, 234611},
	{"CUZC", 4, 234612},
	{"CTYA", 4, 234613},
	{"COYB", 4, 234614},
	{"CKDY", 4, 234615},
	{"BOLP", 4, 234616},
	{"BODN", 4, 234617},
	{"BIMM", 4, 234618},
	{"AUAP", 4, 234619},
	{"ANXC", 4, 234620},
	{"AKYH", 4, 234621},
	{"ACBI", 4, 234622},
	{"UROTHELIAL", 10, 234623},
	{"RELOADABLE", 10, 234624},
	{"HOCKETT", 7, 234625},
	{"OWASP", 5, 234626},
	{"KINDREDS", 8, 234627},
	{"IVANS", 5, 234628},
	{"CTORIES", 7, 234629},
	{"BURKART", 7, 234630},
	{"HACIENDAS", 9, 234631},
	{"BONLEBON", 8, 234632},
	{"PROPHAGE", 8, 234633},
	{"PLAYMIDI", 8, 234634},
	{"GROUTS", 6, 234635},
	{"COUNTERFEITED", 13, 234636},
	{"CHILENO", 7, 234637},
	{"MIDDLEBOROUGH", 13, 234638},
	{"GRDETING", 8, 234639},
	{"EDETIC", 6, 234640},
	{"CONDITIONALITIES", 16, 234641},
	{"SIRKUS", 6, 234642},
	{"PHUOC", 5, 234643},
	{"XAPOOL", 6, 234644},
	{"SWEETMEATS", 10, 234645},
	{"TAENIA", 6, 234646},
	{"ORCHIECTOMY", 11, 234647},
	{"CHRYSOPRASE", 11, 234648},
	{"SCREENSAVRES", 12, 234649},
	{"KOGANEI", 7, 234650},
	{"KAPPEL", 6, 234651},
	{"WOLFER", 6, 234652},
	{"TOUSLED", 7, 234653},
	{"TARU", 4, 234654},
	{"SUNON", 5, 234655},
	{"PILLSPHENTERMINE", 16, 234656},
	{"UNFASTENED", 10, 234657},
	{"SALAHUDDIN", 10, 234658},
	{"DORIN", 5, 234659},
	{"WHOLEVIEW", 9, 234660},
	{"MEZZA", 5, 234661},
	{"HARRISS", 7, 234662},
	{"DIANO", 5, 234663},
	{"VENIRE", 6, 234664},
	{"QUIBBLING", 9, 234665},
	{"HUACLLA", 7, 234666},
	{"TOBBY", 5, 234667},
	{"SOLARES", 7, 234668},
	{"SERENADED", 9, 234669},
	{"WHUP", 4, 234670},
	{"TOPMARGIN", 9, 234671},
	{"FAUSETT", 7, 234672},
	{"UIGHURS", 7, 234673},
	{"UGASHIK", 7, 234674},
	{"TERVIS", 6, 234675},
	{"RGEETING", 8, 234676},
	{"NEWAY", 5, 234677},
	{"METC", 4, 234678},
	{"KALININ", 7, 234679},
	{"COURSER", 7, 234680},
	{"TALAS", 5, 234681},
	{"TOUHY", 5, 234682},
	{"SEIROTS", 7, 234683},
	{"NETREGS", 7, 234684},
	{"FLAUNTED", 8, 234685},
	{"EBOARD", 6, 234686},
	{"SPEEDWEEKS", 10, 234687},
	{"PERFORATE", 9, 234688},
	{"EASTIN", 6, 234689},
	{"PIARAS", 6, 234690},
	{"NPOESS", 6, 234691},
	{"IMBUES", 6, 234692},
	{"GUIBERT", 7, 234693},
	{"DVIX", 4, 234694},
	{"COMPADRES", 9, 234695},
	{"GTEETING", 8, 234696},
	{"MARIGNY", 7, 234697},
	{"SFIENCE", 7, 234698},
	{"BUNDESRAT", 9, 234699},
	{"BOUFFANT", 8, 234700},
	{"KLANSMAN", 8, 234701},
	{"FUKUNAGA", 8, 234702},
	{"DALLASTOWN", 10, 234703},
	{"COCKTEASE", 9, 234704},
	{"PROLEGOMENA", 11, 234705},
	{"CREMES", 6, 234706},
	{"AMEBIASIS", 9, 234707},
	{"GREETNIG", 8, 234708},
	{"GREEFING", 8, 234709},
	{"GAKKEN", 6, 234710},
	{"PEARLSTEIN", 10, 234711},
	{"PASUK", 5, 234712},
	{"HALBERD", 7, 234713},
	{"MITIGATIONS", 11, 234714},
	{"GREETKNG", 8, 234715},
	{"FRUCTUS", 7, 234716},
	{"DOONA", 5, 234717},
	{"PAHES", 5, 234718},
	{"NCAM", 4, 234719},
	{"GEEETING", 8, 234720},
	{"DOWNOADS", 8, 234721},
	{"BESTPUBS", 8, 234722},
	{"GOLDENE", 7, 234723},
	{"ODKAZ", 5, 234724},
	{"GANJ", 4, 234725},
	{"EFORM", 5, 234726},
	{"BRUCHAC", 7, 234727},
	{"LANMAN", 6, 234728},
	{"WSDA", 4, 234729},
	{"GAVASKAR", 8, 234730},
	{"DUBA", 4, 234731},
	{"BANARAS", 7, 234732},
	{"UNWINNABLE", 10, 234733},
	{"PUBLIKATIONER", 13, 234734},
	{"NTERPRISE", 9, 234735},
	{"GUTERMAN", 8, 234736},
	{"VREETING", 8, 234737},
	{"USRP", 4, 234738},
	{"REFPTR", 6, 234739},
	{"GREETIGN", 8, 234740},
	{"GREEITNG", 8, 234741},
	{"SMEC", 4, 234742},
	{"GETPWNAM", 8, 234743},
	{"VARENNES", 8, 234744},
	{"MICROHABITAT", 12, 234745},
	{"CRUISECRUISE", 12, 234746},
	{"CARATULA", 8, 234747},
	{"BLACKWORM", 9, 234748},
	{"APROXIMADAMENTE", 15, 234749},
	{"VERBINSKI", 9, 234750},
	{"HILGARD", 7, 234751},
	{"WEBPROTECT", 10, 234752},
	{"HECKING", 7, 234753},
	{"GOABASE", 7, 234754},
	{"BAGGOT", 6, 234755},
	{"PGAES", 5, 234756},
	{"JOBEATS", 7, 234757},
	{"SHEPLEY", 7, 234758},
	{"ENTOMBMENT", 10, 234759},
	{"PROCERIN", 8, 234760},
	{"MUHAJABAH", 9, 234761},
	{"FRESHFIELDS", 11, 234762},
	{"PORTSENTRY", 10, 234763},
	{"HERSCHELL", 9, 234764},
	{"SIPTU", 5, 234765},
	{"MYOBJECTWEB", 11, 234766},
	{"MUSICMUSIC", 10, 234767},
	{"METAGENICS", 10, 234768},
	{"CANOPIED", 8, 234769},
	{"LAFOREST", 8, 234770},
	{"FILOSOPHER", 10, 234771},
	{"CRIMESTOPPER", 12, 234772},
	{"MEHG", 4, 234773},
	{"BONZ", 4, 234774},
	{"MARIANSKE", 9, 234775},
	{"STEAMPUNK", 9, 234776},
	{"SGORIES", 7, 234777},
	{"PLATJA", 6, 234778},
	{"MOSIN", 5, 234779},
	{"SEEYA", 5, 234780},
	{"SCREENSAVRS", 11, 234781},
	{"HARBRIDGE", 9, 234782},
	{"ASTRIUM", 7, 234783},
	{"STORISS", 7, 234784},
	{"KIRCHOFF", 8, 234785},
	{"DETHRONE", 8, 234786},
	{"CARDEAN", 7, 234787},
	{"TOLIET", 6, 234788},
	{"SCREENSACERS", 12, 234789},
	{"FULVIC", 6, 234790},
	{"DISCOGRAPH", 10, 234791},
	{"DLTTAPE", 7, 234792},
	{"METHYLENETETRAHYDROFOLATE", 25, 234793},
	{"AHADITH", 7, 234794},
	{"CORNFLAKE", 9, 234795},
	{"CONNELLS", 8, 234796},
	{"BARFOOT", 7, 234797},
	{"RAULKEN", 7, 234798},
	{"CHOIRE", 6, 234799},
	{"WYNCOTE", 7, 234800},
	{"VSERVERS", 8, 234801},
	{"ASTROPHYSICISTS", 15, 234802},
	{"KADDRESSBOOK", 12, 234803},
	{"EDFA", 4, 234804},
	{"VOUCHSAFE", 9, 234805},
	{"GERETING", 8, 234806},
	{"CALITZDORP", 10, 234807},
	{"BIOMAX", 6, 234808},
	{"BABYWEARING", 11, 234809},
	{"KWGN", 4, 234810},
	{"DDHHMM", 6, 234811},
	{"SOMERHALDER", 11, 234812},
	{"MAGALLANES", 10, 234813},
	{"EJECTORS", 8, 234814},
	{"DENIABILITY", 11, 234815},
	{"WOOLSHED", 8, 234816},
	{"MACROGLOBULIN", 13, 234817},
	{"GRWETING", 8, 234818},
	{"PROBLEMY", 8, 234819},
	{"MINDLAB", 7, 234820},
	{"GILLENWATER", 11, 234821},
	{"VIDEOWAVE", 9, 234822},
	{"PALMARES", 8, 234823},
	{"NORMB", 5, 234824},
	{"MISFIRES", 8, 234825},
	{"GHOSHAL", 7, 234826},
	{"RWORK", 5, 234827},
	{"MCBROOM", 7, 234828},
	{"MASQMAIL", 8, 234829},
	{"STORIDS", 7, 234830},
	{"STEPHIE", 7, 234831},
	{"GFEETING", 8, 234832},
	{"HEREABOUTS", 10, 234833},
	{"GREETIHG", 8, 234834},
	{"BLACKGUARD", 10, 234835},
	{"TECLADO", 7, 234836},
	{"ECNEICS", 7, 234837},
	{"COMPARTIR", 9, 234838},
	{"UNITARIANISM", 12, 234839},
	{"PICTURFS", 8, 234840},
	{"HORSEHEAD", 9, 234841},
	{"GREETONG", 8, 234842},
	{"DWQ", 3, 234843},
	{"MEHLDAU", 7, 234844},
	{"IMAGIN", 6, 234845},
	{"WARPLANE", 8, 234846},
	{"PAEGS", 5, 234847},
	{"GREEYING", 8, 234848},
	{"GREEGING", 8, 234849},
	{"GRASONVILLE", 11, 234850},
	{"DEJO", 4, 234851},
	{"BLAW", 4, 234852},
	{"MONOCACY", 8, 234853},
	{"MOLIN", 5, 234854},
	{"FLEXABLE", 8, 234855},
	{"CONSEGNA", 8, 234856},
	{"XRECORD", 7, 234857},
	{"LOLLITAS", 8, 234858},
	{"HALCION", 7, 234859},
	{"RUDL", 4, 234860},
	{"GRSETING", 8, 234861},
	{"GREETIBG", 8, 234862},
	{"GEGENWART", 9, 234863},
	{"BARNHAM", 7, 234864},
	{"WINFO", 5, 234865},
	{"SCOENCE", 7, 234866},
	{"KUSTURICA", 9, 234867},
	{"PTRS", 4, 234868},
	{"GREETUNG", 8, 234869},
	{"GREETIJG", 8, 234870},
	{"ESTETICA", 8, 234871},
	{"MOTHERLODE", 10, 234872},
	{"CONCATENATES", 12, 234873},
	{"ZYFR", 4, 234874},
	{"ZYAR", 4, 234875},
	{"ZWAT", 4, 234876},
	{"ZSOM", 4, 234877},
	{"ZOFM", 4, 234878},
	{"ZCHO", 4, 234879},
	{"YSZT", 4, 234880},
	{"YFOA", 4, 234881},
	{"YEWU", 4, 234882},
	{"XZOO", 4, 234883},
	{"XCIR", 4, 234884},
	{"WKED", 4, 234885},
	{"WBRY", 4, 234886},
	{"WBAW", 4, 234887},
	{"WBAA", 4, 234888},
	{"VIMP", 4, 234889},
	{"VIJO", 4, 234890},
	{"VFAN", 4, 234891},
	{"VDVI", 4, 234892},
	{"UXSU", 4, 234893},
	{"UXEL", 4, 234894},
	{"UTUG", 4, 234895},
	{"UMEQ", 4, 234896},
	{"TVMU", 4, 234897},
	{"TUKW", 4, 234898},
	{"TLSQ", 4, 234899},
	{"SEML", 4, 234900},
	{"SCVI", 4, 234901},
	{"SAVG", 4, 234902},
	{"SAFD", 4, 234903},
	{"RWOK", 4, 234904},
	{"RTVR", 4, 234905},
	{"RRYQ", 4, 234906},
	{"RNCC", 4, 234907},
	{"RFMI", 4, 234908},
	{"RECF", 4, 234909},
	{"RDDY", 4, 234910},
	{"RCUC", 4, 234911},
	{"POBU", 4, 234912},
	{"OLML", 4, 234913},
	{"NMWI", 4, 234914},
	{"NKSQ", 4, 234915},
	{"NIGW", 4, 234916},
	{"MNAF", 4, 234917},
	{"MILV", 4, 234918},
	{"LXIN", 4, 234919},
	{"LPMC", 4, 234920},
	{"LMCU", 4, 234921},
	{"LLCM", 4, 234922},
	{"LIIC", 4, 234923},
	{"LEVC", 4, 234924},
	{"LEKC", 4, 234925},
	{"LBBO", 4, 234926},
	{"IZIL", 4, 234927},
	{"INXF", 4, 234928},
	{"HUNJ", 4, 234929},
	{"GEKU", 4, 234930},
	{"FCYL", 4, 234931},
	{"EMLL", 4, 234932},
	{"ELZU", 4, 234933},
	{"EHPK", 4, 234934},
	{"EDWP", 4, 234935},
	{"DDPI", 4, 234936},
	{"CHKM", 4, 234937},
	{"BYEH", 4, 234938},
	{"BDAI", 4, 234939},
	{"AZLU", 4, 234940},
	{"ALRP", 4, 234941},
	{"GARRULOUS", 9, 234942},
	{"THEPETE", 7, 234943},
	{"INDEN", 5, 234944},
	{"HANCEVILLE", 10, 234945},
	{"DUETTE", 6, 234946},
	{"ENTHRALL", 8, 234947},
	{"CUCKFIELD", 9, 234948},
	{"XCALIA", 6, 234949},
	{"SINISA", 6, 234950},
	{"QESSALONIKHS", 12, 234951},
	{"PROPOSTA", 8, 234952},
	{"SHAMI", 5, 234953},
	{"PINCHBECK", 9, 234954},
	{"EXTOLS", 6, 234955},
	{"WOODCUTTER", 10, 234956},
	{"PREISWERTE", 10, 234957},
	{"SCALO", 5, 234958},
	{"FEBRU", 5, 234959},
	{"WARLAND", 7, 234960},
	{"VANCO", 5, 234961},
	{"SKILLSUSA", 9, 234962},
	{"PINKWATER", 9, 234963},
	{"ONCOPROTEINS", 12, 234964},
	{"BEARTOWN", 8, 234965},
	{"ROUNDHEAD", 9, 234966},
	{"MERITOR", 7, 234967},
	{"WOLA", 4, 234968},
	{"WHITEBLAZE", 10, 234969},
	{"SCIEBCE", 7, 234970},
	{"ITGIRLI", 7, 234971},
	{"HILARIE", 7, 234972},
	{"FINNER", 6, 234973},
	{"ROSTI", 5, 234974},
	{"MCCAUL", 6, 234975},
	{"EATINGFREE", 10, 234976},
	{"ALGAN", 5, 234977},
	{"PYRRHIC", 7, 234978},
	{"MAMDOUH", 7, 234979},
	{"FLUXLIST", 8, 234980},
	{"CONSISTENCIES", 13, 234981},
	{"CHAMBA", 6, 234982},
	{"LGK", 3, 234983},
	{"GREETJNG", 8, 234984},
	{"CLIPAT", 6, 234985},
	{"AYASHI", 6, 234986},
	{"BADRI", 5, 234987},
	{"HUNGRIER", 8, 234988},
	{"WINMPG", 6, 234989},
	{"OUTWEAR", 7, 234990},
	{"ERECTS", 6, 234991},
	{"PRITHVI", 7, 234992},
	{"HOWEV", 5, 234993},
	{"FLLW", 4, 234994},
	{"FLEXIBLES", 9, 234995},
	{"PERTTI", 6, 234996},
	{"MODNAME", 7, 234997},
	{"EFTERSOM", 8, 234998},
	{"TELEVANTAGE", 11, 234999},
	{"ELIX", 4, 235000},
	{"ACTINOBACILLUS", 14, 235001},
	{"REINDEX", 7, 235002},
	{"OLLIVIER", 8, 235003},
	{"KYNET", 5, 235004},
	{"INSTARS", 7, 235005},
	{"ENVIA", 5, 235006},
	{"EGYPTION", 8, 235007},
	{"COWDERY", 7, 235008},
	{"LATASHA", 7, 235009},
	{"BRACHIOPODS", 11, 235010},
	{"ASPID", 5, 235011},
	{"SCIDNCE", 7, 235012},
	{"DIVANI", 6, 235013},
	{"CARDMGR", 7, 235014},
	{"MARDIS", 6, 235015},
	{"KODAIRA", 7, 235016},
	{"ASPIRATES", 9, 235017},
	{"MURRE", 5, 235018},
	{"MOTORMOUTH", 10, 235019},
	{"KGHM", 4, 235020},
	{"HORRIFICALLY", 12, 235021},
	{"ROTIFERS", 8, 235022},
	{"PLANITIA", 8, 235023},
	{"KOVACEVIC", 9, 235024},
	{"ISILOXC", 7, 235025},
	{"CAVERNA", 7, 235026},
	{"AMONTILLADO", 11, 235027},
	{"CLIPRT", 6, 235028},
	{"CLIART", 6, 235029},
	{"TIMPO", 5, 235030},
	{"STOFIES", 7, 235031},
	{"SCREEBSAVERS", 12, 235032},
	{"PAGRS", 5, 235033},
	{"SCKENCE", 7, 235034},
	{"MINISTERE", 9, 235035},
	{"LEPOMIS", 7, 235036},
	{"ELERT", 5, 235037},
	{"SHERRYL", 7, 235038},
	{"FSIR", 4, 235039},
	{"PONTOISE", 8, 235040},
	{"HARUMI", 6, 235041},
	{"WINDOWSCE", 9, 235042},
	{"WINDCHASER", 10, 235043},
	{"GREERING", 8, 235044},
	{"EZPOP", 5, 235045},
	{"DONALSONVILLE", 13, 235046},
	{"CELIE", 5, 235047},
	{"ARTOO", 5, 235048},
	{"STLRIES", 7, 235049},
	{"SEMAG", 5, 235050},
	{"SCIEJCE", 7, 235051},
	{"CORDWAINER", 10, 235052},
	{"MENESES", 7, 235053},
	{"SNORKELERS", 10, 235054},
	{"HREETING", 8, 235055},
	{"SUPRANUCLEAR", 12, 235056},
	{"REHAN", 5, 235057},
	{"PXR", 3, 235058},
	{"OXYSPORUM", 9, 235059},
	{"LOZENETS", 8, 235060},
	{"IDSL", 4, 235061},
	{"CCIENCE", 7, 235062},
	{"ICPR", 4, 235063},
	{"GREENCARD", 9, 235064},
	{"YOSSEF", 6, 235065},
	{"REDRAFTED", 9, 235066},
	{"GARDENEX", 8, 235067},
	{"DSHEA", 5, 235068},
	{"BUYMOBILEPHONES", 15, 235069},
	{"ZAKUPY", 6, 235070},
	{"TRADICIONAL", 11, 235071},
	{"NIGG", 4, 235072},
	{"JANIERO", 7, 235073},
	{"MCARTHY", 7, 235074},
	{"LPSTR", 5, 235075},
	{"SFORIES", 7, 235076},
	{"SDIENCE", 7, 235077},
	{"SCUENCE", 7, 235078},
	{"CHILLUM", 7, 235079},
	{"BATHOLITH", 9, 235080},
	{"ULLER", 5, 235081},
	{"SCOPIC", 6, 235082},
	{"TAKAAKI", 7, 235083},
	{"HIRSCHSPRUNG", 12, 235084},
	{"CONTROVERTED", 12, 235085},
	{"AMEIVA", 6, 235086},
	{"SRCEENSAVERS", 12, 235087},
	{"REATTACHED", 10, 235088},
	{"READMISSIONS", 12, 235089},
	{"BHARADWAJ", 9, 235090},
	{"BELLBOY", 7, 235091},
	{"BAGCHEE", 7, 235092},
	{"STORJES", 7, 235093},
	{"EXECUTER", 8, 235094},
	{"AMARYLLISS", 10, 235095},
	{"STRATHERN", 9, 235096},
	{"SPLOT", 5, 235097},
	{"NGHIEP", 6, 235098},
	{"GAMD", 4, 235099},
	{"CCTC", 4, 235100},
	{"SCIWNCE", 7, 235101},
	{"PASPALUM", 8, 235102},
	{"MELANOCORTIN", 12, 235103},
	{"OVERRIDABLE", 11, 235104},
	{"LXV", 3, 235105},
	{"OBERWERK", 8, 235106},
	{"SERVIETTE", 9, 235107},
	{"EMMIE", 5, 235108},
	{"COEAECIENT", 10, 235109},
	{"SCISNCE", 7, 235110},
	{"PHOTOGRAVURE", 12, 235111},
	{"DISCLAMER", 9, 235112},
	{"GRUENE", 6, 235113},
	{"FRITSCHE", 8, 235114},
	{"EUROFILES", 9, 235115},
	{"SLOPPILY", 8, 235116},
	{"FITZWELL", 8, 235117},
	{"SXIENCE", 7, 235118},
	{"AMSU", 4, 235119},
	{"SHINDE", 6, 235120},
	{"SCIEHCE", 7, 235121},
	{"DRAGONFLYBSD", 12, 235122},
	{"VOCALIZE", 8, 235123},
	{"TWACOMM", 7, 235124},
	{"GNOD", 4, 235125},
	{"GLAY", 4, 235126},
	{"DAUGHER", 7, 235127},
	{"REAK", 4, 235128},
	{"KKR", 3, 235129},
	{"GALATIAN", 8, 235130},
	{"EDVIN", 5, 235131},
	{"AFMAN", 5, 235132},
	{"NAPHTHYL", 8, 235133},
	{"HEADSUP", 7, 235134},
	{"APPOINTIVE", 10, 235135},
	{"BENCHER", 7, 235136},
	{"SCJENCE", 7, 235137},
	{"NANOGRAMS", 9, 235138},
	{"FISHKEEPING", 11, 235139},
	{"PHENOMENONS", 11, 235140},
	{"MAHDIA", 6, 235141},
	{"MULTISENSOR", 11, 235142},
	{"DOUMIT", 6, 235143},
	{"DESGIN", 6, 235144},
	{"BIOSTATISTICAL", 14, 235145},
	{"FUNCTIE", 7, 235146},
	{"PERIMENT", 8, 235147},
	{"AWDUR", 5, 235148},
	{"ABOYNE", 6, 235149},
	{"SCREENSAFERS", 12, 235150},
	{"HYPERGEOMETRICPFQ", 17, 235151},
	{"HOROWHENUA", 10, 235152},
	{"EWCA", 4, 235153},
	{"ANSCOMBE", 8, 235154},
	{"VORA", 4, 235155},
	{"RENOUF", 6, 235156},
	{"VENGA", 5, 235157},
	{"SOUNDGATE", 9, 235158},
	{"PROGMODES", 9, 235159},
	{"BERLEX", 6, 235160},
	{"CACHEFS", 7, 235161},
	{"AMIABLY", 7, 235162},
	{"UNCERTIFICATED", 14, 235163},
	{"BARLETT", 7, 235164},
	{"SCHREIBT", 8, 235165},
	{"WYNBERG", 7, 235166},
	{"ISSIMA", 6, 235167},
	{"TRIATHALON", 10, 235168},
	{"SOWOHL", 6, 235169},
	{"PROBLHMATA", 10, 235170},
	{"MOOREWATCH", 10, 235171},
	{"HEADBANGERS", 11, 235172},
	{"GWAN", 4, 235173},
	{"CARACTER", 8, 235174},
	{"SUNDOG", 6, 235175},
	{"MADDIN", 6, 235176},
	{"HITSLINK", 8, 235177},
	{"FILEMAN", 7, 235178},
	{"KADISH", 6, 235179},
	{"MORG", 4, 235180},
	{"WATTEAU", 7, 235181},
	{"IODBC", 5, 235182},
	{"URBANSPECS", 10, 235183},
	{"SPEEDORDER", 10, 235184},
	{"RUBENFELD", 9, 235185},
	{"NECVOX", 6, 235186},
	{"LONDINIUM", 9, 235187},
	{"CLEMMENSEN", 10, 235188},
	{"THEDFORD", 8, 235189},
	{"NINOMIYA", 8, 235190},
	{"KBAR", 4, 235191},
	{"CORTINAS", 8, 235192},
	{"STREETSIDE", 10, 235193},
	{"SEABEACN", 8, 235194},
	{"PABES", 5, 235195},
	{"NISSWA", 6, 235196},
	{"NIREX", 5, 235197},
	{"HELISKIING", 10, 235198},
	{"CLIPATR", 7, 235199},
	{"ZALU", 4, 235200},
	{"YTWA", 4, 235201},
	{"YPMB", 4, 235202},
	{"YPCA", 4, 235203},
	{"YLFO", 4, 235204},
	{"XBUL", 4, 235205},
	{"VVAN", 4, 235206},
	{"VUTO", 4, 235207},
	{"VOLM", 4, 235208},
	{"VMOS", 4, 235209},
	{"UYIF", 4, 235210},
	{"USDJ", 4, 235211},
	{"UBFU", 4, 235212},
	{"RTNY", 4, 235213},
	{"RPRY", 4, 235214},
	{"RHPK", 4, 235215},
	{"RECN", 4, 235216},
	{"RDRK", 4, 235217},
	{"RAQG", 4, 235218},
	{"RACB", 4, 235219},
	{"RABV", 4, 235220},
	{"QUBA", 4, 235221},
	{"PORY", 4, 235222},
	{"OZCA", 4, 235223},
	{"ORXE", 4, 235224},
	{"NZDE", 4, 235225},
	{"NUTU", 4, 235226},
	{"MMAZ", 4, 235227},
	{"LIAQ", 4, 235228},
	{"KJRA", 4, 235229},
	{"IJOR", 4, 235230},
	{"HUOR", 4, 235231},
	{"FWEU", 4, 235232},
	{"FPMA", 4, 235233},
	{"EDCV", 4, 235234},
	{"CTSX", 4, 235235},
	{"CFBA", 4, 235236},
	{"BOPI", 4, 235237},
	{"ARXT", 4, 235238},
	{"AHFL", 4, 235239},
	{"AEDM", 4, 235240},
	{"ZUTPHEN", 7, 235241},
	{"PILCHARD", 8, 235242},
	{"TLCKETS", 7, 235243},
	{"ITCL", 4, 235244},
	{"XMAN", 4, 235245},
	{"UNIVEGA", 7, 235246},
	{"THERMOGRAPHIC", 13, 235247},
	{"SCAMANDER", 9, 235248},
	{"PAFES", 5, 235249},
	{"LULEA", 5, 235250},
	{"FIREGROUND", 10, 235251},
	{"ESCALAS", 7, 235252},
	{"RHAPSODIES", 10, 235253},
	{"DECESARE", 8, 235254},
	{"BLOWHOLE", 8, 235255},
	{"ANTIKE", 6, 235256},
	{"KRIVOY", 6, 235257},
	{"SVIENCE", 7, 235258},
	{"SUPERSLOTS", 10, 235259},
	{"PROMEDIO", 8, 235260},
	{"SHOPLIFT", 8, 235261},
	{"LAVIOLETTE", 10, 235262},
	{"KWSTAS", 6, 235263},
	{"DAND", 4, 235264},
	{"ZWICKAU", 7, 235265},
	{"LIFA", 4, 235266},
	{"MERRYWEATHER", 12, 235267},
	{"NAPPE", 5, 235268},
	{"MICROGLIAL", 10, 235269},
	{"SUGIHARA", 8, 235270},
	{"SPITERI", 7, 235271},
	{"PMNS", 4, 235272},
	{"FWIR", 4, 235273},
	{"DEFIAS", 6, 235274},
	{"TRANSNATIONALISM", 16, 235275},
	{"NZSX", 4, 235276},
	{"DELPHIA", 7, 235277},
	{"BOLIVIANS", 9, 235278},
	{"ARNELL", 6, 235279},
	{"OBSERVATORIO", 12, 235280},
	{"DARRAN", 6, 235281},
	{"BROADWELL", 9, 235282},
	{"WATERDEEP", 9, 235283},
	{"ICONOCLASM", 10, 235284},
	{"FULSOME", 7, 235285},
	{"PARSEFLOAT", 10, 235286},
	{"TRANSPIRING", 11, 235287},
	{"REFERENZ", 8, 235288},
	{"DNIPROPETROVSK", 14, 235289},
	{"DIRI", 4, 235290},
	{"BARBADIAN", 9, 235291},
	{"APPRE", 5, 235292},
	{"WHELMING", 8, 235293},
	{"THREADSAFE", 10, 235294},
	{"EUROTHERM", 9, 235295},
	{"MIGR", 4, 235296},
	{"FLUOROMETER", 11, 235297},
	{"SCREENSAERS", 11, 235298},
	{"OLEDS", 5, 235299},
	{"CHEMDRAW", 8, 235300},
	{"TANGSHAN", 8, 235301},
	{"OSTERREICH", 10, 235302},
	{"BIPIN", 5, 235303},
	{"SCROLLERS", 9, 235304},
	{"NYESTE", 6, 235305},
	{"FADEL", 5, 235306},
	{"TERRIBLES", 9, 235307},
	{"OUTSOLES", 8, 235308},
	{"IRDT", 4, 235309},
	{"BALSAMO", 7, 235310},
	{"EMPLO", 5, 235311},
	{"WORMLEY", 7, 235312},
	{"SCHMALZ", 7, 235313},
	{"ROBOCON", 7, 235314},
	{"NAFTALI", 7, 235315},
	{"FONTAN", 6, 235316},
	{"TRIACYLGLYCEROL", 15, 235317},
	{"HITCHER", 7, 235318},
	{"TIMOSHENKO", 10, 235319},
	{"CYCLEWAY", 8, 235320},
	{"CLPART", 6, 235321},
	{"STAINSBY", 8, 235322},
	{"OTTAVIO", 7, 235323},
	{"GORSHIN", 7, 235324},
	{"ATKINSONS", 9, 235325},
	{"OKAWA", 5, 235326},
	{"RETITLE", 7, 235327},
	{"RCOM", 4, 235328},
	{"DOCDIR", 6, 235329},
	{"ARCPAD", 6, 235330},
	{"PQGES", 5, 235331},
	{"MIGRANS", 7, 235332},
	{"GAUZY", 5, 235333},
	{"BATESIAS", 8, 235334},
	{"TAHOKA", 6, 235335},
	{"GLV", 3, 235336},
	{"CURIES", 6, 235337},
	{"ATYRAU", 6, 235338},
	{"CREFORGE", 8, 235339},
	{"AFIP", 4, 235340},
	{"STINGREY", 8, 235341},
	{"BCAAS", 5, 235342},
	{"BANKROLLED", 10, 235343},
	{"ASCENDANCE", 10, 235344},
	{"CONVERGENCES", 12, 235345},
	{"TECHWEAR", 8, 235346},
	{"DISCRIMI", 8, 235347},
	{"BANNANA", 7, 235348},
	{"ZSUZSA", 6, 235349},
	{"STRIKEIRON", 10, 235350},
	{"VIEWFINDERS", 11, 235351},
	{"SPORTMAX", 8, 235352},
	{"ORNELAS", 7, 235353},
	{"KNOWLEDGEABLY", 13, 235354},
	{"VERIE", 5, 235355},
	{"SVREENSAVERS", 12, 235356},
	{"HARSHBARGER", 11, 235357},
	{"PHETAMINE", 9, 235358},
	{"YOKOI", 5, 235359},
	{"BREARLEY", 8, 235360},
	{"BLACKANDWHITE", 13, 235361},
	{"REPRESENTITIVE", 14, 235362},
	{"PERIODICITIES", 13, 235363},
	{"COROZAL", 7, 235364},
	{"SPRINGPORT", 10, 235365},
	{"KIMA", 4, 235366},
	{"CLPIART", 7, 235367},
	{"PADDLEFISH", 10, 235368},
	{"SZEKELY", 7, 235369},
	{"CORNES", 6, 235370},
	{"ROTHSCHILDS", 11, 235371},
	{"ROTTENCOM", 9, 235372},
	{"PREVALENCES", 11, 235373},
	{"INCEN", 5, 235374},
	{"OUCS", 4, 235375},
	{"MUFON", 5, 235376},
	{"JEZELF", 6, 235377},
	{"CHRYSANTH", 9, 235378},
	{"VDEO", 4, 235379},
	{"CYBERGUYS", 9, 235380},
	{"CRIVITZ", 7, 235381},
	{"STUCKI", 6, 235382},
	{"SANJOSE", 7, 235383},
	{"QUICKTAGS", 9, 235384},
	{"FOOTPLATE", 9, 235385},
	{"SYRIANOZ", 8, 235386},
	{"LONGHAND", 8, 235387},
	{"CLIPSRT", 7, 235388},
	{"CELEBRETIES", 11, 235389},
	{"VAME", 4, 235390},
	{"NUBUS", 5, 235391},
	{"NOIRES", 6, 235392},
	{"MAGGIES", 7, 235393},
	{"ECHTER", 6, 235394},
	{"CASEBOOKS", 9, 235395},
	{"CLIAPRT", 7, 235396},
	{"NOTEVISION", 10, 235397},
	{"LONGDESC", 8, 235398},
	{"DRIVETIME", 9, 235399},
	{"RASULULLAH", 10, 235400},
	{"VENKATESAN", 10, 235401},
	{"TURNIER", 7, 235402},
	{"CONGENITALLY", 12, 235403},
	{"UNTANGLED", 9, 235404},
	{"GSTAT", 5, 235405},
	{"FATALES", 7, 235406},
	{"WALB", 4, 235407},
	{"SONICATION", 10, 235408},
	{"LUSIC", 5, 235409},
	{"ESSERMAN", 8, 235410},
	{"BARNSTORMING", 12, 235411},
	{"LACKNER", 7, 235412},
	{"ACCEPTENCE", 10, 235413},
	{"TURBODIESEL", 11, 235414},
	{"LICEO", 5, 235415},
	{"WFUV", 4, 235416},
	{"PAGDS", 5, 235417},
	{"LARMER", 6, 235418},
	{"BOLIG", 5, 235419},
	{"PAGSS", 5, 235420},
	{"STRADBALLY", 10, 235421},
	{"MORPEHUS", 8, 235422},
	{"MANGES", 6, 235423},
	{"STRYDOM", 7, 235424},
	{"BIOWARFARE", 10, 235425},
	{"AMOEBAE", 7, 235426},
	{"TUATARA", 7, 235427},
	{"SPERMICIDES", 11, 235428},
	{"PICTKRES", 8, 235429},
	{"MANGEL", 6, 235430},
	{"ECKLEY", 6, 235431},
	{"INTERCESSORS", 12, 235432},
	{"COLTOTALS", 9, 235433},
	{"PERMED", 6, 235434},
	{"BIUE", 4, 235435},
	{"VENTUREBLOG", 11, 235436},
	{"RJWITTAMS", 9, 235437},
	{"MOTM", 4, 235438},
	{"ULTR", 4, 235439},
	{"MONHEGAN", 8, 235440},
	{"JAMBI", 5, 235441},
	{"FILTRONIC", 9, 235442},
	{"CLIPRAT", 7, 235443},
	{"GARDERMOEN", 10, 235444},
	{"KAUKONEN", 8, 235445},
	{"SCOTLANDS", 9, 235446},
	{"HARGETT", 7, 235447},
	{"AJAXIAN", 7, 235448},
	{"ZATZ", 4, 235449},
	{"EXPLANA", 7, 235450},
	{"CHILDERSBURG", 12, 235451},
	{"MARCHER", 7, 235452},
	{"INCORRECTNESS", 13, 235453},
	{"HYDROGENICS", 11, 235454},
	{"BARANOV", 7, 235455},
	{"DIAMOX", 6, 235456},
	{"BLOCKTOTALS", 11, 235457},
	{"BEETJE", 6, 235458},
	{"ANTICLINE", 9, 235459},
	{"RWXRWXRWX", 9, 235460},
	{"GXMES", 5, 235461},
	{"GRAMICIDIN", 10, 235462},
	{"ANEURYSMAL", 10, 235463},
	{"WNEP", 4, 235464},
	{"FQIR", 4, 235465},
	{"COROPLAST", 9, 235466},
	{"RHWYDWAITH", 10, 235467},
	{"KRAMERS", 7, 235468},
	{"VOSTRA", 6, 235469},
	{"STKRIES", 7, 235470},
	{"PATRIE", 6, 235471},
	{"KMOV", 4, 235472},
	{"STEELMAKER", 10, 235473},
	{"STATECHART", 10, 235474},
	{"IGNITABLE", 9, 235475},
	{"BRAGDON", 7, 235476},
	{"ZIGR", 4, 235477},
	{"ZGOV", 4, 235478},
	{"YUUK", 4, 235479},
	{"YOVI", 4, 235480},
	{"YEGI", 4, 235481},
	{"XYBU", 4, 235482},
	{"WSTV", 4, 235483},
	{"VUEC", 4, 235484},
	{"VSUR", 4, 235485},
	{"VDEP", 4, 235486},
	{"UPCF", 4, 235487},
	{"UJIO", 4, 235488},
	{"UGFA", 4, 235489},
	{"UBVA", 4, 235490},
	{"TVEP", 4, 235491},
	{"TRYQ", 4, 235492},
	{"TIFV", 4, 235493},
	{"SYIM", 4, 235494},
	{"SVOU", 4, 235495},
	{"SNYC", 4, 235496},
	{"SMJU", 4, 235497},
	{"SMHU", 4, 235498},
	{"RUBN", 4, 235499},
	{"RIGF", 4, 235500},
	{"RHYG", 4, 235501},
	{"RFBU", 4, 235502},
	{"RDVS", 4, 235503},
	{"QPOL", 4, 235504},
	{"PTUB", 4, 235505},
	{"OZYT", 4, 235506},
	{"ORCK", 4, 235507},
	{"NZEU", 4, 235508},
	{"NZCA", 4, 235509},
	{"NXFA", 4, 235510},
	{"NVOM", 4, 235511},
	{"MRER", 4, 235512},
	{"MPCE", 4, 235513},
	{"MLSI", 4, 235514},
	{"MGUR", 4, 235515},
	{"LYEJ", 4, 235516},
	{"LLFC", 4, 235517},
	{"LIUL", 4, 235518},
	{"LHIV", 4, 235519},
	{"LGEW", 4, 235520},
	{"LBOH", 4, 235521},
	{"KVES", 4, 235522},
	{"JCIE", 4, 235523},
	{"JAMH", 4, 235524},
	{"IWOL", 4, 235525},
	{"IBYP", 4, 235526},
	{"HMRH", 4, 235527},
	{"HIGB", 4, 235528},
	{"GYVA", 4, 235529},
	{"GUCO", 4, 235530},
	{"GPMT", 4, 235531},
	{"GDOB", 4, 235532},
	{"FSYC", 4, 235533},
	{"FSUH", 4, 235534},
	{"FOSP", 4, 235535},
	{"FMSS", 4, 235536},
	{"FDRB", 4, 235537},
	{"FCCD", 4, 235538},
	{"EWVU", 4, 235539},
	{"EUFF", 4, 235540},
	{"ENPF", 4, 235541},
	{"EEMQ", 4, 235542},
	{"EAPV", 4, 235543},
	{"DQWE", 4, 235544},
	{"DCTA", 4, 235545},
	{"BOKT", 4, 235546},
	{"BHEC", 4, 235547},
	{"BAJE", 4, 235548},
	{"JACKRABBITS", 11, 235549},
	{"FOODSAFE", 8, 235550},
	{"COMPAREFILES", 12, 235551},
	{"REALTED", 7, 235552},
	{"AVENS", 5, 235553},
	{"ROWTOTALS", 9, 235554},
	{"LDEO", 4, 235555},
	{"PROVAL", 6, 235556},
	{"LAWHEAD", 7, 235557},
	{"FADIMAN", 7, 235558},
	{"GIGAWORKS", 9, 235559},
	{"COPPEROPOLIS", 12, 235560},
	{"LVII", 4, 235561},
	{"HEBBURN", 7, 235562},
	{"CONCEPTUALISE", 13, 235563},
	{"ALZA", 4, 235564},
	{"POLARBEAR", 9, 235565},
	{"ADULTBOUNCER", 12, 235566},
	{"REPCO", 5, 235567},
	{"YPBPR", 5, 235568},
	{"LEGERDEMAIN", 11, 235569},
	{"SMATHERS", 8, 235570},
	{"KOLIVAS", 7, 235571},
	{"COXS", 4, 235572},
	{"BEAUTICONTROL", 13, 235573},
	{"BDY", 3, 235574},
	{"TENMILE", 7, 235575},
	{"HIRTH", 5, 235576},
	{"ARAW", 4, 235577},
	{"SLEEPWALK", 9, 235578},
	{"NIMODIPINE", 10, 235579},
	{"ZELMA", 5, 235580},
	{"SQUELCHED", 9, 235581},
	{"INSERIRE", 8, 235582},
	{"INSECTIVOROUS", 13, 235583},
	{"CROSBYTON", 9, 235584},
	{"VERSANDKOSTENFREI", 17, 235585},
	{"SUBMODULES", 10, 235586},
	{"MOATED", 6, 235587},
	{"MANDELIEU", 9, 235588},
	{"HORRIGAN", 8, 235589},
	{"RIBO", 4, 235590},
	{"NALLEY", 6, 235591},
	{"ZASSENHAUS", 10, 235592},
	{"HOLLINGSHEAD", 12, 235593},
	{"SCROLLWORK", 10, 235594},
	{"QUIREMENT", 9, 235595},
	{"GAMFS", 5, 235596},
	{"MAZUREK", 7, 235597},
	{"EROCKTAVISION", 13, 235598},
	{"CORDESMAN", 9, 235599},
	{"TDEFORMATIONFIELD", 17, 235600},
	{"STRUB", 5, 235601},
	{"LOESTRIN", 8, 235602},
	{"CIRCLEID", 8, 235603},
	{"CLIOART", 7, 235604},
	{"CIVL", 4, 235605},
	{"BRANDXPICTURES", 14, 235606},
	{"MILLAND", 7, 235607},
	{"ASPATH", 6, 235608},
	{"REVPAR", 6, 235609},
	{"RAHU", 4, 235610},
	{"LCIPART", 7, 235611},
	{"CHURCHTOWN", 10, 235612},
	{"HEATHERTON", 10, 235613},
	{"DLIPART", 7, 235614},
	{"CLIPARR", 7, 235615},
	{"BLITZES", 7, 235616},
	{"XEVIOUS", 7, 235617},
	{"NEUBURGER", 9, 235618},
	{"MCCLURKIN", 9, 235619},
	{"PROJECTMANAGEMENT", 17, 235620},
	{"OWLET", 5, 235621},
	{"FLIPART", 7, 235622},
	{"ETAPA", 5, 235623},
	{"DZIEWCZYNY", 10, 235624},
	{"ARAVOSIS", 8, 235625},
	{"LONGHI", 6, 235626},
	{"AMOEBIC", 7, 235627},
	{"LONGSTOCKING", 12, 235628},
	{"FZIR", 4, 235629},
	{"FPSC", 4, 235630},
	{"FARAJ", 5, 235631},
	{"CLOPART", 7, 235632},
	{"LAZIEST", 7, 235633},
	{"WAVECREST", 9, 235634},
	{"TOPTON", 6, 235635},
	{"GODFORSAKEN", 11, 235636},
	{"ENTERNET", 8, 235637},
	{"DILATORY", 8, 235638},
	{"COCKADED", 8, 235639},
	{"MAHALE", 6, 235640},
	{"GRANTIAU", 8, 235641},
	{"EGIDIO", 6, 235642},
	{"CKIPART", 7, 235643},
	{"XLIPART", 7, 235644},
	{"STAPLEY", 7, 235645},
	{"OBLASTS", 7, 235646},
	{"ALTRU", 5, 235647},
	{"WCCC", 4, 235648},
	{"TEVES", 5, 235649},
	{"CIALI", 5, 235650},
	{"PUMPHOUSE", 9, 235651},
	{"YREETING", 8, 235652},
	{"NIGHTSIDE", 9, 235653},
	{"TIPICO", 6, 235654},
	{"CLUPART", 7, 235655},
	{"CLIPATT", 7, 235656},
	{"WHLTE", 5, 235657},
	{"STANBURY", 8, 235658},
	{"SHORIES", 7, 235659},
	{"ORTNER", 6, 235660},
	{"CLIPARG", 7, 235661},
	{"ZINOVIEV", 8, 235662},
	{"SLOVENSKA", 9, 235663},
	{"MOMENTAN", 8, 235664},
	{"FINEGAN", 7, 235665},
	{"ACQUIROR", 8, 235666},
	{"CLIPAET", 7, 235667},
	{"OFSTREAM", 8, 235668},
	{"CLIPSAL", 7, 235669},
	{"ALLOCATORS", 10, 235670},
	{"VISIONGAIN", 10, 235671},
	{"UNCO", 4, 235672},
	{"TROUBLEMAN", 10, 235673},
	{"SCHAIK", 6, 235674},
	{"CEFIXIME", 8, 235675},
	{"SCREEMSAVERS", 12, 235676},
	{"ORICA", 5, 235677},
	{"MKSIC", 5, 235678},
	{"SENNACHERIB", 11, 235679},
	{"CPIPART", 7, 235680},
	{"BROADGATE", 9, 235681},
	{"STONEFIELD", 10, 235682},
	{"MZPS", 4, 235683},
	{"CZARIST", 7, 235684},
	{"CLIPARY", 7, 235685},
	{"ULYANOVSK", 9, 235686},
	{"CODDLE", 6, 235687},
	{"JAGD", 4, 235688},
	{"CLKPART", 7, 235689},
	{"DESMIN", 6, 235690},
	{"SLIGH", 5, 235691},
	{"DEBASE", 6, 235692},
	{"CLIPQRT", 7, 235693},
	{"MQPS", 4, 235694},
	{"DOWBLOADS", 9, 235695},
	{"CLIPAFT", 7, 235696},
	{"WAPA", 4, 235697},
	{"TOROIDS", 7, 235698},
	{"INGENIERIA", 10, 235699},
	{"SCREENAVERS", 11, 235700},
	{"GOSSIPY", 7, 235701},
	{"SHARKEYMARINE", 13, 235702},
	{"FACTEUR", 7, 235703},
	{"CLILART", 7, 235704},
	{"CLIPWRT", 7, 235705},
	{"METHYLTESTOSTERONE", 18, 235706},
	{"BORLAUG", 7, 235707},
	{"TEXTUALITY", 10, 235708},
	{"CLIPZRT", 7, 235709},
	{"TNITAC", 6, 235710},
	{"DAVISSON", 8, 235711},
	{"CLLP", 4, 235712},
	{"CLIPARF", 7, 235713},
	{"BARCHART", 8, 235714},
	{"MARSHAM", 7, 235715},
	{"INCOMMENSURATE", 14, 235716},
	{"MORPHESU", 8, 235717},
	{"COIPART", 7, 235718},
	{"POLYATOMIC", 10, 235719},
	{"OROGENY", 7, 235720},
	{"LIFEKEEPER", 10, 235721},
	{"HALLENBECK", 10, 235722},
	{"BIRDSVILLE", 10, 235723},
	{"BAMENDA", 7, 235724},
	{"RCUK", 4, 235725},
	{"NEBULISERS", 10, 235726},
	{"COMPUTERE", 9, 235727},
	{"SHANTANU", 8, 235728},
	{"SCRENESAVERS", 12, 235729},
	{"YAXLEY", 6, 235730},
	{"PZGES", 5, 235731},
	{"DIETHYLENE", 10, 235732},
	{"MAHAVISHNU", 10, 235733},
	{"DEALIN", 6, 235734},
	{"WILLER", 6, 235735},
	{"FISRT", 5, 235736},
	{"SAVITRI", 7, 235737},
	{"MOTORCYLES", 10, 235738},
	{"PSYCHOTICS", 10, 235739},
	{"PORTB", 5, 235740},
	{"HUKA", 4, 235741},
	{"FERRIDAY", 8, 235742},
	{"ESTLAND", 7, 235743},
	{"ARCCOS", 6, 235744},
	{"SERVCE", 6, 235745},
	{"COLLECTIBLESTODAY", 17, 235746},
	{"TROGLITAZONE", 12, 235747},
	{"VOXLINKS", 8, 235748},
	{"DEODATO", 7, 235749},
	{"GZME", 4, 235750},
	{"POPPLEWELL", 10, 235751},
	{"HOHER", 5, 235752},
	{"SUBLESSEE", 9, 235753},
	{"GREGR", 5, 235754},
	{"QUASILINEAR", 11, 235755},
	{"BASKE", 5, 235756},
	{"ALLOWWEBMANAGE", 14, 235757},
	{"RAINCOAST", 9, 235758},
	{"TRANSFINITE", 11, 235759},
	{"TAYMOR", 6, 235760},
	{"DCREENSAVERS", 12, 235761},
	{"CLJPART", 7, 235762},
	{"KURL", 4, 235763},
	{"KULLU", 5, 235764},
	{"CHAPPIE", 7, 235765},
	{"FATTURA", 7, 235766},
	{"DJAX", 4, 235767},
	{"MERCURI", 7, 235768},
	{"ZZIM", 4, 235769},
	{"ZUOK", 4, 235770},
	{"YNSF", 4, 235771},
	{"YKOF", 4, 235772},
	{"YEVT", 4, 235773},
	{"YEKI", 4, 235774},
	{"XGUY", 4, 235775},
	{"WHEU", 4, 235776},
	{"UBYH", 4, 235777},
	{"TEYL", 4, 235778},
	{"SGMO", 4, 235779},
	{"RSZI", 4, 235780},
	{"RDYU", 4, 235781},
	{"PUBR", 4, 235782},
	{"PTJE", 4, 235783},
	{"OWTV", 4, 235784},
	{"OLAX", 4, 235785},
	{"OJOM", 4, 235786},
	{"OGGC", 4, 235787},
	{"OFXF", 4, 235788},
	{"MTYR", 4, 235789},
	{"MSJR", 4, 235790},
	{"MRPH", 4, 235791},
	{"LPLC", 4, 235792},
	{"LEUB", 4, 235793},
	{"LDZI", 4, 235794},
	{"LDOK", 4, 235795},
	{"LBYY", 4, 235796},
	{"IUFJ", 4, 235797},
	{"IJIK", 4, 235798},
	{"HLKE", 4, 235799},
	{"GHCY", 4, 235800},
	{"FZAI", 4, 235801},
	{"FURP", 4, 235802},
	{"FRSL", 4, 235803},
	{"FIRP", 4, 235804},
	{"FETL", 4, 235805},
	{"FAOL", 4, 235806},
	{"ETWW", 4, 235807},
	{"EDTP", 4, 235808},
	{"DYYA", 4, 235809},
	{"CVSC", 4, 235810},
	{"COYF", 4, 235811},
	{"CJER", 4, 235812},
	{"CFEV", 4, 235813},
	{"CBYJ", 4, 235814},
	{"BMUR", 4, 235815},
	{"ATWP", 4, 235816},
	{"AGBH", 4, 235817},
	{"KANGXI", 6, 235818},
	{"NOTFD", 5, 235819},
	{"MOVIED", 6, 235820},
	{"ALLTID", 6, 235821},
	{"VIEWFILE", 8, 235822},
	{"SCREENASVERS", 12, 235823},
	{"BRICKED", 7, 235824},
	{"SOUTHHAMPTON", 12, 235825},
	{"CRYSLER", 7, 235826},
	{"BULLFROGS", 9, 235827},
	{"WARNELL", 7, 235828},
	{"BOTTO", 5, 235829},
	{"RUXTON", 6, 235830},
	{"EPILEPSIES", 10, 235831},
	{"WOLLTEN", 7, 235832},
	{"VENEZOLANA", 10, 235833},
	{"TOUCHABLE", 9, 235834},
	{"SATIONAL", 8, 235835},
	{"EIXAN", 5, 235836},
	{"RINARD", 6, 235837},
	{"RASHA", 5, 235838},
	{"ENSUITES", 8, 235839},
	{"EDUCATIVO", 9, 235840},
	{"CORVINUS", 8, 235841},
	{"TENAGLIA", 8, 235842},
	{"STABILITIES", 11, 235843},
	{"JUNKBUSTER", 10, 235844},
	{"FACIALSBLACK", 12, 235845},
	{"RACHAL", 6, 235846},
	{"FULTONDALE", 10, 235847},
	{"CRYPTORCHIDISM", 14, 235848},
	{"RVCA", 4, 235849},
	{"AIKIKAI", 7, 235850},
	{"BRICKBATS", 9, 235851},
	{"PASTO", 5, 235852},
	{"MVCC", 4, 235853},
	{"DREWES", 6, 235854},
	{"SOULFURIC", 9, 235855},
	{"MIDDLEBOX", 9, 235856},
	{"DIECKMANN", 9, 235857},
	{"BARACUDA", 8, 235858},
	{"FACIALSBOYS", 11, 235859},
	{"SHOTSBLACK", 10, 235860},
	{"JICKS", 5, 235861},
	{"HETEROGENEITIES", 15, 235862},
	{"MARGINALIZING", 13, 235863},
	{"MAGINOT", 7, 235864},
	{"KYUSTENDIL", 10, 235865},
	{"FRUTAS", 6, 235866},
	{"XCREENSAVERS", 12, 235867},
	{"SEEDBLACK", 9, 235868},
	{"SCALARTYPE", 10, 235869},
	{"LINETTEBACKROOM", 15, 235870},
	{"ERNMENTS", 8, 235871},
	{"SEEDBILDDATENBANK", 17, 235872},
	{"DISTIL", 6, 235873},
	{"TABULATOR", 9, 235874},
	{"MOVIESBACKROOM", 14, 235875},
	{"FACIALSBACK", 11, 235876},
	{"ALIOTH", 6, 235877},
	{"ACREENSAVERS", 12, 235878},
	{"WEBRINGALAN", 11, 235879},
	{"VLIPART", 7, 235880},
	{"TRAUMAAMBER", 11, 235881},
	{"IIIANIME", 8, 235882},
	{"FREECASSIE", 10, 235883},
	{"FIESTAANIMAL", 12, 235884},
	{"FACIALSANIMAL", 13, 235885},
	{"FACIALEDAMBER", 13, 235886},
	{"TERABITHIA", 10, 235887},
	{"SAROYAN", 7, 235888},
	{"PETRU", 5, 235889},
	{"PAPEN", 5, 235890},
	{"MSCE", 4, 235891},
	{"GLADMAN", 7, 235892},
	{"FAITHBACKROOM", 13, 235893},
	{"PWGES", 5, 235894},
	{"KELLYBACKROOM", 13, 235895},
	{"FACIALSBEAUTY", 13, 235896},
	{"ASSBINOMIAL", 11, 235897},
	{"TERIALS", 7, 235898},
	{"YAHOOGROU", 9, 235899},
	{"SPILSBY", 7, 235900},
	{"PALADINO", 8, 235901},
	{"PENTWATER", 9, 235902},
	{"NIDCR", 5, 235903},
	{"CSREENSAVERS", 12, 235904},
	{"SODWANA", 7, 235905},
	{"HTMLMACRO", 9, 235906},
	{"AIGLINES", 8, 235907},
	{"WCREENSAVERS", 12, 235908},
	{"OPPLAND", 7, 235909},
	{"SHOGUNS", 7, 235910},
	{"SEKINE", 6, 235911},
	{"MECENATE", 8, 235912},
	{"HTMLHELP", 8, 235913},
	{"ZCREENSAVERS", 12, 235914},
	{"BRITNE", 6, 235915},
	{"GRANDJEAN", 9, 235916},
	{"CATHERINEJOHNSON", 16, 235917},
	{"THOTCALLBACK", 12, 235918},
	{"TEMPELHOF", 9, 235919},
	{"ALBITE", 6, 235920},
	{"RAMIFIED", 8, 235921},
	{"CALLOUSED", 9, 235922},
	{"SCIFICTION", 10, 235923},
	{"SYMANT", 6, 235924},
	{"PHOTOLUMINESCENT", 16, 235925},
	{"LOGFORMAT", 9, 235926},
	{"KAROLINE", 8, 235927},
	{"ECREENSAVERS", 12, 235928},
	{"INTELS", 6, 235929},
	{"XIRLINES", 8, 235930},
	{"NUWEIBA", 7, 235931},
	{"KESTEREN", 8, 235932},
	{"QUIDS", 5, 235933},
	{"GONZ", 4, 235934},
	{"SOJU", 4, 235935},
	{"SCRAMJET", 8, 235936},
	{"HETEROPTERA", 11, 235937},
	{"BEAVERBROOK", 11, 235938},
	{"NEWSASIA", 8, 235939},
	{"MORHEUS", 7, 235940},
	{"MILLWRIGHTS", 11, 235941},
	{"LEMANN", 6, 235942},
	{"CALLIER", 7, 235943},
	{"TOOTIN", 6, 235944},
	{"PASSEL", 6, 235945},
	{"ANONYMOUSE", 10, 235946},
	{"TRYPANOSOMES", 12, 235947},
	{"TRUXTON", 7, 235948},
	{"AZAMIN", 6, 235949},
	{"PRISCILLAS", 10, 235950},
	{"KRISHNASWAMY", 12, 235951},
	{"PUFFINUS", 8, 235952},
	{"LAMINARIA", 9, 235953},
	{"AUTOCLAVING", 11, 235954},
	{"SYNODICAL", 9, 235955},
	{"PLANON", 6, 235956},
	{"AIRLINFS", 8, 235957},
	{"YASUNORI", 8, 235958},
	{"SPAINISH", 8, 235959},
	{"RACKLEY", 7, 235960},
	{"ACOUSTO", 7, 235961},
	{"HUGEST", 6, 235962},
	{"ASTEROBSERVATIONMODE", 20, 235963},
	{"SOULFORCE", 9, 235964},
	{"FLEVOLAND", 9, 235965},
	{"DULAS", 5, 235966},
	{"CRYED", 5, 235967},
	{"DISAB", 5, 235968},
	{"CPMP", 4, 235969},
	{"WYMORE", 6, 235970},
	{"LUCIRE", 6, 235971},
	{"OCULTAR", 7, 235972},
	{"HORNISH", 7, 235973},
	{"COLINS", 6, 235974},
	{"TENTERFIELD", 11, 235975},
	{"NETLOGO", 7, 235976},
	{"GEEXBOX", 7, 235977},
	{"EUROPEANIZATION", 15, 235978},
	{"CINNA", 5, 235979},
	{"GELT", 4, 235980},
	{"FINKELMAN", 9, 235981},
	{"SPLENDOURS", 10, 235982},
	{"GUDERIAN", 8, 235983},
	{"STURDIVANT", 10, 235984},
	{"PREETEEN", 8, 235985},
	{"MOERS", 5, 235986},
	{"CANSO", 5, 235987},
	{"GALLIEN", 7, 235988},
	{"DESTINA", 7, 235989},
	{"MCSHERRY", 8, 235990},
	{"EFFECIENT", 9, 235991},
	{"TRUMPINGTON", 11, 235992},
	{"TRANSDUCIN", 10, 235993},
	{"SOCIAIS", 7, 235994},
	{"OBSERVATIONMODECONTAINER", 24, 235995},
	{"NAKEDS", 6, 235996},
	{"MIWOK", 5, 235997},
	{"GONGADZE", 8, 235998},
	{"SPIRITU", 7, 235999},
	{"EVISCERATION", 12, 236000},
	{"PROCELLA", 8, 236001},
	{"DEMORALIZE", 10, 236002},
	{"TSZYU", 5, 236003},
	{"MARATHONER", 10, 236004},
	{"LCURVE", 6, 236005},
	{"ASPART", 6, 236006},
	{"WHIRLY", 6, 236007},
	{"ENTIRES", 7, 236008},
	{"ALRLINE", 7, 236009},
	{"GAGED", 5, 236010},
	{"NALP", 4, 236011},
	{"LYDIARD", 7, 236012},
	{"HAMADAN", 7, 236013},
	{"FRONTE", 6, 236014},
	{"UNBUTTON", 8, 236015},
	{"READAHEAD", 9, 236016},
	{"CRYBABIES", 9, 236017},
	{"TEKAMAH", 7, 236018},
	{"ABREVE", 6, 236019},
	{"CEREB", 5, 236020},
	{"SPHINGOMYELIN", 13, 236021},
	{"MODELESS", 8, 236022},
	{"HOPESFALL", 9, 236023},
	{"EDDINS", 6, 236024},
	{"ANDIRONS", 8, 236025},
	{"TENINO", 6, 236026},
	{"ASSEGNI", 7, 236027},
	{"VERGELIJKING", 12, 236028},
	{"FREEZ", 5, 236029},
	{"BANGKOKPOST", 11, 236030},
	{"SUNCAST", 7, 236031},
	{"JUMBLES", 7, 236032},
	{"SLAPDASH", 8, 236033},
	{"PHARMAZIE", 9, 236034},
	{"CLINKING", 8, 236035},
	{"ALLENTEL", 8, 236036},
	{"POLYAMIDES", 10, 236037},
	{"KAHIN", 5, 236038},
	{"GRETAGMACBETH", 13, 236039},
	{"MOVLES", 6, 236040},
	{"KINDERGARTENERS", 15, 236041},
	{"BIOLOG", 6, 236042},
	{"WALBAUM", 7, 236043},
	{"SAREI", 5, 236044},
	{"PROGAMS", 7, 236045},
	{"HEIGI", 5, 236046},
	{"BROYTMANN", 9, 236047},
	{"VIDEOFLICKS", 11, 236048},
	{"SSIENCE", 7, 236049},
	{"OPOIES", 6, 236050},
	{"DOWNLODAS", 9, 236051},
	{"DOODADS", 7, 236052},
	{"ANALOGX", 7, 236053},
	{"PROSOPIS", 8, 236054},
	{"ENTROPIES", 9, 236055},
	{"DWONLOADS", 9, 236056},
	{"APITAL", 6, 236057},
	{"ABDELAZIZ", 9, 236058},
	{"SUCCESSIVA", 10, 236059},
	{"NOTAIRES", 8, 236060},
	{"NMSNT", 5, 236061},
	{"CYCLOHYDROLASE", 14, 236062},
	{"LIBICE", 6, 236063},
	{"IGPS", 4, 236064},
	{"VUG", 3, 236065},
	{"BEAUCE", 6, 236066},
	{"PRAZIQUANTEL", 12, 236067},
	{"KOEPP", 5, 236068},
	{"APPOSITION", 10, 236069},
	{"QPP", 3, 236070},
	{"CREGAN", 6, 236071},
	{"ZZBU", 4, 236072},
	{"ZPOI", 4, 236073},
	{"YXEN", 4, 236074},
	{"YLMO", 4, 236075},
	{"YEPL", 4, 236076},
	{"VSKE", 4, 236077},
	{"VPWI", 4, 236078},
	{"UOPI", 4, 236079},
	{"UOFG", 4, 236080},
	{"UGEX", 4, 236081},
	{"UFLY", 4, 236082},
	{"TYJI", 4, 236083},
	{"TIKV", 4, 236084},
	{"THDB", 4, 236085},
	{"SYKN", 4, 236086},
	{"SGSF", 4, 236087},
	{"RZOI", 4, 236088},
	{"RQAS", 4, 236089},
	{"RPEB", 4, 236090},
	{"RKUD", 4, 236091},
	{"RKIG", 4, 236092},
	{"RDUV", 4, 236093},
	{"PPUK", 4, 236094},
	{"PPBL", 4, 236095},
	{"PEZL", 4, 236096},
	{"OZEW", 4, 236097},
	{"ORRV", 4, 236098},
	{"OLTV", 4, 236099},
	{"OFBD", 4, 236100},
	{"NYDY", 4, 236101},
	{"NPFI", 4, 236102},
	{"NNBL", 4, 236103},
	{"NDXS", 4, 236104},
	{"LVAF", 4, 236105},
	{"LTZR", 4, 236106},
	{"JOTU", 4, 236107},
	{"JEEW", 4, 236108},
	{"IKGA", 4, 236109},
	{"HUOF", 4, 236110},
	{"HEQM", 4, 236111},
	{"GNQU", 4, 236112},
	{"GAGT", 4, 236113},
	{"FNIX", 4, 236114},
	{"EXYE", 4, 236115},
	{"ESWM", 4, 236116},
	{"ERVF", 4, 236117},
	{"ELMK", 4, 236118},
	{"DZHI", 4, 236119},
	{"DNSW", 4, 236120},
	{"DJRO", 4, 236121},
	{"CDSB", 4, 236122},
	{"BRYZ", 4, 236123},
	{"BMWT", 4, 236124},
	{"BMST", 4, 236125},
	{"BMID", 4, 236126},
	{"BMEL", 4, 236127},
	{"AYOY", 4, 236128},
	{"AKYD", 4, 236129},
	{"ABUU", 4, 236130},
	{"ABEQ", 4, 236131},
	{"AAJU", 4, 236132},
	{"AAFB", 4, 236133},
	{"BOREK", 5, 236134},
	{"TOORA", 5, 236135},
	{"BGF", 3, 236136},
	{"SURRATT", 7, 236137},
	{"OBERLANDER", 10, 236138},
	{"WOWNLOAD", 8, 236139},
	{"TROMS", 5, 236140},
	{"PLACERS", 7, 236141},
	{"MINESWEEPERS", 12, 236142},
	{"BOODA", 5, 236143},
	{"WHCIH", 5, 236144},
	{"ULAAN", 5, 236145},
	{"DISPUTABLE", 10, 236146},
	{"HYBRIDIZATIONS", 14, 236147},
	{"APRLL", 5, 236148},
	{"PHENTARMINE", 11, 236149},
	{"MERINGUES", 9, 236150},
	{"MADDENED", 8, 236151},
	{"IMPARCIALES", 11, 236152},
	{"AIRDROP", 7, 236153},
	{"YAHIO", 5, 236154},
	{"OKLINE", 6, 236155},
	{"IZDQIOFFER", 10, 236156},
	{"VASTER", 6, 236157},
	{"SHORTSLEEVE", 11, 236158},
	{"RUEDAS", 6, 236159},
	{"OLNY", 4, 236160},
	{"EVENTID", 7, 236161},
	{"TAMC", 4, 236162},
	{"PLAXICO", 7, 236163},
	{"FLORENTIN", 9, 236164},
	{"WABAUNSEE", 9, 236165},
	{"UNMAKING", 8, 236166},
	{"TUTELA", 6, 236167},
	{"TOWSLEY", 7, 236168},
	{"IMMOBILIZING", 12, 236169},
	{"ANHAND", 6, 236170},
	{"LEADLIGHT", 9, 236171},
	{"SPITZBERGEN", 11, 236172},
	{"TREVER", 6, 236173},
	{"SEETHE", 6, 236174},
	{"BEBINGTON", 9, 236175},
	{"WATERLILIES", 11, 236176},
	{"APONTE", 6, 236177},
	{"PASCHALL", 8, 236178},
	{"GILDERSLEEVE", 12, 236179},
	{"HYPERFOCAL", 10, 236180},
	{"CRIMINATION", 11, 236181},
	{"RENY", 4, 236182},
	{"CAPPEL", 6, 236183},
	{"CLAU", 4, 236184},
	{"MUQIC", 5, 236185},
	{"GRETTA", 6, 236186},
	{"LACEMAKING", 10, 236187},
	{"INTERBEDDED", 11, 236188},
	{"HAUPTMAN", 8, 236189},
	{"TAMERLANE", 9, 236190},
	{"SLOUCHED", 8, 236191},
	{"KERAMIDAS", 9, 236192},
	{"CORPUSCULAR", 11, 236193},
	{"SIROIS", 6, 236194},
	{"HEALTY", 6, 236195},
	{"DIECUTS", 7, 236196},
	{"REABSORBED", 10, 236197},
	{"PHENOMINAL", 10, 236198},
	{"UNRESTORED", 10, 236199},
	{"TOZZI", 5, 236200},
	{"TOPINKA", 7, 236201},
	{"ABLATED", 7, 236202},
	{"GIPSA", 5, 236203},
	{"CLASSIEST", 9, 236204},
	{"WIKIHELP", 8, 236205},
	{"LOKEY", 5, 236206},
	{"ELLADOS", 7, 236207},
	{"ACTBLUE", 7, 236208},
	{"LEMBIT", 6, 236209},
	{"HYGLOSS", 7, 236210},
	{"BLOGJET", 7, 236211},
	{"MRPHEUS", 7, 236212},
	{"AMERLCAN", 8, 236213},
	{"INSURA", 6, 236214},
	{"HUSIC", 5, 236215},
	{"ASHELY", 6, 236216},
	{"ORPHUS", 6, 236217},
	{"ONINOELECTRICAL", 15, 236218},
	{"KESHAV", 6, 236219},
	{"GETABSTRACT", 11, 236220},
	{"DOANLOADS", 9, 236221},
	{"DOWLNOADS", 9, 236222},
	{"CROPSEY", 7, 236223},
	{"GITTINS", 7, 236224},
	{"BLACKPLANET", 11, 236225},
	{"ARLEE", 5, 236226},
	{"REMONTER", 8, 236227},
	{"ONISHI", 6, 236228},
	{"MAPDANA", 7, 236229},
	{"DOWNOLADS", 9, 236230},
	{"DEODERANT", 9, 236231},
	{"PRITT", 5, 236232},
	{"PATROLMEN", 9, 236233},
	{"IDPB", 4, 236234},
	{"CHERCHEZ", 8, 236235},
	{"GLEIBERMAN", 10, 236236},
	{"CELAN", 5, 236237},
	{"ORIGINES", 8, 236238},
	{"EPIPHYTES", 9, 236239},
	{"ROOMSAVER", 9, 236240},
	{"HIRABAYASHI", 11, 236241},
	{"URBAINE", 7, 236242},
	{"STATSOFT", 8, 236243},
	{"PLSQL", 5, 236244},
	{"COCCIDIOIDOMYCOSIS", 18, 236245},
	{"GROTTA", 6, 236246},
	{"GLENORA", 7, 236247},
	{"GIRALDO", 7, 236248},
	{"FYSHWICK", 8, 236249},
	{"SISIR", 5, 236250},
	{"IMAGINA", 7, 236251},
	{"DIDATTICA", 9, 236252},
	{"BOOKLOVER", 9, 236253},
	{"WHITECROSS", 10, 236254},
	{"PRAJNA", 6, 236255},
	{"CLIFTY", 6, 236256},
	{"EFFAITH", 7, 236257},
	{"SCHEMATRON", 10, 236258},
	{"TEXTSIZE", 8, 236259},
	{"LASSITHI", 8, 236260},
	{"AGUINALDO", 9, 236261},
	{"BITNER", 6, 236262},
	{"SORROWING", 9, 236263},
	{"GARIS", 5, 236264},
	{"REVENIR", 7, 236265},
	{"GETFONT", 7, 236266},
	{"EPITHERMAL", 10, 236267},
	{"DESTRUCTING", 11, 236268},
	{"BURGHILL", 8, 236269},
	{"VELFORM", 7, 236270},
	{"THALASSIOSIRA", 13, 236271},
	{"STANBRIDGE", 10, 236272},
	{"GPSPASSION", 10, 236273},
	{"AGENTCONTACT", 12, 236274},
	{"COMEY", 5, 236275},
	{"MINEAR", 6, 236276},
	{"FANCOURT", 8, 236277},
	{"BLOGMAP", 7, 236278},
	{"GONAL", 5, 236279},
	{"TURISTA", 7, 236280},
	{"POLIN", 5, 236281},
	{"LNCEST", 6, 236282},
	{"ORARI", 5, 236283},
	{"AIRMINES", 8, 236284},
	{"WGL", 3, 236285},
	{"LIBFWBUILDER", 12, 236286},
	{"CHMP", 4, 236287},
	{"SYMBIONTS", 9, 236288},
	{"NITIX", 5, 236289},
	{"DETAILANSICHT", 13, 236290},
	{"KEYSVILLE", 9, 236291},
	{"GSMART", 6, 236292},
	{"WILLKIE", 7, 236293},
	{"GYMNOSPERMS", 11, 236294},
	{"FIORENZA", 8, 236295},
	{"ROGERIO", 7, 236296},
	{"SPERIMENTALE", 12, 236297},
	{"JENDL", 5, 236298},
	{"EMAILCOM", 8, 236299},
	{"WORDWIDE", 8, 236300},
	{"OUTSIDES", 8, 236301},
	{"TURNTABLIST", 11, 236302},
	{"HUGGETT", 7, 236303},
	{"DOLEZAL", 7, 236304},
	{"DOWNLOXD", 8, 236305},
	{"DODNLOAD", 8, 236306},
	{"PREMEDICATION", 13, 236307},
	{"HOHENZOLLERN", 12, 236308},
	{"SAWFLY", 6, 236309},
	{"PEOPME", 6, 236310},
	{"JASCHA", 6, 236311},
	{"STENOSES", 8, 236312},
	{"SPECULA", 7, 236313},
	{"RATEREAL", 8, 236314},
	{"OROCHI", 6, 236315},
	{"BLAIRMORE", 9, 236316},
	{"VANELLI", 7, 236317},
	{"CLASSIER", 8, 236318},
	{"NEERE", 5, 236319},
	{"MCLA", 4, 236320},
	{"EVERE", 5, 236321},
	{"SOSTENUTO", 9, 236322},
	{"ARISINGS", 8, 236323},
	{"BOYSEN", 6, 236324},
	{"PSEUDOPOTENTIAL", 15, 236325},
	{"PICOTTO", 7, 236326},
	{"CAFTAN", 6, 236327},
	{"PRESTIGIO", 9, 236328},
	{"KAMADA", 6, 236329},
	{"GITEX", 5, 236330},
	{"CUSTOS", 6, 236331},
	{"BRAZA", 5, 236332},
	{"BABBO", 5, 236333},
	{"ZOCH", 4, 236334},
	{"YLUP", 4, 236335},
	{"YDSM", 4, 236336},
	{"XBIG", 4, 236337},
	{"XBEH", 4, 236338},
	{"VOSG", 4, 236339},
	{"VADG", 4, 236340},
	{"UZLA", 4, 236341},
	{"UZHK", 4, 236342},
	{"USND", 4, 236343},
	{"UONW", 4, 236344},
	{"TZPE", 4, 236345},
	{"TUHL", 4, 236346},
	{"TUCD", 4, 236347},
	{"TEZC", 4, 236348},
	{"SRMI", 4, 236349},
	{"SOZZ", 4, 236350},
	{"RYGH", 4, 236351},
	{"RUUT", 4, 236352},
	{"RTDP", 4, 236353},
	{"RPKI", 4, 236354},
	{"RNOZ", 4, 236355},
	{"RNIQ", 4, 236356},
	{"PPEF", 4, 236357},
	{"OICB", 4, 236358},
	{"ODDK", 4, 236359},
	{"OBKO", 4, 236360},
	{"NTCF", 4, 236361},
	{"NLCH", 4, 236362},
	{"NIFK", 4, 236363},
	{"NDVP", 4, 236364},
	{"MRKL", 4, 236365},
	{"MNSM", 4, 236366},
	{"MNOU", 4, 236367},
	{"MLAZ", 4, 236368},
	{"LMYI", 4, 236369},
	{"LMSV", 4, 236370},
	{"LMPU", 4, 236371},
	{"LKOH", 4, 236372},
	{"LKEB", 4, 236373},
	{"LEZL", 4, 236374},
	{"LDKL", 4, 236375},
	{"KEIZ", 4, 236376},
	{"KDIM", 4, 236377},
	{"KAEP", 4, 236378},
	{"JIPE", 4, 236379},
	{"JHAL", 4, 236380},
	{"JERD", 4, 236381},
	{"INKZ", 4, 236382},
	{"IFGL", 4, 236383},
	{"HUEM", 4, 236384},
	{"HUDH", 4, 236385},
	{"HPSR", 4, 236386},
	{"GJRW", 4, 236387},
	{"GEKR", 4, 236388},
	{"FCSH", 4, 236389},
	{"ERVG", 4, 236390},
	{"DWWE", 4, 236391},
	{"DTVF", 4, 236392},
	{"DRLU", 4, 236393},
	{"DOXL", 4, 236394},
	{"DFCB", 4, 236395},
	{"CRYH", 4, 236396},
	{"CMPR", 4, 236397},
	{"CIBB", 4, 236398},
	{"CGIB", 4, 236399},
	{"CDOY", 4, 236400},
	{"BDEG", 4, 236401},
	{"AYZS", 4, 236402},
	{"ATZG", 4, 236403},
	{"AJIP", 4, 236404},
	{"ABSK", 4, 236405},
	{"TRIANGULATE", 11, 236406},
	{"INFLAMMATORIES", 14, 236407},
	{"GUATEMALANS", 11, 236408},
	{"CLONDALKIN", 10, 236409},
	{"EROTLC", 6, 236410},
	{"DYNAPOINT", 9, 236411},
	{"APELLIDO", 8, 236412},
	{"XFORM", 5, 236413},
	{"SKYMAX", 6, 236414},
	{"GETELEMENTSBYTAGNAME", 20, 236415},
	{"FAZENDA", 7, 236416},
	{"DPWNLOADS", 9, 236417},
	{"DEADLIFTS", 9, 236418},
	{"ARTBOOKS", 8, 236419},
	{"FIRESIGN", 8, 236420},
	{"AZPHP", 5, 236421},
	{"TELFROW", 7, 236422},
	{"PEROMYSCUS", 10, 236423},
	{"LOCUTUS", 7, 236424},
	{"GANONDORF", 9, 236425},
	{"BISPHOSPHONATE", 14, 236426},
	{"PETTEN", 6, 236427},
	{"MINEWORKERS", 11, 236428},
	{"GLAZEBROOK", 10, 236429},
	{"DOWNLOSDS", 9, 236430},
	{"DEVIENT", 7, 236431},
	{"ALUES", 5, 236432},
	{"INCON", 5, 236433},
	{"DLRECTORY", 9, 236434},
	{"CHELMER", 7, 236435},
	{"SCHIZOTYPAL", 11, 236436},
	{"VOLITIONS", 9, 236437},
	{"SONGNAME", 8, 236438},
	{"MDRS", 4, 236439},
	{"ROBUSTUS", 8, 236440},
	{"GRANDIOSITY", 11, 236441},
	{"INTERLEUKINS", 12, 236442},
	{"DREISSENA", 9, 236443},
	{"SPOC", 4, 236444},
	{"PFOPLE", 6, 236445},
	{"PEOPLEMEET", 10, 236446},
	{"NITRILES", 8, 236447},
	{"MORPHEIS", 8, 236448},
	{"CHAYKIN", 7, 236449},
	{"AUTHZ", 5, 236450},
	{"PCBA", 4, 236451},
	{"MOBILIER", 8, 236452},
	{"MILLAU", 6, 236453},
	{"HORSFORTH", 9, 236454},
	{"ECFMG", 5, 236455},
	{"EASYASK", 7, 236456},
	{"CORROSIVES", 10, 236457},
	{"BERNET", 6, 236458},
	{"ALUS", 4, 236459},
	{"HERERO", 6, 236460},
	{"CONIL", 5, 236461},
	{"BRIGGLE", 7, 236462},
	{"AIRBEDS", 7, 236463},
	{"MYY", 3, 236464},
	{"CFHT", 4, 236465},
	{"MERAN", 5, 236466},
	{"LKCD", 4, 236467},
	{"DOENLOADS", 9, 236468},
	{"ZALMAY", 6, 236469},
	{"TOEGEVOEGD", 10, 236470},
	{"DOUBLESCAN", 10, 236471},
	{"BROOMHILL", 9, 236472},
	{"PREVIEWHUT", 10, 236473},
	{"DOWNOOADS", 9, 236474},
	{"CAJAMARCA", 9, 236475},
	{"WAILPAPER", 9, 236476},
	{"OUSSY", 5, 236477},
	{"LIBBIE", 6, 236478},
	{"LEDOYEN", 7, 236479},
	{"EDINGTON", 8, 236480},
	{"BESOM", 5, 236481},
	{"SILVERSTREAM", 12, 236482},
	{"SCULLEY", 7, 236483},
	{"MOTHERSON", 9, 236484},
	{"OCIFETCH", 8, 236485},
	{"CHXT", 4, 236486},
	{"MOEDER", 6, 236487},
	{"BAJAN", 5, 236488},
	{"DOWNKOADS", 9, 236489},
	{"DIWNLOADS", 9, 236490},
	{"STEFAAN", 7, 236491},
	{"ROCHEFOUCAULD", 13, 236492},
	{"MOPRHEUS", 8, 236493},
	{"MISSIE", 6, 236494},
	{"GLENEAGLE", 9, 236495},
	{"EXULTANT", 8, 236496},
	{"COLORPAD", 8, 236497},
	{"YEILOW", 6, 236498},
	{"WETENSCHAPPELIJK", 16, 236499},
	{"SUBBA", 5, 236500},
	{"MOROHEUS", 8, 236501},
	{"GIGANTOR", 8, 236502},
	{"EZONE", 5, 236503},
	{"SEMPAI", 6, 236504},
	{"RIITTA", 6, 236505},
	{"MISSIOLOGY", 10, 236506},
	{"SIRHAN", 6, 236507},
	{"SHALA", 5, 236508},
	{"RIPARIA", 7, 236509},
	{"RIGHTCLICK", 10, 236510},
	{"CHISOLM", 7, 236511},
	{"CHANNAHON", 9, 236512},
	{"BRUNY", 5, 236513},
	{"MVNOS", 5, 236514},
	{"BRLTNEY", 7, 236515},
	{"ROWCOUNT", 8, 236516},
	{"RONIT", 5, 236517},
	{"PARTYGOERS", 10, 236518},
	{"DOQNLOADS", 9, 236519},
	{"KOCHAN", 6, 236520},
	{"DKWNLOADS", 9, 236521},
	{"DENSHI", 6, 236522},
	{"CARBAMIDE", 9, 236523},
	{"GOALLESS", 8, 236524},
	{"ENGLNES", 7, 236525},
	{"DOWNLOADW", 9, 236526},
	{"DOWHLOADS", 9, 236527},
	{"ABUTILON", 8, 236528},
	{"VVC", 3, 236529},
	{"PICTUWES", 8, 236530},
	{"PARAMETERISED", 13, 236531},
	{"DLWNLOADS", 9, 236532},
	{"DJUKANOVIC", 10, 236533},
	{"WLNZIP", 6, 236534},
	{"SUPERAMERICA", 12, 236535},
	{"RICHARDP", 8, 236536},
	{"DOWJLOADS", 9, 236537},
	{"CHAINREACTION", 13, 236538},
	{"BERD", 4, 236539},
	{"AIRIINE", 7, 236540},
	{"SELFCATERING", 12, 236541},
	{"LARABIE", 7, 236542},
	{"DOWNLOZDS", 9, 236543},
	{"CSONKA", 6, 236544},
	{"SPLATT", 6, 236545},
	{"INSTDIR", 7, 236546},
	{"FINDATA", 7, 236547},
	{"WORKSTATIONPLANET", 17, 236548},
	{"DOWNPOADS", 9, 236549},
	{"DOWNLOQDS", 9, 236550},
	{"DOSNLOADS", 9, 236551},
	{"DERBIES", 7, 236552},
	{"TIGEREYE", 8, 236553},
	{"PRODID", 6, 236554},
	{"METALHEADZ", 10, 236555},
	{"LOLLTA", 6, 236556},
	{"STALNAKER", 9, 236557},
	{"SPRAWLS", 7, 236558},
	{"SCHLUND", 7, 236559},
	{"EUROPHOTONICS", 13, 236560},
	{"CODDLING", 8, 236561},
	{"PILFERING", 9, 236562},
	{"APRII", 5, 236563},
	{"AMPLANDCOM", 10, 236564},
	{"UOUS", 4, 236565},
	{"POSUERE", 7, 236566},
	{"DOWNLOXDS", 9, 236567},
	{"DODNLOADS", 9, 236568},
	{"CORLESS", 7, 236569},
	{"ILYAS", 5, 236570},
	{"CCREENSAVERS", 12, 236571},
	{"DIPTHERIA", 9, 236572},
	{"ARBON", 5, 236573},
	{"VERSTUUR", 8, 236574},
	{"OMNIQUAD", 8, 236575},
	{"NOCTURNA", 8, 236576},
	{"MOTOKO", 6, 236577},
	{"CUSED", 5, 236578},
	{"UDWADIA", 7, 236579},
	{"SCHEMALOCATION", 14, 236580},
	{"METAMORPHOSE", 12, 236581},
	{"GAHES", 5, 236582},
	{"DEVILLERS", 9, 236583},
	{"COWBIRDS", 8, 236584},
	{"PACKETIZATION", 13, 236585},
	{"KAARTJE", 7, 236586},
	{"ARTIKELNUMMER", 13, 236587},
	{"MICROPHYSICAL", 13, 236588},
	{"LABUTE", 6, 236589},
	{"GUNNERSON", 9, 236590},
	{"CLIPAGT", 7, 236591},
	{"BALENO", 6, 236592},
	{"SCREENSSVERS", 12, 236593},
	{"CLIPXRT", 7, 236594},
	{"BENAJARAFE", 10, 236595},
	{"TURQ", 4, 236596},
	{"PIAYBOY", 7, 236597},
	{"MULLAHY", 7, 236598},
	{"AMOUT", 5, 236599},
	{"IJAZ", 4, 236600},
	{"DOWNLOADC", 9, 236601},
	{"APLICATIONS", 11, 236602},
	{"CROSSLINE", 9, 236603},
	{"WOWNLOADS", 9, 236604},
	{"SCEEENSAVERS", 12, 236605},
	{"RCCA", 4, 236606},
	{"AMPIAND", 7, 236607},
	{"TOSCHI", 6, 236608},
	{"CHIUSI", 6, 236609},
	{"DAEMONTOOLS", 11, 236610},
	{"TATMADAW", 8, 236611},
	{"MIRRORDIR", 9, 236612},
	{"FPDI", 4, 236613},
	{"DEPHASING", 9, 236614},
	{"VOLF", 4, 236615},
	{"MICROGRAPHIC", 12, 236616},
	{"HARDWAY", 7, 236617},
	{"FAIW", 4, 236618},
	{"CPRESB", 6, 236619},
	{"CLIPARH", 7, 236620},
	{"TEXTER", 6, 236621},
	{"DAISHONIN", 9, 236622},
	{"CONSULTARE", 10, 236623},
	{"TAINLY", 6, 236624},
	{"ODWNLOADS", 9, 236625},
	{"KAZUMI", 6, 236626},
	{"FLFL", 4, 236627},
	{"SCERENSAVERS", 12, 236628},
	{"IDYLLS", 6, 236629},
	{"DATASTAR", 8, 236630},
	{"SCTEENSAVERS", 12, 236631},
	{"SCREENSQVERS", 12, 236632},
	{"FOLLANSBEE", 10, 236633},
	{"CEFNOGI", 7, 236634},
	{"TROUSSEAU", 9, 236635},
	{"SCREENSABERS", 12, 236636},
	{"ENGLIS", 6, 236637},
	{"SCREENSAEVRS", 12, 236638},
	{"MORPHRUS", 8, 236639},
	{"CONCOCTING", 10, 236640},
	{"MASEK", 5, 236641},
	{"IOLITA", 6, 236642},
	{"BOTOLPH", 7, 236643},
	{"SCREESNAVERS", 12, 236644},
	{"KNIPE", 5, 236645},
	{"GUILFEST", 8, 236646},
	{"EGRAVE", 6, 236647},
	{"BUMPERSTICKER", 13, 236648},
	{"ACTIVIES", 8, 236649},
	{"SCREENSZVERS", 12, 236650},
	{"SCFEENSAVERS", 12, 236651},
	{"PSDS", 4, 236652},
	{"NORPHEUS", 8, 236653},
	{"FOOIS", 5, 236654},
	{"BOGON", 5, 236655},
	{"ATECO", 5, 236656},
	{"SDREENSAVERS", 12, 236657},
	{"MONKEYING", 9, 236658},
	{"MOGGERS", 7, 236659},
	{"FINGERPLAYS", 11, 236660},
	{"BALLENA", 7, 236661},
	{"IINGERIE", 8, 236662},
	{"WINETEST", 8, 236663},
	{"SITRA", 5, 236664},
	{"PPAS", 4, 236665},
	{"SCREEHSAVERS", 12, 236666},
	{"LLNGERIE", 8, 236667},
	{"LEGITIMATED", 11, 236668},
	{"GLENNS", 6, 236669},
	{"FXIR", 4, 236670},
	{"TALOS", 5, 236671},
	{"STORIFS", 7, 236672},
	{"SFREENSAVERS", 12, 236673},
	{"PUERMA", 6, 236674},
	{"PAGFS", 5, 236675},
	{"NIVICO", 6, 236676},
	{"MIRPHEUS", 8, 236677},
	{"LOKIER", 6, 236678},
	{"ISOPTO", 6, 236679},
	{"FRISSON", 7, 236680},
	{"SAVANAH", 7, 236681},
	{"VOWNLOAD", 8, 236682},
	{"SCREENSAGERS", 12, 236683},
	{"SCREEJSAVERS", 12, 236684},
	{"MISHAEL", 7, 236685},
	{"ANCOVA", 6, 236686},
	{"MORPHEYS", 8, 236687},
	{"LEXIQUE", 7, 236688},
	{"LANZI", 5, 236689},
	{"FRIEZES", 7, 236690},
	{"LOLLTAS", 7, 236691},
	{"LIMOSA", 6, 236692},
	{"TOPOINDEX", 9, 236693},
	{"SCREENSWVERS", 12, 236694},
	{"RATGEBER", 8, 236695},
	{"AVCANADA", 8, 236696},
	{"ICPP", 4, 236697},
	{"GREEHING", 8, 236698},
	{"SXREENSAVERS", 12, 236699},
	{"GRFETING", 8, 236700},
	{"MORPHEUD", 8, 236701},
	{"ELIXER", 6, 236702},
	{"MPRPHEUS", 8, 236703},
	{"GGEETING", 8, 236704},
	{"SPRADLIN", 8, 236705},
	{"DOMINICI", 8, 236706},
	{"MROPHEUS", 8, 236707},
	{"MCBRYDE", 7, 236708},
	{"PLAYSFORSURE", 12, 236709},
	{"WADO", 4, 236710},
	{"MELLETTE", 8, 236711},
	{"MEBEST", 6, 236712},
	{"VOWNLOADS", 9, 236713},
	{"SAFILO", 6, 236714},
	{"MOEPHEUS", 8, 236715},
	{"IITEROTICA", 10, 236716},
	{"BAARS", 5, 236717},
	{"SSIDS", 5, 236718},
	{"LLTEROTICA", 10, 236719},
	{"HOTMAII", 7, 236720},
	{"DOWNMOAD", 8, 236721},
	{"ZIAG", 4, 236722},
	{"ZHAG", 4, 236723},
	{"ZEML", 4, 236724},
	{"YYAA", 4, 236725},
	{"YRSW", 4, 236726},
	{"YPLY", 4, 236727},
	{"YAEU", 4, 236728},
	{"XUSW", 4, 236729},
	{"WLWO", 4, 236730},
	{"VFAM", 4, 236731},
	{"VCIT", 4, 236732},
	{"UTCF", 4, 236733},
	{"UJUE", 4, 236734},
	{"TSPD", 4, 236735},
	{"TPFO", 4, 236736},
	{"TCUW", 4, 236737},
	{"TAYV", 4, 236738},
	{"SKUH", 4, 236739},
	{"SDUH", 4, 236740},
	{"RUNQ", 4, 236741},
	{"RUAG", 4, 236742},
	{"RRFI", 4, 236743},
	{"RIKJ", 4, 236744},
	{"RGOK", 4, 236745},
	{"RFTE", 4, 236746},
	{"RCKM", 4, 236747},
	{"RCEQ", 4, 236748},
	{"PUPG", 4, 236749},
	{"PRCI", 4, 236750},
	{"PMGO", 4, 236751},
	{"PLFO", 4, 236752},
	{"PHPL", 4, 236753},
	{"PBIR", 4, 236754},
	{"OMCF", 4, 236755},
	{"OKND", 4, 236756},
	{"NUSZ", 4, 236757},
	{"NURR", 4, 236758},
	{"NUGU", 4, 236759},
	{"NILB", 4, 236760},
	{"NGHL", 4, 236761},
	{"NGHJ", 4, 236762},
	{"NCVI", 4, 236763},
	{"MDOH", 4, 236764},
	{"LMUK", 4, 236765},
	{"LLSZ", 4, 236766},
	{"LCIE", 4, 236767},
	{"LAIY", 4, 236768},
	{"KYNY", 4, 236769},
	{"KPAW", 4, 236770},
	{"KOWR", 4, 236771},
	{"KMYA", 4, 236772},
	{"KHEU", 4, 236773},
	{"IOBV", 4, 236774},
	{"HYLS", 4, 236775},
	{"HMPR", 4, 236776},
	{"HCBC", 4, 236777},
	{"GMRC", 4, 236778},
	{"GMNE", 4, 236779},
	{"FZAP", 4, 236780},
	{"FIBN", 4, 236781},
	{"EVTR", 4, 236782},
	{"EUFL", 4, 236783},
	{"EJIB", 4, 236784},
	{"DGAW", 4, 236785},
	{"COXM", 4, 236786},
	{"CODM", 4, 236787},
	{"BYXA", 4, 236788},
	{"AUJA", 4, 236789},
	{"GNITEERG", 8, 236790},
	{"BRIGHTFIELD", 11, 236791},
	{"NREETING", 8, 236792},
	{"INFIMUM", 7, 236793},
	{"FASTJAR", 7, 236794},
	{"PERFECTIONISTS", 14, 236795},
	{"MIVIE", 5, 236796},
	{"WILLHELM", 8, 236797},
	{"TRAPILC", 7, 236798},
	{"SANGAKKARA", 10, 236799},
	{"JORPHEUS", 8, 236800},
	{"IOLITAS", 7, 236801},
	{"ANONYMIZED", 10, 236802},
	{"TRIPREWARDS", 11, 236803},
	{"PINTLE", 6, 236804},
	{"PHETERAMINE", 11, 236805},
	{"OMRPHEUS", 8, 236806},
	{"KORPHEUS", 8, 236807},
	{"TOMSNETWORKING", 14, 236808},
	{"CBRE", 4, 236809},
	{"MORPGEUS", 8, 236810},
	{"CMIPART", 7, 236811},
	{"BROOKHOLLOW", 11, 236812},
	{"AIRLIGES", 8, 236813},
	{"SPINOUT", 7, 236814},
	{"PATING", 6, 236815},
	{"ORCHESTRATES", 12, 236816},
	{"MORPHWUS", 8, 236817},
	{"GWEETING", 8, 236818},
	{"MOTPHEUS", 8, 236819},
	{"MORPHEUA", 8, 236820},
	{"DARO", 4, 236821},
	{"AIWLINES", 8, 236822},
	{"OFMEET", 6, 236823},
	{"IYRIC", 5, 236824},
	{"EBGAMES", 7, 236825},
	{"QUIERY", 6, 236826},
	{"MORPUEUS", 8, 236827},
	{"DCSS", 4, 236828},
	{"CJL", 3, 236829},
	{"XMLSUBSCRIBE", 12, 236830},
	{"NASUTRA", 7, 236831},
	{"HARDCOURT", 9, 236832},
	{"DOWKLOAD", 8, 236833},
	{"AIRLIKES", 8, 236834},
	{"UNIXES", 6, 236835},
	{"SPRINTPCS", 9, 236836},
	{"MORPHSUS", 8, 236837},
	{"DOWNMOADS", 9, 236838},
	{"DOWGLOAD", 8, 236839},
	{"BALTASAR", 8, 236840},
	{"NIEKRO", 6, 236841},
	{"MORPNEUS", 8, 236842},
	{"MORPHEJS", 8, 236843},
	{"MORPHDUS", 8, 236844},
	{"HORPHEUS", 8, 236845},
	{"GREETIGG", 8, 236846},
	{"SIARAD", 6, 236847},
	{"MORPJEUS", 8, 236848},
	{"MORPHEHS", 8, 236849},
	{"MOFPHEUS", 8, 236850},
	{"MICROBAN", 8, 236851},
	{"INDECOMPOSABLE", 14, 236852},
	{"FRAISER", 7, 236853},
	{"ANSALDO", 7, 236854},
	{"SPARGING", 8, 236855},
	{"MORPYEUS", 8, 236856},
	{"MORPHEUW", 8, 236857},
	{"MLRPHEUS", 8, 236858},
	{"KASHIWAGI", 9, 236859},
	{"BMK", 3, 236860},
	{"MORPHEUE", 8, 236861},
	{"MORPBEUS", 8, 236862},
	{"GREETIKG", 8, 236863},
	{"EXCALIBER", 9, 236864},
	{"EICHENBAUM", 10, 236865},
	{"DOWKLOADS", 9, 236866},
	{"CLIPAWT", 7, 236867},
	{"MORLHEUS", 8, 236868},
	{"DOWGLOADS", 9, 236869},
	{"MKRPHEUS", 8, 236870},
	{"JOKAROO", 7, 236871},
	{"DCAM", 4, 236872},
	{"VILLAFRANCA", 11, 236873},
	{"VASODILATATION", 14, 236874},
	{"DOWNLOADQ", 9, 236875},
	{"BOMBESIN", 8, 236876},
	{"SUPERTONES", 10, 236877},
	{"MORPTEUS", 8, 236878},
	{"KELLUM", 6, 236879},
	{"FLORIANA", 8, 236880},
	{"BPAS", 4, 236881},
	{"BELLSON", 7, 236882},
	{"KAIKKI", 6, 236883},
	{"CHIMAY", 6, 236884},
	{"MORPHFUS", 8, 236885},
	{"MOGPHEUS", 8, 236886},
	{"PARLIA", 6, 236887},
	{"MOWPHEUS", 8, 236888},
	{"MORPMEUS", 8, 236889},
	{"MORPHEUQ", 8, 236890},
	{"ABUELAS", 7, 236891},
	{"POWERBUTTER", 11, 236892},
	{"LORPHEUS", 8, 236893},
	{"LEPIDIUM", 8, 236894},
	{"EUPEDIA", 7, 236895},
	{"POPLARVILLE", 11, 236896},
	{"MORPHEUC", 8, 236897},
	{"MORPHEKS", 8, 236898},
	{"KLASSISCHE", 10, 236899},
	{"UNCONQUERED", 11, 236900},
	{"MCCALLIE", 8, 236901},
	{"LOVAT", 5, 236902},
	{"COSMOLOGISTS", 12, 236903},
	{"LYRLC", 5, 236904},
	{"GOOSEMOOSE", 10, 236905},
	{"FARCES", 6, 236906},
	{"UNSHIFT", 7, 236907},
	{"TAINABLE", 8, 236908},
	{"MIMMINA", 7, 236909},
	{"ACTUALITIES", 11, 236910},
	{"WINHEC", 6, 236911},
	{"UUB", 3, 236912},
	{"LOVEL", 5, 236913},
	{"SHWONLINE", 9, 236914},
	{"PUFFERS", 7, 236915},
	{"YOWERI", 6, 236916},
	{"ANANDAMIDE", 10, 236917},
	{"TUOMO", 5, 236918},
	{"PRADOS", 6, 236919},
	{"ITHINK", 6, 236920},
	{"ARBER", 5, 236921},
	{"DELPHIN", 7, 236922},
	{"SOFTSPIKES", 10, 236923},
	{"SAIKO", 5, 236924},
	{"GQME", 4, 236925},
	{"COLYTON", 7, 236926},
	{"RELIABILITIES", 13, 236927},
	{"SPASSKY", 7, 236928},
	{"CHANTIER", 8, 236929},
	{"WITZEL", 6, 236930},
	{"PSEUDOTUBERCULOSIS", 18, 236931},
	{"RCAS", 4, 236932},
	{"CONNU", 5, 236933},
	{"BASATO", 6, 236934},
	{"NORSCOT", 7, 236935},
	{"BISSONNETTE", 11, 236936},
	{"RICHBORO", 8, 236937},
	{"KERS", 4, 236938},
	{"DILLE", 5, 236939},
	{"TRIMM", 5, 236940},
	{"LOLIDUS", 7, 236941},
	{"UPPAL", 5, 236942},
	{"ETHERNETWORK", 12, 236943},
	{"PETROFF", 7, 236944},
	{"FUSNES", 6, 236945},
	{"BESTRATE", 8, 236946},
	{"REPAI", 5, 236947},
	{"DEVNEWS", 7, 236948},
	{"BALIKPAPAN", 10, 236949},
	{"ASTROFISICA", 11, 236950},
	{"WIREDRED", 8, 236951},
	{"NAVARRETE", 9, 236952},
	{"LIBQUAL", 7, 236953},
	{"AULTMAN", 7, 236954},
	{"ROSEBORO", 8, 236955},
	{"PETROSIAN", 9, 236956},
	{"MICKEL", 6, 236957},
	{"VECTORLINUX", 11, 236958},
	{"UNCLEANED", 9, 236959},
	{"CRYP", 4, 236960},
	{"DISASSOCIATION", 14, 236961},
	{"SUPERLITE", 9, 236962},
	{"PERJURED", 8, 236963},
	{"IMPOSSIBILE", 11, 236964},
	{"HOGSMEADE", 9, 236965},
	{"FRUITWOOD", 9, 236966},
	{"KAGAME", 6, 236967},
	{"RISKIN", 6, 236968},
	{"PICURE", 6, 236969},
	{"LEVITICAL", 9, 236970},
	{"HOULT", 5, 236971},
	{"WAITARA", 7, 236972},
	{"LIBERALOASIS", 12, 236973},
	{"JFP", 3, 236974},
	{"THETOP", 6, 236975},
	{"ABOX", 4, 236976},
	{"GOOKS", 5, 236977},
	{"STRINGIO", 8, 236978},
	{"PARAGLIDERS", 11, 236979},
	{"INTERSHIPS", 10, 236980},
	{"TUDALENNAU", 10, 236981},
	{"RVW", 3, 236982},
	{"TRAER", 5, 236983},
	{"GERACI", 6, 236984},
	{"LIQUIGAS", 8, 236985},
	{"HANDPIECES", 10, 236986},
	{"ACHONDROPLASIA", 14, 236987},
	{"VALCOMPAGINGPRODUCTS", 20, 236988},
	{"MEDIBANK", 8, 236989},
	{"IMLIVE", 6, 236990},
	{"SDPHP", 5, 236991},
	{"SPELLEN", 7, 236992},
	{"SHAMANISTIC", 11, 236993},
	{"SALEK", 5, 236994},
	{"MAPPACK", 7, 236995},
	{"BANDAIDS", 8, 236996},
	{"NELLES", 6, 236997},
	{"CONFIANZA", 9, 236998},
	{"WUJIANG", 7, 236999},
	{"SERUTCIP", 8, 237000},
	{"NISIM", 5, 237001},
	{"FASTBLOGIT", 10, 237002},
	{"POONAWALLA", 10, 237003},
	{"GITAR", 5, 237004},
	{"FERMOY", 6, 237005},
	{"DATABASEJOURNAL", 15, 237006},
	{"TELEFONICO", 10, 237007},
	{"SKIFFLE", 7, 237008},
	{"AKTIVIEREN", 10, 237009},
	{"SCRRENSAVERS", 12, 237010},
	{"GOGEL", 5, 237011},
	{"COWPOKE", 7, 237012},
	{"ATTONEY", 7, 237013},
	{"MYHOUSE", 7, 237014},
	{"HISPAVISTA", 10, 237015},
	{"DATAGRIDVIEW", 12, 237016},
	{"UNNECCESSARY", 12, 237017},
	{"OVERCLOCKIX", 11, 237018},
	{"NOTTEBROCK", 10, 237019},
	{"NISHIOKA", 8, 237020},
	{"KARSTADT", 8, 237021},
	{"SEEKE", 5, 237022},
	{"MENDONCA", 8, 237023},
	{"ELOPED", 6, 237024},
	{"SLIPART", 7, 237025},
	{"FDCPA", 5, 237026},
	{"ESTERN", 6, 237027},
	{"KVCD", 4, 237028},
	{"FELDENE", 7, 237029},
	{"STIGMATIZING", 12, 237030},
	{"LUTTIG", 6, 237031},
	{"GOUVERNANCE", 11, 237032},
	{"ADVOCARE", 8, 237033},
	{"SAMOSAS", 7, 237034},
	{"CORPUSCLES", 10, 237035},
	{"KILBIRNIE", 9, 237036},
	{"ARBAT", 5, 237037},
	{"YAHHOO", 6, 237038},
	{"THERMOCHEMISTRY", 15, 237039},
	{"ANTHRACYCLINE", 13, 237040},
	{"MCGAUGHEY", 9, 237041},
	{"HABURI", 6, 237042},
	{"FAVORITIES", 10, 237043},
	{"JOLANDA", 7, 237044},
	{"WSMV", 4, 237045},
	{"VENTOUX", 7, 237046},
	{"NPROTECT", 8, 237047},
	{"VASILIS", 7, 237048},
	{"OPOLE", 5, 237049},
	{"ACDBXRECORD", 11, 237050},
	{"UNAWARENESS", 11, 237051},
	{"RECVFROM", 8, 237052},
	{"NEOPORTALS", 10, 237053},
	{"TAHERI", 6, 237054},
	{"AUTOTROPHIC", 11, 237055},
	{"ARIANNU", 7, 237056},
	{"POMER", 5, 237057},
	{"KUNIN", 5, 237058},
	{"ZSUP", 4, 237059},
	{"YDRG", 4, 237060},
	{"XAPO", 4, 237061},
	{"VSBL", 4, 237062},
	{"VOAR", 4, 237063},
	{"UMNG", 4, 237064},
	{"UIOC", 4, 237065},
	{"UIKA", 4, 237066},
	{"TUDU", 4, 237067},
	{"TLUO", 4, 237068},
	{"REUV", 4, 237069},
	{"PPYK", 4, 237070},
	{"PPBA", 4, 237071},
	{"OWZO", 4, 237072},
	{"OVFA", 4, 237073},
	{"OLPT", 4, 237074},
	{"OERF", 4, 237075},
	{"NZEK", 4, 237076},
	{"NPSU", 4, 237077},
	{"NGWC", 4, 237078},
	{"NAYP", 4, 237079},
	{"MYGD", 4, 237080},
	{"LMBI", 4, 237081},
	{"LLUF", 4, 237082},
	{"KUTR", 4, 237083},
	{"KIPJ", 4, 237084},
	{"KEGM", 4, 237085},
	{"KAKR", 4, 237086},
	{"IZLI", 4, 237087},
	{"ILTK", 4, 237088},
	{"IEVR", 4, 237089},
	{"IDDT", 4, 237090},
	{"HPWH", 4, 237091},
	{"HMTV", 4, 237092},
	{"GMAV", 4, 237093},
	{"GGDI", 4, 237094},
	{"GGAF", 4, 237095},
	{"GADZ", 4, 237096},
	{"FZHE", 4, 237097},
	{"FYUC", 4, 237098},
	{"FNED", 4, 237099},
	{"FDYE", 4, 237100},
	{"EYFC", 4, 237101},
	{"EWYR", 4, 237102},
	{"EPAZ", 4, 237103},
	{"EOLF", 4, 237104},
	{"EDLH", 4, 237105},
	{"ECTZ", 4, 237106},
	{"DUHI", 4, 237107},
	{"DPEB", 4, 237108},
	{"DNDC", 4, 237109},
	{"DAPD", 4, 237110},
	{"CDED", 4, 237111},
	{"BUDN", 4, 237112},
	{"BRSE", 4, 237113},
	{"BPRA", 4, 237114},
	{"AUMD", 4, 237115},
	{"ALNW", 4, 237116},
	{"RPMSEEK", 7, 237117},
	{"QTORIES", 7, 237118},
	{"PRICEMAD", 8, 237119},
	{"HARSHMAN", 8, 237120},
	{"LJP", 3, 237121},
	{"ELOCON", 6, 237122},
	{"CLONALITY", 9, 237123},
	{"BERNEY", 6, 237124},
	{"YOBBO", 5, 237125},
	{"RONNING", 7, 237126},
	{"OBSCURELY", 9, 237127},
	{"HYDROMASSAGE", 12, 237128},
	{"DREAMLESS", 9, 237129},
	{"REPAIRMEN", 9, 237130},
	{"MEDIAMAX", 8, 237131},
	{"SYNODAL", 7, 237132},
	{"MCCC", 4, 237133},
	{"TAGLIA", 6, 237134},
	{"PARGA", 5, 237135},
	{"GELLES", 6, 237136},
	{"PXGES", 5, 237137},
	{"PENETRATORS", 11, 237138},
	{"ASTRONOMICS", 11, 237139},
	{"KALINOWSKI", 10, 237140},
	{"FESTOOL", 7, 237141},
	{"RECLPES", 7, 237142},
	{"PAREVE", 6, 237143},
	{"DAYCARES", 8, 237144},
	{"SILKSCREENED", 12, 237145},
	{"SCREENSHOTSCREENSHOT", 20, 237146},
	{"OMSCHRIJVING", 12, 237147},
	{"MISCHEL", 7, 237148},
	{"LEEDER", 6, 237149},
	{"GRAYCLIFF", 9, 237150},
	{"FUJIMURA", 8, 237151},
	{"DEWOLFE", 7, 237152},
	{"COPENH", 6, 237153},
	{"RIAF", 4, 237154},
	{"QCIENCE", 7, 237155},
	{"CHEAPERTHANHOTELS", 17, 237156},
	{"SCHULT", 6, 237157},
	{"HUCKSTERS", 9, 237158},
	{"NEHER", 5, 237159},
	{"DADURCH", 7, 237160},
	{"NIZAR", 5, 237161},
	{"LINHART", 7, 237162},
	{"JOSEPHA", 7, 237163},
	{"PNTXTB", 6, 237164},
	{"PEOTONE", 7, 237165},
	{"BLACKLOCK", 9, 237166},
	{"URUBAMBA", 8, 237167},
	{"SOMMELIERS", 10, 237168},
	{"LAMELY", 6, 237169},
	{"ELKLAND", 7, 237170},
	{"DUPLA", 5, 237171},
	{"NEUHERBERG", 10, 237172},
	{"TODARO", 6, 237173},
	{"SPORTCRAFT", 10, 237174},
	{"MENTA", 5, 237175},
	{"CAREERMAG", 9, 237176},
	{"VIRTUALCENTER", 13, 237177},
	{"REFORMANET", 10, 237178},
	{"LEETE", 5, 237179},
	{"EXERGY", 6, 237180},
	{"SALEPHENTERMINE", 15, 237181},
	{"QUANTISATION", 12, 237182},
	{"AVAILABL", 8, 237183},
	{"MACHEL", 6, 237184},
	{"LOVANO", 6, 237185},
	{"ANZSIC", 6, 237186},
	{"ABDURRAHMAN", 11, 237187},
	{"BIOCLUSTERS", 11, 237188},
	{"YAMANOUCHI", 10, 237189},
	{"SPLASHPLASTIC", 13, 237190},
	{"CREMERS", 7, 237191},
	{"TOPNEWS", 7, 237192},
	{"ECONNECT", 8, 237193},
	{"CURDLED", 7, 237194},
	{"CATEGO", 6, 237195},
	{"BANDMATE", 8, 237196},
	{"SEEKLYRICS", 10, 237197},
	{"CLASSIFICHE", 11, 237198},
	{"LAMPTON", 7, 237199},
	{"MANUTENZIONE", 12, 237200},
	{"FINEDRIVE", 9, 237201},
	{"GENARES", 7, 237202},
	{"FEYERABEND", 10, 237203},
	{"SUBPIXEL", 8, 237204},
	{"MENOUNOS", 8, 237205},
	{"BENVENISTE", 10, 237206},
	{"ASESIAD", 7, 237207},
	{"URLCOLLECTION", 13, 237208},
	{"LARVIK", 6, 237209},
	{"GODINGER", 8, 237210},
	{"MICROENTERPRISES", 16, 237211},
	{"DEVALUES", 8, 237212},
	{"MASSPORT", 8, 237213},
	{"WESTPHALIAN", 11, 237214},
	{"OOKER", 5, 237215},
	{"JAMAHI", 6, 237216},
	{"PROLOTHERAPY", 12, 237217},
	{"ACROSOME", 8, 237218},
	{"POWDERCOAT", 10, 237219},
	{"METASTASIZED", 12, 237220},
	{"GEOCONNECTIONS", 14, 237221},
	{"SCHOON", 6, 237222},
	{"ROADERS", 7, 237223},
	{"LOBBING", 7, 237224},
	{"SNECMA", 6, 237225},
	{"CAROTA", 6, 237226},
	{"PACAF", 5, 237227},
	{"WIKIVERSITY", 11, 237228},
	{"IDALIA", 6, 237229},
	{"FELDT", 5, 237230},
	{"UNRESPONSIVENESS", 16, 237231},
	{"THRUN", 5, 237232},
	{"SATELIT", 7, 237233},
	{"MAINLOOP", 8, 237234},
	{"TARRANI", 7, 237235},
	{"CREEM", 5, 237236},
	{"ANONY", 5, 237237},
	{"AADC", 4, 237238},
	{"SHARPVISION", 11, 237239},
	{"LOGRONO", 7, 237240},
	{"KHALDUN", 7, 237241},
	{"YISHUN", 6, 237242},
	{"FLEXBETA", 8, 237243},
	{"DIPEPTIDYL", 10, 237244},
	{"INTERBREW", 9, 237245},
	{"HUEYTOWN", 8, 237246},
	{"HORRELL", 7, 237247},
	{"QCREENSAVERS", 12, 237248},
	{"PHARMALOGIC", 11, 237249},
	{"HELPCENTER", 10, 237250},
	{"SHELLWM", 7, 237251},
	{"ARCU", 4, 237252},
	{"PREDIGESTED", 11, 237253},
	{"OFERTE", 6, 237254},
	{"IMMUNOLOGIST", 12, 237255},
	{"BIBLETIME", 9, 237256},
	{"PACKHAM", 7, 237257},
	{"KINDY", 5, 237258},
	{"TOTALFINAELF", 12, 237259},
	{"PAPUR", 5, 237260},
	{"STOWIES", 7, 237261},
	{"PULLUPS", 7, 237262},
	{"LAPPE", 5, 237263},
	{"RLNGS", 5, 237264},
	{"CREEPIEST", 9, 237265},
	{"CLNG", 4, 237266},
	{"HURN", 4, 237267},
	{"SHIRTING", 8, 237268},
	{"NAHCO", 5, 237269},
	{"CORPORIS", 8, 237270},
	{"PREREGISTER", 11, 237271},
	{"NYCGUIDE", 8, 237272},
	{"MIDCOURSE", 9, 237273},
	{"KUKU", 4, 237274},
	{"SCRWENSAVERS", 12, 237275},
	{"ROSSIYA", 7, 237276},
	{"MCKILLIP", 8, 237277},
	{"GCAL", 4, 237278},
	{"CHAMETZ", 7, 237279},
	{"BIGDADDY", 8, 237280},
	{"CARMANAH", 8, 237281},
	{"BATTLEBOTS", 10, 237282},
	{"SCRSENSAVERS", 12, 237283},
	{"PLUGININDEXES", 13, 237284},
	{"KRONBERG", 8, 237285},
	{"SCRDENSAVERS", 12, 237286},
	{"TECNIFIBRE", 10, 237287},
	{"SOFTWARESOFTWARE", 16, 237288},
	{"PRUCHA", 6, 237289},
	{"DISPROPORTIONALITY", 18, 237290},
	{"CEPTED", 6, 237291},
	{"WAITEMATA", 9, 237292},
	{"SCREWLESS", 9, 237293},
	{"KANZLERAMT", 10, 237294},
	{"DRAMATISATION", 13, 237295},
	{"DERMOID", 7, 237296},
	{"CENTRALISE", 10, 237297},
	{"RAMBAN", 6, 237298},
	{"KIRCHDORF", 9, 237299},
	{"BODYSTYLES", 10, 237300},
	{"TRANQUILLISERS", 14, 237301},
	{"OBRADOR", 7, 237302},
	{"NULLMAILER", 10, 237303},
	{"BAILDON", 7, 237304},
	{"CHURUBUSCO", 10, 237305},
	{"CAROM", 5, 237306},
	{"NEXANS", 6, 237307},
	{"MODFACT", 7, 237308},
	{"ECKENFELS", 9, 237309},
	{"RODEZ", 5, 237310},
	{"REGIUS", 6, 237311},
	{"THUGGISH", 8, 237312},
	{"MADRAZO", 7, 237313},
	{"ANTIRHEUMATIC", 13, 237314},
	{"VINDSL", 6, 237315},
	{"FFECTIVE", 8, 237316},
	{"MYLER", 5, 237317},
	{"MPZ", 3, 237318},
	{"OPTIVIEW", 8, 237319},
	{"INOCULATING", 11, 237320},
	{"CMTY", 4, 237321},
	{"SECDEF", 6, 237322},
	{"ANTICHOLINERGICS", 16, 237323},
	{"WAGA", 4, 237324},
	{"MRAM", 4, 237325},
	{"IMBIBING", 8, 237326},
	{"ICONSETS", 8, 237327},
	{"NUUK", 4, 237328},
	{"PSYLOCKE", 8, 237329},
	{"KIZUNA", 6, 237330},
	{"NETLINGO", 8, 237331},
	{"KENKYUSHA", 9, 237332},
	{"TECNICOS", 8, 237333},
	{"PETTERI", 7, 237334},
	{"LUCINA", 6, 237335},
	{"LIAMO", 5, 237336},
	{"CHECKSTAT", 9, 237337},
	{"ONSTRUCTION", 11, 237338},
	{"DROMANA", 7, 237339},
	{"SIUSLAW", 7, 237340},
	{"HILLCLIMB", 9, 237341},
	{"COLONA", 6, 237342},
	{"YLWH", 4, 237343},
	{"YBUE", 4, 237344},
	{"YAOB", 4, 237345},
	{"XTAV", 4, 237346},
	{"XMRA", 4, 237347},
	{"VOTR", 4, 237348},
	{"UTBP", 4, 237349},
	{"UOKI", 4, 237350},
	{"UCTJ", 4, 237351},
	{"UCSS", 4, 237352},
	{"TCIM", 4, 237353},
	{"SYVA", 4, 237354},
	{"SVSF", 4, 237355},
	{"SDRF", 4, 237356},
	{"RUUS", 4, 237357},
	{"RRPM", 4, 237358},
	{"RIAQ", 4, 237359},
	{"RCTA", 4, 237360},
	{"RCPL", 4, 237361},
	{"PTPH", 4, 237362},
	{"PRUR", 4, 237363},
	{"PNSC", 4, 237364},
	{"PKNE", 4, 237365},
	{"OEDP", 4, 237366},
	{"NGRF", 4, 237367},
	{"NDPV", 4, 237368},
	{"MODB", 4, 237369},
	{"LJIH", 4, 237370},
	{"LBFR", 4, 237371},
	{"KCIP", 4, 237372},
	{"KAGY", 4, 237373},
	{"ICUF", 4, 237374},
	{"IBSM", 4, 237375},
	{"GTFO", 4, 237376},
	{"GOLK", 4, 237377},
	{"GNKI", 4, 237378},
	{"GJRS", 4, 237379},
	{"FYCL", 4, 237380},
	{"FKAW", 4, 237381},
	{"FCME", 4, 237382},
	{"EVYD", 4, 237383},
	{"ENZF", 4, 237384},
	{"ENJY", 4, 237385},
	{"EIRX", 4, 237386},
	{"EGTC", 4, 237387},
	{"DNYC", 4, 237388},
	{"DMSW", 4, 237389},
	{"DMIP", 4, 237390},
	{"DMHA", 4, 237391},
	{"DKST", 4, 237392},
	{"DKMI", 4, 237393},
	{"COXL", 4, 237394},
	{"BCRU", 4, 237395},
	{"AGGT", 4, 237396},
	{"AFME", 4, 237397},
	{"AFIM", 4, 237398},
	{"ZDB", 3, 237399},
	{"FORMOTEROL", 10, 237400},
	{"PSYOP", 5, 237401},
	{"CRIMINALISATION", 15, 237402},
	{"WINTERHAVEN", 11, 237403},
	{"SSREENSAVERS", 12, 237404},
	{"REXML", 5, 237405},
	{"SIGHTLINES", 10, 237406},
	{"CANADIA", 7, 237407},
	{"BRONZERS", 8, 237408},
	{"AQUALAND", 8, 237409},
	{"MITZVOS", 7, 237410},
	{"DANAS", 5, 237411},
	{"COPPENS", 7, 237412},
	{"SPAGE", 5, 237413},
	{"MONIER", 6, 237414},
	{"DRILLINGS", 9, 237415},
	{"ACARS", 5, 237416},
	{"ABDOULAYE", 9, 237417},
	{"MIEVILLE", 8, 237418},
	{"RHYTIDECTOMY", 12, 237419},
	{"DISFUNCTIONAL", 13, 237420},
	{"POTC", 4, 237421},
	{"MALAMUTES", 9, 237422},
	{"ENTITYNAME", 10, 237423},
	{"CARNY", 5, 237424},
	{"VEHICAL", 7, 237425},
	{"TELERAMA", 8, 237426},
	{"SHEFLUG", 7, 237427},
	{"MODULOS", 7, 237428},
	{"FILESPACE", 9, 237429},
	{"WONDEFUL", 8, 237430},
	{"TARGETNAME", 10, 237431},
	{"HORNGREN", 8, 237432},
	{"TRANSLITERATIONS", 16, 237433},
	{"RESULTSIN", 9, 237434},
	{"PAYDAYS", 7, 237435},
	{"DWTN", 4, 237436},
	{"MISBEGOTTEN", 11, 237437},
	{"ATHERECTOMY", 11, 237438},
	{"TEKOA", 5, 237439},
	{"SURU", 4, 237440},
	{"SCHULL", 6, 237441},
	{"HOUSETRAINING", 13, 237442},
	{"EMPEZAR", 7, 237443},
	{"RAMBILL", 7, 237444},
	{"INGBER", 6, 237445},
	{"WONTED", 6, 237446},
	{"UESTIONS", 8, 237447},
	{"LINGUALINKS", 11, 237448},
	{"KUCHEN", 6, 237449},
	{"KIDZMOUSE", 9, 237450},
	{"JUDGESHIPS", 10, 237451},
	{"PRETESTING", 10, 237452},
	{"MOORHUHN", 8, 237453},
	{"ALKEN", 5, 237454},
	{"GUILBERT", 8, 237455},
	{"SUBLIMEDIRECTORYCOM", 19, 237456},
	{"KOZIK", 5, 237457},
	{"PREPUBLICATION", 14, 237458},
	{"CRAWLIN", 7, 237459},
	{"VWHP", 4, 237460},
	{"TERRITORIANS", 12, 237461},
	{"BLUNDEN", 7, 237462},
	{"VOGELSTEIN", 10, 237463},
	{"TRIMESTRE", 9, 237464},
	{"SCIFNCE", 7, 237465},
	{"ANADROL", 7, 237466},
	{"MXZ", 3, 237467},
	{"MOBILEIP", 8, 237468},
	{"GALLANTS", 8, 237469},
	{"DASEIN", 6, 237470},
	{"CELER", 5, 237471},
	{"SYSINST", 7, 237472},
	{"PROFILIC", 8, 237473},
	{"OLDROYD", 7, 237474},
	{"EDEBUG", 6, 237475},
	{"EARTHBEAT", 9, 237476},
	{"VARIATES", 8, 237477},
	{"SWIGER", 6, 237478},
	{"RREETING", 8, 237479},
	{"PERSONAJES", 10, 237480},
	{"WORLDLINGO", 10, 237481},
	{"PEARU", 5, 237482},
	{"CHICKLET", 8, 237483},
	{"PAROUSIA", 8, 237484},
	{"CIETY", 5, 237485},
	{"ANEMIAS", 7, 237486},
	{"FREESPIRIT", 10, 237487},
	{"CYPPRESS", 8, 237488},
	{"SCHNITTKE", 9, 237489},
	{"LHOTKA", 6, 237490},
	{"FURIE", 5, 237491},
	{"EWIGE", 5, 237492},
	{"TRACKNAME", 9, 237493},
	{"SCABBARDS", 9, 237494},
	{"SBCC", 4, 237495},
	{"DALGLIESH", 9, 237496},
	{"VRAY", 4, 237497},
	{"VACATES", 7, 237498},
	{"TOADSTOOLS", 10, 237499},
	{"KAITOU", 6, 237500},
	{"GALLIARD", 8, 237501},
	{"LIGHTWEIGHTS", 12, 237502},
	{"CROSSTAB", 8, 237503},
	{"BENOMYL", 7, 237504},
	{"SCGEENSAVERS", 12, 237505},
	{"RESPECTABLY", 11, 237506},
	{"INTRAWEB", 8, 237507},
	{"TECHBLOG", 8, 237508},
	{"REWORKS", 7, 237509},
	{"FONDI", 5, 237510},
	{"APEKS", 5, 237511},
	{"WIBERG", 6, 237512},
	{"SDAOLNWOD", 9, 237513},
	{"LAUDING", 7, 237514},
	{"CHITOSE", 7, 237515},
	{"GODIUS", 6, 237516},
	{"FMAP", 4, 237517},
	{"CYDNEY", 6, 237518},
	{"BKOZ", 4, 237519},
	{"APING", 5, 237520},
	{"SCRFENSAVERS", 12, 237521},
	{"KRISZTINA", 9, 237522},
	{"BONNI", 5, 237523},
	{"SUBLLME", 7, 237524},
	{"SCREENSXVERS", 12, 237525},
	{"NCOIC", 5, 237526},
	{"DIREZIONE", 9, 237527},
	{"RESIM", 5, 237528},
	{"GROUNDSKEEPING", 14, 237529},
	{"TOKOROA", 7, 237530},
	{"SURMAN", 6, 237531},
	{"SISKEL", 6, 237532},
	{"SCIEGCE", 7, 237533},
	{"PASSIONFLOWER", 13, 237534},
	{"NWTF", 4, 237535},
	{"RSCHEM", 6, 237536},
	{"LASSETERS", 9, 237537},
	{"KOZAR", 5, 237538},
	{"SIRION", 6, 237539},
	{"PCDB", 4, 237540},
	{"FIXITY", 6, 237541},
	{"EGISTRATION", 11, 237542},
	{"DAGA", 4, 237543},
	{"ACTUALIZACION", 13, 237544},
	{"WBCA", 4, 237545},
	{"SENILRIA", 8, 237546},
	{"SCIEKCE", 7, 237547},
	{"PADRINO", 7, 237548},
	{"OGUN", 4, 237549},
	{"TELEWORKER", 10, 237550},
	{"ILLUSTR", 7, 237551},
	{"CREAMSICLE", 10, 237552},
	{"SCREEKSAVERS", 12, 237553},
	{"PENDELTON", 9, 237554},
	{"ENDODONTISTS", 12, 237555},
	{"CURSORXP", 8, 237556},
	{"COPENHAVER", 10, 237557},
	{"CITYVIEW", 8, 237558},
	{"VISTE", 5, 237559},
	{"SCREENSADERS", 12, 237560},
	{"PUNKED", 6, 237561},
	{"AUSGABEN", 8, 237562},
	{"NARATHIWAT", 10, 237563},
	{"MATCHA", 6, 237564},
	{"SECONDING", 9, 237565},
	{"MACERATION", 10, 237566},
	{"BOULENGER", 9, 237567},
	{"WSML", 4, 237568},
	{"VITALSTATE", 10, 237569},
	{"THRUOUT", 7, 237570},
	{"SCWEENSAVERS", 12, 237571},
	{"SCREEGSAVERS", 12, 237572},
	{"UNBREAK", 7, 237573},
	{"OTTMAN", 6, 237574},
	{"BILDERN", 7, 237575},
	{"VAUBAN", 6, 237576},
	{"CAHUENGA", 8, 237577},
	{"BAWARCHI", 8, 237578},
	{"AUTHCONFIG", 10, 237579},
	{"YELPING", 7, 237580},
	{"EROTI", 5, 237581},
	{"CRUIZE", 6, 237582},
	{"BUECHLER", 8, 237583},
	{"BOTTING", 7, 237584},
	{"VAINE", 5, 237585},
	{"QUILCENE", 8, 237586},
	{"NTELOS", 6, 237587},
	{"MIMESWEEPER", 11, 237588},
	{"DOTNETJ", 7, 237589},
	{"QUANTAS", 7, 237590},
	{"KNOXNEWS", 8, 237591},
	{"CROESUS", 7, 237592},
	{"SUEHPROM", 8, 237593},
	{"CATALANS", 8, 237594},
	{"BORRAR", 6, 237595},
	{"AHERNE", 6, 237596},
	{"MAHARANI", 8, 237597},
	{"ASEFI", 5, 237598},
	{"PARROTPAUL", 10, 237599},
	{"LYDGATE", 7, 237600},
	{"RAMC", 4, 237601},
	{"CASINOONLINE", 12, 237602},
	{"BENUTZERN", 9, 237603},
	{"SUBIIME", 7, 237604},
	{"OBDURATE", 8, 237605},
	{"NEALS", 5, 237606},
	{"TRAVESTITO", 10, 237607},
	{"ALLU", 4, 237608},
	{"SWINSTALL", 9, 237609},
	{"SOCON", 5, 237610},
	{"REOCCUR", 7, 237611},
	{"KITNA", 5, 237612},
	{"SREVASNEERCS", 12, 237613},
	{"YOCHANAN", 8, 237614},
	{"MINOTT", 6, 237615},
	{"MAYPEARL", 8, 237616},
	{"VAIDHYANATHAN", 13, 237617},
	{"EVELEIGH", 8, 237618},
	{"DEBOOTSTRAP", 11, 237619},
	{"TUULI", 5, 237620},
	{"ISRAM", 5, 237621},
	{"ADVERTENTIES", 12, 237622},
	{"DORTON", 6, 237623},
	{"APMA", 4, 237624},
	{"TOBYMAC", 7, 237625},
	{"NITSCH", 6, 237626},
	{"MUCOCUTANEOUS", 13, 237627},
	{"DEVILMAN", 8, 237628},
	{"SOUNDSTREAM", 11, 237629},
	{"MEDCOM", 6, 237630},
	{"SUFFERETH", 9, 237631},
	{"RIXEY", 5, 237632},
	{"VELIKI", 6, 237633},
	{"TZARA", 5, 237634},
	{"TEBBUTT", 7, 237635},
	{"MEDSPA", 6, 237636},
	{"KASHMERE", 8, 237637},
	{"FLUNITRAZEPAM", 13, 237638},
	{"ONERROR", 7, 237639},
	{"BERSERKERS", 10, 237640},
	{"POLYPHENOL", 10, 237641},
	{"HYBSERV", 7, 237642},
	{"CONSULTATIONPHENTERMINE", 23, 237643},
	{"SFTY", 4, 237644},
	{"MNESIA", 6, 237645},
	{"GDNS", 4, 237646},
	{"MANGALA", 7, 237647},
	{"ICCC", 4, 237648},
	{"HYBELS", 6, 237649},
	{"ALCUNA", 6, 237650},
	{"VANNEVAR", 8, 237651},
	{"TUAG", 4, 237652},
	{"MROUTE", 6, 237653},
	{"GALACTOSYLTRANSFERASE", 21, 237654},
	{"FAMIE", 5, 237655},
	{"BAHCALL", 7, 237656},
	{"INTERLINING", 11, 237657},
	{"ESPECIALIZADOS", 14, 237658},
	{"SOGGIORNARE", 11, 237659},
	{"BASTIAAN", 8, 237660},
	{"MANZANILLA", 10, 237661},
	{"FAVORITTER", 10, 237662},
	{"CASSIELA", 8, 237663},
	{"RBW", 3, 237664},
	{"BUECHEL", 7, 237665},
	{"PLEMENTED", 9, 237666},
	{"DABUR", 5, 237667},
	{"NANDAN", 6, 237668},
	{"CHDO", 4, 237669},
	{"CAAC", 4, 237670},
	{"ZULK", 4, 237671},
	{"YPTL", 4, 237672},
	{"YJIG", 4, 237673},
	{"XPET", 4, 237674},
	{"WWCL", 4, 237675},
	{"WVEL", 4, 237676},
	{"WCWS", 4, 237677},
	{"VDEX", 4, 237678},
	{"UTHQ", 4, 237679},
	{"UMSJ", 4, 237680},
	{"UGCL", 4, 237681},
	{"UEYL", 4, 237682},
	{"UBGI", 4, 237683},
	{"UADJ", 4, 237684},
	{"TPAB", 4, 237685},
	{"SZWA", 4, 237686},
	{"SPBY", 4, 237687},
	{"SGTG", 4, 237688},
	{"SFTL", 4, 237689},
	{"RVRE", 4, 237690},
	{"RSUH", 4, 237691},
	{"RNYW", 4, 237692},
	{"RLTG", 4, 237693},
	{"RFSE", 4, 237694},
	{"REZJ", 4, 237695},
	{"REMK", 4, 237696},
	{"POFQ", 4, 237697},
	{"PAOP", 4, 237698},
	{"NVIZ", 4, 237699},
	{"NTJR", 4, 237700},
	{"NJRE", 4, 237701},
	{"NGYN", 4, 237702},
	{"NGGD", 4, 237703},
	{"NBPO", 4, 237704},
	{"MLBN", 4, 237705},
	{"LYPC", 4, 237706},
	{"LTDD", 4, 237707},
	{"LIZL", 4, 237708},
	{"KYFU", 4, 237709},
	{"KMBY", 4, 237710},
	{"KEVR", 4, 237711},
	{"JLAN", 4, 237712},
	{"IZUO", 4, 237713},
	{"IZUL", 4, 237714},
	{"IOWR", 4, 237715},
	{"GRIH", 4, 237716},
	{"GHUC", 4, 237717},
	{"FUSV", 4, 237718},
	{"FUDI", 4, 237719},
	{"FMSC", 4, 237720},
	{"FJUT", 4, 237721},
	{"EXGL", 4, 237722},
	{"DFDA", 4, 237723},
	{"DBOF", 4, 237724},
	{"CTJI", 4, 237725},
	{"CDSD", 4, 237726},
	{"CAXI", 4, 237727},
	{"CAKO", 4, 237728},
	{"BPSD", 4, 237729},
	{"ATDJ", 4, 237730},
	{"ANPF", 4, 237731},
	{"AKOY", 4, 237732},
	{"BARNE", 5, 237733},
	{"UNATT", 5, 237734},
	{"UBIN", 4, 237735},
	{"HISTROY", 7, 237736},
	{"REKLAAM", 7, 237737},
	{"FISHWRAP", 8, 237738},
	{"PURRRFECT", 9, 237739},
	{"POLYTHEISTIC", 12, 237740},
	{"GLOTTIS", 7, 237741},
	{"FOGLI", 5, 237742},
	{"GXL", 3, 237743},
	{"BALDINI", 7, 237744},
	{"JHANA", 5, 237745},
	{"BOORSTIN", 8, 237746},
	{"RICHBROOK", 9, 237747},
	{"DAERAH", 6, 237748},
	{"BATTEY", 6, 237749},
	{"STOLTENBERG", 11, 237750},
	{"ABSOLUE", 7, 237751},
	{"LACMA", 5, 237752},
	{"ZAVOD", 5, 237753},
	{"WIEDERHOLD", 10, 237754},
	{"CAFETIERE", 9, 237755},
	{"BEKAA", 5, 237756},
	{"BLOOMINGBURG", 12, 237757},
	{"LATRELL", 7, 237758},
	{"KROEBER", 7, 237759},
	{"CHRISTABEL", 10, 237760},
	{"CHILDPROOFING", 13, 237761},
	{"YESHA", 5, 237762},
	{"ORTHOLOGIES", 11, 237763},
	{"LATCHKEY", 8, 237764},
	{"ELIDED", 6, 237765},
	{"AVING", 5, 237766},
	{"SATTERTHWAITE", 13, 237767},
	{"KARABAGH", 8, 237768},
	{"GVF", 3, 237769},
	{"TCHAR", 5, 237770},
	{"SORBS", 5, 237771},
	{"KOOZIE", 6, 237772},
	{"MONU", 4, 237773},
	{"LIBTEXT", 7, 237774},
	{"DIXFIELD", 8, 237775},
	{"ROSETTI", 7, 237776},
	{"RAMOND", 6, 237777},
	{"IRUN", 4, 237778},
	{"GILBERTON", 9, 237779},
	{"FAUCHER", 7, 237780},
	{"BUCCA", 5, 237781},
	{"SULTANAS", 8, 237782},
	{"MULVANE", 7, 237783},
	{"LLVMDEV", 7, 237784},
	{"SUPPAN", 6, 237785},
	{"CRESSMAN", 8, 237786},
	{"CLEOBURY", 8, 237787},
	{"LANDSIDE", 8, 237788},
	{"GUILLEMIN", 9, 237789},
	{"ARMENDARIZ", 10, 237790},
	{"MELLOWS", 7, 237791},
	{"GOLWG", 5, 237792},
	{"SAVIMBI", 7, 237793},
	{"OROGRAPHIC", 10, 237794},
	{"ESTEL", 5, 237795},
	{"GETKEY", 6, 237796},
	{"AGASSIZII", 9, 237797},
	{"ZAMALEK", 7, 237798},
	{"ULARLY", 6, 237799},
	{"NDUSTRY", 7, 237800},
	{"KLARK", 5, 237801},
	{"BONAVENTURA", 11, 237802},
	{"AMHARA", 6, 237803},
	{"ZIJLSTRA", 8, 237804},
	{"LEGALPOINTER", 12, 237805},
	{"POSURE", 6, 237806},
	{"NDIMENSIONS", 11, 237807},
	{"JFJ", 3, 237808},
	{"GOLDRATT", 8, 237809},
	{"KATJES", 6, 237810},
	{"ICCPRODUCTS", 11, 237811},
	{"SHOBHA", 6, 237812},
	{"ROKZUNDAYZ", 10, 237813},
	{"RESIZEDNAME", 11, 237814},
	{"NAVIGA", 6, 237815},
	{"ITWAS", 5, 237816},
	{"HODGETTS", 8, 237817},
	{"GTHTTP", 6, 237818},
	{"UNBANKED", 8, 237819},
	{"RANSACK", 7, 237820},
	{"OISHII", 6, 237821},
	{"INDV", 4, 237822},
	{"CGEN", 4, 237823},
	{"BALIAN", 6, 237824},
	{"NICASTRO", 8, 237825},
	{"MELENA", 6, 237826},
	{"CYRSIAU", 7, 237827},
	{"BUDDIED", 7, 237828},
	{"ONMOUSEDOWN", 11, 237829},
	{"LECTIO", 6, 237830},
	{"PEAFOWL", 7, 237831},
	{"OVERSTEP", 8, 237832},
	{"KALOO", 5, 237833},
	{"ARRANGMENT", 10, 237834},
	{"ZETTERBERG", 10, 237835},
	{"VACATIONED", 10, 237836},
	{"KOSHEEN", 7, 237837},
	{"KOETTER", 7, 237838},
	{"HALAWA", 6, 237839},
	{"CAPANNA", 7, 237840},
	{"LEWALLEN", 8, 237841},
	{"BLIPPO", 6, 237842},
	{"SPINNERBAITS", 12, 237843},
	{"SEDIE", 5, 237844},
	{"LAURETTE", 8, 237845},
	{"DSTC", 4, 237846},
	{"CONING", 6, 237847},
	{"HAILES", 6, 237848},
	{"BUSBOY", 6, 237849},
	{"TWIKITOPICS", 11, 237850},
	{"INTELLIPOINT", 12, 237851},
	{"SCPONLY", 7, 237852},
	{"ROBLEDO", 7, 237853},
	{"RILLING", 7, 237854},
	{"LEVIEN", 6, 237855},
	{"ILLINOISUSA", 11, 237856},
	{"GURBANI", 7, 237857},
	{"LEMNOS", 6, 237858},
	{"IZZLE", 5, 237859},
	{"ENTEROTOXINS", 12, 237860},
	{"BELISARIUS", 10, 237861},
	{"POMERANZ", 8, 237862},
	{"IDEBENONE", 9, 237863},
	{"HOTEP", 5, 237864},
	{"GENDERING", 9, 237865},
	{"CUDDL", 5, 237866},
	{"RASTERIZATION", 13, 237867},
	{"VISUALITY", 9, 237868},
	{"CYBERJAYA", 9, 237869},
	{"MULBERRIBUSH", 12, 237870},
	{"ZYGOMATIC", 9, 237871},
	{"WACKIES", 7, 237872},
	{"LAKI", 4, 237873},
	{"MAYDE", 5, 237874},
	{"CHUCKER", 7, 237875},
	{"BVU", 3, 237876},
	{"SKIBBEREEN", 10, 237877},
	{"EMBALMERS", 9, 237878},
	{"GAFFIGAN", 8, 237879},
	{"SCHLAG", 6, 237880},
	{"TEXTONLY", 8, 237881},
	{"LARNAKA", 7, 237882},
	{"KORYO", 5, 237883},
	{"GYLE", 4, 237884},
	{"UFOC", 4, 237885},
	{"BOBBSEY", 7, 237886},
	{"PRECIPITATOR", 12, 237887},
	{"LOCKSMITHING", 12, 237888},
	{"BLHE", 4, 237889},
	{"BEACOM", 6, 237890},
	{"ASYNCH", 6, 237891},
	{"ROSENQUIST", 10, 237892},
	{"MAKAYLA", 7, 237893},
	{"DUCKER", 6, 237894},
	{"BORDERLAYOUT", 12, 237895},
	{"BLASDELL", 8, 237896},
	{"POISSONIAN", 10, 237897},
	{"RJL", 3, 237898},
	{"NCOME", 5, 237899},
	{"LIBGCONF", 8, 237900},
	{"JOBCRAWLER", 10, 237901},
	{"HASHSET", 7, 237902},
	{"CHEEZE", 6, 237903},
	{"YAME", 4, 237904},
	{"RECALIBRATED", 12, 237905},
	{"BOUDRIA", 7, 237906},
	{"ARROYOS", 7, 237907},
	{"WEIM", 4, 237908},
	{"TAKAOKA", 7, 237909},
	{"PARERR", 6, 237910},
	{"INFOPTR", 7, 237911},
	{"BEKELE", 6, 237912},
	{"ROCKAUTO", 8, 237913},
	{"OQUENDO", 7, 237914},
	{"CARECURE", 8, 237915},
	{"ROWVILLE", 8, 237916},
	{"NEWWHAT", 7, 237917},
	{"CHARNLEY", 8, 237918},
	{"TITOV", 5, 237919},
	{"SCHUETZ", 7, 237920},
	{"TIPSHEET", 8, 237921},
	{"PITYRIASIS", 10, 237922},
	{"JACL", 4, 237923},
	{"CLIENTGUI", 9, 237924},
	{"INTRAVESICAL", 12, 237925},
	{"EMRS", 4, 237926},
	{"SKIBA", 5, 237927},
	{"RNAP", 4, 237928},
	{"REXEC", 5, 237929},
	{"ETEACH", 6, 237930},
	{"EMSLIE", 6, 237931},
	{"URHGAN", 6, 237932},
	{"STEAMVAC", 8, 237933},
	{"CANADIANDRIVER", 14, 237934},
	{"BASDEN", 6, 237935},
	{"WAPS", 4, 237936},
	{"NANOBOTS", 8, 237937},
	{"LEAFLETING", 10, 237938},
	{"IMATELY", 7, 237939},
	{"KAPLER", 6, 237940},
	{"DQUOT", 5, 237941},
	{"SIGALRM", 7, 237942},
	{"LAUDON", 6, 237943},
	{"CHKSUM", 6, 237944},
	{"TRIPLO", 6, 237945},
	{"SUNNIER", 7, 237946},
	{"GODFLESH", 8, 237947},
	{"DRAENOR", 7, 237948},
	{"AUMSVILLE", 9, 237949},
	{"ORTHOGONALLY", 12, 237950},
	{"GOULART", 7, 237951},
	{"JAGUARES", 8, 237952},
	{"LIVETYPE", 8, 237953},
	{"TORBJORN", 8, 237954},
	{"TALER", 5, 237955},
	{"PRAWO", 5, 237956},
	{"SODOMITES", 9, 237957},
	{"INVITA", 6, 237958},
	{"IMMUNOPHENOTYPING", 17, 237959},
	{"FAVICONS", 8, 237960},
	{"ACETAMIDE", 9, 237961},
	{"ZIOB", 4, 237962},
	{"ZINL", 4, 237963},
	{"ZFIG", 4, 237964},
	{"ZDAI", 4, 237965},
	{"YUNQ", 4, 237966},
	{"YNRI", 4, 237967},
	{"YLRO", 4, 237968},
	{"XLEI", 4, 237969},
	{"WLSL", 4, 237970},
	{"WFEN", 4, 237971},
	{"VNDM", 4, 237972},
	{"VATM", 4, 237973},
	{"UNUR", 4, 237974},
	{"UIBU", 4, 237975},
	{"TNYC", 4, 237976},
	{"SPWO", 4, 237977},
	{"SCHJ", 4, 237978},
	{"PYUS", 4, 237979},
	{"PFEF", 4, 237980},
	{"OPUK", 4, 237981},
	{"OMCZ", 4, 237982},
	{"NUEK", 4, 237983},
	{"MAOK", 4, 237984},
	{"LUXS", 4, 237985},
	{"LUKT", 4, 237986},
	{"LUKC", 4, 237987},
	{"LRUF", 4, 237988},
	{"LMSK", 4, 237989},
	{"LAVF", 4, 237990},
	{"KPAK", 4, 237991},
	{"KOUD", 4, 237992},
	{"JRNS", 4, 237993},
	{"JELK", 4, 237994},
	{"IXSL", 4, 237995},
	{"IBYH", 4, 237996},
	{"GRHO", 4, 237997},
	{"GKUM", 4, 237998},
	{"FTLU", 4, 237999},
	{"FLFA", 4, 238000},
	{"FETF", 4, 238001},
	{"EZIC", 4, 238002},
	{"EIUP", 4, 238003},
	{"ECWC", 4, 238004},
	{"DQUR", 4, 238005},
	{"DOEW", 4, 238006},
	{"DLST", 4, 238007},
	{"CUFO", 4, 238008},
	{"CTUE", 4, 238009},
	{"CPAV", 4, 238010},
	{"CFUS", 4, 238011},
	{"IUSTO", 5, 238012},
	{"BARISTAS", 8, 238013},
	{"SKOAL", 5, 238014},
	{"KIPRUSOFF", 9, 238015},
	{"WHOLSALE", 8, 238016},
	{"READES", 6, 238017},
	{"OPHTHALMOSCOPE", 14, 238018},
	{"PIOUSLY", 7, 238019},
	{"EUROSCEPTIC", 11, 238020},
	{"QUAINTLY", 8, 238021},
	{"NORDSON", 7, 238022},
	{"MYERSTOWN", 9, 238023},
	{"TIDSSKRIFT", 10, 238024},
	{"HICHAM", 6, 238025},
	{"DSLAMS", 6, 238026},
	{"SEISMOMETER", 11, 238027},
	{"SCHILKE", 7, 238028},
	{"NEOWINIAN", 9, 238029},
	{"INFERENTIALLY", 13, 238030},
	{"DISSOLUTIONS", 12, 238031},
	{"SPINTRONICS", 11, 238032},
	{"POMPOSITY", 9, 238033},
	{"OKINO", 5, 238034},
	{"RIZZA", 5, 238035},
	{"BEUTY", 5, 238036},
	{"COMITTED", 8, 238037},
	{"BADALAMENTI", 11, 238038},
	{"VICTIMIZE", 9, 238039},
	{"PERMANENTS", 10, 238040},
	{"DINGED", 6, 238041},
	{"VINOGRADOV", 10, 238042},
	{"TENUIS", 6, 238043},
	{"GROUNDWOOD", 10, 238044},
	{"ENERGUIDE", 9, 238045},
	{"ABBOTSBURY", 10, 238046},
	{"BOGGING", 7, 238047},
	{"BIOGEOGRAPHICAL", 15, 238048},
	{"HONSELECT", 9, 238049},
	{"MARWOOD", 7, 238050},
	{"RAMZAN", 6, 238051},
	{"PUSST", 5, 238052},
	{"NEWP", 4, 238053},
	{"SAKHA", 5, 238054},
	{"RATIONALISTIC", 13, 238055},
	{"KATYDID", 7, 238056},
	{"IAESTE", 6, 238057},
	{"KIRN", 4, 238058},
	{"NOTETAB", 7, 238059},
	{"USQUE", 5, 238060},
	{"ROOMMATECLICK", 13, 238061},
	{"NODATA", 6, 238062},
	{"SGCP", 4, 238063},
	{"PARTIS", 6, 238064},
	{"KERENS", 6, 238065},
	{"EMERTON", 7, 238066},
	{"TARTAGLIA", 9, 238067},
	{"STUX", 4, 238068},
	{"CHATZILLA", 9, 238069},
	{"HASELTINE", 9, 238070},
	{"PTAMAR", 6, 238071},
	{"DIENCEPHALON", 12, 238072},
	{"RUSSULA", 7, 238073},
	{"PORTFORWARD", 11, 238074},
	{"LIUTILITIES", 11, 238075},
	{"INPUTBUFFER", 11, 238076},
	{"GRIMEY", 6, 238077},
	{"FRW", 3, 238078},
	{"TINTORETTO", 10, 238079},
	{"ROSENBURG", 9, 238080},
	{"SITECOMPANY", 11, 238081},
	{"LEVANDE", 7, 238082},
	{"JOBSINHEALTH", 12, 238083},
	{"NANOCRYSTAL", 11, 238084},
	{"NZSEARCH", 8, 238085},
	{"JANNAH", 6, 238086},
	{"TRANSPOSER", 10, 238087},
	{"PRIVILEDGED", 11, 238088},
	{"VISINE", 6, 238089},
	{"MILLAT", 6, 238090},
	{"CYANEA", 6, 238091},
	{"URRY", 4, 238092},
	{"KARAMA", 6, 238093},
	{"VELKOMMEN", 9, 238094},
	{"RADIOIODINE", 11, 238095},
	{"CLOUDMARK", 9, 238096},
	{"JOBSINPUBLICSECTOR", 18, 238097},
	{"JOBSINCONSTRUCTION", 18, 238098},
	{"SPPS", 4, 238099},
	{"SERAS", 5, 238100},
	{"HARWINTON", 9, 238101},
	{"BUTORPHANOL", 11, 238102},
	{"RSRC", 4, 238103},
	{"DISTNAME", 8, 238104},
	{"FEDERATIVE", 10, 238105},
	{"EASTCOTE", 8, 238106},
	{"OSMONDS", 7, 238107},
	{"MASTERSHIP", 10, 238108},
	{"GWME", 4, 238109},
	{"GIEC", 4, 238110},
	{"OCCHIALI", 8, 238111},
	{"CAGA", 4, 238112},
	{"WEISBERGER", 10, 238113},
	{"SHRINKER", 8, 238114},
	{"SCHRITT", 7, 238115},
	{"LZF", 3, 238116},
	{"ARBORETA", 8, 238117},
	{"INDESTRUCTABLE", 14, 238118},
	{"GOLTZ", 5, 238119},
	{"SHARKSKIN", 9, 238120},
	{"KINNELON", 8, 238121},
	{"TELERAU", 7, 238122},
	{"ROUTIER", 7, 238123},
	{"PRINTERFRIENDLY", 15, 238124},
	{"KOOZIES", 7, 238125},
	{"FUDGED", 6, 238126},
	{"BATESBURG", 9, 238127},
	{"RESPACK", 7, 238128},
	{"FLICT", 5, 238129},
	{"SCONTO", 6, 238130},
	{"CANDIDASA", 9, 238131},
	{"ADORAMAPIX", 10, 238132},
	{"RUTLES", 6, 238133},
	{"KNOBLOCH", 8, 238134},
	{"MYOPATHIES", 10, 238135},
	{"LINUXFEST", 9, 238136},
	{"SNELGROVE", 9, 238137},
	{"OFTHESE", 7, 238138},
	{"MYHOTEL", 7, 238139},
	{"DTAR", 4, 238140},
	{"PROCESSABLE", 11, 238141},
	{"CLOC", 4, 238142},
	{"INDOT", 5, 238143},
	{"CABAN", 5, 238144},
	{"ASHLING", 7, 238145},
	{"AEROPUERTOS", 11, 238146},
	{"ADWORD", 6, 238147},
	{"TERRORISED", 10, 238148},
	{"NYASALAND", 9, 238149},
	{"MIKHAILOVICH", 12, 238150},
	{"LOCALIZAR", 9, 238151},
	{"CHESSPARTNER", 12, 238152},
	{"UNDERSTANDABILITY", 17, 238153},
	{"LOVERLY", 7, 238154},
	{"RIGTH", 5, 238155},
	{"MAYORALTY", 9, 238156},
	{"DISINCLINATION", 14, 238157},
	{"COLCORD", 7, 238158},
	{"SHADOWLAND", 10, 238159},
	{"ORGANISMIC", 10, 238160},
	{"VRSN", 4, 238161},
	{"MASTERCAM", 9, 238162},
	{"AURICLE", 7, 238163},
	{"OSAWATOMIE", 10, 238164},
	{"KERNPHYSIK", 10, 238165},
	{"DEHUMANIZATION", 14, 238166},
	{"SATELLIET", 9, 238167},
	{"POLYCHAETE", 10, 238168},
	{"BURMESTER", 9, 238169},
	{"ACCOMPAGNATRICE", 15, 238170},
	{"ABSTAINS", 8, 238171},
	{"XPPRO", 5, 238172},
	{"TROMPETTE", 9, 238173},
	{"CRITERIAS", 9, 238174},
	{"BATTISTI", 8, 238175},
	{"ACCOMMODATIE", 12, 238176},
	{"CFCC", 4, 238177},
	{"VENUGOPAL", 9, 238178},
	{"TOOTHFISH", 9, 238179},
	{"HUNTLEIGH", 9, 238180},
	{"CARTLEDGE", 9, 238181},
	{"QUATAR", 6, 238182},
	{"PERITO", 6, 238183},
	{"MOJOWORLD", 9, 238184},
	{"FRSC", 4, 238185},
	{"CAMBODGE", 8, 238186},
	{"ZAKE", 4, 238187},
	{"EINGANG", 7, 238188},
	{"CHESTERVILLE", 12, 238189},
	{"MORVILLE", 8, 238190},
	{"MANAGABLE", 9, 238191},
	{"CAPSIZING", 9, 238192},
	{"ALOOFNESS", 9, 238193},
	{"SHERRILYN", 9, 238194},
	{"NUORO", 5, 238195},
	{"FINFO", 5, 238196},
	{"ANDINO", 6, 238197},
	{"DOPES", 5, 238198},
	{"IVARS", 5, 238199},
	{"SZABOLCS", 8, 238200},
	{"NECTIONS", 8, 238201},
	{"HYDROPS", 7, 238202},
	{"TISHLER", 7, 238203},
	{"LUPI", 4, 238204},
	{"NEURITES", 8, 238205},
	{"HERSHA", 6, 238206},
	{"BOYAN", 5, 238207},
	{"ANCIC", 5, 238208},
	{"YNLO", 4, 238209},
	{"XIRE", 4, 238210},
	{"XELH", 4, 238211},
	{"WSSW", 4, 238212},
	{"WPEE", 4, 238213},
	{"URMB", 4, 238214},
	{"UBPU", 4, 238215},
	{"TUMK", 4, 238216},
	{"SFOD", 4, 238217},
	{"SCHV", 4, 238218},
	{"SCCL", 4, 238219},
	{"RVAW", 4, 238220},
	{"RUZP", 4, 238221},
	{"RJHA", 4, 238222},
	{"QAJA", 4, 238223},
	{"PCSU", 4, 238224},
	{"NNUY", 4, 238225},
	{"NAYK", 4, 238226},
	{"MUWI", 4, 238227},
	{"MOBF", 4, 238228},
	{"MLSU", 4, 238229},
	{"LYYM", 4, 238230},
	{"LYLD", 4, 238231},
	{"LTAQ", 4, 238232},
	{"LPJO", 4, 238233},
	{"LFIH", 4, 238234},
	{"KVOY", 4, 238235},
	{"KUUS", 4, 238236},
	{"KJAU", 4, 238237},
	{"KDAU", 4, 238238},
	{"IMMW", 4, 238239},
	{"IKBR", 4, 238240},
	{"IEWQ", 4, 238241},
	{"HPYR", 4, 238242},
	{"HDWH", 4, 238243},
	{"FVOG", 4, 238244},
	{"FMOA", 4, 238245},
	{"FEOL", 4, 238246},
	{"FDUI", 4, 238247},
	{"EYAJ", 4, 238248},
	{"EUDP", 4, 238249},
	{"ETZM", 4, 238250},
	{"ERWM", 4, 238251},
	{"ENWF", 4, 238252},
	{"EMMF", 4, 238253},
	{"EGAJ", 4, 238254},
	{"EFRS", 4, 238255},
	{"DVAA", 4, 238256},
	{"DUSJ", 4, 238257},
	{"DTYC", 4, 238258},
	{"DDSV", 4, 238259},
	{"CVIB", 4, 238260},
	{"CPEE", 4, 238261},
	{"BULR", 4, 238262},
	{"BIZK", 4, 238263},
	{"BCPE", 4, 238264},
	{"AHYU", 4, 238265},
	{"AACF", 4, 238266},
	{"QRIO", 4, 238267},
	{"LUDDEN", 6, 238268},
	{"GETDATABACK", 11, 238269},
	{"CURVA", 5, 238270},
	{"MOONSHADOW", 10, 238271},
	{"KDDEBUG", 7, 238272},
	{"INFORMATIONSTECHNIK", 19, 238273},
	{"CARDCAPTORS", 11, 238274},
	{"BOOKWORKZ", 9, 238275},
	{"BARDI", 5, 238276},
	{"MONFERRATO", 10, 238277},
	{"BADGUY", 6, 238278},
	{"WOOLMAN", 7, 238279},
	{"OLYMPIQUES", 10, 238280},
	{"EARLET", 6, 238281},
	{"TBWA", 4, 238282},
	{"MIGWEB", 6, 238283},
	{"LEEROY", 6, 238284},
	{"DOLINA", 6, 238285},
	{"RTCA", 4, 238286},
	{"PAMIDRONATE", 11, 238287},
	{"LOVAN", 5, 238288},
	{"DAYDATE", 7, 238289},
	{"WEBAIR", 6, 238290},
	{"PRIMORDIA", 9, 238291},
	{"ROGERO", 6, 238292},
	{"RCONVERSATION", 13, 238293},
	{"MSCORLIB", 8, 238294},
	{"MOSIAC", 6, 238295},
	{"CHAYANNE", 8, 238296},
	{"QUATHIASKI", 10, 238297},
	{"PAPH", 4, 238298},
	{"KINGBRIGHT", 10, 238299},
	{"TERRORGRUPPE", 12, 238300},
	{"GENERRA", 7, 238301},
	{"AFRICAS", 7, 238302},
	{"SEISMOLOGISTS", 13, 238303},
	{"ZOINKS", 6, 238304},
	{"MIKOLAJ", 7, 238305},
	{"DELIVERERS", 10, 238306},
	{"CANNELTON", 9, 238307},
	{"SECURECRT", 9, 238308},
	{"KOANS", 5, 238309},
	{"KDK", 3, 238310},
	{"HIRERS", 6, 238311},
	{"STRATEGOL", 9, 238312},
	{"IGATE", 5, 238313},
	{"DROM", 4, 238314},
	{"USERV", 5, 238315},
	{"KIDSKIN", 7, 238316},
	{"INTRADUCTAL", 11, 238317},
	{"DUSSEHRA", 8, 238318},
	{"BUISSON", 7, 238319},
	{"SUBOXONE", 8, 238320},
	{"PYTHONIC", 8, 238321},
	{"STEINEL", 7, 238322},
	{"PAHOKEE", 7, 238323},
	{"LYMPHOEDEMA", 11, 238324},
	{"EGOBOO", 6, 238325},
	{"QUIZZICALLY", 11, 238326},
	{"LENCERIA", 8, 238327},
	{"ERYTHRINA", 9, 238328},
	{"HOLLOWBODY", 10, 238329},
	{"HAHIRA", 6, 238330},
	{"STANDE", 6, 238331},
	{"PELLISSIPPI", 11, 238332},
	{"WEERAWARANA", 11, 238333},
	{"REGRESSOR", 9, 238334},
	{"LLANDYSUL", 9, 238335},
	{"DODONA", 6, 238336},
	{"ISOTYPES", 8, 238337},
	{"TELSTRACLEAR", 12, 238338},
	{"INNSUITES", 9, 238339},
	{"JONATHA", 7, 238340},
	{"JENOLAN", 7, 238341},
	{"INKWORKS", 8, 238342},
	{"UNDESCENDED", 11, 238343},
	{"UMSDOS", 6, 238344},
	{"COFES", 5, 238345},
	{"KYP", 3, 238346},
	{"GITANA", 6, 238347},
	{"DIRXML", 6, 238348},
	{"ARMINIUS", 8, 238349},
	{"ARMBRUST", 8, 238350},
	{"ANONYMISED", 10, 238351},
	{"ELANORA", 7, 238352},
	{"DOORSTOPS", 9, 238353},
	{"GOODAVE", 7, 238354},
	{"ALLITERATIVE", 12, 238355},
	{"BIRTWISTLE", 10, 238356},
	{"PLENTYN", 7, 238357},
	{"EICK", 4, 238358},
	{"TITTIED", 7, 238359},
	{"SKINMEM", 7, 238360},
	{"SUBTAB", 6, 238361},
	{"DISKUSI", 7, 238362},
	{"YOSHIHIDE", 9, 238363},
	{"GETCONNECTION", 13, 238364},
	{"CORALLINE", 9, 238365},
	{"BEAUFORD", 8, 238366},
	{"TREADED", 7, 238367},
	{"MICECHAT", 8, 238368},
	{"AMCIS", 5, 238369},
	{"MONOESTER", 9, 238370},
	{"WZR", 3, 238371},
	{"AMERIKAANSE", 11, 238372},
	{"VICH", 4, 238373},
	{"PRECIPITIN", 10, 238374},
	{"OKGO", 4, 238375},
	{"HEARIN", 6, 238376},
	{"CHARBROILED", 11, 238377},
	{"ABMA", 4, 238378},
	{"SKELLIG", 7, 238379},
	{"HABY", 4, 238380},
	{"UNWRAPS", 7, 238381},
	{"KADLEC", 6, 238382},
	{"FOOTLESS", 8, 238383},
	{"WORDART", 7, 238384},
	{"ROBAINA", 7, 238385},
	{"QUIPMENT", 8, 238386},
	{"NESTYH", 6, 238387},
	{"MOUSTAFA", 8, 238388},
	{"ANURADHAPURA", 12, 238389},
	{"AMERICO", 7, 238390},
	{"SAYLER", 6, 238391},
	{"VANELLUS", 8, 238392},
	{"SKYLINER", 8, 238393},
	{"PARESH", 6, 238394},
	{"GEDHTREE", 8, 238395},
	{"ERICMORITZ", 10, 238396},
	{"TORTIE", 6, 238397},
	{"EFFLORESCENCE", 13, 238398},
	{"DILATING", 8, 238399},
	{"BAPTISTERY", 10, 238400},
	{"VDIMENSION", 10, 238401},
	{"PSCP", 4, 238402},
	{"VOYENCE", 7, 238403},
	{"THROMBOPHILIA", 13, 238404},
	{"SALTVILLE", 9, 238405},
	{"NONMOVING", 9, 238406},
	{"NODWEDDION", 10, 238407},
	{"MSSP", 4, 238408},
	{"MESCAL", 6, 238409},
	{"INDET", 5, 238410},
	{"BOOTYS", 6, 238411},
	{"NAGAPATTINAM", 12, 238412},
	{"LABORATO", 8, 238413},
	{"GRANDTREK", 9, 238414},
	{"EPPC", 4, 238415},
	{"GOABROAD", 8, 238416},
	{"SOLONDZ", 7, 238417},
	{"SHERIE", 6, 238418},
	{"PARTHIA", 7, 238419},
	{"BUSM", 4, 238420},
	{"BLOGGERHEADS", 12, 238421},
	{"BIYA", 4, 238422},
	{"SWISSVOICE", 10, 238423},
	{"ROCKETSHIP", 10, 238424},
	{"EPUBLICATIONS", 13, 238425},
	{"CHESSER", 7, 238426},
	{"RYRIE", 5, 238427},
	{"ALOTTA", 6, 238428},
	{"FELUCCA", 7, 238429},
	{"AMINOLEVULINIC", 14, 238430},
	{"MOLLA", 5, 238431},
	{"OHNISHI", 7, 238432},
	{"SUGARFORGE", 10, 238433},
	{"HAPU", 4, 238434},
	{"POZI", 4, 238435},
	{"INPRISE", 7, 238436},
	{"ELECTROCARDIOGRAMS", 18, 238437},
	{"PEOR", 4, 238438},
	{"SAURAV", 6, 238439},
	{"HERSTON", 7, 238440},
	{"HAVERTY", 7, 238441},
	{"GREGER", 6, 238442},
	{"ARLISS", 6, 238443},
	{"PROROGATION", 11, 238444},
	{"HOODYS", 6, 238445},
	{"WELLWOOD", 8, 238446},
	{"PAUWELS", 7, 238447},
	{"MACCHIATO", 9, 238448},
	{"GAMBHIR", 7, 238449},
	{"GANNI", 5, 238450},
	{"ABRAMOV", 7, 238451},
	{"ROMANDE", 7, 238452},
	{"PREMISSES", 9, 238453},
	{"JAPONESAS", 9, 238454},
	{"SHOICHI", 7, 238455},
	{"HOMEZONE", 8, 238456},
	{"GOODENOW", 8, 238457},
	{"FREISING", 8, 238458},
	{"HAYFORK", 7, 238459},
	{"AUTOPAGE", 8, 238460},
	{"USTRING", 7, 238461},
	{"RETROVIRIDAE", 12, 238462},
	{"ITCOBE", 6, 238463},
	{"KINNERSLEY", 10, 238464},
	{"GLIBLY", 6, 238465},
	{"TANYETTE", 8, 238466},
	{"PUTREFACTION", 12, 238467},
	{"COWDREY", 7, 238468},
	{"MEDIACHANNEL", 12, 238469},
	{"BLOGMATRIX", 10, 238470},
	{"ODETTA", 6, 238471},
	{"LADYLAND", 8, 238472},
	{"HAVRILESKY", 10, 238473},
	{"FLAMM", 5, 238474},
	{"PHUNKY", 6, 238475},
	{"KHIM", 4, 238476},
	{"MAKKA", 5, 238477},
	{"INTERMEDIUS", 11, 238478},
	{"EMENTOR", 7, 238479},
	{"BIOLUMINESCENT", 14, 238480},
	{"SIMITAR", 7, 238481},
	{"DURTY", 5, 238482},
	{"ORPHIC", 6, 238483},
	{"KOBER", 5, 238484},
	{"ZIGB", 4, 238485},
	{"ZFSY", 4, 238486},
	{"YOXI", 4, 238487},
	{"YIEX", 4, 238488},
	{"YGNO", 4, 238489},
	{"VBRE", 4, 238490},
	{"ULRS", 4, 238491},
	{"UDAJ", 4, 238492},
	{"UBJA", 4, 238493},
	{"TWAM", 4, 238494},
	{"TUBR", 4, 238495},
	{"THVL", 4, 238496},
	{"STVF", 4, 238497},
	{"SMUZ", 4, 238498},
	{"SGTK", 4, 238499},
	{"RVIJ", 4, 238500},
	{"RCKX", 4, 238501},
	{"RBCI", 4, 238502},
	{"OPEQ", 4, 238503},
	{"OCOY", 4, 238504},
	{"OAWF", 4, 238505},
	{"NZVO", 4, 238506},
	{"NSMP", 4, 238507},
	{"NMUF", 4, 238508},
	{"NGTB", 4, 238509},
	{"NEXR", 4, 238510},
	{"MWEP", 4, 238511},
	{"MPYE", 4, 238512},
	{"MMBU", 4, 238513},
	{"MHZP", 4, 238514},
	{"MHUT", 4, 238515},
	{"LYKL", 4, 238516},
	{"LNAY", 4, 238517},
	{"LEVP", 4, 238518},
	{"KOVF", 4, 238519},
	{"KEKK", 4, 238520},
	{"JMOR", 4, 238521},
	{"IIRU", 4, 238522},
	{"IBYR", 4, 238523},
	{"HLSD", 4, 238524},
	{"GSUK", 4, 238525},
	{"GSHY", 4, 238526},
	{"GIDM", 4, 238527},
	{"FCNE", 4, 238528},
	{"EZQU", 4, 238529},
	{"EFLD", 4, 238530},
	{"EDNP", 4, 238531},
	{"EDMK", 4, 238532},
	{"DTVN", 4, 238533},
	{"CLAX", 4, 238534},
	{"BUSV", 4, 238535},
	{"BUAR", 4, 238536},
	{"ASYY", 4, 238537},
	{"ABBB", 4, 238538},
	{"HEADSCAPE", 9, 238539},
	{"MORRONE", 7, 238540},
	{"MONOPRIL", 8, 238541},
	{"GRUENWALD", 9, 238542},
	{"ZERUBBABEL", 10, 238543},
	{"MIMEOGRAPH", 10, 238544},
	{"HOCHIMINH", 9, 238545},
	{"LARGISH", 7, 238546},
	{"CLONARD", 7, 238547},
	{"AERATING", 8, 238548},
	{"PIVA", 4, 238549},
	{"MIYASHITA", 9, 238550},
	{"TTAGETSSCHEMANAME", 17, 238551},
	{"OXYD", 4, 238552},
	{"MLODA", 5, 238553},
	{"CLOFIBRATE", 10, 238554},
	{"ADVISEE", 7, 238555},
	{"GITHA", 5, 238556},
	{"FRYMAN", 6, 238557},
	{"XNVIEW", 6, 238558},
	{"UNFORTUNATES", 12, 238559},
	{"STUNNERS", 8, 238560},
	{"WSZYSTKO", 8, 238561},
	{"POTTAGE", 7, 238562},
	{"PODDER", 6, 238563},
	{"COTBED", 6, 238564},
	{"STAYERS", 7, 238565},
	{"LIBDIME", 7, 238566},
	{"IMACH", 5, 238567},
	{"FREEPRESS", 9, 238568},
	{"URIN", 4, 238569},
	{"TECHPRICESONLINE", 16, 238570},
	{"NEOPOINTS", 9, 238571},
	{"CABLEWAY", 8, 238572},
	{"SILVEY", 6, 238573},
	{"LIGGER", 6, 238574},
	{"KEYA", 4, 238575},
	{"TATUAGGI", 8, 238576},
	{"DISSIN", 6, 238577},
	{"TUBERCLES", 9, 238578},
	{"TOPIA", 5, 238579},
	{"SUNDRIDGE", 9, 238580},
	{"HERZLICH", 8, 238581},
	{"CANNAVARO", 9, 238582},
	{"MEGESTROL", 9, 238583},
	{"ELLARD", 6, 238584},
	{"DEGRAFF", 7, 238585},
	{"HESHAM", 6, 238586},
	{"ANALYSISCOMMON", 14, 238587},
	{"VONGO", 5, 238588},
	{"MEMOIRIST", 9, 238589},
	{"BESTOF", 6, 238590},
	{"ASWEL", 5, 238591},
	{"TRICHLORO", 9, 238592},
	{"WOHNORT", 7, 238593},
	{"REMASTERS", 9, 238594},
	{"MACERO", 6, 238595},
	{"KWP", 3, 238596},
	{"ATAPATTU", 8, 238597},
	{"MUSICDISH", 9, 238598},
	{"KPLC", 4, 238599},
	{"COSTLINESS", 10, 238600},
	{"ALPINIST", 8, 238601},
	{"OVERSTAY", 8, 238602},
	{"NACHTMUSIK", 10, 238603},
	{"IDIOTYPIC", 9, 238604},
	{"HARDISTY", 8, 238605},
	{"TOLTERODINE", 11, 238606},
	{"IACONO", 6, 238607},
	{"ARRE", 4, 238608},
	{"ANMERKUNGEN", 11, 238609},
	{"TKWIN", 5, 238610},
	{"WILS", 4, 238611},
	{"JMLAB", 5, 238612},
	{"ENSAYOS", 7, 238613},
	{"SAYADAW", 7, 238614},
	{"HARDSCAPE", 9, 238615},
	{"MANSERVANT", 10, 238616},
	{"BALLYMORE", 9, 238617},
	{"FRENZEL", 7, 238618},
	{"EXTERIORES", 10, 238619},
	{"OUTERS", 6, 238620},
	{"JORIE", 5, 238621},
	{"BELLIVEAU", 9, 238622},
	{"FROSTWOLF", 9, 238623},
	{"UNLUCKILY", 9, 238624},
	{"TSURUMI", 7, 238625},
	{"SYNOVUS", 7, 238626},
	{"PREMIE", 6, 238627},
	{"PLUMPED", 7, 238628},
	{"OVERRUNNING", 11, 238629},
	{"WORKFLOWGEN", 11, 238630},
	{"CELLBLOCK", 9, 238631},
	{"SCOTRAIL", 8, 238632},
	{"PRETENSIONERS", 13, 238633},
	{"CONCEALABLE", 11, 238634},
	{"APPENA", 6, 238635},
	{"KARAK", 5, 238636},
	{"KERNES", 6, 238637},
	{"PARMELIA", 8, 238638},
	{"BIOGRAPHICA", 11, 238639},
	{"ALLING", 6, 238640},
	{"TOWNCAR", 7, 238641},
	{"TELCON", 6, 238642},
	{"CHONGYOHAK", 10, 238643},
	{"HALLET", 6, 238644},
	{"ALIMENTI", 8, 238645},
	{"RONCHI", 6, 238646},
	{"MATLIN", 6, 238647},
	{"LIFEWAVE", 8, 238648},
	{"CYNDIE", 6, 238649},
	{"APPOSED", 7, 238650},
	{"HETEROGENIC", 11, 238651},
	{"ROEHM", 5, 238652},
	{"MERRICKVILLE", 12, 238653},
	{"LICHENIFORMIS", 13, 238654},
	{"COLOCAR", 7, 238655},
	{"CLICKATELL", 10, 238656},
	{"FRIEDERICH", 10, 238657},
	{"PELAGIA", 7, 238658},
	{"SOCIOLOGIA", 10, 238659},
	{"HAWTHORNS", 9, 238660},
	{"DOWNFALLS", 9, 238661},
	{"MDPS", 4, 238662},
	{"ELEFANTE", 8, 238663},
	{"MILBLOG", 7, 238664},
	{"LUMBINI", 7, 238665},
	{"MAXNET", 6, 238666},
	{"KRISTO", 6, 238667},
	{"PROCREATIVE", 11, 238668},
	{"GLUCOSYLTRANSFERASE", 19, 238669},
	{"SOFTFORALL", 10, 238670},
	{"MANGINO", 7, 238671},
	{"DISINHERITED", 12, 238672},
	{"ZETAFAX", 7, 238673},
	{"RESOUNDS", 8, 238674},
	{"MOVIEMAKERS", 11, 238675},
	{"DAMSON", 6, 238676},
	{"ANGLICARE", 9, 238677},
	{"WAGENAAR", 8, 238678},
	{"UNPACKS", 7, 238679},
	{"HRLY", 4, 238680},
	{"HERBERGER", 9, 238681},
	{"EXCAL", 5, 238682},
	{"OMONIA", 6, 238683},
	{"EUROCRYPT", 9, 238684},
	{"DLVOIRE", 7, 238685},
	{"ZAOUI", 5, 238686},
	{"SILICONBEAT", 11, 238687},
	{"CRUT", 4, 238688},
	{"COLLETTI", 8, 238689},
	{"TIPPI", 5, 238690},
	{"NITRIS", 6, 238691},
	{"MULLITE", 7, 238692},
	{"BACKFENCE", 9, 238693},
	{"FORL", 4, 238694},
	{"CGAL", 4, 238695},
	{"DAUGH", 5, 238696},
	{"AURANGZEB", 9, 238697},
	{"REBELO", 6, 238698},
	{"THYMOCYTE", 9, 238699},
	{"NEXTBASE", 8, 238700},
	{"FUTUROTIC", 9, 238701},
	{"POPULARISE", 10, 238702},
	{"KOKU", 4, 238703},
	{"LWZ", 3, 238704},
	{"KALONA", 6, 238705},
	{"GLASSNER", 8, 238706},
	{"STRATHALBYN", 11, 238707},
	{"TXCN", 4, 238708},
	{"ROOIJ", 5, 238709},
	{"OLAJUWON", 8, 238710},
	{"HONEYBALL", 9, 238711},
	{"BRANDEL", 7, 238712},
	{"ATTYTOOD", 8, 238713},
	{"ANCIENTLY", 9, 238714},
	{"ADAY", 4, 238715},
	{"PRECOLLEGE", 10, 238716},
	{"MICROMECHANICS", 14, 238717},
	{"LINTOUCH", 8, 238718},
	{"CLAGUE", 6, 238719},
	{"DUFFERS", 7, 238720},
	{"HRQOL", 5, 238721},
	{"EAZEL", 5, 238722},
	{"TZAR", 4, 238723},
	{"MAPUTALAND", 10, 238724},
	{"ASTOUNDS", 8, 238725},
	{"SYWARE", 6, 238726},
	{"NONBELIEVERS", 12, 238727},
	{"UDD", 3, 238728},
	{"MEDIASET", 8, 238729},
	{"WENDIE", 6, 238730},
	{"NEUROKININ", 10, 238731},
	{"GRAGG", 5, 238732},
	{"FUDGY", 5, 238733},
	{"BRANCHPOINT", 11, 238734},
	{"SATAII", 6, 238735},
	{"HEEREN", 6, 238736},
	{"REMAINETH", 9, 238737},
	{"TELENOVELAS", 11, 238738},
	{"MIXOLOGY", 8, 238739},
	{"DEEPLAY", 7, 238740},
	{"RATIONE", 7, 238741},
	{"INCISIONAL", 10, 238742},
	{"LASCH", 5, 238743},
	{"BEGETTING", 9, 238744},
	{"NWAY", 4, 238745},
	{"GILSSON", 7, 238746},
	{"GRECOTEL", 8, 238747},
	{"TESHUVA", 7, 238748},
	{"SLOUGHING", 9, 238749},
	{"GURGLED", 7, 238750},
	{"SANSOME", 7, 238751},
	{"NRIL", 4, 238752},
	{"DRECHSLER", 9, 238753},
	{"CAZZI", 5, 238754},
	{"XWRWN", 5, 238755},
	{"TRETHEWEY", 9, 238756},
	{"TOGETH", 6, 238757},
	{"CARDSTON", 8, 238758},
	{"ZYKS", 4, 238759},
	{"ZORL", 4, 238760},
	{"YRIK", 4, 238761},
	{"YJEO", 4, 238762},
	{"XSAR", 4, 238763},
	{"XINY", 4, 238764},
	{"VOEL", 4, 238765},
	{"UYED", 4, 238766},
	{"ULBW", 4, 238767},
	{"UETD", 4, 238768},
	{"TPUD", 4, 238769},
	{"SYRS", 4, 238770},
	{"SNPW", 4, 238771},
	{"SGSM", 4, 238772},
	{"RSVU", 4, 238773},
	{"RPMN", 4, 238774},
	{"RNWU", 4, 238775},
	{"RIIJ", 4, 238776},
	{"RDWY", 4, 238777},
	{"RBSG", 4, 238778},
	{"PMKI", 4, 238779},
	{"ORWC", 4, 238780},
	{"OKRY", 4, 238781},
	{"NZLA", 4, 238782},
	{"NYGW", 4, 238783},
	{"NPYT", 4, 238784},
	{"NGDM", 4, 238785},
	{"MNYA", 4, 238786},
	{"MJHL", 4, 238787},
	{"MEKL", 4, 238788},
	{"LUKK", 4, 238789},
	{"LMUG", 4, 238790},
	{"KYNU", 4, 238791},
	{"KYEC", 4, 238792},
	{"KBYV", 4, 238793},
	{"INPB", 4, 238794},
	{"HVUL", 4, 238795},
	{"HIVD", 4, 238796},
	{"GURW", 4, 238797},
	{"GGWE", 4, 238798},
	{"GAAW", 4, 238799},
	{"FSJU", 4, 238800},
	{"EUXB", 4, 238801},
	{"ECWT", 4, 238802},
	{"EBSB", 4, 238803},
	{"DUFE", 4, 238804},
	{"DTIK", 4, 238805},
	{"DORZ", 4, 238806},
	{"DMPF", 4, 238807},
	{"DJSE", 4, 238808},
	{"DAKP", 4, 238809},
	{"DAHD", 4, 238810},
	{"CREJ", 4, 238811},
	{"BUTX", 4, 238812},
	{"BOFV", 4, 238813},
	{"BIAY", 4, 238814},
	{"AMRB", 4, 238815},
	{"MONTIGNAC", 9, 238816},
	{"BLONDYNA", 8, 238817},
	{"PROCHARGER", 10, 238818},
	{"JARDINPRAYER", 12, 238819},
	{"HYDROGEOLOGIST", 14, 238820},
	{"JULATTEN", 8, 238821},
	{"DRABA", 5, 238822},
	{"WEICK", 5, 238823},
	{"TABFIND", 7, 238824},
	{"RHYMIN", 6, 238825},
	{"CRYPTOCOCCOSIS", 14, 238826},
	{"ANAEROBES", 9, 238827},
	{"TIBSHIRANI", 10, 238828},
	{"WOWK", 4, 238829},
	{"WABASSO", 7, 238830},
	{"SCHEINT", 7, 238831},
	{"PRSSA", 5, 238832},
	{"SHIPPINGPHENTERMINE", 19, 238833},
	{"ROOMIER", 7, 238834},
	{"NORTHWESTWARD", 13, 238835},
	{"MOTUS", 5, 238836},
	{"COEXISTS", 8, 238837},
	{"YMP", 3, 238838},
	{"SAMSA", 5, 238839},
	{"HERMANTOWN", 10, 238840},
	{"MANTENER", 8, 238841},
	{"LABELMAKER", 10, 238842},
	{"BARDOLINO", 9, 238843},
	{"CONTECH", 7, 238844},
	{"VORONTSOV", 9, 238845},
	{"CHOLESTERYL", 11, 238846},
	{"BUMMING", 7, 238847},
	{"GIBI", 4, 238848},
	{"OVERSTEPPING", 12, 238849},
	{"AUDIOCD", 7, 238850},
	{"MENDY", 5, 238851},
	{"JAHRESBERICHT", 13, 238852},
	{"INCHER", 6, 238853},
	{"USSHER", 6, 238854},
	{"COLUMNINDEX", 11, 238855},
	{"SCHUESSLER", 10, 238856},
	{"GLOSARIO", 8, 238857},
	{"DIAC", 4, 238858},
	{"SANTER", 6, 238859},
	{"MILBURY", 7, 238860},
	{"VACHSS", 6, 238861},
	{"SWAMINARAYAN", 12, 238862},
	{"RECUERDO", 8, 238863},
	{"HERCEG", 6, 238864},
	{"MYEONG", 6, 238865},
	{"CEASER", 6, 238866},
	{"MINIMED", 7, 238867},
	{"WICB", 4, 238868},
	{"PJR", 3, 238869},
	{"DIRECTORYDIRECTORY", 18, 238870},
	{"CALENDA", 7, 238871},
	{"MOSIAH", 6, 238872},
	{"DACAPO", 6, 238873},
	{"CHERAS", 6, 238874},
	{"BERGES", 6, 238875},
	{"ACCORIDNG", 9, 238876},
	{"OCONNELL", 8, 238877},
	{"WEBSPAM", 7, 238878},
	{"PADUAN", 6, 238879},
	{"MAKEDONIJA", 10, 238880},
	{"FLORIA", 6, 238881},
	{"HICKERSON", 9, 238882},
	{"COLLYMORE", 9, 238883},
	{"SUPERDISC", 9, 238884},
	{"SOLIA", 5, 238885},
	{"QUADRATICALLY", 13, 238886},
	{"SALIOR", 6, 238887},
	{"OSCURO", 6, 238888},
	{"ARTERIOSCLER", 12, 238889},
	{"VECTORING", 9, 238890},
	{"ALICA", 5, 238891},
	{"CONDUC", 6, 238892},
	{"CHESTERMAN", 10, 238893},
	{"ZOEGIRL", 7, 238894},
	{"WEBWISE", 7, 238895},
	{"VELCADE", 7, 238896},
	{"PORTMARNOCK", 11, 238897},
	{"PINENE", 6, 238898},
	{"MESQUITA", 8, 238899},
	{"HOPEFULNESS", 11, 238900},
	{"HANUS", 5, 238901},
	{"ESZTERGOM", 9, 238902},
	{"AUTORA", 6, 238903},
	{"APPELANT", 8, 238904},
	{"SPECIALSRESEARCH", 16, 238905},
	{"ROCKA", 5, 238906},
	{"PCSFOREVERYONE", 14, 238907},
	{"STOCKSDALE", 10, 238908},
	{"TELEIT", 6, 238909},
	{"ASHBACHER", 9, 238910},
	{"TERAH", 5, 238911},
	{"TAAFFE", 6, 238912},
	{"BRANCHBURG", 10, 238913},
	{"POIL", 4, 238914},
	{"MATAN", 5, 238915},
	{"DYNAMIST", 8, 238916},
	{"TARAGO", 6, 238917},
	{"SAXMUNDHAM", 10, 238918},
	{"MCNUGGETS", 9, 238919},
	{"INHABER", 7, 238920},
	{"BARNARDOS", 9, 238921},
	{"VOILES", 6, 238922},
	{"JCJ", 3, 238923},
	{"HOMETOWNNEWS", 12, 238924},
	{"PHPLINKS", 8, 238925},
	{"MIDSTATE", 8, 238926},
	{"ALLERGIE", 8, 238927},
	{"UNSCHOOLED", 10, 238928},
	{"RAMAZAN", 7, 238929},
	{"HOMEPORTFOLIO", 13, 238930},
	{"GIBERSON", 8, 238931},
	{"ARNSTEIN", 8, 238932},
	{"MEGHANN", 7, 238933},
	{"ELLAGIC", 7, 238934},
	{"CITER", 5, 238935},
	{"BEAVERLODGE", 11, 238936},
	{"WHEEZY", 6, 238937},
	{"ESCC", 4, 238938},
	{"GAUTREAUX", 9, 238939},
	{"PANNONIA", 8, 238940},
	{"MONDA", 5, 238941},
	{"BRAMKA", 6, 238942},
	{"BETONY", 6, 238943},
	{"DEHORS", 6, 238944},
	{"DDEBUG", 6, 238945},
	{"FISHTAILS", 9, 238946},
	{"MIGNONE", 7, 238947},
	{"CITYU", 5, 238948},
	{"AMERINDIANS", 11, 238949},
	{"PKGINFO", 7, 238950},
	{"ORGANICA", 8, 238951},
	{"TRIABLE", 7, 238952},
	{"TOESTELLEN", 10, 238953},
	{"LIVINGAGENTS", 12, 238954},
	{"LOQUO", 5, 238955},
	{"KAZZ", 4, 238956},
	{"CANUTILLO", 9, 238957},
	{"ARTHROPATHY", 11, 238958},
	{"PDXPHP", 6, 238959},
	{"MINIMUN", 7, 238960},
	{"ICATION", 7, 238961},
	{"VINDICTIVENESS", 14, 238962},
	{"PERIVENTRICULAR", 15, 238963},
	{"CLUELESSNESS", 12, 238964},
	{"PROTABLE", 8, 238965},
	{"EITEM", 5, 238966},
	{"SHANKARA", 8, 238967},
	{"OZYMANDIAS", 10, 238968},
	{"ESOPUS", 6, 238969},
	{"AKEY", 4, 238970},
	{"YANUKOVICH", 10, 238971},
	{"PALMQUIST", 9, 238972},
	{"INDOCHINESE", 11, 238973},
	{"HEEPLIST", 8, 238974},
	{"ENUNCIATE", 9, 238975},
	{"LONDRINA", 8, 238976},
	{"SOULSTAR", 8, 238977},
	{"POTEST", 6, 238978},
	{"WAKTU", 5, 238979},
	{"STRATAGY", 8, 238980},
	{"DZIWKI", 6, 238981},
	{"RUBIDOUX", 8, 238982},
	{"LOLLING", 7, 238983},
	{"LOANREAL", 8, 238984},
	{"ABOUE", 5, 238985},
	{"XTREMEMUSIC", 11, 238986},
	{"KOOLSPAN", 8, 238987},
	{"DRAMATICO", 9, 238988},
	{"DIKING", 6, 238989},
	{"CRISTIE", 7, 238990},
	{"ACCELEPORT", 10, 238991},
	{"RAVN", 4, 238992},
	{"OSDIR", 5, 238993},
	{"BARUA", 5, 238994},
	{"PRBS", 4, 238995},
	{"MIMEOGRAPHED", 12, 238996},
	{"LACEWINGS", 9, 238997},
	{"EXTORTING", 9, 238998},
	{"ALPO", 4, 238999},
	{"GAMMILL", 7, 239000},
	{"CHATT", 5, 239001},
	{"AFFILLIATE", 10, 239002},
	{"PROPERY", 7, 239003},
	{"MAGAR", 5, 239004},
	{"REPICA", 6, 239005},
	{"CCIC", 4, 239006},
	{"KERT", 4, 239007},
	{"ZEIDLER", 7, 239008},
	{"RHEINISCHE", 10, 239009},
	{"PACKETIZED", 10, 239010},
	{"LENTA", 5, 239011},
	{"ADVENTURED", 10, 239012},
	{"SLYSOFT", 7, 239013},
	{"CWEB", 4, 239014},
	{"CERL", 4, 239015},
	{"RONAL", 5, 239016},
	{"ELKAAR", 6, 239017},
	{"LETTERWINNER", 12, 239018},
	{"FOIR", 4, 239019},
	{"EBBTIDE", 7, 239020},
	{"ABSCONDING", 10, 239021},
	{"WOODACRE", 8, 239022},
	{"ELLERMANN", 9, 239023},
	{"CAMPEN", 6, 239024},
	{"PSILOCYBE", 9, 239025},
	{"BATOK", 5, 239026},
	{"PERFMON", 7, 239027},
	{"APPLICATA", 9, 239028},
	{"ZYGA", 4, 239029},
	{"ZPAN", 4, 239030},
	{"ZKYW", 4, 239031},
	{"ZGAR", 4, 239032},
	{"ZEOB", 4, 239033},
	{"ZALW", 4, 239034},
	{"YNKE", 4, 239035},
	{"YIPU", 4, 239036},
	{"YECU", 4, 239037},
	{"YARH", 4, 239038},
	{"XENV", 4, 239039},
	{"WRCO", 4, 239040},
	{"VDSH", 4, 239041},
	{"UZOU", 4, 239042},
	{"UMPQ", 4, 239043},
	{"ULRY", 4, 239044},
	{"TWYA", 4, 239045},
	{"TLUF", 4, 239046},
	{"SMUP", 4, 239047},
	{"SMIY", 4, 239048},
	{"SFSR", 4, 239049},
	{"SEPY", 4, 239050},
	{"SDME", 4, 239051},
	{"RRRO", 4, 239052},
	{"QTRA", 4, 239053},
	{"PTUT", 4, 239054},
	{"PILU", 4, 239055},
	{"OXOW", 4, 239056},
	{"OVIF", 4, 239057},
	{"NPIQ", 4, 239058},
	{"NKTY", 4, 239059},
	{"MMPH", 4, 239060},
	{"MKYL", 4, 239061},
	{"KUHE", 4, 239062},
	{"IGUT", 4, 239063},
	{"IDOJ", 4, 239064},
	{"IBOG", 4, 239065},
	{"HAKP", 4, 239066},
	{"GSUA", 4, 239067},
	{"GOKN", 4, 239068},
	{"FYFA", 4, 239069},
	{"FTMT", 4, 239070},
	{"FCCE", 4, 239071},
	{"FBIM", 4, 239072},
	{"EXYI", 4, 239073},
	{"ESMG", 4, 239074},
	{"ECVE", 4, 239075},
	{"DZEU", 4, 239076},
	{"DYUT", 4, 239077},
	{"DTCE", 4, 239078},
	{"DRSW", 4, 239079},
	{"DEPM", 4, 239080},
	{"CURG", 4, 239081},
	{"CHTG", 4, 239082},
	{"CEGT", 4, 239083},
	{"BYNH", 4, 239084},
	{"BCOP", 4, 239085},
	{"BAKT", 4, 239086},
	{"APYG", 4, 239087},
	{"APHG", 4, 239088},
	{"APEQ", 4, 239089},
	{"ANPG", 4, 239090},
	{"AKGU", 4, 239091},
	{"YMG", 3, 239092},
	{"BILLYS", 6, 239093},
	{"AVERITT", 7, 239094},
	{"NVESTMENT", 9, 239095},
	{"BRUGGER", 7, 239096},
	{"MALANGA", 7, 239097},
	{"POITRAS", 7, 239098},
	{"IPERF", 5, 239099},
	{"FPCSRC", 6, 239100},
	{"PTRSSCHEMA", 10, 239101},
	{"VRAC", 4, 239102},
	{"ETHNOHISTORY", 12, 239103},
	{"DGGE", 4, 239104},
	{"CORROSIVITY", 11, 239105},
	{"HOLSTEINS", 9, 239106},
	{"VOIPTEST", 8, 239107},
	{"MACEK", 5, 239108},
	{"FANKHAUSER", 10, 239109},
	{"ECLASS", 6, 239110},
	{"VALINOR", 7, 239111},
	{"REFERATE", 8, 239112},
	{"ALTERNETYOUR", 12, 239113},
	{"GETSTATE", 8, 239114},
	{"CLATTERED", 9, 239115},
	{"PEREGIAN", 8, 239116},
	{"INCANTO", 7, 239117},
	{"NEUTRALISED", 11, 239118},
	{"ITEMSET", 7, 239119},
	{"HARLES", 6, 239120},
	{"AACP", 4, 239121},
	{"VITRUVIUS", 9, 239122},
	{"POUVANT", 7, 239123},
	{"POSTINDUSTRIAL", 14, 239124},
	{"LORES", 5, 239125},
	{"CHATEAUGAY", 10, 239126},
	{"OURE", 4, 239127},
	{"QBERT", 5, 239128},
	{"DEPRESSOR", 9, 239129},
	{"JOURDANTON", 10, 239130},
	{"HYDROMET", 8, 239131},
	{"COUDAL", 6, 239132},
	{"JABARI", 6, 239133},
	{"HAAKE", 5, 239134},
	{"CARILLION", 9, 239135},
	{"SCOBLETE", 8, 239136},
	{"JANOWITZ", 8, 239137},
	{"UARTS", 5, 239138},
	{"SENOKOT", 7, 239139},
	{"LAKELANDS", 9, 239140},
	{"KOLZIG", 6, 239141},
	{"DELONGE", 7, 239142},
	{"MIFSUD", 6, 239143},
	{"COFFEEVILLE", 11, 239144},
	{"BAKURA", 6, 239145},
	{"WROBLEWSKI", 10, 239146},
	{"UNSTEADILY", 10, 239147},
	{"SUFFERANCE", 10, 239148},
	{"UNSTEADINESS", 12, 239149},
	{"RITTLE", 6, 239150},
	{"PHENO", 5, 239151},
	{"EMAGAZINES", 10, 239152},
	{"DAIRYMAN", 8, 239153},
	{"VELDA", 5, 239154},
	{"HORKHEIMER", 10, 239155},
	{"CPZ", 3, 239156},
	{"COINFECTED", 10, 239157},
	{"WRAPUPS", 7, 239158},
	{"WOLUWE", 6, 239159},
	{"SPELEOLOGICAL", 13, 239160},
	{"SIMLINE", 7, 239161},
	{"MUU", 3, 239162},
	{"IONTOPHORESIS", 13, 239163},
	{"ICMI", 4, 239164},
	{"NUTRIT", 6, 239165},
	{"ZACHRY", 6, 239166},
	{"RUNUP", 5, 239167},
	{"ELIYA", 5, 239168},
	{"ELECTROENCEPHALOGRAPHIC", 23, 239169},
	{"ARBEITSPLATZ", 12, 239170},
	{"VALDESE", 7, 239171},
	{"MOVIR", 5, 239172},
	{"INSTALLPASSWD", 13, 239173},
	{"GREERS", 6, 239174},
	{"ALLENE", 6, 239175},
	{"NUMBSKULL", 9, 239176},
	{"HEINBERG", 8, 239177},
	{"TOGTHER", 7, 239178},
	{"CHARMANT", 8, 239179},
	{"TETRAHYDROFOLATE", 16, 239180},
	{"STRASSBURG", 10, 239181},
	{"ENSEIGNANTS", 11, 239182},
	{"APOTHECARIES", 12, 239183},
	{"PRICELISTS", 10, 239184},
	{"KEPPLE", 6, 239185},
	{"STARRS", 6, 239186},
	{"CASHADVANCE", 11, 239187},
	{"WILDERMUTH", 10, 239188},
	{"ONEPASS", 7, 239189},
	{"MEDE", 4, 239190},
	{"LEVERANS", 8, 239191},
	{"DAHLAN", 6, 239192},
	{"CHAUFFER", 8, 239193},
	{"DRIECTORY", 9, 239194},
	{"BOOTSKIN", 8, 239195},
	{"METOD", 5, 239196},
	{"ABAIXO", 6, 239197},
	{"ADVEN", 5, 239198},
	{"RAPTURES", 8, 239199},
	{"PICTUS", 6, 239200},
	{"LOANBAD", 7, 239201},
	{"DUNELLEN", 8, 239202},
	{"RIQUELME", 8, 239203},
	{"DINNA", 5, 239204},
	{"CARONA", 6, 239205},
	{"BARRENNESS", 10, 239206},
	{"UNDOPED", 7, 239207},
	{"PSYCHONOMIC", 11, 239208},
	{"DEMOC", 5, 239209},
	{"SECFILTERSELECTIVE", 18, 239210},
	{"YELLOWTHROAT", 12, 239211},
	{"UGESKR", 6, 239212},
	{"SKYMAP", 6, 239213},
	{"POWLEY", 6, 239214},
	{"MARSHALLVILLE", 13, 239215},
	{"DIECUT", 6, 239216},
	{"ARSC", 4, 239217},
	{"VANEGAS", 7, 239218},
	{"PLACIDLY", 8, 239219},
	{"AKERCOCKE", 9, 239220},
	{"RHEOSTAT", 8, 239221},
	{"HOHENWALD", 9, 239222},
	{"BAWLED", 6, 239223},
	{"HARVESTABLE", 11, 239224},
	{"GENEREL", 7, 239225},
	{"SHOWBAND", 8, 239226},
	{"UNSUBSC", 7, 239227},
	{"PLAND", 5, 239228},
	{"MAYANK", 6, 239229},
	{"PRITTY", 6, 239230},
	{"JRICHARD", 8, 239231},
	{"CHCL", 4, 239232},
	{"QUICKFIRE", 9, 239233},
	{"JUANS", 5, 239234},
	{"BISHO", 5, 239235},
	{"JEZREEL", 7, 239236},
	{"VERDOT", 6, 239237},
	{"PRINTSCREEN", 11, 239238},
	{"ENKELE", 6, 239239},
	{"YBP", 3, 239240},
	{"SCHILLINGER", 11, 239241},
	{"SIDECARS", 8, 239242},
	{"SIBERRY", 7, 239243},
	{"PROTOPLASM", 10, 239244},
	{"MODULEID", 8, 239245},
	{"LINUM", 5, 239246},
	{"WECK", 4, 239247},
	{"PERHENTIAN", 10, 239248},
	{"HANYANG", 7, 239249},
	{"SATANICA", 8, 239250},
	{"PHOSPHOGLUCONATE", 16, 239251},
	{"MOOMBA", 6, 239252},
	{"MEPA", 4, 239253},
	{"GORACA", 6, 239254},
	{"DOTMOMS", 7, 239255},
	{"ALGUNS", 6, 239256},
	{"WILCZEK", 7, 239257},
	{"UNDS", 4, 239258},
	{"PIPEFISH", 8, 239259},
	{"MEASURMENT", 10, 239260},
	{"GRISBI", 6, 239261},
	{"GRANODIORITE", 12, 239262},
	{"EDPUG", 5, 239263},
	{"CANONBURY", 9, 239264},
	{"WATERBASED", 10, 239265},
	{"SOFTPILE", 8, 239266},
	{"RETIMING", 8, 239267},
	{"LINDI", 5, 239268},
	{"KAUMUDI", 7, 239269},
	{"DVCS", 4, 239270},
	{"NITIONS", 7, 239271},
	{"TOOMS", 5, 239272},
	{"MICROTURBINES", 13, 239273},
	{"CORRESPON", 9, 239274},
	{"TEKNISK", 7, 239275},
	{"HEDGECOCK", 9, 239276},
	{"BLUEBOTTLE", 10, 239277},
	{"MOWLEM", 6, 239278},
	{"KOOIJ", 5, 239279},
	{"CAYTON", 6, 239280},
	{"BARISAL", 7, 239281},
	{"HILES", 5, 239282},
	{"CORYDORAS", 9, 239283},
	{"COCKERHAM", 9, 239284},
	{"TRIGA", 5, 239285},
	{"LUCANE", 6, 239286},
	{"BARGRAPH", 8, 239287},
	{"REPACKED", 8, 239288},
	{"RATCHATHANI", 11, 239289},
	{"CLAYBOURN", 9, 239290},
	{"ARLIN", 5, 239291},
	{"AMURO", 5, 239292},
	{"HOLICS", 6, 239293},
	{"BALLYSHANNON", 12, 239294},
	{"MAYN", 4, 239295},
	{"CAUTHEN", 7, 239296},
	{"PYP", 3, 239297},
	{"UBCINTL", 7, 239298},
	{"PULMONOLOGISTS", 14, 239299},
	{"DYSPEPTIC", 9, 239300},
	{"SOFTSIDE", 8, 239301},
	{"IFTYPE", 6, 239302},
	{"GOREGAON", 8, 239303},
	{"PODKAPOVA", 9, 239304},
	{"GOOLS", 5, 239305},
	{"CHADWYCK", 8, 239306},
	{"BROGUES", 7, 239307},
	{"MEMORISED", 9, 239308},
	{"ISHBADIDDLE", 11, 239309},
	{"FXBLOG", 6, 239310},
	{"SDESC", 5, 239311},
	{"VIAGEM", 6, 239312},
	{"POELS", 5, 239313},
	{"ARMONIA", 7, 239314},
	{"SALIENCY", 8, 239315},
	{"RRV", 3, 239316},
	{"KEEANI", 6, 239317},
	{"MULTIBLITZ", 10, 239318},
	{"ENDOPEROXIDE", 12, 239319},
	{"ZKOP", 4, 239320},
	{"ZDEP", 4, 239321},
	{"YVSS", 4, 239322},
	{"YUKH", 4, 239323},
	{"YGAO", 4, 239324},
	{"XPOO", 4, 239325},
	{"XGAV", 4, 239326},
	{"WYSO", 4, 239327},
	{"WYSI", 4, 239328},
	{"WLFI", 4, 239329},
	{"WBOI", 4, 239330},
	{"VAKW", 4, 239331},
	{"ULMY", 4, 239332},
	{"UIBI", 4, 239333},
	{"UETL", 4, 239334},
	{"TRSL", 4, 239335},
	{"TRBS", 4, 239336},
	{"SSPD", 4, 239337},
	{"SBCI", 4, 239338},
	{"SBAJ", 4, 239339},
	{"RXBR", 4, 239340},
	{"RUZR", 4, 239341},
	{"RIGP", 4, 239342},
	{"PNYS", 4, 239343},
	{"PMFL", 4, 239344},
	{"OWDJ", 4, 239345},
	{"OMMH", 4, 239346},
	{"ODIY", 4, 239347},
	{"NPOB", 4, 239348},
	{"MNDI", 4, 239349},
	{"MLBD", 4, 239350},
	{"MIBN", 4, 239351},
	{"LCOK", 4, 239352},
	{"KMEG", 4, 239353},
	{"KHEJ", 4, 239354},
	{"KASQ", 4, 239355},
	{"JEWT", 4, 239356},
	{"IGWR", 4, 239357},
	{"GHZP", 4, 239358},
	{"GCCO", 4, 239359},
	{"FMRT", 4, 239360},
	{"FIXL", 4, 239361},
	{"EHCL", 4, 239362},
	{"DWYC", 4, 239363},
	{"DRYY", 4, 239364},
	{"DKLU", 4, 239365},
	{"CZIS", 4, 239366},
	{"CFEB", 4, 239367},
	{"BYBM", 4, 239368},
	{"AWEP", 4, 239369},
	{"AUAD", 4, 239370},
	{"AQLA", 4, 239371},
	{"AKPH", 4, 239372},
	{"ADRM", 4, 239373},
	{"MANABE", 6, 239374},
	{"HUISH", 5, 239375},
	{"GUIDERA", 7, 239376},
	{"HANKO", 5, 239377},
	{"ELISPOT", 7, 239378},
	{"BALLEN", 6, 239379},
	{"SEERAD", 6, 239380},
	{"PREINCUBATED", 12, 239381},
	{"NACDS", 5, 239382},
	{"EPERNAY", 7, 239383},
	{"YNGLYN", 6, 239384},
	{"MESSALA", 7, 239385},
	{"GAUE", 4, 239386},
	{"GOODNEWS", 8, 239387},
	{"FPUTC", 5, 239388},
	{"CRICKLADE", 9, 239389},
	{"TAKED", 5, 239390},
	{"MOOSEWOOD", 9, 239391},
	{"PSEUDORABIES", 12, 239392},
	{"BREAGE", 6, 239393},
	{"RRLLRF", 6, 239394},
	{"MOLON", 5, 239395},
	{"XAVI", 4, 239396},
	{"ONCOPROTEIN", 11, 239397},
	{"FRANCORCHAMPS", 13, 239398},
	{"ARNIS", 5, 239399},
	{"SYSONCHIP", 9, 239400},
	{"LCASE", 5, 239401},
	{"DIFFIDENT", 9, 239402},
	{"SPORTIER", 8, 239403},
	{"VERAMENTE", 9, 239404},
	{"SZALAY", 6, 239405},
	{"ROTTMANN", 8, 239406},
	{"HONAUNAU", 8, 239407},
	{"KRIGE", 5, 239408},
	{"BIZZLE", 6, 239409},
	{"TIERING", 7, 239410},
	{"MISALIGNMENTS", 13, 239411},
	{"LDQ", 3, 239412},
	{"HOSTELING", 9, 239413},
	{"AMATA", 5, 239414},
	{"PINEMEADOW", 10, 239415},
	{"HEGOAK", 6, 239416},
	{"AFFIANCED", 9, 239417},
	{"PUSHRODS", 8, 239418},
	{"HUMBUCKING", 10, 239419},
	{"ICMC", 4, 239420},
	{"DESHAWN", 7, 239421},
	{"AVISHAI", 7, 239422},
	{"AUTODETECTION", 13, 239423},
	{"XPLAIN", 6, 239424},
	{"NKOSI", 5, 239425},
	{"LEFSETZ", 7, 239426},
	{"BYNAME", 6, 239427},
	{"UNITTESTS", 9, 239428},
	{"AMSTUTZ", 7, 239429},
	{"GSLIS", 5, 239430},
	{"SHAGS", 5, 239431},
	{"GIRAULT", 7, 239432},
	{"ALLOMBERT", 9, 239433},
	{"PEIRIS", 6, 239434},
	{"HANDLERY", 8, 239435},
	{"TATIONAL", 8, 239436},
	{"PUPPIE", 6, 239437},
	{"LUNDEEN", 7, 239438},
	{"COMPARTMENTED", 13, 239439},
	{"FTAM", 4, 239440},
	{"GENNUM", 6, 239441},
	{"EGADS", 5, 239442},
	{"CORKAGE", 7, 239443},
	{"SECURITAS", 9, 239444},
	{"HEDDIW", 6, 239445},
	{"GADJETS", 7, 239446},
	{"EBGP", 4, 239447},
	{"DURINGTHE", 9, 239448},
	{"COMMUNS", 7, 239449},
	{"BUIES", 5, 239450},
	{"ASAMBLEA", 8, 239451},
	{"VITELIC", 7, 239452},
	{"APPCONFIG", 9, 239453},
	{"ALSTOTT", 7, 239454},
	{"TRANSCONA", 9, 239455},
	{"THISTLEDOWN", 11, 239456},
	{"SLUSSER", 7, 239457},
	{"ZEKER", 5, 239458},
	{"SOLDADURA", 9, 239459},
	{"EUROPEEN", 8, 239460},
	{"BABYNET", 7, 239461},
	{"HENBANE", 7, 239462},
	{"DECKHAND", 8, 239463},
	{"WIGNALL", 7, 239464},
	{"POLYGAMIST", 10, 239465},
	{"OSMOTICS", 8, 239466},
	{"HISENSE", 7, 239467},
	{"BRIGDEN", 7, 239468},
	{"ENERGEX", 7, 239469},
	{"MERITON", 7, 239470},
	{"GHAZNI", 6, 239471},
	{"CULTURALES", 10, 239472},
	{"AKONIX", 6, 239473},
	{"METATECH", 8, 239474},
	{"LECTORS", 7, 239475},
	{"CHERRINGTON", 11, 239476},
	{"BREMMER", 7, 239477},
	{"GEBRUIKER", 9, 239478},
	{"GENARO", 6, 239479},
	{"EXCLUSIV", 8, 239480},
	{"INTERNATIONNALES", 16, 239481},
	{"CELESTIN", 8, 239482},
	{"ATTRAC", 6, 239483},
	{"NANCIE", 6, 239484},
	{"LENTINI", 7, 239485},
	{"FOXHEART", 8, 239486},
	{"CARDIOLOGIE", 11, 239487},
	{"PETHERTON", 9, 239488},
	{"NATURALIZE", 10, 239489},
	{"DUMM", 4, 239490},
	{"CIONA", 5, 239491},
	{"CHARISMATICS", 12, 239492},
	{"TIKANGA", 7, 239493},
	{"MALPRACTICES", 12, 239494},
	{"GUILELESS", 9, 239495},
	{"GOTLIEB", 7, 239496},
	{"EBBE", 4, 239497},
	{"YOUSENDIT", 9, 239498},
	{"OPTICALS", 8, 239499},
	{"MARQUEUR", 8, 239500},
	{"YOSHINOBU", 9, 239501},
	{"PRANAB", 6, 239502},
	{"ORTHOLOGUE", 10, 239503},
	{"ANTHROPOSOPHICAL", 16, 239504},
	{"VEILINGEN", 9, 239505},
	{"REGIONES", 8, 239506},
	{"QUIEDEVILLE", 11, 239507},
	{"JACKFRUIT", 9, 239508},
	{"HENLOPEN", 8, 239509},
	{"TOWLER", 6, 239510},
	{"EPOPROSTENOL", 12, 239511},
	{"CORRUPTLY", 9, 239512},
	{"DEMEULEMEESTER", 14, 239513},
	{"REYNOSO", 7, 239514},
	{"ARPEGGIATOR", 11, 239515},
	{"ALTITUDINAL", 11, 239516},
	{"WERY", 4, 239517},
	{"OXEGEN", 6, 239518},
	{"ARCHAEOGLOBUS", 13, 239519},
	{"LOCKSET", 7, 239520},
	{"FREIGHTS", 8, 239521},
	{"TRURLIB", 7, 239522},
	{"SPLOG", 5, 239523},
	{"SIFTWARE", 8, 239524},
	{"OPPROBRIUM", 10, 239525},
	{"ISOBUSTER", 9, 239526},
	{"MICAEL", 6, 239527},
	{"LIBGAIL", 7, 239528},
	{"GOTAMA", 6, 239529},
	{"COMEDI", 6, 239530},
	{"PTIONS", 6, 239531},
	{"ALDOSE", 6, 239532},
	{"EPITHELIOID", 11, 239533},
	{"ARMINGTON", 9, 239534},
	{"EVENEMENTEN", 11, 239535},
	{"BOKE", 4, 239536},
	{"TENZING", 7, 239537},
	{"NRAD", 4, 239538},
	{"CLOCKERS", 8, 239539},
	{"BROCKINGTON", 11, 239540},
	{"RAVINDER", 8, 239541},
	{"POWERDOWN", 9, 239542},
	{"HIGHWORTH", 9, 239543},
	{"PREOPTIC", 8, 239544},
	{"BROADWOOD", 9, 239545},
	{"WOLFCRAFT", 9, 239546},
	{"WMAKER", 6, 239547},
	{"LEVSKI", 6, 239548},
	{"GEHEIME", 7, 239549},
	{"AMINATION", 9, 239550},
	{"JAGGY", 5, 239551},
	{"REYN", 4, 239552},
	{"DEFENSETECH", 11, 239553},
	{"MEZEI", 5, 239554},
	{"GOINES", 6, 239555},
	{"LEGALIZES", 9, 239556},
	{"GLUTTER", 7, 239557},
	{"BONDARENKO", 10, 239558},
	{"WAARD", 5, 239559},
	{"FTCA", 4, 239560},
	{"SOLAPUR", 7, 239561},
	{"SOFTWARD", 8, 239562},
	{"TRATATA", 7, 239563},
	{"NALIDIXIC", 9, 239564},
	{"MYTOPIC", 7, 239565},
	{"HOMILETICS", 10, 239566},
	{"CANTEY", 6, 239567},
	{"GRANATO", 7, 239568},
	{"VLOOKUP", 7, 239569},
	{"PHPNE", 5, 239570},
	{"MOTER", 5, 239571},
	{"FENDED", 6, 239572},
	{"KENTRIDGE", 9, 239573},
	{"MILANA", 6, 239574},
	{"KHERA", 5, 239575},
	{"CHEAOEST", 8, 239576},
	{"BETROKKEN", 9, 239577},
	{"PARENTID", 8, 239578},
	{"NIDCD", 5, 239579},
	{"MMSC", 4, 239580},
	{"ZSAL", 4, 239581},
	{"ZONU", 4, 239582},
	{"ZLIV", 4, 239583},
	{"YKEO", 4, 239584},
	{"XVOT", 4, 239585},
	{"XTAG", 4, 239586},
	{"WOHY", 4, 239587},
	{"WMEH", 4, 239588},
	{"WAHP", 4, 239589},
	{"UZAD", 4, 239590},
	{"UXVE", 4, 239591},
	{"USNF", 4, 239592},
	{"UKIG", 4, 239593},
	{"TULM", 4, 239594},
	{"TPRY", 4, 239595},
	{"TOXM", 4, 239596},
	{"TBCH", 4, 239597},
	{"SOLZ", 4, 239598},
	{"SMGM", 4, 239599},
	{"SFTW", 4, 239600},
	{"SBWH", 4, 239601},
	{"POLJ", 4, 239602},
	{"PJET", 4, 239603},
	{"OIFM", 4, 239604},
	{"NYMW", 4, 239605},
	{"NUGO", 4, 239606},
	{"NEVW", 4, 239607},
	{"MYIA", 4, 239608},
	{"MOAW", 4, 239609},
	{"LZOR", 4, 239610},
	{"LUMK", 4, 239611},
	{"KJAW", 4, 239612},
	{"KEAZ", 4, 239613},
	{"JRAR", 4, 239614},
	{"JOOR", 4, 239615},
	{"IPKO", 4, 239616},
	{"ILFS", 4, 239617},
	{"IKPE", 4, 239618},
	{"HYKN", 4, 239619},
	{"GULH", 4, 239620},
	{"GOWP", 4, 239621},
	{"GMSU", 4, 239622},
	{"GHIJ", 4, 239623},
	{"FOBR", 4, 239624},
	{"FMRL", 4, 239625},
	{"FMCH", 4, 239626},
	{"FLVI", 4, 239627},
	{"FDRT", 4, 239628},
	{"FACD", 4, 239629},
	{"EWNF", 4, 239630},
	{"EEGW", 4, 239631},
	{"DSSD", 4, 239632},
	{"DOUJ", 4, 239633},
	{"DDBL", 4, 239634},
	{"CLME", 4, 239635},
	{"BYCC", 4, 239636},
	{"BCMU", 4, 239637},
	{"AZUT", 4, 239638},
	{"ARUV", 4, 239639},
	{"AQIY", 4, 239640},
	{"SKIFFS", 6, 239641},
	{"NOVIE", 5, 239642},
	{"JEWITT", 6, 239643},
	{"ASDB", 4, 239644},
	{"MALONYL", 7, 239645},
	{"INBLOGNITO", 10, 239646},
	{"DAUBECHIES", 10, 239647},
	{"AVETE", 5, 239648},
	{"HPSHOPPING", 10, 239649},
	{"GARZON", 6, 239650},
	{"CROMA", 5, 239651},
	{"AGROECOSYSTEMS", 14, 239652},
	{"UNPAGINATED", 11, 239653},
	{"SMBMOUNT", 8, 239654},
	{"SADDLEDOME", 10, 239655},
	{"ONEHANESPLACE", 13, 239656},
	{"DANB", 4, 239657},
	{"ZOROASTRIANS", 12, 239658},
	{"TRANSLA", 7, 239659},
	{"SALYUT", 6, 239660},
	{"PONNURU", 7, 239661},
	{"NACHUM", 6, 239662},
	{"LVIII", 5, 239663},
	{"LOGOWORKS", 9, 239664},
	{"TESTNG", 6, 239665},
	{"NACADA", 6, 239666},
	{"CLOZARIL", 8, 239667},
	{"BIOVAIL", 7, 239668},
	{"BASSPLAYER", 10, 239669},
	{"YAHPO", 5, 239670},
	{"CUTWORK", 7, 239671},
	{"AMMI", 4, 239672},
	{"ROTHFUSS", 8, 239673},
	{"MCVIE", 5, 239674},
	{"ECHEVERRIA", 10, 239675},
	{"SPACEHAB", 8, 239676},
	{"ROELOF", 6, 239677},
	{"GARAGEGAMES", 11, 239678},
	{"BLACKLIGHTS", 11, 239679},
	{"ROYAN", 5, 239680},
	{"NUDISTAS", 8, 239681},
	{"KONEXX", 6, 239682},
	{"KEMO", 4, 239683},
	{"WASCANA", 7, 239684},
	{"PLPGSQL", 7, 239685},
	{"PLABOY", 6, 239686},
	{"MICKLETHWAIT", 12, 239687},
	{"ISICS", 5, 239688},
	{"CHURLEY", 7, 239689},
	{"PRICEWATERHOUSE", 15, 239690},
	{"OLEYNIK", 7, 239691},
	{"DAVIDM", 6, 239692},
	{"REMBERT", 7, 239693},
	{"LART", 4, 239694},
	{"IMPUTATIONS", 11, 239695},
	{"RESORCINOL", 10, 239696},
	{"MZP", 3, 239697},
	{"TSUTSUMI", 8, 239698},
	{"DROGE", 5, 239699},
	{"IREC", 4, 239700},
	{"GLOSSARIO", 9, 239701},
	{"SALTBUSH", 8, 239702},
	{"NONCONDENSING", 13, 239703},
	{"SRIKANT", 7, 239704},
	{"SPELER", 6, 239705},
	{"EOBM", 4, 239706},
	{"DYNANET", 7, 239707},
	{"COLETTA", 7, 239708},
	{"FAUL", 4, 239709},
	{"SHERSTON", 8, 239710},
	{"HINCH", 5, 239711},
	{"BERRIOS", 7, 239712},
	{"AQUIFEX", 7, 239713},
	{"MARRI", 5, 239714},
	{"DESERIALIZER", 12, 239715},
	{"OLMEDO", 6, 239716},
	{"LEFORS", 6, 239717},
	{"CAMSFREE", 8, 239718},
	{"GOZER", 5, 239719},
	{"CULTURENET", 10, 239720},
	{"FANTASTICFICTION", 16, 239721},
	{"WEIST", 5, 239722},
	{"PONTOS", 6, 239723},
	{"ELECTROSURGICAL", 15, 239724},
	{"BUSNESAU", 8, 239725},
	{"MARCHIONESS", 11, 239726},
	{"HAVERS", 6, 239727},
	{"PFERD", 5, 239728},
	{"JANGLY", 6, 239729},
	{"DBGT", 4, 239730},
	{"HIRINGS", 7, 239731},
	{"SOFTWRAE", 8, 239732},
	{"RHEOLAETH", 9, 239733},
	{"SCREWUP", 7, 239734},
	{"CAPRICIOUSLY", 12, 239735},
	{"TENENT", 6, 239736},
	{"SPERMATIC", 9, 239737},
	{"IHEALTHBUZZ", 11, 239738},
	{"GANSKE", 6, 239739},
	{"ELENOR", 6, 239740},
	{"BOLLS", 5, 239741},
	{"NEWCOMEN", 8, 239742},
	{"NARVAEZ", 7, 239743},
	{"HIGHVIEW", 8, 239744},
	{"CHIRNSIDE", 9, 239745},
	{"UNUTILIZED", 10, 239746},
	{"FIRCREST", 8, 239747},
	{"RUSIN", 5, 239748},
	{"OVERLAKE", 8, 239749},
	{"DETRUSOR", 8, 239750},
	{"HONORARIOS", 10, 239751},
	{"TATRO", 5, 239752},
	{"CRASSOSTREA", 11, 239753},
	{"VILLEURBANNE", 12, 239754},
	{"BADDOW", 6, 239755},
	{"SLONY", 5, 239756},
	{"LOYALTON", 8, 239757},
	{"ANGSANA", 7, 239758},
	{"ECASH", 5, 239759},
	{"RICOS", 5, 239760},
	{"ETHNICAL", 8, 239761},
	{"CLICKPAYGO", 10, 239762},
	{"SALIF", 5, 239763},
	{"VERYGOOD", 8, 239764},
	{"IFCS", 4, 239765},
	{"BEHLING", 7, 239766},
	{"ANPEC", 5, 239767},
	{"CELAYA", 6, 239768},
	{"FANTASEA", 8, 239769},
	{"HOBBESIAN", 9, 239770},
	{"CAUCHON", 7, 239771},
	{"YMIR", 4, 239772},
	{"OCIMUM", 6, 239773},
	{"SUPERINTEND", 11, 239774},
	{"PICTET", 6, 239775},
	{"PETARD", 6, 239776},
	{"BANTERING", 9, 239777},
	{"KARJALAINEN", 11, 239778},
	{"ACARBOSE", 8, 239779},
	{"PROPAGULES", 10, 239780},
	{"PERSPIRING", 10, 239781},
	{"NODOSUM", 7, 239782},
	{"DHANI", 5, 239783},
	{"ZINDEL", 6, 239784},
	{"OPTIFIT", 7, 239785},
	{"DEDUCES", 7, 239786},
	{"TULKU", 5, 239787},
	{"TODOR", 5, 239788},
	{"INAYAT", 6, 239789},
	{"GLASCO", 6, 239790},
	{"NAVAID", 6, 239791},
	{"CERMET", 6, 239792},
	{"PANTI", 5, 239793},
	{"LAYEZEE", 7, 239794},
	{"GEISHAS", 7, 239795},
	{"SCWCD", 5, 239796},
	{"ROWBOATS", 8, 239797},
	{"MDIX", 4, 239798},
	{"MARIEMONT", 9, 239799},
	{"BICKERSTAFF", 11, 239800},
	{"SOEHARTO", 8, 239801},
	{"ATROX", 5, 239802},
	{"THELESS", 7, 239803},
	{"SIMPLON", 7, 239804},
	{"GRILICHES", 9, 239805},
	{"RADICULOPATHY", 13, 239806},
	{"EUROPAS", 7, 239807},
	{"VERHAGEN", 8, 239808},
	{"AIRBLOWN", 8, 239809},
	{"SOTERIOLOGY", 11, 239810},
	{"NOMINATORS", 10, 239811},
	{"JDEPEND", 7, 239812},
	{"EXIL", 4, 239813},
	{"TIGAR", 5, 239814},
	{"KEDDY", 5, 239815},
	{"MAHARAJAH", 9, 239816},
	{"DISSENSIONS", 11, 239817},
	{"REAMES", 6, 239818},
	{"KAGA", 4, 239819},
	{"AXELCL", 6, 239820},
	{"GERRIE", 6, 239821},
	{"TIDIGARE", 8, 239822},
	{"TEITHIO", 7, 239823},
	{"OSSAMA", 6, 239824},
	{"FUSEE", 5, 239825},
	{"COLONISE", 8, 239826},
	{"NPGSQL", 6, 239827},
	{"MITTELS", 7, 239828},
	{"BVV", 3, 239829},
	{"BASENESS", 8, 239830},
	{"BACOPA", 6, 239831},
	{"GALVATRON", 9, 239832},
	{"CONCE", 5, 239833},
	{"RAILROADERS", 11, 239834},
	{"SUBGLACIAL", 10, 239835},
	{"REUTLINGEN", 10, 239836},
	{"OCTOPI", 6, 239837},
	{"MICALI", 6, 239838},
	{"ABONNIEREN", 10, 239839},
	{"REARRANGES", 10, 239840},
	{"LUMBERMAN", 9, 239841},
	{"BARIC", 5, 239842},
	{"TUNICK", 6, 239843},
	{"MILSONS", 7, 239844},
	{"INTRODUZIONE", 12, 239845},
	{"ENGNG", 5, 239846},
	{"HELLIER", 7, 239847},
	{"FRAK", 4, 239848},
	{"COLLAPSABLE", 11, 239849},
	{"CODRINGTON", 10, 239850},
	{"HEBBRONVILLE", 12, 239851},
	{"ZGEN", 4, 239852},
	{"ZBOW", 4, 239853},
	{"YNAY", 4, 239854},
	{"YCKE", 4, 239855},
	{"XOCC", 4, 239856},
	{"WKOR", 4, 239857},
	{"VORJ", 4, 239858},
	{"VOLX", 4, 239859},
	{"USBB", 4, 239860},
	{"UIAP", 4, 239861},
	{"UAJO", 4, 239862},
	{"TZSF", 4, 239863},
	{"TLUP", 4, 239864},
	{"THPD", 4, 239865},
	{"TEYU", 4, 239866},
	{"SYJE", 4, 239867},
	{"SSPG", 4, 239868},
	{"SNFC", 4, 239869},
	{"SLTC", 4, 239870},
	{"SKBI", 4, 239871},
	{"RRMI", 4, 239872},
	{"REYY", 4, 239873},
	{"REBW", 4, 239874},
	{"RCGO", 4, 239875},
	{"PLCH", 4, 239876},
	{"PKEA", 4, 239877},
	{"PHJA", 4, 239878},
	{"OZEP", 4, 239879},
	{"OMUZ", 4, 239880},
	{"OMGW", 4, 239881},
	{"OIFP", 4, 239882},
	{"MTVH", 4, 239883},
	{"MNAU", 4, 239884},
	{"MECD", 4, 239885},
	{"LKBI", 4, 239886},
	{"LIJK", 4, 239887},
	{"KSMD", 4, 239888},
	{"INZM", 4, 239889},
	{"IIKK", 4, 239890},
	{"IADY", 4, 239891},
	{"HPMO", 4, 239892},
	{"HPJA", 4, 239893},
	{"HMBO", 4, 239894},
	{"GYSS", 4, 239895},
	{"GWYD", 4, 239896},
	{"GNTU", 4, 239897},
	{"FPUC", 4, 239898},
	{"FKAA", 4, 239899},
	{"FHYM", 4, 239900},
	{"FEYC", 4, 239901},
	{"FEBG", 4, 239902},
	{"EWIJ", 4, 239903},
	{"EUXC", 4, 239904},
	{"EULC", 4, 239905},
	{"EEMJ", 4, 239906},
	{"DYJR", 4, 239907},
	{"DWAM", 4, 239908},
	{"DOKS", 4, 239909},
	{"BOSG", 4, 239910},
	{"BAAG", 4, 239911},
	{"ATZR", 4, 239912},
	{"AFLG", 4, 239913},
	{"ACZA", 4, 239914},
	{"KHIRI", 5, 239915},
	{"FEINMAN", 7, 239916},
	{"AERIALIST", 9, 239917},
	{"MIHAELA", 7, 239918},
	{"MEADER", 6, 239919},
	{"CAPEK", 5, 239920},
	{"ASSERTIVELY", 11, 239921},
	{"ACPID", 5, 239922},
	{"BLOTCHED", 8, 239923},
	{"PIERANGELO", 10, 239924},
	{"SOCIE", 5, 239925},
	{"PHILADELPHIANS", 14, 239926},
	{"NIMPO", 5, 239927},
	{"EMBARRASSES", 11, 239928},
	{"BROOKPARK", 9, 239929},
	{"TICATS", 6, 239930},
	{"JPW", 3, 239931},
	{"REGRESAR", 8, 239932},
	{"PERFORMANT", 10, 239933},
	{"FRINKLIN", 8, 239934},
	{"SFER", 4, 239935},
	{"KANER", 5, 239936},
	{"AZIZA", 5, 239937},
	{"FRUITCAKES", 10, 239938},
	{"DCCH", 4, 239939},
	{"ANMELDELSER", 11, 239940},
	{"QMGR", 4, 239941},
	{"HUICHOL", 7, 239942},
	{"PSEC", 4, 239943},
	{"OOSTEN", 6, 239944},
	{"KINDOM", 6, 239945},
	{"CLASSICISTS", 11, 239946},
	{"UNDERCOATING", 12, 239947},
	{"VITELLOGENIN", 12, 239948},
	{"RINGLER", 7, 239949},
	{"MENZ", 4, 239950},
	{"OPTERONS", 8, 239951},
	{"MERIDITH", 8, 239952},
	{"ZWV", 3, 239953},
	{"ZMX", 3, 239954},
	{"ZMJ", 3, 239955},
	{"ZKJ", 3, 239956},
	{"XRJ", 3, 239957},
	{"XJV", 3, 239958},
	{"XFZ", 3, 239959},
	{"VKZ", 3, 239960},
	{"QZW", 3, 239961},
	{"QXQ", 3, 239962},
	{"QWX", 3, 239963},
	{"QWG", 3, 239964},
	{"QWB", 3, 239965},
	{"QVV", 3, 239966},
	{"QPX", 3, 239967},
	{"QKW", 3, 239968},
	{"QKF", 3, 239969},
	{"QJW", 3, 239970},
	{"QJD", 3, 239971},
	{"KZJ", 3, 239972},
	{"JDX", 3, 239973},
	{"GZJ", 3, 239974},
	{"GQX", 3, 239975},
	{"FQK", 3, 239976},
	{"CJX", 3, 239977},
	{"BZJ", 3, 239978},
	{"BXK", 3, 239979},
	{"BWZ", 3, 239980},
	{"BVX", 3, 239981},
	{"BJQ", 3, 239982},
	{"SLASHDOTTED", 11, 239983},
	{"GIMPWIN", 7, 239984},
	{"POVU", 4, 239985},
	{"NEASC", 5, 239986},
	{"IMPLORES", 8, 239987},
	{"IFPLUGD", 7, 239988},
	{"GALYEN", 6, 239989},
	{"CONSTITUTIONALIST", 17, 239990},
	{"RESPONSIBIL", 11, 239991},
	{"POWERLOGIX", 10, 239992},
	{"RAJENDRAN", 9, 239993},
	{"CARBURETION", 11, 239994},
	{"FGG", 3, 239995},
	{"TREFFPUNKT", 10, 239996},
	{"DLZ", 3, 239997},
	{"PERCHLORIC", 10, 239998},
	{"KASILOF", 7, 239999},
	{"DVAR", 4, 240000},
	{"MOONCHILD", 9, 240001},
	{"ANTONINA", 8, 240002},
	{"WEBRPG", 6, 240003},
	{"VGER", 4, 240004},
	{"DISFRUTAR", 9, 240005},
	{"CONK", 4, 240006},
	{"ANTIWORD", 8, 240007},
	{"SERVERIRON", 10, 240008},
	{"ANREGUNGEN", 10, 240009},
	{"TALKSHOW", 8, 240010},
	{"SCHOOLKIDS", 10, 240011},
	{"COUPERS", 7, 240012},
	{"ALLANS", 6, 240013},
	{"ZIPPOS", 6, 240014},
	{"JASSI", 5, 240015},
	{"FLOWERBULBS", 11, 240016},
	{"AGNESE", 6, 240017},
	{"THEATERMANIA", 12, 240018},
	{"MATERNA", 7, 240019},
	{"JULEE", 5, 240020},
	{"KOMMUN", 6, 240021},
	{"FERRIT", 6, 240022},
	{"RIVONIA", 7, 240023},
	{"PASSEY", 6, 240024},
	{"SANDHOLM", 8, 240025},
	{"RNZAF", 5, 240026},
	{"HAPPYCOW", 8, 240027},
	{"EISENHAUER", 10, 240028},
	{"OLER", 4, 240029},
	{"CASHBOX", 7, 240030},
	{"INEPTNESS", 9, 240031},
	{"EDSP", 4, 240032},
	{"CANARSIE", 8, 240033},
	{"APERATURE", 9, 240034},
	{"THRIFTLODGE", 11, 240035},
	{"CINEMASCREEN", 12, 240036},
	{"KELCH", 5, 240037},
	{"INTERWEAVES", 11, 240038},
	{"DWARFING", 8, 240039},
	{"BLANDNESS", 9, 240040},
	{"SULEMAN", 7, 240041},
	{"LEBRETON", 8, 240042},
	{"BICURIOUS", 9, 240043},
	{"KRANKENHAUS", 11, 240044},
	{"STEINHART", 9, 240045},
	{"LIGHTPOINTE", 11, 240046},
	{"ESTUDIAR", 8, 240047},
	{"ROMINGER", 8, 240048},
	{"MURALIST", 8, 240049},
	{"JOHNM", 5, 240050},
	{"ASPLENIUM", 9, 240051},
	{"PROPOGATION", 11, 240052},
	{"BIPM", 4, 240053},
	{"XANTH", 5, 240054},
	{"DEMOPEDIA", 9, 240055},
	{"CULMS", 5, 240056},
	{"WEATHERWAX", 10, 240057},
	{"SHELLUTILS", 10, 240058},
	{"EMCDDA", 6, 240059},
	{"ECODE", 5, 240060},
	{"BHAVANI", 7, 240061},
	{"REPONSES", 8, 240062},
	{"WORKSTANDS", 10, 240063},
	{"PIERI", 5, 240064},
	{"CURCIO", 6, 240065},
	{"GEWESEN", 7, 240066},
	{"NELIGH", 6, 240067},
	{"INSTALLIEREN", 12, 240068},
	{"FEMORALE", 8, 240069},
	{"CONVIENIENT", 11, 240070},
	{"KIDSHEALTH", 10, 240071},
	{"TRAGUS", 6, 240072},
	{"FLEECING", 8, 240073},
	{"KINNICK", 7, 240074},
	{"ELISABET", 8, 240075},
	{"SARTI", 5, 240076},
	{"PULFORD", 7, 240077},
	{"PHNTERMINE", 10, 240078},
	{"BODELWYDDAN", 11, 240079},
	{"KHAOLAK", 7, 240080},
	{"JYRKI", 5, 240081},
	{"ALTNET", 6, 240082},
	{"MARBURGER", 9, 240083},
	{"DYCHTWALD", 9, 240084},
	{"DIALPAD", 7, 240085},
	{"CONSIGLIATI", 11, 240086},
	{"NTLDR", 5, 240087},
	{"IMAGEDJ", 7, 240088},
	{"OBLATES", 7, 240089},
	{"NOURIEL", 7, 240090},
	{"LINESOLID", 9, 240091},
	{"ONLIHE", 6, 240092},
	{"DDRUM", 5, 240093},
	{"MAKOWSKI", 8, 240094},
	{"SYNTHE", 6, 240095},
	{"KRZYWINSKI", 10, 240096},
	{"KACY", 4, 240097},
	{"DIGNE", 5, 240098},
	{"CHIARELLI", 9, 240099},
	{"UTILIZANDO", 10, 240100},
	{"RENDEVOUS", 9, 240101},
	{"DOULL", 5, 240102},
	{"BALAENOPTERA", 12, 240103},
	{"KILKEEL", 7, 240104},
	{"HILLOCKS", 8, 240105},
	{"DESATURATION", 12, 240106},
	{"NONYLPHENOL", 11, 240107},
	{"COWIN", 5, 240108},
	{"DWFLAGS", 7, 240109},
	{"PHPOPENTRACKER", 14, 240110},
	{"DORRINGTON", 10, 240111},
	{"ACOR", 4, 240112},
	{"QUILLER", 7, 240113},
	{"SOLUSEK", 7, 240114},
	{"BICHENO", 7, 240115},
	{"CABEZAS", 7, 240116},
	{"JALOUSIE", 8, 240117},
	{"COLORBLOCK", 10, 240118},
	{"LUNDBY", 6, 240119},
	{"WINTOUR", 7, 240120},
	{"NEWSTART", 8, 240121},
	{"PAGEMILL", 8, 240122},
	{"DISPENSATIONAL", 14, 240123},
	{"STATFS", 6, 240124},
	{"FLAMINGOES", 10, 240125},
	{"TMENT", 5, 240126},
	{"ROSOCOMMON", 10, 240127},
	{"ONDON", 5, 240128},
	{"EARSET", 6, 240129},
	{"WIGRAM", 6, 240130},
	{"PICKGUARDS", 10, 240131},
	{"HISAX", 5, 240132},
	{"WHEREHOUSE", 10, 240133},
	{"UNITARD", 7, 240134},
	{"YNPE", 4, 240135},
	{"YMSE", 4, 240136},
	{"YMBU", 4, 240137},
	{"YBCS", 4, 240138},
	{"XIWI", 4, 240139},
	{"XIAW", 4, 240140},
	{"XBIT", 4, 240141},
	{"WWTA", 4, 240142},
	{"VPWH", 4, 240143},
	{"ULPW", 4, 240144},
	{"TBHU", 4, 240145},
	{"STCF", 4, 240146},
	{"SRIZ", 4, 240147},
	{"SFCI", 4, 240148},
	{"RNYL", 4, 240149},
	{"REFW", 4, 240150},
	{"QWEL", 4, 240151},
	{"PYAD", 4, 240152},
	{"POYS", 4, 240153},
	{"PMYR", 4, 240154},
	{"PFSA", 4, 240155},
	{"OFVC", 4, 240156},
	{"OEYF", 4, 240157},
	{"MRGL", 4, 240158},
	{"MMGA", 4, 240159},
	{"MLBH", 4, 240160},
	{"MDFO", 4, 240161},
	{"MAUV", 4, 240162},
	{"LUYO", 4, 240163},
	{"LUXD", 4, 240164},
	{"LRIL", 4, 240165},
	{"LRAK", 4, 240166},
	{"LMIH", 4, 240167},
	{"LIKM", 4, 240168},
	{"LAXR", 4, 240169},
	{"KUGL", 4, 240170},
	{"KTIK", 4, 240171},
	{"KOUB", 4, 240172},
	{"KMEB", 4, 240173},
	{"JMIC", 4, 240174},
	{"JEME", 4, 240175},
	{"JAXW", 4, 240176},
	{"INQF", 4, 240177},
	{"HMYV", 4, 240178},
	{"GNVO", 4, 240179},
	{"GKOB", 4, 240180},
	{"GIEK", 4, 240181},
	{"FDRR", 4, 240182},
	{"EYRD", 4, 240183},
	{"EVUK", 4, 240184},
	{"ESFM", 4, 240185},
	{"EMFT", 4, 240186},
	{"ELCB", 4, 240187},
	{"EDVC", 4, 240188},
	{"CKOD", 4, 240189},
	{"BWRO", 4, 240190},
	{"BMOO", 4, 240191},
	{"BBYU", 4, 240192},
	{"AUKB", 4, 240193},
	{"ANXF", 4, 240194},
	{"AJFO", 4, 240195},
	{"AGYE", 4, 240196},
	{"AEGG", 4, 240197},
	{"VIKLUND", 7, 240198},
	{"TEDIOUSLY", 9, 240199},
	{"PIZZELLE", 8, 240200},
	{"MACKILLOP", 9, 240201},
	{"BIEDERMANN", 10, 240202},
	{"WEMPLE", 6, 240203},
	{"REAVERS", 7, 240204},
	{"PUMPHREY", 8, 240205},
	{"CRINOIDS", 8, 240206},
	{"TOBIANO", 7, 240207},
	{"FUJICHROME", 10, 240208},
	{"POOFY", 5, 240209},
	{"PARISOT", 7, 240210},
	{"PAMELLA", 7, 240211},
	{"UTAHNS", 6, 240212},
	{"FARMHAND", 8, 240213},
	{"EUPEN", 5, 240214},
	{"EQUIPME", 7, 240215},
	{"CATTT", 5, 240216},
	{"AVANSERT", 8, 240217},
	{"GALLAGER", 8, 240218},
	{"CORDAY", 6, 240219},
	{"PHILLIMORE", 10, 240220},
	{"MFLOPS", 6, 240221},
	{"GETCONTEXT", 10, 240222},
	{"ANDRX", 5, 240223},
	{"ZWECKFORM", 9, 240224},
	{"OUTRIDER", 8, 240225},
	{"GDKPIXBUF", 9, 240226},
	{"STRAAT", 6, 240227},
	{"NOGLE", 5, 240228},
	{"DEMUS", 5, 240229},
	{"WANAQUE", 7, 240230},
	{"SOLCHE", 6, 240231},
	{"KOSEK", 5, 240232},
	{"KADESH", 6, 240233},
	{"GENEANNOT", 9, 240234},
	{"FILMEN", 6, 240235},
	{"TICOS", 5, 240236},
	{"KONFERENCE", 10, 240237},
	{"ACTIVITEITEN", 12, 240238},
	{"RSTRNT", 6, 240239},
	{"DICULT", 6, 240240},
	{"BROSWER", 7, 240241},
	{"PREVIEWBGIMAGE", 14, 240242},
	{"LAMPMAN", 7, 240243},
	{"DROMS", 5, 240244},
	{"IOFFE", 5, 240245},
	{"FRETFUL", 7, 240246},
	{"NECHAKO", 7, 240247},
	{"GETINSETS", 9, 240248},
	{"TINUING", 7, 240249},
	{"DEVARIM", 7, 240250},
	{"ARSEN", 5, 240251},
	{"GEHEIMNIS", 9, 240252},
	{"TEENBOY", 7, 240253},
	{"KNIFED", 6, 240254},
	{"BEDR", 4, 240255},
	{"ALETHEA", 7, 240256},
	{"PORTUNITIES", 11, 240257},
	{"MELBOURN", 8, 240258},
	{"SMRITI", 6, 240259},
	{"SEIBU", 5, 240260},
	{"PARTN", 5, 240261},
	{"ONSPEED", 7, 240262},
	{"MEDIASOURCE", 11, 240263},
	{"ESTRATEGIAS", 11, 240264},
	{"DUPNITSA", 8, 240265},
	{"DRESSE", 6, 240266},
	{"PRESENSE", 8, 240267},
	{"DESCA", 5, 240268},
	{"SCHEINER", 8, 240269},
	{"YUROK", 5, 240270},
	{"KITAME", 6, 240271},
	{"KATSUYA", 7, 240272},
	{"TILDES", 6, 240273},
	{"ACDBDIMENSION", 13, 240274},
	{"WINFREE", 7, 240275},
	{"UNTREATABLE", 11, 240276},
	{"ROSTREVOR", 9, 240277},
	{"CALVED", 6, 240278},
	{"QMP", 3, 240279},
	{"JURRIAAN", 8, 240280},
	{"EUBACTERIA", 10, 240281},
	{"MYOMECTOMY", 10, 240282},
	{"OUSU", 4, 240283},
	{"LEXICOGRAPHICALLY", 17, 240284},
	{"INFINITESIMALLY", 15, 240285},
	{"CLOUSTON", 8, 240286},
	{"POTGIETER", 9, 240287},
	{"FUNDAMEN", 8, 240288},
	{"ELECTABLE", 9, 240289},
	{"REACHOUT", 8, 240290},
	{"MOBIKE", 6, 240291},
	{"EMERIC", 6, 240292},
	{"DEGRE", 5, 240293},
	{"HEAVENER", 8, 240294},
	{"RILLA", 5, 240295},
	{"INQUISITORIAL", 13, 240296},
	{"DIVISA", 6, 240297},
	{"CHELONIA", 8, 240298},
	{"STRATAVIEW", 10, 240299},
	{"FALIRAKI", 8, 240300},
	{"BACCETTI", 8, 240301},
	{"WHATLINKSHERE", 13, 240302},
	{"NEWSRACK", 8, 240303},
	{"FLYSPRAY", 8, 240304},
	{"VIDEOTRON", 9, 240305},
	{"DESTUN", 6, 240306},
	{"BIOLOGICA", 9, 240307},
	{"YOUSKO", 6, 240308},
	{"USATI", 5, 240309},
	{"DOUAI", 5, 240310},
	{"INDEPENDENCY", 12, 240311},
	{"PALAZZI", 7, 240312},
	{"SOTFWARE", 8, 240313},
	{"MCELHONE", 8, 240314},
	{"FIBRAX", 6, 240315},
	{"BAGNI", 5, 240316},
	{"STOUTS", 6, 240317},
	{"CUBO", 4, 240318},
	{"DHBS", 4, 240319},
	{"ABSORPTIOMETRY", 14, 240320},
	{"XLNT", 4, 240321},
	{"TOMDISPATCH", 11, 240322},
	{"NEWSPAD", 7, 240323},
	{"HAVOLINE", 8, 240324},
	{"IWONA", 5, 240325},
	{"BINDVIEW", 8, 240326},
	{"YOJANA", 6, 240327},
	{"SCATCHARD", 9, 240328},
	{"PASSFIELD", 9, 240329},
	{"EVERITE", 7, 240330},
	{"TFMB", 4, 240331},
	{"RAIJIN", 6, 240332},
	{"NECCESSITY", 10, 240333},
	{"INHAND", 6, 240334},
	{"DEADBOLTS", 9, 240335},
	{"CANESCENS", 9, 240336},
	{"ACCOUNTACCOUNT", 14, 240337},
	{"SONOGRAPHERS", 12, 240338},
	{"MEXICANUS", 9, 240339},
	{"DASSEN", 6, 240340},
	{"ASIATIQUES", 10, 240341},
	{"SOUTHSHORE", 10, 240342},
	{"SAJKA", 5, 240343},
	{"CONSERVATORSHIPS", 16, 240344},
	{"ATORNEY", 7, 240345},
	{"APPLICATI", 9, 240346},
	{"MARGINHEIGHT", 12, 240347},
	{"SWALWELL", 8, 240348},
	{"MOGHUL", 6, 240349},
	{"MASHERS", 7, 240350},
	{"KOSTROMA", 8, 240351},
	{"PORTWAY", 7, 240352},
	{"BADCOPIES", 9, 240353},
	{"SCIACCA", 7, 240354},
	{"MAFHOUM", 7, 240355},
	{"CSNET", 5, 240356},
	{"INSTEN", 6, 240357},
	{"UNSULLIED", 9, 240358},
	{"STRUDWICK", 9, 240359},
	{"MORIKAWA", 8, 240360},
	{"MINICABS", 8, 240361},
	{"GOODMINBUSY", 11, 240362},
	{"GOODMAXBUSY", 11, 240363},
	{"MANDAWA", 7, 240364},
	{"LANGU", 5, 240365},
	{"KARISMA", 7, 240366},
	{"CARDMEMBERS", 11, 240367},
	{"DYNAMOMETERS", 12, 240368},
	{"SZILARD", 7, 240369},
	{"DYNOJET", 7, 240370},
	{"RMIJDBC", 7, 240371},
	{"HOOPOE", 6, 240372},
	{"CHORISTES", 9, 240373},
	{"WINMATRIX", 9, 240374},
	{"CARINGBAH", 9, 240375},
	{"SUNSHOWER", 9, 240376},
	{"MAQUILA", 7, 240377},
	{"BRUSHWORK", 9, 240378},
	{"BLOGHOP", 7, 240379},
	{"VETOING", 7, 240380},
	{"LXML", 4, 240381},
	{"MOGADORE", 8, 240382},
	{"INGLEY", 6, 240383},
	{"HANDGUNNER", 10, 240384},
	{"SCHOENHUT", 9, 240385},
	{"POWEREDBY", 9, 240386},
	{"HTTPSESSION", 11, 240387},
	{"ANOTHE", 6, 240388},
	{"EREKAT", 6, 240389},
	{"CORNELIAN", 9, 240390},
	{"GTAR", 4, 240391},
	{"CODDLED", 7, 240392},
	{"VISCONTE", 8, 240393},
	{"SCHESTOWITZ", 11, 240394},
	{"MIGDAL", 6, 240395},
	{"LOTHE", 5, 240396},
	{"FESTVOX", 7, 240397},
	{"CZERWINSKI", 10, 240398},
	{"ARACEAE", 7, 240399},
	{"PNEUMONECTOMY", 13, 240400},
	{"MEMORYFRAME", 11, 240401},
	{"DESPARATELY", 11, 240402},
	{"BARGELLO", 8, 240403},
	{"RINGTAIL", 8, 240404},
	{"ILGAUSKAS", 9, 240405},
	{"SPIRITUOUS", 10, 240406},
	{"MCFARLIN", 8, 240407},
	{"CAMARINES", 9, 240408},
	{"CUADERNOS", 9, 240409},
	{"ACCUCUT", 7, 240410},
	{"SHAMASH", 7, 240411},
	{"CELCEE", 6, 240412},
	{"TANNY", 5, 240413},
	{"SNOWSPORT", 9, 240414},
	{"PAVIMENTO", 9, 240415},
	{"BAGHEERA", 8, 240416},
	{"RICKETTSIAL", 11, 240417},
	{"MARYLANDERS", 11, 240418},
	{"INLOVE", 6, 240419},
	{"EEPROMS", 7, 240420},
	{"AEOLICUS", 8, 240421},
	{"MCMORROW", 8, 240422},
	{"KREUZER", 7, 240423},
	{"FIFER", 5, 240424},
	{"MACROECONOMY", 12, 240425},
	{"GALLORY", 7, 240426},
	{"FRIDMAN", 7, 240427},
	{"UTILICE", 7, 240428},
	{"INTERROGATES", 12, 240429},
	{"COCOROSIE", 9, 240430},
	{"NEUROANATOMICAL", 15, 240431},
	{"FREO", 4, 240432},
	{"LUDERITZ", 8, 240433},
	{"DAMADOLA", 8, 240434},
	{"BRUCETON", 8, 240435},
	{"SCHULTES", 8, 240436},
	{"CHOLO", 5, 240437},
	{"WEIG", 4, 240438},
	{"MISTERIO", 8, 240439},
	{"KSERVER", 7, 240440},
	{"WAFTS", 5, 240441},
	{"METAFILES", 9, 240442},
	{"ANOBJECT", 8, 240443},
	{"AMRI", 4, 240444},
	{"ZEJO", 4, 240445},
	{"ZBOY", 4, 240446},
	{"ZASD", 4, 240447},
	{"YPUD", 4, 240448},
	{"YOGY", 4, 240449},
	{"XTAU", 4, 240450},
	{"WDSP", 4, 240451},
	{"VSRI", 4, 240452},
	{"UZIK", 4, 240453},
	{"UPTV", 4, 240454},
	{"UOCR", 4, 240455},
	{"UIBO", 4, 240456},
	{"UGMC", 4, 240457},
	{"UFES", 4, 240458},
	{"UDKN", 4, 240459},
	{"TZEX", 4, 240460},
	{"TYRT", 4, 240461},
	{"TKIB", 4, 240462},
	{"TCMD", 4, 240463},
	{"TAPY", 4, 240464},
	{"SRBR", 4, 240465},
	{"SPOG", 4, 240466},
	{"SFIZ", 4, 240467},
	{"SFIJ", 4, 240468},
	{"SDLA", 4, 240469},
	{"SDDI", 4, 240470},
	{"SBMI", 4, 240471},
	{"RZAF", 4, 240472},
	{"RRPG", 4, 240473},
	{"RMPF", 4, 240474},
	{"RDHP", 4, 240475},
	{"RAZW", 4, 240476},
	{"QBSA", 4, 240477},
	{"QANY", 4, 240478},
	{"POIZ", 4, 240479},
	{"PJEW", 4, 240480},
	{"PIFN", 4, 240481},
	{"PBYV", 4, 240482},
	{"ORQA", 4, 240483},
	{"OCOZ", 4, 240484},
	{"NTLC", 4, 240485},
	{"NMUZ", 4, 240486},
	{"NEPF", 4, 240487},
	{"MBDU", 4, 240488},
	{"LZIM", 4, 240489},
	{"LYTS", 4, 240490},
	{"LSOZ", 4, 240491},
	{"LDTT", 4, 240492},
	{"KSOG", 4, 240493},
	{"KDUB", 4, 240494},
	{"KBAP", 4, 240495},
	{"JKAN", 4, 240496},
	{"JJRE", 4, 240497},
	{"ISUW", 4, 240498},
	{"IQOF", 4, 240499},
	{"IEUL", 4, 240500},
	{"FOPU", 4, 240501},
	{"FERQ", 4, 240502},
	{"FEMC", 4, 240503},
	{"FDRH", 4, 240504},
	{"EXYM", 4, 240505},
	{"EWDV", 4, 240506},
	{"EVBO", 4, 240507},
	{"ECBY", 4, 240508},
	{"DWAP", 4, 240509},
	{"DKHI", 4, 240510},
	{"DAQM", 4, 240511},
	{"DAIY", 4, 240512},
	{"CJWI", 4, 240513},
	{"BCCL", 4, 240514},
	{"AXYH", 4, 240515},
	{"AMBM", 4, 240516},
	{"AGMU", 4, 240517},
	{"ABUW", 4, 240518},
	{"TRANSFERENCIA", 13, 240519},
	{"HIRTSHALS", 9, 240520},
	{"GARMON", 6, 240521},
	{"WISECOMM", 8, 240522},
	{"REILY", 5, 240523},
	{"NUTRIBIOTIC", 11, 240524},
	{"NONSTATE", 8, 240525},
	{"COWAL", 5, 240526},
	{"ZUSE", 4, 240527},
	{"SLEIGHRIDE", 10, 240528},
	{"USERBASE", 8, 240529},
	{"NARANG", 6, 240530},
	{"BACKRESTS", 9, 240531},
	{"JUHU", 4, 240532},
	{"GARRISONED", 10, 240533},
	{"POWERSTATION", 12, 240534},
	{"LANKIN", 6, 240535},
	{"KHANATE", 7, 240536},
	{"INITIUM", 7, 240537},
	{"NUKLEUZ", 7, 240538},
	{"INTERCITYHOTEL", 14, 240539},
	{"FLUMIST", 7, 240540},
	{"RHEOMETER", 9, 240541},
	{"ITALICIZE", 9, 240542},
	{"UNPAGED", 7, 240543},
	{"SPEDDING", 8, 240544},
	{"MILKMAID", 8, 240545},
	{"BCOZ", 4, 240546},
	{"PARACHUTED", 10, 240547},
	{"TOKYOOFFICE", 11, 240548},
	{"KIRKENDALL", 10, 240549},
	{"JAPANIME", 8, 240550},
	{"DEFUNKER", 8, 240551},
	{"SUPERCILIOUS", 12, 240552},
	{"EFORE", 5, 240553},
	{"UNBLINKING", 10, 240554},
	{"AEDC", 4, 240555},
	{"ZIRCONIAS", 9, 240556},
	{"YOEST", 5, 240557},
	{"SOLDIERY", 8, 240558},
	{"INTERROGANS", 11, 240559},
	{"GALETTE", 7, 240560},
	{"DUECK", 5, 240561},
	{"DIMETHYLFORMAMIDE", 17, 240562},
	{"PHILAE", 6, 240563},
	{"LAGOPUS", 7, 240564},
	{"HEPPELL", 7, 240565},
	{"RICHTIGKEIT", 11, 240566},
	{"DAVEB", 5, 240567},
	{"ANGLOSPHERE", 11, 240568},
	{"MINICRAFT", 9, 240569},
	{"SOCALLED", 8, 240570},
	{"SMITHWICK", 9, 240571},
	{"RODINA", 6, 240572},
	{"ROBOTO", 6, 240573},
	{"PROCOMM", 7, 240574},
	{"NICANOR", 7, 240575},
	{"ILER", 4, 240576},
	{"MASKTRACK", 9, 240577},
	{"GIMENO", 6, 240578},
	{"WOOLLOOMOOLOO", 13, 240579},
	{"PGCC", 4, 240580},
	{"KILLICK", 7, 240581},
	{"RHODOCOCCUS", 11, 240582},
	{"ROBNELL", 7, 240583},
	{"HENFIELD", 8, 240584},
	{"GAMMAPROTEOBACTERIA", 19, 240585},
	{"VERES", 5, 240586},
	{"YAKT", 4, 240587},
	{"VITRINE", 7, 240588},
	{"SIGHTSEE", 8, 240589},
	{"SCHURR", 6, 240590},
	{"BRACO", 5, 240591},
	{"SMARTLIST", 9, 240592},
	{"OMERTA", 6, 240593},
	{"GOFFREDO", 8, 240594},
	{"TORERO", 6, 240595},
	{"OHNOTHEYDIDNT", 13, 240596},
	{"NICET", 5, 240597},
	{"UNFF", 4, 240598},
	{"SIBYLLE", 7, 240599},
	{"PIENZA", 6, 240600},
	{"BRIZ", 4, 240601},
	{"OXYGENATOR", 10, 240602},
	{"WEEBLS", 6, 240603},
	{"UNDOUBTABLY", 11, 240604},
	{"MOVIEFACTORY", 12, 240605},
	{"PIGPEN", 6, 240606},
	{"MICROWIRE", 9, 240607},
	{"KOTKIN", 6, 240608},
	{"SKIRMISHING", 11, 240609},
	{"PROFANED", 8, 240610},
	{"HLSC", 4, 240611},
	{"SUBCHAPTERS", 11, 240612},
	{"MARILYNA", 8, 240613},
	{"CONED", 5, 240614},
	{"CLIKITS", 7, 240615},
	{"CATHAYS", 7, 240616},
	{"XEND", 4, 240617},
	{"MICROBREWS", 10, 240618},
	{"LAATST", 6, 240619},
	{"TAPLOW", 6, 240620},
	{"FABI", 4, 240621},
	{"ORDINAIRE", 9, 240622},
	{"ELYMUS", 6, 240623},
	{"PASTORALIST", 11, 240624},
	{"PROCHAIN", 8, 240625},
	{"PERVS", 5, 240626},
	{"ROTAS", 5, 240627},
	{"QUERIER", 7, 240628},
	{"ZOLI", 4, 240629},
	{"SAMRAI", 6, 240630},
	{"KEOWEE", 6, 240631},
	{"FREQUENZA", 9, 240632},
	{"DAZZ", 4, 240633},
	{"ETAGE", 5, 240634},
	{"VANCITY", 7, 240635},
	{"MEGALODON", 9, 240636},
	{"BETTERTON", 9, 240637},
	{"WISDOT", 6, 240638},
	{"WASTEPAPER", 10, 240639},
	{"TASMIN", 6, 240640},
	{"QUISIERA", 8, 240641},
	{"WHOLEGRAIN", 10, 240642},
	{"MONDIALISATION", 14, 240643},
	{"APPRICIATED", 11, 240644},
	{"VERIDIAN", 8, 240645},
	{"CORKERY", 7, 240646},
	{"MUZAFFAR", 8, 240647},
	{"QADEER", 6, 240648},
	{"IBILITY", 7, 240649},
	{"SPARSENESS", 10, 240650},
	{"HATHERLEY", 9, 240651},
	{"NEBRASKANS", 10, 240652},
	{"CANCELLOUS", 10, 240653},
	{"ANGUILA", 7, 240654},
	{"CALORE", 6, 240655},
	{"LEMPEL", 6, 240656},
	{"COXIELLA", 8, 240657},
	{"WOODIN", 6, 240658},
	{"VOLUTE", 6, 240659},
	{"IRELANDTHIS", 11, 240660},
	{"ROMANTISCHE", 11, 240661},
	{"BULWORTH", 8, 240662},
	{"BIANCHINI", 9, 240663},
	{"CGSB", 4, 240664},
	{"MONGOLIANS", 10, 240665},
	{"LALE", 4, 240666},
	{"KORMA", 5, 240667},
	{"HOLDBACKS", 9, 240668},
	{"EBULLITION", 10, 240669},
	{"ANTICLIMACTIC", 13, 240670},
	{"RMLS", 4, 240671},
	{"VASOPRESSINS", 12, 240672},
	{"INFORMTION", 10, 240673},
	{"NJSTAR", 6, 240674},
	{"KRL", 3, 240675},
	{"FILLIPINO", 9, 240676},
	{"AVOWEDLY", 8, 240677},
	{"ROMZ", 4, 240678},
	{"REAUME", 6, 240679},
	{"NOTWENDIG", 9, 240680},
	{"NANTY", 5, 240681},
	{"CONFE", 5, 240682},
	{"CELO", 4, 240683},
	{"VGL", 3, 240684},
	{"HOHHOT", 6, 240685},
	{"VEYS", 4, 240686},
	{"LIBCRYPT", 8, 240687},
	{"CELLISTS", 8, 240688},
	{"QADHAFI", 7, 240689},
	{"COLLOQUIALISMS", 14, 240690},
	{"YOURBODYNATURALLY", 17, 240691},
	{"BATTERIJEN", 10, 240692},
	{"MUSEPACK", 8, 240693},
	{"REMOTER", 7, 240694},
	{"MATRICULATE", 11, 240695},
	{"LEVITONPRODUCTS", 15, 240696},
	{"CAVALESE", 8, 240697},
	{"TEWARI", 6, 240698},
	{"PISSIN", 6, 240699},
	{"FYP", 3, 240700},
	{"ROZE", 4, 240701},
	{"GATEKEEPING", 11, 240702},
	{"AURILIA", 7, 240703},
	{"SUPERNATURA", 11, 240704},
	{"PAULUSMA", 8, 240705},
	{"SOFFA", 5, 240706},
	{"LATTITUDE", 9, 240707},
	{"AVIARA", 6, 240708},
	{"SPAGOBI", 7, 240709},
	{"WINSPEAR", 8, 240710},
	{"SHERRIF", 7, 240711},
	{"CREATIONDATE", 12, 240712},
	{"PROK", 4, 240713},
	{"CLOSEHANDLE", 11, 240714},
	{"OTTLEY", 6, 240715},
	{"GERINGER", 8, 240716},
	{"TCINCOTT", 8, 240717},
	{"IIZUKA", 6, 240718},
	{"GYPSOPHILA", 10, 240719},
	{"RETROVIROLOGY", 13, 240720},
	{"HOOPING", 7, 240721},
	{"WINESBURG", 9, 240722},
	{"WIKTOR", 6, 240723},
	{"CHOBHAM", 7, 240724},
	{"ZILN", 4, 240725},
	{"YSLD", 4, 240726},
	{"YLBU", 4, 240727},
	{"YCLY", 4, 240728},
	{"XOPL", 4, 240729},
	{"XCAU", 4, 240730},
	{"VYOI", 4, 240731},
	{"VSFL", 4, 240732},
	{"VIVW", 4, 240733},
	{"TDEK", 4, 240734},
	{"SDUV", 4, 240735},
	{"RZOL", 4, 240736},
	{"RWAU", 4, 240737},
	{"RRDT", 4, 240738},
	{"RPGW", 4, 240739},
	{"RIYU", 4, 240740},
	{"PVEH", 4, 240741},
	{"PPPI", 4, 240742},
	{"PMOP", 4, 240743},
	{"PGLE", 4, 240744},
	{"OXXE", 4, 240745},
	{"ORKZ", 4, 240746},
	{"OOCY", 4, 240747},
	{"OMNC", 4, 240748},
	{"NYSJ", 4, 240749},
	{"NVSC", 4, 240750},
	{"NODB", 4, 240751},
	{"NILM", 4, 240752},
	{"NDKV", 4, 240753},
	{"MKWA", 4, 240754},
	{"MCAK", 4, 240755},
	{"LKBL", 4, 240756},
	{"LJAG", 4, 240757},
	{"LDRF", 4, 240758},
	{"ITVD", 4, 240759},
	{"ISGP", 4, 240760},
	{"IPJE", 4, 240761},
	{"IGIW", 4, 240762},
	{"HWAU", 4, 240763},
	{"HRVA", 4, 240764},
	{"HHYB", 4, 240765},
	{"HDUL", 4, 240766},
	{"GYQU", 4, 240767},
	{"GNGI", 4, 240768},
	{"GMPA", 4, 240769},
	{"GKUT", 4, 240770},
	{"GHIZ", 4, 240771},
	{"FOZZ", 4, 240772},
	{"FGYP", 4, 240773},
	{"FAYL", 4, 240774},
	{"EZFS", 4, 240775},
	{"ERKV", 4, 240776},
	{"ELCM", 4, 240777},
	{"EJDU", 4, 240778},
	{"EHYL", 4, 240779},
	{"EACF", 4, 240780},
	{"DUIO", 4, 240781},
	{"DPTE", 4, 240782},
	{"DPFA", 4, 240783},
	{"DMME", 4, 240784},
	{"BOFJ", 4, 240785},
	{"BGAV", 4, 240786},
	{"AWEY", 4, 240787},
	{"AVOX", 4, 240788},
	{"AMGY", 4, 240789},
	{"MODULEINFO", 10, 240790},
	{"EPIDIDYMITIS", 12, 240791},
	{"SNELSON", 7, 240792},
	{"MOLDABLE", 8, 240793},
	{"KROO", 4, 240794},
	{"FONDU", 5, 240795},
	{"ADRESSED", 8, 240796},
	{"SIFYHOSTING", 11, 240797},
	{"SANDMONKEY", 10, 240798},
	{"MMIO", 4, 240799},
	{"DISCRIMINA", 10, 240800},
	{"BIKESHOP", 8, 240801},
	{"ELEANORE", 8, 240802},
	{"PRAYIN", 6, 240803},
	{"KWBG", 4, 240804},
	{"DONTS", 5, 240805},
	{"ANTITUBERCULAR", 14, 240806},
	{"ZAADZSTERS", 10, 240807},
	{"TROTSKYISTS", 11, 240808},
	{"STOFFER", 7, 240809},
	{"PTRPRULE", 8, 240810},
	{"CARU", 4, 240811},
	{"POPAGANDHI", 10, 240812},
	{"IRREDUCIBILITY", 14, 240813},
	{"FLAPJACK", 8, 240814},
	{"NORTHWICK", 9, 240815},
	{"LUPUL", 5, 240816},
	{"ANTIDIURETIC", 12, 240817},
	{"UPER", 4, 240818},
	{"INLCUDING", 9, 240819},
	{"FLORIDE", 7, 240820},
	{"FARMAN", 6, 240821},
	{"EVOCAL", 6, 240822},
	{"QUANDARIES", 10, 240823},
	{"KRYSTA", 6, 240824},
	{"WILLMS", 6, 240825},
	{"BYINGTON", 8, 240826},
	{"TVEIT", 5, 240827},
	{"DPSE", 4, 240828},
	{"BROMMA", 6, 240829},
	{"COVERSHEET", 10, 240830},
	{"BARMENSEN", 9, 240831},
	{"WYCH", 4, 240832},
	{"REFLEXIONS", 10, 240833},
	{"QUAIFE", 6, 240834},
	{"DYNAMICGRAPHICS", 15, 240835},
	{"TREFNIADAU", 10, 240836},
	{"ROSELLI", 7, 240837},
	{"ROCKTRON", 8, 240838},
	{"INTERGRANULAR", 13, 240839},
	{"HEMES", 5, 240840},
	{"MAYAVI", 6, 240841},
	{"MARCK", 5, 240842},
	{"KEYB", 4, 240843},
	{"EMPLEADOS", 9, 240844},
	{"CAMETA", 6, 240845},
	{"ASCORBYL", 8, 240846},
	{"SOMWHAT", 7, 240847},
	{"HEATLH", 6, 240848},
	{"GRADESAVER", 10, 240849},
	{"CIUTI", 5, 240850},
	{"CATAPRES", 8, 240851},
	{"PIPPINS", 7, 240852},
	{"MIRALLES", 8, 240853},
	{"CLAMOROUS", 9, 240854},
	{"CANTS", 5, 240855},
	{"KALUGA", 6, 240856},
	{"VWP", 3, 240857},
	{"SAILMAKERS", 10, 240858},
	{"ATOMIZING", 9, 240859},
	{"ERSON", 5, 240860},
	{"BRAH", 4, 240861},
	{"SCULLERY", 8, 240862},
	{"MOUSIE", 6, 240863},
	{"PLANTERSVILLE", 13, 240864},
	{"HALFLINGS", 9, 240865},
	{"BARTELT", 7, 240866},
	{"PERUSAHAAN", 10, 240867},
	{"NEWSGATHERING", 13, 240868},
	{"MILDMAY", 7, 240869},
	{"ISILDUR", 7, 240870},
	{"SYMM", 4, 240871},
	{"SOFWTARE", 8, 240872},
	{"SIVAS", 5, 240873},
	{"STRISTR", 7, 240874},
	{"GREGO", 5, 240875},
	{"NIKU", 4, 240876},
	{"VAQUEROS", 8, 240877},
	{"STEVEB", 6, 240878},
	{"CLINTWOOD", 9, 240879},
	{"SEEMETH", 7, 240880},
	{"CPHA", 4, 240881},
	{"GENEX", 5, 240882},
	{"BERTHELOT", 9, 240883},
	{"FEEDCREATOR", 11, 240884},
	{"FLAUNTS", 7, 240885},
	{"BENEWAH", 7, 240886},
	{"LBIANS", 6, 240887},
	{"BLASPHEMED", 10, 240888},
	{"BDALE", 5, 240889},
	{"NEGIMA", 6, 240890},
	{"CLOWER", 6, 240891},
	{"SOCIALGRID", 10, 240892},
	{"NOBELCOM", 8, 240893},
	{"KEWASKUM", 8, 240894},
	{"INTELIGENCIA", 12, 240895},
	{"MEGAPOWER", 9, 240896},
	{"GUSTAVIA", 8, 240897},
	{"SPELLERS", 8, 240898},
	{"BOOKFAIR", 8, 240899},
	{"NETTOYER", 8, 240900},
	{"HEADWORKS", 9, 240901},
	{"GHOSTFOREST", 11, 240902},
	{"POLYNUCLEAR", 11, 240903},
	{"CITRIMAX", 8, 240904},
	{"SHAWU", 5, 240905},
	{"RANGARAJAN", 10, 240906},
	{"INTERRUPTOR", 11, 240907},
	{"GLUCO", 5, 240908},
	{"GENEESKD", 8, 240909},
	{"PWGEN", 5, 240910},
	{"HELIOPAN", 8, 240911},
	{"WUFEI", 5, 240912},
	{"VAGIN", 5, 240913},
	{"FUNGO", 5, 240914},
	{"RIBONUCLEOPROTEINS", 18, 240915},
	{"LOVETTSVILLE", 12, 240916},
	{"DISCONSOLATE", 12, 240917},
	{"WINTERMUTE", 10, 240918},
	{"SVNSERVE", 8, 240919},
	{"FALCONSTOR", 10, 240920},
	{"OROMOCTO", 8, 240921},
	{"SIRTF", 5, 240922},
	{"RENCH", 5, 240923},
	{"NZNOG", 5, 240924},
	{"GERMANICA", 9, 240925},
	{"TELECENTER", 10, 240926},
	{"MUFFET", 6, 240927},
	{"SHIRAKI", 7, 240928},
	{"RENNA", 5, 240929},
	{"ACCORDIONIST", 12, 240930},
	{"SALVATO", 7, 240931},
	{"TEMPAT", 6, 240932},
	{"MSRB", 4, 240933},
	{"VOLKMAR", 7, 240934},
	{"PHOTODUDE", 9, 240935},
	{"EINDE", 5, 240936},
	{"HEUMANN", 7, 240937},
	{"UNHYGIENIC", 10, 240938},
	{"NBINT", 5, 240939},
	{"GRAFALLOY", 9, 240940},
	{"BEDFELLOW", 9, 240941},
	{"CASTRATE", 8, 240942},
	{"DAPHNIS", 7, 240943},
	{"CONVOLVULUS", 11, 240944},
	{"PROGNOSES", 9, 240945},
	{"ZIAGEN", 6, 240946},
	{"RUNTS", 5, 240947},
	{"ONREC", 5, 240948},
	{"MENUWE", 6, 240949},
	{"HOLDENVILLE", 11, 240950},
	{"GIUFFRE", 7, 240951},
	{"READMORE", 8, 240952},
	{"MEDIEVALIST", 11, 240953},
	{"WITCHITA", 8, 240954},
	{"KAFELNIKOV", 10, 240955},
	{"DISCRIM", 7, 240956},
	{"VSPRINTF", 8, 240957},
	{"TERAVISION", 10, 240958},
	{"MUNNA", 5, 240959},
	{"EPDS", 4, 240960},
	{"ITSTOCK", 7, 240961},
	{"WHITELY", 7, 240962},
	{"LUBRICATOR", 10, 240963},
	{"JODOHOST", 8, 240964},
	{"ACCESSSORIES", 12, 240965},
	{"INSTUCTIONS", 11, 240966},
	{"ZEYNEP", 6, 240967},
	{"PPID", 4, 240968},
	{"PRETEAR", 7, 240969},
	{"EXAMI", 5, 240970},
	{"LASQUETI", 8, 240971},
	{"KHALEDA", 7, 240972},
	{"FORMZ", 5, 240973},
	{"ANTIQUARIES", 11, 240974},
	{"QUIBUS", 6, 240975},
	{"TOLES", 5, 240976},
	{"TVBGONE", 7, 240977},
	{"PARAEDUCATOR", 12, 240978},
	{"LYNNS", 5, 240979},
	{"LIMED", 5, 240980},
	{"KYABRAM", 7, 240981},
	{"KALENDAR", 8, 240982},
	{"DEKART", 6, 240983},
	{"AGGIUNGERE", 10, 240984},
	{"TUCKWELL", 8, 240985},
	{"SHARENET", 8, 240986},
	{"PYBLIOGRAPHER", 13, 240987},
	{"YANOMAMI", 8, 240988},
	{"METASTASIZE", 11, 240989},
	{"LANSINOH", 8, 240990},
	{"HILLHEAD", 8, 240991},
	{"GAINSFORD", 9, 240992},
	{"SHABAN", 6, 240993},
	{"RANKINS", 7, 240994},
	{"HELLEBORUS", 10, 240995},
	{"FASSEL", 6, 240996},
	{"AMERICOM", 8, 240997},
	{"JCOMBOBOX", 9, 240998},
	{"HERMOSO", 7, 240999},
	{"JIBBER", 6, 241000},
	{"TRUNCUS", 7, 241001},
	{"REPORTBUG", 9, 241002},
	{"MUTISM", 6, 241003},
	{"MESSOPOTAMIAN", 13, 241004},
	{"FASTHOSTS", 9, 241005},
	{"BOTTOMFEEDER", 12, 241006},
	{"TWTF", 4, 241007},
	{"MICROBUS", 8, 241008},
	{"YZAK", 4, 241009},
	{"YKSO", 4, 241010},
	{"YIAC", 4, 241011},
	{"YAHB", 4, 241012},
	{"XUSL", 4, 241013},
	{"XTPU", 4, 241014},
	{"XROB", 4, 241015},
	{"WSIZ", 4, 241016},
	{"WANV", 4, 241017},
	{"TYUC", 4, 241018},
	{"SWMA", 4, 241019},
	{"SSYV", 4, 241020},
	{"SLIW", 4, 241021},
	{"SBFO", 4, 241022},
	{"SAXB", 4, 241023},
	{"SAJJ", 4, 241024},
	{"RUAM", 4, 241025},
	{"RSDC", 4, 241026},
	{"RRPR", 4, 241027},
	{"RHUF", 4, 241028},
	{"RCCR", 4, 241029},
	{"PCME", 4, 241030},
	{"PAYK", 4, 241031},
	{"OBYV", 4, 241032},
	{"NOXP", 4, 241033},
	{"NMRJ", 4, 241034},
	{"NICQ", 4, 241035},
	{"NHDM", 4, 241036},
	{"NEGW", 4, 241037},
	{"NDWL", 4, 241038},
	{"MUTK", 4, 241039},
	{"MSYP", 4, 241040},
	{"MDAE", 4, 241041},
	{"LUHE", 4, 241042},
	{"LILG", 4, 241043},
	{"KVON", 4, 241044},
	{"KRYN", 4, 241045},
	{"KKIB", 4, 241046},
	{"IZWO", 4, 241047},
	{"IZVI", 4, 241048},
	{"IJEL", 4, 241049},
	{"HUMF", 4, 241050},
	{"GXIU", 4, 241051},
	{"FYWE", 4, 241052},
	{"FFUC", 4, 241053},
	{"FCKI", 4, 241054},
	{"EXAW", 4, 241055},
	{"ETZB", 4, 241056},
	{"EHRB", 4, 241057},
	{"DTBI", 4, 241058},
	{"DFWI", 4, 241059},
	{"CSKY", 4, 241060},
	{"CMPM", 4, 241061},
	{"CKOX", 4, 241062},
	{"CCWE", 4, 241063},
	{"AZUH", 4, 241064},
	{"AUBW", 4, 241065},
	{"TYMPANI", 7, 241066},
	{"SWNTS", 5, 241067},
	{"HEGEWISCH", 9, 241068},
	{"WEBPATH", 7, 241069},
	{"UNRAR", 5, 241070},
	{"MUSCARI", 7, 241071},
	{"QUADRANGULAR", 12, 241072},
	{"UNVIEWED", 8, 241073},
	{"EOMER", 5, 241074},
	{"CRILLON", 7, 241075},
	{"BADCOPY", 7, 241076},
	{"ARMLETS", 7, 241077},
	{"GATEMOUTH", 9, 241078},
	{"USHBA", 5, 241079},
	{"LERIDA", 6, 241080},
	{"LECANTO", 7, 241081},
	{"LUAUS", 5, 241082},
	{"FELDEN", 6, 241083},
	{"ESHELMAN", 8, 241084},
	{"WICKETKEEPER", 12, 241085},
	{"FISHBACK", 8, 241086},
	{"FEDA", 4, 241087},
	{"EHRENFELD", 9, 241088},
	{"AJAHN", 5, 241089},
	{"ROMMATES", 8, 241090},
	{"GANBANG", 7, 241091},
	{"PROFITEER", 9, 241092},
	{"DEFAULTTYPE", 11, 241093},
	{"REDCLIFF", 8, 241094},
	{"LENZERHEIDE", 11, 241095},
	{"KEYWORTH", 8, 241096},
	{"KALAMUNDA", 9, 241097},
	{"IHARA", 5, 241098},
	{"DRIA", 4, 241099},
	{"MCGIVNEY", 8, 241100},
	{"NUCLEARDB", 9, 241101},
	{"KAIAPOI", 7, 241102},
	{"FARIN", 5, 241103},
	{"DISTINCTIVES", 12, 241104},
	{"AUTOMATISM", 10, 241105},
	{"IRAKLION", 8, 241106},
	{"GUSTON", 6, 241107},
	{"BADDECK", 7, 241108},
	{"KUTAISI", 7, 241109},
	{"FERRIBY", 7, 241110},
	{"UPCI", 4, 241111},
	{"MOTL", 4, 241112},
	{"GUILIANI", 8, 241113},
	{"GARLIN", 6, 241114},
	{"ENLIVENS", 8, 241115},
	{"GODINEZ", 7, 241116},
	{"CONKERS", 7, 241117},
	{"MEILE", 5, 241118},
	{"BITEFINDER", 10, 241119},
	{"FISHWAY", 7, 241120},
	{"OBSCAT", 6, 241121},
	{"MUDE", 4, 241122},
	{"WHIMSICALLY", 11, 241123},
	{"RAHNER", 6, 241124},
	{"COMPLETLEY", 10, 241125},
	{"CDRL", 4, 241126},
	{"ALBURG", 6, 241127},
	{"WOLFRUM", 7, 241128},
	{"SPORTSINTERACTION", 17, 241129},
	{"RUGGERI", 7, 241130},
	{"MICROSAVER", 10, 241131},
	{"ANAGER", 6, 241132},
	{"SPINSTERS", 9, 241133},
	{"ROTATABLY", 9, 241134},
	{"ENSHRINES", 9, 241135},
	{"REDCOATS", 8, 241136},
	{"NEWRULE", 7, 241137},
	{"HYGEINE", 7, 241138},
	{"ALEMBERT", 8, 241139},
	{"WININET", 7, 241140},
	{"GOODNOW", 7, 241141},
	{"WHIMPERS", 8, 241142},
	{"SUPPLI", 6, 241143},
	{"SKETCHERS", 9, 241144},
	{"MIRNYI", 6, 241145},
	{"CUBANET", 7, 241146},
	{"ANIMATIE", 8, 241147},
	{"GAURA", 5, 241148},
	{"IHTMLEVENTOBJ", 13, 241149},
	{"AZOLE", 5, 241150},
	{"DECKLE", 6, 241151},
	{"BURKEY", 6, 241152},
	{"PARAMETERISATION", 16, 241153},
	{"BOTTLECAPS", 10, 241154},
	{"SHADDAI", 7, 241155},
	{"SALALAH", 7, 241156},
	{"OZONATOR", 8, 241157},
	{"KULTURY", 7, 241158},
	{"BLOWFLY", 7, 241159},
	{"RESTREINTE", 10, 241160},
	{"CTRP", 4, 241161},
	{"SINGLESPEED", 11, 241162},
	{"CLOUTER", 7, 241163},
	{"VOLKMANN", 8, 241164},
	{"SAMTRON", 7, 241165},
	{"PARDEY", 6, 241166},
	{"JALNA", 5, 241167},
	{"WHAY", 4, 241168},
	{"SHAMIM", 6, 241169},
	{"SEGREGATIONIST", 14, 241170},
	{"NATURSCHUTZ", 11, 241171},
	{"MOUSKOURI", 9, 241172},
	{"AMPULES", 7, 241173},
	{"TOEGANG", 7, 241174},
	{"NYMPHALIDAE", 11, 241175},
	{"JORNADAS", 8, 241176},
	{"FFRAMWAITH", 10, 241177},
	{"YGOLD", 5, 241178},
	{"UNHIP", 5, 241179},
	{"CUARON", 6, 241180},
	{"JEVONS", 6, 241181},
	{"JOASH", 5, 241182},
	{"HABSBURGS", 9, 241183},
	{"KAKINADA", 8, 241184},
	{"FAHREN", 6, 241185},
	{"TRENO", 5, 241186},
	{"POLYGONACEAE", 12, 241187},
	{"OUTDOORSY", 9, 241188},
	{"ITLIB", 5, 241189},
	{"HUNNS", 5, 241190},
	{"FREEHEAVEN", 10, 241191},
	{"DENEBA", 6, 241192},
	{"COSFORD", 7, 241193},
	{"DECRIPTION", 10, 241194},
	{"TANJUG", 6, 241195},
	{"LAWR", 4, 241196},
	{"SHOOSHTIME", 10, 241197},
	{"PRAGATI", 7, 241198},
	{"ECOND", 5, 241199},
	{"ASUC", 4, 241200},
	{"ZORRA", 5, 241201},
	{"POUTINE", 7, 241202},
	{"EXACTIONS", 9, 241203},
	{"CUPFUL", 6, 241204},
	{"NOTIZ", 5, 241205},
	{"IMPARZIALI", 10, 241206},
	{"PREDICATIVE", 11, 241207},
	{"OPERATIONALIZING", 16, 241208},
	{"IVREA", 5, 241209},
	{"SPAZA", 5, 241210},
	{"SHIZMOO", 7, 241211},
	{"DCJS", 4, 241212},
	{"CHARTIST", 8, 241213},
	{"YASUYUKI", 8, 241214},
	{"BUYTAERT", 8, 241215},
	{"POKEDEX", 7, 241216},
	{"OVERDUB", 7, 241217},
	{"LIBTERMCAP", 10, 241218},
	{"ABDUCTEE", 8, 241219},
	{"MLSZ", 4, 241220},
	{"CIMITERO", 8, 241221},
	{"AIRBAND", 7, 241222},
	{"CRIMLAW", 7, 241223},
	{"RAINBIRD", 8, 241224},
	{"MOCLOBEMIDE", 11, 241225},
	{"FEMINISTA", 9, 241226},
	{"CYSTATHIONINE", 13, 241227},
	{"COQUI", 5, 241228},
	{"KULOW", 5, 241229},
	{"ISLER", 5, 241230},
	{"ANACHRONOX", 10, 241231},
	{"SERPA", 5, 241232},
	{"ROREM", 5, 241233},
	{"LUGGER", 6, 241234},
	{"TECHWOOD", 8, 241235},
	{"GANGLY", 6, 241236},
	{"ECOPHYSIOLOGY", 13, 241237},
	{"COUTURA", 7, 241238},
	{"TRANSFIXING", 11, 241239},
	{"ISPOT", 5, 241240},
	{"BIRA", 4, 241241},
	{"DECENDANTS", 10, 241242},
	{"BOTNETS", 7, 241243},
	{"VALVO", 5, 241244},
	{"NYMITY", 6, 241245},
	{"MANGLES", 7, 241246},
	{"LINEAS", 6, 241247},
	{"ZIBO", 4, 241248},
	{"SUBBANDS", 8, 241249},
	{"ENTORHINAL", 10, 241250},
	{"LINKTOOLTIPINFO", 15, 241251},
	{"CATY", 4, 241252},
	{"BESTIMMT", 8, 241253},
	{"ADGER", 5, 241254},
	{"JASPERT", 7, 241255},
	{"ITEMFIND", 8, 241256},
	{"OPROGRAMOWANIE", 14, 241257},
	{"LUR", 3, 241258},
	{"PATRICIANS", 10, 241259},
	{"FOXLEY", 6, 241260},
	{"TECHNISCHER", 11, 241261},
	{"IKAROS", 6, 241262},
	{"DAUGHTRY", 8, 241263},
	{"SHUEY", 5, 241264},
	{"PSAPS", 5, 241265},
	{"KOLLA", 5, 241266},
	{"COMPUTECH", 9, 241267},
	{"PICTORAL", 8, 241268},
	{"ULTIMATETV", 10, 241269},
	{"TANZI", 5, 241270},
	{"STERO", 5, 241271},
	{"NYCO", 4, 241272},
	{"MCGOOHAN", 8, 241273},
	{"ATONED", 6, 241274},
	{"XSVCD", 5, 241275},
	{"TIRADO", 6, 241276},
	{"TELEGRAAF", 9, 241277},
	{"JALISTO", 7, 241278},
	{"FULLAN", 6, 241279},
	{"BRIGHTENER", 10, 241280},
	{"TRUMANN", 7, 241281},
	{"KANTIPUR", 8, 241282},
	{"FOTBALL", 7, 241283},
	{"DEKOR", 5, 241284},
	{"BLACKBELT", 9, 241285},
	{"ADESA", 5, 241286},
	{"PERSONALJAVA", 12, 241287},
	{"ARNOUX", 6, 241288},
	{"YMDDANGOS", 9, 241289},
	{"ZYFA", 4, 241290},
	{"ZVIN", 4, 241291},
	{"YXRA", 4, 241292},
	{"YJAL", 4, 241293},
	{"YAMK", 4, 241294},
	{"XJUN", 4, 241295},
	{"XICR", 4, 241296},
	{"WASX", 4, 241297},
	{"UFSA", 4, 241298},
	{"UBYD", 4, 241299},
	{"UAJA", 4, 241300},
	{"TZJO", 4, 241301},
	{"TZGA", 4, 241302},
	{"TLWA", 4, 241303},
	{"SPYL", 4, 241304},
	{"SMSK", 4, 241305},
	{"RYOX", 4, 241306},
	{"REUF", 4, 241307},
	{"PMJO", 4, 241308},
	{"PAKP", 4, 241309},
	{"OUBS", 4, 241310},
	{"OFIU", 4, 241311},
	{"NRBS", 4, 241312},
	{"NDXF", 4, 241313},
	{"NBPA", 4, 241314},
	{"MMOX", 4, 241315},
	{"MGUT", 4, 241316},
	{"LSUV", 4, 241317},
	{"LOCD", 4, 241318},
	{"LNIR", 4, 241319},
	{"LEFK", 4, 241320},
	{"LEFC", 4, 241321},
	{"LAXH", 4, 241322},
	{"KOBZ", 4, 241323},
	{"JUNB", 4, 241324},
	{"JEEB", 4, 241325},
	{"IQAB", 4, 241326},
	{"HKOC", 4, 241327},
	{"GUDR", 4, 241328},
	{"GSTG", 4, 241329},
	{"GRIU", 4, 241330},
	{"GRHA", 4, 241331},
	{"GLUF", 4, 241332},
	{"FOAR", 4, 241333},
	{"FJOD", 4, 241334},
	{"FDRP", 4, 241335},
	{"FCSU", 4, 241336},
	{"EOZZ", 4, 241337},
	{"EIVC", 4, 241338},
	{"DSRY", 4, 241339},
	{"DHDT", 4, 241340},
	{"DEGB", 4, 241341},
	{"CIQU", 4, 241342},
	{"CHGM", 4, 241343},
	{"CAOD", 4, 241344},
	{"BPSI", 4, 241345},
	{"BODU", 4, 241346},
	{"BNDA", 4, 241347},
	{"BGIB", 4, 241348},
	{"BCDU", 4, 241349},
	{"AZYJ", 4, 241350},
	{"ATZC", 4, 241351},
	{"AICK", 4, 241352},
	{"ACLT", 4, 241353},
	{"ACIW", 4, 241354},
	{"ABEJ", 4, 241355},
	{"VARKON", 6, 241356},
	{"GEROLSTEINER", 12, 241357},
	{"CRATIC", 6, 241358},
	{"CIFUENTES", 9, 241359},
	{"ANGEBEN", 7, 241360},
	{"GOTTFREDSON", 11, 241361},
	{"BUYWMA", 6, 241362},
	{"ACTUALIZADA", 11, 241363},
	{"WHAX", 4, 241364},
	{"ROCHAMBEAU", 10, 241365},
	{"REVALUE", 7, 241366},
	{"CAPIT", 5, 241367},
	{"BOULDIN", 7, 241368},
	{"TOURBILLON", 10, 241369},
	{"SPAMCOMBAT", 10, 241370},
	{"MESABI", 6, 241371},
	{"KHADDAM", 7, 241372},
	{"HAPUNA", 6, 241373},
	{"FIBBERS", 7, 241374},
	{"CAUSETH", 7, 241375},
	{"IRISA", 5, 241376},
	{"HASTELLOY", 9, 241377},
	{"CRICCIETH", 9, 241378},
	{"UNPROMISING", 11, 241379},
	{"ULMAN", 5, 241380},
	{"IPSEN", 5, 241381},
	{"SENGA", 5, 241382},
	{"NHBC", 4, 241383},
	{"MOORISHGIRL", 11, 241384},
	{"BRANDSTOF", 9, 241385},
	{"YARR", 4, 241386},
	{"ROXTON", 6, 241387},
	{"LOWNEY", 6, 241388},
	{"PEACEFULL", 9, 241389},
	{"PLUSNEWS", 8, 241390},
	{"GELUID", 6, 241391},
	{"PKWARE", 6, 241392},
	{"CONNECTEURS", 11, 241393},
	{"CIVICO", 6, 241394},
	{"ANGIOLOGY", 9, 241395},
	{"LEAVEY", 6, 241396},
	{"CAISSONS", 8, 241397},
	{"SURCHARGED", 10, 241398},
	{"PUNCTUATING", 11, 241399},
	{"MCBRIEN", 7, 241400},
	{"BAGES", 5, 241401},
	{"NOBREAK", 7, 241402},
	{"TELENCEPHALON", 13, 241403},
	{"SPANG", 5, 241404},
	{"NETEGRITY", 9, 241405},
	{"KARENS", 6, 241406},
	{"COLWALL", 7, 241407},
	{"FLATPICKING", 11, 241408},
	{"STOFF", 5, 241409},
	{"LEAM", 4, 241410},
	{"INVESTIMENTOS", 13, 241411},
	{"APRENDE", 7, 241412},
	{"ALCAUCIN", 8, 241413},
	{"TYGH", 4, 241414},
	{"GRUPE", 5, 241415},
	{"CTAC", 4, 241416},
	{"GOTAN", 5, 241417},
	{"YALMIP", 6, 241418},
	{"WOODCHIP", 8, 241419},
	{"OHURA", 5, 241420},
	{"MOWLAM", 6, 241421},
	{"TRATOR", 6, 241422},
	{"ROMANTASY", 9, 241423},
	{"OUTCALLS", 8, 241424},
	{"FEEDFORALL", 10, 241425},
	{"DOORMEN", 7, 241426},
	{"NAILSTYLE", 9, 241427},
	{"MANCOZEB", 8, 241428},
	{"BLYLEVEN", 8, 241429},
	{"SCRIPTOR", 8, 241430},
	{"CARDIOMEGALY", 12, 241431},
	{"STAVERTON", 9, 241432},
	{"RESENTATIVE", 11, 241433},
	{"FEATHERBEDS", 11, 241434},
	{"CENEGA", 6, 241435},
	{"BACKFLIPS", 9, 241436},
	{"QUARRELED", 9, 241437},
	{"KAMUS", 5, 241438},
	{"UNLEASHX", 8, 241439},
	{"TUSCADERO", 9, 241440},
	{"SUCKLED", 7, 241441},
	{"KOOSER", 6, 241442},
	{"CVSTRAC", 7, 241443},
	{"AUTOMOTIVEAUTOMOTIVE", 20, 241444},
	{"NETAJI", 6, 241445},
	{"ASSABET", 7, 241446},
	{"TABKE", 5, 241447},
	{"SOORT", 5, 241448},
	{"PULPY", 5, 241449},
	{"ONLIBE", 6, 241450},
	{"NONEXISTANT", 11, 241451},
	{"NIGGLE", 6, 241452},
	{"ILLEST", 6, 241453},
	{"FOOTWAYS", 8, 241454},
	{"CAMMACK", 7, 241455},
	{"STEPBROTHER", 11, 241456},
	{"DEBUS", 5, 241457},
	{"GULIK", 5, 241458},
	{"USACOM", 6, 241459},
	{"KOWARI", 6, 241460},
	{"APATOW", 6, 241461},
	{"SENIORNET", 9, 241462},
	{"HAILEYBURY", 10, 241463},
	{"BASELAYOUT", 10, 241464},
	{"ORAU", 4, 241465},
	{"NAHANNI", 7, 241466},
	{"KHAZARS", 7, 241467},
	{"GIOCONDA", 8, 241468},
	{"DIODATI", 7, 241469},
	{"REMOULADE", 9, 241470},
	{"BUSULFAN", 8, 241471},
	{"PETABYTE", 8, 241472},
	{"MADINGLEY", 9, 241473},
	{"LUSER", 5, 241474},
	{"VFF", 3, 241475},
	{"INVIGILATOR", 11, 241476},
	{"AUSTINBURG", 10, 241477},
	{"TECHOFF", 7, 241478},
	{"MILITAIRES", 10, 241479},
	{"MERCAPTAN", 9, 241480},
	{"BSME", 4, 241481},
	{"ADKISSON", 8, 241482},
	{"TROPIX", 6, 241483},
	{"PSWD", 4, 241484},
	{"MPEC", 4, 241485},
	{"LEDERHOSEN", 10, 241486},
	{"INTIMIDATES", 11, 241487},
	{"RAIMO", 5, 241488},
	{"PARTAKER", 8, 241489},
	{"THEOLOGIE", 9, 241490},
	{"SOCHA", 5, 241491},
	{"PIGMY", 5, 241492},
	{"BATHINDA", 8, 241493},
	{"APUESTA", 7, 241494},
	{"WAYANG", 6, 241495},
	{"RJB", 3, 241496},
	{"PUW", 3, 241497},
	{"MIKEB", 5, 241498},
	{"IDREAMSTOCK", 11, 241499},
	{"AUTOMATISCHE", 12, 241500},
	{"SUGLI", 5, 241501},
	{"OLHOS", 5, 241502},
	{"HELMINTHS", 9, 241503},
	{"CENSURES", 8, 241504},
	{"LIBERATORE", 10, 241505},
	{"MORIR", 5, 241506},
	{"JOBURGPETE", 10, 241507},
	{"DARABONT", 8, 241508},
	{"BULBAR", 6, 241509},
	{"KRUIDEN", 7, 241510},
	{"GETPROCADDRESS", 14, 241511},
	{"PCRM", 4, 241512},
	{"LUIZA", 5, 241513},
	{"TRID", 4, 241514},
	{"CHARNEL", 7, 241515},
	{"AZZURA", 6, 241516},
	{"APPOLOGIES", 10, 241517},
	{"BESCHIKBAARHEID", 15, 241518},
	{"RADIONATION", 11, 241519},
	{"KASTURI", 7, 241520},
	{"TADIRAN", 7, 241521},
	{"SUPOSED", 7, 241522},
	{"SUNEX", 5, 241523},
	{"SHATILA", 7, 241524},
	{"DATGANIADAU", 11, 241525},
	{"DMARC", 5, 241526},
	{"CALENDARI", 9, 241527},
	{"AVALAUNCH", 9, 241528},
	{"ZWIESEL", 7, 241529},
	{"FACIALES", 8, 241530},
	{"SPIRELLA", 8, 241531},
	{"MELNYK", 6, 241532},
	{"EXTREMUM", 8, 241533},
	{"AKTY", 4, 241534},
	{"SPOONED", 7, 241535},
	{"SWMP", 4, 241536},
	{"NIGHTHORSE", 10, 241537},
	{"APALACHEE", 9, 241538},
	{"QSIG", 4, 241539},
	{"PINTAR", 6, 241540},
	{"INFUSIUM", 8, 241541},
	{"DRAFTSMEN", 9, 241542},
	{"CRYPTOCOCCAL", 12, 241543},
	{"GALLUCCI", 8, 241544},
	{"CAMBRIDGEPORT", 13, 241545},
	{"VERDA", 5, 241546},
	{"MUJI", 4, 241547},
	{"COFFEEPOT", 9, 241548},
	{"BROODY", 6, 241549},
	{"KNUCKLED", 8, 241550},
	{"DIALECTAL", 9, 241551},
	{"CORILLIAN", 9, 241552},
	{"WMAS", 4, 241553},
	{"SUBCOMANDANTE", 13, 241554},
	{"PRAKRITI", 8, 241555},
	{"VICARIO", 7, 241556},
	{"SOOKIE", 6, 241557},
	{"KINCHELOE", 9, 241558},
	{"INTERCROPPING", 13, 241559},
	{"COSETS", 6, 241560},
	{"USTER", 5, 241561},
	{"SAWMILLING", 10, 241562},
	{"PATRIZIO", 8, 241563},
	{"ANNIESLAND", 10, 241564},
	{"AUSFISH", 7, 241565},
	{"PHOTOGRAPHE", 11, 241566},
	{"NGLS", 4, 241567},
	{"MOBILITOOLS", 11, 241568},
	{"LATYNOSKI", 9, 241569},
	{"BEED", 4, 241570},
	{"MACLEANS", 8, 241571},
	{"NEGRETE", 7, 241572},
	{"ONELIST", 7, 241573},
	{"LANDSTUHL", 9, 241574},
	{"HYDROXYTRYPTOPHAN", 17, 241575},
	{"SWEETNAM", 8, 241576},
	{"INTROGRESSION", 13, 241577},
	{"VIOLE", 5, 241578},
	{"ZZUT", 4, 241579},
	{"ZUNT", 4, 241580},
	{"ZNAR", 4, 241581},
	{"YZEE", 4, 241582},
	{"YDBU", 4, 241583},
	{"YBAZ", 4, 241584},
	{"XJOH", 4, 241585},
	{"WOEC", 4, 241586},
	{"WKAS", 4, 241587},
	{"VCOA", 4, 241588},
	{"UZAM", 4, 241589},
	{"USJI", 4, 241590},
	{"UMUD", 4, 241591},
	{"UIZM", 4, 241592},
	{"TZAU", 4, 241593},
	{"TNUL", 4, 241594},
	{"TEUK", 4, 241595},
	{"TAPG", 4, 241596},
	{"SWCL", 4, 241597},
	{"SUKT", 4, 241598},
	{"STXR", 4, 241599},
	{"SMIV", 4, 241600},
	{"SFJO", 4, 241601},
	{"SDBO", 4, 241602},
	{"RUAA", 4, 241603},
	{"RRAQ", 4, 241604},
	{"RNXI", 4, 241605},
	{"RKAE", 4, 241606},
	{"RHPT", 4, 241607},
	{"RHPB", 4, 241608},
	{"RDTF", 4, 241609},
	{"RDRL", 4, 241610},
	{"QSCO", 4, 241611},
	{"PDWA", 4, 241612},
	{"OWVU", 4, 241613},
	{"ORHC", 4, 241614},
	{"OIDK", 4, 241615},
	{"NZYL", 4, 241616},
	{"NMMS", 4, 241617},
	{"NFDI", 4, 241618},
	{"MGYM", 4, 241619},
	{"MAJS", 4, 241620},
	{"LTNU", 4, 241621},
	{"LODH", 4, 241622},
	{"LJUA", 4, 241623},
	{"LEPF", 4, 241624},
	{"KRIY", 4, 241625},
	{"KPHE", 4, 241626},
	{"IGMT", 4, 241627},
	{"IEMW", 4, 241628},
	{"HAPD", 4, 241629},
	{"GYEQ", 4, 241630},
	{"GTMI", 4, 241631},
	{"GPSP", 4, 241632},
	{"FHUC", 4, 241633},
	{"FEDV", 4, 241634},
	{"EWZI", 4, 241635},
	{"EWFM", 4, 241636},
	{"DUKL", 4, 241637},
	{"DOKK", 4, 241638},
	{"DOCP", 4, 241639},
	{"DJTO", 4, 241640},
	{"DGWY", 4, 241641},
	{"CNAD", 4, 241642},
	{"CLTE", 4, 241643},
	{"CFHA", 4, 241644},
	{"BYNY", 4, 241645},
	{"BTAP", 4, 241646},
	{"BPSE", 4, 241647},
	{"BDEB", 4, 241648},
	{"ATZP", 4, 241649},
	{"APTG", 4, 241650},
	{"AMCF", 4, 241651},
	{"TILESET", 7, 241652},
	{"SAOIRSE", 7, 241653},
	{"IDIQ", 4, 241654},
	{"SUDLEY", 6, 241655},
	{"REVOLU", 6, 241656},
	{"KOSHI", 5, 241657},
	{"UNPROVED", 8, 241658},
	{"UDED", 4, 241659},
	{"DIGGED", 6, 241660},
	{"NEPM", 4, 241661},
	{"ROCKLEA", 7, 241662},
	{"PCNET", 5, 241663},
	{"UREI", 4, 241664},
	{"SAVANNAHS", 9, 241665},
	{"SPAG", 4, 241666},
	{"XIPO", 4, 241667},
	{"SIPX", 4, 241668},
	{"NETBUILDER", 10, 241669},
	{"MOENE", 5, 241670},
	{"TURKCELL", 8, 241671},
	{"DOBELLI", 7, 241672},
	{"SNEATH", 6, 241673},
	{"GLUCKMAN", 8, 241674},
	{"SAMMS", 5, 241675},
	{"ONTIVEROS", 9, 241676},
	{"MINCH", 5, 241677},
	{"CLEARLIGHT", 10, 241678},
	{"BMY", 3, 241679},
	{"MEGEVE", 6, 241680},
	{"CROXTON", 7, 241681},
	{"CLICKTRACKS", 11, 241682},
	{"ATOMLAB", 7, 241683},
	{"UNTRACKED", 9, 241684},
	{"TWEENING", 8, 241685},
	{"HURLERS", 7, 241686},
	{"HRONLINE", 8, 241687},
	{"HERODIAS", 8, 241688},
	{"BIBLIOZ", 7, 241689},
	{"ATENAS", 6, 241690},
	{"MAFFRA", 6, 241691},
	{"ANTICLOCKWISE", 13, 241692},
	{"MANDL", 5, 241693},
	{"STOYANOV", 8, 241694},
	{"SPORTWEAR", 9, 241695},
	{"SAGRADO", 7, 241696},
	{"PERUGINO", 8, 241697},
	{"FLASHPAPER", 10, 241698},
	{"SAFEMODE", 8, 241699},
	{"CLEE", 4, 241700},
	{"AWARNESS", 8, 241701},
	{"GASSET", 6, 241702},
	{"FUST", 4, 241703},
	{"WINEHQ", 6, 241704},
	{"MELLINI", 7, 241705},
	{"INSCRIRE", 8, 241706},
	{"HYPES", 5, 241707},
	{"CONFESSORS", 10, 241708},
	{"HOMR", 4, 241709},
	{"MASSARI", 7, 241710},
	{"RAWL", 4, 241711},
	{"CHEAPPHENTERMINE", 16, 241712},
	{"SHRIKES", 7, 241713},
	{"EARGLOVE", 8, 241714},
	{"KLEUR", 5, 241715},
	{"HOLMESVILLE", 11, 241716},
	{"BRYNMAWR", 8, 241717},
	{"NUCLEOPHILE", 11, 241718},
	{"HOTUSA", 6, 241719},
	{"SHAKESPEARES", 12, 241720},
	{"NEHGS", 5, 241721},
	{"BROOKEVILLE", 11, 241722},
	{"BRAUT", 5, 241723},
	{"ARIZONANS", 9, 241724},
	{"UNFURLING", 9, 241725},
	{"LOSEC", 5, 241726},
	{"HULSHOF", 7, 241727},
	{"ARACHIDONATE", 12, 241728},
	{"LOANAPP", 7, 241729},
	{"LATERZ", 6, 241730},
	{"LACERATED", 9, 241731},
	{"RAYMUNDO", 8, 241732},
	{"PROMPTINGS", 10, 241733},
	{"HERNING", 7, 241734},
	{"GANIZATIONS", 11, 241735},
	{"UNREACTED", 9, 241736},
	{"TRANSPARENCE", 12, 241737},
	{"LGMODULE", 8, 241738},
	{"ENRY", 4, 241739},
	{"DRAHOS", 6, 241740},
	{"FULLARTON", 9, 241741},
	{"SUBREG", 6, 241742},
	{"PROPST", 6, 241743},
	{"MAZAL", 5, 241744},
	{"MARITAIN", 8, 241745},
	{"TETENAL", 7, 241746},
	{"DESPAIN", 7, 241747},
	{"GLOCKS", 6, 241748},
	{"ZYZ", 3, 241749},
	{"TRANCES", 7, 241750},
	{"LUXEMBURGO", 10, 241751},
	{"DUCATO", 6, 241752},
	{"AUTOGALLERY", 11, 241753},
	{"SIGNMAKING", 10, 241754},
	{"COUNTERPROLIFERATION", 20, 241755},
	{"VOUCHED", 7, 241756},
	{"PALAVRAS", 8, 241757},
	{"HJORTH", 6, 241758},
	{"BOUDVILLE", 9, 241759},
	{"ARGUENDO", 8, 241760},
	{"VYPRESS", 7, 241761},
	{"SQIRTING", 8, 241762},
	{"CASETEK", 7, 241763},
	{"NUTEK", 5, 241764},
	{"CEDRICK", 7, 241765},
	{"HOMW", 4, 241766},
	{"SFOTWARE", 8, 241767},
	{"IPKUNGFU", 8, 241768},
	{"DISACCHARIDES", 13, 241769},
	{"BROADLOOM", 9, 241770},
	{"SONORI", 6, 241771},
	{"ROBOTRON", 8, 241772},
	{"KMZ", 3, 241773},
	{"SCHIPPERS", 9, 241774},
	{"POHJOLA", 7, 241775},
	{"DIAMINO", 7, 241776},
	{"DIGWYDD", 7, 241777},
	{"BLAEU", 5, 241778},
	{"TIBUS", 5, 241779},
	{"KINISON", 7, 241780},
	{"JUAL", 4, 241781},
	{"ZIRKIN", 6, 241782},
	{"TAIZE", 5, 241783},
	{"LAROCHELLE", 10, 241784},
	{"PROCEEDURE", 10, 241785},
	{"PENTANES", 8, 241786},
	{"OBLIGINGLY", 10, 241787},
	{"KESSEN", 6, 241788},
	{"QUICKFIX", 8, 241789},
	{"ROMANELLO", 9, 241790},
	{"QUINNS", 6, 241791},
	{"METODI", 6, 241792},
	{"ERMM", 4, 241793},
	{"RIENZI", 6, 241794},
	{"INITSORT", 8, 241795},
	{"WETTABILITY", 11, 241796},
	{"ELVERTA", 7, 241797},
	{"BALLINROBE", 10, 241798},
	{"TENSILICA", 9, 241799},
	{"MARTECH", 7, 241800},
	{"JCATER", 6, 241801},
	{"FUNDINGS", 8, 241802},
	{"MORTGAGEES", 10, 241803},
	{"FRUTESCENS", 10, 241804},
	{"VOLKSWAGENS", 11, 241805},
	{"ONEBASE", 7, 241806},
	{"MOZZILLA", 8, 241807},
	{"TEDDYS", 6, 241808},
	{"OEUF", 4, 241809},
	{"GUTTERBALL", 10, 241810},
	{"USUS", 4, 241811},
	{"MICROSMITH", 10, 241812},
	{"LINKA", 5, 241813},
	{"YERSELF", 7, 241814},
	{"AMBIANCES", 9, 241815},
	{"JAEL", 4, 241816},
	{"BARKEEP", 7, 241817},
	{"TRAGEN", 6, 241818},
	{"PARNAS", 6, 241819},
	{"UNCYCLOPEDIA", 12, 241820},
	{"RECIENTES", 9, 241821},
	{"ADENTRO", 7, 241822},
	{"SPINIFEX", 8, 241823},
	{"MARKETINGPROFS", 14, 241824},
	{"DERMO", 5, 241825},
	{"CALIFORNIE", 10, 241826},
	{"YONGSAN", 7, 241827},
	{"TOARRAY", 7, 241828},
	{"CICONIA", 7, 241829},
	{"YAYASAN", 7, 241830},
	{"OCNL", 4, 241831},
	{"OCHIAI", 6, 241832},
	{"LEAFHOPPERS", 11, 241833},
	{"EMASCULATION", 12, 241834},
	{"SPEEDNAMES", 10, 241835},
	{"POLIFONE", 8, 241836},
	{"STEVEL", 6, 241837},
	{"SOYABEAN", 8, 241838},
	{"REBIN", 5, 241839},
	{"SIGMOIDAL", 9, 241840},
	{"SERVERHOUSING", 13, 241841},
	{"BUKEM", 5, 241842},
	{"HERBALGRAM", 10, 241843},
	{"DAVANUM", 7, 241844},
	{"INBAND", 6, 241845},
	{"AFOR", 4, 241846},
	{"PLAM", 4, 241847},
	{"OUTWITTING", 10, 241848},
	{"FALVEY", 6, 241849},
	{"EARPLUG", 7, 241850},
	{"BRANCACCIO", 10, 241851},
	{"DORMATORY", 9, 241852},
	{"VERTICENT", 9, 241853},
	{"UNEXPRESSED", 11, 241854},
	{"ESTIM", 5, 241855},
	{"HOYLAND", 7, 241856},
	{"GRAYWOLF", 8, 241857},
	{"GAUVIN", 6, 241858},
	{"DIRECTORYNAME", 13, 241859},
	{"ZMEA", 4, 241860},
	{"YFUJ", 4, 241861},
	{"YERQ", 4, 241862},
	{"XIFT", 4, 241863},
	{"WEMY", 4, 241864},
	{"WDAU", 4, 241865},
	{"ULBT", 4, 241866},
	{"UKUY", 4, 241867},
	{"UKUB", 4, 241868},
	{"UILB", 4, 241869},
	{"UHLI", 4, 241870},
	{"UEOL", 4, 241871},
	{"UCYP", 4, 241872},
	{"UBUC", 4, 241873},
	{"UALZ", 4, 241874},
	{"THKW", 4, 241875},
	{"STDM", 4, 241876},
	{"SPMJ", 4, 241877},
	{"SKFE", 4, 241878},
	{"RVLO", 4, 241879},
	{"RRSW", 4, 241880},
	{"ROXW", 4, 241881},
	{"RKYF", 4, 241882},
	{"RFWO", 4, 241883},
	{"RFFW", 4, 241884},
	{"REPV", 4, 241885},
	{"OOGU", 4, 241886},
	{"OILJ", 4, 241887},
	{"OBQU", 4, 241888},
	{"NIGB", 4, 241889},
	{"NEBW", 4, 241890},
	{"NDXT", 4, 241891},
	{"MZCO", 4, 241892},
	{"MAXU", 4, 241893},
	{"LUPN", 4, 241894},
	{"LUAI", 4, 241895},
	{"LKYT", 4, 241896},
	{"LAOM", 4, 241897},
	{"KZDU", 4, 241898},
	{"KTAG", 4, 241899},
	{"KAYK", 4, 241900},
	{"JOOD", 4, 241901},
	{"JFKS", 4, 241902},
	{"JESC", 4, 241903},
	{"IPOK", 4, 241904},
	{"IBIW", 4, 241905},
	{"HYPS", 4, 241906},
	{"HUOC", 4, 241907},
	{"HOGM", 4, 241908},
	{"HDYL", 4, 241909},
	{"GXAN", 4, 241910},
	{"FZAG", 4, 241911},
	{"FRYF", 4, 241912},
	{"FJPM", 4, 241913},
	{"FEOW", 4, 241914},
	{"FCBU", 4, 241915},
	{"EJUC", 4, 241916},
	{"EFNM", 4, 241917},
	{"EBLS", 4, 241918},
	{"DLOH", 4, 241919},
	{"DEGT", 4, 241920},
	{"CKZD", 4, 241921},
	{"CKRD", 4, 241922},
	{"BYMG", 4, 241923},
	{"AYIU", 4, 241924},
	{"AQSM", 4, 241925},
	{"AHPK", 4, 241926},
	{"AEDD", 4, 241927},
	{"ABKI", 4, 241928},
	{"SPONDYLOSIS", 11, 241929},
	{"EVALF", 5, 241930},
	{"BEDT", 4, 241931},
	{"WEEBLE", 6, 241932},
	{"LUNCHED", 7, 241933},
	{"ISOBUTYLENE", 11, 241934},
	{"GUAYAKI", 7, 241935},
	{"BCMA", 4, 241936},
	{"ROSSOUW", 7, 241937},
	{"VENUTI", 6, 241938},
	{"SAIRAM", 6, 241939},
	{"CRYPTOME", 8, 241940},
	{"QUINDON", 7, 241941},
	{"GHEY", 4, 241942},
	{"CLACKMANNAN", 11, 241943},
	{"SOLUT", 5, 241944},
	{"INSTUMENTS", 10, 241945},
	{"TONNAGES", 8, 241946},
	{"KAJA", 4, 241947},
	{"UNESCAPED", 9, 241948},
	{"SUPERADMINGROUP", 15, 241949},
	{"SUBMAXIMAL", 10, 241950},
	{"RIPTON", 6, 241951},
	{"PORFIRIO", 8, 241952},
	{"ALEXAN", 6, 241953},
	{"FUNNYBONES", 10, 241954},
	{"SCOURGING", 9, 241955},
	{"ARCHIVESTUFF", 12, 241956},
	{"NVAR", 4, 241957},
	{"MIGEMO", 6, 241958},
	{"GOOFINESS", 9, 241959},
	{"ULAM", 4, 241960},
	{"DISPATCHEVENT", 13, 241961},
	{"SOUTHDALE", 9, 241962},
	{"SAMEDAYMUSIC", 12, 241963},
	{"NIETZSCHEAN", 11, 241964},
	{"HAROUN", 6, 241965},
	{"CORYLUS", 7, 241966},
	{"SOLIPSISTIC", 11, 241967},
	{"PIKSEL", 6, 241968},
	{"DESHAUN", 7, 241969},
	{"GOETHITE", 8, 241970},
	{"SEATTLENOISE", 12, 241971},
	{"PRESSLOCAL", 10, 241972},
	{"MUINCLUSIVE", 11, 241973},
	{"CREDITE", 7, 241974},
	{"BERTUCCI", 8, 241975},
	{"BOSKO", 5, 241976},
	{"QLC", 3, 241977},
	{"GREENRIDGE", 10, 241978},
	{"SUNNIEST", 8, 241979},
	{"PROPRIETORY", 11, 241980},
	{"BACKROUNDS", 10, 241981},
	{"ZAIBATSU", 8, 241982},
	{"MULTILOCUS", 10, 241983},
	{"BACKLIGHTS", 10, 241984},
	{"SIDECUT", 7, 241985},
	{"PUBLIER", 7, 241986},
	{"HAMZAH", 6, 241987},
	{"SELVAGE", 7, 241988},
	{"RIPKA", 5, 241989},
	{"BOUCHERVILLE", 12, 241990},
	{"ENVOX", 5, 241991},
	{"CHERNEY", 7, 241992},
	{"CHAMAN", 6, 241993},
	{"TRVEL", 5, 241994},
	{"GRAZES", 6, 241995},
	{"RUBAIYAT", 8, 241996},
	{"GLYCOPEPTIDE", 12, 241997},
	{"MKFS", 4, 241998},
	{"JOBTRACK", 8, 241999},
	{"GROOVERIDER", 11, 242000},
	{"POSTHERPETIC", 12, 242001},
	{"MIRAN", 5, 242002},
	{"STTORNEY", 8, 242003},
	{"REINSURED", 9, 242004},
	{"MATIONS", 7, 242005},
	{"STRTOUPPER", 10, 242006},
	{"SITESCOOPER", 11, 242007},
	{"MINIVIEW", 8, 242008},
	{"VAFA", 4, 242009},
	{"SIDEMEN", 7, 242010},
	{"NUCLEATUM", 9, 242011},
	{"ANGELMAN", 8, 242012},
	{"ACEDB", 5, 242013},
	{"HERAKLIO", 8, 242014},
	{"ACTERESS", 8, 242015},
	{"MUTUALS", 7, 242016},
	{"GLEIM", 5, 242017},
	{"BUKAVU", 6, 242018},
	{"MANFULLY", 8, 242019},
	{"CANIM", 5, 242020},
	{"HUNSBERGER", 10, 242021},
	{"KLIA", 4, 242022},
	{"GRANZYME", 8, 242023},
	{"XVNC", 4, 242024},
	{"POLARS", 6, 242025},
	{"DRAINPIPE", 9, 242026},
	{"CONTRAPUNTAL", 12, 242027},
	{"PRINCIPALI", 10, 242028},
	{"PADDYS", 6, 242029},
	{"DEMENTORS", 9, 242030},
	{"CFSA", 4, 242031},
	{"VIDARE", 6, 242032},
	{"SABADO", 6, 242033},
	{"AMSTERDAMER", 11, 242034},
	{"ALISIA", 6, 242035},
	{"PHAROAHE", 8, 242036},
	{"NETTERS", 7, 242037},
	{"KOJE", 4, 242038},
	{"CURMUDGEONRY", 12, 242039},
	{"BARRACUDAMVC", 12, 242040},
	{"TULLOCK", 7, 242041},
	{"SAMPADA", 7, 242042},
	{"SAKAKIBARA", 10, 242043},
	{"ROMANOS", 7, 242044},
	{"HANDOVERS", 9, 242045},
	{"AWHONN", 6, 242046},
	{"TERUMO", 6, 242047},
	{"MOPPETS", 7, 242048},
	{"BOMBADIL", 8, 242049},
	{"REVOLUTIONIST", 13, 242050},
	{"JARRAD", 6, 242051},
	{"FORTWO", 6, 242052},
	{"ESPIO", 5, 242053},
	{"VERSAMAIL", 9, 242054},
	{"GOLDCREST", 9, 242055},
	{"ROMI", 4, 242056},
	{"KILKEE", 6, 242057},
	{"DMINISTRATION", 13, 242058},
	{"MAGALHAES", 9, 242059},
	{"MACALPINE", 9, 242060},
	{"CHEVALLIER", 10, 242061},
	{"CENTENARIANS", 12, 242062},
	{"EXPODISC", 8, 242063},
	{"COLORSYNC", 9, 242064},
	{"CHOGOKIN", 8, 242065},
	{"NGINE", 5, 242066},
	{"AKIMOTO", 7, 242067},
	{"VSEVOLOD", 8, 242068},
	{"INSTRUMENTING", 13, 242069},
	{"UNIMAX", 6, 242070},
	{"SARCO", 5, 242071},
	{"EMPTING", 7, 242072},
	{"UXM", 3, 242073},
	{"PENSO", 5, 242074},
	{"IERLAND", 7, 242075},
	{"LAFEBER", 7, 242076},
	{"DOFTWARE", 8, 242077},
	{"BEDARRA", 7, 242078},
	{"SUCEAVA", 7, 242079},
	{"PROVAN", 6, 242080},
	{"KREHBIEL", 8, 242081},
	{"GREENBUSHES", 11, 242082},
	{"PROANTHOCYANIDINS", 17, 242083},
	{"OPHIDIAN", 8, 242084},
	{"WATONWAN", 8, 242085},
	{"WARTHOGS", 8, 242086},
	{"INCLIN", 6, 242087},
	{"KENNT", 5, 242088},
	{"BELAYING", 8, 242089},
	{"ASSOCIATON", 10, 242090},
	{"WIFFLE", 6, 242091},
	{"KHALI", 5, 242092},
	{"COMMITTEEAGENDAS", 16, 242093},
	{"RCSID", 5, 242094},
	{"NETLAB", 6, 242095},
	{"KCNC", 4, 242096},
	{"ENATURE", 7, 242097},
	{"VEGTABLES", 9, 242098},
	{"CARDAS", 6, 242099},
	{"PICZO", 5, 242100},
	{"NEPHROLOGIST", 12, 242101},
	{"MEDISCH", 7, 242102},
	{"CALINDA", 7, 242103},
	{"ALLARME", 7, 242104},
	{"MULTIDROP", 9, 242105},
	{"WESTAT", 6, 242106},
	{"TRACERY", 7, 242107},
	{"RELAXNG", 7, 242108},
	{"REALJUKEBOX", 11, 242109},
	{"HRUBY", 5, 242110},
	{"BANANE", 6, 242111},
	{"SWINDELLS", 9, 242112},
	{"CHROMEWAVES", 11, 242113},
	{"BILLON", 6, 242114},
	{"SHANNAN", 7, 242115},
	{"HUNTINGBURG", 11, 242116},
	{"YEHUDIT", 7, 242117},
	{"EBERS", 5, 242118},
	{"KERSTEIN", 8, 242119},
	{"DROLET", 6, 242120},
	{"DOLIO", 5, 242121},
	{"GNUCHESS", 8, 242122},
	{"COLTSFOOT", 9, 242123},
	{"MAXTOOL", 7, 242124},
	{"MATERIALIZING", 13, 242125},
	{"TEASLEY", 7, 242126},
	{"OPSEU", 5, 242127},
	{"ELECTRODYNAMIC", 14, 242128},
	{"AKTIVE", 6, 242129},
	{"INOTIFY", 7, 242130},
	{"DOEVERYTHING", 12, 242131},
	{"BERSAMA", 7, 242132},
	{"SPEEDROCK", 9, 242133},
	{"SLACKNESS", 9, 242134},
	{"TECHCONNECT", 11, 242135},
	{"TCUG", 4, 242136},
	{"MICROWORLDS", 11, 242137},
	{"FOODY", 5, 242138},
	{"BLANCHOT", 8, 242139},
	{"BEPPOSAX", 8, 242140},
	{"SURMISES", 8, 242141},
	{"OHLSON", 6, 242142},
	{"GROPER", 6, 242143},
	{"CATEGORIZADOS", 13, 242144},
	{"WINLAW", 6, 242145},
	{"PERRINEAU", 9, 242146},
	{"LAWINFO", 7, 242147},
	{"KRETSCHMER", 10, 242148},
	{"FLUORESCENTLY", 13, 242149},
	{"DYNAPI", 6, 242150},
	{"ALLWN", 5, 242151},
	{"TORNO", 5, 242152},
	{"PANGOLIN", 8, 242153},
	{"ASCENDENT", 9, 242154},
	{"VENAS", 5, 242155},
	{"BEHOOVE", 7, 242156},
	{"KUAT", 4, 242157},
	{"TOWELL", 6, 242158},
	{"TEXIFY", 6, 242159},
	{"RUBBOS", 6, 242160},
	{"YZEH", 4, 242161},
	{"YHIJ", 4, 242162},
	{"WMCD", 4, 242163},
	{"WAKH", 4, 242164},
	{"VYSW", 4, 242165},
	{"VNOV", 4, 242166},
	{"UYIW", 4, 242167},
	{"UXET", 4, 242168},
	{"TWBA", 4, 242169},
	{"TRMO", 4, 242170},
	{"TGOK", 4, 242171},
	{"TDCH", 4, 242172},
	{"SVAD", 4, 242173},
	{"SURJ", 4, 242174},
	{"SRPA", 4, 242175},
	{"SCEG", 4, 242176},
	{"RTEJ", 4, 242177},
	{"ROVM", 4, 242178},
	{"RAAQ", 4, 242179},
	{"QIFU", 4, 242180},
	{"ORNQ", 4, 242181},
	{"ONJP", 4, 242182},
	{"OFKC", 4, 242183},
	{"NWUS", 4, 242184},
	{"NRIJ", 4, 242185},
	{"MWTH", 4, 242186},
	{"MVCA", 4, 242187},
	{"LNDP", 4, 242188},
	{"LFPH", 4, 242189},
	{"KUNH", 4, 242190},
	{"KOAC", 4, 242191},
	{"KKAC", 4, 242192},
	{"JARF", 4, 242193},
	{"IJAD", 4, 242194},
	{"IDZH", 4, 242195},
	{"HPPR", 4, 242196},
	{"GUZA", 4, 242197},
	{"GSAX", 4, 242198},
	{"GKET", 4, 242199},
	{"GCOY", 4, 242200},
	{"GBFO", 4, 242201},
	{"FIUN", 4, 242202},
	{"EWCS", 4, 242203},
	{"EKLM", 4, 242204},
	{"EDWB", 4, 242205},
	{"EBJA", 4, 242206},
	{"DVDL", 4, 242207},
	{"DIIR", 4, 242208},
	{"DDJI", 4, 242209},
	{"CKCD", 4, 242210},
	{"CBIC", 4, 242211},
	{"BMFO", 4, 242212},
	{"AZPI", 4, 242213},
	{"ASGP", 4, 242214},
	{"AJGR", 4, 242215},
	{"ACBY", 4, 242216},
	{"CLADOGRAM", 9, 242217},
	{"BEECHSPORTBILL", 14, 242218},
	{"HOCKENBERRY", 11, 242219},
	{"ZHUAN", 5, 242220},
	{"STREAMWISE", 10, 242221},
	{"SLOC", 4, 242222},
	{"SCHULTHEIS", 10, 242223},
	{"NONFLAMMABLE", 12, 242224},
	{"MARGINWIDTH", 11, 242225},
	{"FIGG", 4, 242226},
	{"CYBERPATROL", 11, 242227},
	{"YEEHAW", 6, 242228},
	{"VITALSTREAM", 11, 242229},
	{"MICROGRAMMA", 11, 242230},
	{"CONNES", 6, 242231},
	{"ACANTHAMOEBA", 12, 242232},
	{"CYFLWYNIAD", 10, 242233},
	{"TAILRACE", 8, 242234},
	{"SHAZIA", 6, 242235},
	{"BEDINGUNGEN", 11, 242236},
	{"STATIO", 6, 242237},
	{"PANDITS", 7, 242238},
	{"ARBORVITAE", 10, 242239},
	{"SLABBED", 7, 242240},
	{"AINLEY", 6, 242241},
	{"SPORTURA", 8, 242242},
	{"RICCA", 5, 242243},
	{"DYRBERG", 7, 242244},
	{"FALLE", 5, 242245},
	{"KARMAS", 6, 242246},
	{"SCHADUW", 7, 242247},
	{"OOSTERHOUT", 10, 242248},
	{"MEHRDAD", 7, 242249},
	{"FILIPACCHI", 10, 242250},
	{"CRUMPET", 7, 242251},
	{"SEEMLY", 6, 242252},
	{"JSWAT", 5, 242253},
	{"IDIOTARIANS", 11, 242254},
	{"VERADALE", 8, 242255},
	{"NIPAWIN", 7, 242256},
	{"LUNDBLAD", 8, 242257},
	{"DORENE", 6, 242258},
	{"BESTBUYPLASMA", 13, 242259},
	{"MONOHYDRAAT", 11, 242260},
	{"MCLG", 4, 242261},
	{"ELEOCHARIS", 10, 242262},
	{"MERRYFIELD", 10, 242263},
	{"TARRING", 7, 242264},
	{"SWIMMIN", 7, 242265},
	{"PRARS", 5, 242266},
	{"MIAME", 5, 242267},
	{"MABIE", 5, 242268},
	{"SCUTELLARIA", 11, 242269},
	{"SAMRA", 5, 242270},
	{"BARBERIE", 8, 242271},
	{"ADMINTOOLS", 10, 242272},
	{"OVERLOCK", 8, 242273},
	{"CATCHED", 7, 242274},
	{"BUSINSS", 7, 242275},
	{"ACKERLY", 7, 242276},
	{"RACKETEERS", 10, 242277},
	{"SPELLAR", 7, 242278},
	{"HARKEY", 6, 242279},
	{"TASTELE", 7, 242280},
	{"SENTATIONS", 10, 242281},
	{"LGPS", 4, 242282},
	{"IDAG", 4, 242283},
	{"AROWANA", 7, 242284},
	{"HOWLITE", 7, 242285},
	{"AXUM", 4, 242286},
	{"CARRABBA", 8, 242287},
	{"TSPC", 4, 242288},
	{"ADSORBATE", 9, 242289},
	{"SAURA", 5, 242290},
	{"INFOWEATHERONLINE", 17, 242291},
	{"FRATES", 6, 242292},
	{"BANDELIER", 9, 242293},
	{"SNARING", 7, 242294},
	{"LENGYEL", 7, 242295},
	{"LANGHOLM", 8, 242296},
	{"KASHIWA", 7, 242297},
	{"ITEMNUMBER", 10, 242298},
	{"MATARAM", 7, 242299},
	{"ALCANCE", 7, 242300},
	{"BARASH", 6, 242301},
	{"WEBCLOTHES", 10, 242302},
	{"SOURCEADDRESS", 13, 242303},
	{"POINTLESSLY", 11, 242304},
	{"LISTO", 5, 242305},
	{"FUNL", 4, 242306},
	{"AMATTEROFFAX", 12, 242307},
	{"WASKOM", 6, 242308},
	{"HAMPSTER", 8, 242309},
	{"AGGRANDIZING", 12, 242310},
	{"RSSVIEW", 7, 242311},
	{"MINDBODYSPIRIT", 14, 242312},
	{"IZVESTIA", 8, 242313},
	{"EXCIPIENT", 9, 242314},
	{"PANCREATIN", 10, 242315},
	{"OVERPACK", 8, 242316},
	{"INDON", 5, 242317},
	{"IMAGECLUB", 9, 242318},
	{"BELLEW", 6, 242319},
	{"SACHTLER", 8, 242320},
	{"SOUNDFIELD", 10, 242321},
	{"PHARMACAL", 9, 242322},
	{"KRUZ", 4, 242323},
	{"TEHUTI", 6, 242324},
	{"SOMATIZATION", 12, 242325},
	{"PUBFINDER", 9, 242326},
	{"RIESTER", 7, 242327},
	{"JARROLD", 7, 242328},
	{"ENREGISTRER", 11, 242329},
	{"SGLI", 4, 242330},
	{"PERSIL", 6, 242331},
	{"LUDWIGS", 7, 242332},
	{"HABET", 5, 242333},
	{"THEOCRATS", 9, 242334},
	{"SHARHOLDERS", 11, 242335},
	{"LICENCIAS", 9, 242336},
	{"JDD", 3, 242337},
	{"INDICOM", 7, 242338},
	{"HESKEY", 6, 242339},
	{"NACIONAIS", 9, 242340},
	{"GEHTS", 5, 242341},
	{"PHYTOPLASMA", 11, 242342},
	{"MYELOFIBROSIS", 13, 242343},
	{"MICROLITER", 10, 242344},
	{"INTEGRAMOD", 10, 242345},
	{"HAIDAR", 6, 242346},
	{"EVENHANDED", 10, 242347},
	{"BODNER", 6, 242348},
	{"CONCEPTUALISING", 15, 242349},
	{"ONOFRI", 6, 242350},
	{"DYNAMIK", 7, 242351},
	{"PRESO", 5, 242352},
	{"HORARIO", 7, 242353},
	{"BEUCLER", 7, 242354},
	{"NARNES", 6, 242355},
	{"DROL", 4, 242356},
	{"INDEXSTOCK", 10, 242357},
	{"MAMAMONTEZZ", 11, 242358},
	{"DANNELLY", 8, 242359},
	{"TELEVISA", 8, 242360},
	{"SCULLION", 8, 242361},
	{"SAUROPOD", 8, 242362},
	{"FREEMOVIE", 9, 242363},
	{"AGRIS", 5, 242364},
	{"PASSU", 5, 242365},
	{"NAUGHTINESS", 11, 242366},
	{"WATCHERHOST", 11, 242367},
	{"ROSALYNN", 8, 242368},
	{"PIDA", 4, 242369},
	{"SCHWYZ", 6, 242370},
	{"PADFOLIO", 8, 242371},
	{"FISTFIGHT", 9, 242372},
	{"DOGFENNAU", 9, 242373},
	{"MARITHE", 7, 242374},
	{"KUAC", 4, 242375},
	{"ADVS", 4, 242376},
	{"STICKEL", 7, 242377},
	{"REQUA", 5, 242378},
	{"NSTEP", 5, 242379},
	{"BENUE", 5, 242380},
	{"CONRADI", 7, 242381},
	{"VENGONO", 7, 242382},
	{"TRANSFERTS", 10, 242383},
	{"SARATH", 6, 242384},
	{"DRUCKANSICHT", 12, 242385},
	{"DECILITER", 9, 242386},
	{"TRYALL", 6, 242387},
	{"RVB", 3, 242388},
	{"REPLICABILITY", 13, 242389},
	{"PAUSANIAS", 9, 242390},
	{"GOWANUS", 7, 242391},
	{"BBSS", 4, 242392},
	{"TIMEWORKS", 9, 242393},
	{"ROSALINDA", 9, 242394},
	{"PALEARCTIC", 10, 242395},
	{"HOSTINGWEB", 10, 242396},
	{"DERECHA", 7, 242397},
	{"CURIEL", 6, 242398},
	{"ASTUDIO", 7, 242399},
	{"ALLOMETRIC", 10, 242400},
	{"MILAD", 5, 242401},
	{"LYZED", 5, 242402},
	{"TRITIATED", 9, 242403},
	{"BOSNIAK", 7, 242404},
	{"NUNATSIAQ", 9, 242405},
	{"MOVILLE", 7, 242406},
	{"DIGIFUSION", 10, 242407},
	{"POETRYNOTES", 11, 242408},
	{"KOOCHICHING", 11, 242409},
	{"FASTIDIOUSNESS", 14, 242410},
	{"MILITARIST", 10, 242411},
	{"JPLM", 4, 242412},
	{"DITOR", 5, 242413},
	{"BILANCIO", 8, 242414},
	{"AYURCEUTICS", 11, 242415},
	{"ANORECTIC", 9, 242416},
	{"WIGGER", 6, 242417},
	{"DEMONIAC", 8, 242418},
	{"WAUKON", 6, 242419},
	{"USTRCMP", 7, 242420},
	{"ZEPHYRUS", 8, 242421},
	{"PUCELLE", 7, 242422},
	{"EVOTOPSITES", 11, 242423},
	{"PSYCHOLOGIES", 12, 242424},
	{"HOMESELLER", 10, 242425},
	{"CLARENVILLE", 11, 242426},
	{"TRUNCATUS", 9, 242427},
	{"SNUBBER", 7, 242428},
	{"EXCERPTA", 8, 242429},
	{"CORNFORD", 8, 242430},
	{"TRIVIALIZED", 11, 242431},
	{"RETSKP", 6, 242432},
	{"RANGO", 5, 242433},
	{"HAMMERSCHMIDT", 13, 242434},
	{"ZZFA", 4, 242435},
	{"ZMIC", 4, 242436},
	{"ZGIV", 4, 242437},
	{"YJBL", 4, 242438},
	{"YIUN", 4, 242439},
	{"YGMI", 4, 242440},
	{"YGHE", 4, 242441},
	{"XVIN", 4, 242442},
	{"XPRA", 4, 242443},
	{"XCHO", 4, 242444},
	{"WSMC", 4, 242445},
	{"WRYO", 4, 242446},
	{"VPUB", 4, 242447},
	{"VIXI", 4, 242448},
	{"UYCR", 4, 242449},
	{"URCD", 4, 242450},
	{"SZHU", 4, 242451},
	{"SOVW", 4, 242452},
	{"RYUD", 4, 242453},
	{"RIXG", 4, 242454},
	{"RHYO", 4, 242455},
	{"POMB", 4, 242456},
	{"PDOY", 4, 242457},
	{"OWLQ", 4, 242458},
	{"OJEK", 4, 242459},
	{"OIMJ", 4, 242460},
	{"NWOV", 4, 242461},
	{"NSWB", 4, 242462},
	{"NSQB", 4, 242463},
	{"NLIR", 4, 242464},
	{"NDXU", 4, 242465},
	{"MOVO", 4, 242466},
	{"LUGR", 4, 242467},
	{"LIIR", 4, 242468},
	{"KOEV", 4, 242469},
	{"JYOU", 4, 242470},
	{"JURU", 4, 242471},
	{"JIVI", 4, 242472},
	{"JCOL", 4, 242473},
	{"IVOG", 4, 242474},
	{"IVFR", 4, 242475},
	{"IMUA", 4, 242476},
	{"HYMR", 4, 242477},
	{"HOMV", 4, 242478},
	{"HIVW", 4, 242479},
	{"GOEC", 4, 242480},
	{"GIKE", 4, 242481},
	{"FKOC", 4, 242482},
	{"FGIU", 4, 242483},
	{"ESFP", 4, 242484},
	{"EGPI", 4, 242485},
	{"DPOA", 4, 242486},
	{"DNYL", 4, 242487},
	{"DLRI", 4, 242488},
	{"DJWH", 4, 242489},
	{"DJRS", 4, 242490},
	{"CIVO", 4, 242491},
	{"BYML", 4, 242492},
	{"BOEM", 4, 242493},
	{"BEUF", 4, 242494},
	{"AXRU", 4, 242495},
	{"ATLP", 4, 242496},
	{"ALCF", 4, 242497},
	{"ACDW", 4, 242498},
	{"AAMY", 4, 242499},
	{"FWW", 3, 242500},
	{"OPENABLE", 8, 242501},
	{"PSYCHOTHERAPIES", 15, 242502},
	{"INFLUENTIALS", 12, 242503},
	{"PENURY", 6, 242504},
	{"CADHERINS", 9, 242505},
	{"JWST", 4, 242506},
	{"HOLBEACH", 8, 242507},
	{"PROGESTOGEN", 11, 242508},
	{"CONJUROR", 8, 242509},
	{"ATTRIBS", 7, 242510},
	{"JTWC", 4, 242511},
	{"GOPNIK", 6, 242512},
	{"EROSPIRIT", 9, 242513},
	{"VIRENS", 6, 242514},
	{"TIMEPOINT", 9, 242515},
	{"IRRADIATING", 11, 242516},
	{"GEVA", 4, 242517},
	{"GANGLIONIC", 10, 242518},
	{"FIREFLIER", 9, 242519},
	{"FIBRILLAR", 9, 242520},
	{"DIRECTRON", 9, 242521},
	{"CHEEMA", 6, 242522},
	{"VENTURINI", 9, 242523},
	{"TGWU", 4, 242524},
	{"MINUTUS", 7, 242525},
	{"HEPATO", 6, 242526},
	{"DEPILATORY", 10, 242527},
	{"CYBERALIEN", 10, 242528},
	{"ESPONJA", 7, 242529},
	{"WNEW", 4, 242530},
	{"WAINSCOT", 8, 242531},
	{"MINIWAREHOUSES", 14, 242532},
	{"BODYPAINTING", 12, 242533},
	{"WHEELERSBURG", 12, 242534},
	{"SUPERNAL", 8, 242535},
	{"RBV", 3, 242536},
	{"MRTONES", 7, 242537},
	{"KIRTI", 5, 242538},
	{"GRACENOTE", 9, 242539},
	{"BCMP", 4, 242540},
	{"TRUDIE", 6, 242541},
	{"MACLAGAN", 8, 242542},
	{"HERPETIFORMIS", 13, 242543},
	{"EXPERIMENTELLE", 14, 242544},
	{"BISOGNO", 7, 242545},
	{"ANTITHYROID", 11, 242546},
	{"TURPAN", 6, 242547},
	{"MOONLIGHTS", 10, 242548},
	{"SMOLENSKY", 9, 242549},
	{"HERMOSAWAVE", 11, 242550},
	{"COLOMBUS", 8, 242551},
	{"SUBTHREAD", 9, 242552},
	{"KISSAMOS", 8, 242553},
	{"BOPPING", 7, 242554},
	{"ZOMETA", 6, 242555},
	{"STEELVILLE", 10, 242556},
	{"HUNSINGER", 9, 242557},
	{"SOWTHISTLE", 10, 242558},
	{"SHOLD", 5, 242559},
	{"FORGERS", 7, 242560},
	{"DUBBS", 5, 242561},
	{"MILLROSE", 8, 242562},
	{"FAMCICLOVIR", 11, 242563},
	{"OUTSOLD", 7, 242564},
	{"ESKY", 4, 242565},
	{"BEINECKE", 8, 242566},
	{"RUFC", 4, 242567},
	{"PRZEPROWADZKI", 13, 242568},
	{"JAZEERAH", 8, 242569},
	{"IMPELLING", 9, 242570},
	{"BRAUEREI", 8, 242571},
	{"TROUNCING", 9, 242572},
	{"KELTIK", 6, 242573},
	{"ELWHA", 5, 242574},
	{"SAGARA", 6, 242575},
	{"GBRMPA", 6, 242576},
	{"SELSEY", 6, 242577},
	{"NOBUHIRO", 8, 242578},
	{"MCAA", 4, 242579},
	{"TRIALING", 8, 242580},
	{"COMIT", 5, 242581},
	{"TANYARD", 7, 242582},
	{"DINAMARCA", 9, 242583},
	{"CKRM", 4, 242584},
	{"WIGDERSON", 9, 242585},
	{"SPSC", 4, 242586},
	{"LESHNER", 7, 242587},
	{"INHACA", 6, 242588},
	{"ALACHLOR", 8, 242589},
	{"ENFERMERAS", 10, 242590},
	{"RICHARDDONKIN", 13, 242591},
	{"RAZON", 5, 242592},
	{"DUBAY", 5, 242593},
	{"RESTIGOUCHE", 11, 242594},
	{"WHIL", 4, 242595},
	{"CAUGHEY", 7, 242596},
	{"WOMENFOLK", 9, 242597},
	{"POWA", 4, 242598},
	{"FACTBITES", 9, 242599},
	{"CLONEABLE", 9, 242600},
	{"BURLWOOD", 8, 242601},
	{"COMEDOWN", 8, 242602},
	{"SEADOVE", 7, 242603},
	{"LINKTIPS", 8, 242604},
	{"GUARDARE", 8, 242605},
	{"POWERBASE", 9, 242606},
	{"KAITSTUD", 8, 242607},
	{"BEACAUSE", 8, 242608},
	{"ABETA", 5, 242609},
	{"SUPERCELLS", 10, 242610},
	{"OPPEL", 5, 242611},
	{"DAMENTAL", 8, 242612},
	{"CASGLIADAU", 10, 242613},
	{"PUCON", 5, 242614},
	{"UNORGANISED", 11, 242615},
	{"SILVIE", 6, 242616},
	{"NODISCLOSURE", 12, 242617},
	{"GLIBENCLAMIDE", 13, 242618},
	{"GAVAZZI", 7, 242619},
	{"THIRDSPHERE", 11, 242620},
	{"MOONDANCER", 10, 242621},
	{"DOWNSHIFTING", 12, 242622},
	{"DATAWAREHOUSE", 13, 242623},
	{"COLUMBI", 7, 242624},
	{"COALMONT", 8, 242625},
	{"BORIN", 5, 242626},
	{"AKAGI", 5, 242627},
	{"SERATO", 6, 242628},
	{"LAVATRICE", 9, 242629},
	{"CECC", 4, 242630},
	{"VALSALVA", 8, 242631},
	{"MERRYLANDS", 10, 242632},
	{"LEPAS", 5, 242633},
	{"ELBRUS", 6, 242634},
	{"DVANCED", 7, 242635},
	{"AMELANCHIER", 11, 242636},
	{"SPAMFILTER", 10, 242637},
	{"REDROCK", 7, 242638},
	{"PLANESPOTTING", 13, 242639},
	{"ONDERNEMING", 11, 242640},
	{"MISHICOT", 8, 242641},
	{"CLEV", 4, 242642},
	{"OBOIST", 6, 242643},
	{"KODESH", 6, 242644},
	{"BRAZAVILLE", 10, 242645},
	{"ACTIVEPLAZA", 11, 242646},
	{"SIMCO", 5, 242647},
	{"MICROCHIPPED", 12, 242648},
	{"INKBEND", 7, 242649},
	{"MOHAPATRA", 9, 242650},
	{"LUDING", 6, 242651},
	{"LIBFILE", 7, 242652},
	{"UHLER", 5, 242653},
	{"GYMRYD", 6, 242654},
	{"FENCEPOST", 9, 242655},
	{"AROUN", 5, 242656},
	{"POCKETBIKE", 10, 242657},
	{"PEGLER", 6, 242658},
	{"AUCLAIR", 7, 242659},
	{"WIBC", 4, 242660},
	{"NONRANDOM", 9, 242661},
	{"FGY", 3, 242662},
	{"CONTENTTUTORIALSE", 17, 242663},
	{"APUNTES", 7, 242664},
	{"DRAGOMIR", 8, 242665},
	{"FERRITIC", 8, 242666},
	{"METABLOG", 8, 242667},
	{"MAGAZINEPREMIUM", 15, 242668},
	{"HOMENEWSE", 9, 242669},
	{"ACTININ", 7, 242670},
	{"TRAYICON", 8, 242671},
	{"MURIS", 5, 242672},
	{"PERGAMUM", 8, 242673},
	{"CELLULE", 7, 242674},
	{"BOOTSLAVES", 10, 242675},
	{"GATTUSO", 7, 242676},
	{"SECOLO", 6, 242677},
	{"SANTILLANA", 10, 242678},
	{"PHOTODISCFILM", 13, 242679},
	{"PANKO", 5, 242680},
	{"MIZATION", 8, 242681},
	{"FUNZIONI", 8, 242682},
	{"APOTELESMA", 10, 242683},
	{"SITWELL", 7, 242684},
	{"ORGUE", 5, 242685},
	{"LOGDIR", 6, 242686},
	{"MONIFIETH", 9, 242687},
	{"VANHOOK", 7, 242688},
	{"EINZELNEN", 9, 242689},
	{"CLOTHESPINS", 11, 242690},
	{"STEVEDORES", 10, 242691},
	{"NCFE", 4, 242692},
	{"MODESTE", 7, 242693},
	{"FLITS", 5, 242694},
	{"VINOGRAPHY", 10, 242695},
	{"PUTATION", 8, 242696},
	{"STICS", 5, 242697},
	{"BREAKAWAYS", 10, 242698},
	{"ANDAMOOKA", 9, 242699},
	{"ANACOM", 6, 242700},
	{"VACILLATING", 11, 242701},
	{"INVIO", 5, 242702},
	{"CLEB", 4, 242703},
	{"CHASITY", 7, 242704},
	{"ROEG", 4, 242705},
	{"RIVASTIGMINE", 12, 242706},
	{"DUNCANNON", 9, 242707},
	{"BLOODAXE", 8, 242708},
	{"VICTIMOLOGY", 11, 242709},
	{"STRONGBAD", 9, 242710},
	{"PREGNANCYPREGNANCY", 18, 242711},
	{"ZSMI", 4, 242712},
	{"ZISY", 4, 242713},
	{"YSNF", 4, 242714},
	{"YKWH", 4, 242715},
	{"XTOV", 4, 242716},
	{"VSOM", 4, 242717},
	{"VOSB", 4, 242718},
	{"UWMA", 4, 242719},
	{"UAPI", 4, 242720},
	{"TBLY", 4, 242721},
	{"STCZ", 4, 242722},
	{"SOYM", 4, 242723},
	{"SGME", 4, 242724},
	{"SADK", 4, 242725},
	{"RMHZ", 4, 242726},
	{"PSYB", 4, 242727},
	{"PFEW", 4, 242728},
	{"OPFS", 4, 242729},
	{"OLYZ", 4, 242730},
	{"OIFC", 4, 242731},
	{"OCFI", 4, 242732},
	{"NOYB", 4, 242733},
	{"MYDV", 4, 242734},
	{"MWEG", 4, 242735},
	{"MIPI", 4, 242736},
	{"MHZC", 4, 242737},
	{"LVLA", 4, 242738},
	{"LUAP", 4, 242739},
	{"LFEG", 4, 242740},
	{"LCDO", 4, 242741},
	{"LCAA", 4, 242742},
	{"JSAR", 4, 242743},
	{"JRMI", 4, 242744},
	{"JOHJ", 4, 242745},
	{"HUDR", 4, 242746},
	{"HLUR", 4, 242747},
	{"HGIU", 4, 242748},
	{"GRYU", 4, 242749},
	{"GPSM", 4, 242750},
	{"FOGW", 4, 242751},
	{"FEYV", 4, 242752},
	{"EKYS", 4, 242753},
	{"EBSK", 4, 242754},
	{"DRMT", 4, 242755},
	{"DPBY", 4, 242756},
	{"DMUE", 4, 242757},
	{"DEZG", 4, 242758},
	{"DCFI", 4, 242759},
	{"CENJ", 4, 242760},
	{"CCYL", 4, 242761},
	{"BYIP", 4, 242762},
	{"BSKN", 4, 242763},
	{"BIDN", 4, 242764},
	{"ATZL", 4, 242765},
	{"AHUJ", 4, 242766},
	{"REWRITEABLE", 11, 242767},
	{"IBUPROFIN", 9, 242768},
	{"AVISE", 5, 242769},
	{"NFER", 4, 242770},
	{"MANCUSI", 7, 242771},
	{"ALLOTTING", 9, 242772},
	{"SHAARA", 6, 242773},
	{"RAVAL", 5, 242774},
	{"PADEREWSKI", 10, 242775},
	{"NEBOJSA", 7, 242776},
	{"FAMOSO", 6, 242777},
	{"CARBURETTORS", 12, 242778},
	{"GINEERING", 9, 242779},
	{"BIBRA", 5, 242780},
	{"GOOGLEMAPS", 10, 242781},
	{"SCHWEIZERHOF", 12, 242782},
	{"MONICAL", 7, 242783},
	{"MAIDENHAIR", 10, 242784},
	{"KULICK", 6, 242785},
	{"CORYDALIS", 9, 242786},
	{"SCIOTA", 6, 242787},
	{"ROMOLA", 6, 242788},
	{"LONGSTRETH", 10, 242789},
	{"CASEI", 5, 242790},
	{"VILANOVA", 8, 242791},
	{"GROLSCH", 7, 242792},
	{"NYXEM", 5, 242793},
	{"MYCORRHIZA", 10, 242794},
	{"KELLMAN", 7, 242795},
	{"INTENSOL", 8, 242796},
	{"COMPUTERNAME", 12, 242797},
	{"WRIGHTSOCK", 10, 242798},
	{"ACQUARIO", 8, 242799},
	{"SCANNON", 7, 242800},
	{"INACIO", 6, 242801},
	{"CLASSAD", 7, 242802},
	{"UROP", 4, 242803},
	{"ORIFLAME", 8, 242804},
	{"WOODPILE", 8, 242805},
	{"JOCULAR", 7, 242806},
	{"ZENAIDA", 7, 242807},
	{"MELLOM", 6, 242808},
	{"MANTIDS", 7, 242809},
	{"JUMPMAN", 7, 242810},
	{"JEHL", 4, 242811},
	{"BANCK", 5, 242812},
	{"WESTHOUGHTON", 12, 242813},
	{"INTERLEAVER", 11, 242814},
	{"XQUARE", 6, 242815},
	{"MADLEY", 6, 242816},
	{"SPEIDEL", 7, 242817},
	{"LIBGNOMEVFS", 11, 242818},
	{"CARLUCCIO", 9, 242819},
	{"SIPADAN", 7, 242820},
	{"REFFERING", 9, 242821},
	{"GALOP", 5, 242822},
	{"JLARC", 5, 242823},
	{"DEKU", 4, 242824},
	{"SKIDDER", 7, 242825},
	{"CHAVIN", 6, 242826},
	{"PSPC", 4, 242827},
	{"SENHOR", 6, 242828},
	{"MICRODISSECTION", 15, 242829},
	{"AEQUIDENS", 9, 242830},
	{"MAIDSERVANT", 11, 242831},
	{"COPRIME", 7, 242832},
	{"BUCKYBALLS", 10, 242833},
	{"AZLAN", 5, 242834},
	{"YOUGOV", 6, 242835},
	{"LEATHERWEAR", 11, 242836},
	{"KASAA", 5, 242837},
	{"CARYOPHYLLACEAE", 15, 242838},
	{"RANALD", 6, 242839},
	{"EDLY", 4, 242840},
	{"BNPFT", 5, 242841},
	{"ACKLES", 6, 242842},
	{"VRABEL", 6, 242843},
	{"KLUYVEROMYCES", 13, 242844},
	{"DOTTIES", 7, 242845},
	{"CFRA", 4, 242846},
	{"ANELLO", 6, 242847},
	{"RAPRA", 5, 242848},
	{"PSTR", 4, 242849},
	{"MANRESA", 7, 242850},
	{"TENASCIN", 8, 242851},
	{"FIGHTSTAR", 9, 242852},
	{"UMAIR", 5, 242853},
	{"RPK", 3, 242854},
	{"JACOBINS", 8, 242855},
	{"CHIPP", 5, 242856},
	{"BLACKDIAMOND", 12, 242857},
	{"RCVS", 4, 242858},
	{"FOLIGNO", 7, 242859},
	{"DELTS", 5, 242860},
	{"COMINO", 6, 242861},
	{"NUIMA", 5, 242862},
	{"DESTINATIONADDRESS", 18, 242863},
	{"TIGHTWAD", 8, 242864},
	{"GAMBELL", 7, 242865},
	{"BADILLO", 7, 242866},
	{"SHOALWATER", 10, 242867},
	{"CERUTTI", 7, 242868},
	{"VFILE", 5, 242869},
	{"IDENTNR", 7, 242870},
	{"WRONGHEADED", 11, 242871},
	{"ROTEM", 5, 242872},
	{"DUCEY", 5, 242873},
	{"BOADICEA", 8, 242874},
	{"TRUESDELL", 9, 242875},
	{"SOLDSMART", 9, 242876},
	{"NEWSSERVERS", 11, 242877},
	{"GRISCOM", 7, 242878},
	{"CAMPUSWIDE", 10, 242879},
	{"CALLBOOK", 8, 242880},
	{"SPAL", 4, 242881},
	{"MILENIO", 7, 242882},
	{"KERST", 5, 242883},
	{"QUICKTOPIC", 10, 242884},
	{"PALANTIR", 8, 242885},
	{"IINSURANCE", 10, 242886},
	{"EIDHSEIS", 8, 242887},
	{"EFFICENCY", 9, 242888},
	{"SEYFARTH", 8, 242889},
	{"GENDA", 5, 242890},
	{"TEQUILLA", 8, 242891},
	{"WATHEN", 6, 242892},
	{"UNSCR", 5, 242893},
	{"FORSYTE", 7, 242894},
	{"KUNGL", 5, 242895},
	{"ULCERATIONS", 11, 242896},
	{"SCHULTEN", 8, 242897},
	{"MADORE", 6, 242898},
	{"INDURATED", 9, 242899},
	{"DURATA", 6, 242900},
	{"NONMARKET", 9, 242901},
	{"BAUKNECHT", 9, 242902},
	{"ROBBERT", 7, 242903},
	{"PBSC", 4, 242904},
	{"NEWCOMERSTOWN", 13, 242905},
	{"INFILLING", 9, 242906},
	{"STOKERS", 7, 242907},
	{"PIPEC", 5, 242908},
	{"CARLYON", 7, 242909},
	{"QUINTER", 7, 242910},
	{"QDB", 3, 242911},
	{"FATHOMLESS", 10, 242912},
	{"EVENTSEVENTS", 12, 242913},
	{"ALWA", 4, 242914},
	{"DAAL", 4, 242915},
	{"PERSONAM", 8, 242916},
	{"MOORFIELDS", 10, 242917},
	{"ONTOLOGICALLY", 13, 242918},
	{"OBLITERANS", 10, 242919},
	{"MORGANFIELD", 11, 242920},
	{"MARGY", 5, 242921},
	{"SUPYBOT", 7, 242922},
	{"MANSKE", 6, 242923},
	{"PAZARDJIK", 9, 242924},
	{"COMPREHENSIBILITY", 17, 242925},
	{"RODING", 6, 242926},
	{"PLEON", 5, 242927},
	{"INSULARITY", 10, 242928},
	{"INNHOLD", 7, 242929},
	{"TIROS", 5, 242930},
	{"TRADITIONNAL", 12, 242931},
	{"GIARDINA", 8, 242932},
	{"ENVIRONMENTENVIRONMENT", 22, 242933},
	{"LEEUWENHOEK", 11, 242934},
	{"GROULX", 6, 242935},
	{"SELPA", 5, 242936},
	{"MAGSAYSAY", 9, 242937},
	{"EBML", 4, 242938},
	{"ASIANWEEK", 9, 242939},
	{"FILLETING", 9, 242940},
	{"DNSC", 4, 242941},
	{"SQLCODE", 7, 242942},
	{"PATELLOFEMORAL", 14, 242943},
	{"CHIDING", 7, 242944},
	{"ABONDANCE", 9, 242945},
	{"ARCSECOND", 9, 242946},
	{"SADIES", 6, 242947},
	{"NEVADANS", 8, 242948},
	{"CAMOUFLAGING", 12, 242949},
	{"REATMENT", 8, 242950},
	{"LICKITY", 7, 242951},
	{"BIGGERT", 7, 242952},
	{"CHATTIN", 7, 242953},
	{"BOGGLED", 7, 242954},
	{"MINIBIKE", 8, 242955},
	{"ISSAM", 5, 242956},
	{"PICCIONI", 8, 242957},
	{"INDIANHEAD", 10, 242958},
	{"REUTILIZATION", 13, 242959},
	{"CHBRDR", 6, 242960},
	{"TANER", 5, 242961},
	{"RENDEL", 6, 242962},
	{"BARCAMP", 7, 242963},
	{"WALKATHON", 9, 242964},
	{"RETROFACTS", 10, 242965},
	{"QUINBY", 6, 242966},
	{"IDIOTVOX", 8, 242967},
	{"RETICULOCYTES", 13, 242968},
	{"HEIER", 5, 242969},
	{"DRYED", 5, 242970},
	{"DARGAN", 6, 242971},
	{"ICEPICK", 7, 242972},
	{"ENKELT", 6, 242973},
	{"SITCHIN", 7, 242974},
	{"RAMMELL", 7, 242975},
	{"LATERITE", 8, 242976},
	{"IANNONE", 7, 242977},
	{"ENDEARINGLY", 11, 242978},
	{"COLCA", 5, 242979},
	{"OFRECEN", 7, 242980},
	{"FPMI", 4, 242981},
	{"SEMIPALMATED", 12, 242982},
	{"ANBIETEN", 8, 242983},
	{"SPRC", 4, 242984},
	{"COMPARATIVA", 11, 242985},
	{"STURDINESS", 10, 242986},
	{"SAVOURED", 8, 242987},
	{"DOCSTRINGS", 10, 242988},
	{"HAEMATOPOIETIC", 14, 242989},
	{"CALAMINE", 8, 242990},
	{"COMMANCHE", 9, 242991},
	{"ANLAGEN", 7, 242992},
	{"ZHIV", 4, 242993},
	{"ZBAT", 4, 242994},
	{"YLSQ", 4, 242995},
	{"YKNU", 4, 242996},
	{"YITY", 4, 242997},
	{"XVIO", 4, 242998},
	{"XTKI", 4, 242999},
	{"WRAV", 4, 243000},
	{"WLSD", 4, 243001},
	{"WITJ", 4, 243002},
	{"VYNS", 4, 243003},
	{"VYAF", 4, 243004},
	{"VPHA", 4, 243005},
	{"VOYL", 4, 243006},
	{"UTGH", 4, 243007},
	{"URDM", 4, 243008},
	{"UKBR", 4, 243009},
	{"UENR", 4, 243010},
	{"UBOD", 4, 243011},
	{"TCYE", 4, 243012},
	{"SCSB", 4, 243013},
	{"RURL", 4, 243014},
	{"RJIS", 4, 243015},
	{"RDRF", 4, 243016},
	{"QTEL", 4, 243017},
	{"QIDE", 4, 243018},
	{"QBTH", 4, 243019},
	{"PYGI", 4, 243020},
	{"PPEY", 4, 243021},
	{"PPEH", 4, 243022},
	{"PJEA", 4, 243023},
	{"PIGC", 4, 243024},
	{"OTDW", 4, 243025},
	{"OOPJ", 4, 243026},
	{"OGEW", 4, 243027},
	{"NWYL", 4, 243028},
	{"NTDC", 4, 243029},
	{"NIDM", 4, 243030},
	{"NFUG", 4, 243031},
	{"NFMT", 4, 243032},
	{"MYEI", 4, 243033},
	{"MURW", 4, 243034},
	{"LZAP", 4, 243035},
	{"LEPG", 4, 243036},
	{"KOBV", 4, 243037},
	{"KDEG", 4, 243038},
	{"HMMT", 4, 243039},
	{"GSRS", 4, 243040},
	{"GRDA", 4, 243041},
	{"GMMO", 4, 243042},
	{"GBTP", 4, 243043},
	{"FUZH", 4, 243044},
	{"FMHZ", 4, 243045},
	{"EXGU", 4, 243046},
	{"EWDB", 4, 243047},
	{"ESPV", 4, 243048},
	{"ESBD", 4, 243049},
	{"ERRG", 4, 243050},
	{"EOLB", 4, 243051},
	{"EGMW", 4, 243052},
	{"EDYY", 4, 243053},
	{"EDRV", 4, 243054},
	{"ECHQ", 4, 243055},
	{"EARX", 4, 243056},
	{"DVCA", 4, 243057},
	{"DNMA", 4, 243058},
	{"DLUA", 4, 243059},
	{"DLSA", 4, 243060},
	{"CFLC", 4, 243061},
	{"CCEO", 4, 243062},
	{"CBDA", 4, 243063},
	{"BIRY", 4, 243064},
	{"AVUA", 4, 243065},
	{"AVPO", 4, 243066},
	{"AUKP", 4, 243067},
	{"AJRE", 4, 243068},
	{"OKIFAX", 6, 243069},
	{"PENGUINRADIO", 12, 243070},
	{"IRLP", 4, 243071},
	{"BAREND", 6, 243072},
	{"SAFEENVPATH", 11, 243073},
	{"LAUBE", 5, 243074},
	{"VITREX", 6, 243075},
	{"KINGSNAKE", 9, 243076},
	{"HUFFORD", 7, 243077},
	{"FUNNEST", 7, 243078},
	{"ODLYZKO", 7, 243079},
	{"MOGO", 4, 243080},
	{"LUPTATUM", 8, 243081},
	{"LIBXPM", 6, 243082},
	{"ACCD", 4, 243083},
	{"TEMPORIS", 8, 243084},
	{"MPROTECT", 8, 243085},
	{"CADDELL", 7, 243086},
	{"PHENYLENEDIAMINE", 16, 243087},
	{"BLOVIATOR", 9, 243088},
	{"WEITHIO", 7, 243089},
	{"PROH", 4, 243090},
	{"DERINGER", 8, 243091},
	{"WADLEIGH", 8, 243092},
	{"STAJICH", 7, 243093},
	{"SPISS", 5, 243094},
	{"GREYHEAD", 8, 243095},
	{"GEOTAIL", 7, 243096},
	{"AVALABLE", 8, 243097},
	{"AUTODISCOVERY", 13, 243098},
	{"ALGUN", 5, 243099},
	{"GYOR", 4, 243100},
	{"CARICATURED", 11, 243101},
	{"SMARTSTART", 10, 243102},
	{"FUTURELOOKS", 11, 243103},
	{"EUBIE", 5, 243104},
	{"THURINGOWA", 10, 243105},
	{"SIRRUS", 6, 243106},
	{"VITRY", 5, 243107},
	{"UNCON", 5, 243108},
	{"GUIDANCES", 9, 243109},
	{"AMERA", 5, 243110},
	{"MUCKRAKING", 10, 243111},
	{"MONARDA", 7, 243112},
	{"NEWFIE", 6, 243113},
	{"GENITALIUM", 10, 243114},
	{"ZWEB", 4, 243115},
	{"WIMS", 4, 243116},
	{"INTELIGENCE", 11, 243117},
	{"STARTSAT", 8, 243118},
	{"ORGLIST", 7, 243119},
	{"ORCIA", 5, 243120},
	{"HYPOTHETICALS", 13, 243121},
	{"HOTELD", 6, 243122},
	{"UNFREEZE", 8, 243123},
	{"POLYSTONE", 9, 243124},
	{"CARDSERVICE", 11, 243125},
	{"SHEEPFOLD", 9, 243126},
	{"MORATH", 6, 243127},
	{"CEDIS", 5, 243128},
	{"KRIENS", 6, 243129},
	{"KNOWNS", 6, 243130},
	{"CAUTERY", 7, 243131},
	{"SWALEDALE", 9, 243132},
	{"CHADBOURN", 9, 243133},
	{"PUNTERLINK", 10, 243134},
	{"SHELKO", 6, 243135},
	{"ONLIJE", 6, 243136},
	{"SPICINESS", 9, 243137},
	{"SOFTAWRE", 8, 243138},
	{"MARVELLING", 10, 243139},
	{"RABINER", 7, 243140},
	{"PLENTIFULLY", 11, 243141},
	{"APDO", 4, 243142},
	{"LINESPACING", 11, 243143},
	{"BONNIES", 7, 243144},
	{"PYSSY", 5, 243145},
	{"ARCHAEOASTRONOMY", 16, 243146},
	{"WINSON", 6, 243147},
	{"PURDON", 6, 243148},
	{"PATIN", 5, 243149},
	{"PARTMINER", 9, 243150},
	{"LIBOPENEXR", 10, 243151},
	{"MONETIZED", 9, 243152},
	{"HALETHORPE", 10, 243153},
	{"WAKEFUL", 7, 243154},
	{"PRETEXTUAL", 10, 243155},
	{"MINIGUN", 7, 243156},
	{"BUGMASTER", 9, 243157},
	{"BATZ", 4, 243158},
	{"DONATH", 6, 243159},
	{"UNDULATUS", 9, 243160},
	{"STATIEF", 7, 243161},
	{"ROUNDOFF", 8, 243162},
	{"KLESKO", 6, 243163},
	{"INTROPICS", 9, 243164},
	{"AANWEZIG", 8, 243165},
	{"LEICK", 5, 243166},
	{"ASSTRAFIC", 9, 243167},
	{"BRADFITZ", 8, 243168},
	{"GETINFO", 7, 243169},
	{"FLUENDO", 7, 243170},
	{"LIBEEL", 6, 243171},
	{"BENGEL", 6, 243172},
	{"CRIMINALISTICS", 14, 243173},
	{"PROPONE", 7, 243174},
	{"KASTLE", 6, 243175},
	{"ASIAMAYA", 8, 243176},
	{"SITEMAPLIST", 11, 243177},
	{"POLYCENTRIC", 11, 243178},
	{"OTAHUHU", 7, 243179},
	{"MAYONAISE", 9, 243180},
	{"DOSIS", 5, 243181},
	{"CENTRISM", 8, 243182},
	{"BIZSPACE", 8, 243183},
	{"SYSTEMATIZE", 11, 243184},
	{"HYPONYMS", 8, 243185},
	{"HINCAPIE", 8, 243186},
	{"REFERENCEMENT", 13, 243187},
	{"BREITKREUZ", 10, 243188},
	{"SPROT", 5, 243189},
	{"BUNGLES", 7, 243190},
	{"POSTFORUM", 9, 243191},
	{"BOBY", 4, 243192},
	{"TRANSMSN", 8, 243193},
	{"TELOK", 5, 243194},
	{"SUNBURSTS", 9, 243195},
	{"NONPRINT", 8, 243196},
	{"MARKOWSKI", 9, 243197},
	{"MACKSVILLE", 10, 243198},
	{"FINSEQUENCE", 11, 243199},
	{"BASHFORD", 8, 243200},
	{"HARRIE", 6, 243201},
	{"MEQUITE", 7, 243202},
	{"LDOTS", 5, 243203},
	{"IMAGINOVA", 9, 243204},
	{"HACKTIVISM", 10, 243205},
	{"RFIC", 4, 243206},
	{"NUMENIUS", 8, 243207},
	{"MCCRONE", 7, 243208},
	{"LIPPARD", 7, 243209},
	{"AWFULS", 6, 243210},
	{"DISPAR", 6, 243211},
	{"CDRWIN", 6, 243212},
	{"NACM", 4, 243213},
	{"EACL", 4, 243214},
	{"DANTAX", 6, 243215},
	{"CYCLODEXTRINS", 13, 243216},
	{"TOREROS", 7, 243217},
	{"LINKLATERS", 10, 243218},
	{"CONTER", 6, 243219},
	{"BIOENG", 6, 243220},
	{"VIDEOFREE", 9, 243221},
	{"PHYSIOGRAPHY", 12, 243222},
	{"MSNWEATHER", 10, 243223},
	{"LINEART", 7, 243224},
	{"KOTSAY", 6, 243225},
	{"GEREN", 5, 243226},
	{"SIGNALIZATION", 13, 243227},
	{"SHEARWATERS", 11, 243228},
	{"DICEN", 5, 243229},
	{"MULTICASTS", 10, 243230},
	{"CAIDA", 5, 243231},
	{"WORKFIRST", 9, 243232},
	{"MYSTICALLY", 10, 243233},
	{"MANIPURI", 8, 243234},
	{"MARCELLINO", 10, 243235},
	{"KEEWORD", 7, 243236},
	{"TIKETS", 6, 243237},
	{"SPINDALE", 8, 243238},
	{"LIVESEARCH", 10, 243239},
	{"ANTRAL", 6, 243240},
	{"NEMCO", 5, 243241},
	{"MASEFIELD", 9, 243242},
	{"FTPSEARCH", 9, 243243},
	{"DRIVERHEAVEN", 12, 243244},
	{"BEMELMANS", 9, 243245},
	{"RIDGLEY", 7, 243246},
	{"MAPHIA", 6, 243247},
	{"HOMELIKE", 8, 243248},
	{"HOLIDA", 6, 243249},
	{"GLOBALMAP", 9, 243250},
	{"DEOXYRIBOSE", 11, 243251},
	{"RAININ", 6, 243252},
	{"WITHIIN", 7, 243253},
	{"EXTERNALIZATION", 15, 243254},
	{"CQM", 3, 243255},
	{"FLOURIDE", 8, 243256},
	{"CLIMO", 5, 243257},
	{"FUJITRONIC", 10, 243258},
	{"VIDEOGUARD", 10, 243259},
	{"PRISET", 6, 243260},
	{"REELIN", 6, 243261},
	{"ELIAHU", 6, 243262},
	{"DRACAENA", 8, 243263},
	{"DIDDER", 6, 243264},
	{"SUNDARESAN", 10, 243265},
	{"SPORTSZONE", 10, 243266},
	{"LOUDERMILK", 10, 243267},
	{"LAWYERAAU", 9, 243268},
	{"COMPOKER", 8, 243269},
	{"SKREEN", 6, 243270},
	{"ENCUESTAS", 9, 243271},
	{"CREAKS", 6, 243272},
	{"ARNDALE", 7, 243273},
	{"ARDECHE", 7, 243274},
	{"HYRWYDDO", 8, 243275},
	{"HUDDINGE", 8, 243276},
	{"COOROY", 6, 243277},
	{"BESTFRIEND", 10, 243278},
	{"WWYC", 4, 243279},
	{"CSBG", 4, 243280},
	{"ROID", 4, 243281},
	{"PRESERVATIONIST", 15, 243282},
	{"OFELIA", 6, 243283},
	{"ISOLEZWE", 8, 243284},
	{"FOTOPIC", 7, 243285},
	{"CSSD", 4, 243286},
	{"LOCKLEY", 7, 243287},
	{"UNCLOG", 6, 243288},
	{"SWOONED", 7, 243289},
	{"SOFFER", 6, 243290},
	{"FENNELLY", 8, 243291},
	{"COLOFON", 7, 243292},
	{"BEADERS", 7, 243293},
	{"HERBASWAY", 9, 243294},
	{"UNSOCIABLE", 10, 243295},
	{"ROTTIES", 7, 243296},
	{"QUREI", 5, 243297},
	{"KHOON", 5, 243298},
	{"DEMETRIO", 8, 243299},
	{"EPIGASTRIC", 10, 243300},
	{"KUDRIN", 6, 243301},
	{"ARFF", 4, 243302},
	{"OPHIOLITE", 9, 243303},
	{"ELECTROPLATE", 12, 243304},
	{"NEUTROPENIC", 11, 243305},
	{"SIMULANTS", 9, 243306},
	{"OZEMAIL", 7, 243307},
	{"ZHAB", 4, 243308},
	{"ZFIL", 4, 243309},
	{"YXIS", 4, 243310},
	{"YTUG", 4, 243311},
	{"XIFE", 4, 243312},
	{"XICG", 4, 243313},
	{"WVUL", 4, 243314},
	{"WIUN", 4, 243315},
	{"WDDI", 4, 243316},
	{"WAAP", 4, 243317},
	{"VDAU", 4, 243318},
	{"UUMF", 4, 243319},
	{"UROQ", 4, 243320},
	{"UNAJ", 4, 243321},
	{"UIDY", 4, 243322},
	{"TSMB", 4, 243323},
	{"TACF", 4, 243324},
	{"SXMA", 4, 243325},
	{"SUCS", 4, 243326},
	{"SGMC", 4, 243327},
	{"RRIJ", 4, 243328},
	{"RFHE", 4, 243329},
	{"RBMU", 4, 243330},
	{"QSOW", 4, 243331},
	{"PYBR", 4, 243332},
	{"PIOM", 4, 243333},
	{"PHSG", 4, 243334},
	{"PHCR", 4, 243335},
	{"OMUF", 4, 243336},
	{"OKUF", 4, 243337},
	{"NAWW", 4, 243338},
	{"MPFU", 4, 243339},
	{"MBSG", 4, 243340},
	{"MAXJ", 4, 243341},
	{"LEPD", 4, 243342},
	{"KSSQ", 4, 243343},
	{"KOTW", 4, 243344},
	{"JHUN", 4, 243345},
	{"IVIK", 4, 243346},
	{"IOLP", 4, 243347},
	{"IIFL", 4, 243348},
	{"GSEB", 4, 243349},
	{"GGFR", 4, 243350},
	{"GAUX", 4, 243351},
	{"FEUT", 4, 243352},
	{"FBPA", 4, 243353},
	{"FAAB", 4, 243354},
	{"EKMH", 4, 243355},
	{"EGWR", 4, 243356},
	{"EBRN", 4, 243357},
	{"DUCU", 4, 243358},
	{"DPBU", 4, 243359},
	{"COYD", 4, 243360},
	{"CJAR", 4, 243361},
	{"CCCR", 4, 243362},
	{"BITQ", 4, 243363},
	{"BCGA", 4, 243364},
	{"ASRF", 4, 243365},
	{"ASPG", 4, 243366},
	{"APUI", 4, 243367},
	{"APTY", 4, 243368},
	{"AMRM", 4, 243369},
	{"AMDP", 4, 243370},
	{"KIESLER", 7, 243371},
	{"BROMAGE", 7, 243372},
	{"COOTAMUNDRA", 11, 243373},
	{"RESTAURANTSULIKE", 16, 243374},
	{"TALTON", 6, 243375},
	{"PUISQUE", 7, 243376},
	{"NISCC", 5, 243377},
	{"BALTAZAR", 8, 243378},
	{"TUTOS", 5, 243379},
	{"MEPG", 4, 243380},
	{"BALINGUP", 8, 243381},
	{"SERFAS", 6, 243382},
	{"DHTMLMENU", 9, 243383},
	{"WAKEY", 5, 243384},
	{"OPENLIST", 8, 243385},
	{"KOLINSKY", 8, 243386},
	{"COZINESS", 8, 243387},
	{"ASCITIC", 7, 243388},
	{"AFFERO", 6, 243389},
	{"WOODCHUCKS", 10, 243390},
	{"VERTUES", 7, 243391},
	{"SIBMAS", 6, 243392},
	{"PARASTATALS", 11, 243393},
	{"VARDON", 6, 243394},
	{"UTSC", 4, 243395},
	{"INDISCERNIBLE", 13, 243396},
	{"HISTORIAL", 9, 243397},
	{"HIDAKA", 6, 243398},
	{"YSTADEGAU", 9, 243399},
	{"HALBACH", 7, 243400},
	{"TRANSLATER", 10, 243401},
	{"APPSERV", 7, 243402},
	{"ALLGEMEINEN", 11, 243403},
	{"SIGNEES", 7, 243404},
	{"PUGIN", 5, 243405},
	{"PARTNERNET", 10, 243406},
	{"VIEWLOADER", 10, 243407},
	{"FATTA", 5, 243408},
	{"BIKEPICS", 8, 243409},
	{"SYARIAH", 7, 243410},
	{"SESQUI", 6, 243411},
	{"NYBORG", 6, 243412},
	{"APPRECIATIVELY", 14, 243413},
	{"ECORV", 5, 243414},
	{"CHAEP", 5, 243415},
	{"BENEVA", 6, 243416},
	{"TALUKA", 6, 243417},
	{"WSSU", 4, 243418},
	{"CAMLAF", 6, 243419},
	{"CALCULO", 7, 243420},
	{"BARCIA", 6, 243421},
	{"UULIB", 5, 243422},
	{"STEATOSIS", 9, 243423},
	{"IMADO", 5, 243424},
	{"HOYMAIL", 7, 243425},
	{"HELMAND", 7, 243426},
	{"DREAR", 5, 243427},
	{"DENTLY", 6, 243428},
	{"BURWASH", 7, 243429},
	{"YAKUBU", 6, 243430},
	{"LICA", 4, 243431},
	{"BOOGIEPOP", 9, 243432},
	{"SPYCOP", 6, 243433},
	{"HAYGARTH", 8, 243434},
	{"BRIDLEWAYS", 10, 243435},
	{"REFERANCE", 9, 243436},
	{"JOME", 4, 243437},
	{"BURSTABLE", 9, 243438},
	{"BAXA", 4, 243439},
	{"PDAPHONES", 9, 243440},
	{"BROADSHEETS", 11, 243441},
	{"BAYSTATE", 8, 243442},
	{"TAKEAWAYSULIKE", 14, 243443},
	{"ERREURS", 7, 243444},
	{"CASSADAGA", 9, 243445},
	{"BRANGELINA", 10, 243446},
	{"ZTTORNEY", 8, 243447},
	{"YLU", 3, 243448},
	{"STAMEY", 6, 243449},
	{"BUFFOONERY", 10, 243450},
	{"TORBERT", 7, 243451},
	{"CHAUX", 5, 243452},
	{"DZWONEK", 7, 243453},
	{"SWAPO", 5, 243454},
	{"RESIDENTIALS", 12, 243455},
	{"FUNGICIDAL", 10, 243456},
	{"DEMKO", 5, 243457},
	{"UPFIELD", 7, 243458},
	{"GUJURAT", 7, 243459},
	{"CONCORDVILLE", 12, 243460},
	{"RELAUNCHES", 10, 243461},
	{"PRELATION", 9, 243462},
	{"PERMALINKFRIDAY", 15, 243463},
	{"STUDENA", 7, 243464},
	{"NOMATCH", 7, 243465},
	{"DNEPR", 5, 243466},
	{"VXL", 3, 243467},
	{"LAGGY", 5, 243468},
	{"MANSER", 6, 243469},
	{"CRAFTWORKS", 10, 243470},
	{"NACDL", 5, 243471},
	{"HEMMINGER", 9, 243472},
	{"EDEC", 4, 243473},
	{"BOOKROLL", 8, 243474},
	{"ANTIQ", 5, 243475},
	{"ARCADIS", 7, 243476},
	{"CECO", 4, 243477},
	{"SALVOWEB", 8, 243478},
	{"ROAF", 4, 243479},
	{"PINIELLA", 8, 243480},
	{"UNDERACHIEVERS", 14, 243481},
	{"THELIN", 6, 243482},
	{"BCRON", 5, 243483},
	{"SWEATSUIT", 9, 243484},
	{"REPLAYER", 8, 243485},
	{"KISHAN", 6, 243486},
	{"NOVAR", 5, 243487},
	{"HIVOS", 5, 243488},
	{"GEDDON", 6, 243489},
	{"BOHINJ", 6, 243490},
	{"AURIEMMA", 8, 243491},
	{"SOBASE", 6, 243492},
	{"HEGGIE", 6, 243493},
	{"RHOMBA", 6, 243494},
	{"AIRBOMB", 7, 243495},
	{"ABOUTME", 7, 243496},
	{"SHARKBOY", 8, 243497},
	{"HUSTLIN", 7, 243498},
	{"TUATHA", 6, 243499},
	{"FOXHALL", 7, 243500},
	{"COULOMBE", 8, 243501},
	{"CATHAR", 6, 243502},
	{"AFRICANIZED", 11, 243503},
	{"GRABOW", 6, 243504},
	{"SQAURE", 6, 243505},
	{"SOLCO", 5, 243506},
	{"PMSF", 4, 243507},
	{"MAPOPOLIS", 9, 243508},
	{"FANTASEEDS", 10, 243509},
	{"DEBTCONSOLIDATION", 17, 243510},
	{"UCHOD", 5, 243511},
	{"SWAPING", 7, 243512},
	{"REFOULEMENT", 11, 243513},
	{"COURGETTES", 10, 243514},
	{"BOTELER", 7, 243515},
	{"WALRATH", 7, 243516},
	{"CLAASSEN", 8, 243517},
	{"CFPS", 4, 243518},
	{"EARTHMOVERS", 11, 243519},
	{"CLIMACTERIC", 11, 243520},
	{"CDDP", 4, 243521},
	{"WTTORNEY", 8, 243522},
	{"EROTC", 5, 243523},
	{"PADDEN", 6, 243524},
	{"MCGARY", 6, 243525},
	{"SLUIS", 5, 243526},
	{"NPLANE", 6, 243527},
	{"CARMON", 6, 243528},
	{"BILOELA", 7, 243529},
	{"SUHAIL", 6, 243530},
	{"DNALINUX", 8, 243531},
	{"ANTHESIS", 8, 243532},
	{"ACTFL", 5, 243533},
	{"KORF", 4, 243534},
	{"HOLLENBERG", 10, 243535},
	{"TAXIED", 6, 243536},
	{"RASHNESS", 8, 243537},
	{"EXHALES", 7, 243538},
	{"BARMEY", 6, 243539},
	{"PODOLSKY", 8, 243540},
	{"GECCO", 5, 243541},
	{"FRBR", 4, 243542},
	{"DESCONOCIDO", 11, 243543},
	{"BIRNIE", 6, 243544},
	{"FAKERS", 6, 243545},
	{"TSUKINEKO", 9, 243546},
	{"TANTALIZINGLY", 13, 243547},
	{"SOBELL", 6, 243548},
	{"MDME", 4, 243549},
	{"BROADFIELD", 10, 243550},
	{"TOMOYUKI", 8, 243551},
	{"JORRIT", 6, 243552},
	{"DISTINTAS", 9, 243553},
	{"YEHEY", 5, 243554},
	{"ILLOGAN", 7, 243555},
	{"HAYLOFT", 7, 243556},
	{"WOGS", 4, 243557},
	{"TWRISTIAETH", 11, 243558},
	{"TORGEIR", 7, 243559},
	{"FIRSTLOOK", 9, 243560},
	{"DIBELS", 6, 243561},
	{"COOLTECHZONE", 12, 243562},
	{"BOKEH", 5, 243563},
	{"AUXILARY", 8, 243564},
	{"WBAD", 4, 243565},
	{"VEGI", 4, 243566},
	{"BIZINFORMER", 11, 243567},
	{"RANGELY", 7, 243568},
	{"PENSAMIENTO", 11, 243569},
	{"INQUIRA", 7, 243570},
	{"HOTELULIKE", 10, 243571},
	{"CARTBUY", 7, 243572},
	{"ULLETIN", 7, 243573},
	{"LABRAT", 6, 243574},
	{"HAEMOST", 7, 243575},
	{"DWLR", 4, 243576},
	{"POINTCAST", 9, 243577},
	{"PIACERI", 7, 243578},
	{"LUXURIATE", 9, 243579},
	{"IFRSS", 5, 243580},
	{"GULAGER", 7, 243581},
	{"CLUBSULIKE", 10, 243582},
	{"CGCC", 4, 243583},
	{"RYTHYM", 6, 243584},
	{"PEPPE", 5, 243585},
	{"WPCP", 4, 243586},
	{"MESABA", 6, 243587},
	{"EWBANK", 6, 243588},
	{"EGYDOC", 6, 243589},
	{"DUPING", 6, 243590},
	{"ARAGONESE", 9, 243591},
	{"SUTHEP", 6, 243592},
	{"BALDASSARE", 10, 243593},
	{"HUNGARICA", 9, 243594},
	{"TARQUINIUS", 10, 243595},
	{"FILTRES", 7, 243596},
	{"MONGRELS", 8, 243597},
	{"IMPELS", 6, 243598},
	{"TROMBLEY", 8, 243599},
	{"BEAMSVILLE", 10, 243600},
	{"ARRESTIN", 8, 243601},
	{"TYPHON", 6, 243602},
	{"BUSINESSTIME", 12, 243603},
	{"ZYSC", 4, 243604},
	{"ZUHI", 4, 243605},
	{"ZOFL", 4, 243606},
	{"ZEGL", 4, 243607},
	{"ZBOO", 4, 243608},
	{"YWIM", 4, 243609},
	{"YTUD", 4, 243610},
	{"YSZO", 4, 243611},
	{"YRSB", 4, 243612},
	{"YKTH", 4, 243613},
	{"YINX", 4, 243614},
	{"YDRP", 4, 243615},
	{"YDCH", 4, 243616},
	{"WWGE", 4, 243617},
	{"VYSF", 4, 243618},
	{"VGAV", 4, 243619},
	{"VBER", 4, 243620},
	{"UILM", 4, 243621},
	{"TWAB", 4, 243622},
	{"SXOR", 4, 243623},
	{"SPHU", 4, 243624},
	{"SMKN", 4, 243625},
	{"RYEE", 4, 243626},
	{"RSCB", 4, 243627},
	{"PJOR", 4, 243628},
	{"PIBA", 4, 243629},
	{"OKEQ", 4, 243630},
	{"OFXT", 4, 243631},
	{"OFNZ", 4, 243632},
	{"NXVI", 4, 243633},
	{"NDFG", 4, 243634},
	{"MLRE", 4, 243635},
	{"LDBB", 4, 243636},
	{"KUNY", 4, 243637},
	{"KUNU", 4, 243638},
	{"JJAB", 4, 243639},
	{"JDAV", 4, 243640},
	{"INBF", 4, 243641},
	{"HLAZ", 4, 243642},
	{"GSEY", 4, 243643},
	{"GKEA", 4, 243644},
	{"GFID", 4, 243645},
	{"FDOB", 4, 243646},
	{"FBMW", 4, 243647},
	{"FAKU", 4, 243648},
	{"EMNR", 4, 243649},
	{"EILJ", 4, 243650},
	{"EDFF", 4, 243651},
	{"EBPC", 4, 243652},
	{"DTEJ", 4, 243653},
	{"DMTA", 4, 243654},
	{"CYEC", 4, 243655},
	{"CUIL", 4, 243656},
	{"COUM", 4, 243657},
	{"CMAM", 4, 243658},
	{"BMDA", 4, 243659},
	{"AWOD", 4, 243660},
	{"AQPR", 4, 243661},
	{"AMVP", 4, 243662},
	{"AJSM", 4, 243663},
	{"AIKW", 4, 243664},
	{"AIFL", 4, 243665},
	{"AFIJ", 4, 243666},
	{"AFCR", 4, 243667},
	{"ACGE", 4, 243668},
	{"YUKATA", 6, 243669},
	{"LORIMAR", 7, 243670},
	{"FCCP", 4, 243671},
	{"CONNNECTION", 11, 243672},
	{"MOFCOM", 6, 243673},
	{"VERH", 4, 243674},
	{"PECORARO", 8, 243675},
	{"DISSEMBLING", 11, 243676},
	{"ANTIANXIETY", 11, 243677},
	{"TOOGOOD", 7, 243678},
	{"INCONJUNCTION", 13, 243679},
	{"ZALAMAN", 7, 243680},
	{"KOMPUTERY", 9, 243681},
	{"GLIS", 4, 243682},
	{"COMPREHENSIONS", 14, 243683},
	{"HASIM", 5, 243684},
	{"MOTILAL", 7, 243685},
	{"HECKLED", 7, 243686},
	{"BRAGUITAS", 9, 243687},
	{"VICODINE", 8, 243688},
	{"WEDMORE", 7, 243689},
	{"SWEETENS", 8, 243690},
	{"BASHMENT", 8, 243691},
	{"PERALES", 7, 243692},
	{"CHOUX", 5, 243693},
	{"BRADLEYS", 8, 243694},
	{"PSEUDOTSUGA", 11, 243695},
	{"HEMIS", 5, 243696},
	{"CONSISTENCE", 11, 243697},
	{"ANGELEYES", 9, 243698},
	{"FLEDGE", 6, 243699},
	{"BASECOAT", 8, 243700},
	{"MORTGAEG", 8, 243701},
	{"ERIM", 4, 243702},
	{"DAFF", 4, 243703},
	{"CETP", 4, 243704},
	{"ROHINTON", 8, 243705},
	{"CANOA", 5, 243706},
	{"WRITERMOM", 9, 243707},
	{"HAZCOM", 6, 243708},
	{"GOVS", 4, 243709},
	{"RANDEE", 6, 243710},
	{"FYRO", 4, 243711},
	{"CHLORAMINES", 11, 243712},
	{"CARSELDINE", 10, 243713},
	{"PITTURA", 7, 243714},
	{"CHALE", 5, 243715},
	{"TOUBY", 5, 243716},
	{"BLAQTHOUGHT", 11, 243717},
	{"TTUHSC", 6, 243718},
	{"POPSHOP", 7, 243719},
	{"OTAVIO", 6, 243720},
	{"BLUESTUDIO", 10, 243721},
	{"AJOR", 4, 243722},
	{"STERIS", 6, 243723},
	{"PARV", 4, 243724},
	{"INTIMATING", 10, 243725},
	{"INTERCOOLED", 11, 243726},
	{"HOLLIMAN", 8, 243727},
	{"GAER", 4, 243728},
	{"DKL", 3, 243729},
	{"MUNUVIANS", 9, 243730},
	{"GARAMONT", 8, 243731},
	{"SHAREBOOK", 9, 243732},
	{"PSYCHOLOOG", 10, 243733},
	{"METALWORKERS", 12, 243734},
	{"HOMEPLACE", 9, 243735},
	{"BAUERFEIND", 10, 243736},
	{"SEIKOSHA", 8, 243737},
	{"KOPPELING", 9, 243738},
	{"BRIFFA", 6, 243739},
	{"AMWU", 4, 243740},
	{"MDIS", 4, 243741},
	{"KELLING", 7, 243742},
	{"KASETSART", 9, 243743},
	{"TUTIONAL", 8, 243744},
	{"SEMMELWEIS", 10, 243745},
	{"BLUD", 4, 243746},
	{"VIOLACEA", 8, 243747},
	{"CAECILIA", 8, 243748},
	{"AIPGE", 5, 243749},
	{"VELOPING", 8, 243750},
	{"DEFROSTED", 9, 243751},
	{"OLUSTEE", 7, 243752},
	{"NEUROFIBRILLARY", 15, 243753},
	{"JPJ", 3, 243754},
	{"ARTANE", 6, 243755},
	{"FAIRWOOD", 8, 243756},
	{"AUTOINSURANCE", 13, 243757},
	{"ZUMBROTA", 8, 243758},
	{"TIDEPOOL", 8, 243759},
	{"SADM", 4, 243760},
	{"FLAYER", 6, 243761},
	{"CRAPPIES", 8, 243762},
	{"VIDEOBUSH", 9, 243763},
	{"CURSER", 6, 243764},
	{"CICLISMO", 8, 243765},
	{"CDMS", 4, 243766},
	{"BDGP", 4, 243767},
	{"TROUVILLE", 9, 243768},
	{"MASONORI", 8, 243769},
	{"GIBBSTOWN", 9, 243770},
	{"SAUBLE", 6, 243771},
	{"EASTONS", 7, 243772},
	{"RUPTCY", 6, 243773},
	{"COVERSLIP", 9, 243774},
	{"HOMERESULTS", 11, 243775},
	{"MENJADI", 7, 243776},
	{"PILLA", 5, 243777},
	{"MYRICA", 6, 243778},
	{"DIAMO", 5, 243779},
	{"REVOLUTIO", 9, 243780},
	{"POMPA", 5, 243781},
	{"TOMASZEWSKI", 11, 243782},
	{"EGGING", 6, 243783},
	{"LITICAL", 7, 243784},
	{"BEDANDBREAKFASTULIKE", 20, 243785},
	{"NIZATIONS", 9, 243786},
	{"EVERPURE", 8, 243787},
	{"TUVALUAN", 8, 243788},
	{"KELOIDS", 7, 243789},
	{"EDSTROM", 7, 243790},
	{"CATCHPOLE", 9, 243791},
	{"DIETH", 5, 243792},
	{"DESSY", 5, 243793},
	{"CATESBY", 7, 243794},
	{"CELISTA", 7, 243795},
	{"TOOLMIX", 7, 243796},
	{"MOJI", 4, 243797},
	{"MISSIS", 6, 243798},
	{"LESTRADE", 8, 243799},
	{"RANDOMIZERS", 11, 243800},
	{"QUICKTEST", 9, 243801},
	{"MICROSC", 7, 243802},
	{"GIVENNAME", 9, 243803},
	{"INTOPIC", 7, 243804},
	{"STUDPUPS", 8, 243805},
	{"EUROBODALLA", 11, 243806},
	{"SCPH", 4, 243807},
	{"RUSNAK", 6, 243808},
	{"MERIDETH", 8, 243809},
	{"ASIAPUNDIT", 10, 243810},
	{"ICUII", 5, 243811},
	{"HARRISTOWN", 10, 243812},
	{"COMMITLOG", 9, 243813},
	{"VERIDICAL", 9, 243814},
	{"CSEC", 4, 243815},
	{"PRODUCTRONICA", 13, 243816},
	{"FILMPRODUKTION", 14, 243817},
	{"RIGHETTI", 8, 243818},
	{"KINFOLK", 7, 243819},
	{"ETHTOOL", 7, 243820},
	{"DAHLEM", 6, 243821},
	{"CALP", 4, 243822},
	{"ZENAWI", 6, 243823},
	{"IGNITERS", 8, 243824},
	{"RELACIONADO", 11, 243825},
	{"FOOLA", 5, 243826},
	{"CAMPINGWORLD", 12, 243827},
	{"PERRINS", 7, 243828},
	{"KARAKAL", 7, 243829},
	{"NOGIFS", 6, 243830},
	{"LUXAIR", 6, 243831},
	{"TOTALISATOR", 11, 243832},
	{"PLHROFORIES", 11, 243833},
	{"GEMATRIA", 8, 243834},
	{"ROSEUS", 6, 243835},
	{"PLESETSK", 8, 243836},
	{"NENETS", 6, 243837},
	{"HIGHTLIGHTS", 11, 243838},
	{"DAULTON", 7, 243839},
	{"BALACHANDRAN", 12, 243840},
	{"SPECTERS", 8, 243841},
	{"LANESVILLE", 10, 243842},
	{"CAVALLERIA", 10, 243843},
	{"INFINITO", 8, 243844},
	{"MESENCEPHALON", 13, 243845},
	{"BITZER", 6, 243846},
	{"KANABEC", 7, 243847},
	{"CHOCTAWS", 8, 243848},
	{"MACNAIR", 7, 243849},
	{"BLAQSTAR", 8, 243850},
	{"APPELER", 7, 243851},
	{"HYPOCRACY", 9, 243852},
	{"FLUNKING", 8, 243853},
	{"SALENA", 6, 243854},
	{"MISSIONER", 9, 243855},
	{"BUTTONWOOD", 10, 243856},
	{"SPENCES", 7, 243857},
	{"EBOOKBASE", 9, 243858},
	{"ALCARAZ", 7, 243859},
	{"WWOOD", 5, 243860},
	{"TEXTEDITOR", 10, 243861},
	{"EYLER", 5, 243862},
	{"ABETZ", 5, 243863},
	{"KONTROLL", 8, 243864},
	{"STARMAIL", 8, 243865},
	{"PUELLA", 6, 243866},
	{"ZOLMITRIPTAN", 12, 243867},
	{"WLG", 3, 243868},
	{"PATROLLER", 9, 243869},
	{"PROPIDIUM", 9, 243870},
	{"METEOROIDS", 10, 243871},
	{"SOZIAL", 6, 243872},
	{"READMEFIRST", 11, 243873},
	{"KUFR", 4, 243874},
	{"ZINSSER", 7, 243875},
	{"THIEFWARE", 9, 243876},
	{"SITTON", 6, 243877},
	{"RACIALIZED", 10, 243878},
	{"MAGNETA", 7, 243879},
	{"BHOSLE", 6, 243880},
	{"AURIOL", 6, 243881},
	{"VERGINE", 7, 243882},
	{"NOGIN", 5, 243883},
	{"RIDEMONKEY", 10, 243884},
	{"MODIN", 5, 243885},
	{"WBGO", 4, 243886},
	{"PICMICRO", 8, 243887},
	{"AACOM", 5, 243888},
	{"POSSA", 5, 243889},
	{"MAINA", 5, 243890},
	{"IMPOVERISH", 10, 243891},
	{"EZRIN", 5, 243892},
	{"ZHEV", 4, 243893},
	{"ZABY", 4, 243894},
	{"YZIE", 4, 243895},
	{"YUES", 4, 243896},
	{"XOFY", 4, 243897},
	{"XIRI", 4, 243898},
	{"WLBI", 4, 243899},
	{"VIRN", 4, 243900},
	{"VAKT", 4, 243901},
	{"UYRU", 4, 243902},
	{"USYJ", 4, 243903},
	{"UAYN", 4, 243904},
	{"UAUH", 4, 243905},
	{"TBUO", 4, 243906},
	{"TAVW", 4, 243907},
	{"SVSR", 4, 243908},
	{"SMVE", 4, 243909},
	{"SKVE", 4, 243910},
	{"SJAF", 4, 243911},
	{"RYNJ", 4, 243912},
	{"RTEY", 4, 243913},
	{"RSNB", 4, 243914},
	{"PNWI", 4, 243915},
	{"PIPL", 4, 243916},
	{"PCBO", 4, 243917},
	{"OWOX", 4, 243918},
	{"ORUO", 4, 243919},
	{"OIGR", 4, 243920},
	{"OGSJ", 4, 243921},
	{"NSKB", 4, 243922},
	{"NPPO", 4, 243923},
	{"MRYE", 4, 243924},
	{"MOCY", 4, 243925},
	{"MNWO", 4, 243926},
	{"MIGF", 4, 243927},
	{"MHZO", 4, 243928},
	{"MDUL", 4, 243929},
	{"MBIP", 4, 243930},
	{"LNYT", 4, 243931},
	{"KIPM", 4, 243932},
	{"KEOM", 4, 243933},
	{"ITVW", 4, 243934},
	{"ITCY", 4, 243935},
	{"IRIJ", 4, 243936},
	{"IMSQ", 4, 243937},
	{"GWAH", 4, 243938},
	{"GTVI", 4, 243939},
	{"FDAO", 4, 243940},
	{"EUBL", 4, 243941},
	{"ERHL", 4, 243942},
	{"EEVM", 4, 243943},
	{"DSMT", 4, 243944},
	{"DRJI", 4, 243945},
	{"CYAH", 4, 243946},
	{"CETM", 4, 243947},
	{"BYBN", 4, 243948},
	{"ATJF", 4, 243949},
	{"ANBM", 4, 243950},
	{"AMJR", 4, 243951},
	{"AMBF", 4, 243952},
	{"AKRS", 4, 243953},
	{"MEHMED", 6, 243954},
	{"MEGILLAH", 8, 243955},
	{"CIVICUS", 7, 243956},
	{"ARIGA", 5, 243957},
	{"ZAREMBA", 7, 243958},
	{"PAPATOETOE", 10, 243959},
	{"VAPOCHILL", 9, 243960},
	{"GRW", 3, 243961},
	{"ADYAR", 5, 243962},
	{"PICKETERS", 9, 243963},
	{"MEIERS", 6, 243964},
	{"KATASTASH", 9, 243965},
	{"INTRATTENIMENTO", 15, 243966},
	{"HEALTHPLAN", 10, 243967},
	{"INFOSTRADA", 10, 243968},
	{"AUDIOFN", 7, 243969},
	{"JILLS", 5, 243970},
	{"DEFEASANCE", 10, 243971},
	{"TARBOX", 6, 243972},
	{"MALLERY", 7, 243973},
	{"GALLINAGO", 9, 243974},
	{"GALANTER", 8, 243975},
	{"ANDROPAUSE", 10, 243976},
	{"LVEF", 4, 243977},
	{"KASIH", 5, 243978},
	{"JFCL", 4, 243979},
	{"STELLWAGEN", 10, 243980},
	{"LETTERER", 8, 243981},
	{"TOCOTRIENOLS", 12, 243982},
	{"KOONIN", 6, 243983},
	{"TBONE", 5, 243984},
	{"SONOITA", 7, 243985},
	{"GLADIOLI", 8, 243986},
	{"ERITREANS", 9, 243987},
	{"PLOCK", 5, 243988},
	{"ILLIANA", 7, 243989},
	{"SUPPLYCHAINER", 13, 243990},
	{"GARRIOTT", 8, 243991},
	{"SCHUPP", 6, 243992},
	{"CFRL", 4, 243993},
	{"SARRAZIN", 8, 243994},
	{"ROWLINGSON", 10, 243995},
	{"PROWLERS", 8, 243996},
	{"KGVI", 4, 243997},
	{"DAIKATANA", 9, 243998},
	{"GIRVIN", 6, 243999},
	{"GIGABITETHERNET", 15, 244000},
	{"DRYPOINT", 8, 244001},
	{"SULPHATES", 9, 244002},
	{"AEMILIUS", 8, 244003},
	{"OWNZ", 4, 244004},
	{"KEFKA", 5, 244005},
	{"TRANSOCEAN", 10, 244006},
	{"KONTAK", 6, 244007},
	{"TEKELEC", 7, 244008},
	{"ENDOCR", 6, 244009},
	{"ARCCATALOG", 10, 244010},
	{"JANAURY", 7, 244011},
	{"ENESCU", 6, 244012},
	{"BRAWNER", 7, 244013},
	{"FUNREPORTS", 10, 244014},
	{"CRUSTING", 8, 244015},
	{"NOBODYTHERE", 11, 244016},
	{"BLAIRE", 6, 244017},
	{"ATOMZ", 5, 244018},
	{"AGRIMONY", 8, 244019},
	{"SLUNK", 5, 244020},
	{"NETIDENTITY", 11, 244021},
	{"MYOSTATIN", 9, 244022},
	{"DOUBS", 5, 244023},
	{"PORTSCAN", 8, 244024},
	{"DIGITISE", 8, 244025},
	{"DESWEGEN", 8, 244026},
	{"SURJIT", 6, 244027},
	{"MANSUETO", 8, 244028},
	{"SENEGALENSIS", 12, 244029},
	{"CROCKFORD", 9, 244030},
	{"MARCHIO", 7, 244031},
	{"KUNDUZ", 6, 244032},
	{"BEISEL", 6, 244033},
	{"LIVERIGHT", 9, 244034},
	{"LIBFLAC", 7, 244035},
	{"STINCHCOMBE", 11, 244036},
	{"COWI", 4, 244037},
	{"NAZIONI", 7, 244038},
	{"MAYLANDS", 8, 244039},
	{"CRANIOSYNOSTOSIS", 16, 244040},
	{"LUICHINY", 8, 244041},
	{"COADJUTOR", 9, 244042},
	{"WELTANSCHAUUNG", 14, 244043},
	{"SIBLY", 5, 244044},
	{"SAQQARA", 7, 244045},
	{"NETNEARU", 8, 244046},
	{"MANCH", 5, 244047},
	{"EMBLETON", 8, 244048},
	{"CROYDE", 6, 244049},
	{"MACCHI", 6, 244050},
	{"CANACCORD", 9, 244051},
	{"BYK", 3, 244052},
	{"XDIM", 4, 244053},
	{"SITEEXPERTS", 11, 244054},
	{"ZEBULUN", 7, 244055},
	{"PFAU", 4, 244056},
	{"HELLRIDE", 8, 244057},
	{"ERGONOMIE", 9, 244058},
	{"DUFAULT", 7, 244059},
	{"SUPPY", 5, 244060},
	{"SOFTWARR", 8, 244061},
	{"FOOTFALLS", 9, 244062},
	{"WHEELMEN", 8, 244063},
	{"SWAD", 4, 244064},
	{"LURLENE", 7, 244065},
	{"ELLENBORO", 9, 244066},
	{"SARGERAS", 8, 244067},
	{"INADA", 5, 244068},
	{"ULBRICH", 7, 244069},
	{"RUSSINOVICH", 11, 244070},
	{"YELPS", 5, 244071},
	{"MICROMAN", 8, 244072},
	{"NOSHOW", 6, 244073},
	{"WWWSEARCH", 9, 244074},
	{"REDEX", 5, 244075},
	{"ORKSHOP", 7, 244076},
	{"BOSQUES", 7, 244077},
	{"ASPEKTE", 7, 244078},
	{"LEUKOCYTOSIS", 12, 244079},
	{"VIRGA", 5, 244080},
	{"SCALDS", 6, 244081},
	{"NIGHTWALKER", 11, 244082},
	{"CRONAN", 6, 244083},
	{"DARUMA", 6, 244084},
	{"TURSIOPS", 8, 244085},
	{"CVPR", 4, 244086},
	{"ISOPTIN", 7, 244087},
	{"RENNISON", 8, 244088},
	{"EXPERTEN", 8, 244089},
	{"WORKDIR", 7, 244090},
	{"FINANCIAMENTO", 13, 244091},
	{"BUILDDATA", 9, 244092},
	{"WUSTL", 5, 244093},
	{"SUPERINTENDANT", 14, 244094},
	{"SPECIALY", 8, 244095},
	{"METALSMITHING", 13, 244096},
	{"INFOWAY", 7, 244097},
	{"GAMEBOOK", 8, 244098},
	{"WAKESKATES", 10, 244099},
	{"ENUMERATIVE", 11, 244100},
	{"DKG", 3, 244101},
	{"DIGITALSPACEMAN", 15, 244102},
	{"BOLOMETER", 9, 244103},
	{"BOLLINGTON", 10, 244104},
	{"BHANU", 5, 244105},
	{"APPSECINC", 9, 244106},
	{"TEITL", 5, 244107},
	{"FLEXORS", 7, 244108},
	{"ATTESTATIONS", 12, 244109},
	{"LISBONA", 7, 244110},
	{"EMENEE", 6, 244111},
	{"LINGUISTICA", 11, 244112},
	{"NZOSS", 5, 244113},
	{"KAUTSKY", 7, 244114},
	{"BAROREFLEX", 10, 244115},
	{"MURAY", 5, 244116},
	{"INPUTSTREAMREADER", 17, 244117},
	{"ROYCROFT", 8, 244118},
	{"RDNS", 4, 244119},
	{"COUNTERWEIGHTS", 14, 244120},
	{"AUTONOME", 8, 244121},
	{"ACTUALWHEELVEL", 14, 244122},
	{"SYMBOLICS", 9, 244123},
	{"PHILIPINE", 9, 244124},
	{"PERMALINKWEDNESDAY", 18, 244125},
	{"LOMBARDS", 8, 244126},
	{"ADEY", 4, 244127},
	{"JEGO", 4, 244128},
	{"BBU", 3, 244129},
	{"APOGEYMA", 8, 244130},
	{"TAKAYA", 6, 244131},
	{"MAFIKENG", 8, 244132},
	{"HEMIN", 5, 244133},
	{"FUNKIN", 6, 244134},
	{"CAPIAS", 6, 244135},
	{"CORPORALS", 9, 244136},
	{"TOTALVOL", 8, 244137},
	{"QSIZE", 5, 244138},
	{"OVERCOOK", 8, 244139},
	{"LIZE", 4, 244140},
	{"LIPODRENE", 9, 244141},
	{"JERS", 4, 244142},
	{"BENEDICTA", 9, 244143},
	{"TELECOMMUTER", 12, 244144},
	{"LIBAVCODEC", 10, 244145},
	{"KAZIRANGA", 9, 244146},
	{"FINSTER", 7, 244147},
	{"PJPEG", 5, 244148},
	{"LEISTUNGEN", 10, 244149},
	{"LAURETTA", 8, 244150},
	{"DAVB", 4, 244151},
	{"BROWNLIE", 8, 244152},
	{"SEMPIONE", 8, 244153},
	{"PENSIERI", 8, 244154},
	{"ULATED", 6, 244155},
	{"TRANQUILO", 9, 244156},
	{"OSSUR", 5, 244157},
	{"BUGIBBA", 7, 244158},
	{"KATAN", 5, 244159},
	{"BORTOLO", 7, 244160},
	{"UNSUITABILITY", 13, 244161},
	{"TANCES", 6, 244162},
	{"CHANN", 5, 244163},
	{"NONPREGNANT", 11, 244164},
	{"DIAGNOSTICIAN", 13, 244165},
	{"BATLLE", 6, 244166},
	{"YELLEN", 6, 244167},
	{"SCUNCI", 6, 244168},
	{"REPRODUCTOR", 11, 244169},
	{"MSECS", 5, 244170},
	{"JHBUILD", 7, 244171},
	{"MOLECULAIRE", 11, 244172},
	{"LARON", 5, 244173},
	{"CELLU", 5, 244174},
	{"USPHS", 5, 244175},
	{"SOFTWSRE", 8, 244176},
	{"SMELSER", 7, 244177},
	{"LAPPEND", 7, 244178},
	{"GARBEE", 6, 244179},
	{"FOLIATED", 8, 244180},
	{"ANNUELLE", 8, 244181},
	{"BUMPASS", 7, 244182},
	{"WEBERS", 6, 244183},
	{"FCODE", 5, 244184},
	{"DANNINA", 7, 244185},
	{"ROMM", 4, 244186},
	{"SICU", 4, 244187},
	{"ECLIPSEJDO", 10, 244188},
	{"RADVD", 5, 244189},
	{"BORJAS", 6, 244190},
	{"ZZLA", 4, 244191},
	{"ZYRI", 4, 244192},
	{"ZSOF", 4, 244193},
	{"ZRAS", 4, 244194},
	{"ZKIL", 4, 244195},
	{"YSCY", 4, 244196},
	{"YPIM", 4, 244197},
	{"YLYA", 4, 244198},
	{"YLUL", 4, 244199},
	{"YIPI", 4, 244200},
	{"XYOR", 4, 244201},
	{"XIVS", 4, 244202},
	{"WOEG", 4, 244203},
	{"WDIO", 4, 244204},
	{"VYOV", 4, 244205},
	{"VUET", 4, 244206},
	{"URDF", 4, 244207},
	{"UHLS", 4, 244208},
	{"UBFL", 4, 244209},
	{"UACS", 4, 244210},
	{"TYMS", 4, 244211},
	{"TEKY", 4, 244212},
	{"SFUD", 4, 244213},
	{"SBOK", 4, 244214},
	{"RTSZ", 4, 244215},
	{"RRBR", 4, 244216},
	{"RPID", 4, 244217},
	{"RLFE", 4, 244218},
	{"RKYU", 4, 244219},
	{"PLLI", 4, 244220},
	{"PISY", 4, 244221},
	{"ORHM", 4, 244222},
	{"OCEY", 4, 244223},
	{"NUAK", 4, 244224},
	{"NTGY", 4, 244225},
	{"NDHG", 4, 244226},
	{"LSRY", 4, 244227},
	{"LICZ", 4, 244228},
	{"KOAP", 4, 244229},
	{"KAJE", 4, 244230},
	{"KAHB", 4, 244231},
	{"ITMP", 4, 244232},
	{"HZFR", 4, 244233},
	{"HYOK", 4, 244234},
	{"GLIW", 4, 244235},
	{"GIBM", 4, 244236},
	{"GDAE", 4, 244237},
	{"FLDI", 4, 244238},
	{"EDMW", 4, 244239},
	{"ECCW", 4, 244240},
	{"DUAW", 4, 244241},
	{"DTEV", 4, 244242},
	{"DGUB", 4, 244243},
	{"CUDR", 4, 244244},
	{"COBK", 4, 244245},
	{"CETF", 4, 244246},
	{"CCPO", 4, 244247},
	{"BVAC", 4, 244248},
	{"BCJU", 4, 244249},
	{"AZZN", 4, 244250},
	{"ARIX", 4, 244251},
	{"ANZR", 4, 244252},
	{"ANQB", 4, 244253},
	{"ALPG", 4, 244254},
	{"WIFLYER", 7, 244255},
	{"NONUSE", 6, 244256},
	{"HALAMAN", 7, 244257},
	{"GAPLESS", 7, 244258},
	{"ZUPREEM", 7, 244259},
	{"PERIODONTOL", 11, 244260},
	{"IFIELD", 6, 244261},
	{"AVAIALBLE", 9, 244262},
	{"JEWESS", 6, 244263},
	{"AVGAS", 5, 244264},
	{"ENDUED", 6, 244265},
	{"VORNICU", 7, 244266},
	{"CHOPHOUSE", 9, 244267},
	{"PETERSBERG", 10, 244268},
	{"NUYORICAN", 9, 244269},
	{"GUYBRUSH", 8, 244270},
	{"ETHERTON", 8, 244271},
	{"WURZ", 4, 244272},
	{"QSTAT", 5, 244273},
	{"HKBU", 4, 244274},
	{"RUBINI", 6, 244275},
	{"FEININGER", 9, 244276},
	{"WARLINGHAM", 10, 244277},
	{"POWERBLOCK", 10, 244278},
	{"NEOPOLITAN", 10, 244279},
	{"SLMM", 4, 244280},
	{"QMF", 3, 244281},
	{"ONECLICKDECOR", 13, 244282},
	{"LEMPSTER", 8, 244283},
	{"KHURSHID", 8, 244284},
	{"CYBERATLAS", 10, 244285},
	{"ACCEPTVOL", 9, 244286},
	{"RAITA", 5, 244287},
	{"FURRER", 6, 244288},
	{"REVIEWFULL", 10, 244289},
	{"NILGIRI", 7, 244290},
	{"CIRCOLO", 7, 244291},
	{"RECENTES", 8, 244292},
	{"MARATHONERS", 11, 244293},
	{"HARGEISA", 8, 244294},
	{"DENETHOR", 8, 244295},
	{"UNDERWING", 9, 244296},
	{"TEXTED", 6, 244297},
	{"REFINANCEMORTGAGE", 17, 244298},
	{"GELLNER", 7, 244299},
	{"DETUNED", 7, 244300},
	{"BOUVARD", 7, 244301},
	{"MORPHETT", 8, 244302},
	{"CHARLIER", 8, 244303},
	{"HEDON", 5, 244304},
	{"CONGRESOS", 9, 244305},
	{"BIGGERSTAFF", 11, 244306},
	{"SATISFAC", 8, 244307},
	{"RECDESCENT", 10, 244308},
	{"WORKSMART", 9, 244309},
	{"FLOWOOD", 7, 244310},
	{"CHTHONIC", 8, 244311},
	{"LYNSKEY", 7, 244312},
	{"AUTHORIZERS", 11, 244313},
	{"ESKIND", 6, 244314},
	{"BOMBAYKIDS", 10, 244315},
	{"REVENGER", 8, 244316},
	{"REMOVIDO", 8, 244317},
	{"KUSHIRO", 7, 244318},
	{"INLAW", 5, 244319},
	{"TOEING", 6, 244320},
	{"SUBMUCOSAL", 10, 244321},
	{"SLUB", 4, 244322},
	{"RECOUPING", 9, 244323},
	{"FACTORISATION", 13, 244324},
	{"BACILLARY", 9, 244325},
	{"UPW", 3, 244326},
	{"UNREGENERATE", 12, 244327},
	{"MCTOOLS", 7, 244328},
	{"DESTRUCTED", 10, 244329},
	{"GAMEAXIS", 8, 244330},
	{"WEBSIDE", 7, 244331},
	{"SORROWFULLY", 11, 244332},
	{"BINFIELD", 8, 244333},
	{"LUEN", 4, 244334},
	{"HABLO", 5, 244335},
	{"MONUMENTALLY", 12, 244336},
	{"INIQUITOUS", 10, 244337},
	{"SUBIF", 5, 244338},
	{"OLIMPUS", 7, 244339},
	{"LAMBORN", 7, 244340},
	{"TAPPERS", 7, 244341},
	{"RENSE", 5, 244342},
	{"HYLAN", 5, 244343},
	{"SAHEB", 5, 244344},
	{"EDUGEEK", 7, 244345},
	{"BLUB", 4, 244346},
	{"BELGARIAD", 9, 244347},
	{"PYMCA", 5, 244348},
	{"EHEMALIGER", 10, 244349},
	{"STANDERS", 8, 244350},
	{"LATKA", 5, 244351},
	{"ICOUNT", 6, 244352},
	{"TRAMPED", 7, 244353},
	{"MODFATHERS", 10, 244354},
	{"JUMPN", 5, 244355},
	{"ECCLESIASTIC", 12, 244356},
	{"BIBLIOMETRIC", 12, 244357},
	{"TROYS", 5, 244358},
	{"POLHEMUS", 8, 244359},
	{"CCYY", 4, 244360},
	{"HQOUTLETSTORE", 13, 244361},
	{"EDELMETALL", 10, 244362},
	{"ASHRIDGE", 8, 244363},
	{"DEGA", 4, 244364},
	{"BIASIA", 6, 244365},
	{"AGRICULTURIST", 13, 244366},
	{"SUPRAPHON", 9, 244367},
	{"STRIA", 5, 244368},
	{"APHTHOUS", 8, 244369},
	{"VISARI", 6, 244370},
	{"DIMWIT", 6, 244371},
	{"BARTLOMIEJ", 10, 244372},
	{"ANGGOTA", 7, 244373},
	{"VETERE", 6, 244374},
	{"THEILER", 7, 244375},
	{"ENOMOTO", 7, 244376},
	{"DAPTO", 5, 244377},
	{"SHAVIT", 6, 244378},
	{"ELMDALE", 7, 244379},
	{"PICONE", 6, 244380},
	{"OLBG", 4, 244381},
	{"BICYCLO", 7, 244382},
	{"TIMESTAMPING", 12, 244383},
	{"DVDO", 4, 244384},
	{"CROSSPOSTING", 12, 244385},
	{"SORBARA", 7, 244386},
	{"HILDEGARDE", 10, 244387},
	{"DIMETAPP", 8, 244388},
	{"SOFTWAER", 8, 244389},
	{"MANDOS", 6, 244390},
	{"WISLEY", 6, 244391},
	{"PREFERREDCLASS", 14, 244392},
	{"KIMSEY", 6, 244393},
	{"FCRON", 5, 244394},
	{"ETHYLMALEIMIDE", 14, 244395},
	{"EARTHSITE", 9, 244396},
	{"WAYLAID", 7, 244397},
	{"PARLAYS", 7, 244398},
	{"BLUSTERING", 10, 244399},
	{"SPARLE", 6, 244400},
	{"HELLFUL", 7, 244401},
	{"CONTEXTMENU", 11, 244402},
	{"BLACKBERRYS", 11, 244403},
	{"ZAFON", 5, 244404},
	{"MISHLER", 7, 244405},
	{"IMSL", 4, 244406},
	{"CHLORAMBUCIL", 12, 244407},
	{"TRUSURROUND", 11, 244408},
	{"RAZIN", 5, 244409},
	{"BLAUWE", 6, 244410},
	{"LOBSANG", 7, 244411},
	{"KEYLOG", 6, 244412},
	{"VFTOOL", 6, 244413},
	{"VADDR", 5, 244414},
	{"GARTERBELT", 10, 244415},
	{"FIRMY", 5, 244416},
	{"TERRORISE", 9, 244417},
	{"TAKASAKI", 8, 244418},
	{"SUHAIB", 6, 244419},
	{"RPLICA", 6, 244420},
	{"MAPQUWST", 8, 244421},
	{"INTUMESCENT", 11, 244422},
	{"EUROTOP", 7, 244423},
	{"UNIFORME", 8, 244424},
	{"KENTLAND", 8, 244425},
	{"SYRINGOMYELIA", 13, 244426},
	{"LENTIVIRAL", 10, 244427},
	{"GULLIVERS", 9, 244428},
	{"GRANARIES", 9, 244429},
	{"ELIGI", 5, 244430},
	{"STAPES", 6, 244431},
	{"CLIMATOLOGISTS", 14, 244432},
	{"STUY", 4, 244433},
	{"RGF", 3, 244434},
	{"ICUS", 4, 244435},
	{"JAQUARD", 7, 244436},
	{"DIESTER", 7, 244437},
	{"ASCOMYCETES", 11, 244438},
	{"TRAILRUNNING", 12, 244439},
	{"ROCKFIELD", 9, 244440},
	{"PURPLEWIKI", 10, 244441},
	{"OCCULTISTS", 10, 244442},
	{"MIAM", 4, 244443},
	{"TKEY", 4, 244444},
	{"MARKEDNESS", 10, 244445},
	{"KAHR", 4, 244446},
	{"ILDB", 4, 244447},
	{"CANNAE", 6, 244448},
	{"BEANCOUNTER", 11, 244449},
	{"KHUFU", 5, 244450},
	{"HALMA", 5, 244451},
	{"AMRHEIN", 7, 244452},
	{"WESTRIM", 7, 244453},
	{"MYXOMA", 6, 244454},
	{"MONITRO", 7, 244455},
	{"DELTAMETHRIN", 12, 244456},
	{"REMPLACEMENT", 12, 244457},
	{"PKGNAME", 7, 244458},
	{"ICONTROL", 8, 244459},
	{"OMBRES", 6, 244460},
	{"NETMON", 6, 244461},
	{"LINDENWOLD", 10, 244462},
	{"SUCHTEN", 7, 244463},
	{"PUMPOUT", 7, 244464},
	{"POWDERLY", 8, 244465},
	{"BORHAM", 6, 244466},
	{"TELEPHONENUMBER", 15, 244467},
	{"STRID", 5, 244468},
	{"SCHNEIDERS", 10, 244469},
	{"OKOCHA", 6, 244470},
	{"GOCOLLECT", 9, 244471},
	{"BANTUAN", 7, 244472},
	{"QALY", 4, 244473},
	{"ISTATIONERS", 11, 244474},
	{"HERIZ", 5, 244475},
	{"FLAGELLIN", 9, 244476},
	{"CUYAMA", 6, 244477},
	{"RIGHTHANDER", 11, 244478},
	{"PUSYS", 5, 244479},
	{"METTERNICH", 10, 244480},
	{"SATSUKI", 7, 244481},
	{"LAPTO", 5, 244482},
	{"JANELA", 6, 244483},
	{"INMAGINEASIA", 12, 244484},
	{"EQUITYDOMAIN", 12, 244485},
	{"CHRISTMA", 8, 244486},
	{"VIRGINIANUS", 11, 244487},
	{"PIRSA", 5, 244488},
	{"MRINAL", 6, 244489},
	{"KICKFLIP", 8, 244490},
	{"HASBEEN", 7, 244491},
	{"SLAVOJ", 6, 244492},
	{"MEDSPAN", 7, 244493},
	{"BLOF", 4, 244494},
	{"UFG", 3, 244495},
	{"ROSTOK", 6, 244496},
	{"ENCULADAS", 9, 244497},
	{"DOLCH", 5, 244498},
	{"AVITA", 5, 244499},
	{"UNINSURANCE", 11, 244500},
	{"ISTRATIVE", 9, 244501},
	{"CERVISIA", 8, 244502},
	{"ARAUCARIA", 9, 244503},
	{"OETTINGER", 9, 244504},
	{"GSVIEW", 6, 244505},
	{"FREIHERR", 8, 244506},
	{"GADGETLAB", 9, 244507},
	{"BOKRECENSIONER", 14, 244508},
	{"JBIG", 4, 244509},
	{"BOHUSLAV", 8, 244510},
	{"THELONIUS", 9, 244511},
	{"SANSTHAN", 8, 244512},
	{"DACOSTA", 7, 244513},
	{"ZMAU", 4, 244514},
	{"YLYL", 4, 244515},
	{"YIAP", 4, 244516},
	{"XLAC", 4, 244517},
	{"VVIR", 4, 244518},
	{"VTWO", 4, 244519},
	{"UQTA", 4, 244520},
	{"UOMU", 4, 244521},
	{"UKPU", 4, 244522},
	{"TZPI", 4, 244523},
	{"TVPO", 4, 244524},
	{"TIDF", 4, 244525},
	{"TDJA", 4, 244526},
	{"SHMR", 4, 244527},
	{"SHMD", 4, 244528},
	{"RVSP", 4, 244529},
	{"RCKT", 4, 244530},
	{"PGAO", 4, 244531},
	{"OYWR", 4, 244532},
	{"OVNY", 4, 244533},
	{"ORWS", 4, 244534},
	{"OHYU", 4, 244535},
	{"NZEV", 4, 244536},
	{"NYMB", 4, 244537},
	{"NLPE", 4, 244538},
	{"NCZY", 4, 244539},
	{"MJAD", 4, 244540},
	{"MCLY", 4, 244541},
	{"MAIV", 4, 244542},
	{"LFJE", 4, 244543},
	{"KTID", 4, 244544},
	{"IUNC", 4, 244545},
	{"IKYA", 4, 244546},
	{"IBMB", 4, 244547},
	{"HRFO", 4, 244548},
	{"HMCI", 4, 244549},
	{"HKAD", 4, 244550},
	{"GPSO", 4, 244551},
	{"GOLW", 4, 244552},
	{"GMDI", 4, 244553},
	{"GJEE", 4, 244554},
	{"GAPN", 4, 244555},
	{"FDLR", 4, 244556},
	{"EWDM", 4, 244557},
	{"ERPV", 4, 244558},
	{"EGCE", 4, 244559},
	{"DJPR", 4, 244560},
	{"DIID", 4, 244561},
	{"DDMY", 4, 244562},
	{"CSOD", 4, 244563},
	{"CRTE", 4, 244564},
	{"BETV", 4, 244565},
	{"BBIK", 4, 244566},
	{"AQSU", 4, 244567},
	{"AMNR", 4, 244568},
	{"ALHD", 4, 244569},
	{"AIMJ", 4, 244570},
	{"ESTABAN", 7, 244571},
	{"DLJ", 3, 244572},
	{"GIGANT", 6, 244573},
	{"ALUMNOS", 7, 244574},
	{"MATHEMATIQUES", 13, 244575},
	{"FRATRICIDE", 10, 244576},
	{"FAKEBOOK", 8, 244577},
	{"DCJ", 3, 244578},
	{"SHOWBUSINESS", 12, 244579},
	{"POLIZIA", 7, 244580},
	{"DERAS", 5, 244581},
	{"EDITORIALE", 10, 244582},
	{"EUMUNDI", 7, 244583},
	{"ZAWINUL", 7, 244584},
	{"OPINONS", 7, 244585},
	{"VERBANIA", 8, 244586},
	{"SCHLOSSNAGLE", 12, 244587},
	{"MADDOW", 6, 244588},
	{"LONGDISTANCE", 12, 244589},
	{"BIOZONE", 7, 244590},
	{"SUSTAINERS", 10, 244591},
	{"RODUCTION", 9, 244592},
	{"TNAME", 5, 244593},
	{"MITHRANDIR", 10, 244594},
	{"SERVATIONS", 10, 244595},
	{"PROJECTORCENTRAL", 16, 244596},
	{"EINTRACHT", 9, 244597},
	{"AGONIZINGLY", 11, 244598},
	{"SECTEURS", 8, 244599},
	{"HYBU", 4, 244600},
	{"DISHONOURABLE", 13, 244601},
	{"PETSTORE", 8, 244602},
	{"ANTEON", 6, 244603},
	{"WILDROSE", 8, 244604},
	{"UNPROVABLE", 10, 244605},
	{"AQUATRONICS", 11, 244606},
	{"HGMD", 4, 244607},
	{"GLUECK", 6, 244608},
	{"CRYPTOGRAPHERS", 14, 244609},
	{"BARANOWSKI", 10, 244610},
	{"CITRINES", 8, 244611},
	{"WETPIXEL", 8, 244612},
	{"ULTIMOS", 7, 244613},
	{"TARMO", 5, 244614},
	{"STREETDRIVEN", 12, 244615},
	{"TEVF", 4, 244616},
	{"KABINETT", 8, 244617},
	{"BUTTERMERE", 10, 244618},
	{"BESPEAKS", 8, 244619},
	{"SCHANBERG", 9, 244620},
	{"PSFRAG", 6, 244621},
	{"LAURIC", 6, 244622},
	{"ERATIVE", 7, 244623},
	{"CHENE", 5, 244624},
	{"BANWELL", 7, 244625},
	{"SMILINGLY", 9, 244626},
	{"PATENTES", 8, 244627},
	{"NETSTANDARD", 11, 244628},
	{"INTERVISTA", 10, 244629},
	{"INTELLINET", 10, 244630},
	{"UNTERNEHMENSINFO", 16, 244631},
	{"MELODI", 6, 244632},
	{"JAGGERS", 7, 244633},
	{"AVOW", 4, 244634},
	{"WALBURG", 7, 244635},
	{"CONNS", 5, 244636},
	{"SUPRNOVA", 8, 244637},
	{"SADF", 4, 244638},
	{"POOBAH", 6, 244639},
	{"MEDIUMI", 7, 244640},
	{"KYOU", 4, 244641},
	{"AUBERGINES", 10, 244642},
	{"POLYOMA", 7, 244643},
	{"EPICARDIAL", 10, 244644},
	{"TBLSP", 5, 244645},
	{"LUHR", 4, 244646},
	{"COWLS", 5, 244647},
	{"INGRANDIRE", 10, 244648},
	{"GOLLA", 5, 244649},
	{"DEEK", 4, 244650},
	{"FLOXIN", 6, 244651},
	{"HORSESHIT", 9, 244652},
	{"BRANQUINHO", 10, 244653},
	{"CTEC", 4, 244654},
	{"VICTORI", 7, 244655},
	{"STEENBERGEN", 11, 244656},
	{"SOULFIRE", 8, 244657},
	{"SHAKEMAP", 8, 244658},
	{"CAPRICORNS", 10, 244659},
	{"BACHELORETTES", 13, 244660},
	{"QUAGLIA", 7, 244661},
	{"DDANGOS", 7, 244662},
	{"CEKA", 4, 244663},
	{"CARME", 5, 244664},
	{"DIPLOMAD", 8, 244665},
	{"BATTIER", 7, 244666},
	{"SINDEN", 6, 244667},
	{"BUTANONE", 8, 244668},
	{"TOOLSHAND", 9, 244669},
	{"GOLDHABER", 9, 244670},
	{"SEATINGS", 8, 244671},
	{"TARGNAME", 8, 244672},
	{"RECIPROCALS", 11, 244673},
	{"POLYFONISKA", 11, 244674},
	{"NUCLEOLI", 8, 244675},
	{"MANASOTA", 8, 244676},
	{"JONBENET", 8, 244677},
	{"FICIAL", 6, 244678},
	{"SAMENWERKING", 12, 244679},
	{"PLAYBILLS", 9, 244680},
	{"MUNCK", 5, 244681},
	{"ARTIGO", 6, 244682},
	{"WHAR", 4, 244683},
	{"RACEY", 5, 244684},
	{"QFONT", 5, 244685},
	{"MOGAMI", 6, 244686},
	{"SELECTOBJECT", 12, 244687},
	{"ICKETS", 6, 244688},
	{"TOMBAUGH", 8, 244689},
	{"PIPPO", 5, 244690},
	{"ZACCHIROLI", 10, 244691},
	{"DELORIA", 7, 244692},
	{"CURARE", 6, 244693},
	{"SCHERZI", 7, 244694},
	{"MARFIL", 6, 244695},
	{"HESSION", 7, 244696},
	{"GOODHEART", 9, 244697},
	{"NYSEG", 5, 244698},
	{"PAKE", 4, 244699},
	{"GERASIMOV", 9, 244700},
	{"FLATIRONS", 9, 244701},
	{"COLOPLAST", 9, 244702},
	{"CERTA", 5, 244703},
	{"TOUCHMAN", 8, 244704},
	{"NEGLIGIBLY", 10, 244705},
	{"GVL", 3, 244706},
	{"RINGTON", 7, 244707},
	{"KUPPER", 6, 244708},
	{"GLENPOOL", 8, 244709},
	{"ANTICI", 6, 244710},
	{"STEARN", 6, 244711},
	{"QUAHOG", 6, 244712},
	{"PENGHU", 6, 244713},
	{"INTRUSIVENESS", 13, 244714},
	{"BOLTE", 5, 244715},
	{"STRIB", 5, 244716},
	{"DEFACEMENTS", 11, 244717},
	{"ASSIZE", 6, 244718},
	{"ARTIGAS", 7, 244719},
	{"SHOPVAC", 7, 244720},
	{"KHUNG", 5, 244721},
	{"HUNGERS", 7, 244722},
	{"KOHOUT", 6, 244723},
	{"FOODSCIENCE", 11, 244724},
	{"PATCHLINK", 9, 244725},
	{"NOREN", 5, 244726},
	{"JACKA", 5, 244727},
	{"AGUADO", 6, 244728},
	{"NOTOCHORD", 9, 244729},
	{"GWALTNEY", 8, 244730},
	{"GILLELAND", 9, 244731},
	{"DUCAT", 5, 244732},
	{"PLUMMING", 8, 244733},
	{"RYD", 3, 244734},
	{"PARTENZA", 8, 244735},
	{"ALLYING", 7, 244736},
	{"WURTH", 5, 244737},
	{"ISBISTER", 8, 244738},
	{"DOPPIO", 6, 244739},
	{"PALYBOY", 7, 244740},
	{"NCHAR", 5, 244741},
	{"APARATO", 7, 244742},
	{"KENTA", 5, 244743},
	{"ITNATION", 8, 244744},
	{"GEOBIDS", 7, 244745},
	{"PAPANUI", 7, 244746},
	{"JOLLIES", 7, 244747},
	{"NIZAMABAD", 9, 244748},
	{"MARMOR", 6, 244749},
	{"MACPYTHON", 9, 244750},
	{"LESPEDEZA", 9, 244751},
	{"GYEONGJU", 8, 244752},
	{"SPEARGUN", 8, 244753},
	{"MILLEDGE", 8, 244754},
	{"ROMPED", 6, 244755},
	{"ATTRONEY", 8, 244756},
	{"DEVOTO", 6, 244757},
	{"CTYI", 4, 244758},
	{"MLLW", 4, 244759},
	{"SKIRBALL", 8, 244760},
	{"QTTORNEY", 8, 244761},
	{"NONMAJOR", 8, 244762},
	{"FORAKER", 7, 244763},
	{"ESTUDIA", 7, 244764},
	{"EPIGRAPHY", 9, 244765},
	{"KEEPALIVES", 10, 244766},
	{"CHILDSPLAY", 10, 244767},
	{"DARGESTELLT", 11, 244768},
	{"CASCADIAN", 9, 244769},
	{"TENBA", 5, 244770},
	{"KULU", 4, 244771},
	{"GRESFORD", 8, 244772},
	{"BODENHAM", 8, 244773},
	{"BOATBUILDER", 11, 244774},
	{"SUURI", 5, 244775},
	{"SUSIEQ", 6, 244776},
	{"HEURISTICALLY", 13, 244777},
	{"HARASSES", 8, 244778},
	{"PSXY", 4, 244779},
	{"PROPP", 5, 244780},
	{"DIPANKAR", 8, 244781},
	{"ALLAM", 5, 244782},
	{"OSCOM", 5, 244783},
	{"MUSCARIA", 8, 244784},
	{"LAINEY", 6, 244785},
	{"OPENWORK", 8, 244786},
	{"HOMENETWORKGEAR", 15, 244787},
	{"CAVILL", 6, 244788},
	{"PRODUCTPAGE", 11, 244789},
	{"HOTELZ", 6, 244790},
	{"COTRANSPORTER", 13, 244791},
	{"YPARXOYN", 8, 244792},
	{"JAPHETH", 7, 244793},
	{"INSITU", 6, 244794},
	{"ZEHU", 4, 244795},
	{"ZEED", 4, 244796},
	{"ZARL", 4, 244797},
	{"YTAD", 4, 244798},
	{"YRCO", 4, 244799},
	{"YBMW", 4, 244800},
	{"XBER", 4, 244801},
	{"WSSK", 4, 244802},
	{"VBET", 4, 244803},
	{"VATL", 4, 244804},
	{"UXWE", 4, 244805},
	{"UKLO", 4, 244806},
	{"UBTV", 4, 244807},
	{"TULR", 4, 244808},
	{"TBCE", 4, 244809},
	{"SXPO", 4, 244810},
	{"SMGI", 4, 244811},
	{"SGBO", 4, 244812},
	{"RUDZ", 4, 244813},
	{"RNKU", 4, 244814},
	{"RGUB", 4, 244815},
	{"RBBO", 4, 244816},
	{"RAXX", 4, 244817},
	{"QSAM", 4, 244818},
	{"QALS", 4, 244819},
	{"PYNC", 4, 244820},
	{"PADN", 4, 244821},
	{"OMRF", 4, 244822},
	{"MUQT", 4, 244823},
	{"MLBF", 4, 244824},
	{"MFUS", 4, 244825},
	{"LTDN", 4, 244826},
	{"LKGA", 4, 244827},
	{"LIGW", 4, 244828},
	{"JRHO", 4, 244829},
	{"JASL", 4, 244830},
	{"IZIM", 4, 244831},
	{"HTVC", 4, 244832},
	{"GFUA", 4, 244833},
	{"GAOM", 4, 244834},
	{"FRYH", 4, 244835},
	{"FNAF", 4, 244836},
	{"FIEW", 4, 244837},
	{"FDYL", 4, 244838},
	{"ELZN", 4, 244839},
	{"EKGL", 4, 244840},
	{"DPMB", 4, 244841},
	{"DNBH", 4, 244842},
	{"DMBI", 4, 244843},
	{"DKUH", 4, 244844},
	{"DJHE", 4, 244845},
	{"CNUI", 4, 244846},
	{"CBCE", 4, 244847},
	{"BRIH", 4, 244848},
	{"BEGB", 4, 244849},
	{"AHLP", 4, 244850},
	{"SCHRIJVEN", 9, 244851},
	{"MAUDIO", 6, 244852},
	{"HUTCHEON", 8, 244853},
	{"CHKERRQ", 7, 244854},
	{"BEEJ", 4, 244855},
	{"WCED", 4, 244856},
	{"KAZUNORI", 8, 244857},
	{"BOBBERS", 7, 244858},
	{"NACHDEM", 7, 244859},
	{"FIRESTORE", 9, 244860},
	{"ANOLE", 5, 244861},
	{"IFTAR", 5, 244862},
	{"ALENCAR", 7, 244863},
	{"AKWESASNE", 9, 244864},
	{"PARTNO", 6, 244865},
	{"JUGGY", 5, 244866},
	{"HUNDREDFOLD", 11, 244867},
	{"SHANON", 6, 244868},
	{"LOPPER", 6, 244869},
	{"COVED", 5, 244870},
	{"BANDOL", 6, 244871},
	{"NOVEX", 5, 244872},
	{"GOODRUM", 7, 244873},
	{"DISLEY", 6, 244874},
	{"CANNERS", 7, 244875},
	{"NGLISH", 6, 244876},
	{"ALUR", 4, 244877},
	{"PARRILLA", 8, 244878},
	{"NEWSITEM", 8, 244879},
	{"KANELLOS", 8, 244880},
	{"HOLYDAY", 7, 244881},
	{"BIVALVIA", 8, 244882},
	{"ALLICIN", 7, 244883},
	{"LINENPLACE", 10, 244884},
	{"SUBR", 4, 244885},
	{"NAZWA", 5, 244886},
	{"METALCRAFT", 10, 244887},
	{"FIGUREN", 7, 244888},
	{"ETZEL", 5, 244889},
	{"DISPLEX", 7, 244890},
	{"GREGAN", 6, 244891},
	{"NETCOOL", 7, 244892},
	{"CESSED", 6, 244893},
	{"UNSUPPORTABLE", 13, 244894},
	{"MINDVIZ", 7, 244895},
	{"MIKAYLA", 7, 244896},
	{"COOLRUNNER", 10, 244897},
	{"AORAKI", 6, 244898},
	{"SUBDISCIPLINES", 14, 244899},
	{"SENHORA", 7, 244900},
	{"IDATE", 5, 244901},
	{"POING", 5, 244902},
	{"GROSFILLEX", 10, 244903},
	{"EXTERNALIZED", 12, 244904},
	{"EFERENCE", 8, 244905},
	{"REDRAFT", 7, 244906},
	{"ACTIVEPYTHON", 12, 244907},
	{"KEUN", 4, 244908},
	{"HEIDSIECK", 9, 244909},
	{"BASILEUS", 8, 244910},
	{"MURTI", 5, 244911},
	{"JAKOBS", 6, 244912},
	{"BRANYAN", 7, 244913},
	{"TRUMBLE", 7, 244914},
	{"KYUQUOT", 7, 244915},
	{"TALIN", 5, 244916},
	{"PBY", 3, 244917},
	{"FURGONETAS", 10, 244918},
	{"ACPS", 4, 244919},
	{"MAKHOLM", 7, 244920},
	{"DANNON", 6, 244921},
	{"ANTAWN", 6, 244922},
	{"GLOBEXPLORER", 12, 244923},
	{"SPILLWAYS", 9, 244924},
	{"LAFFAPALOOZA", 12, 244925},
	{"MJTS", 4, 244926},
	{"KNICKERBOCKERS", 14, 244927},
	{"ANNULATION", 10, 244928},
	{"HECHOS", 6, 244929},
	{"GUNFIGHTERS", 11, 244930},
	{"FIFIFIFI", 8, 244931},
	{"ECONEWS", 7, 244932},
	{"STANDFORD", 9, 244933},
	{"OIDENTD", 7, 244934},
	{"BIRSTALL", 8, 244935},
	{"JOINVILLE", 9, 244936},
	{"CAPYBARA", 8, 244937},
	{"YPOYRGEIOY", 10, 244938},
	{"SRAD", 4, 244939},
	{"GATTA", 5, 244940},
	{"BRYER", 5, 244941},
	{"BLACKLITE", 9, 244942},
	{"BICKING", 7, 244943},
	{"ZEKI", 4, 244944},
	{"EPHEMERIDS", 10, 244945},
	{"DRIVERLESS", 10, 244946},
	{"ROCKJAM", 7, 244947},
	{"MATTOCK", 7, 244948},
	{"DROUGHNS", 8, 244949},
	{"WDD", 3, 244950},
	{"TOMASELLO", 9, 244951},
	{"FIERS", 5, 244952},
	{"CLORIS", 6, 244953},
	{"ACAPELLAS", 9, 244954},
	{"WIKINAMES", 9, 244955},
	{"SPINEFARM", 9, 244956},
	{"DONEN", 5, 244957},
	{"TUMNUS", 6, 244958},
	{"COMUNICADOS", 11, 244959},
	{"VIAJANTES", 9, 244960},
	{"REWRITEENGINE", 13, 244961},
	{"CHOLET", 6, 244962},
	{"SCREAMINGLIFE", 13, 244963},
	{"PERMALINKTHURSDAY", 17, 244964},
	{"NISBETT", 7, 244965},
	{"INDURATION", 10, 244966},
	{"PROLIGHT", 8, 244967},
	{"ICERS", 5, 244968},
	{"GAULD", 5, 244969},
	{"ALICEVILLE", 10, 244970},
	{"MATJAZ", 6, 244971},
	{"INGENIEURWISSENSCHAFTEN", 23, 244972},
	{"GUARNERI", 8, 244973},
	{"FACW", 4, 244974},
	{"INSTEON", 7, 244975},
	{"SEKHAR", 6, 244976},
	{"LEXEY", 5, 244977},
	{"ARNOLDI", 7, 244978},
	{"STROHEIM", 8, 244979},
	{"UNICHEM", 7, 244980},
	{"TUFFS", 5, 244981},
	{"SEPTIMIUS", 9, 244982},
	{"DARKVISION", 10, 244983},
	{"MOSHU", 5, 244984},
	{"LAYFIELD", 8, 244985},
	{"BUSER", 5, 244986},
	{"NETSVCS", 7, 244987},
	{"GARSHOL", 7, 244988},
	{"FARAGHER", 8, 244989},
	{"AMBY", 4, 244990},
	{"SOBOTA", 6, 244991},
	{"FAQSFAQS", 8, 244992},
	{"VEVAY", 5, 244993},
	{"PALMERAS", 8, 244994},
	{"MASHONALAND", 11, 244995},
	{"INDICIES", 8, 244996},
	{"ABIERTA", 7, 244997},
	{"OCCASIONALY", 11, 244998},
	{"RELORA", 6, 244999},
	{"PADDERS", 7, 245000},
	{"LINKFILTER", 10, 245001},
	{"RELICA", 6, 245002},
	{"HARDECORE", 9, 245003},
	{"BODDIE", 6, 245004},
	{"REMOVECHILD", 11, 245005},
	{"YOURDON", 7, 245006},
	{"ALLEL", 5, 245007},
	{"REPRESENTIN", 11, 245008},
	{"KATEGORIA", 9, 245009},
	{"JEFFERYS", 8, 245010},
	{"EVANSDALE", 9, 245011},
	{"CHAMPIONSHI", 11, 245012},
	{"WEBACT", 6, 245013},
	{"SQUIDCO", 7, 245014},
	{"RUSBY", 5, 245015},
	{"ROCKADULT", 9, 245016},
	{"DIAW", 4, 245017},
	{"TSUBA", 5, 245018},
	{"MMY", 3, 245019},
	{"FFEIL", 5, 245020},
	{"TOROK", 5, 245021},
	{"ENNILL", 6, 245022},
	{"AMINET", 6, 245023},
	{"SUDSY", 5, 245024},
	{"CRUISETOUR", 10, 245025},
	{"UBAR", 4, 245026},
	{"SABELA", 6, 245027},
	{"HASLEM", 6, 245028},
	{"GERHARDS", 8, 245029},
	{"KAIRI", 5, 245030},
	{"ROCKSOUTHERN", 12, 245031},
	{"SPANKERS", 8, 245032},
	{"LISTITERATOR", 12, 245033},
	{"PICTURETEL", 10, 245034},
	{"BLEEM", 5, 245035},
	{"WILDMON", 7, 245036},
	{"PERIODOGRAM", 11, 245037},
	{"FRAGGED", 7, 245038},
	{"ERYTHRITOL", 10, 245039},
	{"INTERI", 6, 245040},
	{"RIMER", 5, 245041},
	{"STONECROP", 9, 245042},
	{"MDRC", 4, 245043},
	{"GIMPSY", 6, 245044},
	{"CARDINALIS", 10, 245045},
	{"AKIYOSHI", 8, 245046},
	{"WOODYARD", 8, 245047},
	{"SONGWRITERSOFT", 14, 245048},
	{"ROCKSURFTRIBUTE", 15, 245049},
	{"EREIGNISSE", 10, 245050},
	{"DEISTS", 6, 245051},
	{"ROCKFOREIGN", 11, 245052},
	{"RETORNO", 7, 245053},
	{"MAHOOD", 6, 245054},
	{"FREEGAMES", 9, 245055},
	{"CONTEMPORARYBOOGIE", 18, 245056},
	{"BANDSPOP", 8, 245057},
	{"SLOWPOKE", 8, 245058},
	{"HEBBIAN", 7, 245059},
	{"BETOOK", 6, 245060},
	{"CANEPA", 6, 245061},
	{"SIGNITURE", 9, 245062},
	{"LIVEBLOGGING", 12, 245063},
	{"LANDBOU", 7, 245064},
	{"INTERSTAR", 9, 245065},
	{"AUTONEGOTIATION", 15, 245066},
	{"STRANO", 6, 245067},
	{"PULLETS", 7, 245068},
	{"PIRTLE", 6, 245069},
	{"CYBERALERT", 10, 245070},
	{"SCHNOODLE", 9, 245071},
	{"NARULA", 6, 245072},
	{"CARESSINGLY", 11, 245073},
	{"BAUSMAN", 7, 245074},
	{"KANTAOUI", 8, 245075},
	{"ADDIT", 5, 245076},
	{"SANGLI", 6, 245077},
	{"DECONCINI", 9, 245078},
	{"NONTARGET", 9, 245079},
	{"LEADTOOLS", 9, 245080},
	{"ARCC", 4, 245081},
	{"RARIFIED", 8, 245082},
	{"PARKSTONE", 9, 245083},
	{"CHARACTOR", 9, 245084},
	{"KEGERATOR", 9, 245085},
	{"KEATES", 6, 245086},
	{"IWAR", 4, 245087},
	{"HERMANSEN", 9, 245088},
	{"SESSLER", 7, 245089},
	{"HOOTED", 6, 245090},
	{"SHORTRIDGE", 10, 245091},
	{"FROGGATT", 8, 245092},
	{"SMORES", 6, 245093},
	{"IIRIRA", 6, 245094},
	{"GOETHALS", 8, 245095},
	{"SHALLOWLY", 9, 245096},
	{"PINTECH", 7, 245097},
	{"PAETEC", 6, 245098},
	{"TYPECHECK", 9, 245099},
	{"LEONCAVALLO", 11, 245100},
	{"BASSENTHWAITE", 13, 245101},
	{"GMV", 3, 245102},
	{"BARREAU", 7, 245103},
	{"FLOORCALENDARS", 14, 245104},
	{"ZZPR", 4, 245105},
	{"ZZOB", 4, 245106},
	{"YYUN", 4, 245107},
	{"YWII", 4, 245108},
	{"YQUR", 4, 245109},
	{"YELF", 4, 245110},
	{"YANQ", 4, 245111},
	{"WWIC", 4, 245112},
	{"WUTI", 4, 245113},
	{"VITF", 4, 245114},
	{"UZMO", 4, 245115},
	{"UTYK", 4, 245116},
	{"UKGA", 4, 245117},
	{"UEIG", 4, 245118},
	{"TYEU", 4, 245119},
	{"THUV", 4, 245120},
	{"SDFA", 4, 245121},
	{"RPCP", 4, 245122},
	{"RKKR", 4, 245123},
	{"RDOJ", 4, 245124},
	{"RAQV", 4, 245125},
	{"PPCR", 4, 245126},
	{"ORGJ", 4, 245127},
	{"OLFJ", 4, 245128},
	{"OGEF", 4, 245129},
	{"OFKD", 4, 245130},
	{"OFJS", 4, 245131},
	{"OCFR", 4, 245132},
	{"NZIR", 4, 245133},
	{"NJOM", 4, 245134},
	{"MUNM", 4, 245135},
	{"MROH", 4, 245136},
	{"MOUP", 4, 245137},
	{"MMMW", 4, 245138},
	{"MLUM", 4, 245139},
	{"MEYD", 4, 245140},
	{"LWUL", 4, 245141},
	{"LUTL", 4, 245142},
	{"LGIM", 4, 245143},
	{"LEHL", 4, 245144},
	{"LECF", 4, 245145},
	{"KYMC", 4, 245146},
	{"KSPM", 4, 245147},
	{"KKII", 4, 245148},
	{"KGEA", 4, 245149},
	{"KABH", 4, 245150},
	{"JWAT", 4, 245151},
	{"JUME", 4, 245152},
	{"JRAP", 4, 245153},
	{"JOYU", 4, 245154},
	{"IVRI", 4, 245155},
	{"GUDO", 4, 245156},
	{"GNAY", 4, 245157},
	{"GKHO", 4, 245158},
	{"GHKU", 4, 245159},
	{"FJAW", 4, 245160},
	{"FIYA", 4, 245161},
	{"FCCL", 4, 245162},
	{"EZYA", 4, 245163},
	{"EYRY", 4, 245164},
	{"EYRH", 4, 245165},
	{"EMMB", 4, 245166},
	{"EMCV", 4, 245167},
	{"DUWO", 4, 245168},
	{"CSHR", 4, 245169},
	{"CCBU", 4, 245170},
	{"BYZU", 4, 245171},
	{"BERX", 4, 245172},
	{"BBBA", 4, 245173},
	{"AXPI", 4, 245174},
	{"AFLW", 4, 245175},
	{"AEBR", 4, 245176},
	{"SOMWHERE", 8, 245177},
	{"SCHNECK", 7, 245178},
	{"BALLINCOLLIG", 12, 245179},
	{"INTREATED", 9, 245180},
	{"BAHAY", 5, 245181},
	{"EZPHONESYSTEMS", 14, 245182},
	{"DIETHYLAMIDE", 12, 245183},
	{"TOWBOAT", 7, 245184},
	{"SILBERBERG", 10, 245185},
	{"GJORT", 5, 245186},
	{"STEINHAUSEN", 11, 245187},
	{"OCULOPLASTICS", 13, 245188},
	{"SOLIDEDGE", 9, 245189},
	{"LEVERANCIER", 11, 245190},
	{"HUOSE", 5, 245191},
	{"FRESHDIRECT", 11, 245192},
	{"EDHEC", 5, 245193},
	{"VENTRALLY", 9, 245194},
	{"HOMMA", 5, 245195},
	{"RAISTLIN", 8, 245196},
	{"MYSCHOOLONLINE", 14, 245197},
	{"FOGLIGHTS", 9, 245198},
	{"COTNER", 6, 245199},
	{"THIEMANN", 8, 245200},
	{"FLOWERHAND", 10, 245201},
	{"SUPERBRA", 8, 245202},
	{"EURORACK", 8, 245203},
	{"PXF", 3, 245204},
	{"MAILLET", 7, 245205},
	{"SERIESYORKVILLE", 15, 245206},
	{"REPLICANTS", 10, 245207},
	{"PROFESSIONALI", 13, 245208},
	{"NEERS", 5, 245209},
	{"IAPMO", 5, 245210},
	{"CAMELCASE", 9, 245211},
	{"WARMASTER", 9, 245212},
	{"MYTYPE", 6, 245213},
	{"BUAD", 4, 245214},
	{"KLONOA", 6, 245215},
	{"BIOLOGISCHE", 11, 245216},
	{"SCLEROTINIA", 11, 245217},
	{"LANGPORT", 8, 245218},
	{"CYANAMID", 8, 245219},
	{"TOMAZ", 5, 245220},
	{"LOACHES", 7, 245221},
	{"HPAC", 4, 245222},
	{"THROMBI", 7, 245223},
	{"GLOCESTER", 9, 245224},
	{"SUBSTORES", 9, 245225},
	{"MICROSPOT", 9, 245226},
	{"MECHAM", 6, 245227},
	{"CHUMBE", 6, 245228},
	{"BUCKWALTER", 10, 245229},
	{"BORBONESE", 9, 245230},
	{"CONVULSING", 10, 245231},
	{"QUELLING", 8, 245232},
	{"MARSHALLSOFT", 12, 245233},
	{"KISAN", 5, 245234},
	{"INSTANCED", 9, 245235},
	{"COSTAU", 6, 245236},
	{"UTSUNOMIYA", 10, 245237},
	{"MARESCA", 7, 245238},
	{"DECOMP", 6, 245239},
	{"STARI", 5, 245240},
	{"GURALNICK", 9, 245241},
	{"DUCKTALES", 9, 245242},
	{"AHLER", 5, 245243},
	{"HANDKNIT", 8, 245244},
	{"MASTRANGELO", 11, 245245},
	{"WAGGLE", 6, 245246},
	{"LIASING", 7, 245247},
	{"ACCOMP", 6, 245248},
	{"MISSISSIPPIANS", 14, 245249},
	{"GLYCOPEPTIDES", 13, 245250},
	{"CRISTALLI", 9, 245251},
	{"BRONCHO", 7, 245252},
	{"HALFVALUE", 9, 245253},
	{"DEFA", 4, 245254},
	{"CORIGLIANO", 10, 245255},
	{"STIMULATIONS", 12, 245256},
	{"OPOTIKI", 7, 245257},
	{"ROZYCKI", 7, 245258},
	{"PARTNERN", 8, 245259},
	{"MICAS", 5, 245260},
	{"GEOINFORMATION", 14, 245261},
	{"BROWNCOATS", 10, 245262},
	{"MASSENGER", 9, 245263},
	{"CORPULENT", 9, 245264},
	{"PASTORIA", 8, 245265},
	{"NAGER", 5, 245266},
	{"LIEING", 6, 245267},
	{"PANTEV", 6, 245268},
	{"KIESEL", 6, 245269},
	{"HIDEYOSHI", 9, 245270},
	{"JAYAWARDENE", 11, 245271},
	{"FMCA", 4, 245272},
	{"DEFEKT", 6, 245273},
	{"CTIVITY", 7, 245274},
	{"STENHOUSEMUIR", 13, 245275},
	{"LISSABON", 8, 245276},
	{"ABOLITIONISM", 12, 245277},
	{"ABERDOUR", 8, 245278},
	{"TADREAM", 7, 245279},
	{"MYALGIC", 7, 245280},
	{"REINF", 5, 245281},
	{"LXII", 4, 245282},
	{"SUNQUEST", 8, 245283},
	{"CARLOADS", 8, 245284},
	{"BEAVERDELL", 10, 245285},
	{"SCAMMELL", 8, 245286},
	{"HOROVITZ", 8, 245287},
	{"COLLADO", 7, 245288},
	{"SEBULBA", 7, 245289},
	{"CONTRARILY", 10, 245290},
	{"WOODCHIPS", 9, 245291},
	{"PROCSET", 7, 245292},
	{"DABBLER", 7, 245293},
	{"WEIRICH", 7, 245294},
	{"TRUN", 4, 245295},
	{"QUICKSPELL", 10, 245296},
	{"CYTOCHEMICAL", 12, 245297},
	{"HAYGOOD", 7, 245298},
	{"ZACHARIA", 8, 245299},
	{"PLANIMETRIC", 11, 245300},
	{"NETWERKEN", 9, 245301},
	{"SHEVLIN", 7, 245302},
	{"LETIT", 5, 245303},
	{"JACOBITES", 9, 245304},
	{"INITIALIZECOMPONENT", 19, 245305},
	{"GBITS", 5, 245306},
	{"DRIPLESS", 8, 245307},
	{"CYFFREDIN", 9, 245308},
	{"COREFERENCE", 11, 245309},
	{"BURTIS", 6, 245310},
	{"IMURAN", 6, 245311},
	{"RMRS", 4, 245312},
	{"HYPERSPEED", 10, 245313},
	{"LIVERSEDGE", 10, 245314},
	{"HOLDREN", 7, 245315},
	{"ACKWORTH", 8, 245316},
	{"XLAB", 4, 245317},
	{"TOMBOLA", 7, 245318},
	{"BIOESSAYS", 9, 245319},
	{"JEFFCOAT", 8, 245320},
	{"CAMPONOTUS", 10, 245321},
	{"STUMM", 5, 245322},
	{"TRAEL", 5, 245323},
	{"SANGHVI", 7, 245324},
	{"ELUTE", 5, 245325},
	{"PRIMASE", 7, 245326},
	{"OVERSLEPT", 9, 245327},
	{"INFOWEST", 8, 245328},
	{"FSAP", 4, 245329},
	{"DIRECOTRY", 9, 245330},
	{"ATURAL", 6, 245331},
	{"RANJI", 5, 245332},
	{"MEINEL", 6, 245333},
	{"BISHERIGEN", 10, 245334},
	{"GUILINUX", 8, 245335},
	{"VIOX", 4, 245336},
	{"CLAUDIE", 7, 245337},
	{"WEITERBILDUNG", 13, 245338},
	{"VELDT", 5, 245339},
	{"MCANDREWS", 9, 245340},
	{"JGURU", 5, 245341},
	{"INKWELLS", 8, 245342},
	{"HUNSLET", 7, 245343},
	{"ULUNDI", 6, 245344},
	{"OBJECTSTORE", 11, 245345},
	{"MELANDRI", 8, 245346},
	{"HERRMAN", 7, 245347},
	{"SPRINGEN", 8, 245348},
	{"INCLUSIVES", 10, 245349},
	{"GRUPPER", 7, 245350},
	{"SCARICABILI", 11, 245351},
	{"KNOCKAROUND", 11, 245352},
	{"WOORDENBOEK", 11, 245353},
	{"CROSSON", 7, 245354},
	{"AUTOGAS", 7, 245355},
	{"SCHWANNOMA", 10, 245356},
	{"MOROS", 5, 245357},
	{"MIASMATIC", 9, 245358},
	{"WEEBLES", 7, 245359},
	{"VATTENFALL", 10, 245360},
	{"TINCT", 5, 245361},
	{"NEPOMUK", 7, 245362},
	{"KLEPPER", 7, 245363},
	{"HUBA", 4, 245364},
	{"GLOBALNET", 9, 245365},
	{"GERMANNA", 8, 245366},
	{"RUBBIES", 7, 245367},
	{"RECHTSANWALT", 12, 245368},
	{"NANNUP", 6, 245369},
	{"MUSICPLAYER", 11, 245370},
	{"BANDITRY", 8, 245371},
	{"TRICHINELLA", 11, 245372},
	{"SAVEFILE", 8, 245373},
	{"GINSTALL", 8, 245374},
	{"COLLECTIBILITY", 14, 245375},
	{"BIOFLEX", 7, 245376},
	{"BICUBIC", 7, 245377},
	{"PERMALINKMONDAY", 15, 245378},
	{"INTAKT", 6, 245379},
	{"GJDOC", 5, 245380},
	{"MOISTURIZED", 11, 245381},
	{"JETBRAINS", 9, 245382},
	{"MOZAL", 5, 245383},
	{"BEOORDELING", 11, 245384},
	{"MATZKE", 6, 245385},
	{"STANCIL", 7, 245386},
	{"PRYNNE", 6, 245387},
	{"DISTIBUTION", 11, 245388},
	{"SZYMON", 6, 245389},
	{"STRATHPEFFER", 12, 245390},
	{"TRICKEY", 7, 245391},
	{"SHUCKED", 7, 245392},
	{"HOSPEDAJE", 9, 245393},
	{"FERRANDO", 8, 245394},
	{"BURGETT", 7, 245395},
	{"BARBWIRE", 8, 245396},
	{"USRN", 4, 245397},
	{"MUNGED", 6, 245398},
	{"ALFONSECA", 9, 245399},
	{"POCKETWATCH", 11, 245400},
	{"COPAG", 5, 245401},
	{"MINDJIVE", 8, 245402},
	{"GRENOUILLE", 10, 245403},
	{"TIERRAS", 7, 245404},
	{"REVIO", 5, 245405},
	{"PLANTLIFE", 9, 245406},
	{"BOMI", 4, 245407},
	{"ZELINSKY", 8, 245408},
	{"HIMAL", 5, 245409},
	{"GIRARDIN", 8, 245410},
	{"FACTMONSTER", 11, 245411},
	{"MAXWIDTH", 8, 245412},
	{"AMPLICONS", 9, 245413},
	{"ECLECTICA", 9, 245414},
	{"CODELAIR", 8, 245415},
	{"AKTIVITETER", 11, 245416},
	{"AIMSTER", 7, 245417},
	{"MYSTIFICATION", 13, 245418},
	{"EORUM", 5, 245419},
	{"DYWEDODD", 8, 245420},
	{"BREVI", 5, 245421},
	{"BIBELN", 6, 245422},
	{"TRIAMINIC", 9, 245423},
	{"CHARLBURY", 9, 245424},
	{"CAMPELLO", 8, 245425},
	{"ALGORITHMICA", 12, 245426},
	{"MAKEOUT", 7, 245427},
	{"QUICKS", 6, 245428},
	{"HINDMARCH", 9, 245429},
	{"BELVIEU", 7, 245430},
	{"ZSLI", 4, 245431},
	{"ZHUT", 4, 245432},
	{"ZFRA", 4, 245433},
	{"YURU", 4, 245434},
	{"YOWO", 4, 245435},
	{"VPCH", 4, 245436},
	{"VAED", 4, 245437},
	{"UZOR", 4, 245438},
	{"UTCB", 4, 245439},
	{"UFCC", 4, 245440},
	{"UAYM", 4, 245441},
	{"TYGY", 4, 245442},
	{"SRFC", 4, 245443},
	{"SOKK", 4, 245444},
	{"SBCW", 4, 245445},
	{"SBAV", 4, 245446},
	{"RUXT", 4, 245447},
	{"RKEK", 4, 245448},
	{"RDCB", 4, 245449},
	{"POLN", 4, 245450},
	{"OPIW", 4, 245451},
	{"ONLC", 4, 245452},
	{"OFKV", 4, 245453},
	{"OAGY", 4, 245454},
	{"NPIV", 4, 245455},
	{"NEKC", 4, 245456},
	{"NBHD", 4, 245457},
	{"MZOO", 4, 245458},
	{"MOGW", 4, 245459},
	{"LYII", 4, 245460},
	{"LYEB", 4, 245461},
	{"LTZP", 4, 245462},
	{"LBSB", 4, 245463},
	{"KYNI", 4, 245464},
	{"KUDL", 4, 245465},
	{"KIRP", 4, 245466},
	{"JJPU", 4, 245467},
	{"JISD", 4, 245468},
	{"JEBA", 4, 245469},
	{"JDAL", 4, 245470},
	{"IVSC", 4, 245471},
	{"IEGG", 4, 245472},
	{"GGDE", 4, 245473},
	{"GDOA", 4, 245474},
	{"GCZE", 4, 245475},
	{"EWMS", 4, 245476},
	{"DVOS", 4, 245477},
	{"DUOL", 4, 245478},
	{"DMFR", 4, 245479},
	{"DGBO", 4, 245480},
	{"DEUK", 4, 245481},
	{"CUPJ", 4, 245482},
	{"CBYL", 4, 245483},
	{"BIZS", 4, 245484},
	{"BBSG", 4, 245485},
	{"ANKQ", 4, 245486},
	{"RURALITY", 8, 245487},
	{"PETRARCA", 8, 245488},
	{"JOHNNA", 6, 245489},
	{"DDOT", 4, 245490},
	{"RAIFORD", 7, 245491},
	{"BISHOPSTONE", 11, 245492},
	{"NEUTRA", 6, 245493},
	{"ANIRUDDHA", 9, 245494},
	{"ANCILLA", 7, 245495},
	{"YSTORE", 6, 245496},
	{"SUPERWAREHOUSE", 14, 245497},
	{"RANDR", 5, 245498},
	{"KIKE", 4, 245499},
	{"FLYLADY", 7, 245500},
	{"BCDR", 4, 245501},
	{"TEUCHOS", 7, 245502},
	{"SCUDS", 5, 245503},
	{"MPLEMENTATION", 13, 245504},
	{"MASLOV", 6, 245505},
	{"COOMERA", 7, 245506},
	{"YARDLINE", 8, 245507},
	{"UFFI", 4, 245508},
	{"REPELLENCY", 10, 245509},
	{"JERRAM", 6, 245510},
	{"SCOOTS", 6, 245511},
	{"REBIRTHING", 10, 245512},
	{"VIEWFRAMETABLE", 14, 245513},
	{"RPMLINT", 7, 245514},
	{"NAVELS", 6, 245515},
	{"GENSLER", 7, 245516},
	{"RECOILING", 9, 245517},
	{"GANGULI", 7, 245518},
	{"CARBETAPENTANE", 14, 245519},
	{"PINENTRY", 8, 245520},
	{"LIBSMBCLIENT", 12, 245521},
	{"KEMIRA", 6, 245522},
	{"DINETTES", 8, 245523},
	{"TRAVELOGS", 9, 245524},
	{"RANCOCAS", 8, 245525},
	{"MATHMOS", 7, 245526},
	{"FONTSTYLE", 9, 245527},
	{"EXPERIENTIALLY", 14, 245528},
	{"SHANTEL", 7, 245529},
	{"COOPAMERICA", 11, 245530},
	{"BAYOUMI", 7, 245531},
	{"ARLIS", 5, 245532},
	{"PCMA", 4, 245533},
	{"POWERHEADS", 10, 245534},
	{"JOBA", 4, 245535},
	{"HOMECOMINGS", 11, 245536},
	{"CASHIERED", 9, 245537},
	{"BRAMALEA", 8, 245538},
	{"BOMBARDMENTS", 12, 245539},
	{"BELUM", 5, 245540},
	{"ABITEBOUL", 9, 245541},
	{"SUBMARKET", 9, 245542},
	{"BATTLERS", 8, 245543},
	{"PERTON", 6, 245544},
	{"KNOTTINGLEY", 11, 245545},
	{"POKEREMPIRE", 11, 245546},
	{"SCHAGHTICOKE", 12, 245547},
	{"MOSHAV", 6, 245548},
	{"MATERNELLE", 10, 245549},
	{"DEGUIRE", 7, 245550},
	{"CARTLAND", 8, 245551},
	{"ARTIX", 5, 245552},
	{"TELEMECANIQUE", 13, 245553},
	{"PSHAW", 5, 245554},
	{"ANOLIS", 6, 245555},
	{"CRISPI", 6, 245556},
	{"MERCHAN", 7, 245557},
	{"YNGVE", 5, 245558},
	{"SPEEDBOATS", 10, 245559},
	{"SPECTARE", 8, 245560},
	{"EDICOLA", 7, 245561},
	{"DWYRAIN", 7, 245562},
	{"QUEMADO", 7, 245563},
	{"LFSR", 4, 245564},
	{"BENEDICTINES", 12, 245565},
	{"MALAGUTI", 8, 245566},
	{"MOKHTAR", 7, 245567},
	{"ORCE", 4, 245568},
	{"FATTURE", 7, 245569},
	{"BOGE", 4, 245570},
	{"BARNIER", 7, 245571},
	{"YCL", 3, 245572},
	{"MYELOMONOCYTIC", 14, 245573},
	{"DISINTERMEDIATION", 17, 245574},
	{"NAGASAWA", 8, 245575},
	{"EDITPLUS", 8, 245576},
	{"NALCHIK", 7, 245577},
	{"LAMBOURN", 8, 245578},
	{"BUNIA", 5, 245579},
	{"SUPRACHIASMATIC", 15, 245580},
	{"SADAN", 5, 245581},
	{"QUICKMAIL", 9, 245582},
	{"BANAMEX", 7, 245583},
	{"STORMREAVER", 11, 245584},
	{"INTRACOM", 8, 245585},
	{"ELECTRICIDAD", 12, 245586},
	{"VOKAL", 5, 245587},
	{"TERAPIN", 7, 245588},
	{"PROCEDIMIENTO", 13, 245589},
	{"NSDC", 4, 245590},
	{"KUTANI", 6, 245591},
	{"ARTWORLD", 8, 245592},
	{"BROSCHIERT", 10, 245593},
	{"RICULUM", 7, 245594},
	{"PREISWERT", 9, 245595},
	{"ERSCHEINT", 9, 245596},
	{"EVERYWAY", 8, 245597},
	{"ALLOS", 5, 245598},
	{"MADBURY", 7, 245599},
	{"LEISERSON", 9, 245600},
	{"MIDOFFICE", 9, 245601},
	{"TATTOS", 6, 245602},
	{"KASUGA", 6, 245603},
	{"CHUP", 4, 245604},
	{"CARRIZOZO", 9, 245605},
	{"SHINSEI", 7, 245606},
	{"METAPSYCHOLOGY", 14, 245607},
	{"INITIALLED", 10, 245608},
	{"TREMERE", 7, 245609},
	{"LORDI", 5, 245610},
	{"EDWORLD", 7, 245611},
	{"COLOSSEO", 8, 245612},
	{"GOYIM", 5, 245613},
	{"CHUMLEY", 7, 245614},
	{"SUPERZOOM", 9, 245615},
	{"VOKOUN", 6, 245616},
	{"BIGGA", 5, 245617},
	{"LEXXUS", 6, 245618},
	{"EISHOCKEY", 9, 245619},
	{"KHUL", 4, 245620},
	{"HARNICK", 7, 245621},
	{"TATED", 5, 245622},
	{"TALLI", 5, 245623},
	{"AGINST", 6, 245624},
	{"PANSION", 7, 245625},
	{"YESSSS", 6, 245626},
	{"RWHOIS", 6, 245627},
	{"MILITANTLY", 10, 245628},
	{"LAHAISE", 7, 245629},
	{"WATIER", 6, 245630},
	{"INTRACORONARY", 13, 245631},
	{"GENTECH", 7, 245632},
	{"FERREL", 6, 245633},
	{"GHEZZI", 6, 245634},
	{"FORECLOSUREMORTGAGE", 19, 245635},
	{"COLLARLESS", 10, 245636},
	{"SIEMANS", 7, 245637},
	{"RUBAN", 5, 245638},
	{"ROSHO", 5, 245639},
	{"BALLHEAD", 8, 245640},
	{"NATIV", 5, 245641},
	{"JAMENDO", 7, 245642},
	{"BUSHI", 5, 245643},
	{"BOWMANSVILLE", 12, 245644},
	{"WSUNIT", 6, 245645},
	{"PSYCHOTRONIC", 12, 245646},
	{"PENDERECKI", 10, 245647},
	{"MKDEP", 5, 245648},
	{"LAPORTA", 7, 245649},
	{"KRG", 3, 245650},
	{"ESPARTO", 7, 245651},
	{"MACRONUTRIENT", 13, 245652},
	{"KERATECTOMY", 11, 245653},
	{"GETMINIMUMSIZE", 14, 245654},
	{"TRAIPSING", 9, 245655},
	{"GIRLFIGHT", 9, 245656},
	{"CHINSTRAP", 9, 245657},
	{"THEBUGS", 7, 245658},
	{"KLUGH", 5, 245659},
	{"ASHRAMS", 7, 245660},
	{"PROPIONIBACTERIUM", 17, 245661},
	{"APNINFOMEDIA", 12, 245662},
	{"OCKENDEN", 8, 245663},
	{"CAPITOLINE", 10, 245664},
	{"AMEDD", 5, 245665},
	{"CTLA", 4, 245666},
	{"CENLA", 5, 245667},
	{"TOWABLES", 8, 245668},
	{"APOPLECTIC", 10, 245669},
	{"WATERSCAPE", 10, 245670},
	{"PRACHUAP", 8, 245671},
	{"PAMPLING", 8, 245672},
	{"MARAVILLAS", 10, 245673},
	{"INTERNATIONALER", 15, 245674},
	{"AUGRABIES", 9, 245675},
	{"XALAPA", 6, 245676},
	{"LEHAR", 5, 245677},
	{"HAMMERFEST", 10, 245678},
	{"GUESSTIMATE", 11, 245679},
	{"BUBBLIN", 7, 245680},
	{"QUATTROCCHI", 11, 245681},
	{"FECHNER", 7, 245682},
	{"BETING", 6, 245683},
	{"MADANI", 6, 245684},
	{"ALTERNATIEVE", 12, 245685},
	{"RAUH", 4, 245686},
	{"LOGOSBACKGROUNDS", 16, 245687},
	{"COCOMO", 6, 245688},
	{"BOUTONNIERES", 12, 245689},
	{"MISTERS", 7, 245690},
	{"GUARDAR", 7, 245691},
	{"FOOTPEGS", 8, 245692},
	{"GROPP", 5, 245693},
	{"CONSUMPTIONS", 12, 245694},
	{"DIFFERENCED", 11, 245695},
	{"SOFRWARE", 8, 245696},
	{"MMOS", 4, 245697},
	{"CERVELO", 7, 245698},
	{"ANGY", 4, 245699},
	{"TASKSEL", 7, 245700},
	{"LIPASES", 7, 245701},
	{"SALENTO", 7, 245702},
	{"JALAPA", 6, 245703},
	{"APPERSON", 8, 245704},
	{"HAWKEHURST", 10, 245705},
	{"REDPOLL", 7, 245706},
	{"COMMUNITYFAMILY", 15, 245707},
	{"CHEMLAWN", 8, 245708},
	{"ZENY", 4, 245709},
	{"LALITPUR", 8, 245710},
	{"TRIFLURALIN", 11, 245711},
	{"MIMBRES", 7, 245712},
	{"SUCKLER", 7, 245713},
	{"SINDELAR", 8, 245714},
	{"MISEDUCATION", 12, 245715},
	{"LINGVO", 6, 245716},
	{"SLICKROCK", 9, 245717},
	{"ROHWER", 6, 245718},
	{"MAGU", 4, 245719},
	{"JAYTON", 6, 245720},
	{"HETTICH", 7, 245721},
	{"EUROPAEUS", 9, 245722},
	{"VEACH", 5, 245723},
	{"PALAEONTOLOGICAL", 16, 245724},
	{"MUTZ", 4, 245725},
	{"GONCHAROV", 9, 245726},
	{"FRANKEE", 7, 245727},
	{"BAYA", 4, 245728},
	{"MYNASA", 6, 245729},
	{"FAULKS", 6, 245730},
	{"DIFFSTAT", 8, 245731},
	{"BILLYGOAT", 9, 245732},
	{"APERITIFS", 9, 245733},
	{"ZYEN", 4, 245734},
	{"ZAKR", 4, 245735},
	{"ZAIC", 4, 245736},
	{"YRMA", 4, 245737},
	{"YCMA", 4, 245738},
	{"WYNC", 4, 245739},
	{"VUKA", 4, 245740},
	{"VIVT", 4, 245741},
	{"UCNR", 4, 245742},
	{"UBUK", 4, 245743},
	{"TGED", 4, 245744},
	{"SPMB", 4, 245745},
	{"SCFE", 4, 245746},
	{"RAJF", 4, 245747},
	{"PRCH", 4, 245748},
	{"PPPU", 4, 245749},
	{"PMCT", 4, 245750},
	{"PLTO", 4, 245751},
	{"PCBE", 4, 245752},
	{"OVYA", 4, 245753},
	{"OUAK", 4, 245754},
	{"OSXV", 4, 245755},
	{"OGBL", 4, 245756},
	{"OFXU", 4, 245757},
	{"OFVM", 4, 245758},
	{"OFVF", 4, 245759},
	{"OFNL", 4, 245760},
	{"OEJU", 4, 245761},
	{"NPLC", 4, 245762},
	{"NOUF", 4, 245763},
	{"NJPM", 4, 245764},
	{"MTYI", 4, 245765},
	{"MSAX", 4, 245766},
	{"MKAZ", 4, 245767},
	{"LYLB", 4, 245768},
	{"LUGC", 4, 245769},
	{"LRTH", 4, 245770},
	{"LMRB", 4, 245771},
	{"LIUJ", 4, 245772},
	{"KURW", 4, 245773},
	{"JILE", 4, 245774},
	{"JAJU", 4, 245775},
	{"IYUG", 4, 245776},
	{"IKUK", 4, 245777},
	{"IKBU", 4, 245778},
	{"IGYW", 4, 245779},
	{"HPGA", 4, 245780},
	{"HLUG", 4, 245781},
	{"HKOP", 4, 245782},
	{"GTPA", 4, 245783},
	{"GMBE", 4, 245784},
	{"FXTH", 4, 245785},
	{"FGPS", 4, 245786},
	{"FFIZ", 4, 245787},
	{"FBYJ", 4, 245788},
	{"FBCS", 4, 245789},
	{"FAEG", 4, 245790},
	{"EZEY", 4, 245791},
	{"EOMC", 4, 245792},
	{"ENYK", 4, 245793},
	{"EKVS", 4, 245794},
	{"EIZM", 4, 245795},
	{"ECGT", 4, 245796},
	{"EAYP", 4, 245797},
	{"DUKW", 4, 245798},
	{"DCBO", 4, 245799},
	{"DAQB", 4, 245800},
	{"ASCW", 4, 245801},
	{"SHAYA", 5, 245802},
	{"SAVOLAINEN", 10, 245803},
	{"COOPERVISION", 12, 245804},
	{"BASEST", 6, 245805},
	{"CARDELLINI", 10, 245806},
	{"OBROCHISHTE", 11, 245807},
	{"HARAMBEE", 8, 245808},
	{"BULLFIGHTS", 10, 245809},
	{"SHRIRAM", 7, 245810},
	{"PROBLEMO", 8, 245811},
	{"OMMENDATIONS", 12, 245812},
	{"WITTENBURG", 10, 245813},
	{"MITTELALTER", 11, 245814},
	{"MANSEL", 6, 245815},
	{"FREEBS", 6, 245816},
	{"EPHOD", 5, 245817},
	{"RESTYLE", 7, 245818},
	{"REALLI", 6, 245819},
	{"FITLY", 5, 245820},
	{"FELLNER", 7, 245821},
	{"SKYWARDS", 8, 245822},
	{"PNETLIB", 7, 245823},
	{"LIMAS", 5, 245824},
	{"JAZZE", 5, 245825},
	{"JAYZ", 4, 245826},
	{"EDNY", 4, 245827},
	{"IMPALAS", 7, 245828},
	{"LOOSEST", 7, 245829},
	{"EROTICHE", 8, 245830},
	{"ULTRASCSI", 9, 245831},
	{"EIGENMANN", 9, 245832},
	{"PHONORECORDS", 12, 245833},
	{"GNOLL", 5, 245834},
	{"CHRISTIANSUNITE", 15, 245835},
	{"ALLAYNE", 7, 245836},
	{"PROCHNOW", 8, 245837},
	{"GRADUALISM", 10, 245838},
	{"EUCERIN", 7, 245839},
	{"HOUWITSER", 9, 245840},
	{"MENINGOENCEPHALITIS", 19, 245841},
	{"DASSEL", 6, 245842},
	{"SEABECK", 7, 245843},
	{"PORTELA", 7, 245844},
	{"CHRONOLOGIE", 11, 245845},
	{"WORLDWEB", 8, 245846},
	{"OLDTIMERS", 9, 245847},
	{"MOVIELINE", 9, 245848},
	{"DEEPCUT", 7, 245849},
	{"BMWUUCDIGEST", 12, 245850},
	{"BERU", 4, 245851},
	{"BACTERIOSTATIC", 14, 245852},
	{"MARRIN", 6, 245853},
	{"ANGMAR", 6, 245854},
	{"NEWSHEET", 8, 245855},
	{"INCIVILITY", 10, 245856},
	{"HIREN", 5, 245857},
	{"TOKUDA", 6, 245858},
	{"PUNGENS", 7, 245859},
	{"PROGRAMED", 9, 245860},
	{"KOMPLEX", 7, 245861},
	{"MARCHANDS", 9, 245862},
	{"DRIVESHAFTS", 11, 245863},
	{"VOWLAN", 6, 245864},
	{"FLIRTATIONS", 11, 245865},
	{"BROECK", 6, 245866},
	{"STULTIFYING", 11, 245867},
	{"SEJARAH", 7, 245868},
	{"QDP", 3, 245869},
	{"JXL", 3, 245870},
	{"ALMAGRO", 7, 245871},
	{"JUREVICIUS", 10, 245872},
	{"WUNC", 4, 245873},
	{"MAINVIEW", 8, 245874},
	{"FABRIK", 6, 245875},
	{"CENTRALIS", 9, 245876},
	{"SOUTHBOURNE", 11, 245877},
	{"NASPA", 5, 245878},
	{"RISM", 4, 245879},
	{"NINGEN", 6, 245880},
	{"FINEJEWELERS", 12, 245881},
	{"ANTHELMINTIC", 12, 245882},
	{"SURESTART", 9, 245883},
	{"GLOUSTER", 8, 245884},
	{"XLSHOP", 6, 245885},
	{"HOHENORT", 8, 245886},
	{"BUTTERFLYFISH", 13, 245887},
	{"WYALUSING", 9, 245888},
	{"MULTISAMPLE", 11, 245889},
	{"UESD", 4, 245890},
	{"DARLLEN", 7, 245891},
	{"PACKAG", 6, 245892},
	{"DLSYM", 5, 245893},
	{"MAJERUS", 7, 245894},
	{"AIMD", 4, 245895},
	{"ADDMSG", 6, 245896},
	{"TROCHE", 6, 245897},
	{"NOVOLIN", 7, 245898},
	{"NHSSCOTLAND", 11, 245899},
	{"MONKHOUSE", 9, 245900},
	{"STRAIGHTFROMTHEDOC", 18, 245901},
	{"BOUTCHOUS", 9, 245902},
	{"BLOGBURST", 9, 245903},
	{"MERCADOS", 8, 245904},
	{"KUNIHIKO", 8, 245905},
	{"DELCAMBRE", 9, 245906},
	{"CONOCIDO", 8, 245907},
	{"BEROL", 5, 245908},
	{"VISCERALLY", 10, 245909},
	{"EVERBLADES", 10, 245910},
	{"BROADZILLA", 10, 245911},
	{"ALPHAPATRIOT", 12, 245912},
	{"INETADVISER", 11, 245913},
	{"ERINVALE", 8, 245914},
	{"EGORIES", 7, 245915},
	{"SPEAS", 5, 245916},
	{"ZETASIZER", 9, 245917},
	{"TURBOSOUND", 10, 245918},
	{"FREIDA", 6, 245919},
	{"SSCHEMA", 7, 245920},
	{"REGULARIZE", 10, 245921},
	{"CCX", 3, 245922},
	{"SOFTPRESS", 9, 245923},
	{"MCCLENAHAN", 10, 245924},
	{"HIBBERD", 7, 245925},
	{"GINES", 5, 245926},
	{"ERASURES", 8, 245927},
	{"GINETTA", 7, 245928},
	{"ASTRONOMIC", 10, 245929},
	{"PERONAL", 7, 245930},
	{"GETITEM", 7, 245931},
	{"SEEDBANKS", 9, 245932},
	{"KIKIZO", 6, 245933},
	{"GHOOD", 5, 245934},
	{"SAPERSTEIN", 10, 245935},
	{"NONPHYSICAL", 11, 245936},
	{"GRANTSEEKERS", 12, 245937},
	{"DAGENAIS", 8, 245938},
	{"OBERAU", 6, 245939},
	{"GEBRAUCHTWAGEN", 14, 245940},
	{"BACLIFF", 7, 245941},
	{"TRYPAN", 6, 245942},
	{"SAIKANO", 7, 245943},
	{"ROCKIE", 6, 245944},
	{"WSABI", 5, 245945},
	{"UNCTUOUS", 8, 245946},
	{"COWLISHAW", 9, 245947},
	{"UWW", 3, 245948},
	{"GROF", 4, 245949},
	{"UTTAM", 5, 245950},
	{"TRIDGELL", 8, 245951},
	{"CHINAVENTURENEWS", 16, 245952},
	{"XYLAN", 5, 245953},
	{"ECOTONE", 7, 245954},
	{"NEHRP", 5, 245955},
	{"FURNEAUX", 8, 245956},
	{"FINCHAM", 7, 245957},
	{"TAXABILITY", 10, 245958},
	{"ROUTEPLANNER", 12, 245959},
	{"LSAC", 4, 245960},
	{"FUNKIEST", 8, 245961},
	{"DUETTO", 6, 245962},
	{"COMAN", 5, 245963},
	{"BUGANDA", 7, 245964},
	{"DECANDIDO", 9, 245965},
	{"RODDEN", 6, 245966},
	{"REGURGITATING", 13, 245967},
	{"TAREN", 5, 245968},
	{"RYK", 3, 245969},
	{"YOME", 4, 245970},
	{"MOZE", 4, 245971},
	{"EISOES", 6, 245972},
	{"AEMC", 4, 245973},
	{"UNREFERENCED", 12, 245974},
	{"KLEINERT", 8, 245975},
	{"INFORAD", 7, 245976},
	{"INCLUIDO", 8, 245977},
	{"HONUS", 5, 245978},
	{"ENLIVENING", 10, 245979},
	{"FRANI", 5, 245980},
	{"BRIONY", 6, 245981},
	{"VIAMICHELIN", 11, 245982},
	{"TEFFT", 5, 245983},
	{"SOULES", 6, 245984},
	{"MENCH", 5, 245985},
	{"ARUL", 4, 245986},
	{"LUAR", 4, 245987},
	{"LOTRONEX", 8, 245988},
	{"BURRAGE", 7, 245989},
	{"ZOOPER", 6, 245990},
	{"WONKO", 5, 245991},
	{"SENTIR", 6, 245992},
	{"BUFFYVERSE", 10, 245993},
	{"BASSY", 5, 245994},
	{"RAVALLION", 9, 245995},
	{"CHERNOW", 7, 245996},
	{"ACETYLTRANSFERASES", 18, 245997},
	{"MELBY", 5, 245998},
	{"CALCANEUS", 9, 245999},
	{"BURNLOUNGE", 10, 246000},
	{"DIURON", 6, 246001},
	{"PLUMLEY", 7, 246002},
	{"BOOGIES", 7, 246003},
	{"OPOSICIONES", 11, 246004},
	{"OBTURATOR", 9, 246005},
	{"GXX", 3, 246006},
	{"GASTROSCOPY", 11, 246007},
	{"CHEFNOGAETH", 11, 246008},
	{"BATANG", 6, 246009},
	{"PNNOC", 5, 246010},
	{"MICROLITE", 9, 246011},
	{"IPRA", 4, 246012},
	{"SONIK", 5, 246013},
	{"SCHWEIKER", 9, 246014},
	{"GEHRELS", 7, 246015},
	{"TOMINAGA", 8, 246016},
	{"PAQUITO", 7, 246017},
	{"WOUT", 4, 246018},
	{"VIRI", 4, 246019},
	{"ROSCREA", 7, 246020},
	{"RENAMO", 6, 246021},
	{"KINKEL", 6, 246022},
	{"TYBALT", 6, 246023},
	{"MEDAKA", 6, 246024},
	{"MATAI", 5, 246025},
	{"FINSLIPPY", 9, 246026},
	{"ENCROACHES", 10, 246027},
	{"WEDNESFIELD", 11, 246028},
	{"RELEASABLY", 10, 246029},
	{"NBDL", 4, 246030},
	{"ENCYCLICALS", 11, 246031},
	{"BROWNHILLS", 10, 246032},
	{"ZYDO", 4, 246033},
	{"YTIF", 4, 246034},
	{"XYBE", 4, 246035},
	{"XTVA", 4, 246036},
	{"VWAL", 4, 246037},
	{"VIMU", 4, 246038},
	{"VETZ", 4, 246039},
	{"VDSU", 4, 246040},
	{"VAGL", 4, 246041},
	{"UZAC", 4, 246042},
	{"UYOP", 4, 246043},
	{"THXP", 4, 246044},
	{"RVSS", 4, 246045},
	{"ROVB", 4, 246046},
	{"RNYP", 4, 246047},
	{"RGSG", 4, 246048},
	{"RBHP", 4, 246049},
	{"PJAI", 4, 246050},
	{"PHKA", 4, 246051},
	{"PEJE", 4, 246052},
	{"OVIZ", 4, 246053},
	{"ONMW", 4, 246054},
	{"OFCG", 4, 246055},
	{"ODYQ", 4, 246056},
	{"NGYC", 4, 246057},
	{"NDFP", 4, 246058},
	{"NAWB", 4, 246059},
	{"MPYW", 4, 246060},
	{"MLLO", 4, 246061},
	{"MEWW", 4, 246062},
	{"LOCP", 4, 246063},
	{"LLYX", 4, 246064},
	{"LFSK", 4, 246065},
	{"LFOD", 4, 246066},
	{"LBUO", 4, 246067},
	{"KYOE", 4, 246068},
	{"JRDA", 4, 246069},
	{"JMUS", 4, 246070},
	{"IZHU", 4, 246071},
	{"IJUR", 4, 246072},
	{"IBAZ", 4, 246073},
	{"HEJW", 4, 246074},
	{"GKWA", 4, 246075},
	{"FMOE", 4, 246076},
	{"FISY", 4, 246077},
	{"EZKE", 4, 246078},
	{"ETZR", 4, 246079},
	{"EMVU", 4, 246080},
	{"EKHY", 4, 246081},
	{"DRYV", 4, 246082},
	{"DRUH", 4, 246083},
	{"DPAJ", 4, 246084},
	{"DODW", 4, 246085},
	{"DLIR", 4, 246086},
	{"DIXW", 4, 246087},
	{"DGHZ", 4, 246088},
	{"CNOB", 4, 246089},
	{"CENB", 4, 246090},
	{"BNMU", 4, 246091},
	{"BCEC", 4, 246092},
	{"AJPI", 4, 246093},
	{"OVEREXERTION", 12, 246094},
	{"MNBIRD", 6, 246095},
	{"ATPG", 4, 246096},
	{"LONMIN", 6, 246097},
	{"HBCI", 4, 246098},
	{"VAPORETTO", 9, 246099},
	{"GENERALIS", 9, 246100},
	{"ALLTOGETHER", 11, 246101},
	{"LRFD", 4, 246102},
	{"CALSTOCK", 8, 246103},
	{"ZORIN", 5, 246104},
	{"UNFRACTIONATED", 14, 246105},
	{"TURBEVILLE", 10, 246106},
	{"SHABBONA", 8, 246107},
	{"ICML", 4, 246108},
	{"SARNE", 5, 246109},
	{"NAUKLUFT", 8, 246110},
	{"BLACKSPOTS", 10, 246111},
	{"UNCOLORED", 9, 246112},
	{"MAUVAISE", 8, 246113},
	{"SHOPCARTUSA", 11, 246114},
	{"JOHANNINE", 9, 246115},
	{"ILIESCU", 7, 246116},
	{"SHENLEY", 7, 246117},
	{"PRINTABLESTRING", 15, 246118},
	{"PEDIS", 5, 246119},
	{"VARMUS", 6, 246120},
	{"MEERKATS", 8, 246121},
	{"IMPINGED", 8, 246122},
	{"CONTENTHANDLER", 14, 246123},
	{"MAXTED", 6, 246124},
	{"CHANGHUA", 8, 246125},
	{"CARROLLS", 8, 246126},
	{"SOFTWAREFREE", 12, 246127},
	{"MERCIAN", 7, 246128},
	{"LYRICK", 6, 246129},
	{"LINACRE", 7, 246130},
	{"BUIST", 5, 246131},
	{"ANIMATO", 7, 246132},
	{"USFK", 4, 246133},
	{"MOUTHWASHES", 11, 246134},
	{"KEAR", 4, 246135},
	{"INSIGNIFICANTLY", 15, 246136},
	{"AUBERJONOIS", 11, 246137},
	{"WMAZ", 4, 246138},
	{"VISAYA", 6, 246139},
	{"SUPERCUTS", 9, 246140},
	{"PARKADE", 7, 246141},
	{"BENFRO", 6, 246142},
	{"BEAUMARCHAIS", 12, 246143},
	{"OTOROHANGA", 10, 246144},
	{"INFIDELITIES", 12, 246145},
	{"UNDERSTAN", 9, 246146},
	{"WEYLAND", 7, 246147},
	{"VIETOR", 6, 246148},
	{"DROOD", 5, 246149},
	{"ASYMP", 5, 246150},
	{"CORVO", 5, 246151},
	{"DCDO", 4, 246152},
	{"MISCAVIGE", 9, 246153},
	{"METALCRAFTERS", 13, 246154},
	{"KOUGA", 5, 246155},
	{"PLAINTS", 7, 246156},
	{"NANOTECHBUZZ", 12, 246157},
	{"LEUCEMIA", 8, 246158},
	{"EGLUG", 5, 246159},
	{"TIMEFORCE", 9, 246160},
	{"HUMMOCK", 7, 246161},
	{"FUSHIA", 6, 246162},
	{"ABADON", 6, 246163},
	{"JAVASSIST", 9, 246164},
	{"MERGEANT", 8, 246165},
	{"LUKEN", 5, 246166},
	{"LIBRATION", 9, 246167},
	{"SOPHARMA", 8, 246168},
	{"MASIEL", 6, 246169},
	{"MANHATTANS", 10, 246170},
	{"HERAUSGEBER", 11, 246171},
	{"WHYTELEAFE", 10, 246172},
	{"NEWBB", 5, 246173},
	{"KATSUHIKO", 9, 246174},
	{"PTCS", 4, 246175},
	{"PREAD", 5, 246176},
	{"OPLEIDINGEN", 11, 246177},
	{"CRIAR", 5, 246178},
	{"BACKSWING", 9, 246179},
	{"KEMPIS", 6, 246180},
	{"BONINGTON", 9, 246181},
	{"MUSICI", 6, 246182},
	{"SERU", 4, 246183},
	{"BELZONI", 7, 246184},
	{"SCHEDUL", 7, 246185},
	{"PMED", 4, 246186},
	{"VITAMINSHOPPE", 13, 246187},
	{"MEMORYLESS", 10, 246188},
	{"MTTR", 4, 246189},
	{"STRICTED", 8, 246190},
	{"NASMYTH", 7, 246191},
	{"KIMAGURE", 8, 246192},
	{"STEREOGRAMS", 11, 246193},
	{"FRENCHAY", 8, 246194},
	{"ZAPRUDER", 8, 246195},
	{"TTMKFDIR", 8, 246196},
	{"CALIFORNIACALIFORNIA", 20, 246197},
	{"STOPSAT", 7, 246198},
	{"RESACA", 6, 246199},
	{"PRIMAS", 6, 246200},
	{"RAGDOLLS", 8, 246201},
	{"GARRELL", 7, 246202},
	{"CARTONE", 7, 246203},
	{"HUIDIGE", 7, 246204},
	{"TAKAMI", 6, 246205},
	{"STERILISER", 10, 246206},
	{"MYPUBLISHER", 11, 246207},
	{"BAZZZMAN", 8, 246208},
	{"OPHIUCHUS", 9, 246209},
	{"MISBRUIK", 8, 246210},
	{"FREDERIKSTED", 12, 246211},
	{"WEOBLEY", 7, 246212},
	{"MACIDOL", 7, 246213},
	{"FINISTERRE", 10, 246214},
	{"FETCHER", 7, 246215},
	{"GUTSOON", 7, 246216},
	{"GERRITY", 7, 246217},
	{"CYBERCOM", 8, 246218},
	{"COPPI", 5, 246219},
	{"WESTERDAM", 9, 246220},
	{"HYJAL", 5, 246221},
	{"YOONG", 5, 246222},
	{"URBANI", 6, 246223},
	{"OESTROGENS", 10, 246224},
	{"HAVEA", 5, 246225},
	{"GRAYBILL", 8, 246226},
	{"WELZ", 4, 246227},
	{"PRIMALOFT", 9, 246228},
	{"OVERSTEER", 9, 246229},
	{"MARKELL", 7, 246230},
	{"GOMPA", 5, 246231},
	{"ZINGIBER", 8, 246232},
	{"VESALIUS", 8, 246233},
	{"IGETC", 5, 246234},
	{"RISSA", 5, 246235},
	{"CONEXTIONS", 10, 246236},
	{"SLICKEDIT", 9, 246237},
	{"POPRAD", 6, 246238},
	{"NCCN", 4, 246239},
	{"LAFLIN", 6, 246240},
	{"WAECO", 5, 246241},
	{"ALTHEIM", 7, 246242},
	{"TRADUCTOR", 9, 246243},
	{"ENTFERNUNG", 10, 246244},
	{"ACTIVEVOTES", 11, 246245},
	{"QUICKLOGIC", 10, 246246},
	{"PALMPAK", 7, 246247},
	{"WINSLEY", 7, 246248},
	{"INVERNO", 7, 246249},
	{"VARUKERS", 8, 246250},
	{"WOMENLIT", 8, 246251},
	{"SUDDUTH", 7, 246252},
	{"CGIIRC", 6, 246253},
	{"WILLISMS", 8, 246254},
	{"STARTLES", 8, 246255},
	{"MOONEN", 6, 246256},
	{"LINGUVIC", 8, 246257},
	{"ISMP", 4, 246258},
	{"DATALEN", 7, 246259},
	{"WEALE", 5, 246260},
	{"LETTICE", 7, 246261},
	{"KOINE", 5, 246262},
	{"LICKETY", 7, 246263},
	{"DRAMATIZES", 10, 246264},
	{"PROCESADORES", 12, 246265},
	{"MAUSB", 5, 246266},
	{"MACROCYCLIC", 11, 246267},
	{"KOPPER", 6, 246268},
	{"FACESIT", 7, 246269},
	{"COSTANTINI", 10, 246270},
	{"COLLGE", 6, 246271},
	{"MEKNES", 6, 246272},
	{"CORPN", 5, 246273},
	{"BITSHIFT", 8, 246274},
	{"RUSERS", 6, 246275},
	{"MATCHETT", 8, 246276},
	{"UNAMENDED", 9, 246277},
	{"NORTHOVER", 9, 246278},
	{"CREOLA", 6, 246279},
	{"BATRE", 5, 246280},
	{"DESCALING", 9, 246281},
	{"COLONNADES", 10, 246282},
	{"BACKWORD", 8, 246283},
	{"STANDEE", 7, 246284},
	{"SOLTEROS", 8, 246285},
	{"PROMETRIUM", 10, 246286},
	{"HENOCH", 6, 246287},
	{"ELION", 5, 246288},
	{"ADMINISTRACION", 14, 246289},
	{"PARAVENTRICULAR", 15, 246290},
	{"MADHATTER", 9, 246291},
	{"JELLICOE", 8, 246292},
	{"THEATRICALS", 11, 246293},
	{"CADDISFLIES", 11, 246294},
	{"AMPULE", 6, 246295},
	{"ACOMPANANTES", 12, 246296},
	{"VIDEORAMA", 9, 246297},
	{"DOHETH", 6, 246298},
	{"DAKTRONICS", 10, 246299},
	{"CESARIO", 7, 246300},
	{"QUERCETTI", 9, 246301},
	{"GALASSO", 7, 246302},
	{"ATTORENY", 8, 246303},
	{"AIKSAURUS", 9, 246304},
	{"XLM", 3, 246305},
	{"TERMINALIA", 10, 246306},
	{"TASMANIANS", 10, 246307},
	{"HOOGTE", 6, 246308},
	{"DEVOTCHKAS", 10, 246309},
	{"PRINCETOWN", 10, 246310},
	{"NEWSMEDIANET", 12, 246311},
	{"JOBGEEK", 7, 246312},
	{"FLASHDRIVE", 10, 246313},
	{"MANDINO", 7, 246314},
	{"GRAPHICGO", 9, 246315},
	{"STANTIALLY", 10, 246316},
	{"KABINET", 7, 246317},
	{"DARBYSHIRE", 10, 246318},
	{"AUTOCHTONES", 11, 246319},
	{"MACARTNEY", 9, 246320},
	{"ZBOU", 4, 246321},
	{"ZASR", 4, 246322},
	{"YYAP", 4, 246323},
	{"YLPR", 4, 246324},
	{"YCMI", 4, 246325},
	{"XORR", 4, 246326},
	{"WDOP", 4, 246327},
	{"VEGM", 4, 246328},
	{"ULFN", 4, 246329},
	{"UAZO", 4, 246330},
	{"TJAU", 4, 246331},
	{"SEVR", 4, 246332},
	{"SCCT", 4, 246333},
	{"RYKM", 4, 246334},
	{"RULR", 4, 246335},
	{"RUKP", 4, 246336},
	{"RRDO", 4, 246337},
	{"RPMH", 4, 246338},
	{"RCBR", 4, 246339},
	{"QBDA", 4, 246340},
	{"PRDI", 4, 246341},
	{"PKES", 4, 246342},
	{"PDRM", 4, 246343},
	{"OZYR", 4, 246344},
	{"OYEC", 4, 246345},
	{"OMCP", 4, 246346},
	{"OKLU", 4, 246347},
	{"OEGL", 4, 246348},
	{"ODJI", 4, 246349},
	{"NZAY", 4, 246350},
	{"NVSP", 4, 246351},
	{"NTKY", 4, 246352},
	{"NGPN", 4, 246353},
	{"MUJE", 4, 246354},
	{"MRIR", 4, 246355},
	{"MMCH", 4, 246356},
	{"MKUS", 4, 246357},
	{"MKLA", 4, 246358},
	{"MBHU", 4, 246359},
	{"LSJR", 4, 246360},
	{"LOVN", 4, 246361},
	{"LEZN", 4, 246362},
	{"LEBF", 4, 246363},
	{"KULW", 4, 246364},
	{"KTOZ", 4, 246365},
	{"JOUN", 4, 246366},
	{"JAXI", 4, 246367},
	{"JAWT", 4, 246368},
	{"IRMV", 4, 246369},
	{"IPHR", 4, 246370},
	{"IFGM", 4, 246371},
	{"GUSY", 4, 246372},
	{"FDEJ", 4, 246373},
	{"EWRT", 4, 246374},
	{"EVCL", 4, 246375},
	{"ESXX", 4, 246376},
	{"EKIY", 4, 246377},
	{"EEZW", 4, 246378},
	{"DKOF", 4, 246379},
	{"BPUS", 4, 246380},
	{"AKMR", 4, 246381},
	{"DOZY", 4, 246382},
	{"VLX", 3, 246383},
	{"VIDEOES", 7, 246384},
	{"TISSUS", 6, 246385},
	{"ENGLEFIELD", 10, 246386},
	{"PUCCINIA", 8, 246387},
	{"PERINATOLOGY", 12, 246388},
	{"FIRSTRAND", 9, 246389},
	{"SORTWARE", 8, 246390},
	{"MIAKA", 5, 246391},
	{"BOOTLEGGED", 10, 246392},
	{"CHENARD", 7, 246393},
	{"DRAGGER", 7, 246394},
	{"SCUBADIVING", 11, 246395},
	{"SAVOURING", 9, 246396},
	{"MISCAST", 7, 246397},
	{"MARQUET", 7, 246398},
	{"PALEMBANG", 9, 246399},
	{"PDCA", 4, 246400},
	{"NAVILIS", 7, 246401},
	{"MASL", 4, 246402},
	{"GREGOD", 6, 246403},
	{"TICKES", 6, 246404},
	{"STAMPLEY", 8, 246405},
	{"FANDOMS", 7, 246406},
	{"ZIRIN", 5, 246407},
	{"QUARTERMAN", 10, 246408},
	{"LARE", 4, 246409},
	{"INVITADO", 8, 246410},
	{"CAMPBELLFORD", 12, 246411},
	{"HYPERKINETIC", 12, 246412},
	{"CHEMIDPLUS", 10, 246413},
	{"RENTHAL", 7, 246414},
	{"MEDEX", 5, 246415},
	{"RECOMBINING", 11, 246416},
	{"RAISINGS", 8, 246417},
	{"PARGRES", 7, 246418},
	{"MOKUTI", 6, 246419},
	{"MICCO", 5, 246420},
	{"CATLETTSBURG", 12, 246421},
	{"SIVUN", 5, 246422},
	{"MICHELANGELI", 12, 246423},
	{"DEEJ", 4, 246424},
	{"BIOP", 4, 246425},
	{"TAMALA", 6, 246426},
	{"KOLYA", 5, 246427},
	{"KELVINGROVE", 11, 246428},
	{"ELEUTHERODACTYLUS", 17, 246429},
	{"APERS", 5, 246430},
	{"LINDAM", 6, 246431},
	{"ENCHANTS", 8, 246432},
	{"DEVELOPPER", 10, 246433},
	{"AMANDINE", 8, 246434},
	{"LIGHTINGELECTRICAL", 18, 246435},
	{"SPIRALIS", 8, 246436},
	{"FLOWERSTORE", 11, 246437},
	{"MAAP", 4, 246438},
	{"LIPIL", 5, 246439},
	{"ATTORNET", 8, 246440},
	{"DEADER", 6, 246441},
	{"PUBBLIC", 7, 246442},
	{"PETP", 4, 246443},
	{"SPFTWARE", 8, 246444},
	{"SOLVIL", 6, 246445},
	{"FLUIDE", 6, 246446},
	{"DUSTPAN", 7, 246447},
	{"TWENTYSOMETHINGS", 16, 246448},
	{"SESTAT", 6, 246449},
	{"EXPEDITER", 9, 246450},
	{"CASATI", 6, 246451},
	{"MORTGAGESECOND", 14, 246452},
	{"ORANGERIE", 9, 246453},
	{"DEPRESSIE", 9, 246454},
	{"DEVALUATIONS", 12, 246455},
	{"AUDIENCIA", 9, 246456},
	{"YAHOOOM", 7, 246457},
	{"IMPROVISER", 10, 246458},
	{"GROUNDSMAN", 10, 246459},
	{"ROCKCLIMBING", 12, 246460},
	{"NEWARD", 6, 246461},
	{"CIPAL", 5, 246462},
	{"ATTONREY", 8, 246463},
	{"PUSHPA", 6, 246464},
	{"JAYAPURA", 8, 246465},
	{"WILTZ", 5, 246466},
	{"WELF", 4, 246467},
	{"DURRES", 6, 246468},
	{"NONJUDGMENTAL", 13, 246469},
	{"DREDS", 5, 246470},
	{"SAIKI", 5, 246471},
	{"RPU", 3, 246472},
	{"INVISIONIZE", 11, 246473},
	{"WAWANESA", 8, 246474},
	{"SIPERIAN", 8, 246475},
	{"SOMEHTING", 9, 246476},
	{"SICURAMENTE", 11, 246477},
	{"OPENDOC", 7, 246478},
	{"SHIFA", 5, 246479},
	{"ANTONIETTA", 10, 246480},
	{"SPRAWLMARTS", 11, 246481},
	{"INTIMACIES", 10, 246482},
	{"DELICIAS", 8, 246483},
	{"WILDCRAFTED", 11, 246484},
	{"TRAMDOCK", 8, 246485},
	{"GUARDAMAR", 9, 246486},
	{"COUNS", 5, 246487},
	{"PRIVEE", 6, 246488},
	{"KRUGERSDORP", 11, 246489},
	{"REPUGS", 6, 246490},
	{"LEAMY", 5, 246491},
	{"CHUCKMAN", 8, 246492},
	{"BENZPHETAMINE", 13, 246493},
	{"REWINDERS", 9, 246494},
	{"GLINA", 5, 246495},
	{"SUCCEDED", 8, 246496},
	{"RASSEGNA", 8, 246497},
	{"HYDRASOFT", 9, 246498},
	{"UTTLESFORD", 10, 246499},
	{"UNDERGLAZE", 10, 246500},
	{"HOPPA", 5, 246501},
	{"USEFLASHLC", 10, 246502},
	{"DIMITRA", 7, 246503},
	{"OPIRG", 5, 246504},
	{"MATRIMONI", 9, 246505},
	{"EQUIMOLAR", 9, 246506},
	{"CPLR", 4, 246507},
	{"NEBULAS", 7, 246508},
	{"GWENER", 6, 246509},
	{"REDROOT", 7, 246510},
	{"POWERC", 6, 246511},
	{"CMML", 4, 246512},
	{"PELEM", 5, 246513},
	{"DUPCIE", 6, 246514},
	{"NORVEGI", 7, 246515},
	{"WINDBER", 7, 246516},
	{"SEREMBAN", 8, 246517},
	{"REMONSTRATED", 12, 246518},
	{"QUOTER", 6, 246519},
	{"ATTOREY", 7, 246520},
	{"WEATER", 6, 246521},
	{"ONSUBMIT", 8, 246522},
	{"LEICHTER", 8, 246523},
	{"BRAYING", 7, 246524},
	{"NUAGES", 6, 246525},
	{"DANCEY", 6, 246526},
	{"COOLPICKING", 11, 246527},
	{"NEWSHAM", 7, 246528},
	{"SPREP", 5, 246529},
	{"ELANTEC", 7, 246530},
	{"AURAN", 5, 246531},
	{"BUTLIN", 6, 246532},
	{"TELOSYS", 7, 246533},
	{"COPPIA", 6, 246534},
	{"CARFREE", 7, 246535},
	{"SAULI", 5, 246536},
	{"DESTINIA", 8, 246537},
	{"ALRITE", 6, 246538},
	{"SOUNDOFFS", 9, 246539},
	{"LASSITUDE", 9, 246540},
	{"SPRINGSIDE", 10, 246541},
	{"MUIZENBERG", 10, 246542},
	{"MSGBUFFER", 9, 246543},
	{"SUBWORD", 7, 246544},
	{"PASCRELL", 8, 246545},
	{"BLUET", 5, 246546},
	{"BEEDLE", 6, 246547},
	{"SAKAE", 5, 246548},
	{"ROUNDANDBROWN", 13, 246549},
	{"LOOKSTER", 8, 246550},
	{"CRAPTASTIC", 10, 246551},
	{"TESAR", 5, 246552},
	{"MAMY", 4, 246553},
	{"FREEB", 5, 246554},
	{"ATTRIBUTENAME", 13, 246555},
	{"ECKANKAR", 8, 246556},
	{"AUTOLIVE", 8, 246557},
	{"ELIZE", 5, 246558},
	{"BRIMHALL", 8, 246559},
	{"STRUTTURE", 9, 246560},
	{"SALLA", 5, 246561},
	{"POAG", 4, 246562},
	{"SUPERPACK", 9, 246563},
	{"PRENEED", 7, 246564},
	{"JOICE", 5, 246565},
	{"EMPTIVELY", 9, 246566},
	{"LTPS", 4, 246567},
	{"CASEYS", 6, 246568},
	{"TFLIGHT", 7, 246569},
	{"PRODUTTORI", 10, 246570},
	{"GRAFFIX", 7, 246571},
	{"BANEGA", 6, 246572},
	{"NONCLASSICAL", 12, 246573},
	{"NIUM", 4, 246574},
	{"IBEROAMERICANA", 14, 246575},
	{"HIDETAKA", 8, 246576},
	{"WYTE", 4, 246577},
	{"UNBINDING", 9, 246578},
	{"TRICHINOSIS", 11, 246579},
	{"INFRAGISTICS", 12, 246580},
	{"GYNGOR", 6, 246581},
	{"FIRETRUST", 9, 246582},
	{"YOCHAI", 6, 246583},
	{"HOLTEN", 6, 246584},
	{"XCLUSIVE", 8, 246585},
	{"MATICAL", 7, 246586},
	{"IMAGEABLEAREA", 13, 246587},
	{"ELSWICK", 7, 246588},
	{"YACHTSMEN", 9, 246589},
	{"REACQUAINTED", 12, 246590},
	{"LIVENGOOD", 9, 246591},
	{"KAAP", 4, 246592},
	{"JANOFSKY", 8, 246593},
	{"BLEE", 4, 246594},
	{"YOKOZUNA", 8, 246595},
	{"PRESSERS", 8, 246596},
	{"DULCIS", 6, 246597},
	{"CHIROMALL", 9, 246598},
	{"AKOMA", 5, 246599},
	{"PICTOGRAPH", 10, 246600},
	{"GIWRGOS", 7, 246601},
	{"NEUROPTERA", 10, 246602},
	{"CIGI", 4, 246603},
	{"CLOTHBOUND", 10, 246604},
	{"HAMWORTHY", 9, 246605},
	{"THUNNUS", 7, 246606},
	{"SALVARE", 7, 246607},
	{"RELEVANTLY", 10, 246608},
	{"MCCALLION", 9, 246609},
	{"FOXHUNTING", 10, 246610},
	{"ZURG", 4, 246611},
	{"ZRIV", 4, 246612},
	{"YSMD", 4, 246613},
	{"XYCA", 4, 246614},
	{"XSYN", 4, 246615},
	{"WWUS", 4, 246616},
	{"WSEF", 4, 246617},
	{"WNFC", 4, 246618},
	{"WMYG", 4, 246619},
	{"WLAI", 4, 246620},
	{"VSEL", 4, 246621},
	{"VMET", 4, 246622},
	{"VDSC", 4, 246623},
	{"UYGI", 4, 246624},
	{"UTVS", 4, 246625},
	{"UMQI", 4, 246626},
	{"TDRT", 4, 246627},
	{"SVPT", 4, 246628},
	{"SCSD", 4, 246629},
	{"RZUN", 4, 246630},
	{"RZOS", 4, 246631},
	{"RYDM", 4, 246632},
	{"RBTA", 4, 246633},
	{"OTCC", 4, 246634},
	{"OCIM", 4, 246635},
	{"NXPA", 4, 246636},
	{"NUOP", 4, 246637},
	{"NJPE", 4, 246638},
	{"NAYB", 4, 246639},
	{"MWWE", 4, 246640},
	{"MOMY", 4, 246641},
	{"MOMJ", 4, 246642},
	{"MIIM", 4, 246643},
	{"MHUI", 4, 246644},
	{"MEYH", 4, 246645},
	{"LUDH", 4, 246646},
	{"LILM", 4, 246647},
	{"LHYN", 4, 246648},
	{"LCHM", 4, 246649},
	{"LAMV", 4, 246650},
	{"KHOZ", 4, 246651},
	{"KFOS", 4, 246652},
	{"KEUL", 4, 246653},
	{"JRLE", 4, 246654},
	{"JREA", 4, 246655},
	{"JOCU", 4, 246656},
	{"JAHD", 4, 246657},
	{"IUNL", 4, 246658},
	{"ISLB", 4, 246659},
	{"IAZU", 4, 246660},
	{"HUMY", 4, 246661},
	{"HSKU", 4, 246662},
	{"HLUL", 4, 246663},
	{"HEZX", 4, 246664},
	{"HEJJ", 4, 246665},
	{"GLII", 4, 246666},
	{"GGBU", 4, 246667},
	{"FSYF", 4, 246668},
	{"FMSP", 4, 246669},
	{"FELR", 4, 246670},
	{"EZIF", 4, 246671},
	{"ESVC", 4, 246672},
	{"ELJF", 4, 246673},
	{"EKGU", 4, 246674},
	{"EHDC", 4, 246675},
	{"EAGB", 4, 246676},
	{"DXII", 4, 246677},
	{"DUTV", 4, 246678},
	{"DUML", 4, 246679},
	{"DTEK", 4, 246680},
	{"DJCO", 4, 246681},
	{"DCYA", 4, 246682},
	{"DAZT", 4, 246683},
	{"DAHC", 4, 246684},
	{"CTKO", 4, 246685},
	{"CREZ", 4, 246686},
	{"CBUC", 4, 246687},
	{"CAIW", 4, 246688},
	{"BYTC", 4, 246689},
	{"BOXJ", 4, 246690},
	{"BMIB", 4, 246691},
	{"BETG", 4, 246692},
	{"ARGM", 4, 246693},
	{"AQGO", 4, 246694},
	{"AKML", 4, 246695},
	{"POSTINFECTION", 13, 246696},
	{"ALPHACRAZE", 10, 246697},
	{"AHARONOV", 8, 246698},
	{"MUTUO", 5, 246699},
	{"RAILAY", 6, 246700},
	{"NACUBO", 6, 246701},
	{"BALUG", 5, 246702},
	{"HIDATSA", 7, 246703},
	{"SHEILDS", 7, 246704},
	{"LEIBNITZ", 8, 246705},
	{"GERMANWINGS", 11, 246706},
	{"BRONCHISEPTICA", 14, 246707},
	{"PROSO", 5, 246708},
	{"FEMORIS", 7, 246709},
	{"CAYES", 5, 246710},
	{"UNESCORTED", 10, 246711},
	{"JADWIN", 6, 246712},
	{"ATTRNEY", 7, 246713},
	{"SORPRESA", 8, 246714},
	{"ANOUNCED", 8, 246715},
	{"THUNDERCLAP", 11, 246716},
	{"PLINTHS", 7, 246717},
	{"HEERSCHER", 9, 246718},
	{"CAPELET", 7, 246719},
	{"VALIDEA", 7, 246720},
	{"LACSON", 6, 246721},
	{"BATTAILE", 8, 246722},
	{"VANDEVENTER", 11, 246723},
	{"JOVANOTTI", 9, 246724},
	{"HEATINGPLUMBING", 15, 246725},
	{"AMERICANISMS", 12, 246726},
	{"URZ", 3, 246727},
	{"SHORTLINE", 9, 246728},
	{"PERMISSIVENESS", 14, 246729},
	{"CAFODD", 6, 246730},
	{"GIRLACTIK", 9, 246731},
	{"DRUIDRY", 7, 246732},
	{"CHILDMUS", 8, 246733},
	{"SASAMI", 6, 246734},
	{"PHANOM", 6, 246735},
	{"GERSH", 5, 246736},
	{"EBAR", 4, 246737},
	{"AMBITIOUSLY", 11, 246738},
	{"PETSHOUSEHOLD", 13, 246739},
	{"MOONLESS", 8, 246740},
	{"ISLAMOFASCISTS", 14, 246741},
	{"COCCINELLE", 10, 246742},
	{"SAKET", 5, 246743},
	{"GROTTOS", 7, 246744},
	{"GIANLUIGI", 9, 246745},
	{"PHONIES", 7, 246746},
	{"FASTENERSHARDWARE", 17, 246747},
	{"DECORATEPAINT", 13, 246748},
	{"DALARNA", 7, 246749},
	{"SUNNEYDALE", 10, 246750},
	{"DIPEPTIDES", 10, 246751},
	{"KLEOPATRA", 9, 246752},
	{"WAGGENER", 8, 246753},
	{"STOIBER", 7, 246754},
	{"ROURKELA", 8, 246755},
	{"ROOTES", 6, 246756},
	{"BROOKVIEW", 9, 246757},
	{"ERNESTINA", 9, 246758},
	{"CHANGELESS", 10, 246759},
	{"PASTILLA", 8, 246760},
	{"NARDELLI", 8, 246761},
	{"IOSIF", 5, 246762},
	{"SAGELY", 6, 246763},
	{"PHILIPSON", 9, 246764},
	{"MAUNALOA", 8, 246765},
	{"DELENIT", 7, 246766},
	{"PAGEWISE", 8, 246767},
	{"HURTLED", 7, 246768},
	{"GEPOST", 6, 246769},
	{"BLINKSTOCK", 10, 246770},
	{"LPADMIN", 7, 246771},
	{"YACOLT", 6, 246772},
	{"SYNCTEST", 8, 246773},
	{"GEBIED", 6, 246774},
	{"BLAUW", 5, 246775},
	{"ACDBALIGNEDDIMENSION", 20, 246776},
	{"TRUMPF", 6, 246777},
	{"SPACY", 5, 246778},
	{"MASTERLOCK", 10, 246779},
	{"ADIPIC", 6, 246780},
	{"ROBICHEAUX", 10, 246781},
	{"GETCH", 5, 246782},
	{"CRESCENTUS", 10, 246783},
	{"LIFESTAGE", 9, 246784},
	{"MIDDLERD", 8, 246785},
	{"KREM", 4, 246786},
	{"UNFAVOURABLY", 12, 246787},
	{"MUSSON", 6, 246788},
	{"DICKSTEIN", 9, 246789},
	{"BYLO", 4, 246790},
	{"EDYTHE", 6, 246791},
	{"JACKEL", 6, 246792},
	{"REQUIP", 6, 246793},
	{"MOTORCITY", 9, 246794},
	{"MAWGAN", 6, 246795},
	{"INPADOC", 7, 246796},
	{"AKSU", 4, 246797},
	{"WFTU", 4, 246798},
	{"WAGMAN", 6, 246799},
	{"RNGS", 4, 246800},
	{"WORDSMITHS", 10, 246801},
	{"UNIFI", 5, 246802},
	{"GEOCODE", 7, 246803},
	{"CODMAN", 6, 246804},
	{"SQUAWKBOX", 9, 246805},
	{"IMMORTELLE", 10, 246806},
	{"ZEEBERG", 7, 246807},
	{"VALOROUS", 8, 246808},
	{"TPTL", 4, 246809},
	{"NASDAQSC", 8, 246810},
	{"HORIZREF", 8, 246811},
	{"RELATIF", 7, 246812},
	{"PLASTIQUES", 10, 246813},
	{"SIGILLI", 7, 246814},
	{"PARULA", 6, 246815},
	{"PUBLICITATE", 11, 246816},
	{"JOSSE", 5, 246817},
	{"GREIL", 5, 246818},
	{"ZWILLING", 8, 246819},
	{"DEHYDRO", 7, 246820},
	{"MERVILLE", 8, 246821},
	{"TINKLER", 7, 246822},
	{"DBMODELLER", 10, 246823},
	{"CHORDIANT", 9, 246824},
	{"JUSAGE", 6, 246825},
	{"VSTUDIO", 7, 246826},
	{"PAYSLIP", 7, 246827},
	{"STARNER", 7, 246828},
	{"RENEGING", 8, 246829},
	{"PEIERLS", 7, 246830},
	{"CORRI", 5, 246831},
	{"TREGARON", 8, 246832},
	{"LOUVIERE", 8, 246833},
	{"ELECTROBEL", 10, 246834},
	{"BUSDRIVER", 9, 246835},
	{"BOBBLES", 7, 246836},
	{"VALVING", 7, 246837},
	{"PTOWNSON", 8, 246838},
	{"PHENTERMNE", 10, 246839},
	{"BJR", 3, 246840},
	{"ALONDRA", 7, 246841},
	{"VIOBIN", 6, 246842},
	{"KISTNER", 7, 246843},
	{"ENDURABLE", 9, 246844},
	{"REORIENTING", 11, 246845},
	{"OVERAGES", 8, 246846},
	{"MERITAS", 7, 246847},
	{"RAMBERT", 7, 246848},
	{"LABILITY", 8, 246849},
	{"LEID", 4, 246850},
	{"COVERD", 6, 246851},
	{"LOUNG", 5, 246852},
	{"ZHUO", 4, 246853},
	{"OVERLIES", 8, 246854},
	{"GUILLEMOTS", 10, 246855},
	{"SPINET", 6, 246856},
	{"MCCARLEY", 8, 246857},
	{"PACKEN", 6, 246858},
	{"FPOS", 4, 246859},
	{"UCISA", 5, 246860},
	{"LAWBREAKERS", 11, 246861},
	{"JOYAS", 5, 246862},
	{"FARZAD", 6, 246863},
	{"MOMIJI", 6, 246864},
	{"KLENOW", 6, 246865},
	{"IMAGETEAM", 9, 246866},
	{"HAYMES", 6, 246867},
	{"CHARANGA", 8, 246868},
	{"CLDR", 4, 246869},
	{"VARVEL", 6, 246870},
	{"GESELL", 6, 246871},
	{"BEPPU", 5, 246872},
	{"ANCHETA", 7, 246873},
	{"NVOCC", 5, 246874},
	{"NATSIOS", 7, 246875},
	{"MURUGAN", 7, 246876},
	{"KILLERGRAM", 10, 246877},
	{"BOWELL", 6, 246878},
	{"BIRKENFELD", 10, 246879},
	{"ADLEMAN", 7, 246880},
	{"PEOMS", 5, 246881},
	{"HEDDLE", 6, 246882},
	{"AKTORKI", 7, 246883},
	{"ABORTIFACIENT", 13, 246884},
	{"IKONCODE", 8, 246885},
	{"BRIGHTHAND", 10, 246886},
	{"RTAG", 4, 246887},
	{"IMPERSONATED", 12, 246888},
	{"CLOUET", 6, 246889},
	{"CHIROFIND", 9, 246890},
	{"BREDASDORP", 10, 246891},
	{"AUTOSELECT", 10, 246892},
	{"ENGRAILED", 9, 246893},
	{"VELOCET", 7, 246894},
	{"DIATCHENKO", 10, 246895},
	{"BRAUDE", 6, 246896},
	{"KALACHAKRA", 10, 246897},
	{"TRIPHOSPHATASE", 14, 246898},
	{"ATTORMEY", 8, 246899},
	{"REALTRAVEL", 10, 246900},
	{"AFRIKANERS", 10, 246901},
	{"PROLIX", 6, 246902},
	{"POKRR", 5, 246903},
	{"EUGENOL", 7, 246904},
	{"UCCE", 4, 246905},
	{"MYCOOKINGBLOG", 13, 246906},
	{"YOSHIKAZU", 9, 246907},
	{"TICKETLINE", 10, 246908},
	{"CONJUNCTS", 9, 246909},
	{"BOYLH", 5, 246910},
	{"REBIF", 5, 246911},
	{"NCVS", 4, 246912},
	{"HORSTMAN", 8, 246913},
	{"DNIPRO", 6, 246914},
	{"BROADSPEED", 10, 246915},
	{"SAGAMI", 6, 246916},
	{"RUNKLE", 6, 246917},
	{"GRAZIELLA", 9, 246918},
	{"FEURIO", 6, 246919},
	{"COTANGENT", 9, 246920},
	{"AUTOLITE", 8, 246921},
	{"ATTORNYE", 8, 246922},
	{"ZEIC", 4, 246923},
	{"ZARF", 4, 246924},
	{"YPPT", 4, 246925},
	{"YOHM", 4, 246926},
	{"YLOE", 4, 246927},
	{"YJOG", 4, 246928},
	{"YAKM", 4, 246929},
	{"XSAM", 4, 246930},
	{"XARG", 4, 246931},
	{"WORY", 4, 246932},
	{"WETG", 4, 246933},
	{"WAJO", 4, 246934},
	{"VIWE", 4, 246935},
	{"VINZ", 4, 246936},
	{"VEOX", 4, 246937},
	{"VEKL", 4, 246938},
	{"UKUP", 4, 246939},
	{"UFIO", 4, 246940},
	{"TMBU", 4, 246941},
	{"SYCI", 4, 246942},
	{"SWAU", 4, 246943},
	{"STVD", 4, 246944},
	{"SNPM", 4, 246945},
	{"SBOZ", 4, 246946},
	{"RFDA", 4, 246947},
	{"REFD", 4, 246948},
	{"PSMR", 4, 246949},
	{"PNSP", 4, 246950},
	{"PIRL", 4, 246951},
	{"PDFT", 4, 246952},
	{"OLDX", 4, 246953},
	{"NYIG", 4, 246954},
	{"NHYG", 4, 246955},
	{"NHUY", 4, 246956},
	{"NDLM", 4, 246957},
	{"MRMR", 4, 246958},
	{"MJOK", 4, 246959},
	{"MCOG", 4, 246960},
	{"LYGM", 4, 246961},
	{"LUMJ", 4, 246962},
	{"LCHB", 4, 246963},
	{"KGLI", 4, 246964},
	{"JPIE", 4, 246965},
	{"INFF", 4, 246966},
	{"IFUE", 4, 246967},
	{"HVOY", 4, 246968},
	{"GSTV", 4, 246969},
	{"GRNE", 4, 246970},
	{"GEMF", 4, 246971},
	{"GDWA", 4, 246972},
	{"GDUL", 4, 246973},
	{"GALZ", 4, 246974},
	{"FOSB", 4, 246975},
	{"FMWE", 4, 246976},
	{"FCFR", 4, 246977},
	{"EXYW", 4, 246978},
	{"ERVB", 4, 246979},
	{"EPCF", 4, 246980},
	{"DRSR", 4, 246981},
	{"DNEF", 4, 246982},
	{"DFSY", 4, 246983},
	{"BAED", 4, 246984},
	{"AXWR", 4, 246985},
	{"AQPA", 4, 246986},
	{"APIB", 4, 246987},
	{"ACJA", 4, 246988},
	{"CURIUM", 6, 246989},
	{"APARTHOTELS", 11, 246990},
	{"SIDEBLOG", 8, 246991},
	{"NAVYBOOT", 8, 246992},
	{"SCOPS", 5, 246993},
	{"QUICKSET", 8, 246994},
	{"CONTINO", 7, 246995},
	{"SOUNDFX", 7, 246996},
	{"PYROPHOSPHORYLASE", 17, 246997},
	{"HELDS", 5, 246998},
	{"GROUPSYSTEMS", 12, 246999},
	{"LYU", 3, 247000},
	{"COLR", 4, 247001},
	{"BALAM", 5, 247002},
	{"PAKTRIBUNE", 10, 247003},
	{"MICHIGANUSA", 11, 247004},
	{"JMV", 3, 247005},
	{"TRESPASSED", 10, 247006},
	{"TONKINESE", 9, 247007},
	{"SFPUC", 5, 247008},
	{"MICROSWITCH", 11, 247009},
	{"BOLDFACED", 9, 247010},
	{"WILENTZ", 7, 247011},
	{"LIAISES", 7, 247012},
	{"INDIVIDUALIZING", 15, 247013},
	{"ADILT", 5, 247014},
	{"ACILITIES", 9, 247015},
	{"MOANALUA", 8, 247016},
	{"GEOCODED", 8, 247017},
	{"ALVAH", 5, 247018},
	{"TRACKDAY", 8, 247019},
	{"SHEWS", 5, 247020},
	{"LONGTEMPS", 9, 247021},
	{"CLAEYS", 6, 247022},
	{"REPUBL", 6, 247023},
	{"TALITY", 6, 247024},
	{"QUEDARME", 8, 247025},
	{"PETERED", 7, 247026},
	{"LUTENS", 6, 247027},
	{"DINARA", 6, 247028},
	{"TRAVELERMATCH", 13, 247029},
	{"PANTHEIST", 9, 247030},
	{"PAARMA", 6, 247031},
	{"SIDELONG", 8, 247032},
	{"PRINCIPALEMENT", 14, 247033},
	{"LIGNENDE", 8, 247034},
	{"BMCS", 4, 247035},
	{"PROXIMALLY", 10, 247036},
	{"MLSS", 4, 247037},
	{"LIMNOLOGICAL", 12, 247038},
	{"PARFUMES", 8, 247039},
	{"DEFENDAMERICA", 13, 247040},
	{"TURANGI", 7, 247041},
	{"THEREIS", 7, 247042},
	{"LORENZA", 7, 247043},
	{"GLYFADA", 7, 247044},
	{"SPORTSHIRTS", 11, 247045},
	{"SCHAAD", 6, 247046},
	{"CLAMORED", 8, 247047},
	{"YAFFA", 5, 247048},
	{"PROPIOS", 7, 247049},
	{"ASCARI", 6, 247050},
	{"TERRAE", 6, 247051},
	{"JINGOISM", 8, 247052},
	{"FELICIAN", 8, 247053},
	{"UNREALSCRIPT", 12, 247054},
	{"DICTIONNAIRES", 13, 247055},
	{"CYFLEUSTERAU", 12, 247056},
	{"BOZRAH", 6, 247057},
	{"CRUDEN", 6, 247058},
	{"PHACOEMULSIFICATION", 19, 247059},
	{"EINIGEN", 7, 247060},
	{"SUMERSAULT", 10, 247061},
	{"DEMEANED", 8, 247062},
	{"BABAJI", 6, 247063},
	{"UTGIVARE", 8, 247064},
	{"PROACTION", 9, 247065},
	{"INCARNATIONAL", 13, 247066},
	{"ROLLINGS", 8, 247067},
	{"CATEGORYLIST", 12, 247068},
	{"ZACCHAEUS", 9, 247069},
	{"GOTEL", 5, 247070},
	{"AKKAD", 5, 247071},
	{"SALAI", 5, 247072},
	{"AFTORNEY", 8, 247073},
	{"SUSSURRI", 8, 247074},
	{"STEENBURGEN", 11, 247075},
	{"KIPPAX", 6, 247076},
	{"JABBERWOCK", 10, 247077},
	{"HORNLESS", 8, 247078},
	{"EXTRAC", 6, 247079},
	{"OUTF", 4, 247080},
	{"MOGAMBO", 7, 247081},
	{"ADDOBSERVER", 11, 247082},
	{"FORMATGMTIME", 12, 247083},
	{"DEBUGS", 6, 247084},
	{"CHERNIGOV", 9, 247085},
	{"ATOTRNEY", 8, 247086},
	{"XTTORNEY", 8, 247087},
	{"VVF", 3, 247088},
	{"NORVIG", 6, 247089},
	{"FIESTY", 6, 247090},
	{"BELLEAU", 7, 247091},
	{"SCHEDULABILITY", 14, 247092},
	{"LIBMISC", 7, 247093},
	{"IBRARY", 6, 247094},
	{"DAVEZILLA", 9, 247095},
	{"WORKINGFORCHANGE", 16, 247096},
	{"MAKOSI", 6, 247097},
	{"SALLEH", 6, 247098},
	{"HEXDUMP", 7, 247099},
	{"DEUDA", 5, 247100},
	{"CHIMELIS", 8, 247101},
	{"ATTOENEY", 8, 247102},
	{"KROKUS", 6, 247103},
	{"AYTES", 5, 247104},
	{"MXODBC", 6, 247105},
	{"BRUSS", 5, 247106},
	{"ATTOTNEY", 8, 247107},
	{"BRIZO", 5, 247108},
	{"ATTORNRY", 8, 247109},
	{"ZARKO", 5, 247110},
	{"SIROL", 5, 247111},
	{"CITIGATE", 8, 247112},
	{"HALACHAH", 8, 247113},
	{"ALIANTE", 7, 247114},
	{"TOMOLLO", 7, 247115},
	{"AVEYRON", 7, 247116},
	{"ARTORNEY", 8, 247117},
	{"VEDEO", 5, 247118},
	{"URBANISED", 9, 247119},
	{"DISPOS", 6, 247120},
	{"GENETESTS", 9, 247121},
	{"PROPELLOR", 9, 247122},
	{"NUIC", 4, 247123},
	{"FRONTIERE", 9, 247124},
	{"WAQF", 4, 247125},
	{"STARPORT", 8, 247126},
	{"IMPOVE", 6, 247127},
	{"HADRIEN", 7, 247128},
	{"CHILIDOG", 8, 247129},
	{"SOUTHWATER", 10, 247130},
	{"CONGRESSI", 9, 247131},
	{"ATTIRNEY", 8, 247132},
	{"CHOLANGIOGRAPHY", 15, 247133},
	{"INPIRATIONAL", 12, 247134},
	{"BUBINGA", 7, 247135},
	{"NEGRIN", 6, 247136},
	{"SCHELDT", 7, 247137},
	{"SCATTERER", 9, 247138},
	{"PROJECTEUR", 10, 247139},
	{"PERTE", 5, 247140},
	{"GOONER", 6, 247141},
	{"BERMEJO", 7, 247142},
	{"SUAZO", 5, 247143},
	{"GARAVANI", 8, 247144},
	{"WINGARD", 7, 247145},
	{"UESHIBA", 7, 247146},
	{"MIFFLINTOWN", 11, 247147},
	{"EXEMPLO", 7, 247148},
	{"DEFORMS", 7, 247149},
	{"BLACKWORK", 9, 247150},
	{"ALSUP", 5, 247151},
	{"SOUHAITEZ", 9, 247152},
	{"LORR", 4, 247153},
	{"UNIGAMES", 8, 247154},
	{"SUPPLIMENT", 10, 247155},
	{"REARMAMENT", 10, 247156},
	{"IDIOSYNCRASY", 12, 247157},
	{"NUDEBOYZ", 8, 247158},
	{"NARRA", 5, 247159},
	{"DUALTONE", 8, 247160},
	{"DECIS", 5, 247161},
	{"VOLPI", 5, 247162},
	{"ATTPRNEY", 8, 247163},
	{"YENROTTA", 8, 247164},
	{"XYLOPHONES", 10, 247165},
	{"RUBISCO", 7, 247166},
	{"ENEFITS", 7, 247167},
	{"AYTORNEY", 8, 247168},
	{"ATTORNEJ", 8, 247169},
	{"NODDERS", 7, 247170},
	{"JUELICH", 7, 247171},
	{"ESSLINGEN", 9, 247172},
	{"NEBRASKAN", 9, 247173},
	{"CAZENOVE", 8, 247174},
	{"ATTORHEY", 8, 247175},
	{"REPUBLI", 7, 247176},
	{"ATTORBEY", 8, 247177},
	{"ATTOFNEY", 8, 247178},
	{"WILMOTH", 7, 247179},
	{"SECUNDUS", 8, 247180},
	{"MICROGRAFX", 10, 247181},
	{"MEALYBUG", 8, 247182},
	{"MARZIO", 6, 247183},
	{"JOYRIDES", 8, 247184},
	{"POPPLETON", 9, 247185},
	{"WAITLEY", 7, 247186},
	{"GAMOW", 5, 247187},
	{"DODAAC", 6, 247188},
	{"PENTOXIDE", 9, 247189},
	{"CHOLIS", 6, 247190},
	{"CLUCKING", 8, 247191},
	{"GETSTATUS", 9, 247192},
	{"ADJANI", 6, 247193},
	{"GLAUBE", 6, 247194},
	{"ATTORNSY", 8, 247195},
	{"ATTLRNEY", 8, 247196},
	{"PROHORMONE", 10, 247197},
	{"BAGPIPER", 8, 247198},
	{"ATTORNWY", 8, 247199},
	{"ATTORNEU", 8, 247200},
	{"ATTORNEH", 8, 247201},
	{"ATTORJEY", 8, 247202},
	{"AGTORNEY", 8, 247203},
	{"SCHOOLAGE", 9, 247204},
	{"ATTORNEG", 8, 247205},
	{"ASSOUS", 6, 247206},
	{"ARNCLIFFE", 9, 247207},
	{"LONGPORT", 8, 247208},
	{"BAEDEKER", 8, 247209},
	{"ADMINISTRATIF", 13, 247210},
	{"PROSPAQEIA", 10, 247211},
	{"NINTENDODS", 10, 247212},
	{"ATTKRNEY", 8, 247213},
	{"RIECK", 5, 247214},
	{"LIDSTROM", 8, 247215},
	{"CHANNELADVISOR", 14, 247216},
	{"NANOMETRICS", 11, 247217},
	{"GRANISLE", 8, 247218},
	{"SMIDGE", 6, 247219},
	{"PADOVAN", 7, 247220},
	{"COAGULATED", 10, 247221},
	{"PHAKT", 5, 247222},
	{"KALLAS", 6, 247223},
	{"BANQUO", 6, 247224},
	{"ALTRES", 6, 247225},
	{"MEGHNA", 6, 247226},
	{"DABSVALUE", 9, 247227},
	{"ATTOWNEY", 8, 247228},
	{"ATTOGNEY", 8, 247229},
	{"ZYNE", 4, 247230},
	{"ZEMP", 4, 247231},
	{"ZDRA", 4, 247232},
	{"YSDY", 4, 247233},
	{"YNVI", 4, 247234},
	{"YENQ", 4, 247235},
	{"YDRL", 4, 247236},
	{"YDHI", 4, 247237},
	{"XSCI", 4, 247238},
	{"XIVT", 4, 247239},
	{"WNIP", 4, 247240},
	{"WCOH", 4, 247241},
	{"WABY", 4, 247242},
	{"VUTH", 4, 247243},
	{"VNDB", 4, 247244},
	{"VDMO", 4, 247245},
	{"URCK", 4, 247246},
	{"UNKV", 4, 247247},
	{"UDDB", 4, 247248},
	{"UBSJ", 4, 247249},
	{"TYIV", 4, 247250},
	{"TVAB", 4, 247251},
	{"SYTY", 4, 247252},
	{"SLBE", 4, 247253},
	{"SDDA", 4, 247254},
	{"RYDW", 4, 247255},
	{"POKH", 4, 247256},
	{"POEP", 4, 247257},
	{"PBSO", 4, 247258},
	{"OBSV", 4, 247259},
	{"OBGY", 4, 247260},
	{"NSCM", 4, 247261},
	{"NPUF", 4, 247262},
	{"NMFO", 4, 247263},
	{"NIVP", 4, 247264},
	{"NGXP", 4, 247265},
	{"MYAA", 4, 247266},
	{"MWEF", 4, 247267},
	{"MVST", 4, 247268},
	{"MTVO", 4, 247269},
	{"MREO", 4, 247270},
	{"MREK", 4, 247271},
	{"LYLL", 4, 247272},
	{"LMVA", 4, 247273},
	{"KHTU", 4, 247274},
	{"KDUO", 4, 247275},
	{"JCHO", 4, 247276},
	{"IULT", 4, 247277},
	{"ICZH", 4, 247278},
	{"IBFO", 4, 247279},
	{"HKAK", 4, 247280},
	{"GXUA", 4, 247281},
	{"GIFC", 4, 247282},
	{"GDAF", 4, 247283},
	{"FMRW", 4, 247284},
	{"FMDI", 4, 247285},
	{"FIOF", 4, 247286},
	{"FFSV", 4, 247287},
	{"EWRC", 4, 247288},
	{"EUDF", 4, 247289},
	{"ESKG", 4, 247290},
	{"ERVD", 4, 247291},
	{"EGLC", 4, 247292},
	{"EAYL", 4, 247293},
	{"DCFA", 4, 247294},
	{"CAFG", 4, 247295},
	{"BUNJ", 4, 247296},
	{"BRDE", 4, 247297},
	{"BHAU", 4, 247298},
	{"BBBO", 4, 247299},
	{"BAIY", 4, 247300},
	{"AZUB", 4, 247301},
	{"AWYA", 4, 247302},
	{"AWLF", 4, 247303},
	{"SBCYAHOO", 8, 247304},
	{"NONINFECTIOUS", 13, 247305},
	{"LIBMAIL", 7, 247306},
	{"ATTORNFY", 8, 247307},
	{"AHTORNEY", 8, 247308},
	{"LEVATOR", 7, 247309},
	{"HRUSKA", 6, 247310},
	{"ELMARIT", 7, 247311},
	{"ATTORKEY", 8, 247312},
	{"ATTORGEY", 8, 247313},
	{"QUIGG", 5, 247314},
	{"FECS", 4, 247315},
	{"CHILDLIFE", 9, 247316},
	{"ROSOFT", 6, 247317},
	{"LTHOUGH", 7, 247318},
	{"KRIER", 5, 247319},
	{"HALAKHIC", 8, 247320},
	{"GARANCE", 7, 247321},
	{"CALLISTER", 9, 247322},
	{"BAECHLE", 7, 247323},
	{"STANIS", 6, 247324},
	{"PICKNICK", 8, 247325},
	{"LADISMITH", 9, 247326},
	{"LITUANIA", 8, 247327},
	{"BENTLEYVILLE", 12, 247328},
	{"WALM", 4, 247329},
	{"SERVEIS", 7, 247330},
	{"LABA", 4, 247331},
	{"GIGOT", 5, 247332},
	{"SOFTEE", 6, 247333},
	{"CLEOMENES", 9, 247334},
	{"CEEDS", 5, 247335},
	{"MULTIBODY", 9, 247336},
	{"JSONLINE", 8, 247337},
	{"PATRAN", 6, 247338},
	{"GOSNELLS", 8, 247339},
	{"KOGO", 4, 247340},
	{"LORCAN", 6, 247341},
	{"FEENY", 5, 247342},
	{"CUALQUIERA", 10, 247343},
	{"MOUTHGUARDS", 11, 247344},
	{"ETHEKWINI", 9, 247345},
	{"FLUNO", 5, 247346},
	{"NAILL", 5, 247347},
	{"DEPOSING", 8, 247348},
	{"CODGER", 6, 247349},
	{"VENTERS", 7, 247350},
	{"SAUERLAND", 9, 247351},
	{"SPITAL", 6, 247352},
	{"REARRESTED", 10, 247353},
	{"FLOBO", 5, 247354},
	{"FIACCO", 6, 247355},
	{"FILEBROWSER", 11, 247356},
	{"BACHAND", 7, 247357},
	{"WATERTHRUSH", 11, 247358},
	{"GEOREFERENCING", 14, 247359},
	{"GTOP", 4, 247360},
	{"CHEMS", 5, 247361},
	{"TIKKERS", 7, 247362},
	{"NYCLIFE", 7, 247363},
	{"DONJON", 6, 247364},
	{"CONAIRPHONE", 11, 247365},
	{"AUTONUMBER", 10, 247366},
	{"SUGITA", 6, 247367},
	{"ROMAR", 5, 247368},
	{"MESSIEURS", 9, 247369},
	{"MGK", 3, 247370},
	{"ATGET", 5, 247371},
	{"SELUES", 6, 247372},
	{"GOUTTE", 6, 247373},
	{"WATERWISE", 9, 247374},
	{"ROLOFF", 6, 247375},
	{"POSTRES", 7, 247376},
	{"NAWK", 4, 247377},
	{"MONTANER", 8, 247378},
	{"UMOJA", 5, 247379},
	{"TIFFANIE", 8, 247380},
	{"LEVET", 5, 247381},
	{"GIGUE", 5, 247382},
	{"FINIAN", 6, 247383},
	{"BESR", 4, 247384},
	{"LIFSCHITZ", 9, 247385},
	{"HACHEM", 6, 247386},
	{"PBIOPAGE", 8, 247387},
	{"HIROKAWA", 8, 247388},
	{"FRONTO", 6, 247389},
	{"RIER", 4, 247390},
	{"HALITE", 6, 247391},
	{"EPICONDYLITIS", 13, 247392},
	{"EFFANBEE", 8, 247393},
	{"ZANSKAR", 7, 247394},
	{"COGNITO", 7, 247395},
	{"CALZAGHE", 8, 247396},
	{"SENATUS", 7, 247397},
	{"HODGEMAN", 8, 247398},
	{"TRANENT", 7, 247399},
	{"LIENAU", 6, 247400},
	{"PTIME", 5, 247401},
	{"JUNCEA", 6, 247402},
	{"HOKURIKU", 8, 247403},
	{"DINAMIC", 7, 247404},
	{"ANANTAPUR", 9, 247405},
	{"PERRYSVILLE", 11, 247406},
	{"OSAKI", 5, 247407},
	{"TINUES", 6, 247408},
	{"SILJA", 5, 247409},
	{"NEWITZ", 6, 247410},
	{"CHEANEY", 7, 247411},
	{"BLECK", 5, 247412},
	{"MASCALZONATE", 12, 247413},
	{"TREMENS", 7, 247414},
	{"ACCLIVITY", 9, 247415},
	{"WAFF", 4, 247416},
	{"TREMONTON", 9, 247417},
	{"POMPONS", 7, 247418},
	{"MISALLOCATION", 13, 247419},
	{"BISECTOR", 8, 247420},
	{"STOYKITE", 8, 247421},
	{"ZERNIKE", 7, 247422},
	{"MODUCARE", 8, 247423},
	{"FERLINGHETTI", 12, 247424},
	{"RUPPRECHT", 9, 247425},
	{"KHADR", 5, 247426},
	{"EXCLUSIVAMENTE", 14, 247427},
	{"QUARTOS", 7, 247428},
	{"LJC", 3, 247429},
	{"KIRKSTALL", 9, 247430},
	{"HOUSEL", 6, 247431},
	{"GWYE", 4, 247432},
	{"TIOUS", 5, 247433},
	{"SPECIFIY", 8, 247434},
	{"SCRAPBOOKER", 11, 247435},
	{"YUKAI", 5, 247436},
	{"WISHARD", 7, 247437},
	{"IKARIA", 6, 247438},
	{"SPRU", 4, 247439},
	{"ODMG", 4, 247440},
	{"MINITOTS", 8, 247441},
	{"CARAMBOLA", 9, 247442},
	{"YAZAKI", 6, 247443},
	{"PRUNEDALE", 9, 247444},
	{"PEABO", 5, 247445},
	{"MERKEY", 6, 247446},
	{"COMITATO", 8, 247447},
	{"TUMERIC", 7, 247448},
	{"RODBOOMBOOM", 11, 247449},
	{"EVONNE", 6, 247450},
	{"YAMAL", 5, 247451},
	{"LUMMIS", 6, 247452},
	{"EPLICA", 6, 247453},
	{"WEBITE", 6, 247454},
	{"DGNEWS", 6, 247455},
	{"BLACKEY", 7, 247456},
	{"MONTEMAYOR", 10, 247457},
	{"TRAVERSABLE", 11, 247458},
	{"SCHWYZER", 8, 247459},
	{"CYPROHEPTADINE", 14, 247460},
	{"CADORE", 6, 247461},
	{"SUNDRE", 6, 247462},
	{"KLAW", 4, 247463},
	{"SEDIA", 5, 247464},
	{"PISSER", 6, 247465},
	{"ABSTRACTOR", 10, 247466},
	{"PROTECCION", 10, 247467},
	{"DIQUAT", 6, 247468},
	{"BIGIRON", 7, 247469},
	{"PHASELLUS", 9, 247470},
	{"MAGNETOSTRICTIVE", 16, 247471},
	{"HEARTWORMS", 10, 247472},
	{"TURISTICO", 9, 247473},
	{"NETLINKS", 8, 247474},
	{"BIRDSBORO", 9, 247475},
	{"POLTICAL", 8, 247476},
	{"DATAFEEDS", 9, 247477},
	{"APPLESCRIPTS", 12, 247478},
	{"WORKINGMEN", 10, 247479},
	{"LODOVICO", 8, 247480},
	{"KYNAR", 5, 247481},
	{"KLINGLER", 8, 247482},
	{"STRANIERI", 9, 247483},
	{"SCHWABACHER", 11, 247484},
	{"PORAT", 5, 247485},
	{"JUSTOFFBASE", 11, 247486},
	{"IDLEAIRE", 8, 247487},
	{"EBANO", 5, 247488},
	{"COOLLIST", 8, 247489},
	{"WURTZEL", 7, 247490},
	{"STERILISING", 11, 247491},
	{"SIGLA", 5, 247492},
	{"RATJADA", 7, 247493},
	{"FASYNCHRONOUS", 13, 247494},
	{"UNREDUCED", 9, 247495},
	{"KIDDPEAT", 8, 247496},
	{"FASTRAK", 7, 247497},
	{"DSIG", 4, 247498},
	{"AMARIN", 6, 247499},
	{"TUNARE", 6, 247500},
	{"NEIGHBORWORKS", 13, 247501},
	{"MRAIBLE", 7, 247502},
	{"LAURER", 6, 247503},
	{"KIMBRELL", 8, 247504},
	{"BONESET", 7, 247505},
	{"FLOGGERS", 8, 247506},
	{"ADDITON", 7, 247507},
	{"CHLORINATORS", 12, 247508},
	{"VREDENBURG", 10, 247509},
	{"POUTS", 5, 247510},
	{"CORBIJN", 7, 247511},
	{"BARRAZA", 7, 247512},
	{"ROLLERSKATING", 13, 247513},
	{"BLUEWAVE", 8, 247514},
	{"ALIMENTAIRES", 12, 247515},
	{"JORDYN", 6, 247516},
	{"HOGANS", 6, 247517},
	{"CLOTHESPIN", 10, 247518},
	{"ADRIVER", 7, 247519},
	{"OCEANPORT", 9, 247520},
	{"DIGGLER", 7, 247521},
	{"BOXPLOT", 7, 247522},
	{"RUARK", 5, 247523},
	{"MEHLHORN", 8, 247524},
	{"LIMTED", 6, 247525},
	{"HOTELW", 6, 247526},
	{"FRIGILIANA", 10, 247527},
	{"ACURATE", 7, 247528},
	{"FRESCOBALDI", 11, 247529},
	{"CONCURSOS", 9, 247530},
	{"SUPERMOD", 8, 247531},
	{"RIOTED", 6, 247532},
	{"BIOIMAGES", 9, 247533},
	{"SHEETMUSICPLUS", 14, 247534},
	{"CORRALITOS", 10, 247535},
	{"CITRATES", 8, 247536},
	{"GERSTEN", 7, 247537},
	{"TORRUS", 6, 247538},
	{"FRANSON", 7, 247539},
	{"CORALIFE", 8, 247540},
	{"DJL", 3, 247541},
	{"CHLA", 4, 247542},
	{"CEVO", 4, 247543},
	{"AXWELL", 6, 247544},
	{"KREGER", 6, 247545},
	{"CECILIO", 7, 247546},
	{"OTHING", 6, 247547},
	{"ACTIVECAMPUS", 12, 247548},
	{"WRAB", 4, 247549},
	{"WLUX", 4, 247550},
	{"WBUF", 4, 247551},
	{"WADW", 4, 247552},
	{"VTOG", 4, 247553},
	{"UXEA", 4, 247554},
	{"UDJU", 4, 247555},
	{"TRUZ", 4, 247556},
	{"TRPG", 4, 247557},
	{"TOKD", 4, 247558},
	{"SMPI", 4, 247559},
	{"SKGL", 4, 247560},
	{"SCUH", 4, 247561},
	{"RYLJ", 4, 247562},
	{"RSRD", 4, 247563},
	{"PYVI", 4, 247564},
	{"PPBY", 4, 247565},
	{"PGTO", 4, 247566},
	{"PFTH", 4, 247567},
	{"NZCH", 4, 247568},
	{"NWWF", 4, 247569},
	{"NSPF", 4, 247570},
	{"NPPM", 4, 247571},
	{"NABW", 4, 247572},
	{"MVAT", 4, 247573},
	{"MUHI", 4, 247574},
	{"MJAV", 4, 247575},
	{"MHOD", 4, 247576},
	{"LUWO", 4, 247577},
	{"LOLC", 4, 247578},
	{"LKFL", 4, 247579},
	{"LAVD", 4, 247580},
	{"HIDP", 4, 247581},
	{"GPIK", 4, 247582},
	{"GCYP", 4, 247583},
	{"FHTM", 4, 247584},
	{"FAZU", 4, 247585},
	{"FAPC", 4, 247586},
	{"EVYV", 4, 247587},
	{"ESVP", 4, 247588},
	{"EFQU", 4, 247589},
	{"EBNG", 4, 247590},
	{"EBJU", 4, 247591},
	{"DZAL", 4, 247592},
	{"DYUC", 4, 247593},
	{"DWOB", 4, 247594},
	{"DOSQ", 4, 247595},
	{"DMUI", 4, 247596},
	{"DHPR", 4, 247597},
	{"CPTO", 4, 247598},
	{"CKZO", 4, 247599},
	{"BYHR", 4, 247600},
	{"BYAX", 4, 247601},
	{"BUGP", 4, 247602},
	{"BOEV", 4, 247603},
	{"BEFF", 4, 247604},
	{"AYEZ", 4, 247605},
	{"AJBA", 4, 247606},
	{"ACSG", 4, 247607},
	{"ABRC", 4, 247608},
	{"WHILEY", 6, 247609},
	{"PRAETORIUS", 10, 247610},
	{"LOOKIT", 6, 247611},
	{"KORNBLUTH", 9, 247612},
	{"CASCATA", 7, 247613},
	{"LORANE", 6, 247614},
	{"LIEFER", 6, 247615},
	{"KOPIEREN", 8, 247616},
	{"DEBEERS", 7, 247617},
	{"ASGC", 4, 247618},
	{"AMEMIYA", 7, 247619},
	{"PENNSBURY", 9, 247620},
	{"OCASION", 7, 247621},
	{"AEROPORTI", 9, 247622},
	{"COMMIN", 6, 247623},
	{"WBU", 3, 247624},
	{"THARPE", 6, 247625},
	{"SHANTYTOWN", 10, 247626},
	{"NESHANIC", 8, 247627},
	{"LYRI", 4, 247628},
	{"BUSHIE", 6, 247629},
	{"BRIGHTPOINT", 11, 247630},
	{"CONYNGHAM", 9, 247631},
	{"ARRLDX", 6, 247632},
	{"POSTATO", 7, 247633},
	{"SHENMEN", 7, 247634},
	{"SEIGO", 5, 247635},
	{"SCRUTINIZES", 11, 247636},
	{"PRIMATIVE", 9, 247637},
	{"DNTPS", 5, 247638},
	{"CYBERSTALKING", 13, 247639},
	{"CURTICE", 7, 247640},
	{"PALENESS", 8, 247641},
	{"LINECARD", 8, 247642},
	{"GALLEYCAT", 9, 247643},
	{"FRIEDHELM", 9, 247644},
	{"FAXMAIL", 7, 247645},
	{"VITROS", 6, 247646},
	{"MARGARETT", 9, 247647},
	{"YLIGHTING", 9, 247648},
	{"ULTRABEAT", 9, 247649},
	{"SAMPLERATE", 10, 247650},
	{"NETWORKINGFORPROS", 17, 247651},
	{"HASSEN", 6, 247652},
	{"GROVELING", 9, 247653},
	{"ALKYNES", 7, 247654},
	{"DEIDRA", 6, 247655},
	{"ANATIDAE", 8, 247656},
	{"WESTAIR", 7, 247657},
	{"SEARCHIRC", 9, 247658},
	{"SEBL", 4, 247659},
	{"RYALS", 5, 247660},
	{"ESMERELDA", 9, 247661},
	{"LIBGGI", 6, 247662},
	{"JOHNL", 5, 247663},
	{"DEFNYDDIWCH", 11, 247664},
	{"CYDOOR", 6, 247665},
	{"GRPPHA", 6, 247666},
	{"CHEAPY", 6, 247667},
	{"SMAILUS", 7, 247668},
	{"INTERF", 6, 247669},
	{"CLEARAUDIO", 10, 247670},
	{"MECENAT", 7, 247671},
	{"MADY", 4, 247672},
	{"LINCON", 6, 247673},
	{"JAROME", 6, 247674},
	{"ETAPE", 5, 247675},
	{"AYUTHAYA", 8, 247676},
	{"WWM", 3, 247677},
	{"FESTEN", 6, 247678},
	{"CHANDU", 6, 247679},
	{"CAMANCHE", 8, 247680},
	{"BUNDS", 5, 247681},
	{"BULGA", 5, 247682},
	{"VANESA", 6, 247683},
	{"STROCK", 6, 247684},
	{"THISDAY", 7, 247685},
	{"JCREATOR", 8, 247686},
	{"DUBY", 4, 247687},
	{"TOPGEAR", 7, 247688},
	{"ROCKEUROPOPEXPERIMENTAL", 23, 247689},
	{"PYTHIAS", 7, 247690},
	{"KLAM", 4, 247691},
	{"FRAMEFINDER", 11, 247692},
	{"OLAFUR", 6, 247693},
	{"NATURALIZING", 12, 247694},
	{"MENUETTO", 8, 247695},
	{"JEUGD", 5, 247696},
	{"WWWASIAN", 8, 247697},
	{"GAMBOL", 6, 247698},
	{"LIBEXTRACTOR", 12, 247699},
	{"ISSOCIATE", 9, 247700},
	{"HUNDERTWASSER", 13, 247701},
	{"BAWTRY", 6, 247702},
	{"YEDIOT", 6, 247703},
	{"BIGMOUTH", 8, 247704},
	{"WMX", 3, 247705},
	{"THOUROUGHLY", 11, 247706},
	{"TECPLOT", 7, 247707},
	{"SMOLINSKI", 9, 247708},
	{"ERRA", 4, 247709},
	{"CHELIOS", 7, 247710},
	{"ALACK", 5, 247711},
	{"PERMALINKTUESDAY", 16, 247712},
	{"FRIJOLES", 8, 247713},
	{"WAGNERIAN", 9, 247714},
	{"KEYWEST", 7, 247715},
	{"GROOME", 6, 247716},
	{"REPLCA", 6, 247717},
	{"COMPARTMENTATION", 16, 247718},
	{"BISSE", 5, 247719},
	{"PITER", 5, 247720},
	{"YOSHIRO", 7, 247721},
	{"YELEY", 5, 247722},
	{"RUDNICKI", 8, 247723},
	{"LOMIRA", 6, 247724},
	{"BROTHAS", 7, 247725},
	{"MAXILLOFAC", 10, 247726},
	{"DESKBOOK", 8, 247727},
	{"PSOAS", 5, 247728},
	{"JERALYN", 7, 247729},
	{"SOCIOPATHS", 10, 247730},
	{"ISFOCUSCYCLEROOT", 16, 247731},
	{"MELMAC", 6, 247732},
	{"MAESTAS", 7, 247733},
	{"BRAUDEL", 7, 247734},
	{"TRIVIALITIES", 12, 247735},
	{"TRISTESSE", 9, 247736},
	{"SCORT", 5, 247737},
	{"MIAOW", 5, 247738},
	{"FENNY", 5, 247739},
	{"MAGZINE", 7, 247740},
	{"GOOL", 4, 247741},
	{"DISCOURTEOUS", 12, 247742},
	{"ANASTOMOTIC", 11, 247743},
	{"SIECUS", 6, 247744},
	{"NANODEVICES", 11, 247745},
	{"GAREN", 5, 247746},
	{"FARNDON", 7, 247747},
	{"EASTFORD", 8, 247748},
	{"PRECIOGASOLINA", 14, 247749},
	{"NIVISON", 7, 247750},
	{"KEYERS", 6, 247751},
	{"SEARCHABILITY", 13, 247752},
	{"CRYSTALTECH", 11, 247753},
	{"COLLATIONS", 10, 247754},
	{"SAMSONOV", 8, 247755},
	{"ONOMA", 5, 247756},
	{"LNBF", 4, 247757},
	{"LIBSELINUX", 10, 247758},
	{"KENGO", 5, 247759},
	{"HELPCARD", 8, 247760},
	{"DIMNESS", 7, 247761},
	{"CRISTOFORO", 10, 247762},
	{"RISIBLE", 7, 247763},
	{"HOLBECK", 7, 247764},
	{"PROSERIES", 9, 247765},
	{"ONLINEID", 8, 247766},
	{"PROWAZEKII", 10, 247767},
	{"ANTISUBMARINE", 13, 247768},
	{"INTELLISPACE", 12, 247769},
	{"NETCENTREX", 10, 247770},
	{"MATRIZ", 6, 247771},
	{"DEVIA", 5, 247772},
	{"PLSC", 4, 247773},
	{"WARUNKI", 7, 247774},
	{"PIEMONTESE", 10, 247775},
	{"READELF", 7, 247776},
	{"PSYCHOSOM", 9, 247777},
	{"MAINLINES", 9, 247778},
	{"BREEDINGS", 9, 247779},
	{"NAVTEX", 6, 247780},
	{"LIZED", 5, 247781},
	{"ARUCH", 5, 247782},
	{"ULTREX", 6, 247783},
	{"DRIPPER", 7, 247784},
	{"TRUBY", 5, 247785},
	{"DEMAINE", 7, 247786},
	{"ACCENTUATION", 12, 247787},
	{"WINAMAC", 7, 247788},
	{"MADRI", 5, 247789},
	{"HPDC", 4, 247790},
	{"GOOHLE", 6, 247791},
	{"RAKOFF", 6, 247792},
	{"MAED", 4, 247793},
	{"IFSTREAM", 8, 247794},
	{"GRENNAN", 7, 247795},
	{"CYPRAEA", 7, 247796},
	{"TSUBAKI", 7, 247797},
	{"MAINTOUR", 8, 247798},
	{"BIOMEDIC", 8, 247799},
	{"AUTOMA", 6, 247800},
	{"TTLWHKR", 7, 247801},
	{"RAVIV", 5, 247802},
	{"GSCI", 4, 247803},
	{"DECLARACION", 11, 247804},
	{"BLENDIMAGES", 11, 247805},
	{"SEMIMONTHLY", 11, 247806},
	{"PURSELL", 7, 247807},
	{"ELROHIR", 7, 247808},
	{"BRONSKI", 7, 247809},
	{"SEARCHCOMMERCIAL", 16, 247810},
	{"ESCHEAT", 7, 247811},
	{"OXIDIZES", 8, 247812},
	{"LENDERBAD", 9, 247813},
	{"ERINN", 5, 247814},
	{"AEROGELS", 8, 247815},
	{"VICTOIRES", 9, 247816},
	{"KHANS", 5, 247817},
	{"DACHARY", 7, 247818},
	{"SUPERGENIUS", 11, 247819},
	{"SCHROTH", 7, 247820},
	{"SATOU", 5, 247821},
	{"PINEIRO", 7, 247822},
	{"PEPFAR", 6, 247823},
	{"GENTOOX", 7, 247824},
	{"REFUELED", 8, 247825},
	{"AICHA", 5, 247826},
	{"PALAEO", 6, 247827},
	{"MAPLAB", 6, 247828},
	{"KERNAGHAN", 9, 247829},
	{"TBRANCH", 7, 247830},
	{"PESHMERGA", 9, 247831},
	{"LAMBDAMOO", 9, 247832},
	{"KWESI", 5, 247833},
	{"INAUTHENTIC", 11, 247834},
	{"NITROGLYCERINE", 14, 247835},
	{"MISBEHAVED", 10, 247836},
	{"LEYENDA", 7, 247837},
	{"VNPT", 4, 247838},
	{"SUSSE", 5, 247839},
	{"SUNRAYS", 7, 247840},
	{"NYANZA", 6, 247841},
	{"WADDOUPS", 8, 247842},
	{"JGM", 3, 247843},
	{"GOOSEFOOT", 9, 247844},
	{"WORMALD", 7, 247845},
	{"TYMOR", 5, 247846},
	{"MCLAY", 5, 247847},
	{"SPERBERG", 8, 247848},
	{"SHANDLING", 9, 247849},
	{"PHOTOSCOM", 9, 247850},
	{"BESETTING", 9, 247851},
	{"DANSEN", 6, 247852},
	{"COLVIC", 6, 247853},
	{"INFOSOURCE", 10, 247854},
	{"GASTOS", 6, 247855},
	{"DAUNT", 5, 247856},
	{"POWERSCAN", 9, 247857},
	{"CHIKARA", 7, 247858},
	{"ZCLASS", 6, 247859},
	{"SAISISSEZ", 9, 247860},
	{"LAHU", 4, 247861},
	{"JAKOBSON", 8, 247862},
	{"GILLIE", 6, 247863},
	{"YKYO", 4, 247864},
	{"YBAX", 4, 247865},
	{"XUPA", 4, 247866},
	{"XISJ", 4, 247867},
	{"WEIY", 4, 247868},
	{"WCUB", 4, 247869},
	{"VOYP", 4, 247870},
	{"VGOT", 4, 247871},
	{"VAKL", 4, 247872},
	{"UITZ", 4, 247873},
	{"UEZJ", 4, 247874},
	{"UCSI", 4, 247875},
	{"TRRE", 4, 247876},
	{"TRCO", 4, 247877},
	{"TIPD", 4, 247878},
	{"THUW", 4, 247879},
	{"SYRT", 4, 247880},
	{"SVCA", 4, 247881},
	{"SLCH", 4, 247882},
	{"SHWY", 4, 247883},
	{"SBAX", 4, 247884},
	{"RSNF", 4, 247885},
	{"RPEF", 4, 247886},
	{"REFB", 4, 247887},
	{"RCSF", 4, 247888},
	{"RBYQ", 4, 247889},
	{"RAUJ", 4, 247890},
	{"QISF", 4, 247891},
	{"OUXH", 4, 247892},
	{"MOAD", 4, 247893},
	{"MAGC", 4, 247894},
	{"LYKG", 4, 247895},
	{"LMNI", 4, 247896},
	{"LKAZ", 4, 247897},
	{"LDUI", 4, 247898},
	{"JUET", 4, 247899},
	{"JRSO", 4, 247900},
	{"IXSW", 4, 247901},
	{"IVBU", 4, 247902},
	{"IADJ", 4, 247903},
	{"HEPZ", 4, 247904},
	{"HDAG", 4, 247905},
	{"FKOK", 4, 247906},
	{"ESYW", 4, 247907},
	{"DTFI", 4, 247908},
	{"DPFE", 4, 247909},
	{"DMOJ", 4, 247910},
	{"CATJ", 4, 247911},
	{"BIRB", 4, 247912},
	{"AXIB", 4, 247913},
	{"ATKC", 4, 247914},
	{"ALUY", 4, 247915},
	{"PIERWSZA", 8, 247916},
	{"PCHELPERS", 9, 247917},
	{"SWANMORE", 8, 247918},
	{"STARMATE", 8, 247919},
	{"PETPET", 6, 247920},
	{"CARRYOVERS", 10, 247921},
	{"PRETED", 6, 247922},
	{"GROBE", 5, 247923},
	{"MICHEALS", 8, 247924},
	{"BOUE", 4, 247925},
	{"UNCOMPROMISINGLY", 16, 247926},
	{"FSTRING", 7, 247927},
	{"ESKILSTUNA", 10, 247928},
	{"CIRANO", 6, 247929},
	{"NONCOMBATANTS", 13, 247930},
	{"LOWRISE", 7, 247931},
	{"TRINUCLEOTIDE", 13, 247932},
	{"TEMUCO", 6, 247933},
	{"GEOSCIENTIST", 12, 247934},
	{"FREESIAS", 8, 247935},
	{"VORM", 4, 247936},
	{"AFCEE", 5, 247937},
	{"ZEPPELINS", 9, 247938},
	{"PQRS", 4, 247939},
	{"BRANDSMA", 8, 247940},
	{"TOPUP", 5, 247941},
	{"SUKUMAR", 7, 247942},
	{"MUESTRAN", 8, 247943},
	{"FISHBOWLNY", 10, 247944},
	{"DISUTILITY", 10, 247945},
	{"CIRES", 5, 247946},
	{"FACILISI", 8, 247947},
	{"CMVM", 4, 247948},
	{"TSONGAS", 7, 247949},
	{"NOOGLE", 6, 247950},
	{"GSBCA", 5, 247951},
	{"TRANSLIT", 8, 247952},
	{"PIMMS", 5, 247953},
	{"EPICIMAGES", 10, 247954},
	{"PARODYING", 9, 247955},
	{"COMMENTAAR", 10, 247956},
	{"ARCHIMONDE", 10, 247957},
	{"SKYROS", 6, 247958},
	{"NOROTON", 7, 247959},
	{"SPDS", 4, 247960},
	{"SOLLI", 5, 247961},
	{"MALUTI", 6, 247962},
	{"LIFEINSURANCE", 13, 247963},
	{"POLANSKY", 8, 247964},
	{"POKY", 4, 247965},
	{"FORMACION", 9, 247966},
	{"WOOLCOCK", 8, 247967},
	{"OBTENGA", 7, 247968},
	{"GLASSBLOWER", 11, 247969},
	{"CHERSONESS", 10, 247970},
	{"AWPA", 4, 247971},
	{"JOURNYX", 7, 247972},
	{"HERPESVIRIDAE", 13, 247973},
	{"COLECTION", 9, 247974},
	{"OKUJI", 5, 247975},
	{"MITCALC", 7, 247976},
	{"PUCCIO", 6, 247977},
	{"INOCULATEIT", 11, 247978},
	{"HOMENAJE", 8, 247979},
	{"RONCALLI", 8, 247980},
	{"HYPOTHEKEN", 10, 247981},
	{"TARIM", 5, 247982},
	{"PREPLANNED", 10, 247983},
	{"INDISPOSED", 10, 247984},
	{"PAOLETTI", 8, 247985},
	{"FUJ", 3, 247986},
	{"EXTRAVAGANZAS", 13, 247987},
	{"GJM", 3, 247988},
	{"SKULLCRUSHER", 12, 247989},
	{"IMSR", 4, 247990},
	{"DISPMODE", 8, 247991},
	{"CWWANY", 6, 247992},
	{"CAROWINDS", 9, 247993},
	{"BUMI", 4, 247994},
	{"RENTE", 5, 247995},
	{"DROG", 4, 247996},
	{"DMITRIEV", 8, 247997},
	{"BLAENAVON", 9, 247998},
	{"UNIONGYRCHOL", 12, 247999},
	{"PHARMINGEN", 10, 248000},
	{"LITKICKS", 8, 248001},
	{"ESPON", 5, 248002},
	{"DIVXNETWORKS", 12, 248003},
	{"COSATTO", 7, 248004},
	{"MANENT", 6, 248005},
	{"ADID", 4, 248006},
	{"MPJ", 3, 248007},
	{"MICROTACTIX", 11, 248008},
	{"WOOLRIDGE", 9, 248009},
	{"SHADOWNESS", 10, 248010},
	{"UNAPIX", 6, 248011},
	{"PASTORING", 9, 248012},
	{"INVERLOCH", 9, 248013},
	{"KUKULCAN", 8, 248014},
	{"CHESNEE", 7, 248015},
	{"STRATEGICAL", 11, 248016},
	{"FORDF", 5, 248017},
	{"VITOSHA", 7, 248018},
	{"TURKOGLU", 8, 248019},
	{"FRUTTA", 6, 248020},
	{"GIMBLE", 6, 248021},
	{"DATAFLUX", 8, 248022},
	{"CELLONE", 7, 248023},
	{"BRIGHTWATERS", 12, 248024},
	{"SOCIA", 5, 248025},
	{"INFOWAVE", 8, 248026},
	{"PEDICEL", 7, 248027},
	{"USARMY", 6, 248028},
	{"LUDFORD", 7, 248029},
	{"VOLKSKRANT", 10, 248030},
	{"PODICEPS", 8, 248031},
	{"THERMOPYLAE", 11, 248032},
	{"POTHOLDER", 9, 248033},
	{"HEMINGFORD", 10, 248034},
	{"GEORGIAUSA", 10, 248035},
	{"DIEMER", 6, 248036},
	{"PEREGRINA", 9, 248037},
	{"LANDHOLDINGS", 12, 248038},
	{"LAFALCE", 7, 248039},
	{"XELA", 4, 248040},
	{"PROLANGS", 8, 248041},
	{"PROCERA", 7, 248042},
	{"DUCHA", 5, 248043},
	{"IXION", 5, 248044},
	{"GLOG", 4, 248045},
	{"HAKUGEI", 7, 248046},
	{"VACUVIN", 7, 248047},
	{"SCRAMBLERS", 10, 248048},
	{"IVANOVNA", 8, 248049},
	{"FLANNAGAN", 9, 248050},
	{"LEVICK", 6, 248051},
	{"CAMPBELLSPORT", 13, 248052},
	{"AMODRA", 6, 248053},
	{"MPQ", 3, 248054},
	{"MELASMA", 7, 248055},
	{"HAPTOGLOBIN", 11, 248056},
	{"TAGLIATELLE", 11, 248057},
	{"PATRIS", 6, 248058},
	{"OBOVATE", 7, 248059},
	{"LANDET", 6, 248060},
	{"CAPR", 4, 248061},
	{"LUBITSCH", 8, 248062},
	{"PERFECTE", 8, 248063},
	{"DISCIPLINA", 10, 248064},
	{"RESOPAL", 7, 248065},
	{"JASINSKI", 8, 248066},
	{"HAMMACK", 7, 248067},
	{"DIRTBIKES", 9, 248068},
	{"BLUESCREEN", 10, 248069},
	{"WWWTHE", 6, 248070},
	{"MANIACALLY", 10, 248071},
	{"KUCHAR", 6, 248072},
	{"BREITENBACH", 11, 248073},
	{"BLACKHEART", 10, 248074},
	{"ZABIELA", 7, 248075},
	{"MUSKRATS", 8, 248076},
	{"LAKSHMANA", 9, 248077},
	{"KOCHEN", 6, 248078},
	{"BACKCARE", 8, 248079},
	{"ZAKAH", 5, 248080},
	{"USERLEVEL", 9, 248081},
	{"TROPICALIA", 10, 248082},
	{"CUDJOE", 6, 248083},
	{"SKOLA", 5, 248084},
	{"TRENDSPOTTING", 13, 248085},
	{"ROCQUENCOURT", 12, 248086},
	{"MORENET", 7, 248087},
	{"GAMBREL", 7, 248088},
	{"SKOOKUM", 7, 248089},
	{"MATWEB", 6, 248090},
	{"JOHNNI", 6, 248091},
	{"DEUBA", 5, 248092},
	{"KAMIEN", 6, 248093},
	{"IMPULS", 6, 248094},
	{"UNGUENTS", 8, 248095},
	{"SLIMNOTE", 8, 248096},
	{"RELMAX", 6, 248097},
	{"MUSSET", 6, 248098},
	{"KNIGHTSTOWN", 11, 248099},
	{"ELJER", 5, 248100},
	{"AMERISOURCE", 11, 248101},
	{"TREORCHY", 8, 248102},
	{"REDUZIERT", 9, 248103},
	{"AMIDSHIPS", 9, 248104},
	{"SPALOOK", 7, 248105},
	{"RAVITCH", 7, 248106},
	{"POLICEWOMEN", 11, 248107},
	{"GASKETED", 8, 248108},
	{"WORRIER", 7, 248109},
	{"PREJUDICING", 11, 248110},
	{"FROOM", 5, 248111},
	{"DRAFTEES", 8, 248112},
	{"VAVRA", 5, 248113},
	{"SPLOGS", 6, 248114},
	{"PSELBOX", 7, 248115},
	{"LYTTLETON", 9, 248116},
	{"HESBURGH", 8, 248117},
	{"CHOOS", 5, 248118},
	{"AWSTRALIA", 9, 248119},
	{"MILVERTON", 9, 248120},
	{"AQUAE", 5, 248121},
	{"PEARCEY", 7, 248122},
	{"AMPUTATE", 8, 248123},
	{"DOTD", 4, 248124},
	{"DOSER", 5, 248125},
	{"LIZBETH", 7, 248126},
	{"PUHCA", 5, 248127},
	{"DHAL", 4, 248128},
	{"CULATION", 8, 248129},
	{"BENTOTA", 7, 248130},
	{"WEBSOC", 6, 248131},
	{"PARADISES", 9, 248132},
	{"IGLOOS", 6, 248133},
	{"LEIFHEIT", 8, 248134},
	{"STARSIEGE", 9, 248135},
	{"PROSTHETIST", 11, 248136},
	{"DEFORESTED", 10, 248137},
	{"NORDLINGER", 10, 248138},
	{"INVASIONCOMEDY", 14, 248139},
	{"FATIMAH", 7, 248140},
	{"SHOME", 5, 248141},
	{"HOEFT", 5, 248142},
	{"HATHCOCK", 8, 248143},
	{"GOTTSTEIN", 9, 248144},
	{"ZYKO", 4, 248145},
	{"ZANR", 4, 248146},
	{"YVOD", 4, 248147},
	{"YRBI", 4, 248148},
	{"YJRT", 4, 248149},
	{"YGPS", 4, 248150},
	{"XMLI", 4, 248151},
	{"WYAL", 4, 248152},
	{"WEGN", 4, 248153},
	{"WAXO", 4, 248154},
	{"WAPB", 4, 248155},
	{"VIBU", 4, 248156},
	{"VEGP", 4, 248157},
	{"UTZF", 4, 248158},
	{"UNRW", 4, 248159},
	{"UKMU", 4, 248160},
	{"UIZD", 4, 248161},
	{"UEZN", 4, 248162},
	{"UEPP", 4, 248163},
	{"UDUA", 4, 248164},
	{"UBOC", 4, 248165},
	{"TZEP", 4, 248166},
	{"TTVP", 4, 248167},
	{"TSJR", 4, 248168},
	{"TGEB", 4, 248169},
	{"SYFU", 4, 248170},
	{"STZU", 4, 248171},
	{"SHRY", 4, 248172},
	{"ROVP", 4, 248173},
	{"PPMT", 4, 248174},
	{"PMNA", 4, 248175},
	{"PAAW", 4, 248176},
	{"OYUP", 4, 248177},
	{"OVCR", 4, 248178},
	{"OUIR", 4, 248179},
	{"OFKF", 4, 248180},
	{"NGPF", 4, 248181},
	{"NFOY", 4, 248182},
	{"NECF", 4, 248183},
	{"MYRM", 4, 248184},
	{"MEXM", 4, 248185},
	{"LTEG", 4, 248186},
	{"KGOW", 4, 248187},
	{"IYUE", 4, 248188},
	{"ISWB", 4, 248189},
	{"INBD", 4, 248190},
	{"IMYT", 4, 248191},
	{"HUPN", 4, 248192},
	{"HLBA", 4, 248193},
	{"HCZE", 4, 248194},
	{"HCCO", 4, 248195},
	{"GOMC", 4, 248196},
	{"GKOO", 4, 248197},
	{"GJAL", 4, 248198},
	{"GBTR", 4, 248199},
	{"FRSO", 4, 248200},
	{"FJEH", 4, 248201},
	{"FDRK", 4, 248202},
	{"FCUE", 4, 248203},
	{"EPSQ", 4, 248204},
	{"ECGE", 4, 248205},
	{"DRYJ", 4, 248206},
	{"DJSC", 4, 248207},
	{"DGHI", 4, 248208},
	{"CRUY", 4, 248209},
	{"CPII", 4, 248210},
	{"CMFO", 4, 248211},
	{"CGLI", 4, 248212},
	{"CBSL", 4, 248213},
	{"BKER", 4, 248214},
	{"BGAL", 4, 248215},
	{"BAFL", 4, 248216},
	{"AZFO", 4, 248217},
	{"WESTERLO", 8, 248218},
	{"SCRIBESTUDIO", 12, 248219},
	{"CRIGHTON", 8, 248220},
	{"PTEROSAURS", 10, 248221},
	{"CHUBUT", 6, 248222},
	{"PERCEPTS", 8, 248223},
	{"LITTLESTOWN", 11, 248224},
	{"DUSTLESS", 8, 248225},
	{"BRAILSFORD", 10, 248226},
	{"AMPITHEATRE", 11, 248227},
	{"RUKMINI", 7, 248228},
	{"RAMCITY", 7, 248229},
	{"EDUPAGE", 7, 248230},
	{"RELOCATOR", 9, 248231},
	{"LUECK", 5, 248232},
	{"IGRAVE", 6, 248233},
	{"CHESANING", 9, 248234},
	{"STONEWORLD", 10, 248235},
	{"SCHEV", 5, 248236},
	{"MONEYBAGS", 9, 248237},
	{"JUBAIL", 6, 248238},
	{"HARNED", 6, 248239},
	{"ENVIROTHON", 10, 248240},
	{"CHICKENMAN", 10, 248241},
	{"DWSRF", 5, 248242},
	{"CIVILIZATIONAL", 14, 248243},
	{"BABATUNDE", 9, 248244},
	{"GALANG", 6, 248245},
	{"CHARLOTTES", 10, 248246},
	{"BUMBLERIDE", 10, 248247},
	{"VERVET", 6, 248248},
	{"MERLION", 7, 248249},
	{"ENVIROWISE", 10, 248250},
	{"BENNISON", 8, 248251},
	{"BEANSHELL", 9, 248252},
	{"SUBURBANIZATION", 15, 248253},
	{"DIJET", 5, 248254},
	{"BLOCKLEY", 8, 248255},
	{"AUXILIAR", 8, 248256},
	{"CINCHONA", 8, 248257},
	{"AETEC", 5, 248258},
	{"NORESULTSERROR", 14, 248259},
	{"CHAMPOLLION", 11, 248260},
	{"OKRUG", 5, 248261},
	{"LAITH", 5, 248262},
	{"VARMINTS", 8, 248263},
	{"PROGRAMES", 9, 248264},
	{"HYMER", 5, 248265},
	{"BROJ", 4, 248266},
	{"TOLWORTH", 8, 248267},
	{"SAWL", 4, 248268},
	{"MEFEEDIA", 8, 248269},
	{"STARPOINT", 9, 248270},
	{"SERIN", 5, 248271},
	{"BLACKDUCK", 9, 248272},
	{"ADDREF", 6, 248273},
	{"QMW", 3, 248274},
	{"PRETERISM", 9, 248275},
	{"HIGHTOWN", 8, 248276},
	{"TEAMWARE", 8, 248277},
	{"MEETE", 5, 248278},
	{"GEARMOTORS", 10, 248279},
	{"CABLESERVE", 10, 248280},
	{"BALLYHOOED", 10, 248281},
	{"NINNY", 5, 248282},
	{"MUFFLING", 8, 248283},
	{"INANCE", 6, 248284},
	{"HOTRECRUIT", 10, 248285},
	{"FOLIATIONS", 10, 248286},
	{"APRECIATED", 10, 248287},
	{"POLLUTIONS", 10, 248288},
	{"CSHL", 4, 248289},
	{"GREENLANE", 9, 248290},
	{"MAGNETIX", 8, 248291},
	{"HONKIN", 6, 248292},
	{"PLEATING", 8, 248293},
	{"NPGS", 4, 248294},
	{"LAVATRICI", 9, 248295},
	{"TAGAWA", 6, 248296},
	{"OFFLINEID", 9, 248297},
	{"MAINTANCE", 9, 248298},
	{"GARDER", 6, 248299},
	{"KITCHELL", 8, 248300},
	{"FRIEDERIKE", 10, 248301},
	{"BECOZ", 5, 248302},
	{"ACTULLY", 7, 248303},
	{"WEBDESIGNS", 10, 248304},
	{"AFFID", 5, 248305},
	{"CDEC", 4, 248306},
	{"BULLEEN", 7, 248307},
	{"WASSAT", 6, 248308},
	{"STUPIDITIES", 11, 248309},
	{"GETRESPONSE", 11, 248310},
	{"GARLINGTON", 10, 248311},
	{"ECHAM", 5, 248312},
	{"RHODAN", 6, 248313},
	{"GOLGLE", 6, 248314},
	{"BARMAH", 6, 248315},
	{"TORRENTSPY", 10, 248316},
	{"HYDEL", 5, 248317},
	{"DZIEWICE", 8, 248318},
	{"HOTELX", 6, 248319},
	{"BUITEN", 6, 248320},
	{"RODANTHE", 8, 248321},
	{"PUAKA", 5, 248322},
	{"LSEG", 4, 248323},
	{"CHRISTOFFERSEN", 14, 248324},
	{"ZODIAQUE", 8, 248325},
	{"SHADOWFIRE", 10, 248326},
	{"SEPERTI", 7, 248327},
	{"GUMI", 4, 248328},
	{"GOIGLE", 6, 248329},
	{"DANZAS", 6, 248330},
	{"ORIZABA", 7, 248331},
	{"FASTBALLS", 9, 248332},
	{"CAPET", 5, 248333},
	{"BUELOW", 6, 248334},
	{"MEADOWVALE", 10, 248335},
	{"CAPOBIANCO", 10, 248336},
	{"ANGELOPOULOS", 12, 248337},
	{"ALERTCOMMERCIAL", 15, 248338},
	{"AIRSNORT", 8, 248339},
	{"THAIR", 5, 248340},
	{"SKOL", 4, 248341},
	{"PBUILDING", 9, 248342},
	{"ONKELZ", 6, 248343},
	{"TYPESETTERS", 11, 248344},
	{"CACKLED", 7, 248345},
	{"BREIMAN", 7, 248346},
	{"SOLSTICES", 9, 248347},
	{"ENTHUSES", 8, 248348},
	{"RINGNALDA", 9, 248349},
	{"FENNVILLE", 9, 248350},
	{"EPIDERMOID", 10, 248351},
	{"ADOLYGU", 7, 248352},
	{"SOMERSAULTS", 11, 248353},
	{"RHOD", 4, 248354},
	{"KALYN", 5, 248355},
	{"INNOVEER", 8, 248356},
	{"EBOOT", 5, 248357},
	{"GOODSELL", 8, 248358},
	{"EXTRACTNAMEVALUEPAIR", 20, 248359},
	{"NEDERLANDSCHE", 13, 248360},
	{"INTRACELLULARLY", 15, 248361},
	{"GERENCIA", 8, 248362},
	{"DOFUS", 5, 248363},
	{"EURUSD", 6, 248364},
	{"SHORTLISTING", 12, 248365},
	{"LOGINCOMMERCIAL", 15, 248366},
	{"KRICHIM", 7, 248367},
	{"HAPY", 4, 248368},
	{"SITEKIT", 7, 248369},
	{"MOVIESTAR", 9, 248370},
	{"CIMON", 5, 248371},
	{"UMNS", 4, 248372},
	{"GATER", 5, 248373},
	{"SOFTEARE", 8, 248374},
	{"BRUJO", 5, 248375},
	{"RDYNAMIC", 8, 248376},
	{"MATCHPLAY", 9, 248377},
	{"HUNKA", 5, 248378},
	{"OPENTOKEN", 9, 248379},
	{"HOLYLAND", 8, 248380},
	{"BEEVES", 6, 248381},
	{"KLANTEN", 7, 248382},
	{"FATELESS", 8, 248383},
	{"NEMEN", 5, 248384},
	{"LEVALLOIS", 9, 248385},
	{"LUCKS", 5, 248386},
	{"TESTUSER", 8, 248387},
	{"SUBSTITUTIONAL", 14, 248388},
	{"HYPERTENSIVES", 13, 248389},
	{"HEAVYFACE", 9, 248390},
	{"DENIO", 5, 248391},
	{"VANDALIZING", 11, 248392},
	{"UNFORTU", 7, 248393},
	{"LIPSTIK", 7, 248394},
	{"ARXES", 5, 248395},
	{"ALWAYES", 7, 248396},
	{"MOUNTER", 7, 248397},
	{"FRUTOS", 6, 248398},
	{"EFOR", 4, 248399},
	{"CYPROTERONE", 11, 248400},
	{"ATRC", 4, 248401},
	{"STOREROOMS", 10, 248402},
	{"PELTONEN", 8, 248403},
	{"CONY", 4, 248404},
	{"INITRAMFS", 9, 248405},
	{"KENTUCKIANA", 11, 248406},
	{"DELRAN", 6, 248407},
	{"BIOSTATISTICIAN", 15, 248408},
	{"SUPPLYHOUSETIMES", 16, 248409},
	{"DORIGO", 6, 248410},
	{"UNREINFORCED", 12, 248411},
	{"LYMPHADENITIS", 13, 248412},
	{"BRENEMAN", 8, 248413},
	{"TOPER", 5, 248414},
	{"SIBILITIES", 10, 248415},
	{"MATRAS", 6, 248416},
	{"QUACKER", 7, 248417},
	{"LAFFONT", 7, 248418},
	{"DUEY", 4, 248419},
	{"UHLENBECK", 9, 248420},
	{"SURGETTE", 8, 248421},
	{"SMEGMA", 6, 248422},
	{"HINFO", 5, 248423},
	{"XDX", 3, 248424},
	{"POSX", 4, 248425},
	{"KASSEM", 6, 248426},
	{"INSERIMENTO", 11, 248427},
	{"EXTREMEMLY", 10, 248428},
	{"CWLA", 4, 248429},
	{"BORGMANN", 8, 248430},
	{"FLURAZEPAM", 10, 248431},
	{"BUSCAN", 6, 248432},
	{"NIKAYA", 6, 248433},
	{"OLBRICH", 7, 248434},
	{"ERAM", 4, 248435},
	{"SUPHP", 5, 248436},
	{"RERELEASE", 9, 248437},
	{"FRENCHIES", 9, 248438},
	{"ODIHAM", 6, 248439},
	{"DEPR", 4, 248440},
	{"MTHFR", 5, 248441},
	{"LEPS", 4, 248442},
	{"DENNER", 6, 248443},
	{"BATHELEMY", 9, 248444},
	{"SUNDE", 5, 248445},
	{"PRAE", 4, 248446},
	{"MAURUS", 6, 248447},
	{"SOBEY", 5, 248448},
	{"LOOKE", 5, 248449},
	{"PRETERNATURAL", 13, 248450},
	{"KAMIAH", 6, 248451},
	{"GEMEINSAME", 10, 248452},
	{"DOWDLE", 6, 248453},
	{"DATATAKING", 10, 248454},
	{"GIAMBATTISTA", 12, 248455},
	{"FQHC", 4, 248456},
	{"PROENZA", 7, 248457},
	{"INDICTING", 9, 248458},
	{"MOUNDVILLE", 10, 248459},
	{"BABESIA", 7, 248460},
	{"AVVID", 5, 248461},
	{"GEMBLOUX", 8, 248462},
	{"VERSUCH", 7, 248463},
	{"SUCCINYLCHOLINE", 15, 248464},
	{"JAGAT", 5, 248465},
	{"KAND", 4, 248466},
	{"FLAMENGO", 8, 248467},
	{"MANCUNIAN", 9, 248468},
	{"CONDUCE", 7, 248469},
	{"AQUAIMAGE", 9, 248470},
	{"DEFRANCESCO", 11, 248471},
	{"GLIADIN", 7, 248472},
	{"BASTEN", 6, 248473},
	{"CENTIMES", 8, 248474},
	{"CANTORS", 7, 248475},
	{"PHPROJEKT", 9, 248476},
	{"HORSELESS", 9, 248477},
	{"DIGITALENTERTAINMENT", 20, 248478},
	{"FISCHEL", 7, 248479},
	{"MYAPPLEMENU", 11, 248480},
	{"HOTRODDERS", 10, 248481},
	{"ACCOUNTLOGIN", 12, 248482},
	{"ZOUS", 4, 248483},
	{"ZJOH", 4, 248484},
	{"YNGL", 4, 248485},
	{"YLSH", 4, 248486},
	{"XLAP", 4, 248487},
	{"WCOF", 4, 248488},
	{"WAUW", 4, 248489},
	{"VDBL", 4, 248490},
	{"UTZU", 4, 248491},
	{"UOMR", 4, 248492},
	{"UNZO", 4, 248493},
	{"TPPG", 4, 248494},
	{"THRW", 4, 248495},
	{"TDMO", 4, 248496},
	{"SVPA", 4, 248497},
	{"SUQU", 4, 248498},
	{"RYKW", 4, 248499},
	{"RUMJ", 4, 248500},
	{"RTVW", 4, 248501},
	{"RIDJ", 4, 248502},
	{"RDPT", 4, 248503},
	{"PRWH", 4, 248504},
	{"PMMU", 4, 248505},
	{"PCSF", 4, 248506},
	{"ORCW", 4, 248507},
	{"NYUB", 4, 248508},
	{"NSUW", 4, 248509},
	{"NOXR", 4, 248510},
	{"NKMM", 4, 248511},
	{"NGDT", 4, 248512},
	{"NAGW", 4, 248513},
	{"MUGN", 4, 248514},
	{"MNGU", 4, 248515},
	{"MNFI", 4, 248516},
	{"MIKV", 4, 248517},
	{"LTZD", 4, 248518},
	{"KEMT", 4, 248519},
	{"JUNN", 4, 248520},
	{"JOPE", 4, 248521},
	{"JIWE", 4, 248522},
	{"IRZI", 4, 248523},
	{"IGSY", 4, 248524},
	{"HYLD", 4, 248525},
	{"HGAG", 4, 248526},
	{"HDUO", 4, 248527},
	{"HAWU", 4, 248528},
	{"GMVP", 4, 248529},
	{"GEWW", 4, 248530},
	{"ERDK", 4, 248531},
	{"EKOJ", 4, 248532},
	{"EJKA", 4, 248533},
	{"EIFV", 4, 248534},
	{"EAGW", 4, 248535},
	{"DUHE", 4, 248536},
	{"DPPT", 4, 248537},
	{"DJEV", 4, 248538},
	{"DDCI", 4, 248539},
	{"DAKL", 4, 248540},
	{"CTAJ", 4, 248541},
	{"CPAA", 4, 248542},
	{"COYR", 4, 248543},
	{"CMHI", 4, 248544},
	{"CGOU", 4, 248545},
	{"CEYG", 4, 248546},
	{"BMOT", 4, 248547},
	{"ATLW", 4, 248548},
	{"ASWC", 4, 248549},
	{"AOBV", 4, 248550},
	{"TREDINNICK", 10, 248551},
	{"FORTIFIES", 9, 248552},
	{"STERMAN", 7, 248553},
	{"SECURITYHOLDERS", 15, 248554},
	{"STEWARTVILLE", 12, 248555},
	{"SHOULDBE", 8, 248556},
	{"NEUROCHIR", 9, 248557},
	{"ISOTONER", 8, 248558},
	{"SALADA", 6, 248559},
	{"SCHNORR", 7, 248560},
	{"ROARNATS", 8, 248561},
	{"REPLIA", 6, 248562},
	{"LOPING", 6, 248563},
	{"IUGR", 4, 248564},
	{"TRUSSING", 8, 248565},
	{"GALCIV", 6, 248566},
	{"ADJU", 4, 248567},
	{"SHANGAI", 7, 248568},
	{"EUBACTERIAL", 11, 248569},
	{"IMMIGRATIONS", 12, 248570},
	{"ANATASE", 7, 248571},
	{"VOEGELIN", 8, 248572},
	{"WILLIBALD", 9, 248573},
	{"SWANA", 5, 248574},
	{"TURRAMURRA", 10, 248575},
	{"STANDBYS", 8, 248576},
	{"AMGYLCHEDDOL", 12, 248577},
	{"SHAREWARES", 10, 248578},
	{"BRUSSAT", 7, 248579},
	{"BEZOEKERS", 9, 248580},
	{"MICROTUS", 8, 248581},
	{"MALTIPOO", 8, 248582},
	{"REPUDIATES", 10, 248583},
	{"QLIKTECH", 8, 248584},
	{"KLOOGE", 6, 248585},
	{"METROPCS", 8, 248586},
	{"CUBENSIS", 8, 248587},
	{"XEROXED", 7, 248588},
	{"POWERLEVELING", 13, 248589},
	{"SOMBODY", 7, 248590},
	{"ROSSIE", 6, 248591},
	{"PUBLICSUPPORTED", 15, 248592},
	{"ERAP", 4, 248593},
	{"ADJOURNING", 10, 248594},
	{"RECLINES", 8, 248595},
	{"NEPOOL", 6, 248596},
	{"DARNER", 6, 248597},
	{"WEISBROD", 8, 248598},
	{"SCHMICK", 7, 248599},
	{"GRATIUT", 7, 248600},
	{"EFFECTUER", 9, 248601},
	{"BUCHSBAUM", 9, 248602},
	{"WITHEVENTS", 10, 248603},
	{"FEARE", 5, 248604},
	{"TRAVELMALL", 10, 248605},
	{"REGULON", 7, 248606},
	{"MILIARY", 7, 248607},
	{"FLORIDAS", 8, 248608},
	{"ABUELO", 6, 248609},
	{"BRADING", 7, 248610},
	{"OMBUD", 5, 248611},
	{"MANNOSIDASE", 11, 248612},
	{"INGLEBY", 7, 248613},
	{"FAKTA", 5, 248614},
	{"ALONISSOS", 9, 248615},
	{"LONGLEAT", 8, 248616},
	{"HONGQIAO", 8, 248617},
	{"CHEMEKETA", 9, 248618},
	{"ANNCE", 5, 248619},
	{"TOMKINSON", 9, 248620},
	{"RETOURNER", 9, 248621},
	{"NEDER", 5, 248622},
	{"EARLDOM", 7, 248623},
	{"TOKAIDO", 7, 248624},
	{"MSGTYPE", 7, 248625},
	{"INDUBITABLE", 11, 248626},
	{"EDUWONK", 7, 248627},
	{"MORONE", 6, 248628},
	{"MANWARING", 9, 248629},
	{"WKYT", 4, 248630},
	{"VIDER", 5, 248631},
	{"CAIRNCROSS", 10, 248632},
	{"UNPRINTABLE", 11, 248633},
	{"NATALES", 7, 248634},
	{"SRCPORT", 7, 248635},
	{"QUALCOSA", 8, 248636},
	{"YOSHKAR", 7, 248637},
	{"JUIFS", 5, 248638},
	{"FIREMASTER", 10, 248639},
	{"DATABASING", 10, 248640},
	{"MISMALOYA", 9, 248641},
	{"MYERZ", 5, 248642},
	{"MIFLUZ", 6, 248643},
	{"FUMAGALLI", 9, 248644},
	{"SHAILESH", 8, 248645},
	{"LIGHTCYCLER", 11, 248646},
	{"GLINES", 6, 248647},
	{"BIIG", 4, 248648},
	{"EXISITNG", 8, 248649},
	{"WITSAND", 7, 248650},
	{"MYMONEYANGEL", 12, 248651},
	{"DINITROPHENOL", 13, 248652},
	{"BLUELIST", 8, 248653},
	{"ASSIMILATIVE", 12, 248654},
	{"ALLBRITTON", 10, 248655},
	{"NEWSARCHIVE", 11, 248656},
	{"REIMPLEMENTATION", 16, 248657},
	{"COLLATOR", 8, 248658},
	{"CMDL", 4, 248659},
	{"CIRM", 4, 248660},
	{"BREITKOPF", 9, 248661},
	{"HANSPETER", 9, 248662},
	{"AUDIOTRAK", 9, 248663},
	{"SANDIMMUNE", 10, 248664},
	{"MOORELAND", 9, 248665},
	{"MELANCHTHON", 11, 248666},
	{"BOTANI", 6, 248667},
	{"TICKY", 5, 248668},
	{"SLOSHED", 7, 248669},
	{"NETPAL", 6, 248670},
	{"LEIPZIGER", 9, 248671},
	{"ISCAN", 5, 248672},
	{"FREEAMP", 7, 248673},
	{"CHEATPLAZA", 10, 248674},
	{"SPIROCHETE", 10, 248675},
	{"AMABLE", 6, 248676},
	{"PANTEK", 6, 248677},
	{"MCVICKER", 8, 248678},
	{"BDV", 3, 248679},
	{"TOMATOE", 7, 248680},
	{"RABBITOHS", 9, 248681},
	{"ANCC", 4, 248682},
	{"EXCEPTIONALITY", 14, 248683},
	{"PITTORI", 7, 248684},
	{"CYFRA", 5, 248685},
	{"COUNTERTENOR", 12, 248686},
	{"CAULKS", 6, 248687},
	{"ALECM", 5, 248688},
	{"SCARFE", 6, 248689},
	{"UNPRIMED", 8, 248690},
	{"TAVERAS", 7, 248691},
	{"DEROY", 5, 248692},
	{"BOLLO", 5, 248693},
	{"YESASIA", 7, 248694},
	{"OLIGODENDROCYTE", 15, 248695},
	{"HANDSOMEST", 10, 248696},
	{"UGOPLAYER", 9, 248697},
	{"MYALBUM", 7, 248698},
	{"DECOROUS", 8, 248699},
	{"TCPS", 4, 248700},
	{"WOLINSKY", 8, 248701},
	{"UKHOTEL", 7, 248702},
	{"OSSERVATORE", 11, 248703},
	{"BARGY", 5, 248704},
	{"IFTF", 4, 248705},
	{"ABADAN", 6, 248706},
	{"POUTRE", 6, 248707},
	{"CREDITSIGHTS", 12, 248708},
	{"TECHCENTRAL", 11, 248709},
	{"BRAHMANS", 8, 248710},
	{"APIL", 4, 248711},
	{"PROMESO", 7, 248712},
	{"BGLII", 5, 248713},
	{"OVERSUBSCRIPTION", 16, 248714},
	{"XOFTWARE", 8, 248715},
	{"TREEWIDTH", 9, 248716},
	{"CARTIA", 6, 248717},
	{"AURICULARES", 11, 248718},
	{"HLDG", 4, 248719},
	{"CHAGRINED", 9, 248720},
	{"CERBERA", 7, 248721},
	{"BMUS", 4, 248722},
	{"CRIBCANDY", 9, 248723},
	{"CGSC", 4, 248724},
	{"AMAMI", 5, 248725},
	{"WESTCLOX", 8, 248726},
	{"WEBSHIELD", 9, 248727},
	{"PROWERS", 7, 248728},
	{"GLIMCHER", 8, 248729},
	{"COMMISIONS", 10, 248730},
	{"ARALIA", 6, 248731},
	{"HOLUALOA", 8, 248732},
	{"ETALON", 6, 248733},
	{"BEBER", 5, 248734},
	{"STRIEBER", 8, 248735},
	{"COCKRUM", 7, 248736},
	{"DURABLY", 7, 248737},
	{"GOOSTER", 7, 248738},
	{"BMAT", 4, 248739},
	{"ZMAN", 4, 248740},
	{"TILLETT", 7, 248741},
	{"STARVES", 7, 248742},
	{"PASSDB", 6, 248743},
	{"GOOYLE", 6, 248744},
	{"GOOTLE", 6, 248745},
	{"DEREFERENCED", 12, 248746},
	{"GEMEINDE", 8, 248747},
	{"GARANTIERT", 10, 248748},
	{"TRABALHADOR", 11, 248749},
	{"RIGHTWARDS", 10, 248750},
	{"MCTEER", 6, 248751},
	{"ENDM", 4, 248752},
	{"EDGINGS", 7, 248753},
	{"DARKWING", 8, 248754},
	{"BLUDGEONING", 11, 248755},
	{"ROBLEM", 6, 248756},
	{"IMBECILITY", 10, 248757},
	{"GINOCCHIO", 9, 248758},
	{"DOGSLED", 7, 248759},
	{"LUBAVITCHER", 11, 248760},
	{"RIBARITSA", 9, 248761},
	{"MANSBRIDGE", 10, 248762},
	{"WASHINGTONIANS", 14, 248763},
	{"TRICHET", 7, 248764},
	{"KETU", 4, 248765},
	{"HOSTELWORLD", 11, 248766},
	{"EINARSSON", 9, 248767},
	{"ABOTEL", 6, 248768},
	{"ROMAS", 5, 248769},
	{"DOJRZALE", 8, 248770},
	{"SYNERGASIA", 10, 248771},
	{"GTKADA", 6, 248772},
	{"ARSLIST", 7, 248773},
	{"SUIR", 4, 248774},
	{"OUVERTE", 7, 248775},
	{"HIERACIUM", 9, 248776},
	{"AGARKAR", 7, 248777},
	{"VISHAKHAPATNAM", 14, 248778},
	{"POOKER", 6, 248779},
	{"INSULINOMA", 10, 248780},
	{"YUNDI", 5, 248781},
	{"WILHELMSEN", 10, 248782},
	{"POVO", 4, 248783},
	{"CHIYO", 5, 248784},
	{"MICROPHOTO", 10, 248785},
	{"STARTKDE", 8, 248786},
	{"CELERRA", 7, 248787},
	{"SIVIGLIA", 8, 248788},
	{"MUGHALS", 7, 248789},
	{"MOPP", 4, 248790},
	{"MAXIUM", 6, 248791},
	{"GOUD", 4, 248792},
	{"DENITRIFICANS", 13, 248793},
	{"COLWOOD", 7, 248794},
	{"CHELATOR", 8, 248795},
	{"MONOPOLISTS", 11, 248796},
	{"MCGLASHAN", 9, 248797},
	{"ANATOMICALS", 11, 248798},
	{"RDDL", 4, 248799},
	{"PIGG", 4, 248800},
	{"PANERIS", 7, 248801},
	{"KITAJIMA", 8, 248802},
	{"HALODURANS", 10, 248803},
	{"GNOMISH", 7, 248804},
	{"ECTOPLASM", 9, 248805},
	{"CODINE", 6, 248806},
	{"CHECKINSTALL", 12, 248807},
	{"ZEEF", 4, 248808},
	{"YNDP", 4, 248809},
	{"WKTO", 4, 248810},
	{"VYMU", 4, 248811},
	{"VWHA", 4, 248812},
	{"VROU", 4, 248813},
	{"VOGO", 4, 248814},
	{"UVEU", 4, 248815},
	{"ULIY", 4, 248816},
	{"TZSR", 4, 248817},
	{"TTPG", 4, 248818},
	{"TOUZ", 4, 248819},
	{"TJRO", 4, 248820},
	{"TJOG", 4, 248821},
	{"SNYM", 4, 248822},
	{"SKKI", 4, 248823},
	{"RUZG", 4, 248824},
	{"RRDP", 4, 248825},
	{"RNTC", 4, 248826},
	{"RNIU", 4, 248827},
	{"RLPI", 4, 248828},
	{"RIFJ", 4, 248829},
	{"QSOM", 4, 248830},
	{"PAAV", 4, 248831},
	{"OYEW", 4, 248832},
	{"OEWR", 4, 248833},
	{"NBOF", 4, 248834},
	{"MRVO", 4, 248835},
	{"MLBR", 4, 248836},
	{"MGAD", 4, 248837},
	{"MEGN", 4, 248838},
	{"LOEG", 4, 248839},
	{"KYPH", 4, 248840},
	{"KUFI", 4, 248841},
	{"IMRY", 4, 248842},
	{"IKRU", 4, 248843},
	{"IEMD", 4, 248844},
	{"HLRO", 4, 248845},
	{"HCYN", 4, 248846},
	{"GODV", 4, 248847},
	{"GLOE", 4, 248848},
	{"GJEL", 4, 248849},
	{"GEWY", 4, 248850},
	{"GCPR", 4, 248851},
	{"GAIP", 4, 248852},
	{"FUTM", 4, 248853},
	{"FOEM", 4, 248854},
	{"FHYA", 4, 248855},
	{"FAXL", 4, 248856},
	{"EYAQ", 4, 248857},
	{"EURK", 4, 248858},
	{"ETFC", 4, 248859},
	{"EMUO", 4, 248860},
	{"DZEW", 4, 248861},
	{"DMPE", 4, 248862},
	{"DMEZ", 4, 248863},
	{"DCGO", 4, 248864},
	{"DBIH", 4, 248865},
	{"CMIK", 4, 248866},
	{"BOXK", 4, 248867},
	{"AKOG", 4, 248868},
	{"AFCU", 4, 248869},
	{"MANJUNATH", 9, 248870},
	{"TATORNEY", 8, 248871},
	{"PESQUISAR", 9, 248872},
	{"GEODES", 6, 248873},
	{"FRISTON", 7, 248874},
	{"KOOD", 4, 248875},
	{"HYMES", 5, 248876},
	{"GLEBLANC", 8, 248877},
	{"BUFFETING", 9, 248878},
	{"RIDNOUR", 7, 248879},
	{"SKINKS", 6, 248880},
	{"PSMA", 4, 248881},
	{"NIRVDRUM", 8, 248882},
	{"KALKA", 5, 248883},
	{"ANPING", 6, 248884},
	{"BOOKSIGNING", 11, 248885},
	{"PARTNERSCHAFT", 13, 248886},
	{"NOVECENTO", 9, 248887},
	{"ELLENBERG", 9, 248888},
	{"CODINGTON", 9, 248889},
	{"STOUGH", 6, 248890},
	{"BMCC", 4, 248891},
	{"ALTERNC", 7, 248892},
	{"PHOTOPOINTS", 11, 248893},
	{"GOOVLE", 6, 248894},
	{"HUNAJA", 6, 248895},
	{"UROGRAPHY", 9, 248896},
	{"UECKER", 6, 248897},
	{"BOLITHO", 7, 248898},
	{"POTTSBORO", 9, 248899},
	{"EXORCISMS", 9, 248900},
	{"SAROS", 5, 248901},
	{"MACTAVISH", 9, 248902},
	{"TRPA", 4, 248903},
	{"RHBA", 4, 248904},
	{"TONELLI", 7, 248905},
	{"SICKLERVILLE", 12, 248906},
	{"BARNEA", 6, 248907},
	{"GREU", 4, 248908},
	{"DESP", 4, 248909},
	{"ZIBA", 4, 248910},
	{"MAZEPPA", 7, 248911},
	{"CROUZET", 7, 248912},
	{"INDICAT", 7, 248913},
	{"TOCHTERGESELLSCHAFTEN", 21, 248914},
	{"VISUELLE", 8, 248915},
	{"ESCALI", 6, 248916},
	{"DOORKEEPER", 10, 248917},
	{"BANANAFISH", 10, 248918},
	{"CORNETTA", 8, 248919},
	{"PHINIUS", 7, 248920},
	{"INEFFECTIVELY", 13, 248921},
	{"BANNATYNE", 9, 248922},
	{"TRKA", 4, 248923},
	{"OUTENIQUA", 9, 248924},
	{"HISARONU", 8, 248925},
	{"CARTADD", 7, 248926},
	{"CIVIT", 5, 248927},
	{"TRIMET", 6, 248928},
	{"CEPHALONIA", 10, 248929},
	{"BRISTISH", 8, 248930},
	{"AGINET", 6, 248931},
	{"RECONVENES", 10, 248932},
	{"SANKOFA", 7, 248933},
	{"LENTS", 5, 248934},
	{"KOHEI", 5, 248935},
	{"KADDISFLY", 9, 248936},
	{"DORRIE", 6, 248937},
	{"BATTIN", 6, 248938},
	{"AICD", 4, 248939},
	{"ABSOLUMENT", 10, 248940},
	{"LILITA", 6, 248941},
	{"NAMBA", 5, 248942},
	{"INFY", 4, 248943},
	{"APPFORGE", 8, 248944},
	{"UAIR", 4, 248945},
	{"SYCOPHANTIC", 11, 248946},
	{"STEVESTON", 9, 248947},
	{"SPYWAREINFO", 11, 248948},
	{"SCHWARZENBERG", 13, 248949},
	{"ROGOWSKI", 8, 248950},
	{"KAZAMA", 6, 248951},
	{"HEARTRATE", 9, 248952},
	{"ROWBOTHAM", 9, 248953},
	{"MESODERMAL", 10, 248954},
	{"KOMAROV", 7, 248955},
	{"EDGELL", 6, 248956},
	{"CARSO", 5, 248957},
	{"BUSHRANGERS", 11, 248958},
	{"HYPERRESPONSIVENESS", 19, 248959},
	{"METHYLAMINE", 11, 248960},
	{"LAFCADIO", 8, 248961},
	{"DPREVIEW", 8, 248962},
	{"DONKLEPHANT", 11, 248963},
	{"VIRTON", 6, 248964},
	{"SPLICEOSOMAL", 12, 248965},
	{"NYCTICORAX", 10, 248966},
	{"LEZONLY", 7, 248967},
	{"HSPF", 4, 248968},
	{"BARSON", 6, 248969},
	{"INVERSO", 7, 248970},
	{"FURTO", 5, 248971},
	{"TRANSITIVELY", 12, 248972},
	{"PLITVICE", 8, 248973},
	{"PHOTOREALISM", 12, 248974},
	{"LEBOVITZ", 8, 248975},
	{"LINAGE", 6, 248976},
	{"ZANNA", 5, 248977},
	{"RIDISC", 6, 248978},
	{"CHIASSO", 7, 248979},
	{"IMENTS", 6, 248980},
	{"TOURNEMENT", 10, 248981},
	{"REALLYNICEGUY", 13, 248982},
	{"GINGERS", 7, 248983},
	{"WINGERT", 7, 248984},
	{"PADMINI", 7, 248985},
	{"GHUL", 4, 248986},
	{"BOUNTEOUS", 9, 248987},
	{"SHADOWPLAY", 10, 248988},
	{"UNDERSPEND", 10, 248989},
	{"CAMMIE", 6, 248990},
	{"TAMSULOSIN", 10, 248991},
	{"KAONS", 5, 248992},
	{"JANURARY", 8, 248993},
	{"STEINE", 6, 248994},
	{"PRESTWOOD", 9, 248995},
	{"DECONSTRUCTS", 12, 248996},
	{"PROSES", 6, 248997},
	{"PARETSKY", 8, 248998},
	{"IZETBEGOVIC", 11, 248999},
	{"EDITIEREN", 9, 249000},
	{"TEXTOR", 6, 249001},
	{"OBLITERATES", 11, 249002},
	{"COLOMBIANOS", 11, 249003},
	{"TERRITORIE", 10, 249004},
	{"TECCOR", 6, 249005},
	{"MATERS", 6, 249006},
	{"GRAMMATIK", 9, 249007},
	{"QTDOM", 5, 249008},
	{"PETRONELLA", 10, 249009},
	{"LULLING", 7, 249010},
	{"GUANYLYL", 8, 249011},
	{"SCOPRI", 6, 249012},
	{"DICCIONARIOS", 12, 249013},
	{"BRIGGSAE", 8, 249014},
	{"XUNG", 4, 249015},
	{"CALVET", 6, 249016},
	{"BOUNDINGBOX", 11, 249017},
	{"HANDSAW", 7, 249018},
	{"EMIAL", 5, 249019},
	{"CLIL", 4, 249020},
	{"PERIAPICAL", 10, 249021},
	{"NEWBE", 5, 249022},
	{"CANCERHELP", 10, 249023},
	{"GOOGLL", 6, 249024},
	{"TOUCHER", 7, 249025},
	{"SHEETER", 7, 249026},
	{"MCKOWN", 6, 249027},
	{"ENGENUITY", 9, 249028},
	{"COMERCIALWARE", 13, 249029},
	{"STREIGHT", 8, 249030},
	{"SOSBORNE", 8, 249031},
	{"BARRS", 5, 249032},
	{"ARRAYOBJECT", 11, 249033},
	{"YPM", 3, 249034},
	{"POSTINO", 7, 249035},
	{"GOOBLE", 6, 249036},
	{"WANDO", 5, 249037},
	{"PERMISION", 9, 249038},
	{"NICEA", 5, 249039},
	{"DRAMBUIE", 8, 249040},
	{"CIRCUT", 6, 249041},
	{"ATTRIBUTEVALUE", 14, 249042},
	{"BRAGGS", 6, 249043},
	{"KAYLIE", 6, 249044},
	{"HEIZER", 6, 249045},
	{"POLICYCOREUTILS", 15, 249046},
	{"NILOTICUS", 9, 249047},
	{"LILAS", 5, 249048},
	{"MERETZ", 6, 249049},
	{"BRIDESHEAD", 10, 249050},
	{"ALPINES", 7, 249051},
	{"ROWTH", 5, 249052},
	{"BLUETONGUE", 10, 249053},
	{"MJPEGTOOLS", 10, 249054},
	{"HELSE", 5, 249055},
	{"EPRDF", 5, 249056},
	{"PARTICOLARE", 11, 249057},
	{"KUOW", 4, 249058},
	{"INTERIX", 7, 249059},
	{"SIEBOLD", 7, 249060},
	{"RESPONSA", 8, 249061},
	{"NUKEEDIT", 8, 249062},
	{"VIDEOCAST", 9, 249063},
	{"CONCORDEBOY", 11, 249064},
	{"WILLINGER", 9, 249065},
	{"GYFLWYNO", 8, 249066},
	{"KLETNIEKS", 9, 249067},
	{"LEMMONS", 7, 249068},
	{"HOOLEHUA", 8, 249069},
	{"GEPE", 4, 249070},
	{"COLETTI", 7, 249071},
	{"ACRIS", 5, 249072},
	{"LUKIMBI", 7, 249073},
	{"FIORELLA", 8, 249074},
	{"DORKBOT", 7, 249075},
	{"PORTEDMODS", 10, 249076},
	{"MORHUA", 6, 249077},
	{"TROPSCH", 7, 249078},
	{"ARCADETOWN", 10, 249079},
	{"JOESPH", 6, 249080},
	{"EXCUTIVE", 8, 249081},
	{"CHOLESTEATOMA", 13, 249082},
	{"BRINLEY", 7, 249083},
	{"PELOS", 5, 249084},
	{"PCARD", 5, 249085},
	{"BOKANMELDELSER", 14, 249086},
	{"ONIDA", 5, 249087},
	{"CELFYDDYDAU", 11, 249088},
	{"OLEORESIN", 9, 249089},
	{"MELOIDOGYNE", 11, 249090},
	{"HUMPBACKS", 9, 249091},
	{"THALYS", 6, 249092},
	{"ONAMIA", 6, 249093},
	{"TTING", 5, 249094},
	{"ONAWA", 5, 249095},
	{"UMOR", 4, 249096},
	{"KADYELLEBEE", 11, 249097},
	{"IRPS", 4, 249098},
	{"CONOLLY", 7, 249099},
	{"BRLUG", 5, 249100},
	{"TECHSTORE", 9, 249101},
	{"BONICA", 6, 249102},
	{"BLOODSCALP", 10, 249103},
	{"WINACE", 6, 249104},
	{"PERMANENTEMENTE", 15, 249105},
	{"BHARATH", 7, 249106},
	{"ZZSE", 4, 249107},
	{"ZIMR", 4, 249108},
	{"ZFUN", 4, 249109},
	{"YITK", 4, 249110},
	{"YIMJ", 4, 249111},
	{"YEIL", 4, 249112},
	{"WMYN", 4, 249113},
	{"WDUB", 4, 249114},
	{"VJEN", 4, 249115},
	{"VIID", 4, 249116},
	{"VATB", 4, 249117},
	{"UXDO", 4, 249118},
	{"UTZB", 4, 249119},
	{"UTMD", 4, 249120},
	{"UKKE", 4, 249121},
	{"TMSD", 4, 249122},
	{"TMMS", 4, 249123},
	{"TDDR", 4, 249124},
	{"SXFO", 4, 249125},
	{"SPSD", 4, 249126},
	{"SEFB", 4, 249127},
	{"RYTS", 4, 249128},
	{"RUAW", 4, 249129},
	{"RNYU", 4, 249130},
	{"RDCD", 4, 249131},
	{"PSIV", 4, 249132},
	{"ONXD", 4, 249133},
	{"OMUI", 4, 249134},
	{"OKYT", 4, 249135},
	{"OHPK", 4, 249136},
	{"NZFO", 4, 249137},
	{"NYCD", 4, 249138},
	{"NPOG", 4, 249139},
	{"NPFE", 4, 249140},
	{"NLYZ", 4, 249141},
	{"NDUU", 4, 249142},
	{"MRWR", 4, 249143},
	{"MGAG", 4, 249144},
	{"LPBL", 4, 249145},
	{"LLGH", 4, 249146},
	{"LBJA", 4, 249147},
	{"LBHI", 4, 249148},
	{"KWEJ", 4, 249149},
	{"KCST", 4, 249150},
	{"JRSH", 4, 249151},
	{"JRNA", 4, 249152},
	{"JALB", 4, 249153},
	{"IZDO", 4, 249154},
	{"IUNF", 4, 249155},
	{"INFB", 4, 249156},
	{"HPDA", 4, 249157},
	{"HMRG", 4, 249158},
	{"HLDI", 4, 249159},
	{"HLBU", 4, 249160},
	{"GOXF", 4, 249161},
	{"GOVK", 4, 249162},
	{"FYVI", 4, 249163},
	{"FVOY", 4, 249164},
	{"FCBC", 4, 249165},
	{"ESXM", 4, 249166},
	{"EOKC", 4, 249167},
	{"ELGM", 4, 249168},
	{"EFYE", 4, 249169},
	{"EERQ", 4, 249170},
	{"EBBP", 4, 249171},
	{"DHDI", 4, 249172},
	{"DCEP", 4, 249173},
	{"CHOZ", 4, 249174},
	{"CENM", 4, 249175},
	{"BBUN", 4, 249176},
	{"AXFE", 4, 249177},
	{"ARNULF", 6, 249178},
	{"TRIKKE", 6, 249179},
	{"LANDMANN", 8, 249180},
	{"PODRAS", 6, 249181},
	{"PEPO", 4, 249182},
	{"FREMER", 6, 249183},
	{"DUNLEVY", 7, 249184},
	{"EFHMERIDA", 9, 249185},
	{"GILANI", 6, 249186},
	{"TEXTVERSION", 11, 249187},
	{"PRACTION", 8, 249188},
	{"IDEOGRAPHS", 10, 249189},
	{"GANTTHEAD", 9, 249190},
	{"AGENTLINK", 9, 249191},
	{"IVANOVO", 7, 249192},
	{"STONYFIELD", 10, 249193},
	{"MUNICIPALES", 11, 249194},
	{"GANGSTARR", 9, 249195},
	{"AIRASIA", 7, 249196},
	{"URBANIST", 8, 249197},
	{"FARMSTEADS", 10, 249198},
	{"KILFOYLE", 8, 249199},
	{"THYRA", 5, 249200},
	{"HOSPITA", 7, 249201},
	{"GOUDEY", 6, 249202},
	{"TRIPEAKS", 8, 249203},
	{"NROBERTS", 8, 249204},
	{"IMBER", 5, 249205},
	{"HPME", 4, 249206},
	{"CLUBFACE", 8, 249207},
	{"ACTIVEFORUMS", 12, 249208},
	{"STEELED", 7, 249209},
	{"KANTI", 5, 249210},
	{"DACOM", 5, 249211},
	{"CAREBEAR", 8, 249212},
	{"PATRONISED", 10, 249213},
	{"FERRAT", 6, 249214},
	{"FACILMENTE", 10, 249215},
	{"RHPS", 4, 249216},
	{"LINGUAE", 7, 249217},
	{"HOUSEGUEST", 10, 249218},
	{"LCDC", 4, 249219},
	{"JBAVIERA", 8, 249220},
	{"EDITIZE", 7, 249221},
	{"SOWDEN", 6, 249222},
	{"QUICKVERSE", 10, 249223},
	{"FRESA", 5, 249224},
	{"ABYSMALLY", 9, 249225},
	{"VISIONNEUSE", 11, 249226},
	{"DUNTROON", 8, 249227},
	{"YESHE", 5, 249228},
	{"EMBROIDERER", 11, 249229},
	{"BULLINGTON", 10, 249230},
	{"BROTHERSJUDD", 12, 249231},
	{"FENNESZ", 7, 249232},
	{"KRIG", 4, 249233},
	{"AGCC", 4, 249234},
	{"YANAGI", 6, 249235},
	{"WHISPERINGS", 11, 249236},
	{"WHAC", 4, 249237},
	{"MSWINDOWS", 9, 249238},
	{"IODIDES", 7, 249239},
	{"TREEING", 7, 249240},
	{"PORTHLEVEN", 10, 249241},
	{"IGREJA", 6, 249242},
	{"QUISQUE", 7, 249243},
	{"RHANBARTHOL", 11, 249244},
	{"HORTENSIUS", 10, 249245},
	{"BLAHDVD", 7, 249246},
	{"INTERLANGUAGE", 13, 249247},
	{"GOOLG", 5, 249248},
	{"EYECUP", 6, 249249},
	{"APPARET", 7, 249250},
	{"PANICLES", 8, 249251},
	{"EDGARS", 6, 249252},
	{"WINDOWSUPDATE", 13, 249253},
	{"DATZ", 4, 249254},
	{"HUMBLENESS", 10, 249255},
	{"CAMPITELLO", 10, 249256},
	{"BACKSET", 7, 249257},
	{"LIVERWORTS", 10, 249258},
	{"IMARKETING", 10, 249259},
	{"GENUITY", 7, 249260},
	{"FVB", 3, 249261},
	{"ABBEYFIELD", 10, 249262},
	{"OOSTBURG", 8, 249263},
	{"KORTRIGHT", 9, 249264},
	{"LANGI", 5, 249265},
	{"NAUSET", 6, 249266},
	{"ELEFANTEN", 9, 249267},
	{"CHINEES", 7, 249268},
	{"DETESTS", 7, 249269},
	{"TYRON", 5, 249270},
	{"TIMECHECK", 9, 249271},
	{"SAVARESE", 8, 249272},
	{"ODDLABS", 7, 249273},
	{"DUBBY", 5, 249274},
	{"CHARITE", 7, 249275},
	{"SINGLESNET", 10, 249276},
	{"ORGANISATIES", 12, 249277},
	{"KLOTEN", 6, 249278},
	{"EDFU", 4, 249279},
	{"WWWPICS", 7, 249280},
	{"MCELRATH", 8, 249281},
	{"MACENTEE", 8, 249282},
	{"ANASTASI", 8, 249283},
	{"WORDLISTS", 9, 249284},
	{"SIMAC", 5, 249285},
	{"STRUTH", 6, 249286},
	{"TOGET", 5, 249287},
	{"RECEI", 5, 249288},
	{"DNSBOX", 6, 249289},
	{"CLOSEBY", 7, 249290},
	{"USFL", 4, 249291},
	{"OXIME", 5, 249292},
	{"ELEPHONE", 8, 249293},
	{"SOULARD", 7, 249294},
	{"LEGIONARIES", 11, 249295},
	{"BUILDWORLD", 10, 249296},
	{"AMPHI", 5, 249297},
	{"PUMBAA", 6, 249298},
	{"INTERNETDIENSTEN", 16, 249299},
	{"HAUGHTINESS", 11, 249300},
	{"DEGETTE", 7, 249301},
	{"DEBES", 5, 249302},
	{"JEDIDIAH", 8, 249303},
	{"THIERER", 7, 249304},
	{"MAIORI", 6, 249305},
	{"TOPCOATS", 8, 249306},
	{"MFK", 3, 249307},
	{"INTERCUT", 8, 249308},
	{"FENDOM", 6, 249309},
	{"AMMIANO", 7, 249310},
	{"ALIVENESS", 9, 249311},
	{"WILLOWY", 7, 249312},
	{"TOURNIER", 8, 249313},
	{"SNOWBEE", 7, 249314},
	{"SHOTOVER", 8, 249315},
	{"MORRA", 5, 249316},
	{"SKYRAIL", 7, 249317},
	{"BASYE", 5, 249318},
	{"UNCURED", 7, 249319},
	{"MINUSTAH", 8, 249320},
	{"MARCINIAK", 9, 249321},
	{"JREPORT", 7, 249322},
	{"EKQESH", 6, 249323},
	{"BEARKATS", 8, 249324},
	{"LITTLEBIT", 9, 249325},
	{"CRYSTALLOGRAPHICA", 17, 249326},
	{"ANNULI", 6, 249327},
	{"TERAZ", 5, 249328},
	{"BRANDIES", 8, 249329},
	{"BARCEPUNDIT", 11, 249330},
	{"ATHOME", 6, 249331},
	{"WORKLOG", 7, 249332},
	{"TERBIUM", 7, 249333},
	{"SEMATARY", 8, 249334},
	{"HARBORMASTER", 12, 249335},
	{"VALENCIANO", 10, 249336},
	{"GGCGGG", 6, 249337},
	{"ULTIMELE", 8, 249338},
	{"OSFTWARE", 8, 249339},
	{"MUNNS", 5, 249340},
	{"FIBERFILL", 9, 249341},
	{"EASYGET", 7, 249342},
	{"CABARITA", 8, 249343},
	{"POSTY", 5, 249344},
	{"PERPLEXION", 10, 249345},
	{"NARELLAN", 8, 249346},
	{"AIRCEL", 6, 249347},
	{"ARTCORE", 7, 249348},
	{"PARUTION", 8, 249349},
	{"OMENTUM", 7, 249350},
	{"NEWSBLAST", 9, 249351},
	{"LANGWORTHY", 10, 249352},
	{"WIGET", 5, 249353},
	{"MINDBENDER", 10, 249354},
	{"FOPR", 4, 249355},
	{"KNMI", 4, 249356},
	{"ECPG", 4, 249357},
	{"ADASA", 5, 249358},
	{"STREPTOPELIA", 12, 249359},
	{"ILKA", 4, 249360},
	{"ASMODEUS", 8, 249361},
	{"OSZENIA", 7, 249362},
	{"LYCAEUM", 7, 249363},
	{"BOOKWEB", 7, 249364},
	{"DEFILING", 8, 249365},
	{"BANTOCK", 7, 249366},
	{"AKIHIKO", 7, 249367},
	{"PHARMCIES", 9, 249368},
	{"VASHI", 5, 249369},
	{"PCCS", 4, 249370},
	{"MONSTEROUS", 10, 249371},
	{"LOANLOWEST", 10, 249372},
	{"DISACCHARIDE", 12, 249373},
	{"BORAN", 5, 249374},
	{"VIDUKA", 6, 249375},
	{"SFMS", 4, 249376},
	{"NSURE", 5, 249377},
	{"HYDROLYSED", 10, 249378},
	{"GRIMMS", 6, 249379},
	{"DIBROMO", 7, 249380},
	{"PRONENESS", 9, 249381},
	{"PLOTMTV", 7, 249382},
	{"YELLVILLE", 9, 249383},
	{"MCROY", 5, 249384},
	{"ROLLATORS", 9, 249385},
	{"FRENCHWOMAN", 11, 249386},
	{"DISLODGING", 10, 249387},
	{"KARAKA", 6, 249388},
	{"HOLLINGHURST", 12, 249389},
	{"WIDDOWSON", 9, 249390},
	{"LORENSEN", 8, 249391},
	{"CLIFFTOP", 8, 249392},
	{"CATALONIAN", 10, 249393},
	{"CHORISMATE", 10, 249394},
	{"BELGOROD", 8, 249395},
	{"ABUSEREPORT", 11, 249396},
	{"TELCEL", 6, 249397},
	{"INTRAX", 6, 249398},
	{"DISSAPOINT", 10, 249399},
	{"DAVITAMON", 9, 249400},
	{"BETIDE", 6, 249401},
	{"ROTOGRAVURE", 11, 249402},
	{"UGRAVE", 6, 249403},
	{"OTTOCENTO", 9, 249404},
	{"JORDACHE", 8, 249405},
	{"YOANN", 5, 249406},
	{"SAMUELSEN", 9, 249407},
	{"INDEXICAL", 9, 249408},
	{"MICROFILAMENT", 13, 249409},
	{"WTLS", 4, 249410},
	{"JURKOWITZ", 9, 249411},
	{"FRIENDLOGIN", 11, 249412},
	{"VIOLENZ", 7, 249413},
	{"SICILIANS", 9, 249414},
	{"NWCC", 4, 249415},
	{"PALAISEAU", 9, 249416},
	{"GUSTARIA", 8, 249417},
	{"BOULUD", 6, 249418},
	{"UMENT", 5, 249419},
	{"RESC", 4, 249420},
	{"LORENTZEN", 9, 249421},
	{"ECKINGTON", 9, 249422},
	{"BRONCHOCONSTRICTION", 19, 249423},
	{"BERNARDA", 8, 249424},
	{"SUPERGROUPS", 11, 249425},
	{"SPELEOLOGY", 10, 249426},
	{"HAUULA", 6, 249427},
	{"BUDGED", 6, 249428},
	{"ANTONITO", 8, 249429},
	{"ZKOI", 4, 249430},
	{"ZDRU", 4, 249431},
	{"YRRA", 4, 249432},
	{"YKOE", 4, 249433},
	{"YHAK", 4, 249434},
	{"YCHH", 4, 249435},
	{"YAIG", 4, 249436},
	{"WRST", 4, 249437},
	{"WRAG", 4, 249438},
	{"WNNY", 4, 249439},
	{"VSJA", 4, 249440},
	{"UZUS", 4, 249441},
	{"UXSY", 4, 249442},
	{"URFG", 4, 249443},
	{"UOGA", 4, 249444},
	{"UHAJ", 4, 249445},
	{"TDSY", 4, 249446},
	{"TDIZ", 4, 249447},
	{"SVIJ", 4, 249448},
	{"SPSB", 4, 249449},
	{"SLMA", 4, 249450},
	{"RWYA", 4, 249451},
	{"RVOA", 4, 249452},
	{"RTJI", 4, 249453},
	{"ROVF", 4, 249454},
	{"RMYQ", 4, 249455},
	{"RHYA", 4, 249456},
	{"PSKW", 4, 249457},
	{"PLMA", 4, 249458},
	{"PKEH", 4, 249459},
	{"PHEJ", 4, 249460},
	{"OPYN", 4, 249461},
	{"OARP", 4, 249462},
	{"NYLB", 4, 249463},
	{"NMDI", 4, 249464},
	{"NLCA", 4, 249465},
	{"NDKF", 4, 249466},
	{"NDBG", 4, 249467},
	{"MNFL", 4, 249468},
	{"MMNA", 4, 249469},
	{"MHZM", 4, 249470},
	{"LWYD", 4, 249471},
	{"LOXT", 4, 249472},
	{"LMJA", 4, 249473},
	{"LMFL", 4, 249474},
	{"KOGR", 4, 249475},
	{"IVIJ", 4, 249476},
	{"IKMU", 4, 249477},
	{"IKBO", 4, 249478},
	{"IFYK", 4, 249479},
	{"IFOW", 4, 249480},
	{"HURV", 4, 249481},
	{"HEUY", 4, 249482},
	{"HDOV", 4, 249483},
	{"GTYL", 4, 249484},
	{"GTVC", 4, 249485},
	{"GLLO", 4, 249486},
	{"GGBA", 4, 249487},
	{"FSIV", 4, 249488},
	{"FRSP", 4, 249489},
	{"FHOD", 4, 249490},
	{"EXVO", 4, 249491},
	{"EHPL", 4, 249492},
	{"EDTL", 4, 249493},
	{"ECYF", 4, 249494},
	{"ECLC", 4, 249495},
	{"DJSW", 4, 249496},
	{"DJFO", 4, 249497},
	{"DHSB", 4, 249498},
	{"DDRN", 4, 249499},
	{"DAVP", 4, 249500},
	{"BMTO", 4, 249501},
	{"AKGI", 4, 249502},
	{"LEWTON", 6, 249503},
	{"FRIENDSFORWARD", 14, 249504},
	{"ESTIME", 6, 249505},
	{"ACGT", 4, 249506},
	{"LOANE", 5, 249507},
	{"COMPORTAMIENTO", 14, 249508},
	{"WSTOSO", 6, 249509},
	{"WIBRO", 5, 249510},
	{"WATHER", 6, 249511},
	{"KRUST", 5, 249512},
	{"PALOMIDES", 9, 249513},
	{"EMOLUMENT", 9, 249514},
	{"CHARLOTT", 8, 249515},
	{"BURGETTSTOWN", 12, 249516},
	{"BUDG", 4, 249517},
	{"RUFFORD", 7, 249518},
	{"PCCTS", 5, 249519},
	{"OBERLE", 6, 249520},
	{"INSRISCI", 8, 249521},
	{"HENRIE", 6, 249522},
	{"BILLIES", 7, 249523},
	{"APRX", 4, 249524},
	{"POSTWATCH", 9, 249525},
	{"PELLACH", 7, 249526},
	{"MONST", 5, 249527},
	{"DRAKENGARD", 10, 249528},
	{"WORTON", 6, 249529},
	{"SQUEALER", 8, 249530},
	{"MEDLEYS", 7, 249531},
	{"SYSTECH", 7, 249532},
	{"SMITHSBURG", 10, 249533},
	{"NCMS", 4, 249534},
	{"KLX", 3, 249535},
	{"FUNICELLO", 9, 249536},
	{"YARO", 4, 249537},
	{"MASSI", 5, 249538},
	{"LANCO", 5, 249539},
	{"HUSABERG", 8, 249540},
	{"AQBANKING", 9, 249541},
	{"ACKERSON", 8, 249542},
	{"SOORTEN", 7, 249543},
	{"MEINDERT", 8, 249544},
	{"FACCIO", 6, 249545},
	{"BIBLIOQUEST", 11, 249546},
	{"DECIMA", 6, 249547},
	{"POCZ", 4, 249548},
	{"MELVA", 5, 249549},
	{"CMPLX", 5, 249550},
	{"TESHUVAH", 8, 249551},
	{"OVERSIMPLIFY", 12, 249552},
	{"HYERES", 6, 249553},
	{"HAUTMAN", 7, 249554},
	{"ECHAD", 5, 249555},
	{"DILTS", 5, 249556},
	{"ADVANTUS", 8, 249557},
	{"RIFIUTI", 7, 249558},
	{"PIPETS", 6, 249559},
	{"DEHYDROGENATION", 15, 249560},
	{"CLAVEL", 6, 249561},
	{"BEAUTIE", 7, 249562},
	{"BAUDRATE", 8, 249563},
	{"AKREGATOR", 9, 249564},
	{"DEVELOPPERS", 11, 249565},
	{"PARTITAS", 8, 249566},
	{"EROTICSTORIES", 13, 249567},
	{"BROADFOOT", 9, 249568},
	{"MUJAHIDIN", 9, 249569},
	{"MEIKO", 5, 249570},
	{"DIZON", 5, 249571},
	{"JAPONESE", 8, 249572},
	{"HANDWHEEL", 9, 249573},
	{"GOPINION", 8, 249574},
	{"DESKTO", 6, 249575},
	{"AGLIO", 5, 249576},
	{"VECP", 4, 249577},
	{"UNSEATED", 8, 249578},
	{"TREISMAN", 8, 249579},
	{"SMARTPARTS", 10, 249580},
	{"JORDISON", 8, 249581},
	{"GFEDC", 5, 249582},
	{"ERICO", 5, 249583},
	{"DESHI", 5, 249584},
	{"TILBA", 5, 249585},
	{"LAKO", 4, 249586},
	{"COLLINGHAM", 10, 249587},
	{"UNLORD", 6, 249588},
	{"TIEDOWN", 7, 249589},
	{"RAMTHA", 6, 249590},
	{"AZESEARCH", 9, 249591},
	{"TISTICAL", 8, 249592},
	{"WACKEN", 6, 249593},
	{"TERMING", 7, 249594},
	{"SILKIES", 7, 249595},
	{"ROLLROOTSSINGER", 15, 249596},
	{"MUKUNDA", 7, 249597},
	{"CORWM", 5, 249598},
	{"WHALETOWN", 9, 249599},
	{"PPPSTATUS", 9, 249600},
	{"PHORIA", 6, 249601},
	{"MATZOH", 6, 249602},
	{"LEIDSEPLEIN", 11, 249603},
	{"LAVERS", 6, 249604},
	{"GGD", 3, 249605},
	{"PASTEDOWN", 9, 249606},
	{"RAWAL", 5, 249607},
	{"RAPIDGET", 8, 249608},
	{"GERMISTON", 9, 249609},
	{"NESHAMINY", 9, 249610},
	{"DOSBOX", 6, 249611},
	{"DETANGLER", 9, 249612},
	{"USUARI", 6, 249613},
	{"VIOLINO", 7, 249614},
	{"RIVALLED", 8, 249615},
	{"RAILHEAD", 8, 249616},
	{"PRITHEE", 7, 249617},
	{"LOGANS", 6, 249618},
	{"WIKINOTATION", 12, 249619},
	{"THREADGILL", 10, 249620},
	{"BUTOH", 5, 249621},
	{"WISSE", 5, 249622},
	{"LUBRIZOL", 8, 249623},
	{"KIKKOMAN", 8, 249624},
	{"COMEAUX", 7, 249625},
	{"STUDT", 5, 249626},
	{"CIKKOLATA", 9, 249627},
	{"SEARCHU", 7, 249628},
	{"ROCKEY", 6, 249629},
	{"EXPEDIENTS", 10, 249630},
	{"EXICO", 5, 249631},
	{"EURASIAHEALTH", 13, 249632},
	{"WINEGARD", 8, 249633},
	{"PULKOVO", 7, 249634},
	{"PERSICO", 7, 249635},
	{"ALAYKUM", 7, 249636},
	{"MAZURKAS", 8, 249637},
	{"DISABILI", 8, 249638},
	{"BEAUTIFIED", 10, 249639},
	{"BAQIR", 5, 249640},
	{"JOEYS", 5, 249641},
	{"DISKINTERNALS", 13, 249642},
	{"FUU", 3, 249643},
	{"EUCOM", 5, 249644},
	{"WESTERNPORT", 11, 249645},
	{"DOTZLER", 7, 249646},
	{"BEEPED", 6, 249647},
	{"QUIRINO", 7, 249648},
	{"MATRYOSHKA", 10, 249649},
	{"INTASC", 6, 249650},
	{"PHOTOCAMEL", 10, 249651},
	{"MULTIUSE", 8, 249652},
	{"ECONOMICAS", 10, 249653},
	{"MATEUS", 6, 249654},
	{"FAVORIETE", 9, 249655},
	{"LUPONE", 6, 249656},
	{"WEWOKA", 6, 249657},
	{"SEROLOGICALLY", 13, 249658},
	{"YACAS", 5, 249659},
	{"NHIBERNATE", 10, 249660},
	{"EXTRANJERO", 10, 249661},
	{"CAPUCINE", 8, 249662},
	{"ENCIRCLEMENT", 12, 249663},
	{"DEFLATES", 8, 249664},
	{"SALING", 6, 249665},
	{"MAGTF", 5, 249666},
	{"LAAGER", 6, 249667},
	{"ULISES", 6, 249668},
	{"RIVULATUS", 9, 249669},
	{"WHADDAYA", 8, 249670},
	{"WEINREB", 7, 249671},
	{"HYPOCOTYL", 9, 249672},
	{"AFFILIATING", 11, 249673},
	{"CORDINGLY", 9, 249674},
	{"RIPPY", 5, 249675},
	{"PRECIPICES", 10, 249676},
	{"NIKLAAS", 7, 249677},
	{"EXPLA", 5, 249678},
	{"BLUEJAKE", 8, 249679},
	{"BIOTYPES", 8, 249680},
	{"STABIN", 6, 249681},
	{"SNOOKS", 6, 249682},
	{"HANGA", 5, 249683},
	{"BICUSPID", 8, 249684},
	{"LWG", 3, 249685},
	{"LINKTIP", 7, 249686},
	{"LETREC", 6, 249687},
	{"ENDZ", 4, 249688},
	{"PROFFESIYNOL", 12, 249689},
	{"DARICE", 6, 249690},
	{"STAVIS", 6, 249691},
	{"REMKO", 5, 249692},
	{"PENTANGLE", 9, 249693},
	{"LUPINO", 6, 249694},
	{"LLEVAR", 6, 249695},
	{"HENERY", 6, 249696},
	{"WALKETH", 7, 249697},
	{"GEELY", 5, 249698},
	{"ESPION", 6, 249699},
	{"CHITARRA", 8, 249700},
	{"CARBOXAMIDE", 11, 249701},
	{"VOORBURG", 8, 249702},
	{"VERM", 4, 249703},
	{"QPC", 3, 249704},
	{"TECHNICOLOUR", 12, 249705},
	{"SPINERGY", 8, 249706},
	{"SCHUETTE", 8, 249707},
	{"CULBURRA", 8, 249708},
	{"MONOMORPHIC", 11, 249709},
	{"CCLS", 4, 249710},
	{"BLIZZ", 5, 249711},
	{"BALAGUER", 8, 249712},
	{"VLADE", 5, 249713},
	{"MINCHA", 6, 249714},
	{"INVERESK", 8, 249715},
	{"DAUFUSKIE", 9, 249716},
	{"YUZU", 4, 249717},
	{"MONTCLARE", 9, 249718},
	{"KADEN", 5, 249719},
	{"FRENTZEN", 8, 249720},
	{"FEFOCUS", 7, 249721},
	{"WWWPICTURES", 11, 249722},
	{"SEPER", 5, 249723},
	{"PRATIBHA", 8, 249724},
	{"METHACRYLIC", 11, 249725},
	{"ALTERNATIVO", 11, 249726},
	{"PLATFORMERS", 11, 249727},
	{"VARILUX", 7, 249728},
	{"VALEK", 5, 249729},
	{"MUTTA", 5, 249730},
	{"XYLICHEW", 8, 249731},
	{"TOPOGRAPHICALLY", 15, 249732},
	{"SPACESHOTS", 10, 249733},
	{"COLORIZING", 10, 249734},
	{"POHLMAN", 7, 249735},
	{"BYLER", 5, 249736},
	{"CHROMOLY", 8, 249737},
	{"UQM", 3, 249738},
	{"COURTICE", 8, 249739},
	{"AMCANION", 8, 249740},
	{"TERASEN", 7, 249741},
	{"RJTD", 4, 249742},
	{"LAWAL", 5, 249743},
	{"ORITE", 5, 249744},
	{"HOMCO", 5, 249745},
	{"GALLARYS", 8, 249746},
	{"FEROZ", 5, 249747},
	{"CARABALLO", 9, 249748},
	{"WAPLES", 6, 249749},
	{"PLASMACYTOMA", 12, 249750},
	{"METHANEX", 8, 249751},
	{"LUCTUS", 6, 249752},
	{"ETHNOS", 6, 249753},
	{"VFPRINTF", 8, 249754},
	{"PORTUMNA", 8, 249755},
	{"GILR", 4, 249756},
	{"BERTELSEN", 9, 249757},
	{"DLSU", 4, 249758},
	{"TEPPANYAKI", 10, 249759},
	{"SAVONAROLA", 10, 249760},
	{"PERCHERON", 9, 249761},
	{"LEUCOCEPHALUS", 13, 249762},
	{"FEER", 4, 249763},
	{"DIFFIDENCE", 10, 249764},
	{"WWWFETISH", 9, 249765},
	{"KEWADIN", 7, 249766},
	{"ZZIL", 4, 249767},
	{"ZMEX", 4, 249768},
	{"YUHO", 4, 249769},
	{"YBCW", 4, 249770},
	{"XERU", 4, 249771},
	{"XBON", 4, 249772},
	{"WMYO", 4, 249773},
	{"WIUS", 4, 249774},
	{"VWRO", 4, 249775},
	{"UTLD", 4, 249776},
	{"URMM", 4, 249777},
	{"UERZ", 4, 249778},
	{"TPEK", 4, 249779},
	{"TFBI", 4, 249780},
	{"TEGP", 4, 249781},
	{"TECF", 4, 249782},
	{"SCZA", 4, 249783},
	{"RYNY", 4, 249784},
	{"RKJI", 4, 249785},
	{"RFGE", 4, 249786},
	{"PSSK", 4, 249787},
	{"PAWW", 4, 249788},
	{"PAMG", 4, 249789},
	{"OZEC", 4, 249790},
	{"OXBL", 4, 249791},
	{"OMOJ", 4, 249792},
	{"OGFL", 4, 249793},
	{"OECC", 4, 249794},
	{"OCYO", 4, 249795},
	{"OAPD", 4, 249796},
	{"NTZB", 4, 249797},
	{"NMPE", 4, 249798},
	{"NJMA", 4, 249799},
	{"NGXE", 4, 249800},
	{"MSTV", 4, 249801},
	{"MOUZ", 4, 249802},
	{"MNFE", 4, 249803},
	{"MEZU", 4, 249804},
	{"MECB", 4, 249805},
	{"LPMF", 4, 249806},
	{"LAUV", 4, 249807},
	{"KTUM", 4, 249808},
	{"KKOK", 4, 249809},
	{"JEWO", 4, 249810},
	{"HMTR", 4, 249811},
	{"HMRR", 4, 249812},
	{"GPUE", 4, 249813},
	{"GKLA", 4, 249814},
	{"GIPL", 4, 249815},
	{"FLSW", 4, 249816},
	{"FCYT", 4, 249817},
	{"EJCC", 4, 249818},
	{"DQAN", 4, 249819},
	{"DIRB", 4, 249820},
	{"DIQA", 4, 249821},
	{"DHDD", 4, 249822},
	{"DGYS", 4, 249823},
	{"DCPC", 4, 249824},
	{"CSJE", 4, 249825},
	{"CPWH", 4, 249826},
	{"CPED", 4, 249827},
	{"BOPH", 4, 249828},
	{"BDIP", 4, 249829},
	{"AYCB", 4, 249830},
	{"ASBJ", 4, 249831},
	{"ANCG", 4, 249832},
	{"LAWD", 4, 249833},
	{"BARYCENTRIC", 11, 249834},
	{"VANDELLAS", 9, 249835},
	{"TABLESPOONFUL", 13, 249836},
	{"SINNAMON", 8, 249837},
	{"NANOBUSINESS", 12, 249838},
	{"SWINDLES", 8, 249839},
	{"MEDIABOX", 8, 249840},
	{"MEUM", 4, 249841},
	{"HILEMAN", 7, 249842},
	{"BTDINO", 6, 249843},
	{"BESTOWAL", 8, 249844},
	{"TITBITS", 7, 249845},
	{"TIMME", 5, 249846},
	{"POONAM", 6, 249847},
	{"HAVILL", 6, 249848},
	{"WWWGALLERIES", 12, 249849},
	{"ORLANDI", 7, 249850},
	{"STAGERS", 7, 249851},
	{"SEMIMAJOR", 9, 249852},
	{"SAUBERKEIT", 10, 249853},
	{"BELVILLE", 8, 249854},
	{"RGANIZATION", 11, 249855},
	{"POXY", 4, 249856},
	{"JUANITO", 7, 249857},
	{"HENSLOW", 7, 249858},
	{"CELAYIX", 7, 249859},
	{"POLONSKY", 8, 249860},
	{"IBEROTEL", 8, 249861},
	{"DZIA", 4, 249862},
	{"FRYSK", 5, 249863},
	{"DVOA", 4, 249864},
	{"DURRANCE", 8, 249865},
	{"AELIUS", 6, 249866},
	{"RIPOLL", 6, 249867},
	{"FREAKBEAT", 9, 249868},
	{"SIEGWART", 8, 249869},
	{"DOPANTS", 7, 249870},
	{"MYMENTOR", 8, 249871},
	{"MUCCI", 5, 249872},
	{"MATRIMONIALE", 12, 249873},
	{"MADWAVE", 7, 249874},
	{"GIRMI", 5, 249875},
	{"ROMBAUER", 8, 249876},
	{"KOMEDIE", 7, 249877},
	{"GRINDMASTER", 11, 249878},
	{"ANANDAUTSAV", 11, 249879},
	{"OVERREACTED", 11, 249880},
	{"LDEQ", 4, 249881},
	{"SMACNA", 6, 249882},
	{"MOUNTMELLICK", 12, 249883},
	{"MENDACIOUS", 10, 249884},
	{"ADVENTISM", 9, 249885},
	{"KUFSTEIN", 8, 249886},
	{"DHAVID", 6, 249887},
	{"DERENZY", 7, 249888},
	{"AMITRI", 6, 249889},
	{"PCOM", 4, 249890},
	{"SDRC", 4, 249891},
	{"EMPEROUR", 8, 249892},
	{"CAWTHORNE", 9, 249893},
	{"STANNO", 6, 249894},
	{"PVCC", 4, 249895},
	{"MTOR", 4, 249896},
	{"ARKAOS", 6, 249897},
	{"ADDCHILD", 8, 249898},
	{"TSQL", 4, 249899},
	{"SHEYENNE", 8, 249900},
	{"INDRAGOSTITILOR", 15, 249901},
	{"ICNORTHWALES", 12, 249902},
	{"MINUTA", 6, 249903},
	{"CORDARONE", 9, 249904},
	{"BUINESS", 7, 249905},
	{"BOHMAN", 6, 249906},
	{"SONGKRAN", 8, 249907},
	{"CLEBS", 5, 249908},
	{"BUYMUSIC", 8, 249909},
	{"TINGLED", 7, 249910},
	{"GOOEL", 5, 249911},
	{"SARFATTI", 8, 249912},
	{"NARROMINE", 9, 249913},
	{"LENZI", 5, 249914},
	{"BOOKOUT", 7, 249915},
	{"ALLBRIGHT", 9, 249916},
	{"RUNDELL", 7, 249917},
	{"PELLI", 5, 249918},
	{"GINEPRO", 7, 249919},
	{"BLUEJACKING", 11, 249920},
	{"ARCHLORD", 8, 249921},
	{"LISU", 4, 249922},
	{"DILWYN", 6, 249923},
	{"THORNDON", 8, 249924},
	{"SWECKER", 7, 249925},
	{"CHIMIQUES", 9, 249926},
	{"SNIPPING", 8, 249927},
	{"GIROUARD", 8, 249928},
	{"BSIZE", 5, 249929},
	{"NISOURCE", 8, 249930},
	{"IMMUNOELECTRON", 14, 249931},
	{"IMAGECOLORALLOCATE", 18, 249932},
	{"FSWISS", 6, 249933},
	{"FAROL", 5, 249934},
	{"TASSLES", 7, 249935},
	{"PHENOLOGICAL", 12, 249936},
	{"MJW", 3, 249937},
	{"MAPY", 4, 249938},
	{"LTCM", 4, 249939},
	{"BELLAIRS", 8, 249940},
	{"HEATHMAN", 8, 249941},
	{"ALAGOAS", 7, 249942},
	{"YACOM", 5, 249943},
	{"LIENHARD", 8, 249944},
	{"LENTULUS", 8, 249945},
	{"OLMS", 4, 249946},
	{"MARITIMUS", 9, 249947},
	{"COMMONHOLD", 10, 249948},
	{"OHAKUNE", 7, 249949},
	{"FRANSE", 6, 249950},
	{"DISINFO", 7, 249951},
	{"DEMORALISED", 11, 249952},
	{"STOYAN", 6, 249953},
	{"CLIFTONVILLE", 12, 249954},
	{"HANDCUFFING", 11, 249955},
	{"FONCTIONNE", 10, 249956},
	{"DELERUE", 7, 249957},
	{"SYMPO", 5, 249958},
	{"TRICAL", 6, 249959},
	{"STINKERS", 8, 249960},
	{"PIPPED", 6, 249961},
	{"MCCULLUM", 8, 249962},
	{"GIGASTACK", 9, 249963},
	{"ACTIVEPDF", 9, 249964},
	{"ONKAPARINGA", 11, 249965},
	{"FLAXMAN", 7, 249966},
	{"CHURNIN", 7, 249967},
	{"LAUNDRETTE", 10, 249968},
	{"KIRDY", 5, 249969},
	{"SUAECES", 7, 249970},
	{"RCCS", 4, 249971},
	{"PIANETA", 7, 249972},
	{"HOTELC", 6, 249973},
	{"THOUGHTWORKS", 12, 249974},
	{"TERACTION", 9, 249975},
	{"DEMOED", 6, 249976},
	{"WXPH", 4, 249977},
	{"YESSIR", 6, 249978},
	{"WWBC", 4, 249979},
	{"FIGMENTS", 8, 249980},
	{"JIANCHAO", 8, 249981},
	{"SOROKA", 6, 249982},
	{"ARABIST", 7, 249983},
	{"XIAOLIN", 7, 249984},
	{"WOMS", 4, 249985},
	{"TERRACAN", 8, 249986},
	{"TASSELL", 7, 249987},
	{"STEREOSCOPE", 11, 249988},
	{"SNOWBLOWERS", 11, 249989},
	{"PYRUVIC", 7, 249990},
	{"YELLOWJACKET", 12, 249991},
	{"VERDISSIMA", 10, 249992},
	{"NICCO", 5, 249993},
	{"NEXTERNAL", 9, 249994},
	{"BALKON", 6, 249995},
	{"WILMERDING", 10, 249996},
	{"RAMPERSAD", 9, 249997},
	{"KIMYA", 5, 249998},
	{"YVQ", 3, 249999},
	{"YJQ", 3, 250000},
	{"XQQ", 3, 250001},
	{"XMJ", 3, 250002},
	{"VGZ", 3, 250003},
	{"UVQ", 3, 250004},
	{"QVL", 3, 250005},
	{"QQG", 3, 250006},
	{"QJB", 3, 250007},
	{"PQY", 3, 250008},
	{"PQV", 3, 250009},
	{"PJX", 3, 250010},
	{"JYQ", 3, 250011},
	{"JXU", 3, 250012},
	{"BQY", 3, 250013},
	{"BQX", 3, 250014},
	{"BQQ", 3, 250015},
	{"SELSDON", 7, 250016},
	{"NDASH", 5, 250017},
	{"HANGEN", 6, 250018},
	{"EPROMS", 6, 250019},
	{"DIWANI", 6, 250020},
	{"BUNNINGS", 8, 250021},
	{"AWID", 4, 250022},
	{"PRODUK", 6, 250023},
	{"DOWNRIGGER", 10, 250024},
	{"BELLMONT", 8, 250025},
	{"AYAZ", 4, 250026},
	{"AUSBLENDEN", 10, 250027},
	{"ALFS", 4, 250028},
	{"TESTIMONALS", 11, 250029},
	{"PHONECALL", 9, 250030},
	{"MONTAUBAN", 9, 250031},
	{"KRAMSKI", 7, 250032},
	{"FOREPERSON", 10, 250033},
	{"ESCRIBA", 7, 250034},
	{"DARKFIELD", 9, 250035},
	{"SHOUJI", 6, 250036},
	{"OREOCHROMIS", 11, 250037},
	{"GOBBY", 5, 250038},
	{"WWWTGP", 6, 250039},
	{"COMOVING", 8, 250040},
	{"YPLUS", 5, 250041},
	{"PCHILD", 6, 250042},
	{"LYCA", 4, 250043},
	{"COECIENTS", 9, 250044},
	{"WOYAA", 5, 250045},
	{"TOPAZES", 7, 250046},
	{"THEMAN", 6, 250047},
	{"FILEHANDLES", 11, 250048},
	{"RCCL", 4, 250049},
	{"LADYHAWKE", 9, 250050},
	{"AWASU", 5, 250051},
	{"ADDMODULE", 9, 250052},
	{"SPACKMAN", 8, 250053},
	{"CREATEELEMENT", 13, 250054},
	{"ZYF", 3, 250055},
	{"XFILES", 6, 250056},
	{"NTFPS", 5, 250057},
	{"JADOT", 5, 250058},
	{"HASIDISM", 8, 250059},
	{"ANTONIOS", 8, 250060},
	{"WITHERINGTON", 12, 250061},
	{"JMENUITEM", 9, 250062},
	{"GOOLEG", 6, 250063},
	{"IMPRIMERIE", 10, 250064},
	{"GEWEX", 5, 250065},
	{"DHOOM", 5, 250066},
	{"HOMETEK", 7, 250067},
	{"VSLIVE", 6, 250068},
	{"LCPC", 4, 250069},
	{"HCAL", 4, 250070},
	{"MCKUEN", 6, 250071},
	{"JACS", 4, 250072},
	{"GOOGEEL", 7, 250073},
	{"GGGOLE", 6, 250074},
	{"CONDUIRE", 8, 250075},
	{"CANNELLA", 8, 250076},
	{"SIFTS", 5, 250077},
	{"BOOKZ", 5, 250078},
	{"BECCARIA", 8, 250079},
	{"SCHLICK", 7, 250080},
	{"LASVEGASHOTEL", 13, 250081},
	{"GOLLGE", 6, 250082},
	{"TRAVELAPE", 9, 250083},
	{"GOOOLGE", 7, 250084},
	{"GETHIN", 6, 250085},
	{"PERRING", 7, 250086},
	{"MAMBELFISH", 10, 250087},
	{"ADHESIVENESS", 12, 250088},
	{"GOYLE", 5, 250089},
	{"CEFAZOLIN", 9, 250090},
	{"RANDE", 5, 250091},
	{"NEPHRITE", 8, 250092},
	{"LONGINUS", 8, 250093},
	{"SPMD", 4, 250094},
	{"EMOTIONALISM", 12, 250095},
	{"SKYTOP", 6, 250096},
	{"HYDROXYCHLOROQUINE", 18, 250097},
	{"CAPELL", 6, 250098},
	{"ZOOD", 4, 250099},
	{"ZIGT", 4, 250100},
	{"YPCS", 4, 250101},
	{"YMOG", 4, 250102},
	{"YMCS", 4, 250103},
	{"YCYL", 4, 250104},
	{"YATZ", 4, 250105},
	{"WWBL", 4, 250106},
	{"WTHY", 4, 250107},
	{"WKEI", 4, 250108},
	{"WBAF", 4, 250109},
	{"VAJU", 4, 250110},
	{"UZAB", 4, 250111},
	{"UVAM", 4, 250112},
	{"USDH", 4, 250113},
	{"URFD", 4, 250114},
	{"UPOO", 4, 250115},
	{"UERV", 4, 250116},
	{"UCSU", 4, 250117},
	{"TZPU", 4, 250118},
	{"TFSY", 4, 250119},
	{"TCCE", 4, 250120},
	{"SMFU", 4, 250121},
	{"RYZG", 4, 250122},
	{"RYLK", 4, 250123},
	{"RWMA", 4, 250124},
	{"RSKW", 4, 250125},
	{"RROQ", 4, 250126},
	{"RNYB", 4, 250127},
	{"RLBL", 4, 250128},
	{"RDTB", 4, 250129},
	{"QISU", 4, 250130},
	{"PIRK", 4, 250131},
	{"OIMD", 4, 250132},
	{"OGDU", 4, 250133},
	{"OFWB", 4, 250134},
	{"NJIV", 4, 250135},
	{"MKOO", 4, 250136},
	{"LIXG", 4, 250137},
	{"JWAR", 4, 250138},
	{"JBEC", 4, 250139},
	{"INXW", 4, 250140},
	{"IMFH", 4, 250141},
	{"HKEM", 4, 250142},
	{"GHSQ", 4, 250143},
	{"GAIW", 4, 250144},
	{"FUPB", 4, 250145},
	{"FRUF", 4, 250146},
	{"FMSU", 4, 250147},
	{"FJIL", 4, 250148},
	{"FELH", 4, 250149},
	{"EVRU", 4, 250150},
	{"EKMD", 4, 250151},
	{"EHPC", 4, 250152},
	{"EAUU", 4, 250153},
	{"DLAE", 4, 250154},
	{"DIIC", 4, 250155},
	{"CEMM", 4, 250156},
	{"CCBO", 4, 250157},
	{"BPFO", 4, 250158},
	{"AVOB", 4, 250159},
	{"AVKI", 4, 250160},
	{"ATFB", 4, 250161},
	{"ARLZ", 4, 250162},
	{"ALPD", 4, 250163},
	{"AKHD", 4, 250164},
	{"AFIW", 4, 250165},
	{"PULLY", 5, 250166},
	{"MORTONS", 7, 250167},
	{"BUSCEMA", 7, 250168},
	{"ACQUAVIVA", 9, 250169},
	{"TALAMANCA", 9, 250170},
	{"PLATIPUS", 8, 250171},
	{"NEUADD", 6, 250172},
	{"WWWFACIALS", 10, 250173},
	{"UNRELIEVED", 10, 250174},
	{"SBORRATE", 8, 250175},
	{"HITCHINS", 8, 250176},
	{"FRANKLINS", 9, 250177},
	{"EAPG", 4, 250178},
	{"COMPLEXING", 10, 250179},
	{"OSTRACISED", 10, 250180},
	{"MOSKAL", 6, 250181},
	{"MATUSOW", 7, 250182},
	{"KAAAWA", 6, 250183},
	{"JZJ", 3, 250184},
	{"FALLAS", 6, 250185},
	{"DAYO", 4, 250186},
	{"BIGRAM", 6, 250187},
	{"WEDING", 6, 250188},
	{"SWOSU", 5, 250189},
	{"FLUMMOXED", 9, 250190},
	{"UNWINDS", 7, 250191},
	{"SUBSTITUE", 9, 250192},
	{"BIOMEDCENTRAL", 13, 250193},
	{"MALVOLIO", 8, 250194},
	{"BIALEK", 6, 250195},
	{"SORRELLS", 8, 250196},
	{"RUIMTE", 6, 250197},
	{"MORGON", 6, 250198},
	{"JARING", 6, 250199},
	{"GENOTROPIN", 10, 250200},
	{"AUTONATION", 10, 250201},
	{"CURTO", 5, 250202},
	{"AMERIKANISCHE", 13, 250203},
	{"UNIMAGINED", 10, 250204},
	{"PERKIOMEN", 9, 250205},
	{"MARAS", 5, 250206},
	{"JORI", 4, 250207},
	{"UNCATEGORIZABLE", 15, 250208},
	{"SUBLIMINALLY", 12, 250209},
	{"JOELIB", 6, 250210},
	{"SCILLA", 6, 250211},
	{"HEALTHCONNECT", 13, 250212},
	{"DEVELOPPING", 11, 250213},
	{"SENSICAL", 8, 250214},
	{"METAPRODUCTS", 12, 250215},
	{"LAGERND", 7, 250216},
	{"YALAFORGE", 9, 250217},
	{"WOODLING", 8, 250218},
	{"THAMMARAT", 9, 250219},
	{"ARIOSTO", 7, 250220},
	{"TELLEZ", 6, 250221},
	{"MENCARI", 7, 250222},
	{"NDUE", 4, 250223},
	{"SWINDLING", 9, 250224},
	{"MEDDELANDEN", 11, 250225},
	{"ITTIHAD", 7, 250226},
	{"MAHONIA", 7, 250227},
	{"LILYETTE", 8, 250228},
	{"HYANG", 5, 250229},
	{"GRAMLICH", 8, 250230},
	{"GEEKED", 6, 250231},
	{"ARDIENTES", 9, 250232},
	{"WESTHOST", 8, 250233},
	{"FALSIFIES", 9, 250234},
	{"SUPERSTUD", 9, 250235},
	{"NAAMIAISJUHLA", 13, 250236},
	{"MNGR", 4, 250237},
	{"VELTMAN", 7, 250238},
	{"SODHI", 5, 250239},
	{"SARAGOSSA", 9, 250240},
	{"ADAULT", 6, 250241},
	{"PROTECTABLE", 11, 250242},
	{"KAPURTHALA", 10, 250243},
	{"TCMS", 4, 250244},
	{"NEOCLASSIC", 10, 250245},
	{"CHRISTODOULOU", 13, 250246},
	{"SIGCSE", 6, 250247},
	{"HAKAMA", 6, 250248},
	{"GORATH", 6, 250249},
	{"TIMEINEUROPE", 12, 250250},
	{"GOBIN", 5, 250251},
	{"SWINSON", 7, 250252},
	{"KUSHI", 5, 250253},
	{"BVSC", 4, 250254},
	{"XKMS", 4, 250255},
	{"RWHO", 4, 250256},
	{"LUCKENBACH", 10, 250257},
	{"TELEPLUS", 8, 250258},
	{"VOTAW", 5, 250259},
	{"PLAYTHE", 7, 250260},
	{"MYCOPLASMAS", 11, 250261},
	{"BIJU", 4, 250262},
	{"POLLI", 5, 250263},
	{"GLADIATORIAL", 12, 250264},
	{"DILLWYN", 7, 250265},
	{"QUIRKIES", 8, 250266},
	{"QUENCIES", 8, 250267},
	{"PARALLHLA", 9, 250268},
	{"MINTZER", 7, 250269},
	{"KELLOGS", 7, 250270},
	{"DEALERNEWS", 10, 250271},
	{"MEISTENS", 8, 250272},
	{"JOYFULL", 7, 250273},
	{"MAGAN", 5, 250274},
	{"GDPS", 4, 250275},
	{"GAMBRO", 6, 250276},
	{"MANGELS", 7, 250277},
	{"INOCULANT", 9, 250278},
	{"COZIER", 6, 250279},
	{"AUTHENTICATORS", 14, 250280},
	{"ULTRACOLD", 9, 250281},
	{"RESIDENTIALLY", 13, 250282},
	{"HAMMAR", 6, 250283},
	{"CONFRATERNITY", 13, 250284},
	{"SCAGLIONE", 9, 250285},
	{"PHILOSOPHIA", 11, 250286},
	{"INSTABLOGS", 10, 250287},
	{"FREESITE", 8, 250288},
	{"DOOMHAMMER", 10, 250289},
	{"SWITCHBLADES", 12, 250290},
	{"PHARELL", 7, 250291},
	{"GILAT", 5, 250292},
	{"COINCIDENTLY", 12, 250293},
	{"FLATTEST", 8, 250294},
	{"CULTIVABLE", 10, 250295},
	{"BALBO", 5, 250296},
	{"WHORLED", 7, 250297},
	{"BALLANTRAE", 10, 250298},
	{"WILHELMSHAVEN", 13, 250299},
	{"BERTELLI", 8, 250300},
	{"GERELATEERDE", 12, 250301},
	{"AXBRIDGE", 8, 250302},
	{"YOWIE", 5, 250303},
	{"PAVLO", 5, 250304},
	{"GYNNAL", 6, 250305},
	{"CONVINIENT", 10, 250306},
	{"BLAZEY", 6, 250307},
	{"OPENCT", 6, 250308},
	{"MONEYCLIPS", 10, 250309},
	{"FILIBUSTERED", 12, 250310},
	{"HELPONINSTALLING", 16, 250311},
	{"EMBRACEABLE", 11, 250312},
	{"DURSLEYS", 8, 250313},
	{"CANUS", 5, 250314},
	{"MAINTANANCE", 11, 250315},
	{"TREOCENTRAL", 11, 250316},
	{"QUIETS", 6, 250317},
	{"PIRC", 4, 250318},
	{"PANKISI", 7, 250319},
	{"KLAY", 4, 250320},
	{"DEPENDABLY", 10, 250321},
	{"ASTRONAUTICA", 12, 250322},
	{"CYLINDRICA", 10, 250323},
	{"ARCHIPELAGOS", 12, 250324},
	{"PAOLUCCI", 8, 250325},
	{"LUCULLUS", 8, 250326},
	{"HTCHECK", 7, 250327},
	{"AEROBICALLY", 11, 250328},
	{"ROSSEL", 6, 250329},
	{"ICEST", 5, 250330},
	{"BUMGARDNER", 10, 250331},
	{"VEREEN", 6, 250332},
	{"NFLU", 4, 250333},
	{"MALAI", 5, 250334},
	{"WECHSELN", 8, 250335},
	{"SELECTBOARD", 11, 250336},
	{"LSASS", 5, 250337},
	{"LAMBERTW", 8, 250338},
	{"SUITA", 5, 250339},
	{"PARTHIANS", 9, 250340},
	{"FORUMCO", 7, 250341},
	{"THEOREMA", 8, 250342},
	{"EMPIRIX", 7, 250343},
	{"CRYSTALLIZING", 13, 250344},
	{"LUTIONS", 7, 250345},
	{"LONGMORE", 8, 250346},
	{"CULTURALI", 9, 250347},
	{"PROPHOTO", 8, 250348},
	{"LATERALUS", 9, 250349},
	{"VWC", 3, 250350},
	{"SYSTIMAX", 8, 250351},
	{"SCHRYVER", 8, 250352},
	{"PETRICH", 7, 250353},
	{"EBBC", 4, 250354},
	{"BUERGER", 7, 250355},
	{"WWWTERRAES", 10, 250356},
	{"ERYN", 4, 250357},
	{"ANTHOCYANIN", 11, 250358},
	{"ANTHELMINTICS", 13, 250359},
	{"WINNETT", 7, 250360},
	{"MYOTUBES", 8, 250361},
	{"INADVERTENCE", 12, 250362},
	{"IKKI", 4, 250363},
	{"GUILLOCHE", 9, 250364},
	{"NORDISKA", 8, 250365},
	{"EELCOVISSER", 11, 250366},
	{"CHRISTV", 7, 250367},
	{"ADJTIMEX", 8, 250368},
	{"VISTARIL", 8, 250369},
	{"OUROBOROS", 9, 250370},
	{"LARN", 4, 250371},
	{"CALLISBURG", 10, 250372},
	{"NAIRNE", 6, 250373},
	{"ENTRENCHING", 11, 250374},
	{"WRTY", 4, 250375},
	{"PODLE", 5, 250376},
	{"MORINAGA", 8, 250377},
	{"OTHERPRESS", 10, 250378},
	{"CASTRONEVES", 11, 250379},
	{"SADIK", 5, 250380},
	{"PARALLAXOFFSET", 14, 250381},
	{"MOVF", 4, 250382},
	{"RENDERTEXT", 10, 250383},
	{"HOLDRIDGE", 9, 250384},
	{"RASTERS", 7, 250385},
	{"YAHOOCHAT", 9, 250386},
	{"PPIS", 4, 250387},
	{"NANDITA", 7, 250388},
	{"LICHTEN", 7, 250389},
	{"GALEANO", 7, 250390},
	{"WINDRES", 7, 250391},
	{"SEMMENS", 7, 250392},
	{"ROCKPSYCHEDELIC", 15, 250393},
	{"BREMSHEY", 8, 250394},
	{"ISOLINUX", 8, 250395},
	{"WYKONAWCA", 9, 250396},
	{"LAWHELP", 7, 250397},
	{"DEININGER", 9, 250398},
	{"CULINARIA", 9, 250399},
	{"CAREERGRAPH", 11, 250400},
	{"DFCI", 4, 250401},
	{"HELMICK", 7, 250402},
	{"BARDIN", 6, 250403},
	{"INVISTICS", 9, 250404},
	{"GRRLS", 5, 250405},
	{"SILKWEIGHT", 10, 250406},
	{"CROPLANDS", 9, 250407},
	{"CANTALOUPES", 11, 250408},
	{"IRGINIA", 7, 250409},
	{"GLYCYL", 6, 250410},
	{"UNCHS", 5, 250411},
	{"STICKLAND", 9, 250412},
	{"PERCEPTRONS", 11, 250413},
	{"CHABRIER", 8, 250414},
	{"MESOPHYLL", 9, 250415},
	{"CHANNE", 6, 250416},
	{"UHMM", 4, 250417},
	{"LIONNI", 6, 250418},
	{"CASELLI", 7, 250419},
	{"SYMPATHECTOMY", 13, 250420},
	{"NORRITON", 8, 250421},
	{"JYNX", 4, 250422},
	{"CIMICIFUGA", 10, 250423},
	{"PARER", 5, 250424},
	{"KYPRIAKHS", 9, 250425},
	{"BELIEVABLY", 10, 250426},
	{"AARTS", 5, 250427},
	{"PERLON", 6, 250428},
	{"MICROMOLAR", 10, 250429},
	{"WEATHERPROOFING", 15, 250430},
	{"IMAGETYPE", 9, 250431},
	{"UDU", 3, 250432},
	{"TRIBLE", 6, 250433},
	{"SKRIPT", 6, 250434},
	{"REICHEN", 7, 250435},
	{"DRUGMAKERS", 10, 250436},
	{"SXETIKA", 7, 250437},
	{"SIDEBOTTOM", 10, 250438},
	{"RUPPEL", 6, 250439},
	{"PUREES", 6, 250440},
	{"SKEFFINGTON", 11, 250441},
	{"MYUNSW", 6, 250442},
	{"LEUCHTER", 8, 250443},
	{"KURAMOTO", 8, 250444},
	{"PROBLHMA", 8, 250445},
	{"BOALSBURG", 9, 250446},
	{"WOODMOOR", 8, 250447},
	{"NINILCHIK", 9, 250448},
	{"TRANSRACIAL", 11, 250449},
	{"HOMEBODY", 8, 250450},
	{"ESKEW", 5, 250451},
	{"APOSTOLAKIS", 11, 250452},
	{"ZSEC", 4, 250453},
	{"ZPAL", 4, 250454},
	{"YSZC", 4, 250455},
	{"YJRH", 4, 250456},
	{"YEEV", 4, 250457},
	{"XTIC", 4, 250458},
	{"WSEY", 4, 250459},
	{"WKIM", 4, 250460},
	{"WBYJ", 4, 250461},
	{"VYES", 4, 250462},
	{"VCHO", 4, 250463},
	{"UYID", 4, 250464},
	{"USOY", 4, 250465},
	{"USKL", 4, 250466},
	{"URLW", 4, 250467},
	{"UIPU", 4, 250468},
	{"UBYL", 4, 250469},
	{"TYCC", 4, 250470},
	{"TKLO", 4, 250471},
	{"TDJO", 4, 250472},
	{"SZUC", 4, 250473},
	{"STBP", 4, 250474},
	{"SLRE", 4, 250475},
	{"SEFC", 4, 250476},
	{"RYDS", 4, 250477},
	{"RWOW", 4, 250478},
	{"RUTK", 4, 250479},
	{"RRFA", 4, 250480},
	{"RIVU", 4, 250481},
	{"RCUD", 4, 250482},
	{"RBVI", 4, 250483},
	{"QLAS", 4, 250484},
	{"QDUR", 4, 250485},
	{"PTSV", 4, 250486},
	{"PRPA", 4, 250487},
	{"PLOE", 4, 250488},
	{"PEWF", 4, 250489},
	{"PDYN", 4, 250490},
	{"PCSB", 4, 250491},
	{"PAIU", 4, 250492},
	{"OROQ", 4, 250493},
	{"NZUC", 4, 250494},
	{"NSYC", 4, 250495},
	{"NPCT", 4, 250496},
	{"NKUO", 4, 250497},
	{"MUAT", 4, 250498},
	{"MMRB", 4, 250499},
	{"MHLE", 4, 250500},
	{"LZNI", 4, 250501},
	{"LWAX", 4, 250502},
	{"LTAZ", 4, 250503},
	{"LILR", 4, 250504},
	{"LFSF", 4, 250505},
	{"KMCN", 4, 250506},
	{"KDEW", 4, 250507},
	{"JOFO", 4, 250508},
	{"JAFJ", 4, 250509},
	{"JAFI", 4, 250510},
	{"JADR", 4, 250511},
	{"HYUP", 4, 250512},
	{"HWOW", 4, 250513},
	{"HRMO", 4, 250514},
	{"HDUF", 4, 250515},
	{"GIUR", 4, 250516},
	{"FYAV", 4, 250517},
	{"FMEP", 4, 250518},
	{"FFAJ", 4, 250519},
	{"FCPU", 4, 250520},
	{"EXIX", 4, 250521},
	{"EUFS", 4, 250522},
	{"ESFB", 4, 250523},
	{"ERLR", 4, 250524},
	{"ECAZ", 4, 250525},
	{"DMCR", 4, 250526},
	{"DIKL", 4, 250527},
	{"DGAF", 4, 250528},
	{"DEHL", 4, 250529},
	{"DAPB", 4, 250530},
	{"CUOL", 4, 250531},
	{"BWEE", 4, 250532},
	{"BNOB", 4, 250533},
	{"BMSE", 4, 250534},
	{"BIUN", 4, 250535},
	{"BFEB", 4, 250536},
	{"ABZO", 4, 250537},
	{"TERTIUS", 7, 250538},
	{"KNEWS", 5, 250539},
	{"BANDARANAIKE", 12, 250540},
	{"TREYS", 5, 250541},
	{"SYNOVIUM", 8, 250542},
	{"KERSH", 5, 250543},
	{"BOTANICO", 8, 250544},
	{"JANTZ", 5, 250545},
	{"CPOPJ", 5, 250546},
	{"YRBS", 4, 250547},
	{"STEREOISOMERISM", 15, 250548},
	{"TAILPIPES", 9, 250549},
	{"CUTION", 6, 250550},
	{"PAPERDIMENSION", 14, 250551},
	{"COMPIEGNE", 9, 250552},
	{"RAMANAN", 7, 250553},
	{"LISM", 4, 250554},
	{"TERRIFYINGLY", 12, 250555},
	{"SEARCHADVANCED", 14, 250556},
	{"MOLLIG", 6, 250557},
	{"MOLARITY", 8, 250558},
	{"BACCHANAL", 9, 250559},
	{"VARISTOR", 8, 250560},
	{"SHIRLY", 6, 250561},
	{"SCHILY", 6, 250562},
	{"SANHELIOS", 9, 250563},
	{"STEUN", 5, 250564},
	{"DELIO", 5, 250565},
	{"COWEETA", 7, 250566},
	{"MELLIFLUOUS", 11, 250567},
	{"LDRS", 4, 250568},
	{"SLOVENES", 8, 250569},
	{"GAIAS", 5, 250570},
	{"HARTHOUSE", 9, 250571},
	{"SCHOOOL", 7, 250572},
	{"SARRIA", 6, 250573},
	{"GILSUM", 6, 250574},
	{"FIGUERAS", 8, 250575},
	{"PURKISS", 7, 250576},
	{"LEUCHARS", 8, 250577},
	{"DINIZ", 5, 250578},
	{"PERPLEXITIES", 12, 250579},
	{"NKLG", 4, 250580},
	{"ABLUTIONS", 9, 250581},
	{"PRETENTIOUSNESS", 15, 250582},
	{"CRAPOLA", 7, 250583},
	{"GUZZLE", 6, 250584},
	{"DIAGRAMMED", 10, 250585},
	{"CORTS", 5, 250586},
	{"HALLI", 5, 250587},
	{"WROXHAM", 7, 250588},
	{"ARTEN", 5, 250589},
	{"TOWLES", 6, 250590},
	{"SPCR", 4, 250591},
	{"RECESSIONARY", 12, 250592},
	{"POSETS", 6, 250593},
	{"PGCERT", 6, 250594},
	{"NORTHDALE", 9, 250595},
	{"ANTIBIOT", 8, 250596},
	{"MARRE", 5, 250597},
	{"CANONICALIZE", 12, 250598},
	{"GUZZO", 5, 250599},
	{"FRAID", 5, 250600},
	{"FILEOPEN", 8, 250601},
	{"CONSILIENCE", 11, 250602},
	{"PERTHES", 7, 250603},
	{"NOATAK", 6, 250604},
	{"STANF", 5, 250605},
	{"VIOLS", 5, 250606},
	{"VANDERHEIDEN", 12, 250607},
	{"ROBOTJCB", 8, 250608},
	{"MANTER", 6, 250609},
	{"BYB", 3, 250610},
	{"SAGARMATHA", 10, 250611},
	{"OPNAV", 5, 250612},
	{"LANDRACES", 9, 250613},
	{"FHLBANK", 7, 250614},
	{"EASTERWOOD", 10, 250615},
	{"ENNISCRONE", 10, 250616},
	{"DIAGENETIC", 10, 250617},
	{"QUALMARK", 8, 250618},
	{"CILEA", 5, 250619},
	{"AMWA", 4, 250620},
	{"STABLED", 7, 250621},
	{"SNOWPLOWS", 9, 250622},
	{"PARALLELIZE", 11, 250623},
	{"IMMORTALIZE", 11, 250624},
	{"CHEMIKAL", 8, 250625},
	{"BARWELL", 7, 250626},
	{"JCLASS", 6, 250627},
	{"ERBIL", 5, 250628},
	{"NEOCONSERVATISM", 15, 250629},
	{"EFFETTO", 7, 250630},
	{"APLA", 4, 250631},
	{"TIONALITY", 9, 250632},
	{"KBK", 3, 250633},
	{"KTRE", 4, 250634},
	{"AFFS", 4, 250635},
	{"VALLEN", 6, 250636},
	{"SERVICEEXECUTIVE", 16, 250637},
	{"FLAGRANTE", 9, 250638},
	{"DEVASTATES", 10, 250639},
	{"ZENICA", 6, 250640},
	{"TULLA", 5, 250641},
	{"SELECCIONA", 10, 250642},
	{"LIBNAUTILUS", 11, 250643},
	{"SOPHOCLEUS", 10, 250644},
	{"PLATIN", 6, 250645},
	{"JOKIN", 5, 250646},
	{"ADEBAYOR", 8, 250647},
	{"TRAGEDIA", 8, 250648},
	{"HELGESON", 8, 250649},
	{"GARWIN", 6, 250650},
	{"RAINVILLE", 9, 250651},
	{"NOORDHOEK", 9, 250652},
	{"MARGARETTE", 10, 250653},
	{"STOPP", 5, 250654},
	{"QUARRYVILLE", 11, 250655},
	{"UNKINDLY", 8, 250656},
	{"NUOVEGIOIE", 10, 250657},
	{"FUZZBALL", 8, 250658},
	{"ARROWTOP", 8, 250659},
	{"ZOLLHOF", 7, 250660},
	{"CREAZIONE", 9, 250661},
	{"BERENSTAI", 9, 250662},
	{"ARDOIN", 6, 250663},
	{"EPDP", 4, 250664},
	{"ALTERAC", 7, 250665},
	{"TORIE", 5, 250666},
	{"RFW", 3, 250667},
	{"OUTPOURINGS", 11, 250668},
	{"COXSACKIEVIRUS", 14, 250669},
	{"TLED", 4, 250670},
	{"RUMPF", 5, 250671},
	{"FLUOROMETRIC", 12, 250672},
	{"STDGTI", 6, 250673},
	{"DENING", 6, 250674},
	{"SIMPLEHUMAN", 11, 250675},
	{"PROPABLY", 8, 250676},
	{"HALLAND", 7, 250677},
	{"BODIL", 5, 250678},
	{"SDEV", 4, 250679},
	{"NUTRASOLUTIONS", 14, 250680},
	{"EXTERNALIZE", 11, 250681},
	{"EDOCS", 5, 250682},
	{"DOUSMAN", 7, 250683},
	{"VGAS", 4, 250684},
	{"NEMINI", 6, 250685},
	{"LWM", 3, 250686},
	{"LUSO", 4, 250687},
	{"CYBERZONE", 9, 250688},
	{"CROATIANS", 9, 250689},
	{"SMITA", 5, 250690},
	{"SAMSYS", 6, 250691},
	{"POPGLAM", 7, 250692},
	{"MARIONVILLE", 11, 250693},
	{"NONLIN", 6, 250694},
	{"KEYMAIL", 7, 250695},
	{"SPONSIBILITY", 12, 250696},
	{"MARICON", 7, 250697},
	{"EPIDURALS", 9, 250698},
	{"BARTONSVILLE", 12, 250699},
	{"TGID", 4, 250700},
	{"PAESAGGIO", 9, 250701},
	{"NITROSOUREA", 11, 250702},
	{"KHUZESTAN", 9, 250703},
	{"CAGAN", 5, 250704},
	{"TRAVRL", 6, 250705},
	{"HANDYLOGOS", 10, 250706},
	{"GUNPLAY", 7, 250707},
	{"GLAUDE", 6, 250708},
	{"SHADOWLINE", 10, 250709},
	{"SFAR", 4, 250710},
	{"MARAZION", 8, 250711},
	{"DUPLI", 5, 250712},
	{"VYSYA", 5, 250713},
	{"MANRELAXN", 9, 250714},
	{"SNITCHES", 8, 250715},
	{"LOVEST", 6, 250716},
	{"IMAGEID", 7, 250717},
	{"GERROLD", 7, 250718},
	{"QUADRUPLING", 11, 250719},
	{"MOOSEY", 6, 250720},
	{"AVVENTURA", 9, 250721},
	{"ZEUGMA", 6, 250722},
	{"QURAISH", 7, 250723},
	{"YELLA", 5, 250724},
	{"UNICES", 6, 250725},
	{"SIGACT", 6, 250726},
	{"KAPITAN", 7, 250727},
	{"ANTIGUOS", 8, 250728},
	{"MINNS", 5, 250729},
	{"BRUGER", 6, 250730},
	{"INVERSUS", 8, 250731},
	{"EDUCATIVA", 9, 250732},
	{"PRICER", 6, 250733},
	{"PHOSPHOCREATINE", 15, 250734},
	{"OGREN", 5, 250735},
	{"UGLYDOLL", 8, 250736},
	{"ISOTOPICALLY", 12, 250737},
	{"DADY", 4, 250738},
	{"NPSC", 4, 250739},
	{"WANTIN", 6, 250740},
	{"SUITT", 5, 250741},
	{"RELIGHT", 7, 250742},
	{"PONENS", 6, 250743},
	{"PCDF", 4, 250744},
	{"WINGAP", 6, 250745},
	{"SENTIAL", 7, 250746},
	{"PROCLUS", 7, 250747},
	{"PEACOCKE", 8, 250748},
	{"HULYK", 5, 250749},
	{"MIKEG", 5, 250750},
	{"EZILON", 6, 250751},
	{"SEPAK", 5, 250752},
	{"LAWPHIL", 7, 250753},
	{"JITNEY", 6, 250754},
	{"BABYDAN", 7, 250755},
	{"MANOHLA", 7, 250756},
	{"LLANFYLLIN", 10, 250757},
	{"FIBRONECTINS", 12, 250758},
	{"EASINGWOLD", 10, 250759},
	{"SOFTWATE", 8, 250760},
	{"LDIRECTORD", 10, 250761},
	{"INNERSPACE", 10, 250762},
	{"GRONER", 6, 250763},
	{"GOOSEY", 6, 250764},
	{"THAPSIGARGIN", 12, 250765},
	{"STRATAGEMS", 10, 250766},
	{"SOFTWARW", 8, 250767},
	{"SKALSKA", 7, 250768},
	{"CIFA", 4, 250769},
	{"GASCOGNE", 8, 250770},
	{"TRAEGER", 7, 250771},
	{"SYNERGETICS", 11, 250772},
	{"ETICHETTA", 9, 250773},
	{"BELLINZONA", 10, 250774},
	{"RUFFWEAR", 8, 250775},
	{"MOEDA", 5, 250776},
	{"SOFYWARE", 8, 250777},
	{"SCARLETEEN", 10, 250778},
	{"PSEUDOTUMOR", 11, 250779},
	{"LETABA", 6, 250780},
	{"DRAGGERS", 8, 250781},
	{"ACEBUTOLOL", 10, 250782},
	{"TOOND", 5, 250783},
	{"IMAGELIST", 9, 250784},
	{"BLURTS", 6, 250785},
	{"WIGU", 4, 250786},
	{"IZAWA", 5, 250787},
	{"HOWZ", 4, 250788},
	{"GODOWNLOAD", 10, 250789},
	{"FUNAKI", 6, 250790},
	{"CAROUSING", 9, 250791},
	{"ISTERED", 7, 250792},
	{"DULIN", 5, 250793},
	{"CHANDNI", 7, 250794},
	{"VANSON", 6, 250795},
	{"PEDALED", 7, 250796},
	{"COURCE", 6, 250797},
	{"PARAMIO", 7, 250798},
	{"GIBLIB", 6, 250799},
	{"ZRUN", 4, 250800},
	{"ZAOU", 4, 250801},
	{"YZGA", 4, 250802},
	{"YTHJ", 4, 250803},
	{"YOMN", 4, 250804},
	{"YMHE", 4, 250805},
	{"YKIA", 4, 250806},
	{"YJRO", 4, 250807},
	{"YHEZ", 4, 250808},
	{"YEXU", 4, 250809},
	{"YBAA", 4, 250810},
	{"XGEO", 4, 250811},
	{"WYFI", 4, 250812},
	{"WWBU", 4, 250813},
	{"WOWD", 4, 250814},
	{"WODD", 4, 250815},
	{"WIBA", 4, 250816},
	{"WAKT", 4, 250817},
	{"VROA", 4, 250818},
	{"VEOK", 4, 250819},
	{"UDUK", 4, 250820},
	{"UDSG", 4, 250821},
	{"UAAD", 4, 250822},
	{"TVOP", 4, 250823},
	{"TVOG", 4, 250824},
	{"TJUB", 4, 250825},
	{"SWAW", 4, 250826},
	{"STVB", 4, 250827},
	{"RMIU", 4, 250828},
	{"RJEH", 4, 250829},
	{"RFTA", 4, 250830},
	{"RBOK", 4, 250831},
	{"PMSW", 4, 250832},
	{"OWMP", 4, 250833},
	{"ODHR", 4, 250834},
	{"OCBU", 4, 250835},
	{"OADQ", 4, 250836},
	{"NZUS", 4, 250837},
	{"NVBO", 4, 250838},
	{"NSWG", 4, 250839},
	{"NSBB", 4, 250840},
	{"NLMA", 4, 250841},
	{"NDLF", 4, 250842},
	{"NAYY", 4, 250843},
	{"MPVE", 4, 250844},
	{"MOQU", 4, 250845},
	{"MLDE", 4, 250846},
	{"MDUP", 4, 250847},
	{"LTRN", 4, 250848},
	{"LOKN", 4, 250849},
	{"KNUR", 4, 250850},
	{"KIOU", 4, 250851},
	{"KETQ", 4, 250852},
	{"KESZ", 4, 250853},
	{"JPAL", 4, 250854},
	{"IOUF", 4, 250855},
	{"HZEL", 4, 250856},
	{"HYLP", 4, 250857},
	{"HEZV", 4, 250858},
	{"GYSL", 4, 250859},
	{"GUOJ", 4, 250860},
	{"GNIP", 4, 250861},
	{"FZEP", 4, 250862},
	{"FLSL", 4, 250863},
	{"FGTT", 4, 250864},
	{"FFOB", 4, 250865},
	{"EZBY", 4, 250866},
	{"EGVE", 4, 250867},
	{"DWWI", 4, 250868},
	{"DMSF", 4, 250869},
	{"DDSY", 4, 250870},
	{"DBOZ", 4, 250871},
	{"CYKA", 4, 250872},
	{"CNCA", 4, 250873},
	{"CISY", 4, 250874},
	{"BUGU", 4, 250875},
	{"BUDM", 4, 250876},
	{"BTSR", 4, 250877},
	{"AUPG", 4, 250878},
	{"AUBM", 4, 250879},
	{"ATFP", 4, 250880},
	{"ARZM", 4, 250881},
	{"AJJO", 4, 250882},
	{"ACGY", 4, 250883},
	{"ENVIES", 6, 250884},
	{"MHCC", 4, 250885},
	{"GEDIFRA", 7, 250886},
	{"HYPERCUBES", 10, 250887},
	{"GIEMSA", 6, 250888},
	{"CATALUNA", 8, 250889},
	{"HESPERIAN", 9, 250890},
	{"SURFTHING", 9, 250891},
	{"SHIPPMENT", 9, 250892},
	{"CONDESCENDED", 12, 250893},
	{"CONFERENCIAS", 12, 250894},
	{"SETWINDOWTEXT", 13, 250895},
	{"JIGGLY", 6, 250896},
	{"VERRAZANO", 9, 250897},
	{"LOOR", 4, 250898},
	{"KINNARD", 7, 250899},
	{"GATEWORLD", 9, 250900},
	{"YARDBIRD", 8, 250901},
	{"NONCOMMITTAL", 12, 250902},
	{"SWYDDOGION", 10, 250903},
	{"PIGMEAT", 7, 250904},
	{"NETELLIGENT", 11, 250905},
	{"DNLM", 4, 250906},
	{"RAILTON", 7, 250907},
	{"PUVA", 4, 250908},
	{"ESHELL", 6, 250909},
	{"OPTHALMOLOGY", 12, 250910},
	{"LONGENECKER", 11, 250911},
	{"BARTHE", 6, 250912},
	{"AUTARKY", 7, 250913},
	{"ACTORESS", 8, 250914},
	{"SEPTRA", 6, 250915},
	{"REKNOWN", 7, 250916},
	{"ONEEIGHTY", 9, 250917},
	{"LANDIN", 6, 250918},
	{"COCS", 4, 250919},
	{"WORKTHING", 9, 250920},
	{"NECON", 5, 250921},
	{"MASCARAS", 8, 250922},
	{"LESSA", 5, 250923},
	{"CURRICU", 7, 250924},
	{"CONSI", 5, 250925},
	{"UNIVERSITARIAS", 14, 250926},
	{"PLANETPENGUIN", 13, 250927},
	{"GADGESTER", 9, 250928},
	{"ACTIVCARD", 9, 250929},
	{"INTERTEXTUAL", 12, 250930},
	{"ACCOMIDATIONS", 13, 250931},
	{"INSEMINATED", 11, 250932},
	{"FORTUNOFF", 9, 250933},
	{"BARBADENSIS", 11, 250934},
	{"MICHIGANDER", 11, 250935},
	{"CUBOID", 6, 250936},
	{"BAOTOU", 6, 250937},
	{"VOICEPULSE", 10, 250938},
	{"MANNINGS", 8, 250939},
	{"AMERICANUM", 10, 250940},
	{"STRIVERS", 8, 250941},
	{"PEPITA", 6, 250942},
	{"GOPUSA", 6, 250943},
	{"INNISFREE", 9, 250944},
	{"SHORTLISTS", 10, 250945},
	{"PREMOTOR", 8, 250946},
	{"METROCARD", 9, 250947},
	{"JUSTED", 6, 250948},
	{"XMLDOC", 6, 250949},
	{"ILLIG", 5, 250950},
	{"SHOPPERTRON", 11, 250951},
	{"SHINDO", 6, 250952},
	{"REVERTE", 7, 250953},
	{"GEOMEMBRANE", 11, 250954},
	{"FREIGHTED", 9, 250955},
	{"VOLVE", 5, 250956},
	{"TOMACHINE", 9, 250957},
	{"SCHNERCH", 8, 250958},
	{"TRADIONAL", 9, 250959},
	{"CAFC", 4, 250960},
	{"SAADAT", 6, 250961},
	{"KLAPPER", 7, 250962},
	{"GADA", 4, 250963},
	{"DIOGENIUS", 9, 250964},
	{"DANITA", 6, 250965},
	{"SLAVKO", 6, 250966},
	{"PINNATE", 7, 250967},
	{"PENNGROVE", 9, 250968},
	{"NITELY", 6, 250969},
	{"MACKY", 5, 250970},
	{"LAEKEN", 6, 250971},
	{"ARMM", 4, 250972},
	{"SIMULANS", 8, 250973},
	{"ACDBROTATEDDIMENSION", 20, 250974},
	{"PROINSULIN", 10, 250975},
	{"GLISSANDO", 9, 250976},
	{"TFOR", 4, 250977},
	{"SCHURTER", 8, 250978},
	{"GERTNER", 7, 250979},
	{"YSED", 4, 250980},
	{"CHTYPE", 6, 250981},
	{"UNRE", 4, 250982},
	{"TYROSYL", 7, 250983},
	{"STOMACHACHE", 11, 250984},
	{"MRCPSYCH", 8, 250985},
	{"VASTUS", 6, 250986},
	{"PHOTOGRAPY", 10, 250987},
	{"MRQE", 4, 250988},
	{"LINIMENT", 8, 250989},
	{"MYLANGUAGE", 10, 250990},
	{"KAIGE", 5, 250991},
	{"HMMPFAM", 7, 250992},
	{"LUXTON", 6, 250993},
	{"DINU", 4, 250994},
	{"CONSTRICTIONS", 13, 250995},
	{"CHRISTISON", 10, 250996},
	{"RMED", 4, 250997},
	{"PATZ", 4, 250998},
	{"ETHERTYPE", 9, 250999},
	{"CANTZ", 5, 251000},
	{"NUTTS", 5, 251001},
	{"MULTEX", 6, 251002},
	{"BREATS", 6, 251003},
	{"REPLENISHER", 11, 251004},
	{"DEVOURER", 8, 251005},
	{"UTAGAWA", 7, 251006},
	{"INTERUPTED", 10, 251007},
	{"HIDUP", 5, 251008},
	{"GANGE", 5, 251009},
	{"GALAMBOS", 8, 251010},
	{"SHMITHS", 7, 251011},
	{"LICKA", 5, 251012},
	{"TVERSKAYA", 9, 251013},
	{"KUBLAI", 6, 251014},
	{"SKYJACKER", 9, 251015},
	{"IPAM", 4, 251016},
	{"GRAVENSTEIN", 11, 251017},
	{"DIBONA", 6, 251018},
	{"UNDERSTATING", 12, 251019},
	{"PUMATECH", 8, 251020},
	{"BEAMON", 6, 251021},
	{"ACCOLATE", 8, 251022},
	{"PHOSPHOGLUCOMUTASE", 18, 251023},
	{"EJERCITO", 8, 251024},
	{"SPHYGMOMANOMETERS", 17, 251025},
	{"DATAREADER", 10, 251026},
	{"SAUNDERSFOOT", 12, 251027},
	{"ADAPTADOR", 9, 251028},
	{"TECHNIP", 7, 251029},
	{"OFFRAMP", 7, 251030},
	{"COTTONY", 7, 251031},
	{"CIPLE", 5, 251032},
	{"BENELUXCAR", 10, 251033},
	{"SCHROER", 7, 251034},
	{"ELEONORE", 8, 251035},
	{"WOOTTEN", 7, 251036},
	{"HERRNSTEIN", 10, 251037},
	{"NORMANDIN", 9, 251038},
	{"GEOTECH", 7, 251039},
	{"LMJ", 3, 251040},
	{"LIBBA", 5, 251041},
	{"WIELKA", 6, 251042},
	{"WGNSAT", 6, 251043},
	{"TITRATORS", 9, 251044},
	{"ANDREEA", 7, 251045},
	{"WAVEFLUX", 8, 251046},
	{"KERNA", 5, 251047},
	{"APPENZELLER", 11, 251048},
	{"ANGAS", 5, 251049},
	{"TITED", 5, 251050},
	{"LINKHUB", 7, 251051},
	{"JALBERT", 7, 251052},
	{"EKLIND", 6, 251053},
	{"GOLFS", 5, 251054},
	{"CHAEBOL", 7, 251055},
	{"AMBROGIO", 8, 251056},
	{"ALLDNS", 6, 251057},
	{"UBEROI", 6, 251058},
	{"TRIODOS", 7, 251059},
	{"SIVAJI", 6, 251060},
	{"PATIENTEN", 9, 251061},
	{"CAELUM", 6, 251062},
	{"WORLDGUIDE", 10, 251063},
	{"VENIT", 5, 251064},
	{"LIMNOS", 6, 251065},
	{"CHAPATI", 7, 251066},
	{"KAGURA", 6, 251067},
	{"HENSALL", 7, 251068},
	{"NONMAGNETIC", 11, 251069},
	{"NARM", 4, 251070},
	{"COLLETOTRICHUM", 14, 251071},
	{"VIRILIO", 7, 251072},
	{"KOLSTAD", 7, 251073},
	{"CAPITANO", 8, 251074},
	{"METAS", 5, 251075},
	{"HALLAHAN", 8, 251076},
	{"PERSINGER", 9, 251077},
	{"MOBBS", 5, 251078},
	{"SIMILIS", 7, 251079},
	{"RDMS", 4, 251080},
	{"GRIZZ", 5, 251081},
	{"BELLOCHIO", 9, 251082},
	{"SCUIRTING", 9, 251083},
	{"MEEKINS", 7, 251084},
	{"GOLDENRAM", 9, 251085},
	{"NAUGAHYDE", 9, 251086},
	{"PLOUERSURRANCE", 14, 251087},
	{"COPYEDITOR", 10, 251088},
	{"STUMBO", 6, 251089},
	{"USCCAN", 6, 251090},
	{"POLYPLOIDY", 10, 251091},
	{"CONDAMINE", 9, 251092},
	{"BRAINCANDY", 10, 251093},
	{"NONRESPONSIVE", 13, 251094},
	{"MANDAG", 6, 251095},
	{"TNPC", 4, 251096},
	{"SIRENIS", 7, 251097},
	{"INTEROPERATING", 14, 251098},
	{"BIOETHANOL", 10, 251099},
	{"ARANEA", 6, 251100},
	{"LEONETTI", 8, 251101},
	{"ELEUSIS", 7, 251102},
	{"WHOOSHING", 9, 251103},
	{"ALMAYATE", 8, 251104},
	{"TRACTING", 8, 251105},
	{"SIBER", 5, 251106},
	{"ROSENKAVALIER", 13, 251107},
	{"FVF", 3, 251108},
	{"STYLUSES", 8, 251109},
	{"DIGITALIZED", 11, 251110},
	{"CAILE", 5, 251111},
	{"NYSUT", 5, 251112},
	{"LOSSING", 7, 251113},
	{"FLOUNCE", 7, 251114},
	{"DETOXING", 8, 251115},
	{"PINGTUNG", 8, 251116},
	{"WIEDMANN", 8, 251117},
	{"SHUSTERMAN", 10, 251118},
	{"STRAKE", 6, 251119},
	{"THUTMOSE", 8, 251120},
	{"NAPHTHALENES", 12, 251121},
	{"LETTURE", 7, 251122},
	{"SIONED", 6, 251123},
	{"PENTIUMS", 8, 251124},
	{"BURHAN", 6, 251125},
	{"ANTIDEGRADATION", 15, 251126},
	{"VEZI", 4, 251127},
	{"RETCH", 5, 251128},
	{"MCLOUD", 6, 251129},
	{"GREANT", 6, 251130},
	{"AOFTWARE", 8, 251131},
	{"TOWAGE", 6, 251132},
	{"DUNCANSVILLE", 12, 251133},
	{"MUNTINLUPA", 10, 251134},
	{"COMPAGNIES", 10, 251135},
	{"ANTIEMETICS", 11, 251136},
	{"POHLMANN", 8, 251137},
	{"PGACCESS", 8, 251138},
	{"GRITZ", 5, 251139},
	{"ZYSI", 4, 251140},
	{"ZIPU", 4, 251141},
	{"XROC", 4, 251142},
	{"XIAD", 4, 251143},
	{"XAVO", 4, 251144},
	{"XAVA", 4, 251145},
	{"WULI", 4, 251146},
	{"VOBA", 4, 251147},
	{"VBEL", 4, 251148},
	{"UYUT", 4, 251149},
	{"UCWA", 4, 251150},
	{"UCOF", 4, 251151},
	{"UATP", 4, 251152},
	{"TYRC", 4, 251153},
	{"TPPE", 4, 251154},
	{"TPMY", 4, 251155},
	{"SYUP", 4, 251156},
	{"SXPS", 4, 251157},
	{"SKJA", 4, 251158},
	{"SJRC", 4, 251159},
	{"SCDM", 4, 251160},
	{"RLVA", 4, 251161},
	{"RKYH", 4, 251162},
	{"RCJA", 4, 251163},
	{"RCEX", 4, 251164},
	{"PYYE", 4, 251165},
	{"PEZG", 4, 251166},
	{"OVTC", 4, 251167},
	{"OIRU", 4, 251168},
	{"NLPG", 4, 251169},
	{"NGBT", 4, 251170},
	{"NDZY", 4, 251171},
	{"MNME", 4, 251172},
	{"MLOE", 4, 251173},
	{"MKET", 4, 251174},
	{"MJOA", 4, 251175},
	{"MDBA", 4, 251176},
	{"LIZP", 4, 251177},
	{"LFYA", 4, 251178},
	{"KBUG", 4, 251179},
	{"JEDG", 4, 251180},
	{"JASB", 4, 251181},
	{"IXAU", 4, 251182},
	{"ILIQ", 4, 251183},
	{"IGKA", 4, 251184},
	{"IBCH", 4, 251185},
	{"HIFC", 4, 251186},
	{"GYSM", 4, 251187},
	{"GMTR", 4, 251188},
	{"FOGB", 4, 251189},
	{"FMLB", 4, 251190},
	{"FGWE", 4, 251191},
	{"EUXD", 4, 251192},
	{"EFVE", 4, 251193},
	{"DPYO", 4, 251194},
	{"DDJU", 4, 251195},
	{"DDGE", 4, 251196},
	{"DCYT", 4, 251197},
	{"DBWI", 4, 251198},
	{"DAUF", 4, 251199},
	{"COKA", 4, 251200},
	{"BIYE", 4, 251201},
	{"BEUG", 4, 251202},
	{"BCED", 4, 251203},
	{"ARFD", 4, 251204},
	{"ANZP", 4, 251205},
	{"LONGLEGS", 8, 251206},
	{"KREISEL", 7, 251207},
	{"BARCELONETA", 11, 251208},
	{"PPST", 4, 251209},
	{"CONQUISTA", 9, 251210},
	{"MERUS", 5, 251211},
	{"HOBBLES", 7, 251212},
	{"ELANOR", 6, 251213},
	{"DILSHOD", 7, 251214},
	{"CHITTOOR", 8, 251215},
	{"ANJUM", 5, 251216},
	{"CANDIDACIES", 11, 251217},
	{"ASAHIKAWA", 9, 251218},
	{"SLACKENING", 10, 251219},
	{"MOCKINGBIRDS", 12, 251220},
	{"BATTAT", 6, 251221},
	{"AMNION", 6, 251222},
	{"KOBIETY", 7, 251223},
	{"AMAUTER", 7, 251224},
	{"LIMEKILN", 8, 251225},
	{"BUCKNALL", 8, 251226},
	{"IRMGARD", 7, 251227},
	{"VRFY", 4, 251228},
	{"SUPERSCOPE", 10, 251229},
	{"SHARECROPPER", 12, 251230},
	{"KEFF", 4, 251231},
	{"CINZIA", 6, 251232},
	{"ACTD", 4, 251233},
	{"SHOUTBOARD", 10, 251234},
	{"SAUDADE", 7, 251235},
	{"PALMTREE", 8, 251236},
	{"KAENON", 6, 251237},
	{"PARDNER", 7, 251238},
	{"OSHIRO", 6, 251239},
	{"GEOCHRON", 8, 251240},
	{"WONDROUSLY", 10, 251241},
	{"LATSIS", 6, 251242},
	{"BLEIER", 6, 251243},
	{"ZAPPY", 5, 251244},
	{"TUSKERS", 7, 251245},
	{"ODDEN", 5, 251246},
	{"INTERMINISTERIAL", 16, 251247},
	{"PERFERENCE", 10, 251248},
	{"FATBRAIN", 8, 251249},
	{"DINGEN", 6, 251250},
	{"CONOMICS", 8, 251251},
	{"SAVABLE", 7, 251252},
	{"SALVADORI", 9, 251253},
	{"TITIRANGI", 9, 251254},
	{"ROUNDSTONE", 10, 251255},
	{"NGIX", 4, 251256},
	{"LASTMINUTECOM", 13, 251257},
	{"BALNEARIOS", 10, 251258},
	{"WIKA", 4, 251259},
	{"PLAYMORE", 8, 251260},
	{"MONDS", 5, 251261},
	{"LECOMPTON", 9, 251262},
	{"JABA", 4, 251263},
	{"INVESTORGUIDE", 13, 251264},
	{"RESIDENZE", 9, 251265},
	{"MARILOU", 7, 251266},
	{"LEEB", 4, 251267},
	{"BRAYDEN", 7, 251268},
	{"TEILEN", 6, 251269},
	{"FRIEGHT", 7, 251270},
	{"MESORHIZOBIUM", 13, 251271},
	{"SHIMMERED", 9, 251272},
	{"HARRO", 5, 251273},
	{"APPLICATONS", 11, 251274},
	{"BIGRED", 6, 251275},
	{"OPALE", 5, 251276},
	{"DUSTPROOF", 9, 251277},
	{"ANARCHISTIC", 11, 251278},
	{"TARVEL", 6, 251279},
	{"KATZENBERG", 10, 251280},
	{"BJD", 3, 251281},
	{"REISERFSPROGS", 13, 251282},
	{"NANOFILTRATION", 14, 251283},
	{"KOYA", 4, 251284},
	{"INTEGRO", 7, 251285},
	{"DADD", 4, 251286},
	{"BLATINO", 7, 251287},
	{"GAVRILOV", 8, 251288},
	{"EPARGNE", 7, 251289},
	{"RAYMI", 5, 251290},
	{"FASTBREAK", 9, 251291},
	{"KALMIA", 6, 251292},
	{"TROR", 4, 251293},
	{"CORSETRY", 8, 251294},
	{"MIROSLAW", 8, 251295},
	{"OSKIT", 5, 251296},
	{"EXTRAOCULAR", 11, 251297},
	{"REMC", 4, 251298},
	{"REVER", 5, 251299},
	{"PINNIPED", 8, 251300},
	{"REEKIE", 6, 251301},
	{"DISSIDENCE", 10, 251302},
	{"SPRAYSUN", 8, 251303},
	{"MTTF", 4, 251304},
	{"EWCH", 4, 251305},
	{"CUSUMANO", 8, 251306},
	{"VEILLEUX", 8, 251307},
	{"OVERRULES", 9, 251308},
	{"ENTSPRECHENDEN", 14, 251309},
	{"DOTEL", 5, 251310},
	{"BLOGMEISTER", 11, 251311},
	{"TAVERNE", 7, 251312},
	{"MERCATINO", 9, 251313},
	{"CINEMARATI", 10, 251314},
	{"DOMINALIST", 10, 251315},
	{"UNQUESTIONINGLY", 15, 251316},
	{"SHLAIN", 6, 251317},
	{"PISC", 4, 251318},
	{"LECTURAS", 8, 251319},
	{"AESTHETICIANS", 13, 251320},
	{"DECSTATION", 10, 251321},
	{"YANCEYVILLE", 11, 251322},
	{"POCKETGEAR", 10, 251323},
	{"GEORGIANNA", 10, 251324},
	{"BOYARS", 6, 251325},
	{"ALLERAIR", 8, 251326},
	{"PROOVE", 6, 251327},
	{"OLEARY", 6, 251328},
	{"ECED", 4, 251329},
	{"COALGEBRA", 9, 251330},
	{"TANKINIS", 8, 251331},
	{"LYSIMACHIA", 10, 251332},
	{"JAMIES", 6, 251333},
	{"GRMS", 4, 251334},
	{"DECANTED", 8, 251335},
	{"WILDES", 6, 251336},
	{"VARIZOOM", 8, 251337},
	{"LEEANNE", 7, 251338},
	{"GLUCOSA", 7, 251339},
	{"CLUSTRMAPS", 10, 251340},
	{"HANDFASTING", 11, 251341},
	{"ANTEROOM", 8, 251342},
	{"TAPPS", 5, 251343},
	{"NEWTEST", 7, 251344},
	{"NETSPRINT", 9, 251345},
	{"STRLCPY", 7, 251346},
	{"BARBIERE", 8, 251347},
	{"AQUISITIONS", 11, 251348},
	{"MAHAREY", 7, 251349},
	{"HOSTEXPLORER", 12, 251350},
	{"DIOEERENT", 9, 251351},
	{"UNIERSITY", 9, 251352},
	{"TICKLABEL", 9, 251353},
	{"ATLANTICBLOG", 12, 251354},
	{"JDOE", 4, 251355},
	{"PRESTITO", 8, 251356},
	{"CREATA", 6, 251357},
	{"CADEN", 5, 251358},
	{"REEMERGENCE", 11, 251359},
	{"MATERASSI", 9, 251360},
	{"HANGES", 6, 251361},
	{"DOORFRAME", 9, 251362},
	{"BICUCULLINE", 11, 251363},
	{"KMK", 3, 251364},
	{"ELBERON", 7, 251365},
	{"DDRAW", 5, 251366},
	{"SOFFWARE", 8, 251367},
	{"AGRICULTURISTS", 14, 251368},
	{"SCHNEWS", 7, 251369},
	{"DIFCO", 5, 251370},
	{"DARKANGEL", 9, 251371},
	{"VISCHER", 7, 251372},
	{"TESTIN", 6, 251373},
	{"AUBERRY", 7, 251374},
	{"PRIMAR", 6, 251375},
	{"INLAYED", 7, 251376},
	{"CUNDY", 5, 251377},
	{"CARACTERISTICAS", 15, 251378},
	{"HAUERWAS", 8, 251379},
	{"GETFILE", 7, 251380},
	{"PROZESSE", 8, 251381},
	{"CHANCROID", 9, 251382},
	{"SPVC", 4, 251383},
	{"SARONIC", 7, 251384},
	{"READJUSTS", 9, 251385},
	{"FLOATABLE", 9, 251386},
	{"FLAGGER", 7, 251387},
	{"BESTIA", 6, 251388},
	{"SELECR", 6, 251389},
	{"FLAMELESS", 9, 251390},
	{"CYPRIPEDIUM", 11, 251391},
	{"ATTLIST", 7, 251392},
	{"UNEATEN", 7, 251393},
	{"KMW", 3, 251394},
	{"HOGENOM", 7, 251395},
	{"ACTIVO", 6, 251396},
	{"WEEPIES", 7, 251397},
	{"JMKE", 4, 251398},
	{"DUNEMAUL", 8, 251399},
	{"CILPS", 5, 251400},
	{"UNREADY", 7, 251401},
	{"TRATEGY", 7, 251402},
	{"DINODATA", 8, 251403},
	{"TOXICOGENOMICS", 14, 251404},
	{"EYESORES", 8, 251405},
	{"MULATAS", 7, 251406},
	{"CLIPMARKS", 9, 251407},
	{"DOSSEY", 6, 251408},
	{"DEXFENFLURAMINE", 15, 251409},
	{"TRUANTS", 7, 251410},
	{"NEOPIA", 6, 251411},
	{"SUBGRANTEES", 11, 251412},
	{"ROCAS", 5, 251413},
	{"OXYDRENE", 8, 251414},
	{"IMMOBILIARE", 11, 251415},
	{"LIBTABE", 7, 251416},
	{"DOWJONES", 8, 251417},
	{"MEDIAFUSION", 11, 251418},
	{"DONTRELLE", 9, 251419},
	{"EXPERTCLICK", 11, 251420},
	{"CAMBRIDGESOFT", 13, 251421},
	{"BSDS", 4, 251422},
	{"MOSTOW", 6, 251423},
	{"HPCMIPS", 7, 251424},
	{"WALLHANGINGS", 12, 251425},
	{"FROMT", 5, 251426},
	{"FEBREZE", 7, 251427},
	{"HFSPLUS", 7, 251428},
	{"STOPFORD", 8, 251429},
	{"SKATEBUYS", 9, 251430},
	{"FREEDOMIST", 10, 251431},
	{"CREDITREPORT", 12, 251432},
	{"SPEILBERG", 9, 251433},
	{"CASALI", 6, 251434},
	{"ELLUL", 5, 251435},
	{"BROCKLEHURST", 12, 251436},
	{"WEIGHTLIFTER", 12, 251437},
	{"MOATES", 6, 251438},
	{"LENHARD", 7, 251439},
	{"FOSSATI", 7, 251440},
	{"ALYCIA", 6, 251441},
	{"KEYTEL", 6, 251442},
	{"CMRR", 4, 251443},
	{"MAWES", 5, 251444},
	{"GARRIGUE", 8, 251445},
	{"HARUO", 5, 251446},
	{"ADRIAEN", 7, 251447},
	{"TAMIM", 5, 251448},
	{"CROOKLYN", 8, 251449},
	{"ZZFR", 4, 251450},
	{"ZOWN", 4, 251451},
	{"ZMEM", 4, 251452},
	{"YUBU", 4, 251453},
	{"YMTE", 4, 251454},
	{"WPSY", 4, 251455},
	{"VYRI", 4, 251456},
	{"VRAA", 4, 251457},
	{"VJUS", 4, 251458},
	{"VIKP", 4, 251459},
	{"VAEV", 4, 251460},
	{"VABH", 4, 251461},
	{"UUJI", 4, 251462},
	{"ULFG", 4, 251463},
	{"UILC", 4, 251464},
	{"UBIF", 4, 251465},
	{"UAYF", 4, 251466},
	{"TVAZ", 4, 251467},
	{"TUBL", 4, 251468},
	{"TRLA", 4, 251469},
	{"TMUK", 4, 251470},
	{"TMDI", 4, 251471},
	{"TCFS", 4, 251472},
	{"SOPM", 4, 251473},
	{"SCYA", 4, 251474},
	{"SCUZ", 4, 251475},
	{"RWEU", 4, 251476},
	{"PFAK", 4, 251477},
	{"OYIF", 4, 251478},
	{"OVSL", 4, 251479},
	{"OVBY", 4, 251480},
	{"OIPP", 4, 251481},
	{"NYPC", 4, 251482},
	{"NUMV", 4, 251483},
	{"NRWI", 4, 251484},
	{"NJOF", 4, 251485},
	{"NIKG", 4, 251486},
	{"MUNJ", 4, 251487},
	{"MGLU", 4, 251488},
	{"LSZL", 4, 251489},
	{"KEIU", 4, 251490},
	{"JSWE", 4, 251491},
	{"JOOL", 4, 251492},
	{"JISB", 4, 251493},
	{"IJIB", 4, 251494},
	{"IGMF", 4, 251495},
	{"GSUZ", 4, 251496},
	{"GOUM", 4, 251497},
	{"GBOH", 4, 251498},
	{"FDTH", 4, 251499},
	{"FBHO", 4, 251500},
	{"EYNG", 4, 251501},
	{"ERXS", 4, 251502},
	{"EPMJ", 4, 251503},
	{"EJIV", 4, 251504},
	{"DEWT", 4, 251505},
	{"DEVN", 4, 251506},
	{"DASX", 4, 251507},
	{"CTCY", 4, 251508},
	{"CFIX", 4, 251509},
	{"BWAA", 4, 251510},
	{"BUDR", 4, 251511},
	{"BPWH", 4, 251512},
	{"BCNA", 4, 251513},
	{"BAVO", 4, 251514},
	{"AXCE", 4, 251515},
	{"ATYK", 4, 251516},
	{"ARZH", 4, 251517},
	{"AKMM", 4, 251518},
	{"AJCH", 4, 251519},
	{"AFMU", 4, 251520},
	{"CAREEN", 6, 251521},
	{"STUPAS", 6, 251522},
	{"TOUGALOO", 8, 251523},
	{"HERPANACINE", 11, 251524},
	{"PRODUZENT", 9, 251525},
	{"PHOSPHATIDIC", 12, 251526},
	{"MICRODOT", 8, 251527},
	{"DDITIONAL", 9, 251528},
	{"SQUAREBACK", 10, 251529},
	{"CURRYING", 8, 251530},
	{"EASTVILLE", 9, 251531},
	{"INBAR", 5, 251532},
	{"GOWERS", 6, 251533},
	{"GLENBARD", 8, 251534},
	{"VALVETRAIN", 10, 251535},
	{"TRAVELCHAIR", 11, 251536},
	{"KARLO", 5, 251537},
	{"IMAGINET", 8, 251538},
	{"ICHTHUS", 7, 251539},
	{"ETFINVESTOR", 11, 251540},
	{"YUNQUE", 6, 251541},
	{"BUSCAGLIA", 9, 251542},
	{"BACO", 4, 251543},
	{"SILVEN", 6, 251544},
	{"SERVERLIST", 10, 251545},
	{"GAMESMANSHIP", 12, 251546},
	{"ESSENTIA", 8, 251547},
	{"MUISE", 5, 251548},
	{"MELCHOR", 7, 251549},
	{"MAHTOMEDI", 9, 251550},
	{"OSSIFIED", 8, 251551},
	{"WICKRAMASINGHE", 14, 251552},
	{"STROBECK", 8, 251553},
	{"SHOWOFFNOMINATE", 15, 251554},
	{"ORTMAN", 6, 251555},
	{"FABRIANO", 8, 251556},
	{"CROSSMAP", 8, 251557},
	{"BELOVETH", 8, 251558},
	{"BAUS", 4, 251559},
	{"SHOPFITTERS", 11, 251560},
	{"LEMBONGAN", 9, 251561},
	{"CHITRAL", 7, 251562},
	{"ZELANDA", 7, 251563},
	{"NCREL", 5, 251564},
	{"JOSTEN", 6, 251565},
	{"HELPAGE", 7, 251566},
	{"HOBHOUSE", 8, 251567},
	{"FAIXA", 5, 251568},
	{"CCED", 4, 251569},
	{"MARINS", 6, 251570},
	{"LARRANAGA", 9, 251571},
	{"KLIKNIJ", 7, 251572},
	{"INTENTED", 8, 251573},
	{"HBOHD", 5, 251574},
	{"GUITARES", 8, 251575},
	{"ERYTHEMATOUS", 12, 251576},
	{"ANUMBER", 7, 251577},
	{"REBID", 5, 251578},
	{"NONGUNS", 7, 251579},
	{"KIPPA", 5, 251580},
	{"MORTGAGELOAN", 12, 251581},
	{"LONGSTONE", 9, 251582},
	{"BABUSHKA", 8, 251583},
	{"CHAMPCAR", 8, 251584},
	{"TIBIALIS", 8, 251585},
	{"CHIRK", 5, 251586},
	{"SLECHTS", 7, 251587},
	{"INTERLOPERS", 11, 251588},
	{"DEPLOYERS", 9, 251589},
	{"BLUEPRINTING", 12, 251590},
	{"WATERMEN", 8, 251591},
	{"KRASNY", 6, 251592},
	{"TVRADIOWORLD", 12, 251593},
	{"REAPPLYING", 10, 251594},
	{"LINKSWARM", 9, 251595},
	{"CITOYENS", 8, 251596},
	{"GUITARRAS", 9, 251597},
	{"LERA", 4, 251598},
	{"HORKAN", 6, 251599},
	{"DESCRIB", 7, 251600},
	{"GDATA", 5, 251601},
	{"MARKKAA", 7, 251602},
	{"LEAPFROGGING", 12, 251603},
	{"KROUSE", 6, 251604},
	{"KRASHEN", 7, 251605},
	{"ELUNE", 5, 251606},
	{"DOLAND", 6, 251607},
	{"NESTLER", 7, 251608},
	{"MESALAMINE", 10, 251609},
	{"SORTI", 5, 251610},
	{"LIBDEPS", 7, 251611},
	{"JOTHAM", 6, 251612},
	{"INTEROPERATES", 13, 251613},
	{"BARNSTORM", 9, 251614},
	{"USMARC", 6, 251615},
	{"LYRICAF", 7, 251616},
	{"POSSUMBLOG", 10, 251617},
	{"CASTRA", 6, 251618},
	{"BETTIN", 6, 251619},
	{"PWNAGE", 6, 251620},
	{"LOGISITICS", 10, 251621},
	{"LEURABOOKS", 10, 251622},
	{"PRESLEYS", 8, 251623},
	{"MELCHERS", 8, 251624},
	{"COMPULSARY", 10, 251625},
	{"ALLYSA", 6, 251626},
	{"FEDERALE", 8, 251627},
	{"DICA", 4, 251628},
	{"COCACOLA", 8, 251629},
	{"HOULD", 5, 251630},
	{"SNDK", 4, 251631},
	{"SENOIA", 6, 251632},
	{"ISSSP", 5, 251633},
	{"EMBAJADA", 8, 251634},
	{"PERCNT", 6, 251635},
	{"ASRC", 4, 251636},
	{"TVGUIDE", 7, 251637},
	{"SYNTHESISERS", 12, 251638},
	{"GEOMICRO", 8, 251639},
	{"DISOPYRAMIDE", 12, 251640},
	{"SKOUSEN", 7, 251641},
	{"GALANGAL", 8, 251642},
	{"SHUTESBURY", 10, 251643},
	{"MORIOND", 7, 251644},
	{"ECOLI", 5, 251645},
	{"SEATLE", 6, 251646},
	{"WOOSNAM", 7, 251647},
	{"SLUGGISHLY", 10, 251648},
	{"CUCHULAINN", 10, 251649},
	{"COMMISSIONABLE", 14, 251650},
	{"SUPPLEMENTHERBAL", 16, 251651},
	{"SMCRA", 5, 251652},
	{"MEGARA", 6, 251653},
	{"MAYENNE", 7, 251654},
	{"LISENCE", 7, 251655},
	{"GRABO", 5, 251656},
	{"MROZ", 4, 251657},
	{"BEARDLESS", 9, 251658},
	{"YSTRAD", 6, 251659},
	{"MITC", 4, 251660},
	{"METHOXYCHLOR", 12, 251661},
	{"HELENDALE", 9, 251662},
	{"TILLMANS", 8, 251663},
	{"RHYNGRWYD", 9, 251664},
	{"ABYSSINIANS", 11, 251665},
	{"POSIBILITY", 10, 251666},
	{"HELLERTOWN", 10, 251667},
	{"TIMELAPSE", 9, 251668},
	{"SCOBEE", 6, 251669},
	{"PROBLEEM", 8, 251670},
	{"STROZZI", 7, 251671},
	{"GENSER", 6, 251672},
	{"ELLOW", 5, 251673},
	{"EDMO", 4, 251674},
	{"CANINUS", 7, 251675},
	{"BIERSCH", 7, 251676},
	{"AGGIORNAMENTI", 13, 251677},
	{"HARLOCK", 7, 251678},
	{"SUIKO", 5, 251679},
	{"APPEN", 5, 251680},
	{"ALYSIA", 6, 251681},
	{"PARON", 5, 251682},
	{"MIDRIB", 6, 251683},
	{"FOGGIEST", 8, 251684},
	{"ANSELMI", 7, 251685},
	{"SUNSOUT", 7, 251686},
	{"ROBERVAL", 8, 251687},
	{"ONBLUR", 6, 251688},
	{"OBJECTBAR", 9, 251689},
	{"MALDA", 5, 251690},
	{"TRIST", 5, 251691},
	{"KATYDIDS", 8, 251692},
	{"MENSURATION", 11, 251693},
	{"INVISTA", 7, 251694},
	{"HCDX", 4, 251695},
	{"CHEERLESS", 9, 251696},
	{"ATANU", 5, 251697},
	{"REORIENTED", 10, 251698},
	{"MIRACLESUIT", 11, 251699},
	{"JAGGI", 5, 251700},
	{"BLIZZCENTER", 11, 251701},
	{"ROMIC", 5, 251702},
	{"GEDI", 4, 251703},
	{"YAZID", 5, 251704},
	{"TATLA", 5, 251705},
	{"LALITHA", 7, 251706},
	{"KHANA", 5, 251707},
	{"ACADE", 5, 251708},
	{"SWEITZER", 8, 251709},
	{"SCRIBER", 7, 251710},
	{"ETHMOID", 7, 251711},
	{"TENIDO", 6, 251712},
	{"URBANIZING", 10, 251713},
	{"ASPINALLS", 9, 251714},
	{"SELEKTA", 7, 251715},
	{"LAMBERTSON", 10, 251716},
	{"JOUKO", 5, 251717},
	{"GIBSONTON", 9, 251718},
	{"NEWSTEX", 7, 251719},
	{"LYCANTHROPY", 11, 251720},
	{"UPSIDEDOWN", 10, 251721},
	{"LANDSDOWNE", 10, 251722},
	{"WATERLAND", 9, 251723},
	{"LRZSZ", 5, 251724},
	{"ROHRE", 5, 251725},
	{"RALLYCROSS", 10, 251726},
	{"POUNDSTRETCHER", 14, 251727},
	{"KOOCANUSA", 9, 251728},
	{"TJENESTER", 9, 251729},
	{"OTOKO", 5, 251730},
	{"ADIPRENE", 8, 251731},
	{"ZHENJIANG", 9, 251732},
	{"GUMM", 4, 251733},
	{"FACILITITIES", 12, 251734},
	{"AMBASCIATORI", 12, 251735},
	{"POTTON", 6, 251736},
	{"CONFLATING", 10, 251737},
	{"CLARIN", 6, 251738},
	{"ABARAT", 6, 251739},
	{"MONTICOLA", 9, 251740},
	{"ZOLEDRONIC", 10, 251741},
	{"SAUGEEN", 7, 251742},
	{"INFODIAL", 8, 251743},
	{"ESTYN", 5, 251744},
	{"NUACHT", 6, 251745},
	{"GILLIN", 6, 251746},
	{"EWSLETTER", 9, 251747},
	{"WAINFLEET", 9, 251748},
	{"INCUS", 5, 251749},
	{"FULLA", 5, 251750},
	{"ULEV", 4, 251751},
	{"PRODUCTEUR", 10, 251752},
	{"HOUWE", 5, 251753},
	{"CRIMENES", 8, 251754},
	{"ARTHROSIS", 9, 251755},
	{"ACREE", 5, 251756},
	{"PERDIDA", 7, 251757},
	{"ELECTROMIGRATION", 16, 251758},
	{"DIMSTYLE", 8, 251759},
	{"HOKUTO", 6, 251760},
	{"COMPUTERBUYS", 12, 251761},
	{"SPOONFEEDER", 11, 251762},
	{"SAAREMAA", 8, 251763},
	{"KAYODE", 6, 251764},
	{"DINGOES", 7, 251765},
	{"BATTLESTATIONS", 14, 251766},
	{"ATTUNITY", 8, 251767},
	{"ESTRO", 5, 251768},
	{"OCILLA", 6, 251769},
	{"YZEC", 4, 251770},
	{"YNCC", 4, 251771},
	{"YGNE", 4, 251772},
	{"XROT", 4, 251773},
	{"XROM", 4, 251774},
	{"XRAB", 4, 251775},
	{"WUIS", 4, 251776},
	{"WUDI", 4, 251777},
	{"WHEJ", 4, 251778},
	{"WDSL", 4, 251779},
	{"WBCW", 4, 251780},
	{"VUIS", 4, 251781},
	{"VTOV", 4, 251782},
	{"VSJO", 4, 251783},
	{"VEZF", 4, 251784},
	{"VDDI", 4, 251785},
	{"VAAM", 4, 251786},
	{"UTUH", 4, 251787},
	{"USKC", 4, 251788},
	{"UOMP", 4, 251789},
	{"UINZ", 4, 251790},
	{"UAOF", 4, 251791},
	{"UAMT", 4, 251792},
	{"TGMC", 4, 251793},
	{"SYLH", 4, 251794},
	{"SCPO", 4, 251795},
	{"RRTR", 4, 251796},
	{"RPOG", 4, 251797},
	{"RCPO", 4, 251798},
	{"QRES", 4, 251799},
	{"PYDU", 4, 251800},
	{"PMAH", 4, 251801},
	{"OKAQ", 4, 251802},
	{"NYZO", 4, 251803},
	{"NYLF", 4, 251804},
	{"NLCO", 4, 251805},
	{"NGGB", 4, 251806},
	{"MZAH", 4, 251807},
	{"MGKG", 4, 251808},
	{"MEEZ", 4, 251809},
	{"MBUW", 4, 251810},
	{"LVSC", 4, 251811},
	{"LOAU", 4, 251812},
	{"LLNH", 4, 251813},
	{"LKYB", 4, 251814},
	{"LIKC", 4, 251815},
	{"KUER", 4, 251816},
	{"KCNN", 4, 251817},
	{"JRIC", 4, 251818},
	{"JKHA", 4, 251819},
	{"JAXT", 4, 251820},
	{"IXPH", 4, 251821},
	{"IAZB", 4, 251822},
	{"HPIK", 4, 251823},
	{"HMDE", 4, 251824},
	{"GSOK", 4, 251825},
	{"GOSV", 4, 251826},
	{"FSVA", 4, 251827},
	{"FNIP", 4, 251828},
	{"FKOU", 4, 251829},
	{"FKMO", 4, 251830},
	{"FIQA", 4, 251831},
	{"FEJI", 4, 251832},
	{"EZFE", 4, 251833},
	{"EYGH", 4, 251834},
	{"ELNW", 4, 251835},
	{"EKYU", 4, 251836},
	{"EBND", 4, 251837},
	{"DZIT", 4, 251838},
	{"DWAJ", 4, 251839},
	{"DUGR", 4, 251840},
	{"DFFA", 4, 251841},
	{"DBSE", 4, 251842},
	{"CYEP", 4, 251843},
	{"COBV", 4, 251844},
	{"CKPM", 4, 251845},
	{"BUDF", 4, 251846},
	{"BPMI", 4, 251847},
	{"BMOF", 4, 251848},
	{"AVLY", 4, 251849},
	{"ATDV", 4, 251850},
	{"AKYN", 4, 251851},
	{"AEJU", 4, 251852},
	{"ERIAL", 5, 251853},
	{"JULIANN", 7, 251854},
	{"HORSERACE", 9, 251855},
	{"GREFFE", 6, 251856},
	{"EDGEHILL", 8, 251857},
	{"CESC", 4, 251858},
	{"STEELING", 8, 251859},
	{"EGULATIONS", 10, 251860},
	{"INTERJURISDICTIONAL", 19, 251861},
	{"CRISIL", 6, 251862},
	{"TEILNEHMER", 10, 251863},
	{"PASTIS", 6, 251864},
	{"IKIRU", 5, 251865},
	{"HEDGESVILLE", 11, 251866},
	{"UNTRIMMED", 9, 251867},
	{"JEHANGIR", 8, 251868},
	{"ESTERHAZY", 9, 251869},
	{"NATIVISM", 8, 251870},
	{"NERY", 4, 251871},
	{"HORNDEAN", 8, 251872},
	{"LOJAS", 5, 251873},
	{"RASCHE", 6, 251874},
	{"ERFC", 4, 251875},
	{"TUCH", 4, 251876},
	{"WACHT", 5, 251877},
	{"CHARTBOOK", 9, 251878},
	{"AMKOR", 5, 251879},
	{"VICIOSOS", 8, 251880},
	{"MICROFINE", 9, 251881},
	{"LOFA", 4, 251882},
	{"TMATTERN", 8, 251883},
	{"LYBRA", 5, 251884},
	{"TOPICACTION", 11, 251885},
	{"NFOR", 4, 251886},
	{"HOUSTONIAN", 10, 251887},
	{"CUCKHOLD", 8, 251888},
	{"KARLY", 5, 251889},
	{"DOUD", 4, 251890},
	{"CIVILES", 7, 251891},
	{"SUFFICENT", 9, 251892},
	{"FOURTRAX", 8, 251893},
	{"DNIEPER", 7, 251894},
	{"BENZIN", 6, 251895},
	{"WORKBOARD", 9, 251896},
	{"SUBLATTICE", 10, 251897},
	{"GUSHUE", 6, 251898},
	{"INTRAGOVERNMENTAL", 17, 251899},
	{"BOQUETE", 7, 251900},
	{"MANZANA", 7, 251901},
	{"JOBD", 4, 251902},
	{"ALMORA", 6, 251903},
	{"TUOMINEN", 8, 251904},
	{"RAZALI", 6, 251905},
	{"PLAZO", 5, 251906},
	{"BASILICO", 8, 251907},
	{"JDORJE", 6, 251908},
	{"CONSITUTION", 11, 251909},
	{"SERVERADMIN", 11, 251910},
	{"PEOM", 4, 251911},
	{"ANCED", 5, 251912},
	{"TAGMARKMAN", 10, 251913},
	{"DREDGER", 7, 251914},
	{"PSTART", 6, 251915},
	{"PRECIOUSNESS", 12, 251916},
	{"PICAS", 5, 251917},
	{"TRAVELLIN", 9, 251918},
	{"PICKOFF", 7, 251919},
	{"MOISTENING", 10, 251920},
	{"CASSOPOLIS", 10, 251921},
	{"MOVIX", 5, 251922},
	{"MAIRA", 5, 251923},
	{"CEFTIN", 6, 251924},
	{"CAPTURA", 7, 251925},
	{"WOODBOURNE", 10, 251926},
	{"SHAWNNA", 7, 251927},
	{"SAVARY", 6, 251928},
	{"UVEAL", 5, 251929},
	{"SODTWARE", 8, 251930},
	{"MILLAA", 6, 251931},
	{"KELSIE", 6, 251932},
	{"BOOKNEWS", 8, 251933},
	{"APPDB", 5, 251934},
	{"WARESDIRECT", 11, 251935},
	{"TULKAREM", 8, 251936},
	{"PERRIGO", 7, 251937},
	{"EJECUTIVO", 9, 251938},
	{"YAPHANK", 7, 251939},
	{"PREDAWN", 7, 251940},
	{"BREASTPUMPS", 11, 251941},
	{"EXCITINGLY", 10, 251942},
	{"BAREROOT", 8, 251943},
	{"STROKEJOBS", 10, 251944},
	{"SNOWDRIFT", 9, 251945},
	{"CRONER", 6, 251946},
	{"CINCHER", 7, 251947},
	{"VERTEBROPLASTY", 14, 251948},
	{"UNPREJUDICED", 12, 251949},
	{"SIDECHAIN", 9, 251950},
	{"ROOBARB", 7, 251951},
	{"KETCHERSIDE", 11, 251952},
	{"CINCHES", 7, 251953},
	{"ARNY", 4, 251954},
	{"VERMONTER", 9, 251955},
	{"TIPICI", 6, 251956},
	{"SLOWDIVE", 8, 251957},
	{"JANOWSKI", 8, 251958},
	{"CAILEY", 6, 251959},
	{"YALLOCK", 7, 251960},
	{"VICKERMAN", 9, 251961},
	{"SHOPPACH", 8, 251962},
	{"HARPERTROPHY", 12, 251963},
	{"GREETINGCARDS", 13, 251964},
	{"EXPLICATIONS", 12, 251965},
	{"BEACHCOMBING", 12, 251966},
	{"SEAFAIR", 7, 251967},
	{"DAPNIA", 6, 251968},
	{"ALCES", 5, 251969},
	{"FSSP", 4, 251970},
	{"ARIANISM", 8, 251971},
	{"NAFEX", 5, 251972},
	{"MIDL", 4, 251973},
	{"IRPA", 4, 251974},
	{"INDIANAUSA", 10, 251975},
	{"POWERPLUS", 9, 251976},
	{"MSPR", 4, 251977},
	{"KUROSAKI", 8, 251978},
	{"JECTIVE", 7, 251979},
	{"HARBER", 6, 251980},
	{"REPRODUCIBLY", 12, 251981},
	{"PERINDOPRIL", 11, 251982},
	{"LAMBDIN", 7, 251983},
	{"AKERLOF", 7, 251984},
	{"PRICINGS", 8, 251985},
	{"SUMMARYLAST", 11, 251986},
	{"LOCORRIERE", 10, 251987},
	{"GLUELESS", 8, 251988},
	{"CENTRIX", 7, 251989},
	{"ASHIKAGA", 8, 251990},
	{"PROUDMOORE", 10, 251991},
	{"KALLISTA", 8, 251992},
	{"HAINSWORTH", 10, 251993},
	{"CVAC", 4, 251994},
	{"SRINI", 5, 251995},
	{"MATCHS", 6, 251996},
	{"INSPECTEUR", 10, 251997},
	{"HYEOK", 5, 251998},
	{"PENCAK", 6, 251999},
	{"OTOLARYNGOLOGIST", 16, 252000},
	{"DUSSELDORP", 10, 252001},
	{"REOFFENDING", 11, 252002},
	{"KARIMNAGAR", 10, 252003},
	{"CAPPUCCINOS", 11, 252004},
	{"TREEBEARD", 9, 252005},
	{"RAMBERG", 7, 252006},
	{"EREC", 4, 252007},
	{"DIMONA", 6, 252008},
	{"TENNIEL", 7, 252009},
	{"LODGINGGUIDE", 12, 252010},
	{"ERGOSTEROL", 10, 252011},
	{"DISSIMULATION", 13, 252012},
	{"BROOKTON", 8, 252013},
	{"BRANDONS", 8, 252014},
	{"ANNAMALAI", 9, 252015},
	{"MOOSONEE", 8, 252016},
	{"BRIANC", 6, 252017},
	{"AVIVO", 5, 252018},
	{"DONGA", 5, 252019},
	{"WPU", 3, 252020},
	{"SITREP", 6, 252021},
	{"BIENNIALS", 9, 252022},
	{"SQUAR", 5, 252023},
	{"ALDIS", 5, 252024},
	{"RESTES", 6, 252025},
	{"MERLINO", 7, 252026},
	{"GLOM", 4, 252027},
	{"GIVAT", 5, 252028},
	{"BREIF", 5, 252029},
	{"REGINES", 7, 252030},
	{"PPER", 4, 252031},
	{"MAKRIS", 6, 252032},
	{"INTERAKTIVE", 11, 252033},
	{"DEARAUGO", 8, 252034},
	{"VERSIONES", 9, 252035},
	{"LGAS", 4, 252036},
	{"ENDERMOLOGIE", 12, 252037},
	{"ARMON", 5, 252038},
	{"MUNCHES", 7, 252039},
	{"LLYR", 4, 252040},
	{"LIBUSER", 7, 252041},
	{"CBIZ", 4, 252042},
	{"TALISKER", 8, 252043},
	{"PCIA", 4, 252044},
	{"IGNORABLE", 9, 252045},
	{"AMGN", 4, 252046},
	{"ENBERG", 6, 252047},
	{"VLINK", 5, 252048},
	{"LADYBIRDS", 9, 252049},
	{"DEBURGH", 7, 252050},
	{"ANALYTICITY", 11, 252051},
	{"WINFUEL", 7, 252052},
	{"VARIANTE", 8, 252053},
	{"SOUNDCLIPS", 10, 252054},
	{"BELLINO", 7, 252055},
	{"YAHOOMAPS", 9, 252056},
	{"SIBILLA", 7, 252057},
	{"POSTCALENDAR", 12, 252058},
	{"GEURTS", 6, 252059},
	{"WAVERTREE", 9, 252060},
	{"LAURETH", 7, 252061},
	{"HENRIQUEZ", 9, 252062},
	{"GARDMAN", 7, 252063},
	{"LEOBEN", 6, 252064},
	{"GRAZIANI", 8, 252065},
	{"ADALBERTO", 9, 252066},
	{"STUMPER", 7, 252067},
	{"CRAIGIEBURN", 11, 252068},
	{"CEILINGED", 9, 252069},
	{"PINED", 5, 252070},
	{"INDAPAMIDE", 10, 252071},
	{"BERNARDAUD", 10, 252072},
	{"HUMINT", 6, 252073},
	{"GRAEAGLE", 8, 252074},
	{"SCATTING", 8, 252075},
	{"PICTORIALLY", 11, 252076},
	{"MAGHERA", 7, 252077},
	{"CROOKSVILLE", 11, 252078},
	{"AVAILABLES", 10, 252079},
	{"MAKEFLAGS", 9, 252080},
	{"OPPILIAPPAN", 11, 252081},
	{"FLUOROPHORES", 12, 252082},
	{"CHAYS", 5, 252083},
	{"RATHDOWN", 8, 252084},
	{"PROVISIONALS", 12, 252085},
	{"NONPAYING", 9, 252086},
	{"LIQUITEX", 8, 252087},
	{"FONDLES", 7, 252088},
	{"AGSYNC", 6, 252089},
	{"BLAGO", 5, 252090},
	{"ASKYOURNEIGHBOUR", 16, 252091},
	{"VIIX", 4, 252092},
	{"SINGA", 5, 252093},
	{"ROMD", 4, 252094},
	{"AUGHRIM", 7, 252095},
	{"TRSVEL", 6, 252096},
	{"HESPELER", 8, 252097},
	{"HIRSUTA", 7, 252098},
	{"MORIS", 5, 252099},
	{"WWWWE", 5, 252100},
	{"INDUSTRYS", 9, 252101},
	{"ARTIZEN", 7, 252102},
	{"SGDID", 5, 252103},
	{"POALES", 6, 252104},
	{"ADVERBLOG", 9, 252105},
	{"MOSTER", 6, 252106},
	{"JIJI", 4, 252107},
	{"BALLITO", 7, 252108},
	{"LEXILE", 6, 252109},
	{"KILBANE", 7, 252110},
	{"INCULCATING", 11, 252111},
	{"GVD", 3, 252112},
	{"TOOLMAKING", 10, 252113},
	{"DINAPOLI", 8, 252114},
	{"DATANET", 7, 252115},
	{"JDRSANTOS", 9, 252116},
	{"ANODIZE", 7, 252117},
	{"UMICORE", 7, 252118},
	{"TEUR", 4, 252119},
	{"SPRUCES", 7, 252120},
	{"MOBILEBURN", 10, 252121},
	{"KANERIA", 7, 252122},
	{"MATHON", 6, 252123},
	{"TELLIS", 6, 252124},
	{"PETARDAS", 8, 252125},
	{"MESMERISED", 10, 252126},
	{"CASEMODS", 8, 252127},
	{"SALZGITTER", 10, 252128},
	{"IBUF", 4, 252129},
	{"FILLINSTACKTRACE", 16, 252130},
	{"EDMONSTON", 9, 252131},
	{"CUTCO", 5, 252132},
	{"ACMC", 4, 252133},
	{"ZKIN", 4, 252134},
	{"YNPO", 4, 252135},
	{"XTMU", 4, 252136},
	{"XORF", 4, 252137},
	{"XKEY", 4, 252138},
	{"XATR", 4, 252139},
	{"WWLO", 4, 252140},
	{"WCWI", 4, 252141},
	{"WAIB", 4, 252142},
	{"WAAD", 4, 252143},
	{"VAEL", 4, 252144},
	{"UXSC", 4, 252145},
	{"UXLA", 4, 252146},
	{"UWEW", 4, 252147},
	{"ULPP", 4, 252148},
	{"UKOL", 4, 252149},
	{"TMLD", 4, 252150},
	{"SRDO", 4, 252151},
	{"SPYE", 4, 252152},
	{"SKIU", 4, 252153},
	{"SAUQ", 4, 252154},
	{"RZBE", 4, 252155},
	{"RXME", 4, 252156},
	{"RVCO", 4, 252157},
	{"RSHK", 4, 252158},
	{"RHEZ", 4, 252159},
	{"RGUD", 4, 252160},
	{"REGV", 4, 252161},
	{"RAZV", 4, 252162},
	{"PYOV", 4, 252163},
	{"POWO", 4, 252164},
	{"OTCD", 4, 252165},
	{"OLUZ", 4, 252166},
	{"OFYT", 4, 252167},
	{"OFHL", 4, 252168},
	{"NRCM", 4, 252169},
	{"NOJR", 4, 252170},
	{"NFDR", 4, 252171},
	{"MLLA", 4, 252172},
	{"MGOW", 4, 252173},
	{"MFMA", 4, 252174},
	{"LXRA", 4, 252175},
	{"LNSB", 4, 252176},
	{"KMHB", 4, 252177},
	{"JSER", 4, 252178},
	{"JMAD", 4, 252179},
	{"IRVU", 4, 252180},
	{"IDNY", 4, 252181},
	{"IADF", 4, 252182},
	{"HUIR", 4, 252183},
	{"HLOX", 4, 252184},
	{"GAUP", 4, 252185},
	{"FFUD", 4, 252186},
	{"EVKE", 4, 252187},
	{"EUZI", 4, 252188},
	{"EUYG", 4, 252189},
	{"EPNM", 4, 252190},
	{"ENUV", 4, 252191},
	{"EKEU", 4, 252192},
	{"DOCY", 4, 252193},
	{"DEZU", 4, 252194},
	{"CJET", 4, 252195},
	{"BPEX", 4, 252196},
	{"BOAW", 4, 252197},
	{"BFES", 4, 252198},
	{"BEKB", 4, 252199},
	{"BAPH", 4, 252200},
	{"ATRF", 4, 252201},
	{"ATJR", 4, 252202},
	{"ASQF", 4, 252203},
	{"ALBM", 4, 252204},
	{"AJDO", 4, 252205},
	{"AFUJ", 4, 252206},
	{"ADRT", 4, 252207},
	{"SALLI", 5, 252208},
	{"PROCON", 6, 252209},
	{"PAGENO", 6, 252210},
	{"MIMELNK", 7, 252211},
	{"DESOCUPADOS", 11, 252212},
	{"BARABASI", 8, 252213},
	{"YOUNKIN", 7, 252214},
	{"WINOKUR", 7, 252215},
	{"ESHLEMAN", 8, 252216},
	{"DISAPEAR", 8, 252217},
	{"BABBIE", 6, 252218},
	{"MCGARRIGLE", 10, 252219},
	{"COMBIEN", 7, 252220},
	{"THROUGHTOUT", 11, 252221},
	{"NCRC", 4, 252222},
	{"LOUBOUTIN", 9, 252223},
	{"IFCSIMPLEPROPERTY", 17, 252224},
	{"SENCILLO", 8, 252225},
	{"NAWROCKI", 8, 252226},
	{"LALAH", 5, 252227},
	{"DEOXYRIBONUCLEASES", 18, 252228},
	{"STARGIRL", 8, 252229},
	{"REENGINEER", 10, 252230},
	{"LUNDEN", 6, 252231},
	{"DAILYCANDY", 10, 252232},
	{"BUMETANIDE", 10, 252233},
	{"NECESIDADES", 11, 252234},
	{"FILCH", 5, 252235},
	{"DEBY", 4, 252236},
	{"BGAFD", 5, 252237},
	{"BARISH", 6, 252238},
	{"PENSANDO", 8, 252239},
	{"OTLK", 4, 252240},
	{"ISHMAIL", 7, 252241},
	{"IPODNN", 6, 252242},
	{"UVVIS", 5, 252243},
	{"LAKA", 4, 252244},
	{"IFPS", 4, 252245},
	{"GOLAY", 5, 252246},
	{"DOGTRA", 6, 252247},
	{"POWERCADD", 9, 252248},
	{"KABBALA", 7, 252249},
	{"JAISH", 5, 252250},
	{"GUNFLINT", 8, 252251},
	{"CEEDING", 7, 252252},
	{"URALIC", 6, 252253},
	{"ROMATES", 7, 252254},
	{"MEISTERSINGER", 13, 252255},
	{"CANARE", 6, 252256},
	{"VALDARNO", 8, 252257},
	{"SANDNES", 7, 252258},
	{"PRESHARED", 9, 252259},
	{"KIFF", 4, 252260},
	{"JOBMARKET", 9, 252261},
	{"JRANDOM", 7, 252262},
	{"GERST", 5, 252263},
	{"WIEL", 4, 252264},
	{"ROWETT", 6, 252265},
	{"EATONS", 6, 252266},
	{"AYOOB", 5, 252267},
	{"WEEDER", 6, 252268},
	{"MONAZITE", 8, 252269},
	{"KOHINOOR", 8, 252270},
	{"EMOTIONALITY", 12, 252271},
	{"AILINE", 6, 252272},
	{"MALINS", 6, 252273},
	{"EIDSVOLD", 8, 252274},
	{"MATARA", 6, 252275},
	{"ZOOMBROWSER", 11, 252276},
	{"UNSENSORED", 10, 252277},
	{"GASTER", 6, 252278},
	{"SARRE", 5, 252279},
	{"MOVIEE", 6, 252280},
	{"SMRS", 4, 252281},
	{"OORLOG", 6, 252282},
	{"INTERPARLIAMENTARY", 18, 252283},
	{"DISCURSO", 8, 252284},
	{"CAMBOGIA", 8, 252285},
	{"BLER", 4, 252286},
	{"KCMO", 4, 252287},
	{"HUGETITS", 8, 252288},
	{"BLADDERWRACK", 12, 252289},
	{"EZRETREAT", 9, 252290},
	{"ADAMIC", 6, 252291},
	{"CINDERELLAS", 11, 252292},
	{"DMAT", 4, 252293},
	{"DIMITROVA", 9, 252294},
	{"PRTS", 4, 252295},
	{"PLAITS", 6, 252296},
	{"FREETRIALSOFT", 13, 252297},
	{"EISCHEN", 7, 252298},
	{"BOISSEVAIN", 10, 252299},
	{"MANNUM", 6, 252300},
	{"EIGHTIETH", 9, 252301},
	{"BUSHCRAFT", 9, 252302},
	{"KAEDING", 7, 252303},
	{"DELIN", 5, 252304},
	{"GOJIRA", 6, 252305},
	{"MANCIC", 6, 252306},
	{"DESSES", 6, 252307},
	{"PURPURE", 7, 252308},
	{"CENTOCOR", 8, 252309},
	{"CABINAS", 7, 252310},
	{"THORSTEIN", 9, 252311},
	{"TECHFORGE", 9, 252312},
	{"HOLSCLAW", 8, 252313},
	{"BALCOM", 6, 252314},
	{"CRAWSHAW", 8, 252315},
	{"AWAR", 4, 252316},
	{"HEPZIBAH", 8, 252317},
	{"DETTMER", 7, 252318},
	{"MONEYPUNCT", 10, 252319},
	{"MAKEBOX", 7, 252320},
	{"IVANOVITCH", 10, 252321},
	{"DTRA", 4, 252322},
	{"DEEPBLUE", 8, 252323},
	{"UNBEATENS", 9, 252324},
	{"SPINOCEREBELLAR", 15, 252325},
	{"HERBON", 6, 252326},
	{"SOTTWARE", 8, 252327},
	{"MENHINICK", 9, 252328},
	{"FLEUVE", 6, 252329},
	{"FARNER", 6, 252330},
	{"CPUIC", 5, 252331},
	{"RAWLEY", 6, 252332},
	{"MMIX", 4, 252333},
	{"KIRSTI", 6, 252334},
	{"EQUIVILENT", 10, 252335},
	{"GETTABLE", 8, 252336},
	{"AVICI", 5, 252337},
	{"SUBSTANTIALITY", 14, 252338},
	{"ANTHROPOCENTRIC", 15, 252339},
	{"USCALL", 6, 252340},
	{"LAKHANI", 7, 252341},
	{"BOVILL", 6, 252342},
	{"OVERSPEED", 9, 252343},
	{"ANLEN", 5, 252344},
	{"NEGOTIA", 7, 252345},
	{"DAFTAR", 6, 252346},
	{"MALEFIRST", 9, 252347},
	{"GAUCI", 5, 252348},
	{"DEPRENYL", 8, 252349},
	{"ANODISING", 9, 252350},
	{"CSHB", 4, 252351},
	{"BIOSMAGAZINE", 12, 252352},
	{"MOMONGA", 7, 252353},
	{"METALICA", 8, 252354},
	{"CONEXIONES", 10, 252355},
	{"SLYCK", 5, 252356},
	{"MIZERAK", 7, 252357},
	{"WSGI", 4, 252358},
	{"TOTEMIC", 7, 252359},
	{"MESSINESS", 9, 252360},
	{"JPROFILER", 9, 252361},
	{"EFFICIENY", 9, 252362},
	{"BMIS", 4, 252363},
	{"PLETION", 7, 252364},
	{"EUTHYPHRO", 9, 252365},
	{"COMPRES", 7, 252366},
	{"ISIGN", 5, 252367},
	{"GHOSTED", 7, 252368},
	{"FREROTTE", 8, 252369},
	{"ELFORD", 6, 252370},
	{"BASCULE", 7, 252371},
	{"ABBEYDALE", 9, 252372},
	{"WOODCARVINGS", 12, 252373},
	{"WINNINGHAM", 10, 252374},
	{"PAPR", 4, 252375},
	{"OORURI", 6, 252376},
	{"HARNDEN", 7, 252377},
	{"ECHOSTREAM", 10, 252378},
	{"SUBCOMPLEX", 10, 252379},
	{"TRINNY", 6, 252380},
	{"JOHANNSON", 9, 252381},
	{"EGION", 5, 252382},
	{"COLACE", 6, 252383},
	{"NONSLIP", 7, 252384},
	{"LYNK", 4, 252385},
	{"KENSUKE", 7, 252386},
	{"DECKERT", 7, 252387},
	{"TWYFELFONTEIN", 13, 252388},
	{"TRESSEL", 7, 252389},
	{"PBXTEXTBOOKMARK", 15, 252390},
	{"ANORAKS", 7, 252391},
	{"ROCHUS", 6, 252392},
	{"MAZZEI", 6, 252393},
	{"BECONTREE", 9, 252394},
	{"SPRS", 4, 252395},
	{"STRADLING", 9, 252396},
	{"RUCKS", 5, 252397},
	{"KINETICALLY", 11, 252398},
	{"TONGJI", 6, 252399},
	{"STONEWASHED", 11, 252400},
	{"PUBLICID", 8, 252401},
	{"ALPHAGRAPHICS", 13, 252402},
	{"UNDERACHIEVED", 13, 252403},
	{"TWIKICATEGORYTABLE", 18, 252404},
	{"POSITRONIC", 10, 252405},
	{"GODAWFUL", 8, 252406},
	{"SHINGLED", 8, 252407},
	{"SCHEUERMANN", 11, 252408},
	{"PESCADO", 7, 252409},
	{"OFALLON", 7, 252410},
	{"STARWAY", 7, 252411},
	{"PIME", 4, 252412},
	{"GOLKAR", 6, 252413},
	{"THAXTED", 7, 252414},
	{"PHILBY", 6, 252415},
	{"IMNAHA", 6, 252416},
	{"HORNICK", 7, 252417},
	{"NISHIZAWA", 9, 252418},
	{"MARTORELL", 9, 252419},
	{"GUANXI", 6, 252420},
	{"CATARRHALIS", 11, 252421},
	{"CHEATOOGLE", 10, 252422},
	{"SYNAPTOTAGMIN", 13, 252423},
	{"RHYW", 4, 252424},
	{"LEKS", 4, 252425},
	{"KLEVEN", 6, 252426},
	{"JDOCS", 5, 252427},
	{"CAMAU", 5, 252428},
	{"BABESIOSIS", 10, 252429},
	{"AGRIPPINA", 9, 252430},
	{"SPYCATCHER", 10, 252431},
	{"HESWALL", 7, 252432},
	{"ABACRE", 6, 252433},
	{"CORKBOARD", 9, 252434},
	{"THEATRICALITY", 13, 252435},
	{"KAUNDA", 6, 252436},
	{"SOUNDWAVES", 10, 252437},
	{"CASPARI", 7, 252438},
	{"TEARIN", 6, 252439},
	{"SCOUTERS", 8, 252440},
	{"NASHEEDS", 8, 252441},
	{"HARVESTOR", 9, 252442},
	{"DIPPENAAR", 9, 252443},
	{"UPMOST", 6, 252444},
	{"SELEUCID", 8, 252445},
	{"INFLUENCIA", 10, 252446},
	{"HALOES", 6, 252447},
	{"BRICKFIELD", 10, 252448},
	{"BLASPHEMER", 10, 252449},
	{"LIBCROCO", 8, 252450},
	{"CHICKENHAWKS", 12, 252451},
	{"PERSONEEL", 9, 252452},
	{"NOBUYOSHI", 9, 252453},
	{"KADOKAWA", 8, 252454},
	{"GLUTINOSA", 9, 252455},
	{"EXMORE", 6, 252456},
	{"BEHLENDORF", 10, 252457},
	{"SPECIALSREQUEST", 15, 252458},
	{"BELABOR", 7, 252459},
	{"LONGSPUR", 8, 252460},
	{"XTENSIONS", 9, 252461},
	{"SPKI", 4, 252462},
	{"PENETROMETER", 12, 252463},
	{"HIRTA", 5, 252464},
	{"HACMP", 5, 252465},
	{"SCRAGGLY", 8, 252466},
	{"IMPEY", 5, 252467},
	{"CROSSGATES", 10, 252468},
	{"TOPOCK", 6, 252469},
	{"ALICYN", 6, 252470},
	{"WINDCREST", 9, 252471},
	{"MONSTA", 6, 252472},
	{"KORSMEYER", 9, 252473},
	{"HERMAS", 6, 252474},
	{"POJOAQUE", 8, 252475},
	{"KINNAN", 6, 252476},
	{"ZESJ", 4, 252477},
	{"YPDA", 4, 252478},
	{"YNSU", 4, 252479},
	{"YMSL", 4, 252480},
	{"YMLB", 4, 252481},
	{"YAOC", 4, 252482},
	{"XYFI", 4, 252483},
	{"XSOR", 4, 252484},
	{"XECA", 4, 252485},
	{"XBIS", 4, 252486},
	{"WSAK", 4, 252487},
	{"VFAC", 4, 252488},
	{"VETF", 4, 252489},
	{"VAVO", 4, 252490},
	{"UXIU", 4, 252491},
	{"UUMM", 4, 252492},
	{"URLD", 4, 252493},
	{"UHEM", 4, 252494},
	{"UBIW", 4, 252495},
	{"TXER", 4, 252496},
	{"TPOB", 4, 252497},
	{"TOXR", 4, 252498},
	{"TDSU", 4, 252499},
	{"RUGK", 4, 252500},
	{"RTHZ", 4, 252501},
	{"RIDZ", 4, 252502},
	{"RDVR", 4, 252503},
	{"PRUB", 4, 252504},
	{"POMF", 4, 252505},
	{"PMTA", 4, 252506},
	{"OXSR", 4, 252507},
	{"OVSB", 4, 252508},
	{"ORJD", 4, 252509},
	{"OGTV", 4, 252510},
	{"NRFI", 4, 252511},
	{"NKKO", 4, 252512},
	{"NBCG", 4, 252513},
	{"MRJI", 4, 252514},
	{"MMLI", 4, 252515},
	{"MGCO", 4, 252516},
	{"LUXB", 4, 252517},
	{"KEWW", 4, 252518},
	{"KAXE", 4, 252519},
	{"INJP", 4, 252520},
	{"ILUV", 4, 252521},
	{"IKSL", 4, 252522},
	{"IDNG", 4, 252523},
	{"HTMD", 4, 252524},
	{"HMPA", 4, 252525},
	{"HJOC", 4, 252526},
	{"GUAZ", 4, 252527},
	{"GJOL", 4, 252528},
	{"GIRV", 4, 252529},
	{"GHPS", 4, 252530},
	{"FEIV", 4, 252531},
	{"EZFL", 4, 252532},
	{"EKMB", 4, 252533},
	{"EHBU", 4, 252534},
	{"ECPD", 4, 252535},
	{"DYIC", 4, 252536},
	{"DXME", 4, 252537},
	{"DWAB", 4, 252538},
	{"DSYP", 4, 252539},
	{"DPAX", 4, 252540},
	{"DOSX", 4, 252541},
	{"DMPR", 4, 252542},
	{"DGST", 4, 252543},
	{"DBAW", 4, 252544},
	{"DATX", 4, 252545},
	{"CVOW", 4, 252546},
	{"CRYD", 4, 252547},
	{"CKKL", 4, 252548},
	{"BWIS", 4, 252549},
	{"BRYH", 4, 252550},
	{"BLAP", 4, 252551},
	{"BEKR", 4, 252552},
	{"BAHY", 4, 252553},
	{"AMNL", 4, 252554},
	{"ALUV", 4, 252555},
	{"AGHP", 4, 252556},
	{"UDR", 3, 252557},
	{"ROIL", 4, 252558},
	{"KRASNAPOLSKY", 12, 252559},
	{"BIZZAROKIEHL", 12, 252560},
	{"AGAYNE", 6, 252561},
	{"NICCOL", 6, 252562},
	{"CHEEKBONE", 9, 252563},
	{"MINOC", 5, 252564},
	{"GLOBECAST", 9, 252565},
	{"FROR", 4, 252566},
	{"BRIDEWELL", 9, 252567},
	{"TERTIA", 6, 252568},
	{"WILHOIT", 7, 252569},
	{"RPSI", 4, 252570},
	{"CONTICO", 7, 252571},
	{"SHIRELLES", 9, 252572},
	{"SAWAYA", 6, 252573},
	{"MAREL", 5, 252574},
	{"INSTALLDIR", 10, 252575},
	{"GORENG", 6, 252576},
	{"DAZZLERS", 8, 252577},
	{"CYNHYRCHU", 9, 252578},
	{"MARGAY", 6, 252579},
	{"HAMSUN", 6, 252580},
	{"TOKENIZE", 8, 252581},
	{"PRYDA", 5, 252582},
	{"LUMBAGO", 7, 252583},
	{"GSMA", 4, 252584},
	{"NABLA", 5, 252585},
	{"KAIULANI", 8, 252586},
	{"FLCC", 4, 252587},
	{"ISWIPE", 6, 252588},
	{"GADGETGIRL", 10, 252589},
	{"SOFTWARS", 8, 252590},
	{"GORBY", 5, 252591},
	{"CRAZYTALK", 9, 252592},
	{"WFTC", 4, 252593},
	{"VALLIANT", 8, 252594},
	{"EZULA", 5, 252595},
	{"UNIK", 4, 252596},
	{"RAQUELS", 7, 252597},
	{"EIXAMPLE", 8, 252598},
	{"DIGITRON", 8, 252599},
	{"KIELDER", 7, 252600},
	{"EVERSHEDS", 9, 252601},
	{"CHIROPODIST", 11, 252602},
	{"GABAY", 5, 252603},
	{"DIRCK", 5, 252604},
	{"BOOZOO", 6, 252605},
	{"BIRTLEY", 7, 252606},
	{"AAXX", 4, 252607},
	{"ESPOTTING", 9, 252608},
	{"PETAH", 5, 252609},
	{"LARYNGOSCOPY", 12, 252610},
	{"KNAACK", 6, 252611},
	{"FILMFEST", 8, 252612},
	{"AVLABS", 6, 252613},
	{"ARENE", 5, 252614},
	{"STARECASE", 9, 252615},
	{"YAVUZ", 5, 252616},
	{"FURSE", 5, 252617},
	{"YANBU", 5, 252618},
	{"CHAGE", 5, 252619},
	{"RAYCROFT", 8, 252620},
	{"NEUBURG", 7, 252621},
	{"LITANIES", 8, 252622},
	{"ADVANCENO", 9, 252623},
	{"TELMEX", 6, 252624},
	{"RICHMONDSHIRE", 13, 252625},
	{"MULLETT", 7, 252626},
	{"MCMAHONS", 8, 252627},
	{"SMALLWORLD", 10, 252628},
	{"METROMEDIA", 10, 252629},
	{"DROUHIN", 7, 252630},
	{"COPOLYMERIZATION", 16, 252631},
	{"ALONENESS", 9, 252632},
	{"VEAU", 4, 252633},
	{"TPGA", 4, 252634},
	{"KALLANG", 7, 252635},
	{"WEBREFERENCE", 12, 252636},
	{"GERMA", 5, 252637},
	{"COMMSCOPE", 9, 252638},
	{"PERIVALE", 8, 252639},
	{"HANJIN", 6, 252640},
	{"CRIANZA", 7, 252641},
	{"XLOCKMORE", 9, 252642},
	{"ROTTMAN", 7, 252643},
	{"FUQ", 3, 252644},
	{"AZIJA", 5, 252645},
	{"OREDR", 5, 252646},
	{"HARDWORK", 8, 252647},
	{"SKYLANE", 7, 252648},
	{"OVERDRIVEN", 10, 252649},
	{"MONEYSAVERS", 11, 252650},
	{"LEVANTINE", 9, 252651},
	{"VERL", 4, 252652},
	{"SHASHANK", 8, 252653},
	{"STRADE", 6, 252654},
	{"HAUGAN", 6, 252655},
	{"CEEJ", 4, 252656},
	{"ZEMLYA", 6, 252657},
	{"PIRAT", 5, 252658},
	{"TORICAL", 7, 252659},
	{"ENDPLATE", 8, 252660},
	{"THRILLSEEKERS", 13, 252661},
	{"KAYODEOK", 8, 252662},
	{"LIGS", 4, 252663},
	{"FINEBERG", 8, 252664},
	{"FAMOUSE", 7, 252665},
	{"NONSMOOTH", 9, 252666},
	{"FIDS", 4, 252667},
	{"MARYE", 5, 252668},
	{"FELGTORG", 8, 252669},
	{"ENVIRONME", 9, 252670},
	{"SAKSA", 5, 252671},
	{"PVALUE", 6, 252672},
	{"MARUSINA", 8, 252673},
	{"COSELL", 6, 252674},
	{"ALTERNITY", 9, 252675},
	{"MHOR", 4, 252676},
	{"MAIZ", 4, 252677},
	{"LYMPHOBLASTOID", 14, 252678},
	{"GARREN", 6, 252679},
	{"GANTER", 6, 252680},
	{"ELLADAN", 7, 252681},
	{"TORMEN", 6, 252682},
	{"TOMIC", 5, 252683},
	{"CASSIAN", 7, 252684},
	{"TINYURL", 7, 252685},
	{"POWERDIRECTOR", 13, 252686},
	{"PRICETARGET", 11, 252687},
	{"MORGUL", 6, 252688},
	{"KILOHERTZ", 9, 252689},
	{"BJB", 3, 252690},
	{"AGNESAPARIS", 11, 252691},
	{"MERNA", 5, 252692},
	{"HSPICE", 6, 252693},
	{"EFIC", 4, 252694},
	{"BOTANICALLY", 11, 252695},
	{"BASHAW", 6, 252696},
	{"ORISHA", 6, 252697},
	{"BUDDED", 6, 252698},
	{"KOKIRI", 6, 252699},
	{"ARRHYTHMIC", 10, 252700},
	{"ANYON", 5, 252701},
	{"UNIWERSYTET", 11, 252702},
	{"LIEST", 5, 252703},
	{"DRPS", 4, 252704},
	{"CHATO", 5, 252705},
	{"PROCONNECT", 10, 252706},
	{"LEOVINUS", 8, 252707},
	{"TRADURRE", 8, 252708},
	{"RONIS", 5, 252709},
	{"METROCALL", 9, 252710},
	{"PLAINTIVELY", 11, 252711},
	{"MOUTHPARTS", 10, 252712},
	{"MOONIES", 7, 252713},
	{"OTHERKIN", 8, 252714},
	{"GRANDHOTEL", 10, 252715},
	{"TRISA", 5, 252716},
	{"ROCEDURES", 9, 252717},
	{"PARANJAPE", 9, 252718},
	{"MAPBLAST", 8, 252719},
	{"YOURMUSIC", 9, 252720},
	{"VOYLES", 6, 252721},
	{"KARLYN", 6, 252722},
	{"INVESTIG", 8, 252723},
	{"GARAGEROCK", 10, 252724},
	{"DEGRANULATION", 13, 252725},
	{"BIRZEIT", 7, 252726},
	{"PHALANGES", 9, 252727},
	{"LYRICSHOME", 10, 252728},
	{"KRNV", 4, 252729},
	{"GYNS", 4, 252730},
	{"COURTLIST", 9, 252731},
	{"ARTICALS", 8, 252732},
	{"SWANY", 5, 252733},
	{"DEVENU", 6, 252734},
	{"PHERTEMINE", 10, 252735},
	{"OVERNIGHTPHENTERMINE", 20, 252736},
	{"THREATENINGLY", 13, 252737},
	{"DAVIDSONS", 9, 252738},
	{"DARKGREEN", 9, 252739},
	{"CHORNOBYL", 9, 252740},
	{"BOLYWOOD", 8, 252741},
	{"WEEZ", 4, 252742},
	{"MCCA", 4, 252743},
	{"PROFLIGACY", 10, 252744},
	{"BOOKCROSSER", 11, 252745},
	{"BAYO", 4, 252746},
	{"MLYNEDD", 7, 252747},
	{"COUNRTY", 7, 252748},
	{"BUITENLANDSE", 12, 252749},
	{"REUSEABLE", 9, 252750},
	{"MELLISA", 7, 252751},
	{"LUNKER", 6, 252752},
	{"HOOGSTRATEN", 11, 252753},
	{"ZIEKENHUIS", 10, 252754},
	{"GLIMEPIRIDE", 11, 252755},
	{"GWENDOLEN", 9, 252756},
	{"GAYDOS", 6, 252757},
	{"AQUILINA", 8, 252758},
	{"FINBAR", 6, 252759},
	{"DANIELSEN", 9, 252760},
	{"HYDROXYLASES", 12, 252761},
	{"CHOPTANK", 8, 252762},
	{"GOLSPIE", 7, 252763},
	{"ANTIPRODUCT", 11, 252764},
	{"COSENS", 6, 252765},
	{"ANCHORFREE", 10, 252766},
	{"WSEAS", 5, 252767},
	{"KURALT", 6, 252768},
	{"DECORATIE", 9, 252769},
	{"BITLBEE", 7, 252770},
	{"WELLINGS", 8, 252771},
	{"PROPENE", 7, 252772},
	{"MADEAS", 6, 252773},
	{"KEALY", 5, 252774},
	{"TERAYON", 7, 252775},
	{"GOSKI", 5, 252776},
	{"SUBTIL", 6, 252777},
	{"PRECOOKED", 9, 252778},
	{"COLLUDED", 8, 252779},
	{"BOLAM", 5, 252780},
	{"BOBCO", 5, 252781},
	{"QURAYSH", 7, 252782},
	{"MOOKS", 5, 252783},
	{"ASCUS", 5, 252784},
	{"SUBHAS", 6, 252785},
	{"MOUNCE", 6, 252786},
	{"LYMPHADENECTOMY", 15, 252787},
	{"INUM", 4, 252788},
	{"CAERFYRDDIN", 11, 252789},
	{"SPIRITISM", 9, 252790},
	{"PURTON", 6, 252791},
	{"DOPPLERS", 8, 252792},
	{"SICAL", 5, 252793},
	{"MOFFET", 6, 252794},
	{"FOLGARIA", 8, 252795},
	{"UNCONCIOUS", 10, 252796},
	{"SARANGI", 7, 252797},
	{"PAUW", 4, 252798},
	{"BEEGEES", 7, 252799},
	{"PEDRAM", 6, 252800},
	{"HIMMELFARB", 10, 252801},
	{"FRIELING", 8, 252802},
	{"FISCHINGER", 10, 252803},
	{"CTHULU", 6, 252804},
	{"CITRONELLE", 10, 252805},
	{"MEYLAN", 6, 252806},
	{"HADCO", 5, 252807},
	{"BHOJPURI", 8, 252808},
	{"MOWS", 4, 252809},
	{"HYPOTHALAMO", 11, 252810},
	{"FOSINOPRIL", 10, 252811},
	{"EURODISNEY", 10, 252812},
	{"ADVANTYS", 8, 252813},
	{"ABENOBASHI", 10, 252814},
	{"WINNERO", 7, 252815},
	{"TAILLESS", 8, 252816},
	{"WECKL", 5, 252817},
	{"VAMPIRO", 7, 252818},
	{"THNKS", 5, 252819},
	{"POSTORDER", 9, 252820},
	{"JIMM", 4, 252821},
	{"ZZOV", 4, 252822},
	{"ZANL", 4, 252823},
	{"YPUG", 4, 252824},
	{"YNKA", 4, 252825},
	{"YEAB", 4, 252826},
	{"XLIG", 4, 252827},
	{"XGAL", 4, 252828},
	{"WUMI", 4, 252829},
	{"WUIN", 4, 252830},
	{"WSJR", 4, 252831},
	{"WLUS", 4, 252832},
	{"WLQU", 4, 252833},
	{"WKWH", 4, 252834},
	{"WBYG", 4, 252835},
	{"VIZM", 4, 252836},
	{"TYKU", 4, 252837},
	{"TFDI", 4, 252838},
	{"STYY", 4, 252839},
	{"SGOY", 4, 252840},
	{"RZMA", 4, 252841},
	{"RJRI", 4, 252842},
	{"RCKN", 4, 252843},
	{"PWEV", 4, 252844},
	{"PWET", 4, 252845},
	{"PPAQ", 4, 252846},
	{"PHFE", 4, 252847},
	{"PDIL", 4, 252848},
	{"OXML", 4, 252849},
	{"OUFS", 4, 252850},
	{"OOUG", 4, 252851},
	{"ONBD", 4, 252852},
	{"NYLW", 4, 252853},
	{"NVSB", 4, 252854},
	{"NEML", 4, 252855},
	{"MLWA", 4, 252856},
	{"LVYS", 4, 252857},
	{"LUDV", 4, 252858},
	{"LIFG", 4, 252859},
	{"LEZU", 4, 252860},
	{"IUWH", 4, 252861},
	{"IUCC", 4, 252862},
	{"ICDN", 4, 252863},
	{"GYIC", 4, 252864},
	{"GRWA", 4, 252865},
	{"GMOZ", 4, 252866},
	{"GIGR", 4, 252867},
	{"GAOB", 4, 252868},
	{"FHYS", 4, 252869},
	{"FACM", 4, 252870},
	{"EWPP", 4, 252871},
	{"EWMM", 4, 252872},
	{"EVEQ", 4, 252873},
	{"EICB", 4, 252874},
	{"DPCB", 4, 252875},
	{"DJEB", 4, 252876},
	{"DIKK", 4, 252877},
	{"DBMA", 4, 252878},
	{"CHYK", 4, 252879},
	{"CEKY", 4, 252880},
	{"BURZ", 4, 252881},
	{"BTDO", 4, 252882},
	{"BPMT", 4, 252883},
	{"BGOR", 4, 252884},
	{"BEGY", 4, 252885},
	{"AZEG", 4, 252886},
	{"APYL", 4, 252887},
	{"AMCW", 4, 252888},
	{"AJOF", 4, 252889},
	{"AJDI", 4, 252890},
	{"SYNERTECH", 9, 252891},
	{"PGEM", 4, 252892},
	{"MUMMERT", 7, 252893},
	{"FERNHILL", 8, 252894},
	{"DOXEY", 5, 252895},
	{"BLAZEK", 6, 252896},
	{"ADHESIN", 7, 252897},
	{"STEVEKING", 9, 252898},
	{"PIMIENTA", 8, 252899},
	{"NOOSPHERE", 9, 252900},
	{"MESHACH", 7, 252901},
	{"TRIL", 4, 252902},
	{"MKFIFO", 6, 252903},
	{"VIDERE", 6, 252904},
	{"GESTALTUNG", 10, 252905},
	{"ALIOTO", 6, 252906},
	{"WWJ", 3, 252907},
	{"CAGLIOSTRO", 10, 252908},
	{"ARMIE", 5, 252909},
	{"WORKMANS", 8, 252910},
	{"PROVENTIA", 9, 252911},
	{"MAUGER", 6, 252912},
	{"LELLA", 5, 252913},
	{"CUDDYER", 7, 252914},
	{"CLORAZEPATE", 11, 252915},
	{"VENERIS", 7, 252916},
	{"FEDELE", 6, 252917},
	{"ERUBY", 5, 252918},
	{"DEMEANS", 7, 252919},
	{"ALLWAY", 6, 252920},
	{"NEWSPAPERMAN", 12, 252921},
	{"LEIHEN", 6, 252922},
	{"PRIORESS", 8, 252923},
	{"PARKEN", 6, 252924},
	{"LANDFIELD", 9, 252925},
	{"SUDIE", 5, 252926},
	{"NWDA", 4, 252927},
	{"COLRAIN", 7, 252928},
	{"ARTMAM", 6, 252929},
	{"STRINGFIELD", 11, 252930},
	{"BALLESTER", 9, 252931},
	{"MEROM", 5, 252932},
	{"MERIAM", 6, 252933},
	{"DOOB", 4, 252934},
	{"SEALLINE", 8, 252935},
	{"PULSATE", 7, 252936},
	{"ORDA", 4, 252937},
	{"MAINING", 7, 252938},
	{"KOZANI", 6, 252939},
	{"HOMETECH", 8, 252940},
	{"FOGSTOCK", 8, 252941},
	{"LASSUS", 6, 252942},
	{"HOFFE", 5, 252943},
	{"DRAYAGE", 7, 252944},
	{"BOYETTE", 7, 252945},
	{"REPOSITIONABLE", 14, 252946},
	{"ONONEMAP", 8, 252947},
	{"HUMPER", 6, 252948},
	{"DPST", 4, 252949},
	{"DIRECTOY", 8, 252950},
	{"QUASICRYSTALS", 13, 252951},
	{"ESPANHA", 7, 252952},
	{"MEDIABLVD", 9, 252953},
	{"QUAST", 5, 252954},
	{"PREHEATER", 9, 252955},
	{"KELLEYS", 7, 252956},
	{"IMPRINTER", 9, 252957},
	{"GOSLINGS", 8, 252958},
	{"NICKOLAY", 8, 252959},
	{"AIRTECH", 7, 252960},
	{"REVIVALISM", 10, 252961},
	{"NAVAGATION", 10, 252962},
	{"COMMVIEW", 8, 252963},
	{"RUNOFFS", 7, 252964},
	{"LAMBERTH", 8, 252965},
	{"ANGUSTIFOLIUM", 13, 252966},
	{"SPLOTCHES", 9, 252967},
	{"PHASIS", 6, 252968},
	{"KURIAN", 6, 252969},
	{"MCSC", 4, 252970},
	{"HIRUDIN", 7, 252971},
	{"REFRESHERS", 10, 252972},
	{"PERVERTING", 10, 252973},
	{"KEYANO", 6, 252974},
	{"CARBOLIC", 8, 252975},
	{"XTERMINATOR", 11, 252976},
	{"TRIPACK", 7, 252977},
	{"IMAGI", 5, 252978},
	{"COLORADANS", 10, 252979},
	{"ARIKA", 5, 252980},
	{"IDIRECT", 7, 252981},
	{"HUNGERED", 8, 252982},
	{"GASHES", 6, 252983},
	{"FLATONIA", 8, 252984},
	{"CATEGORI", 8, 252985},
	{"KLOV", 4, 252986},
	{"CEREC", 5, 252987},
	{"ARMADAS", 7, 252988},
	{"PUTARIA", 7, 252989},
	{"MOLGEN", 6, 252990},
	{"DREAMTEAM", 9, 252991},
	{"FLYPAGE", 7, 252992},
	{"SAMIT", 5, 252993},
	{"HINEY", 5, 252994},
	{"EPHINY", 6, 252995},
	{"TRAVELPOWER", 11, 252996},
	{"OFICIALES", 9, 252997},
	{"PONTELAND", 9, 252998},
	{"NOVIES", 6, 252999},
	{"CTGTC", 5, 253000},
	{"SUNNYSLOPE", 10, 253001},
	{"GOLOD", 5, 253002},
	{"PULSERA", 7, 253003},
	{"TEMTEC", 6, 253004},
	{"DISAD", 5, 253005},
	{"SOCHAUX", 7, 253006},
	{"EVRYTHING", 9, 253007},
	{"RETARTED", 8, 253008},
	{"DIDJERIDU", 9, 253009},
	{"DIAGNOSABLE", 11, 253010},
	{"BIORHYTHMIC", 11, 253011},
	{"VENTILO", 7, 253012},
	{"OMRO", 4, 253013},
	{"OBUKHOV", 7, 253014},
	{"LYSSA", 5, 253015},
	{"DUVALLE", 7, 253016},
	{"CLDS", 4, 253017},
	{"MORLOCK", 7, 253018},
	{"CRAKER", 6, 253019},
	{"PAULOWNIA", 9, 253020},
	{"ECCS", 4, 253021},
	{"DIGITALEN", 9, 253022},
	{"DEFO", 4, 253023},
	{"CANTORIAL", 9, 253024},
	{"WATCHTOWERS", 11, 253025},
	{"NWHRC", 5, 253026},
	{"GONDOLIN", 8, 253027},
	{"CHARNY", 6, 253028},
	{"SPARHAWK", 8, 253029},
	{"SARILY", 6, 253030},
	{"DUECE", 5, 253031},
	{"BLANDA", 6, 253032},
	{"ASHERONS", 8, 253033},
	{"YARMULKE", 8, 253034},
	{"SQUIDTIMES", 10, 253035},
	{"RIMONABANT", 10, 253036},
	{"VNCSERVER", 9, 253037},
	{"TRECE", 5, 253038},
	{"RUPTION", 7, 253039},
	{"PARTH", 5, 253040},
	{"PRIMERAS", 8, 253041},
	{"NAAMA", 5, 253042},
	{"LEISUREJOBS", 11, 253043},
	{"PECHO", 5, 253044},
	{"PAJAMAGRAM", 10, 253045},
	{"MEMBERNAME", 10, 253046},
	{"FEDERAZIONE", 11, 253047},
	{"HORIZONT", 8, 253048},
	{"SWANSONG", 8, 253049},
	{"MUPIROCIN", 9, 253050},
	{"DIAPAUSE", 8, 253051},
	{"WSTAT", 5, 253052},
	{"SERVICESANIMALS", 15, 253053},
	{"PISIN", 5, 253054},
	{"GNAR", 4, 253055},
	{"MISPRINTED", 10, 253056},
	{"COULTON", 7, 253057},
	{"VCOS", 4, 253058},
	{"SOGTWARE", 8, 253059},
	{"MPAGE", 5, 253060},
	{"MAZZONI", 7, 253061},
	{"EVALINE", 7, 253062},
	{"COJONES", 7, 253063},
	{"HUTONG", 6, 253064},
	{"REGELS", 6, 253065},
	{"NEELA", 5, 253066},
	{"SUBOPTION", 9, 253067},
	{"SERM", 4, 253068},
	{"PINGTEL", 7, 253069},
	{"NEWSBITS", 8, 253070},
	{"ERENKRANTZ", 10, 253071},
	{"BURA", 4, 253072},
	{"SERICEA", 7, 253073},
	{"RAYTEL", 6, 253074},
	{"PTLA", 4, 253075},
	{"LOQUELLANO", 10, 253076},
	{"DICYCLOMINE", 11, 253077},
	{"UNCACHED", 8, 253078},
	{"SHORED", 6, 253079},
	{"ISLOWER", 7, 253080},
	{"USAP", 4, 253081},
	{"DEVIDED", 7, 253082},
	{"VIRTUALIZE", 10, 253083},
	{"VARVARA", 7, 253084},
	{"SHUNGA", 6, 253085},
	{"LAPPY", 5, 253086},
	{"DECISIONING", 11, 253087},
	{"KROAH", 5, 253088},
	{"EMETH", 5, 253089},
	{"RECUPERO", 8, 253090},
	{"PROMOZIONI", 10, 253091},
	{"MATHMATICS", 10, 253092},
	{"KIRKSEY", 7, 253093},
	{"GRENDADINES", 11, 253094},
	{"SATRAN", 6, 253095},
	{"BLUFFMASTER", 11, 253096},
	{"BIOCOMPLEXITY", 13, 253097},
	{"FAWAZ", 5, 253098},
	{"PHARMACOGNOSY", 13, 253099},
	{"PAMILA", 6, 253100},
	{"CEMENTERIO", 10, 253101},
	{"BOONEN", 6, 253102},
	{"MUSKELLUNGE", 11, 253103},
	{"GULAB", 5, 253104},
	{"MULTIFREQUENCY", 14, 253105},
	{"LUCCHI", 6, 253106},
	{"JOUSE", 5, 253107},
	{"REDRAFTING", 10, 253108},
	{"OOKING", 6, 253109},
	{"VESSEY", 6, 253110},
	{"GAMGEE", 6, 253111},
	{"FUNDERBURK", 10, 253112},
	{"AZIONI", 6, 253113},
	{"JDID", 4, 253114},
	{"PAGECONTEXT", 11, 253115},
	{"NECEDAH", 7, 253116},
	{"PDATOPSOFT", 10, 253117},
	{"NAKISKA", 7, 253118},
	{"IGRAINE", 7, 253119},
	{"TRAVELSHOP", 10, 253120},
	{"BURSCOUGH", 9, 253121},
	{"USERIDS", 7, 253122},
	{"HOSTID", 6, 253123},
	{"WEINSTEINS", 10, 253124},
	{"INAME", 5, 253125},
	{"ESCRITURA", 9, 253126},
	{"WOFTWARE", 8, 253127},
	{"TAXATIONWEB", 11, 253128},
	{"OUTSIZE", 7, 253129},
	{"MUNDOS", 6, 253130},
	{"LICO", 4, 253131},
	{"SWMLAC", 6, 253132},
	{"GOLBEZ", 6, 253133},
	{"SACKMANN", 8, 253134},
	{"WPFW", 4, 253135},
	{"OTHERHAND", 9, 253136},
	{"ALLTECH", 7, 253137},
	{"XCAP", 4, 253138},
	{"ORSZAG", 6, 253139},
	{"HETER", 5, 253140},
	{"AMBNT", 5, 253141},
	{"MEDITERANEAN", 12, 253142},
	{"BOAVISTA", 8, 253143},
	{"HOROSCOP", 8, 253144},
	{"GINTHER", 7, 253145},
	{"ELFRIEDE", 8, 253146},
	{"CCIW", 4, 253147},
	{"BLUNTNESS", 9, 253148},
	{"VANTIS", 6, 253149},
	{"POLLICI", 7, 253150},
	{"FUSCIA", 6, 253151},
	{"ULCERATED", 9, 253152},
	{"ISDR", 4, 253153},
	{"OFFENE", 6, 253154},
	{"KUIN", 4, 253155},
	{"FUNZIONAMENTO", 13, 253156},
	{"TRIKALA", 7, 253157},
	{"MILLEFOLIUM", 11, 253158},
	{"IMPLAN", 6, 253159},
	{"ESCROWS", 7, 253160},
	{"MRIB", 4, 253161},
	{"INTERARCHY", 10, 253162},
	{"HADRAT", 6, 253163},
	{"GENTEX", 6, 253164},
	{"COMMUNITES", 10, 253165},
	{"DUNDY", 5, 253166},
	{"HASIL", 5, 253167},
	{"LEBE", 4, 253168},
	{"GESTICULATING", 13, 253169},
	{"ALENDAR", 7, 253170},
	{"ZREV", 4, 253171},
	{"ZIOP", 4, 253172},
	{"ZANF", 4, 253173},
	{"XORH", 4, 253174},
	{"WFIF", 4, 253175},
	{"UWST", 4, 253176},
	{"UURA", 4, 253177},
	{"UAPU", 4, 253178},
	{"TSVU", 4, 253179},
	{"TSQB", 4, 253180},
	{"TNPR", 4, 253181},
	{"TKAV", 4, 253182},
	{"TDBU", 4, 253183},
	{"STQB", 4, 253184},
	{"SROK", 4, 253185},
	{"SPEB", 4, 253186},
	{"SMJO", 4, 253187},
	{"SLRA", 4, 253188},
	{"SBUK", 4, 253189},
	{"RSCD", 4, 253190},
	{"RDMN", 4, 253191},
	{"OTVC", 4, 253192},
	{"ONYZ", 4, 253193},
	{"OGPS", 4, 253194},
	{"OFLR", 4, 253195},
	{"OBBB", 4, 253196},
	{"OAML", 4, 253197},
	{"NSVU", 4, 253198},
	{"NFMI", 4, 253199},
	{"NAJR", 4, 253200},
	{"MPYM", 4, 253201},
	{"MPEH", 4, 253202},
	{"MIGD", 4, 253203},
	{"LVDO", 4, 253204},
	{"LUKH", 4, 253205},
	{"LDDY", 4, 253206},
	{"KUCE", 4, 253207},
	{"KTAV", 4, 253208},
	{"KNAK", 4, 253209},
	{"KMDO", 4, 253210},
	{"KKUY", 4, 253211},
	{"IXTW", 4, 253212},
	{"IARK", 4, 253213},
	{"HUMR", 4, 253214},
	{"HBHU", 4, 253215},
	{"GRMI", 4, 253216},
	{"EYUB", 4, 253217},
	{"EWYM", 4, 253218},
	{"EWAQ", 4, 253219},
	{"EVUN", 4, 253220},
	{"ETZD", 4, 253221},
	{"EDKB", 4, 253222},
	{"DMLS", 4, 253223},
	{"CGYV", 4, 253224},
	{"BCOW", 4, 253225},
	{"BAOD", 4, 253226},
	{"AZRU", 4, 253227},
	{"AXYB", 4, 253228},
	{"ASMV", 4, 253229},
	{"ARWY", 4, 253230},
	{"AERB", 4, 253231},
	{"VERTICALE", 9, 253232},
	{"TAILSTOCK", 9, 253233},
	{"PURLS", 5, 253234},
	{"PLAYDATE", 8, 253235},
	{"OBVI", 4, 253236},
	{"MIRECKI", 7, 253237},
	{"BOUNZ", 5, 253238},
	{"ACULAB", 6, 253239},
	{"REPOPULATE", 10, 253240},
	{"IDIR", 4, 253241},
	{"SCHREIBSCHRIFT", 14, 253242},
	{"POURRAIENT", 10, 253243},
	{"ZOOP", 4, 253244},
	{"JYOTISH", 7, 253245},
	{"HORNBROOK", 9, 253246},
	{"ROLLOFF", 7, 253247},
	{"PUZZ", 4, 253248},
	{"INHOLTRA", 8, 253249},
	{"HETEROSIS", 9, 253250},
	{"DAPOL", 5, 253251},
	{"YASU", 4, 253252},
	{"RGEN", 4, 253253},
	{"DEPOY", 5, 253254},
	{"BAQUBA", 6, 253255},
	{"ZIEMAN", 6, 253256},
	{"ZARZUELA", 8, 253257},
	{"TASKMANAGER", 11, 253258},
	{"RAURIS", 6, 253259},
	{"CINQUAIN", 8, 253260},
	{"PELANGI", 7, 253261},
	{"DZIEDZIC", 8, 253262},
	{"BOZARTH", 7, 253263},
	{"ASAHEL", 6, 253264},
	{"WIMEN", 5, 253265},
	{"SUNDSTRAND", 10, 253266},
	{"RAMAMURTHY", 10, 253267},
	{"FNUM", 4, 253268},
	{"POTSHOTS", 8, 253269},
	{"ORLEY", 5, 253270},
	{"NEUTON", 6, 253271},
	{"LESOVO", 6, 253272},
	{"CHALLONER", 9, 253273},
	{"BOULEVARDE", 10, 253274},
	{"MILLETTE", 8, 253275},
	{"DVORSKY", 7, 253276},
	{"DONIE", 5, 253277},
	{"GORLESTON", 9, 253278},
	{"DATU", 4, 253279},
	{"DYLUNIO", 7, 253280},
	{"CASAMAGNA", 9, 253281},
	{"AIRSPAN", 7, 253282},
	{"VITAMINLIFE", 11, 253283},
	{"SOKOTO", 6, 253284},
	{"ELYON", 5, 253285},
	{"ATHWART", 7, 253286},
	{"THROUGOUT", 9, 253287},
	{"JMPR", 4, 253288},
	{"JANAE", 5, 253289},
	{"DOUGLASII", 9, 253290},
	{"CUSTOMINK", 9, 253291},
	{"VOICEBOX", 8, 253292},
	{"RONMENTS", 8, 253293},
	{"MAGZINES", 8, 253294},
	{"RELUG", 5, 253295},
	{"FLUFFED", 7, 253296},
	{"CUDDAPAH", 8, 253297},
	{"REDUNDANCYTEST", 14, 253298},
	{"HERMANA", 7, 253299},
	{"MAHARASTRA", 10, 253300},
	{"LITERALISM", 10, 253301},
	{"GLK", 3, 253302},
	{"BRUGGEN", 7, 253303},
	{"BALCATTA", 8, 253304},
	{"TIMBA", 5, 253305},
	{"HOOLA", 5, 253306},
	{"CHARENTON", 9, 253307},
	{"WESTLANDS", 9, 253308},
	{"FELLMAN", 7, 253309},
	{"DECLAWING", 9, 253310},
	{"YALOBUSHA", 9, 253311},
	{"MCCUTCHAN", 9, 253312},
	{"NAVICULAR", 9, 253313},
	{"LITTLEPORT", 10, 253314},
	{"CALIFORNA", 9, 253315},
	{"GUMDROP", 7, 253316},
	{"XDATA", 5, 253317},
	{"WBP", 3, 253318},
	{"SELECTRIC", 9, 253319},
	{"KENSHI", 6, 253320},
	{"JAIMEE", 6, 253321},
	{"FALLIS", 6, 253322},
	{"ACESULFAME", 10, 253323},
	{"WINDBREAKERS", 12, 253324},
	{"PIURA", 5, 253325},
	{"MOHUN", 5, 253326},
	{"JSTV", 4, 253327},
	{"ISOPTERA", 8, 253328},
	{"GODHOOD", 7, 253329},
	{"ZMUD", 4, 253330},
	{"YAHOOOO", 7, 253331},
	{"STAALPLAAT", 10, 253332},
	{"SHAMBLING", 9, 253333},
	{"WIHTE", 5, 253334},
	{"CINEMAPLAY", 10, 253335},
	{"RUZYNE", 6, 253336},
	{"KANIA", 5, 253337},
	{"COMPUTERWARE", 12, 253338},
	{"SANDBOARDING", 12, 253339},
	{"KITEBOARD", 9, 253340},
	{"KAMALI", 6, 253341},
	{"HANNEMANN", 9, 253342},
	{"DEPOLYMERIZATION", 16, 253343},
	{"BUNZL", 5, 253344},
	{"ALGOOD", 6, 253345},
	{"AFYON", 5, 253346},
	{"ADDICKS", 7, 253347},
	{"TUNNY", 5, 253348},
	{"ROULET", 6, 253349},
	{"RABAN", 5, 253350},
	{"EMBERLEY", 8, 253351},
	{"DQD", 3, 253352},
	{"DLLNAME", 7, 253353},
	{"THEMISTOCLES", 12, 253354},
	{"PREASSEMBLED", 12, 253355},
	{"JUNJI", 5, 253356},
	{"BAQMOYS", 7, 253357},
	{"ALAPAHA", 7, 253358},
	{"TAGLIAFERRI", 11, 253359},
	{"NORBIE", 6, 253360},
	{"NETSEMINARS", 11, 253361},
	{"MACROPHYTE", 10, 253362},
	{"MUSICHE", 7, 253363},
	{"FISCUS", 6, 253364},
	{"CHIFF", 5, 253365},
	{"DEVRAIENT", 9, 253366},
	{"WHITETHORN", 10, 253367},
	{"VTKIMAGEDATA", 12, 253368},
	{"MICROTOME", 9, 253369},
	{"ASTROPOP", 8, 253370},
	{"TENDEREST", 9, 253371},
	{"ACEVES", 6, 253372},
	{"EOTIC", 5, 253373},
	{"BZP", 3, 253374},
	{"OCEANSIZE", 9, 253375},
	{"METATRADER", 10, 253376},
	{"GROMMIT", 7, 253377},
	{"ECCC", 4, 253378},
	{"BIOSCOOP", 8, 253379},
	{"WEBHOSTER", 9, 253380},
	{"NEWINDPRESS", 11, 253381},
	{"MYLIFE", 6, 253382},
	{"ENTREMONT", 9, 253383},
	{"DUBUS", 5, 253384},
	{"VOCALIZING", 10, 253385},
	{"SOFTQARE", 8, 253386},
	{"PSMOUSE", 7, 253387},
	{"PHIPPSBURG", 10, 253388},
	{"KOMMENTIEREN", 12, 253389},
	{"CANSIM", 6, 253390},
	{"NATIONALISMS", 12, 253391},
	{"FLECO", 5, 253392},
	{"PITTARD", 7, 253393},
	{"BELLBIRD", 8, 253394},
	{"ATASCOCITA", 10, 253395},
	{"ZOMER", 5, 253396},
	{"ORDAINS", 7, 253397},
	{"OLDTIME", 7, 253398},
	{"MYELODYSPLASIA", 14, 253399},
	{"MAGNAN", 6, 253400},
	{"JAUN", 4, 253401},
	{"AUMONT", 6, 253402},
	{"SCHICKEL", 8, 253403},
	{"METZE", 5, 253404},
	{"FOLTER", 6, 253405},
	{"EPOR", 4, 253406},
	{"CHAMPNEYS", 9, 253407},
	{"MOBITOPIA", 9, 253408},
	{"XMLPARSERCTXTPTR", 16, 253409},
	{"SANDIN", 6, 253410},
	{"PLUGGER", 7, 253411},
	{"MATCHPOINTS", 11, 253412},
	{"CONGURATION", 11, 253413},
	{"ZEGERS", 6, 253414},
	{"POCKETLINUX", 11, 253415},
	{"PERMAX", 6, 253416},
	{"BSAD", 4, 253417},
	{"YABA", 4, 253418},
	{"PREDEVELOPMENT", 14, 253419},
	{"BRANCUSI", 8, 253420},
	{"CHOIRBOYS", 9, 253421},
	{"TRANSITED", 9, 253422},
	{"TORAND", 6, 253423},
	{"RABIH", 5, 253424},
	{"MARINCO", 7, 253425},
	{"KEMA", 4, 253426},
	{"INSTAN", 6, 253427},
	{"SKEWERING", 9, 253428},
	{"GIGAWATT", 8, 253429},
	{"ENCHANTICA", 10, 253430},
	{"NOVELLUS", 8, 253431},
	{"COLUMBARIUM", 11, 253432},
	{"CDFOPR", 6, 253433},
	{"VENTIONS", 8, 253434},
	{"STOLI", 5, 253435},
	{"PIPETTORS", 9, 253436},
	{"ARBOLEDA", 8, 253437},
	{"WOHLER", 6, 253438},
	{"KYOWA", 5, 253439},
	{"CALBLOG", 7, 253440},
	{"TANIMOTO", 8, 253441},
	{"PEPPERING", 9, 253442},
	{"LOVERING", 8, 253443},
	{"JAND", 4, 253444},
	{"JAISWAL", 7, 253445},
	{"HILIGHT", 7, 253446},
	{"PHPBBHACKS", 10, 253447},
	{"UNBUNDLE", 8, 253448},
	{"TWINSET", 7, 253449},
	{"GRAZIERS", 8, 253450},
	{"KHARIF", 6, 253451},
	{"JIMSONWEED", 10, 253452},
	{"IAFC", 4, 253453},
	{"EASYJOURNAL", 11, 253454},
	{"TYWYDD", 6, 253455},
	{"SKYMALL", 7, 253456},
	{"MALANDRINO", 10, 253457},
	{"EROTOC", 6, 253458},
	{"DACARBAZINE", 11, 253459},
	{"SETDESCRIPTION", 14, 253460},
	{"DWEEBS", 6, 253461},
	{"PICSS", 5, 253462},
	{"MYCOTIC", 7, 253463},
	{"LAVAN", 5, 253464},
	{"NETCONFIG", 9, 253465},
	{"KYMA", 4, 253466},
	{"DOMPERIDONE", 11, 253467},
	{"ROSSINGTON", 10, 253468},
	{"MMPR", 4, 253469},
	{"MARIAGES", 8, 253470},
	{"GOCR", 4, 253471},
	{"ARAFURA", 7, 253472},
	{"KROONS", 6, 253473},
	{"ENGAGMENT", 9, 253474},
	{"CLOCKHOUSE", 10, 253475},
	{"BIEDT", 5, 253476},
	{"AFRICAPUNDIT", 12, 253477},
	{"ZUPALO", 6, 253478},
	{"SCHUETT", 7, 253479},
	{"WOMEM", 5, 253480},
	{"NANNETTE", 8, 253481},
	{"MERITLESS", 9, 253482},
	{"CUTTEN", 6, 253483},
	{"HONEYWOOD", 9, 253484},
	{"CHEARLEADERS", 12, 253485},
	{"BUNDI", 5, 253486},
	{"STREAMCAST", 10, 253487},
	{"PLAYLISTMAG", 11, 253488},
	{"DEARLOVE", 8, 253489},
	{"PLINKLET", 8, 253490},
	{"PENMAENMAWR", 11, 253491},
	{"AVRERAGE", 8, 253492},
	{"ACQUAINTS", 9, 253493},
	{"PHYTOESTROGEN", 13, 253494},
	{"KUNERT", 6, 253495},
	{"BORONIC", 7, 253496},
	{"ZENDO", 5, 253497},
	{"YFZ", 3, 253498},
	{"MEGACITIES", 10, 253499},
	{"MAZZOCCHI", 9, 253500},
	{"COLDTONNAGE", 11, 253501},
	{"MACCULLOCH", 10, 253502},
	{"EWROP", 5, 253503},
	{"EDGEWORN", 8, 253504},
	{"WEIDEMANN", 9, 253505},
	{"TRANSVERSALITY", 14, 253506},
	{"SEJANUS", 7, 253507},
	{"MINWAX", 6, 253508},
	{"MEDICADE", 8, 253509},
	{"GAMESBLOG", 9, 253510},
	{"MACGIL", 6, 253511},
	{"AJRAM", 5, 253512},
	{"ABMAHNUNGEN", 11, 253513},
	{"TAPANI", 6, 253514},
	{"KQUEUE", 6, 253515},
	{"SCOOBA", 6, 253516},
	{"PURPA", 5, 253517},
	{"JANTAR", 6, 253518},
	{"INGROSSO", 8, 253519},
	{"SCHECKTER", 9, 253520},
	{"ISTORE", 6, 253521},
	{"CSPC", 4, 253522},
	{"BACKOUTPATCH", 12, 253523},
	{"INPAINT", 7, 253524},
	{"BRACHMAN", 8, 253525},
	{"BLAMEWORTHY", 11, 253526},
	{"ZZYP", 4, 253527},
	{"ZBET", 4, 253528},
	{"YLPE", 4, 253529},
	{"YJED", 4, 253530},
	{"YCTO", 4, 253531},
	{"XUSR", 4, 253532},
	{"XSEP", 4, 253533},
	{"XDOM", 4, 253534},
	{"XAMC", 4, 253535},
	{"WESG", 4, 253536},
	{"WAIW", 4, 253537},
	{"VOUG", 4, 253538},
	{"VECN", 4, 253539},
	{"VAMB", 4, 253540},
	{"UTKL", 4, 253541},
	{"UOMH", 4, 253542},
	{"UBYF", 4, 253543},
	{"UBTN", 4, 253544},
	{"UAUS", 4, 253545},
	{"TUDL", 4, 253546},
	{"TKHU", 4, 253547},
	{"SPEV", 4, 253548},
	{"SMCU", 4, 253549},
	{"SLLE", 4, 253550},
	{"SKMD", 4, 253551},
	{"RLIW", 4, 253552},
	{"RDMB", 4, 253553},
	{"RBPI", 4, 253554},
	{"QUND", 4, 253555},
	{"QMJH", 4, 253556},
	{"PUNZ", 4, 253557},
	{"POCI", 4, 253558},
	{"PAPT", 4, 253559},
	{"PABY", 4, 253560},
	{"PAAG", 4, 253561},
	{"OXXA", 4, 253562},
	{"ORRN", 4, 253563},
	{"ONQB", 4, 253564},
	{"OLPM", 4, 253565},
	{"OBBH", 4, 253566},
	{"NTCM", 4, 253567},
	{"NSRW", 4, 253568},
	{"NLTC", 4, 253569},
	{"NEPG", 4, 253570},
	{"NDNL", 4, 253571},
	{"NAUZ", 4, 253572},
	{"MIOK", 4, 253573},
	{"MDUD", 4, 253574},
	{"LUKW", 4, 253575},
	{"LATQ", 4, 253576},
	{"KWEO", 4, 253577},
	{"IWIW", 4, 253578},
	{"INZC", 4, 253579},
	{"IKSR", 4, 253580},
	{"IDWY", 4, 253581},
	{"FFIH", 4, 253582},
	{"FCOY", 4, 253583},
	{"FAMD", 4, 253584},
	{"EVOP", 4, 253585},
	{"EUOR", 4, 253586},
	{"EPEZ", 4, 253587},
	{"EFJI", 4, 253588},
	{"EDJB", 4, 253589},
	{"DRFL", 4, 253590},
	{"DOKW", 4, 253591},
	{"DNCI", 4, 253592},
	{"DKEO", 4, 253593},
	{"DIPC", 4, 253594},
	{"DGMO", 4, 253595},
	{"DDYY", 4, 253596},
	{"DDAX", 4, 253597},
	{"CGUE", 4, 253598},
	{"BRUF", 4, 253599},
	{"BEEY", 4, 253600},
	{"BDOR", 4, 253601},
	{"AVUJ", 4, 253602},
	{"AUKU", 4, 253603},
	{"ATVB", 4, 253604},
	{"ARBM", 4, 253605},
	{"AMLB", 4, 253606},
	{"AGYS", 4, 253607},
	{"SUPERMEMO", 9, 253608},
	{"BLDRS", 5, 253609},
	{"BENZIMIDAZOLE", 13, 253610},
	{"ARCHIPEL", 8, 253611},
	{"HAMPI", 5, 253612},
	{"FASTBRK", 7, 253613},
	{"BNCHPTS", 7, 253614},
	{"BERMAGUI", 8, 253615},
	{"AKKA", 4, 253616},
	{"TARGE", 5, 253617},
	{"MAUKA", 5, 253618},
	{"MANISA", 6, 253619},
	{"ANNEMASSE", 9, 253620},
	{"MINOCCURS", 9, 253621},
	{"KEYCARD", 7, 253622},
	{"CORNROWS", 8, 253623},
	{"AZINGER", 7, 253624},
	{"ELLINWOOD", 9, 253625},
	{"PROPOUND", 8, 253626},
	{"GTKPOD", 6, 253627},
	{"VIHARA", 6, 253628},
	{"SPORADES", 8, 253629},
	{"PIOMBO", 6, 253630},
	{"NORTHBOURNE", 11, 253631},
	{"FREENEY", 7, 253632},
	{"CONTEMPORAINE", 13, 253633},
	{"MEHLER", 6, 253634},
	{"EDCO", 4, 253635},
	{"CRATERED", 8, 253636},
	{"ARBOVIRUS", 9, 253637},
	{"ABCDEFGHIJKL", 12, 253638},
	{"SUNRUNNER", 9, 253639},
	{"MARLES", 6, 253640},
	{"GYLES", 5, 253641},
	{"BLUEOREGON", 10, 253642},
	{"RAVENSTHORPE", 12, 253643},
	{"PIMECROLIMUS", 12, 253644},
	{"CARLINE", 7, 253645},
	{"BIOGS", 5, 253646},
	{"KLEMMER", 7, 253647},
	{"IMMODERATE", 10, 253648},
	{"ALUMNE", 6, 253649},
	{"XCAL", 4, 253650},
	{"CLICKWALK", 9, 253651},
	{"AIRF", 4, 253652},
	{"GBARR", 5, 253653},
	{"ATOMOXETINE", 11, 253654},
	{"STIDY", 5, 253655},
	{"OBJECTIFY", 9, 253656},
	{"ACOLL", 5, 253657},
	{"MITY", 4, 253658},
	{"ACUTENESS", 9, 253659},
	{"SECARA", 6, 253660},
	{"REASSESSMENTS", 13, 253661},
	{"MITHUN", 6, 253662},
	{"FITMENTS", 8, 253663},
	{"LETRASET", 8, 253664},
	{"ROESELARE", 9, 253665},
	{"OBOK", 4, 253666},
	{"HEWED", 5, 253667},
	{"PINNIPEDS", 9, 253668},
	{"COFS", 4, 253669},
	{"CARICATURISTS", 13, 253670},
	{"WEBLIOGRAPHY", 12, 253671},
	{"SAMODE", 6, 253672},
	{"PAMMY", 5, 253673},
	{"AIUK", 4, 253674},
	{"KAMCHIA", 7, 253675},
	{"CSEL", 4, 253676},
	{"SOCIETAS", 8, 253677},
	{"PARKLANE", 8, 253678},
	{"RAVENSWORTH", 11, 253679},
	{"GWENN", 5, 253680},
	{"DULLIAU", 7, 253681},
	{"MOSC", 4, 253682},
	{"COMPLAINER", 10, 253683},
	{"PEOPLING", 8, 253684},
	{"LYNDS", 5, 253685},
	{"KINDNESSES", 10, 253686},
	{"BARMES", 6, 253687},
	{"MENING", 6, 253688},
	{"EVENTLISTENER", 13, 253689},
	{"BLYNYDDOEDD", 11, 253690},
	{"JOFA", 4, 253691},
	{"FLUNKY", 6, 253692},
	{"DOUZE", 5, 253693},
	{"UNACCOUNTABLY", 13, 253694},
	{"BUSKERUD", 8, 253695},
	{"BATTLEMATS", 10, 253696},
	{"APICES", 6, 253697},
	{"SIMCINEMA", 9, 253698},
	{"UNWAITH", 7, 253699},
	{"MELKITE", 7, 253700},
	{"DRGEO", 5, 253701},
	{"SPARKPEOPLE", 11, 253702},
	{"RINGA", 5, 253703},
	{"HONDEN", 6, 253704},
	{"GLENRIDGE", 9, 253705},
	{"CAREERZONE", 10, 253706},
	{"BOUCK", 5, 253707},
	{"FINDEX", 6, 253708},
	{"CASTIGLIONI", 11, 253709},
	{"ZOOMBINIS", 9, 253710},
	{"SERVEEZ", 7, 253711},
	{"MANGOTSFIELD", 12, 253712},
	{"LIPOLYTICA", 10, 253713},
	{"KENSETT", 7, 253714},
	{"ANTIGONUS", 9, 253715},
	{"RHOMBOID", 8, 253716},
	{"JAYARAM", 7, 253717},
	{"SZYMANOWSKI", 11, 253718},
	{"LOVELLS", 7, 253719},
	{"FILOMENA", 8, 253720},
	{"EARLSFIELD", 10, 253721},
	{"DENTATA", 7, 253722},
	{"PLANKINTON", 10, 253723},
	{"HAITINK", 7, 253724},
	{"DEVELOPMENTOR", 13, 253725},
	{"THACH", 5, 253726},
	{"NEUTRALISING", 12, 253727},
	{"KETRON", 6, 253728},
	{"FLEETINGLY", 10, 253729},
	{"BARBLESS", 8, 253730},
	{"TYPA", 4, 253731},
	{"ROSSELLI", 8, 253732},
	{"QGIS", 4, 253733},
	{"PEPINO", 6, 253734},
	{"SELENIDE", 8, 253735},
	{"MEGAKARYOCYTES", 14, 253736},
	{"LALR", 4, 253737},
	{"MAKUHARI", 8, 253738},
	{"HOUSS", 5, 253739},
	{"PLAINEST", 8, 253740},
	{"MATHEMATICAE", 12, 253741},
	{"LIGHTSABRE", 10, 253742},
	{"TRETYAKOV", 9, 253743},
	{"SPARKLIFE", 9, 253744},
	{"KUDA", 4, 253745},
	{"TIDSSKR", 7, 253746},
	{"KINNUNEN", 8, 253747},
	{"DACO", 4, 253748},
	{"APPROCHES", 9, 253749},
	{"TAUREAN", 7, 253750},
	{"REDRESSAL", 9, 253751},
	{"PEQUENA", 7, 253752},
	{"GERICKE", 7, 253753},
	{"MATRIXONE", 9, 253754},
	{"HERTSDIRECT", 11, 253755},
	{"CHOISY", 6, 253756},
	{"ASYST", 5, 253757},
	{"ARROWINDUSTRY", 13, 253758},
	{"XINHA", 5, 253759},
	{"KITTLER", 7, 253760},
	{"STIPES", 6, 253761},
	{"ROSENKRANTZ", 11, 253762},
	{"REMOT", 5, 253763},
	{"DETALLE", 7, 253764},
	{"BRYDGES", 7, 253765},
	{"OIKAWA", 6, 253766},
	{"BRANDERS", 8, 253767},
	{"REQUESTID", 9, 253768},
	{"BEMBIDION", 9, 253769},
	{"OBSTACK", 7, 253770},
	{"SELVIN", 6, 253771},
	{"FRIULIAN", 8, 253772},
	{"CHAUSSON", 8, 253773},
	{"ALCYONE", 7, 253774},
	{"DICOUNT", 7, 253775},
	{"BABYWORLD", 9, 253776},
	{"GIBBER", 6, 253777},
	{"FRCSC", 5, 253778},
	{"BLACKBELTSALES", 14, 253779},
	{"VETYVER", 7, 253780},
	{"TRAVELTIME", 10, 253781},
	{"SCHEFF", 6, 253782},
	{"KONOPKA", 7, 253783},
	{"SYSDIR", 6, 253784},
	{"MANGELSDORF", 11, 253785},
	{"FATBACK", 7, 253786},
	{"INTERMAPPER", 11, 253787},
	{"ALDERAAN", 8, 253788},
	{"SNUBBING", 8, 253789},
	{"LQJ", 3, 253790},
	{"BOIRE", 5, 253791},
	{"GWEITHWYR", 9, 253792},
	{"EMPTYWELL", 9, 253793},
	{"COMPSOURCE", 10, 253794},
	{"CHERRYBROOK", 11, 253795},
	{"STANSELL", 8, 253796},
	{"ATHLONROB", 9, 253797},
	{"ARTICLED", 8, 253798},
	{"ORLANDINI", 9, 253799},
	{"FLATMANIA", 9, 253800},
	{"ELKIND", 6, 253801},
	{"BALLOCH", 7, 253802},
	{"ATOVAQUONE", 10, 253803},
	{"NOWEBM", 6, 253804},
	{"FUSKER", 6, 253805},
	{"RESISTOL", 8, 253806},
	{"CHECKSIG", 8, 253807},
	{"PESAR", 5, 253808},
	{"ABAGNALE", 8, 253809},
	{"YUUKI", 5, 253810},
	{"ADHAN", 5, 253811},
	{"GARBS", 5, 253812},
	{"CABILDO", 7, 253813},
	{"SASIALIT", 8, 253814},
	{"HIELO", 5, 253815},
	{"GAVEST", 6, 253816},
	{"EXOBIOLOGY", 10, 253817},
	{"DJORDJEVIC", 10, 253818},
	{"GOLFBALLS", 9, 253819},
	{"COCKERS", 7, 253820},
	{"TAMMIN", 6, 253821},
	{"STOJANOVIC", 10, 253822},
	{"DEVORAH", 7, 253823},
	{"OLADO", 5, 253824},
	{"YUDIT", 5, 253825},
	{"HENRICI", 7, 253826},
	{"CLARANET", 8, 253827},
	{"MYWIRELESS", 10, 253828},
	{"FYEO", 4, 253829},
	{"TURUN", 5, 253830},
	{"BURSTON", 7, 253831},
	{"YLM", 3, 253832},
	{"STREAMZAP", 9, 253833},
	{"ORDINI", 6, 253834},
	{"KAMBOURIS", 9, 253835},
	{"OMEGAMON", 8, 253836},
	{"MULLINAX", 8, 253837},
	{"GOTOVINA", 8, 253838},
	{"ROADMAPPING", 11, 253839},
	{"DATENSCHUTZHINWEIS", 18, 253840},
	{"INBEV", 5, 253841},
	{"EDUCOM", 6, 253842},
	{"SUBTLEST", 8, 253843},
	{"EVERCHANGING", 12, 253844},
	{"DEHRA", 5, 253845},
	{"WEBCHALKBOARD", 13, 253846},
	{"SNOWCAPPED", 10, 253847},
	{"HALDEX", 6, 253848},
	{"GETCONTENTPANE", 14, 253849},
	{"FERRUGINEA", 10, 253850},
	{"MARIENTHAL", 10, 253851},
	{"BIOSHIELD", 9, 253852},
	{"GETHOSTNAME", 11, 253853},
	{"CONCETTA", 8, 253854},
	{"ZOFTWARE", 8, 253855},
	{"VCAST", 5, 253856},
	{"QUACKERS", 8, 253857},
	{"MORECOMPUTERS", 13, 253858},
	{"VIKE", 4, 253859},
	{"JURISPRUDENTIAL", 15, 253860},
	{"DSOUND", 6, 253861},
	{"DANDOH", 6, 253862},
	{"RADIOSEE", 8, 253863},
	{"RACINES", 7, 253864},
	{"PARTAKEN", 8, 253865},
	{"MCKINZIE", 8, 253866},
	{"GAMEPLAYING", 11, 253867},
	{"EKSTRA", 6, 253868},
	{"SANELY", 6, 253869},
	{"GRUFFLY", 7, 253870},
	{"ERRY", 4, 253871},
	{"ZZWE", 4, 253872},
	{"ZKIW", 4, 253873},
	{"ZIKE", 4, 253874},
	{"ZHUZ", 4, 253875},
	{"ZHEW", 4, 253876},
	{"ZHAM", 4, 253877},
	{"YHYM", 4, 253878},
	{"YFAX", 4, 253879},
	{"YCYP", 4, 253880},
	{"YAEM", 4, 253881},
	{"WUSB", 4, 253882},
	{"WOWL", 4, 253883},
	{"WKAL", 4, 253884},
	{"WGIA", 4, 253885},
	{"WEEF", 4, 253886},
	{"VUKR", 4, 253887},
	{"VOBU", 4, 253888},
	{"VHEW", 4, 253889},
	{"UXFI", 4, 253890},
	{"UOCC", 4, 253891},
	{"UGJO", 4, 253892},
	{"UFFV", 4, 253893},
	{"TUTF", 4, 253894},
	{"TIVL", 4, 253895},
	{"THPB", 4, 253896},
	{"TFCO", 4, 253897},
	{"SYOL", 4, 253898},
	{"STGP", 4, 253899},
	{"SGTW", 4, 253900},
	{"SEKL", 4, 253901},
	{"RGII", 4, 253902},
	{"REUW", 4, 253903},
	{"PTVO", 4, 253904},
	{"PEOC", 4, 253905},
	{"OUGN", 4, 253906},
	{"OUEF", 4, 253907},
	{"OMMN", 4, 253908},
	{"OCWO", 4, 253909},
	{"NNQU", 4, 253910},
	{"LXBO", 4, 253911},
	{"KVOC", 4, 253912},
	{"KUDZ", 4, 253913},
	{"KMSF", 4, 253914},
	{"KKUL", 4, 253915},
	{"JYLL", 4, 253916},
	{"JKAA", 4, 253917},
	{"IZSP", 4, 253918},
	{"IGOK", 4, 253919},
	{"IBUB", 4, 253920},
	{"HYGL", 4, 253921},
	{"HNFU", 4, 253922},
	{"GMSN", 4, 253923},
	{"GKAW", 4, 253924},
	{"FYWO", 4, 253925},
	{"FRUE", 4, 253926},
	{"FLSF", 4, 253927},
	{"FEKR", 4, 253928},
	{"EABW", 4, 253929},
	{"DTVD", 4, 253930},
	{"DNDB", 4, 253931},
	{"DDCC", 4, 253932},
	{"DBOV", 4, 253933},
	{"CTVB", 4, 253934},
	{"BYPY", 4, 253935},
	{"BYHP", 4, 253936},
	{"BVEN", 4, 253937},
	{"BOEP", 4, 253938},
	{"BIDY", 4, 253939},
	{"BEKH", 4, 253940},
	{"ARRJ", 4, 253941},
	{"AQPO", 4, 253942},
	{"AQDU", 4, 253943},
	{"APJI", 4, 253944},
	{"AOLW", 4, 253945},
	{"ALBP", 4, 253946},
	{"AGUJ", 4, 253947},
	{"ABAQ", 4, 253948},
	{"AAKU", 4, 253949},
	{"SOUTHLANDS", 10, 253950},
	{"TYRUS", 5, 253951},
	{"TINKERER", 8, 253952},
	{"MOLAS", 5, 253953},
	{"GERRINGONG", 10, 253954},
	{"PERLFUNC", 8, 253955},
	{"REBETOL", 7, 253956},
	{"SUDOERS", 7, 253957},
	{"FODR", 4, 253958},
	{"WONTFIX", 7, 253959},
	{"SANADA", 6, 253960},
	{"RAFFO", 5, 253961},
	{"VALLECITO", 9, 253962},
	{"MARKAL", 6, 253963},
	{"TIMESYS", 7, 253964},
	{"SOPPY", 5, 253965},
	{"MOGLIANO", 8, 253966},
	{"EYER", 4, 253967},
	{"CASESTUDIES", 11, 253968},
	{"SCHUNK", 6, 253969},
	{"KUBIN", 5, 253970},
	{"DIVISADERO", 10, 253971},
	{"AHORRA", 6, 253972},
	{"GAFFS", 5, 253973},
	{"CSSP", 4, 253974},
	{"VLISSINGEN", 10, 253975},
	{"ONLINECASINOS", 13, 253976},
	{"NETELER", 7, 253977},
	{"LECOMTE", 7, 253978},
	{"GETNEXT", 7, 253979},
	{"CFITSIO", 7, 253980},
	{"WAIRAU", 6, 253981},
	{"GUIDEPOST", 9, 253982},
	{"STRAUMANN", 9, 253983},
	{"KOVE", 4, 253984},
	{"GALBA", 5, 253985},
	{"NICOTROL", 8, 253986},
	{"HOLZSCHLAG", 10, 253987},
	{"LORONG", 6, 253988},
	{"WOZN", 4, 253989},
	{"SIXTYNINE", 9, 253990},
	{"DAIM", 4, 253991},
	{"ALGOA", 5, 253992},
	{"ACCOMPT", 7, 253993},
	{"THIEMO", 6, 253994},
	{"WASON", 5, 253995},
	{"PANUI", 5, 253996},
	{"NANKIN", 6, 253997},
	{"MARGARETVILLE", 13, 253998},
	{"CHEESEMAKING", 12, 253999},
	{"CAPACITATED", 11, 254000},
	{"ESTELLINE", 9, 254001},
	{"WOOLLOONGABBA", 13, 254002},
	{"MEDCENTER", 9, 254003},
	{"ANEURISM", 8, 254004},
	{"MOURVEDRE", 9, 254005},
	{"KERRISON", 8, 254006},
	{"CAMEROONS", 9, 254007},
	{"PERMISSIBILITY", 14, 254008},
	{"INFARCTIONS", 11, 254009},
	{"DULU", 4, 254010},
	{"PASSATO", 7, 254011},
	{"OSTINATO", 8, 254012},
	{"MINHAS", 6, 254013},
	{"SNOWFIELDS", 10, 254014},
	{"RAUMA", 5, 254015},
	{"RAPIDAN", 7, 254016},
	{"HANDL", 5, 254017},
	{"FLICKA", 6, 254018},
	{"STUFE", 5, 254019},
	{"INTELIGENTE", 11, 254020},
	{"DURAFLEX", 8, 254021},
	{"LESLEE", 6, 254022},
	{"GSPOTS", 6, 254023},
	{"CONDOTTI", 8, 254024},
	{"AARONSWATCHES", 13, 254025},
	{"RESHUFFLED", 10, 254026},
	{"XIAODONG", 8, 254027},
	{"STRUCTURATION", 13, 254028},
	{"SPUNKER", 7, 254029},
	{"GARET", 5, 254030},
	{"DILA", 4, 254031},
	{"POWERGLIDE", 10, 254032},
	{"FLOHR", 5, 254033},
	{"CUBAVERA", 8, 254034},
	{"MAYLAND", 7, 254035},
	{"LIPOSCULPTURE", 13, 254036},
	{"LANAO", 5, 254037},
	{"ENKEPHALINS", 11, 254038},
	{"BUZZELL", 7, 254039},
	{"UTIMCO", 6, 254040},
	{"STOKLEY", 7, 254041},
	{"MYCO", 4, 254042},
	{"MASKA", 5, 254043},
	{"HENSELAE", 8, 254044},
	{"BESTANDEN", 9, 254045},
	{"SOFTWAEE", 8, 254046},
	{"RISQ", 4, 254047},
	{"TECHFINDER", 10, 254048},
	{"JANGAN", 6, 254049},
	{"GORITHMS", 8, 254050},
	{"FURIOSUS", 8, 254051},
	{"DWV", 3, 254052},
	{"BIOASSESSMENT", 13, 254053},
	{"WELKIN", 6, 254054},
	{"SIGNFICANT", 10, 254055},
	{"LUTCHER", 7, 254056},
	{"LIEBAU", 6, 254057},
	{"DEALY", 5, 254058},
	{"SOOTHERS", 8, 254059},
	{"HBENT", 5, 254060},
	{"EMILEE", 6, 254061},
	{"IONISED", 7, 254062},
	{"JAZZFEST", 8, 254063},
	{"GOOGLEMAP", 9, 254064},
	{"BERCEUSE", 8, 254065},
	{"WARSZ", 5, 254066},
	{"STRUIK", 6, 254067},
	{"MARJANOVIC", 10, 254068},
	{"SUPOSE", 6, 254069},
	{"SUPERHITS", 9, 254070},
	{"SPUNDAE", 7, 254071},
	{"RURALE", 6, 254072},
	{"NBAR", 4, 254073},
	{"MARLE", 5, 254074},
	{"BERTINO", 7, 254075},
	{"ARBETE", 6, 254076},
	{"TEHILLIM", 8, 254077},
	{"SPORTSPYDER", 11, 254078},
	{"SHEIKHS", 7, 254079},
	{"PRAIAS", 6, 254080},
	{"MALRAUX", 7, 254081},
	{"FRITID", 6, 254082},
	{"COONOOR", 7, 254083},
	{"UPSETTERS", 9, 254084},
	{"QCUTEX", 6, 254085},
	{"MATRILINEAL", 11, 254086},
	{"HANIMEX", 7, 254087},
	{"GUEDES", 6, 254088},
	{"COALTON", 7, 254089},
	{"TRAVELHERO", 10, 254090},
	{"MUNICIPALE", 10, 254091},
	{"ELVERSON", 8, 254092},
	{"POWEFUL", 7, 254093},
	{"KAZANLAK", 8, 254094},
	{"KEYUP", 5, 254095},
	{"ORTHODOXIES", 11, 254096},
	{"HACETTEPE", 9, 254097},
	{"PHOTOSTAT", 9, 254098},
	{"BIOVAR", 6, 254099},
	{"ARROWOPEN", 9, 254100},
	{"AMVESCAP", 8, 254101},
	{"UNTRADITIONAL", 13, 254102},
	{"UNHEDGED", 8, 254103},
	{"TRAUTMANN", 9, 254104},
	{"OPTIMIERUNG", 11, 254105},
	{"SOLEM", 5, 254106},
	{"INFLAMATION", 11, 254107},
	{"IPCRESS", 7, 254108},
	{"KILTED", 6, 254109},
	{"DARINGLY", 8, 254110},
	{"BALCLUTHA", 9, 254111},
	{"BLADEMASTER", 11, 254112},
	{"GAERNE", 6, 254113},
	{"DUESBERG", 8, 254114},
	{"NEWYORKOLOGY", 12, 254115},
	{"MAIPO", 5, 254116},
	{"DEINTERLACING", 13, 254117},
	{"SYSTEMBAU", 9, 254118},
	{"NONACCRUAL", 10, 254119},
	{"MATURANA", 8, 254120},
	{"GETFILENAME", 11, 254121},
	{"DAUGAVPILS", 10, 254122},
	{"THINGYS", 7, 254123},
	{"FIREGUARD", 9, 254124},
	{"DOUBLEWIDE", 10, 254125},
	{"TRACGUIDE", 9, 254126},
	{"STRZELECKI", 10, 254127},
	{"SESAC", 5, 254128},
	{"GOSMILE", 7, 254129},
	{"LIGHTINGUNIVERSE", 16, 254130},
	{"HOMD", 4, 254131},
	{"DIVERSIDAD", 10, 254132},
	{"AUCC", 4, 254133},
	{"RRY", 3, 254134},
	{"GADOL", 5, 254135},
	{"BUNCHER", 7, 254136},
	{"TMDS", 4, 254137},
	{"EGHARVARD", 9, 254138},
	{"VEHICULOS", 9, 254139},
	{"STACKELBERG", 11, 254140},
	{"SCFV", 4, 254141},
	{"PRODUCTEURS", 11, 254142},
	{"ZURAB", 5, 254143},
	{"TOPAD", 5, 254144},
	{"PRODUTTORE", 10, 254145},
	{"GLENNALLEN", 10, 254146},
	{"FEDERALSBURG", 12, 254147},
	{"SITLL", 5, 254148},
	{"DISMUKES", 8, 254149},
	{"AUTOLIV", 7, 254150},
	{"ANTIPROTONS", 11, 254151},
	{"DERAISON", 8, 254152},
	{"BREVIARY", 8, 254153},
	{"QLISTVIEWITEM", 13, 254154},
	{"BENGUERRA", 9, 254155},
	{"VERSATEL", 8, 254156},
	{"FOURSTAR", 8, 254157},
	{"CLOKE", 5, 254158},
	{"SOUTHCENTER", 11, 254159},
	{"PEDESTRIANISED", 14, 254160},
	{"BINNY", 5, 254161},
	{"WWAN", 4, 254162},
	{"OEHLER", 6, 254163},
	{"DDERBYN", 7, 254164},
	{"SHALEH", 6, 254165},
	{"LAPEYRE", 7, 254166},
	{"PERSPEKTIVEN", 12, 254167},
	{"CATTO", 5, 254168},
	{"ARTSBUILDER", 11, 254169},
	{"LINEAMENTS", 10, 254170},
	{"GORICA", 6, 254171},
	{"ENDGAMES", 8, 254172},
	{"WAGNALLS", 8, 254173},
	{"SOURCERESOLVE", 13, 254174},
	{"MYZONE", 6, 254175},
	{"SPTREMBL", 8, 254176},
	{"PUREX", 5, 254177},
	{"ENOGGERA", 8, 254178},
	{"DEFCONFIG", 9, 254179},
	{"ARROWINSURANCE", 14, 254180},
	{"QBD", 3, 254181},
	{"ARIPRINT", 8, 254182},
	{"HLME", 4, 254183},
	{"BEELDEN", 7, 254184},
	{"UNBURIED", 8, 254185},
	{"TOYTOWN", 7, 254186},
	{"SCELTO", 6, 254187},
	{"NUCLEOPROTEIN", 13, 254188},
	{"FREEMEM", 7, 254189},
	{"CHIEL", 5, 254190},
	{"MARCELLIN", 9, 254191},
	{"MAZURY", 6, 254192},
	{"ARROWRECENT", 11, 254193},
	{"RACEMASE", 8, 254194},
	{"KINGSPADE", 9, 254195},
	{"CUSSIONS", 8, 254196},
	{"CENTRALISM", 10, 254197},
	{"GRAMINEAE", 9, 254198},
	{"PIPEDOWN", 8, 254199},
	{"WEIGLE", 6, 254200},
	{"KOOISTRA", 8, 254201},
	{"ENTERTAININGLY", 14, 254202},
	{"LATORY", 6, 254203},
	{"RRAS", 4, 254204},
	{"SKACEL", 6, 254205},
	{"INSATIATE", 9, 254206},
	{"ELEKTRIK", 8, 254207},
	{"KONTROLLE", 9, 254208},
	{"INTOLERABLY", 11, 254209},
	{"EULAS", 5, 254210},
	{"ZYTE", 4, 254211},
	{"ZOFR", 4, 254212},
	{"ZEEW", 4, 254213},
	{"YWYO", 4, 254214},
	{"YBOP", 4, 254215},
	{"XTSD", 4, 254216},
	{"XMIX", 4, 254217},
	{"XJOI", 4, 254218},
	{"XELM", 4, 254219},
	{"XCOO", 4, 254220},
	{"WRYC", 4, 254221},
	{"WLNO", 4, 254222},
	{"VDEF", 4, 254223},
	{"VAYE", 4, 254224},
	{"UVUL", 4, 254225},
	{"UOYU", 4, 254226},
	{"UOGE", 4, 254227},
	{"UHYA", 4, 254228},
	{"TWIV", 4, 254229},
	{"TRME", 4, 254230},
	{"TPSU", 4, 254231},
	{"SMKI", 4, 254232},
	{"SLUA", 4, 254233},
	{"SAGW", 4, 254234},
	{"RZIE", 4, 254235},
	{"RCCI", 4, 254236},
	{"RBWO", 4, 254237},
	{"PUPN", 4, 254238},
	{"PMFA", 4, 254239},
	{"PIDV", 4, 254240},
	{"PDFI", 4, 254241},
	{"PCCR", 4, 254242},
	{"OUIJ", 4, 254243},
	{"ORLG", 4, 254244},
	{"NZYW", 4, 254245},
	{"NDMK", 4, 254246},
	{"LZIO", 4, 254247},
	{"LYNV", 4, 254248},
	{"LUAD", 4, 254249},
	{"LTHJ", 4, 254250},
	{"LNCH", 4, 254251},
	{"KMSA", 4, 254252},
	{"KKWA", 4, 254253},
	{"KAYJ", 4, 254254},
	{"JRES", 4, 254255},
	{"JCOU", 4, 254256},
	{"JASD", 4, 254257},
	{"IXKE", 4, 254258},
	{"IOBJ", 4, 254259},
	{"INXC", 4, 254260},
	{"IMYU", 4, 254261},
	{"IGGT", 4, 254262},
	{"IFXI", 4, 254263},
	{"HYUR", 4, 254264},
	{"HTCM", 4, 254265},
	{"HLFI", 4, 254266},
	{"GXIS", 4, 254267},
	{"GWBU", 4, 254268},
	{"GURP", 4, 254269},
	{"GPCS", 4, 254270},
	{"GOIG", 4, 254271},
	{"GHAQ", 4, 254272},
	{"FIDB", 4, 254273},
	{"EDWM", 4, 254274},
	{"DYUL", 4, 254275},
	{"DNYM", 4, 254276},
	{"DMSL", 4, 254277},
	{"DKTH", 4, 254278},
	{"DHVA", 4, 254279},
	{"CAUF", 4, 254280},
	{"BISV", 4, 254281},
	{"BECD", 4, 254282},
	{"BDAS", 4, 254283},
	{"BBAM", 4, 254284},
	{"ARZB", 4, 254285},
	{"ALBT", 4, 254286},
	{"AKTW", 4, 254287},
	{"DISCOMFITURE", 12, 254288},
	{"RHAPSODIC", 9, 254289},
	{"LEFTHANDED", 10, 254290},
	{"JAIRUS", 6, 254291},
	{"TRADUCTEUR", 10, 254292},
	{"SULIK", 5, 254293},
	{"ARROWFILING", 11, 254294},
	{"SINDELFINGEN", 12, 254295},
	{"NAYYAR", 6, 254296},
	{"BARGOED", 7, 254297},
	{"TANZEN", 6, 254298},
	{"METROCENTER", 11, 254299},
	{"IWORSHIP", 8, 254300},
	{"GVM", 3, 254301},
	{"BLADEZ", 6, 254302},
	{"ARTICULATOR", 11, 254303},
	{"WALESKA", 7, 254304},
	{"INSANA", 6, 254305},
	{"BURKARD", 7, 254306},
	{"NORCOOL", 7, 254307},
	{"MAILREADER", 10, 254308},
	{"ARROWRULEMAKINGS", 16, 254309},
	{"TICKNER", 7, 254310},
	{"RESENDE", 7, 254311},
	{"MESSICO", 7, 254312},
	{"ARROWDOCKET", 11, 254313},
	{"WINGDINGS", 9, 254314},
	{"TUNYA", 5, 254315},
	{"RAINMETER", 9, 254316},
	{"PUSO", 4, 254317},
	{"MIRANDO", 7, 254318},
	{"THREEPENCE", 10, 254319},
	{"OTTAVIANO", 9, 254320},
	{"MARIKINA", 8, 254321},
	{"EARLTON", 7, 254322},
	{"DIVIETO", 7, 254323},
	{"AYAME", 5, 254324},
	{"YULIN", 5, 254325},
	{"SEGUENTI", 8, 254326},
	{"SCHWENKSVILLE", 13, 254327},
	{"SUSTRAN", 7, 254328},
	{"MEOWING", 7, 254329},
	{"INGOS", 5, 254330},
	{"HOOGE", 5, 254331},
	{"SIMONEAU", 8, 254332},
	{"SIGNORILE", 9, 254333},
	{"PEREGRINES", 10, 254334},
	{"MYCHAL", 6, 254335},
	{"KEMENY", 6, 254336},
	{"INTENATIONAL", 12, 254337},
	{"FRITZSCHE", 9, 254338},
	{"FOLKERT", 7, 254339},
	{"ENDERLIN", 8, 254340},
	{"SITESTUDIO", 10, 254341},
	{"PALMARI", 7, 254342},
	{"ORGANISASI", 10, 254343},
	{"KISELEV", 7, 254344},
	{"ALAGNA", 6, 254345},
	{"OGILBY", 6, 254346},
	{"MISMATCHING", 11, 254347},
	{"MILNTHORPE", 10, 254348},
	{"HEGEDUS", 7, 254349},
	{"QUANTEGY", 8, 254350},
	{"MUSKOX", 6, 254351},
	{"MANNOROTH", 9, 254352},
	{"GCPS", 4, 254353},
	{"POULE", 5, 254354},
	{"LYNDALL", 7, 254355},
	{"HSPCOMPLETE", 11, 254356},
	{"HOYLES", 6, 254357},
	{"TIBBY", 5, 254358},
	{"SHAFRAN", 7, 254359},
	{"PYOGENIC", 8, 254360},
	{"PENUS", 5, 254361},
	{"ZZJ", 3, 254362},
	{"REENGINEERED", 12, 254363},
	{"OVENPROOF", 9, 254364},
	{"IHOUSE", 6, 254365},
	{"STOEHR", 6, 254366},
	{"PIASA", 5, 254367},
	{"MISBRANDING", 11, 254368},
	{"DEDICA", 6, 254369},
	{"BREVOORT", 8, 254370},
	{"SPECULIST", 9, 254371},
	{"DELLCOM", 7, 254372},
	{"ASKSLASHDOT", 11, 254373},
	{"DEKORATION", 10, 254374},
	{"CAPABILI", 8, 254375},
	{"WINZ", 4, 254376},
	{"TILTER", 6, 254377},
	{"TEAMWORKING", 11, 254378},
	{"STRATEGOXT", 10, 254379},
	{"BENZIDINE", 9, 254380},
	{"INVOICEDEALERS", 14, 254381},
	{"AMBIKA", 6, 254382},
	{"WEISKOPF", 8, 254383},
	{"PURSLEY", 7, 254384},
	{"NABARRO", 7, 254385},
	{"FICHERO", 7, 254386},
	{"YONEZAWA", 8, 254387},
	{"SEMPO", 5, 254388},
	{"SAPELO", 6, 254389},
	{"REIMAGINING", 11, 254390},
	{"LABRECQUE", 9, 254391},
	{"CLARICA", 7, 254392},
	{"BURLISON", 8, 254393},
	{"WEBMASTERSERVICE", 16, 254394},
	{"KOBRIN", 6, 254395},
	{"GREENBURGH", 10, 254396},
	{"EBENFALLS", 9, 254397},
	{"CHUKOTKA", 8, 254398},
	{"CAULERPA", 8, 254399},
	{"HASLET", 6, 254400},
	{"BOOTES", 6, 254401},
	{"SAMU", 4, 254402},
	{"EFFACEMENT", 10, 254403},
	{"VREID", 5, 254404},
	{"RADIOLABELLED", 13, 254405},
	{"INTERNATIONALIS", 15, 254406},
	{"CURACY", 6, 254407},
	{"LIBANUS", 7, 254408},
	{"UMPS", 4, 254409},
	{"PETHIDINE", 9, 254410},
	{"ESTHERO", 7, 254411},
	{"NCARB", 5, 254412},
	{"EOFTWARE", 8, 254413},
	{"BARTOL", 6, 254414},
	{"REVERSIONS", 10, 254415},
	{"NORDMAN", 7, 254416},
	{"HYPERTEXTS", 10, 254417},
	{"WOODLEIGH", 9, 254418},
	{"MINORE", 6, 254419},
	{"ENFOQUE", 7, 254420},
	{"BERKES", 6, 254421},
	{"UNMERCIFULLY", 12, 254422},
	{"SHAMUR", 6, 254423},
	{"RINGWAY", 7, 254424},
	{"MILORD", 6, 254425},
	{"MADWOMAN", 8, 254426},
	{"KNIGHTMARE", 10, 254427},
	{"NCPDP", 5, 254428},
	{"MSVU", 4, 254429},
	{"MAKELA", 6, 254430},
	{"COMPORIUM", 9, 254431},
	{"WAUU", 4, 254432},
	{"OHIOPYLE", 8, 254433},
	{"MEINERT", 7, 254434},
	{"ELIZABET", 8, 254435},
	{"MESSAGECAST", 11, 254436},
	{"ARTWALK", 7, 254437},
	{"SOFTWAFE", 8, 254438},
	{"YELLOE", 6, 254439},
	{"JILLETTE", 8, 254440},
	{"BEHANDLUNG", 10, 254441},
	{"VELOURS", 7, 254442},
	{"TXTUNIQUEMEMBERID", 17, 254443},
	{"OUTPERFORMANCE", 14, 254444},
	{"OCHIL", 5, 254445},
	{"DECADRY", 7, 254446},
	{"VONDELPARK", 10, 254447},
	{"CAHIR", 5, 254448},
	{"SARIT", 5, 254449},
	{"FRACTIONPRICE", 13, 254450},
	{"WHITTED", 7, 254451},
	{"PETERLIN", 8, 254452},
	{"LWRS", 4, 254453},
	{"HOUELLEBECQ", 11, 254454},
	{"WARNINGSRC", 10, 254455},
	{"RICHD", 5, 254456},
	{"MEIC", 4, 254457},
	{"DEODORIZATION", 13, 254458},
	{"CHICKENED", 9, 254459},
	{"TITILLATION", 11, 254460},
	{"GOIGN", 5, 254461},
	{"BULLRICH", 8, 254462},
	{"HOLOS", 5, 254463},
	{"WIADOMO", 7, 254464},
	{"KEYFOBS", 7, 254465},
	{"FONTENELLE", 10, 254466},
	{"STARWRITER", 10, 254467},
	{"NETGROUP", 8, 254468},
	{"INDIANSTATES", 12, 254469},
	{"GRUDZIELANEK", 12, 254470},
	{"GENEST", 6, 254471},
	{"YUVA", 4, 254472},
	{"ORPORATION", 10, 254473},
	{"NUWARA", 6, 254474},
	{"ROCCAFORTE", 10, 254475},
	{"EURABIA", 7, 254476},
	{"CROWNPOINT", 10, 254477},
	{"SIZZLERS", 8, 254478},
	{"ICBS", 4, 254479},
	{"PONTIACS", 8, 254480},
	{"MONOPHONE", 9, 254481},
	{"CROATIE", 7, 254482},
	{"DIPSY", 5, 254483},
	{"CONFLICTUAL", 11, 254484},
	{"CAPISUITE", 9, 254485},
	{"BENYLIN", 7, 254486},
	{"BARBO", 5, 254487},
	{"REINTEGRATED", 12, 254488},
	{"MOLLICA", 7, 254489},
	{"MACRA", 5, 254490},
	{"EDUKATORS", 9, 254491},
	{"UPLEVEL", 7, 254492},
	{"FOLLAND", 7, 254493},
	{"VEILIGHEID", 10, 254494},
	{"TESTLET", 7, 254495},
	{"LXVI", 4, 254496},
	{"AMARR", 5, 254497},
	{"YAKOVENKO", 9, 254498},
	{"TOCHTER", 7, 254499},
	{"PLECKSTRIN", 10, 254500},
	{"OGIP", 4, 254501},
	{"ROWDEN", 6, 254502},
	{"SLADEK", 6, 254503},
	{"GEBRUIKSVOORWAARDEN", 19, 254504},
	{"FORELEGS", 8, 254505},
	{"GRANTWRITING", 12, 254506},
	{"CASCONE", 7, 254507},
	{"ARTERBURN", 9, 254508},
	{"UDAYA", 5, 254509},
	{"BACKSTROM", 9, 254510},
	{"VIETS", 5, 254511},
	{"VAYIKRA", 7, 254512},
	{"CHANTICLEERS", 12, 254513},
	{"CALLEBAUT", 9, 254514},
	{"ALEMANY", 7, 254515},
	{"LAURELHURST", 11, 254516},
	{"KOEHL", 5, 254517},
	{"MAHIMA", 6, 254518},
	{"KNIPPENBERG", 11, 254519},
	{"WYF", 3, 254520},
	{"SIDHWA", 6, 254521},
	{"GIGHA", 5, 254522},
	{"OCFS", 4, 254523},
	{"MOLLIN", 6, 254524},
	{"HOUSR", 5, 254525},
	{"YAMAN", 5, 254526},
	{"VESTITI", 7, 254527},
	{"CAMBUSLANG", 10, 254528},
	{"AKATHISIA", 9, 254529},
	{"SHORTBUS", 8, 254530},
	{"EPITOMISES", 10, 254531},
	{"SLINGSBY", 8, 254532},
	{"HARDTOPS", 8, 254533},
	{"NIKTO", 5, 254534},
	{"GELSINGER", 9, 254535},
	{"SLEPIAN", 7, 254536},
	{"RAFFY", 5, 254537},
	{"PRODFINDNEXTCAT", 15, 254538},
	{"EXFOLIANTS", 10, 254539},
	{"BRENTHAVEN", 10, 254540},
	{"SULAYMAN", 8, 254541},
	{"QUICKSHOT", 9, 254542},
	{"GOTOS", 5, 254543},
	{"BYY", 3, 254544},
	{"WHITMARSH", 9, 254545},
	{"FORTVILLE", 9, 254546},
	{"FAZEKAS", 7, 254547},
	{"SOVTWARE", 8, 254548},
	{"MIDSHIP", 7, 254549},
	{"JUNGO", 5, 254550},
	{"FRIM", 4, 254551},
	{"WATCHBANDS", 10, 254552},
	{"CIRAD", 5, 254553},
	{"BLUEMONT", 8, 254554},
	{"TURISTAS", 8, 254555},
	{"ELEASE", 6, 254556},
	{"TERPSICHORE", 11, 254557},
	{"ROSSETT", 7, 254558},
	{"GRUNOW", 6, 254559},
	{"LREC", 4, 254560},
	{"HIBERIA", 7, 254561},
	{"ESADE", 5, 254562},
	{"LEHRBUCH", 8, 254563},
	{"TRINDER", 7, 254564},
	{"STERS", 5, 254565},
	{"COLLENETTE", 10, 254566},
	{"CALLALA", 7, 254567},
	{"SZWARC", 6, 254568},
	{"PENNIMAN", 8, 254569},
	{"AGCL", 4, 254570},
	{"PEACENIKS", 9, 254571},
	{"CONGERS", 7, 254572},
	{"BIRCHARD", 8, 254573},
	{"ACUTA", 5, 254574},
	{"VERDENS", 7, 254575},
	{"SEAMSTRESSES", 12, 254576},
	{"MANQUEZ", 7, 254577},
	{"FUNTIONS", 8, 254578},
	{"PRZED", 5, 254579},
	{"NIKOLOV", 7, 254580},
	{"HIPKISS", 7, 254581},
	{"KBDI", 4, 254582},
	{"BERNABEU", 8, 254583},
	{"SONOGRAMS", 9, 254584},
	{"WBW", 3, 254585},
	{"EXORCISED", 9, 254586},
	{"CUADROS", 7, 254587},
	{"AUSTRAC", 7, 254588},
	{"ZYLE", 4, 254589},
	{"ZIGU", 4, 254590},
	{"ZIAK", 4, 254591},
	{"ZBRE", 4, 254592},
	{"YXBO", 4, 254593},
	{"WVAT", 4, 254594},
	{"WKRA", 4, 254595},
	{"WDWO", 4, 254596},
	{"VDSF", 4, 254597},
	{"VAFF", 4, 254598},
	{"UWRE", 4, 254599},
	{"UVAH", 4, 254600},
	{"USKF", 4, 254601},
	{"UPQB", 4, 254602},
	{"UNKK", 4, 254603},
	{"ULZI", 4, 254604},
	{"UKDU", 4, 254605},
	{"UDYY", 4, 254606},
	{"TPCL", 4, 254607},
	{"TOWD", 4, 254608},
	{"TMPP", 4, 254609},
	{"SCDV", 4, 254610},
	{"RZUC", 4, 254611},
	{"RYPC", 4, 254612},
	{"RPKS", 4, 254613},
	{"ROSX", 4, 254614},
	{"RGYY", 4, 254615},
	{"RDDV", 4, 254616},
	{"RCSM", 4, 254617},
	{"QLDA", 4, 254618},
	{"QILE", 4, 254619},
	{"PYSM", 4, 254620},
	{"POKU", 4, 254621},
	{"PECP", 4, 254622},
	{"OMPD", 4, 254623},
	{"ODRD", 4, 254624},
	{"MUWH", 4, 254625},
	{"MPMY", 4, 254626},
	{"LUAA", 4, 254627},
	{"LIDK", 4, 254628},
	{"KHOK", 4, 254629},
	{"IKJO", 4, 254630},
	{"IBSD", 4, 254631},
	{"HUYN", 4, 254632},
	{"HKWA", 4, 254633},
	{"GOUI", 4, 254634},
	{"GMYY", 4, 254635},
	{"GKAZ", 4, 254636},
	{"GHND", 4, 254637},
	{"FXME", 4, 254638},
	{"FXAV", 4, 254639},
	{"FOYA", 4, 254640},
	{"FEYD", 4, 254641},
	{"EUFU", 4, 254642},
	{"ESFF", 4, 254643},
	{"ERVN", 4, 254644},
	{"DSDS", 4, 254645},
	{"DPUJ", 4, 254646},
	{"DPTA", 4, 254647},
	{"DMUA", 4, 254648},
	{"CKDW", 4, 254649},
	{"CELV", 4, 254650},
	{"CDCE", 4, 254651},
	{"BFIV", 4, 254652},
	{"BCTI", 4, 254653},
	{"AURM", 4, 254654},
	{"ALYV", 4, 254655},
	{"ALWW", 4, 254656},
	{"ACUF", 4, 254657},
	{"STATEGIES", 9, 254658},
	{"SERVERWPI", 9, 254659},
	{"AVARAGE", 7, 254660},
	{"BISYS", 5, 254661},
	{"CRUSHRIDGE", 10, 254662},
	{"VENNOOTSCHAP", 12, 254663},
	{"SPAINE", 6, 254664},
	{"TANCREDI", 8, 254665},
	{"UNOLS", 5, 254666},
	{"SIDDHI", 6, 254667},
	{"KAIDAN", 6, 254668},
	{"VASCULARITY", 11, 254669},
	{"PYRITES", 7, 254670},
	{"DEWEYCLASS", 10, 254671},
	{"WUZZY", 5, 254672},
	{"THUNDERCAT", 10, 254673},
	{"RABBINATE", 9, 254674},
	{"LIGHTBAR", 8, 254675},
	{"JACORB", 6, 254676},
	{"DURABRITE", 9, 254677},
	{"CABLESUN", 8, 254678},
	{"KOGEL", 5, 254679},
	{"COUNTERTERRORIST", 16, 254680},
	{"SOTIRIS", 7, 254681},
	{"SOCTWARE", 8, 254682},
	{"MYCELIA", 7, 254683},
	{"KREYOL", 6, 254684},
	{"CASADOS", 7, 254685},
	{"WOMMEN", 6, 254686},
	{"RABER", 5, 254687},
	{"STAMMERS", 8, 254688},
	{"SEMIAHMOO", 9, 254689},
	{"KINTARO", 7, 254690},
	{"COGBURN", 7, 254691},
	{"TENDANCES", 9, 254692},
	{"SAYYED", 6, 254693},
	{"MOONBATTERY", 11, 254694},
	{"KIPI", 4, 254695},
	{"GRIDLAYOUT", 10, 254696},
	{"GEOLOGIE", 8, 254697},
	{"USFR", 4, 254698},
	{"PUSTULAR", 8, 254699},
	{"PROCUREAPRO", 11, 254700},
	{"BACKHAUS", 8, 254701},
	{"TAQWA", 5, 254702},
	{"OUTSELLING", 10, 254703},
	{"BLOE", 4, 254704},
	{"RUDRANGSHU", 10, 254705},
	{"CERISES", 7, 254706},
	{"QUERRY", 6, 254707},
	{"FOSCARI", 7, 254708},
	{"ETHOSTREAM", 10, 254709},
	{"BOSENDORFER", 11, 254710},
	{"STELLATA", 8, 254711},
	{"ORGANIZZAZIONE", 14, 254712},
	{"CPLUS", 5, 254713},
	{"WITHUT", 6, 254714},
	{"SOFTSARE", 8, 254715},
	{"NOCES", 5, 254716},
	{"ARNING", 6, 254717},
	{"VERTED", 6, 254718},
	{"ESPOSO", 6, 254719},
	{"CORONAE", 7, 254720},
	{"WORKHORSES", 10, 254721},
	{"MYHOME", 6, 254722},
	{"MURIETA", 7, 254723},
	{"BRINKWORTH", 10, 254724},
	{"ABCSOUND", 8, 254725},
	{"WHEELY", 6, 254726},
	{"REMINYL", 7, 254727},
	{"NIKISKI", 7, 254728},
	{"COUZENS", 7, 254729},
	{"RUKEYSER", 8, 254730},
	{"LOGOTHETIS", 10, 254731},
	{"KOSZYKA", 7, 254732},
	{"GLIDECAM", 8, 254733},
	{"GEBAUER", 7, 254734},
	{"BOFFO", 5, 254735},
	{"BAMFORTH", 8, 254736},
	{"BALDELLI", 8, 254737},
	{"THESPUNKER", 10, 254738},
	{"PROGRAMMATORE", 13, 254739},
	{"OVERVALUATION", 13, 254740},
	{"LAMPES", 6, 254741},
	{"ARTSMART", 8, 254742},
	{"TREADCLIMBER", 12, 254743},
	{"STREETMAN", 9, 254744},
	{"SCANLINES", 9, 254745},
	{"FLTRD", 5, 254746},
	{"FILGRASTIM", 10, 254747},
	{"CHARY", 5, 254748},
	{"LAMPRE", 6, 254749},
	{"ANIAK", 5, 254750},
	{"SNOPAKE", 7, 254751},
	{"QUAS", 4, 254752},
	{"ZOULAS", 6, 254753},
	{"PIGEONHOLED", 11, 254754},
	{"LIBDBIX", 7, 254755},
	{"GIMNASIO", 8, 254756},
	{"EXTERNALSITE", 12, 254757},
	{"DICHLOROPROPENE", 15, 254758},
	{"INTERTIE", 8, 254759},
	{"SISTEME", 7, 254760},
	{"JUMPSTARTS", 10, 254761},
	{"KURDI", 5, 254762},
	{"JFD", 3, 254763},
	{"CATHARS", 7, 254764},
	{"SLFTWARE", 8, 254765},
	{"BORTEZOMIB", 10, 254766},
	{"SWECO", 5, 254767},
	{"SHIGATSE", 8, 254768},
	{"MIKRON", 6, 254769},
	{"EGIRL", 5, 254770},
	{"YOBLING", 7, 254771},
	{"COMPATIBEL", 10, 254772},
	{"BIORUST", 7, 254773},
	{"TECHLIBRARY", 11, 254774},
	{"PNUELI", 6, 254775},
	{"NETWERKLOGO", 11, 254776},
	{"TEKLA", 5, 254777},
	{"RESOLUTIONUNIT", 14, 254778},
	{"ENUCLEATION", 11, 254779},
	{"MSTISLAV", 8, 254780},
	{"MONTACUTE", 9, 254781},
	{"BENESCH", 7, 254782},
	{"SOUNDFONTS", 10, 254783},
	{"MCNAY", 5, 254784},
	{"BEEVOR", 6, 254785},
	{"BANKOK", 6, 254786},
	{"VIPOWER", 7, 254787},
	{"INTAL", 5, 254788},
	{"GRENAD", 6, 254789},
	{"GARAMENDI", 9, 254790},
	{"AMMINISTRAZIONE", 15, 254791},
	{"STOICALLY", 9, 254792},
	{"WESTSOUND", 9, 254793},
	{"SOUTHPAWDVD", 11, 254794},
	{"SOULSHINE", 9, 254795},
	{"MILEAGES", 8, 254796},
	{"CARSREAL", 8, 254797},
	{"OLAR", 4, 254798},
	{"CREMASTER", 9, 254799},
	{"TIGHTY", 6, 254800},
	{"SMALLTECH", 9, 254801},
	{"CLEARFACE", 9, 254802},
	{"STIRFRY", 7, 254803},
	{"PROCYTE", 7, 254804},
	{"LATECOMER", 9, 254805},
	{"HARASTA", 7, 254806},
	{"VLOCK", 5, 254807},
	{"CCGT", 4, 254808},
	{"BHPS", 4, 254809},
	{"ANDERSELITE", 11, 254810},
	{"REUNIFIED", 9, 254811},
	{"HRRI", 4, 254812},
	{"SOUSAPHONE", 10, 254813},
	{"MTREE", 5, 254814},
	{"CANFOR", 6, 254815},
	{"CORPORATIZATION", 15, 254816},
	{"STUDENTSTORE", 12, 254817},
	{"OLOGICAL", 8, 254818},
	{"MATARAZZO", 9, 254819},
	{"CONSO", 5, 254820},
	{"LARDY", 5, 254821},
	{"JUNC", 4, 254822},
	{"JNCO", 4, 254823},
	{"MARKESAN", 8, 254824},
	{"COROWA", 6, 254825},
	{"CHOLANGIOPANCREATOGRAPHY", 24, 254826},
	{"CEMP", 4, 254827},
	{"GWLEDIG", 7, 254828},
	{"FINCHEM", 7, 254829},
	{"UNDERDRIVE", 10, 254830},
	{"POWEROFF", 8, 254831},
	{"KISANGANI", 9, 254832},
	{"ACDS", 4, 254833},
	{"TRIMOX", 6, 254834},
	{"NIXZMARY", 8, 254835},
	{"GINEPRI", 7, 254836},
	{"CONEZYME", 8, 254837},
	{"ALLMOVIE", 8, 254838},
	{"SNAPNAMES", 9, 254839},
	{"LOGANHOLME", 10, 254840},
	{"LLLI", 4, 254841},
	{"IZUMO", 5, 254842},
	{"DANACH", 6, 254843},
	{"ROKSAN", 6, 254844},
	{"MCKINTY", 7, 254845},
	{"NABEEL", 6, 254846},
	{"KARLEN", 6, 254847},
	{"IMMIGRATIONPORTAL", 17, 254848},
	{"FBGA", 4, 254849},
	{"WOULDEST", 8, 254850},
	{"UFFE", 4, 254851},
	{"TOSCO", 5, 254852},
	{"PORTMAPPER", 10, 254853},
	{"FORLANE", 7, 254854},
	{"PRINSLOO", 8, 254855},
	{"IMPRENSA", 8, 254856},
	{"DISOBEYS", 8, 254857},
	{"ASSIAN", 6, 254858},
	{"SATURNS", 7, 254859},
	{"PDMR", 4, 254860},
	{"KABARDINO", 9, 254861},
	{"SOCIALISED", 10, 254862},
	{"PRIMROSES", 9, 254863},
	{"ELIMINA", 7, 254864},
	{"BIOPAX", 6, 254865},
	{"BCLR", 4, 254866},
	{"VIESTURS", 8, 254867},
	{"READJUSTING", 11, 254868},
	{"PARASAIL", 8, 254869},
	{"HUMBORG", 7, 254870},
	{"PUNG", 4, 254871},
	{"SERVISE", 7, 254872},
	{"HANDBUILT", 9, 254873},
	{"GAINSBORO", 9, 254874},
	{"CONNECTIONSTRING", 16, 254875},
	{"MIZZEN", 6, 254876},
	{"PHISM", 5, 254877},
	{"KULLBACK", 8, 254878},
	{"ICFAI", 5, 254879},
	{"ENTAJH", 6, 254880},
	{"BOOKSURGE", 9, 254881},
	{"PAPPALARDO", 10, 254882},
	{"NOCTE", 5, 254883},
	{"MSHCP", 5, 254884},
	{"DATAMATICS", 10, 254885},
	{"TIMESTEN", 8, 254886},
	{"RABAH", 5, 254887},
	{"PICSL", 5, 254888},
	{"INTELENET", 9, 254889},
	{"DRAGONMAW", 9, 254890},
	{"ALMAN", 5, 254891},
	{"CAMPISI", 7, 254892},
	{"FFUNCTION", 9, 254893},
	{"ZAWADZKI", 8, 254894},
	{"WEBBERS", 7, 254895},
	{"TAJIKS", 6, 254896},
	{"ANDRIESSEN", 10, 254897},
	{"PROLES", 6, 254898},
	{"MANUMISSION", 11, 254899},
	{"JLD", 3, 254900},
	{"VIREOS", 6, 254901},
	{"MORTIFYING", 10, 254902},
	{"CHENERY", 7, 254903},
	{"JUZO", 4, 254904},
	{"SOFTWQRE", 8, 254905},
	{"CHRW", 4, 254906},
	{"ZAPPERS", 7, 254907},
	{"PREEZ", 5, 254908},
	{"VINDICATES", 10, 254909},
	{"SISSIFICATION", 13, 254910},
	{"EXLIM", 5, 254911},
	{"BTUH", 4, 254912},
	{"REITEN", 6, 254913},
	{"ORIGINALARRIVALTIME", 19, 254914},
	{"GODD", 4, 254915},
	{"DAGOBERT", 8, 254916},
	{"ZTIM", 4, 254917},
	{"ZOSW", 4, 254918},
	{"ZANM", 4, 254919},
	{"YSRH", 4, 254920},
	{"YNYC", 4, 254921},
	{"YDBO", 4, 254922},
	{"UKSW", 4, 254923},
	{"UGUD", 4, 254924},
	{"UFDE", 4, 254925},
	{"UBKH", 4, 254926},
	{"TZIK", 4, 254927},
	{"TOVM", 4, 254928},
	{"TABP", 4, 254929},
	{"STPB", 4, 254930},
	{"ROZT", 4, 254931},
	{"ROPV", 4, 254932},
	{"RKHY", 4, 254933},
	{"RBJU", 4, 254934},
	{"RABZ", 4, 254935},
	{"PYCE", 4, 254936},
	{"PRPE", 4, 254937},
	{"PDDE", 4, 254938},
	{"OTRB", 4, 254939},
	{"OLWY", 4, 254940},
	{"OFDG", 4, 254941},
	{"NXOR", 4, 254942},
	{"NWWA", 4, 254943},
	{"MYKL", 4, 254944},
	{"MOOP", 4, 254945},
	{"MELJ", 4, 254946},
	{"KYKE", 4, 254947},
	{"KYJE", 4, 254948},
	{"KUZM", 4, 254949},
	{"KOAF", 4, 254950},
	{"JOUT", 4, 254951},
	{"ISBC", 4, 254952},
	{"IDGN", 4, 254953},
	{"HMYY", 4, 254954},
	{"HKUS", 4, 254955},
	{"GGDO", 4, 254956},
	{"FIDC", 4, 254957},
	{"FGIM", 4, 254958},
	{"FAYW", 4, 254959},
	{"EZRU", 4, 254960},
	{"EUXF", 4, 254961},
	{"EPKK", 4, 254962},
	{"ENZP", 4, 254963},
	{"EGIW", 4, 254964},
	{"DKAE", 4, 254965},
	{"DHTC", 4, 254966},
	{"DEMG", 4, 254967},
	{"DEKW", 4, 254968},
	{"DAOD", 4, 254969},
	{"CMEI", 4, 254970},
	{"CAWT", 4, 254971},
	{"AZPA", 4, 254972},
	{"AXVO", 4, 254973},
	{"ATGP", 4, 254974},
	{"AJEM", 4, 254975},
	{"AGGH", 4, 254976},
	{"AFDU", 4, 254977},
	{"SUBKINGDOM", 10, 254978},
	{"BRAEBURN", 8, 254979},
	{"BOOZETIME", 9, 254980},
	{"GONDOLIERS", 10, 254981},
	{"KRIJGEN", 7, 254982},
	{"TABSTRIP", 8, 254983},
	{"PERCRIPTION", 11, 254984},
	{"PEDDER", 6, 254985},
	{"NASFAA", 6, 254986},
	{"YETTER", 6, 254987},
	{"TIEDJE", 6, 254988},
	{"THREEWAVE", 9, 254989},
	{"SDULT", 5, 254990},
	{"HOFBURG", 7, 254991},
	{"DRAINABLE", 9, 254992},
	{"BARBORA", 7, 254993},
	{"VANISHINGLY", 11, 254994},
	{"OROSI", 5, 254995},
	{"LILLYWHITE", 10, 254996},
	{"EDLIN", 5, 254997},
	{"CRUISESPRINCESS", 15, 254998},
	{"BRITTINGHAM", 11, 254999},
	{"AREAWEB", 7, 255000},
	{"XVIDEO", 6, 255001},
	{"PATRIMONIAL", 11, 255002},
	{"BLUNTING", 8, 255003},
	{"BIAIS", 5, 255004},
	{"UNRESOLVABLE", 12, 255005},
	{"RENEHAN", 7, 255006},
	{"POLYBIUS", 8, 255007},
	{"MISHKAN", 7, 255008},
	{"MASTICATORY", 11, 255009},
	{"HOEPPNER", 8, 255010},
	{"BLEATS", 6, 255011},
	{"ALLBASE", 7, 255012},
	{"OBJEKTIV", 8, 255013},
	{"MICROBIOTA", 10, 255014},
	{"HORULU", 6, 255015},
	{"COLLINEARITY", 12, 255016},
	{"WIGGLERS", 8, 255017},
	{"KIMOCK", 6, 255018},
	{"ANGHARAD", 8, 255019},
	{"GSUSA", 5, 255020},
	{"DUKAT", 5, 255021},
	{"DEDIPOWER", 9, 255022},
	{"ENTRYS", 6, 255023},
	{"RUX", 3, 255024},
	{"DRAWE", 5, 255025},
	{"COMISION", 8, 255026},
	{"AROMAT", 6, 255027},
	{"HOLESAWS", 8, 255028},
	{"TRANSGENERATION", 15, 255029},
	{"NMTOKEN", 7, 255030},
	{"CBLDF", 5, 255031},
	{"RSYSLOG", 7, 255032},
	{"DCED", 4, 255033},
	{"YARE", 4, 255034},
	{"UNBEIGE", 7, 255035},
	{"SUPERCARD", 9, 255036},
	{"HARPISTS", 8, 255037},
	{"GROBLER", 7, 255038},
	{"BARZUN", 6, 255039},
	{"SLOCOMBE", 8, 255040},
	{"PEPPERMINTS", 11, 255041},
	{"LUMCON", 6, 255042},
	{"LOURENS", 7, 255043},
	{"GRAVATARS", 9, 255044},
	{"SDADATA", 7, 255045},
	{"REFORME", 7, 255046},
	{"PORTERING", 9, 255047},
	{"KUTNA", 5, 255048},
	{"BANANAMAN", 9, 255049},
	{"OMTALE", 6, 255050},
	{"FURRIER", 7, 255051},
	{"BANCASSURANCE", 13, 255052},
	{"SANGRO", 6, 255053},
	{"POLISCI", 7, 255054},
	{"LOITAS", 6, 255055},
	{"ROBERTSVILLE", 12, 255056},
	{"MICHALS", 7, 255057},
	{"DERRING", 7, 255058},
	{"SHNTOOL", 7, 255059},
	{"PRINTE", 6, 255060},
	{"LUCEDALE", 8, 255061},
	{"DIVULGES", 8, 255062},
	{"BRAZELL", 7, 255063},
	{"CHELTON", 7, 255064},
	{"WAVRE", 5, 255065},
	{"VELVEL", 6, 255066},
	{"ENGELAND", 8, 255067},
	{"AUTOPACKAGE", 11, 255068},
	{"ARGENTIA", 8, 255069},
	{"SPIVACK", 7, 255070},
	{"VISNU", 5, 255071},
	{"LIBGHTTP", 8, 255072},
	{"WHATCOUNTS", 10, 255073},
	{"GUZZINI", 7, 255074},
	{"GTCC", 4, 255075},
	{"FANFARES", 8, 255076},
	{"VOCALE", 6, 255077},
	{"RHINOL", 6, 255078},
	{"LIBUTIL", 7, 255079},
	{"DOLIN", 5, 255080},
	{"CAPITALIZATIONS", 15, 255081},
	{"HENRYVILLE", 10, 255082},
	{"THARU", 5, 255083},
	{"DIVENTA", 7, 255084},
	{"TAKIZAWA", 8, 255085},
	{"SILSOE", 6, 255086},
	{"HABAND", 6, 255087},
	{"PREMCHAND", 9, 255088},
	{"DUNNINGTON", 10, 255089},
	{"SPOTBOT", 7, 255090},
	{"MILLETS", 7, 255091},
	{"KANGNAM", 7, 255092},
	{"HOLSTEN", 7, 255093},
	{"SMOOTHENING", 11, 255094},
	{"HOULLIER", 8, 255095},
	{"CARLAND", 7, 255096},
	{"PEARISBURG", 10, 255097},
	{"PALAUTE", 7, 255098},
	{"LAMARCA", 7, 255099},
	{"JANDIA", 6, 255100},
	{"GBW", 3, 255101},
	{"CITICARDS", 9, 255102},
	{"SMPL", 4, 255103},
	{"MOVT", 4, 255104},
	{"METACOMPUTING", 13, 255105},
	{"JESKE", 5, 255106},
	{"SWALLOWER", 9, 255107},
	{"MRAZEK", 6, 255108},
	{"JWP", 3, 255109},
	{"COORDINADORA", 12, 255110},
	{"ANTIALIASED", 11, 255111},
	{"CIRIA", 5, 255112},
	{"WOLLEY", 6, 255113},
	{"MINISTRES", 9, 255114},
	{"DRINA", 5, 255115},
	{"TERREL", 6, 255116},
	{"TACY", 4, 255117},
	{"PIZER", 5, 255118},
	{"ENTRAVISION", 11, 255119},
	{"ABAXIALLY", 9, 255120},
	{"OREIGN", 6, 255121},
	{"LANGUAG", 7, 255122},
	{"IRANICA", 7, 255123},
	{"HTGL", 4, 255124},
	{"PROCELL", 7, 255125},
	{"GWENDA", 6, 255126},
	{"TOSHIKO", 7, 255127},
	{"TSUNEO", 6, 255128},
	{"EXTREAMLY", 9, 255129},
	{"ATTRIBUTELIST", 13, 255130},
	{"SVALBARDAND", 11, 255131},
	{"ORBITERS", 8, 255132},
	{"OVIDE", 5, 255133},
	{"KOPIE", 5, 255134},
	{"DELFINA", 7, 255135},
	{"USPA", 4, 255136},
	{"OCUPA", 5, 255137},
	{"GONVILLE", 8, 255138},
	{"BRUCEVILLE", 10, 255139},
	{"SAMBORA", 7, 255140},
	{"LRAD", 4, 255141},
	{"ISHIGAKI", 8, 255142},
	{"FRACT", 5, 255143},
	{"EYTAN", 5, 255144},
	{"FKL", 3, 255145},
	{"MULTIGRAIN", 10, 255146},
	{"LVF", 3, 255147},
	{"GAFAS", 5, 255148},
	{"SALZMANN", 8, 255149},
	{"CARG", 4, 255150},
	{"AMPITHEATER", 11, 255151},
	{"POLYSULFONE", 11, 255152},
	{"AUDULT", 6, 255153},
	{"GILGAL", 6, 255154},
	{"ADVC", 4, 255155},
	{"ZIVKOVIC", 8, 255156},
	{"FAUCIBUS", 8, 255157},
	{"PVX", 3, 255158},
	{"FASTT", 5, 255159},
	{"CRISSCROSSING", 13, 255160},
	{"SUTPHIN", 7, 255161},
	{"TRVAEL", 6, 255162},
	{"LEWSEY", 6, 255163},
	{"AMOXAPINE", 9, 255164},
	{"ABSYNTH", 7, 255165},
	{"GMCSIERRA", 9, 255166},
	{"FLUTING", 7, 255167},
	{"SWAGE", 5, 255168},
	{"LOADBALANCER", 12, 255169},
	{"GRABILL", 7, 255170},
	{"FIRAS", 5, 255171},
	{"CONFORD", 7, 255172},
	{"HOMETEAMS", 9, 255173},
	{"EMPNO", 5, 255174},
	{"ARABSAT", 7, 255175},
	{"VILLIGER", 8, 255176},
	{"TARIH", 5, 255177},
	{"SECHE", 5, 255178},
	{"INTERCARRIER", 12, 255179},
	{"DESCRIPTIO", 10, 255180},
	{"GARBED", 6, 255181},
	{"ESSAGE", 6, 255182},
	{"CHLEWBOT", 8, 255183},
	{"FIRECLAY", 8, 255184},
	{"CAVIN", 5, 255185},
	{"TROLLIES", 8, 255186},
	{"MISRHYMED", 9, 255187},
	{"DENTING", 7, 255188},
	{"ABRUPTION", 9, 255189},
	{"ORGANUM", 7, 255190},
	{"NICEGUY", 7, 255191},
	{"KNEECAPS", 8, 255192},
	{"INCREMENTO", 10, 255193},
	{"EPINAL", 6, 255194},
	{"CHMN", 4, 255195},
	{"REPPERT", 7, 255196},
	{"KAKAMEGA", 8, 255197},
	{"FERCH", 5, 255198},
	{"EUROPEANISATION", 15, 255199},
	{"BULGARIE", 8, 255200},
	{"RUMELY", 6, 255201},
	{"RAZO", 4, 255202},
	{"YRAVEL", 6, 255203},
	{"STATEFLOW", 9, 255204},
	{"PENNACCHIO", 10, 255205},
	{"HIPOTECAS", 9, 255206},
	{"CHEMOPREVENTIVE", 15, 255207},
	{"CENTRIOS", 8, 255208},
	{"DEFMACRO", 8, 255209},
	{"DECWINDOWS", 10, 255210},
	{"DISCOVERYCHANNELSTORE", 21, 255211},
	{"MINIMUMSIZE", 11, 255212},
	{"CIESIN", 6, 255213},
	{"SOFTWZRE", 8, 255214},
	{"PIXI", 4, 255215},
	{"BORDES", 6, 255216},
	{"RUNNNING", 8, 255217},
	{"ROSINE", 6, 255218},
	{"PILOTO", 6, 255219},
	{"PERIDOTITE", 10, 255220},
	{"DRUGA", 5, 255221},
	{"ARKETING", 8, 255222},
	{"IBLIS", 5, 255223},
	{"BACKPAIN", 8, 255224},
	{"TICKEST", 7, 255225},
	{"PRAKTIKUM", 9, 255226},
	{"FVD", 3, 255227},
	{"DRAUGHTING", 10, 255228},
	{"PTMS", 4, 255229},
	{"STATENDAM", 9, 255230},
	{"PROMOD", 6, 255231},
	{"PRESBYTERIANISM", 15, 255232},
	{"MATRICARIA", 10, 255233},
	{"EBLOGGY", 7, 255234},
	{"ADELHEID", 8, 255235},
	{"VITRIC", 6, 255236},
	{"LIBREADLINE", 11, 255237},
	{"EPHY", 4, 255238},
	{"CONCIEVED", 9, 255239},
	{"LINDSAYISM", 10, 255240},
	{"DARKSTATION", 11, 255241},
	{"TOUCHET", 7, 255242},
	{"STORMWATCH", 10, 255243},
	{"QUESA", 5, 255244},
	{"FUJIN", 5, 255245},
	{"DICOR", 5, 255246},
	{"PACELLI", 7, 255247},
	{"MEMNON", 6, 255248},
	{"DEBASER", 7, 255249},
	{"SXEDIO", 6, 255250},
	{"MORTLOCK", 8, 255251},
	{"KINMEN", 6, 255252},
	{"GRAYVILLE", 9, 255253},
	{"CYCLOPES", 8, 255254},
	{"CONGUE", 6, 255255},
	{"PETEN", 5, 255256},
	{"COPULATE", 8, 255257},
	{"VISCOELASTICITY", 15, 255258},
	{"TUSSIONEX", 9, 255259},
	{"SAMISH", 6, 255260},
	{"JOONGANG", 8, 255261},
	{"NAVICAT", 7, 255262},
	{"MIKULAS", 7, 255263},
	{"YOBANG", 6, 255264},
	{"TRAG", 4, 255265},
	{"SALVADORE", 9, 255266},
	{"KMEM", 4, 255267},
	{"BASILAN", 7, 255268},
	{"SUPERMINI", 9, 255269},
	{"SOFGWARE", 8, 255270},
	{"ROYE", 4, 255271},
	{"NGHIA", 5, 255272},
	{"TRIMITE", 7, 255273},
	{"RAPHAELITES", 11, 255274},
	{"KLUANE", 6, 255275},
	{"INSINUATES", 10, 255276},
	{"ZYFE", 4, 255277},
	{"ZADW", 4, 255278},
	{"YLTA", 4, 255279},
	{"YLNE", 4, 255280},
	{"YAEX", 4, 255281},
	{"WURG", 4, 255282},
	{"WAKK", 4, 255283},
	{"VYGE", 4, 255284},
	{"UPIP", 4, 255285},
	{"TVGO", 4, 255286},
	{"TCYH", 4, 255287},
	{"RYUB", 4, 255288},
	{"RYNP", 4, 255289},
	{"RVSG", 4, 255290},
	{"RIVL", 4, 255291},
	{"RCGI", 4, 255292},
	{"PUPY", 4, 255293},
	{"POEW", 4, 255294},
	{"PHPU", 4, 255295},
	{"OYJE", 4, 255296},
	{"OXSD", 4, 255297},
	{"ORLP", 4, 255298},
	{"OIBU", 4, 255299},
	{"NDPJ", 4, 255300},
	{"MVLA", 4, 255301},
	{"MPOH", 4, 255302},
	{"LTVN", 4, 255303},
	{"LMGL", 4, 255304},
	{"LIKF", 4, 255305},
	{"KOTU", 4, 255306},
	{"KOKC", 4, 255307},
	{"KIAV", 4, 255308},
	{"KGTH", 4, 255309},
	{"JKIN", 4, 255310},
	{"IPMC", 4, 255311},
	{"IJEC", 4, 255312},
	{"IGGB", 4, 255313},
	{"GAUI", 4, 255314},
	{"FNME", 4, 255315},
	{"FMEF", 4, 255316},
	{"ERLN", 4, 255317},
	{"EOLP", 4, 255318},
	{"ELUV", 4, 255319},
	{"EDBD", 4, 255320},
	{"EBKE", 4, 255321},
	{"CLTD", 4, 255322},
	{"BYMB", 4, 255323},
	{"BYFB", 4, 255324},
	{"BULP", 4, 255325},
	{"BMXA", 4, 255326},
	{"BBEW", 4, 255327},
	{"ASYQ", 4, 255328},
	{"AMRT", 4, 255329},
	{"ZAENTZ", 6, 255330},
	{"YOSHII", 6, 255331},
	{"BIPODS", 6, 255332},
	{"VVAW", 4, 255333},
	{"MONOCULTURES", 12, 255334},
	{"JECTION", 7, 255335},
	{"DESPERADOES", 11, 255336},
	{"VAERS", 5, 255337},
	{"SIMBOLO", 7, 255338},
	{"TETSURO", 7, 255339},
	{"MIZUSHIMA", 9, 255340},
	{"MITIS", 5, 255341},
	{"REGEV", 5, 255342},
	{"ENGERT", 6, 255343},
	{"BLURR", 5, 255344},
	{"SNOWRENTAL", 10, 255345},
	{"NACONKANTARI", 12, 255346},
	{"FUNAFUTI", 8, 255347},
	{"CZARINA", 7, 255348},
	{"BASIDIOMYCOTA", 13, 255349},
	{"SPIRI", 5, 255350},
	{"MOSTELLER", 9, 255351},
	{"GORNY", 5, 255352},
	{"WWWYAHOOFR", 10, 255353},
	{"SMARTXX", 7, 255354},
	{"SITESI", 6, 255355},
	{"MONTANEZ", 8, 255356},
	{"CHAYTOR", 7, 255357},
	{"UREAPLASMA", 10, 255358},
	{"JUXTA", 5, 255359},
	{"UMAC", 4, 255360},
	{"SCOL", 4, 255361},
	{"BELLUCI", 7, 255362},
	{"NUAGE", 5, 255363},
	{"NOVACONVERTERS", 14, 255364},
	{"STARIN", 6, 255365},
	{"NHDR", 4, 255366},
	{"MARIHEMP", 8, 255367},
	{"KURATA", 6, 255368},
	{"WYEAST", 6, 255369},
	{"WHIPP", 5, 255370},
	{"MAESTOSO", 8, 255371},
	{"JOBW", 4, 255372},
	{"HILBURN", 7, 255373},
	{"FLEXINODE", 9, 255374},
	{"LARIOS", 6, 255375},
	{"KITZHABER", 9, 255376},
	{"FLAIRS", 6, 255377},
	{"FASCICLES", 9, 255378},
	{"HUYTON", 6, 255379},
	{"PREAWARD", 8, 255380},
	{"PERATA", 6, 255381},
	{"RAYNAL", 6, 255382},
	{"OVEREXPLOITATION", 16, 255383},
	{"KETEK", 5, 255384},
	{"DYAX", 4, 255385},
	{"BARATTA", 7, 255386},
	{"REDEDICATE", 10, 255387},
	{"MARGAREE", 8, 255388},
	{"GALAXIANS", 9, 255389},
	{"DIWETHAF", 8, 255390},
	{"COMENTARII", 10, 255391},
	{"JIHLAVA", 7, 255392},
	{"FREELIST", 8, 255393},
	{"ENDX", 4, 255394},
	{"UPAMANYU", 8, 255395},
	{"PROTECTIVENESS", 14, 255396},
	{"ANWENDUNGSDATEN", 15, 255397},
	{"MADELIA", 7, 255398},
	{"GALO", 4, 255399},
	{"NEROS", 5, 255400},
	{"MARNEY", 6, 255401},
	{"LEARNKEY", 8, 255402},
	{"FREAKAZOID", 10, 255403},
	{"BARRUS", 6, 255404},
	{"PHILHARMONIE", 12, 255405},
	{"MONITO", 6, 255406},
	{"SESTERCES", 9, 255407},
	{"MIKHAEL", 7, 255408},
	{"MEDIASERVICES", 13, 255409},
	{"INVESTIGAT", 10, 255410},
	{"FEMINISATION", 12, 255411},
	{"BIELER", 6, 255412},
	{"RRX", 3, 255413},
	{"MARTINEK", 8, 255414},
	{"KEETCH", 6, 255415},
	{"DEBOSSED", 8, 255416},
	{"DBAR", 4, 255417},
	{"BLOS", 4, 255418},
	{"SIMILI", 6, 255419},
	{"SIMES", 5, 255420},
	{"PLAMENSL", 8, 255421},
	{"WOLTLAB", 7, 255422},
	{"DREAMQUEST", 10, 255423},
	{"LIBRAS", 6, 255424},
	{"HUDDLES", 7, 255425},
	{"HAXBY", 5, 255426},
	{"DUFUR", 5, 255427},
	{"TETONA", 6, 255428},
	{"PULLET", 6, 255429},
	{"PARRETT", 7, 255430},
	{"BADC", 4, 255431},
	{"ABATES", 6, 255432},
	{"FREQUENZ", 8, 255433},
	{"ELEMENTTREE", 11, 255434},
	{"COUCHER", 7, 255435},
	{"AUFIDIUS", 8, 255436},
	{"SOLICITAR", 9, 255437},
	{"FREUNDEN", 8, 255438},
	{"DOUSING", 7, 255439},
	{"MENAND", 6, 255440},
	{"LIFEPAC", 7, 255441},
	{"ALANCHEAH", 9, 255442},
	{"STARRESOURCE", 12, 255443},
	{"PASPORT", 7, 255444},
	{"WEBSTARTER", 10, 255445},
	{"CENY", 4, 255446},
	{"BPK", 3, 255447},
	{"BENZOPHENONE", 12, 255448},
	{"ZUIDERDAM", 9, 255449},
	{"WHITEWOLF", 9, 255450},
	{"METALINE", 8, 255451},
	{"ATDEC", 5, 255452},
	{"ZAGATO", 6, 255453},
	{"RITSON", 6, 255454},
	{"PEASY", 5, 255455},
	{"INCONVIENCE", 11, 255456},
	{"MBCHB", 5, 255457},
	{"FUNCTIONALIZATION", 17, 255458},
	{"CRISLER", 7, 255459},
	{"ATYPIA", 6, 255460},
	{"CREAGH", 6, 255461},
	{"CIVILIZE", 8, 255462},
	{"BOURNVILLE", 10, 255463},
	{"IULIA", 5, 255464},
	{"SNIDELY", 7, 255465},
	{"PHIAL", 5, 255466},
	{"AUTOMO", 6, 255467},
	{"DEONTOLOGICAL", 13, 255468},
	{"ZEBU", 4, 255469},
	{"PSYCHOACOUSTIC", 14, 255470},
	{"DEDDINGTON", 10, 255471},
	{"WAECHTER", 8, 255472},
	{"OUTERMARK", 9, 255473},
	{"DSLRS", 5, 255474},
	{"DESCRIBABLE", 11, 255475},
	{"CREATEVOLATILEIMAGE", 19, 255476},
	{"TRAU", 4, 255477},
	{"POWDERCOATED", 12, 255478},
	{"KOTANI", 6, 255479},
	{"GETOPTS", 7, 255480},
	{"HEIMERDINGER", 12, 255481},
	{"CHAMPI", 6, 255482},
	{"ZEEUW", 5, 255483},
	{"GIFTBASKET", 10, 255484},
	{"FOURPLEX", 8, 255485},
	{"CLASSIFED", 9, 255486},
	{"CANNAN", 6, 255487},
	{"ZAITCEV", 7, 255488},
	{"CONTRARIWISE", 12, 255489},
	{"POTERIE", 7, 255490},
	{"FAUTE", 5, 255491},
	{"ARRANT", 6, 255492},
	{"DISHER", 6, 255493},
	{"DELTANA", 7, 255494},
	{"BUILDINGTALK", 12, 255495},
	{"ALLCOCK", 7, 255496},
	{"PEARTREE", 8, 255497},
	{"CYTOCHEM", 8, 255498},
	{"CLURE", 5, 255499},
	{"GALNAC", 6, 255500},
	{"ELLHNIKHS", 9, 255501},
	{"LEGARE", 6, 255502},
	{"ABZUG", 5, 255503},
	{"OFFRIR", 6, 255504},
	{"INTEK", 5, 255505},
	{"ELEMS", 5, 255506},
	{"CHARRING", 8, 255507},
	{"PENNEYS", 7, 255508},
	{"GARDEZ", 6, 255509},
	{"TORREMUELLE", 11, 255510},
	{"APPEALINGLY", 11, 255511},
	{"WRTE", 4, 255512},
	{"OVERLANDER", 10, 255513},
	{"NAMBIAN", 7, 255514},
	{"BBBS", 4, 255515},
	{"WHIRPOOL", 8, 255516},
	{"MULLIGANS", 9, 255517},
	{"BRUNTSFIELD", 11, 255518},
	{"WOLLATON", 8, 255519},
	{"SITCH", 5, 255520},
	{"MULTE", 5, 255521},
	{"JALALI", 6, 255522},
	{"ILLIO", 5, 255523},
	{"ANTRON", 6, 255524},
	{"CHRISPIAN", 9, 255525},
	{"CIJEDGE", 7, 255526},
	{"CALCULATORCURRENT", 17, 255527},
	{"BREADBASKET", 11, 255528},
	{"SKANKS", 6, 255529},
	{"PERTAMINA", 9, 255530},
	{"PPLICATIONS", 11, 255531},
	{"BANCHE", 6, 255532},
	{"ALLSTREAM", 9, 255533},
	{"REICHMANN", 9, 255534},
	{"VISUALIZAR", 10, 255535},
	{"GOSVAMI", 7, 255536},
	{"CORRUGATION", 11, 255537},
	{"SAVESUBSCRIBE", 13, 255538},
	{"OPTIMIZA", 8, 255539},
	{"NUNAN", 5, 255540},
	{"LACT", 4, 255541},
	{"SEPARATRIX", 10, 255542},
	{"SUPERALLOYS", 11, 255543},
	{"NESTEROV", 8, 255544},
	{"KRACH", 5, 255545},
	{"CAMPESINA", 9, 255546},
	{"HOTHEAD", 7, 255547},
	{"AMBROGI", 7, 255548},
	{"QUAH", 4, 255549},
	{"CELLARBAR", 9, 255550},
	{"ALNASEEJ", 8, 255551},
	{"ZAPACHY", 7, 255552},
	{"ULSD", 4, 255553},
	{"TROGDOR", 7, 255554},
	{"REDECORATION", 12, 255555},
	{"NOGUERA", 7, 255556},
	{"MIKEH", 5, 255557},
	{"MERITING", 8, 255558},
	{"CYFREITHIOL", 11, 255559},
	{"TARIFE", 6, 255560},
	{"SLOBS", 5, 255561},
	{"WVSTREAM", 8, 255562},
	{"CAYWOOD", 7, 255563},
	{"PIATKUS", 7, 255564},
	{"WETTABLE", 8, 255565},
	{"SEUSSICAL", 9, 255566},
	{"RIQUE", 5, 255567},
	{"INSTORES", 8, 255568},
	{"TRAING", 6, 255569},
	{"ROCKSPRINGS", 11, 255570},
	{"MOVEOFF", 7, 255571},
	{"HELICHRYSUM", 11, 255572},
	{"CRREL", 5, 255573},
	{"CONTINUAR", 9, 255574},
	{"POWERSTOP", 9, 255575},
	{"PHAZER", 6, 255576},
	{"ZOOMTEXT", 8, 255577},
	{"VIVIANNE", 8, 255578},
	{"SHMALE", 6, 255579},
	{"CARDIOLIPIN", 11, 255580},
	{"YAHII", 5, 255581},
	{"WENSEN", 6, 255582},
	{"MARKARIAN", 9, 255583},
	{"TRANSMITTALS", 12, 255584},
	{"MURAMIDASE", 10, 255585},
	{"TRAMONTINA", 10, 255586},
	{"JLIST", 5, 255587},
	{"DIGICAMHELP", 11, 255588},
	{"LATORTUE", 8, 255589},
	{"CONSIGLIA", 9, 255590},
	{"ABIDIA", 6, 255591},
	{"PIECEWORK", 9, 255592},
	{"OOOOPS", 6, 255593},
	{"DECLAMATION", 11, 255594},
	{"BLWCH", 5, 255595},
	{"AREAID", 6, 255596},
	{"ANTILLEAN", 9, 255597},
	{"YARI", 4, 255598},
	{"UKW", 3, 255599},
	{"OSPITI", 6, 255600},
	{"MARKOVA", 7, 255601},
	{"INDEXESSM", 9, 255602},
	{"ILARY", 5, 255603},
	{"MISCARRY", 8, 255604},
	{"GEOCACHERS", 10, 255605},
	{"CHYBA", 5, 255606},
	{"TANGELO", 7, 255607},
	{"MISHOO", 6, 255608},
	{"GINSU", 5, 255609},
	{"WENDLER", 7, 255610},
	{"MATHEUS", 7, 255611},
	{"SWEATBANDS", 10, 255612},
	{"HARWARE", 7, 255613},
	{"ELOVE", 5, 255614},
	{"WEBNEWS", 7, 255615},
	{"LAMORAK", 7, 255616},
	{"ABOWD", 5, 255617},
	{"XUZHOU", 6, 255618},
	{"WAAG", 4, 255619},
	{"UOME", 4, 255620},
	{"STAPLEHURST", 11, 255621},
	{"REMANUFACTURERS", 15, 255622},
	{"HOGEL", 5, 255623},
	{"EVENTUATE", 9, 255624},
	{"CARAQUET", 8, 255625},
	{"NIELD", 5, 255626},
	{"MAGAZINELINE", 12, 255627},
	{"EVILLYRICS", 10, 255628},
	{"DANNEVIRKE", 10, 255629},
	{"XEIORVOBIBEWO", 13, 255630},
	{"SOLARSCOPE", 10, 255631},
	{"FLOURLESS", 9, 255632},
	{"APKA", 4, 255633},
	{"SWAMPER", 7, 255634},
	{"FLASHGUNS", 9, 255635},
	{"ZIZS", 4, 255636},
	{"ZDAA", 4, 255637},
	{"ZAAP", 4, 255638},
	{"YDPL", 4, 255639},
	{"YDBL", 4, 255640},
	{"XTSR", 4, 255641},
	{"XIIC", 4, 255642},
	{"WWFL", 4, 255643},
	{"WOOZ", 4, 255644},
	{"WBUG", 4, 255645},
	{"VTAK", 4, 255646},
	{"UWAB", 4, 255647},
	{"UOVI", 4, 255648},
	{"UMKO", 4, 255649},
	{"UDDF", 4, 255650},
	{"UBRY", 4, 255651},
	{"TMIY", 4, 255652},
	{"TILQ", 4, 255653},
	{"TCUH", 4, 255654},
	{"SVSD", 4, 255655},
	{"SIPF", 4, 255656},
	{"SGPA", 4, 255657},
	{"RVYA", 4, 255658},
	{"RVWA", 4, 255659},
	{"RUMY", 4, 255660},
	{"RRNO", 4, 255661},
	{"RJRE", 4, 255662},
	{"RIEY", 4, 255663},
	{"QIPA", 4, 255664},
	{"PWIC", 4, 255665},
	{"PPEX", 4, 255666},
	{"ONCJ", 4, 255667},
	{"NZEG", 4, 255668},
	{"NUPK", 4, 255669},
	{"NOYW", 4, 255670},
	{"NMEZ", 4, 255671},
	{"NLBS", 4, 255672},
	{"NKHZ", 4, 255673},
	{"NDNZ", 4, 255674},
	{"MXRA", 4, 255675},
	{"MUEH", 4, 255676},
	{"MDOB", 4, 255677},
	{"LUHI", 4, 255678},
	{"LROE", 4, 255679},
	{"LPMW", 4, 255680},
	{"JPHA", 4, 255681},
	{"JINZ", 4, 255682},
	{"JIGE", 4, 255683},
	{"JHOW", 4, 255684},
	{"ISZU", 4, 255685},
	{"IPIW", 4, 255686},
	{"INYJ", 4, 255687},
	{"IKMS", 4, 255688},
	{"HYLM", 4, 255689},
	{"HIKM", 4, 255690},
	{"GYMD", 4, 255691},
	{"GNIW", 4, 255692},
	{"GMUH", 4, 255693},
	{"GMGM", 4, 255694},
	{"FLOZ", 4, 255695},
	{"EKKN", 4, 255696},
	{"EBBM", 4, 255697},
	{"DJMI", 4, 255698},
	{"DDDU", 4, 255699},
	{"CYAV", 4, 255700},
	{"BDRU", 4, 255701},
	{"AWZI", 4, 255702},
	{"ASBM", 4, 255703},
	{"ARHM", 4, 255704},
	{"AQBO", 4, 255705},
	{"SEKUR", 5, 255706},
	{"MASYARAKAT", 10, 255707},
	{"KAZUHISA", 8, 255708},
	{"GASSNER", 7, 255709},
	{"SHRIVENHAM", 10, 255710},
	{"LEISTUNG", 8, 255711},
	{"CCSSO", 5, 255712},
	{"ALYSE", 5, 255713},
	{"WERTE", 5, 255714},
	{"MALEC", 5, 255715},
	{"KARYOTYPES", 10, 255716},
	{"DUERR", 5, 255717},
	{"STREAMIUM", 9, 255718},
	{"ROBOMINATION", 12, 255719},
	{"POUF", 4, 255720},
	{"EXCRETIONS", 10, 255721},
	{"DULCOLAX", 8, 255722},
	{"DIGTIAL", 7, 255723},
	{"CENEX", 5, 255724},
	{"ORRERY", 6, 255725},
	{"BOINCSTATS", 10, 255726},
	{"PRESBY", 6, 255727},
	{"MRAFROHEAD", 10, 255728},
	{"COMPLACENTLY", 12, 255729},
	{"BEABLE", 6, 255730},
	{"MURLEY", 6, 255731},
	{"HARKING", 7, 255732},
	{"GOEMON", 6, 255733},
	{"CRITERA", 7, 255734},
	{"OPENTV", 6, 255735},
	{"TRAEVL", 6, 255736},
	{"GVU", 3, 255737},
	{"CODESIGN", 8, 255738},
	{"BABG", 4, 255739},
	{"KALMYK", 6, 255740},
	{"BUXUS", 5, 255741},
	{"MODELICA", 8, 255742},
	{"IMAGINARYI", 10, 255743},
	{"CORDILLERAN", 11, 255744},
	{"THOMAE", 6, 255745},
	{"NATCA", 5, 255746},
	{"KENDRICKS", 9, 255747},
	{"FLATWORMS", 9, 255748},
	{"MUSEEN", 6, 255749},
	{"INTERSUBJECTIVE", 15, 255750},
	{"BWILD", 5, 255751},
	{"MARMONT", 7, 255752},
	{"BERKSWELL", 9, 255753},
	{"BERGFELD", 8, 255754},
	{"ANATOMISTS", 10, 255755},
	{"WHITESPACES", 11, 255756},
	{"JBOVLASTE", 9, 255757},
	{"PWF", 3, 255758},
	{"MAPMAKING", 9, 255759},
	{"EYEBALLING", 10, 255760},
	{"SCIENTER", 8, 255761},
	{"LNCAP", 5, 255762},
	{"GIANI", 5, 255763},
	{"EROSBLOG", 8, 255764},
	{"SMUSH", 5, 255765},
	{"PICKEN", 6, 255766},
	{"CLIVEDEN", 8, 255767},
	{"ARGASSI", 7, 255768},
	{"SCHOOLBUS", 9, 255769},
	{"GANDOLFO", 8, 255770},
	{"SOFTWWRE", 8, 255771},
	{"BCMSN", 5, 255772},
	{"ROCKERY", 7, 255773},
	{"METROBILITY", 11, 255774},
	{"IPRC", 4, 255775},
	{"GONCHAR", 7, 255776},
	{"EPIDOTE", 7, 255777},
	{"COUNCILPERSON", 13, 255778},
	{"CHOLANGIOCARCINOMA", 18, 255779},
	{"WBAN", 4, 255780},
	{"SXESEIS", 7, 255781},
	{"PRASEODYMIUM", 12, 255782},
	{"OPENNET", 7, 255783},
	{"GNUIFT", 6, 255784},
	{"SLAVIK", 6, 255785},
	{"NEWWINDOW", 9, 255786},
	{"DEMONSTRA", 9, 255787},
	{"SKIMBOARDING", 12, 255788},
	{"PSECT", 5, 255789},
	{"UYUNI", 5, 255790},
	{"MATMOS", 6, 255791},
	{"KEYDETS", 7, 255792},
	{"DEVPTS", 6, 255793},
	{"REQUIERE", 8, 255794},
	{"SAMUELE", 7, 255795},
	{"LEAGUERUGBY", 11, 255796},
	{"JTRS", 4, 255797},
	{"CEYLAN", 6, 255798},
	{"ACCUFLEX", 8, 255799},
	{"SOPHRONIA", 9, 255800},
	{"RUSYN", 5, 255801},
	{"REAGANS", 7, 255802},
	{"DIIVA", 5, 255803},
	{"COZINHA", 7, 255804},
	{"SUPERNANNY", 10, 255805},
	{"PENQUIN", 7, 255806},
	{"ITING", 5, 255807},
	{"DOPPEL", 6, 255808},
	{"VACHERIE", 8, 255809},
	{"QVARIANT", 8, 255810},
	{"GOODLAD", 7, 255811},
	{"CHOOETTE", 8, 255812},
	{"TELOPEA", 7, 255813},
	{"SARAY", 5, 255814},
	{"MOBILEATION", 11, 255815},
	{"LIVEABILITY", 11, 255816},
	{"FLASHMOVE", 9, 255817},
	{"SQUART", 6, 255818},
	{"SNORRI", 6, 255819},
	{"ACRYLITE", 8, 255820},
	{"MOLINEUX", 8, 255821},
	{"MANCINELLI", 10, 255822},
	{"HAKLUYT", 7, 255823},
	{"AUSTROADS", 9, 255824},
	{"VCARDS", 6, 255825},
	{"SPERS", 5, 255826},
	{"SARVODAYA", 9, 255827},
	{"FARMERVILLE", 11, 255828},
	{"FANTIN", 6, 255829},
	{"WATERPARKS", 10, 255830},
	{"UNTARRED", 8, 255831},
	{"LIKELIER", 8, 255832},
	{"APERT", 5, 255833},
	{"CRYSTA", 6, 255834},
	{"AVLIMIL", 7, 255835},
	{"WINTERNATIONALS", 15, 255836},
	{"SEELENLUFT", 10, 255837},
	{"ACDT", 4, 255838},
	{"FUNSCHOOL", 9, 255839},
	{"BRENNTAG", 8, 255840},
	{"BESAME", 6, 255841},
	{"GOERGE", 6, 255842},
	{"ENANTIOMERIC", 12, 255843},
	{"UNTALENTED", 10, 255844},
	{"OSDEV", 5, 255845},
	{"ODONTOGENIC", 11, 255846},
	{"SURIMI", 6, 255847},
	{"HORNIER", 7, 255848},
	{"EXCORIATED", 10, 255849},
	{"DUCREYI", 7, 255850},
	{"CELIK", 5, 255851},
	{"ARTIMM", 6, 255852},
	{"VAMPYRES", 8, 255853},
	{"MOVIEFREE", 9, 255854},
	{"IVING", 5, 255855},
	{"ATALAYA", 7, 255856},
	{"VAGO", 4, 255857},
	{"INFLAMES", 8, 255858},
	{"SKFTWARE", 8, 255859},
	{"KHAZAR", 6, 255860},
	{"GCAT", 4, 255861},
	{"BLOGSEARCH", 10, 255862},
	{"YETISPORTS", 10, 255863},
	{"LOADMOVIE", 9, 255864},
	{"BILEVEL", 7, 255865},
	{"SAGRES", 6, 255866},
	{"PITONS", 6, 255867},
	{"BUSLOAD", 7, 255868},
	{"THIAZOLES", 9, 255869},
	{"HEIJDEN", 7, 255870},
	{"DESIDERIUS", 10, 255871},
	{"SETARIA", 7, 255872},
	{"POKEER", 6, 255873},
	{"PARAMETRICALLY", 14, 255874},
	{"CXD", 3, 255875},
	{"ITWIRE", 6, 255876},
	{"SHARROW", 7, 255877},
	{"DCOR", 4, 255878},
	{"UNMERITED", 9, 255879},
	{"HEDMARK", 7, 255880},
	{"MOUNIR", 6, 255881},
	{"KERSTETTER", 10, 255882},
	{"SCHOENBERGER", 12, 255883},
	{"RSVPAIR", 7, 255884},
	{"PHATE", 5, 255885},
	{"CAMD", 4, 255886},
	{"CAYMUS", 6, 255887},
	{"ZAXWERKS", 8, 255888},
	{"COMMAN", 6, 255889},
	{"PGRP", 4, 255890},
	{"HAGENSBORG", 10, 255891},
	{"WICKSTROM", 9, 255892},
	{"INSUBORDINATE", 13, 255893},
	{"INGLESA", 7, 255894},
	{"WHIPPOORWILL", 12, 255895},
	{"ROSALBA", 7, 255896},
	{"RESPONSABILIZA", 14, 255897},
	{"PROFESIONALS", 12, 255898},
	{"LXIII", 5, 255899},
	{"REESES", 6, 255900},
	{"EBONEY", 6, 255901},
	{"VICIO", 5, 255902},
	{"SYMBIANOS", 9, 255903},
	{"KOSMAN", 6, 255904},
	{"HOURIGAN", 8, 255905},
	{"FEUX", 4, 255906},
	{"KEITARO", 7, 255907},
	{"TOPLINKS", 8, 255908},
	{"STEPLESS", 8, 255909},
	{"TIMBUK", 6, 255910},
	{"PARAMTER", 8, 255911},
	{"OZONATION", 9, 255912},
	{"AGAINT", 6, 255913},
	{"TORRENTPORTAL", 13, 255914},
	{"THALLUS", 7, 255915},
	{"OVERRIPE", 8, 255916},
	{"KATANNING", 9, 255917},
	{"CARBAJAL", 8, 255918},
	{"ANIMERICA", 9, 255919},
	{"HOLLERITH", 9, 255920},
	{"FUSCE", 5, 255921},
	{"DUFTY", 5, 255922},
	{"CESARI", 6, 255923},
	{"SOMATROPIN", 10, 255924},
	{"CHORISTER", 9, 255925},
	{"HAGENS", 6, 255926},
	{"PLEWS", 5, 255927},
	{"INDUC", 5, 255928},
	{"LEPIDOPTERAN", 12, 255929},
	{"JARDINIERE", 10, 255930},
	{"HYBORIAN", 8, 255931},
	{"CARBAMOYLTRANSFERASE", 20, 255932},
	{"WRITERLY", 8, 255933},
	{"PHLS", 4, 255934},
	{"INTERPRETATIONBOX", 17, 255935},
	{"INNOVENTIONS", 12, 255936},
	{"VPAP", 4, 255937},
	{"KAYU", 4, 255938},
	{"BRINDABELLA", 11, 255939},
	{"WINED", 5, 255940},
	{"PICCOLOS", 8, 255941},
	{"HANDE", 5, 255942},
	{"ASSUAGED", 8, 255943},
	{"MICROONDE", 9, 255944},
	{"IMMUNOSUPPRESSANT", 17, 255945},
	{"BRENAU", 6, 255946},
	{"BLOGEASY", 8, 255947},
	{"WORKSTREAM", 10, 255948},
	{"PAGENEXT", 8, 255949},
	{"NAKSHATRA", 9, 255950},
	{"KREGEL", 6, 255951},
	{"EXOTISCH", 8, 255952},
	{"CGFNS", 5, 255953},
	{"ANNELISE", 8, 255954},
	{"WWWYAHOOCOM", 11, 255955},
	{"LUOYANYI", 8, 255956},
	{"LOANA", 5, 255957},
	{"YCHYDIG", 7, 255958},
	{"PASCHKE", 7, 255959},
	{"ADEILADAU", 9, 255960},
	{"MELANI", 6, 255961},
	{"DUPUYTREN", 9, 255962},
	{"NONPRODUCTIVE", 13, 255963},
	{"DUKEDOM", 7, 255964},
	{"DOWITCHER", 9, 255965},
	{"TOOKER", 6, 255966},
	{"TDWI", 4, 255967},
	{"PASSERINE", 9, 255968},
	{"BERGESON", 8, 255969},
	{"AFSHIN", 6, 255970},
	{"HUANGPU", 7, 255971},
	{"FREELARRY", 9, 255972},
	{"OCPA", 4, 255973},
	{"JARKEY", 6, 255974},
	{"HYDROLYZE", 9, 255975},
	{"ZRAP", 4, 255976},
	{"ZAIL", 4, 255977},
	{"YYON", 4, 255978},
	{"YTVM", 4, 255979},
	{"YSRD", 4, 255980},
	{"YRAO", 4, 255981},
	{"YAUX", 4, 255982},
	{"XSKI", 4, 255983},
	{"WXME", 4, 255984},
	{"WIID", 4, 255985},
	{"VEZP", 4, 255986},
	{"VEDZ", 4, 255987},
	{"UXCH", 4, 255988},
	{"UXAP", 4, 255989},
	{"UUTU", 4, 255990},
	{"TSYF", 4, 255991},
	{"TFAG", 4, 255992},
	{"TCUF", 4, 255993},
	{"TCFI", 4, 255994},
	{"SSDW", 4, 255995},
	{"SNGU", 4, 255996},
	{"RTVB", 4, 255997},
	{"RTDY", 4, 255998},
	{"QLAN", 4, 255999},
	{"OZYO", 4, 256000},
	{"OZUR", 4, 256001},
	{"OWYP", 4, 256002},
	{"OUKU", 4, 256003},
	{"OMUB", 4, 256004},
	{"OMHP", 4, 256005},
	{"ODMC", 4, 256006},
	{"NZWO", 4, 256007},
	{"NTMM", 4, 256008},
	{"NPWA", 4, 256009},
	{"MOMK", 4, 256010},
	{"MEZR", 4, 256011},
	{"MDAF", 4, 256012},
	{"LYUD", 4, 256013},
	{"LRHA", 4, 256014},
	{"LNOG", 4, 256015},
	{"LFSD", 4, 256016},
	{"LEUX", 4, 256017},
	{"LBEZ", 4, 256018},
	{"LBAE", 4, 256019},
	{"KYIE", 4, 256020},
	{"KMPA", 4, 256021},
	{"KEEZ", 4, 256022},
	{"JSWH", 4, 256023},
	{"JAIV", 4, 256024},
	{"IZZR", 4, 256025},
	{"IZEQ", 4, 256026},
	{"HYRC", 4, 256027},
	{"HMRD", 4, 256028},
	{"HDRD", 4, 256029},
	{"HCAG", 4, 256030},
	{"GPYR", 4, 256031},
	{"GKAK", 4, 256032},
	{"GJUG", 4, 256033},
	{"GIBN", 4, 256034},
	{"FSJO", 4, 256035},
	{"FDAB", 4, 256036},
	{"FCIL", 4, 256037},
	{"EZGI", 4, 256038},
	{"ERWN", 4, 256039},
	{"EPVC", 4, 256040},
	{"EKYT", 4, 256041},
	{"EDNM", 4, 256042},
	{"EABM", 4, 256043},
	{"DRDT", 4, 256044},
	{"DMEV", 4, 256045},
	{"DIPW", 4, 256046},
	{"DILH", 4, 256047},
	{"DBTW", 4, 256048},
	{"CWEH", 4, 256049},
	{"CRTI", 4, 256050},
	{"COYP", 4, 256051},
	{"CLYK", 4, 256052},
	{"CISZ", 4, 256053},
	{"CASQ", 4, 256054},
	{"BYXI", 4, 256055},
	{"BYCP", 4, 256056},
	{"BIZC", 4, 256057},
	{"BILW", 4, 256058},
	{"AQAP", 4, 256059},
	{"ANPD", 4, 256060},
	{"AERM", 4, 256061},
	{"ZARE", 4, 256062},
	{"YEMASSEE", 8, 256063},
	{"NAPOSIM", 7, 256064},
	{"GEMMILL", 7, 256065},
	{"GAMEWINNERS", 11, 256066},
	{"DECODABLE", 9, 256067},
	{"CMETH", 5, 256068},
	{"FOBT", 4, 256069},
	{"BIOFORUM", 8, 256070},
	{"ALAMODOME", 9, 256071},
	{"LIVESETS", 8, 256072},
	{"IRONWORKER", 10, 256073},
	{"DIRECTIONLESS", 13, 256074},
	{"CRUSING", 7, 256075},
	{"TIEDOWNS", 8, 256076},
	{"EFFACE", 6, 256077},
	{"ANTEROGRADE", 11, 256078},
	{"YEVAUD", 6, 256079},
	{"HYPERVENTILATING", 16, 256080},
	{"HEMOPOIETIC", 11, 256081},
	{"ASIAROOMS", 9, 256082},
	{"TUCS", 4, 256083},
	{"IFFR", 4, 256084},
	{"VATICANA", 8, 256085},
	{"VARER", 5, 256086},
	{"JWOD", 4, 256087},
	{"CHIMBORAZO", 10, 256088},
	{"PARECON", 7, 256089},
	{"DOLLIS", 6, 256090},
	{"WIMPOLE", 7, 256091},
	{"PRACE", 5, 256092},
	{"OBERAMMERGAU", 12, 256093},
	{"YANGJIANG", 9, 256094},
	{"ILGILI", 6, 256095},
	{"LITERATUUR", 10, 256096},
	{"FIXINC", 6, 256097},
	{"FURIOSO", 7, 256098},
	{"YAHPP", 5, 256099},
	{"VISEU", 5, 256100},
	{"SADOWSKY", 8, 256101},
	{"OLALLA", 6, 256102},
	{"NATSUMI", 7, 256103},
	{"LASTRA", 6, 256104},
	{"BEERBOHM", 8, 256105},
	{"VEGARD", 6, 256106},
	{"TIRMIDHI", 8, 256107},
	{"SPERMAMAX", 9, 256108},
	{"OPENESS", 7, 256109},
	{"ELGORT", 6, 256110},
	{"APOSTILLE", 9, 256111},
	{"TRANSFECTANTS", 13, 256112},
	{"SEYYED", 6, 256113},
	{"IMAGEMAPS", 9, 256114},
	{"IDLERIOT", 8, 256115},
	{"GRAVETTE", 8, 256116},
	{"DATASTRUCTURE", 13, 256117},
	{"TAURO", 5, 256118},
	{"RECCOMENDATION", 14, 256119},
	{"CRUETS", 6, 256120},
	{"MEDISCHE", 8, 256121},
	{"OTOME", 5, 256122},
	{"TDMONTHLY", 9, 256123},
	{"LKW", 3, 256124},
	{"CASSHERN", 8, 256125},
	{"AUTOMATICAMENTE", 15, 256126},
	{"REGRUN", 6, 256127},
	{"HEYBURN", 7, 256128},
	{"DFPS", 4, 256129},
	{"DATENTECHNIK", 12, 256130},
	{"PWEDE", 5, 256131},
	{"KERENSKY", 8, 256132},
	{"HATTED", 6, 256133},
	{"VEZINA", 6, 256134},
	{"TWOHY", 5, 256135},
	{"WIZZY", 5, 256136},
	{"TUBULARS", 8, 256137},
	{"RISHIS", 6, 256138},
	{"SOFTAARE", 8, 256139},
	{"BUFFLEHEAD", 10, 256140},
	{"DIWYLLIANT", 10, 256141},
	{"DAZZLINGLY", 10, 256142},
	{"ALLGAME", 7, 256143},
	{"SAISIE", 6, 256144},
	{"NISHANT", 7, 256145},
	{"MANANGEMENT", 11, 256146},
	{"LANDOW", 6, 256147},
	{"RESCATE", 7, 256148},
	{"MENDELEEV", 9, 256149},
	{"SNEEZY", 6, 256150},
	{"LIESE", 5, 256151},
	{"KUND", 4, 256152},
	{"FUNNYMAN", 8, 256153},
	{"TIELENS", 7, 256154},
	{"THINKOUTSIDE", 12, 256155},
	{"LUNY", 4, 256156},
	{"HABANERA", 8, 256157},
	{"DRESNER", 7, 256158},
	{"DMAKE", 5, 256159},
	{"SAVEPOINT", 9, 256160},
	{"KRUNK", 5, 256161},
	{"ETHERLORDS", 10, 256162},
	{"ESCOS", 5, 256163},
	{"ENGRAINED", 9, 256164},
	{"CHRISTABELLE", 12, 256165},
	{"REDU", 4, 256166},
	{"PEINTRE", 7, 256167},
	{"HORTICULTURISTS", 15, 256168},
	{"GMETAD", 6, 256169},
	{"FEFC", 4, 256170},
	{"WOUK", 4, 256171},
	{"NEWKIDCO", 8, 256172},
	{"MINAMOTO", 8, 256173},
	{"STEIGIES", 8, 256174},
	{"OSUG", 4, 256175},
	{"MUNHALL", 7, 256176},
	{"FURNITUR", 8, 256177},
	{"SOCKPUPPET", 10, 256178},
	{"PATWARDHAN", 10, 256179},
	{"CROSSNET", 8, 256180},
	{"BIANI", 5, 256181},
	{"TESTINO", 7, 256182},
	{"RUSHBY", 6, 256183},
	{"LISTPROC", 8, 256184},
	{"GARABEDIAN", 10, 256185},
	{"PASWORDS", 8, 256186},
	{"DQL", 3, 256187},
	{"PUSHMATAHA", 10, 256188},
	{"POMATON", 7, 256189},
	{"HPRT", 4, 256190},
	{"HKUVPN", 6, 256191},
	{"TICKTS", 6, 256192},
	{"JIBRIL", 6, 256193},
	{"SORTATION", 9, 256194},
	{"OTOSCLEROSIS", 12, 256195},
	{"WILLOWTIP", 9, 256196},
	{"TENSER", 6, 256197},
	{"DAMICO", 6, 256198},
	{"VANITA", 6, 256199},
	{"DEPORTABLE", 10, 256200},
	{"XYX", 3, 256201},
	{"NSNUMBER", 8, 256202},
	{"GILLISPIE", 9, 256203},
	{"BRIEUC", 6, 256204},
	{"MACUTILS", 8, 256205},
	{"LOOKETH", 7, 256206},
	{"FELIU", 5, 256207},
	{"WAKU", 4, 256208},
	{"GREYTOWN", 8, 256209},
	{"BLEAKNESS", 9, 256210},
	{"KAVERY", 6, 256211},
	{"TWINKLES", 8, 256212},
	{"SWAROOP", 7, 256213},
	{"RHIND", 5, 256214},
	{"HYPERGLYCAEMIA", 14, 256215},
	{"FLAILS", 6, 256216},
	{"ARNES", 5, 256217},
	{"TRKATTRIBS", 10, 256218},
	{"DIFFERENTIATIONS", 16, 256219},
	{"AEREE", 5, 256220},
	{"PIOCHE", 6, 256221},
	{"LAUCK", 5, 256222},
	{"PRAIRE", 6, 256223},
	{"DUPLAIX", 7, 256224},
	{"TEXASONLINE", 11, 256225},
	{"RJF", 3, 256226},
	{"JOBX", 4, 256227},
	{"AFPL", 4, 256228},
	{"RETROTRANSPOSON", 15, 256229},
	{"PRENTON", 7, 256230},
	{"NANCARROW", 9, 256231},
	{"LYRES", 5, 256232},
	{"DSDM", 4, 256233},
	{"WEBZINES", 8, 256234},
	{"MANAGINGTOPICS", 14, 256235},
	{"WATERBIRTH", 10, 256236},
	{"IMPLEMENTION", 12, 256237},
	{"DULLS", 5, 256238},
	{"STABROEK", 8, 256239},
	{"SALETAN", 7, 256240},
	{"ORIGINALISM", 11, 256241},
	{"KILKELLY", 8, 256242},
	{"SHINTOISM", 9, 256243},
	{"ERIDANI", 7, 256244},
	{"WHALEBONE", 9, 256245},
	{"NUDR", 4, 256246},
	{"ORELAND", 7, 256247},
	{"PALEOGENE", 9, 256248},
	{"EPOXIDES", 8, 256249},
	{"APPUNTI", 7, 256250},
	{"TURBONET", 8, 256251},
	{"SLIGHLY", 7, 256252},
	{"SICC", 4, 256253},
	{"RODER", 5, 256254},
	{"NAYSMITH", 8, 256255},
	{"LASSILA", 7, 256256},
	{"GEEKPRESS", 9, 256257},
	{"GARCI", 5, 256258},
	{"TALAN", 5, 256259},
	{"PINETREE", 8, 256260},
	{"ITSHARESA", 9, 256261},
	{"JWANG", 5, 256262},
	{"INSUANCE", 8, 256263},
	{"XANANA", 6, 256264},
	{"CONVERTIDOR", 11, 256265},
	{"NIPP", 4, 256266},
	{"TONECLUSTER", 11, 256267},
	{"PIND", 4, 256268},
	{"WEBDATE", 7, 256269},
	{"GNOMIE", 6, 256270},
	{"ADERHOLT", 8, 256271},
	{"THIMBLEBERRIES", 14, 256272},
	{"COMPANYWIDE", 11, 256273},
	{"BODYTRENDS", 10, 256274},
	{"FURIO", 5, 256275},
	{"MONOPSONY", 9, 256276},
	{"KILINOCHCHI", 11, 256277},
	{"DVDCLONER", 9, 256278},
	{"ERDAL", 5, 256279},
	{"PROSAMPLES", 10, 256280},
	{"FEISTHAMMEL", 11, 256281},
	{"PROTISTA", 8, 256282},
	{"ASDM", 4, 256283},
	{"ALUMINATE", 9, 256284},
	{"AINGER", 6, 256285},
	{"RTAVEL", 6, 256286},
	{"AUSM", 4, 256287},
	{"PRESLAV", 7, 256288},
	{"POGS", 4, 256289},
	{"HERPETOLOGISTS", 14, 256290},
	{"COMLEY", 6, 256291},
	{"ALLYLIC", 7, 256292},
	{"MAKEDONSKI", 10, 256293},
	{"MARGARETHE", 10, 256294},
	{"ZARIA", 5, 256295},
	{"MINUTEST", 8, 256296},
	{"MANZOOR", 7, 256297},
	{"INFRASTRUXURE", 13, 256298},
	{"INCET", 5, 256299},
	{"CDEV", 4, 256300},
	{"ALGAS", 5, 256301},
	{"SERMONAUDIO", 11, 256302},
	{"ELEISON", 7, 256303},
	{"SZELL", 5, 256304},
	{"RETROSPECTION", 13, 256305},
	{"HIMACHALPRADESH", 15, 256306},
	{"EVGENIY", 7, 256307},
	{"UNGOVERNABLE", 12, 256308},
	{"ACHITECTURE", 11, 256309},
	{"RASCHKE", 7, 256310},
	{"MUSOLIST", 8, 256311},
	{"XULRUNNER", 9, 256312},
	{"FIXATIVES", 9, 256313},
	{"CHOGM", 5, 256314},
	{"WHTIE", 5, 256315},
	{"HARPOONS", 8, 256316},
	{"BURNETTES", 9, 256317},
	{"BROWNRIGG", 9, 256318},
	{"BATWING", 7, 256319},
	{"PROCARDIA", 9, 256320},
	{"MOGILNY", 7, 256321},
	{"SAWTELLE", 8, 256322},
	{"LIBAST", 6, 256323},
	{"ILOVEYOU", 8, 256324},
	{"CARTALKCANADA", 13, 256325},
	{"ZWRI", 4, 256326},
	{"ZOFP", 4, 256327},
	{"ZMOT", 4, 256328},
	{"ZHOP", 4, 256329},
	{"YPGA", 4, 256330},
	{"YMSB", 4, 256331},
	{"XRSQ", 4, 256332},
	{"WUNR", 4, 256333},
	{"WRYH", 4, 256334},
	{"WPAK", 4, 256335},
	{"WOWP", 4, 256336},
	{"WJEA", 4, 256337},
	{"VFWA", 4, 256338},
	{"UTZC", 4, 256339},
	{"UTNB", 4, 256340},
	{"UEXJ", 4, 256341},
	{"TYSZ", 4, 256342},
	{"TUBF", 4, 256343},
	{"TPCB", 4, 256344},
	{"TKUW", 4, 256345},
	{"THJP", 4, 256346},
	{"SUUN", 4, 256347},
	{"SUEX", 4, 256348},
	{"SRDP", 4, 256349},
	{"SMML", 4, 256350},
	{"ROVD", 4, 256351},
	{"RDIY", 4, 256352},
	{"PRUG", 4, 256353},
	{"PHHU", 4, 256354},
	{"OTCY", 4, 256355},
	{"ORUZ", 4, 256356},
	{"ORNZ", 4, 256357},
	{"OMTC", 4, 256358},
	{"OBZO", 4, 256359},
	{"OBBD", 4, 256360},
	{"NUCS", 4, 256361},
	{"NGUV", 4, 256362},
	{"NCRT", 4, 256363},
	{"MTHW", 4, 256364},
	{"MSDY", 4, 256365},
	{"MMBR", 4, 256366},
	{"MKOM", 4, 256367},
	{"LOPV", 4, 256368},
	{"LJEL", 4, 256369},
	{"LCNN", 4, 256370},
	{"KKOA", 4, 256371},
	{"KGHA", 4, 256372},
	{"JVTE", 4, 256373},
	{"JPAU", 4, 256374},
	{"JNIC", 4, 256375},
	{"JIKS", 4, 256376},
	{"INMW", 4, 256377},
	{"IEBM", 4, 256378},
	{"HLUP", 4, 256379},
	{"HECX", 4, 256380},
	{"GUKS", 4, 256381},
	{"GTCL", 4, 256382},
	{"FEOB", 4, 256383},
	{"EZKN", 4, 256384},
	{"EVSG", 4, 256385},
	{"EKHR", 4, 256386},
	{"EDHL", 4, 256387},
	{"DDVO", 4, 256388},
	{"CKHY", 4, 256389},
	{"CKEU", 4, 256390},
	{"BKEV", 4, 256391},
	{"BACN", 4, 256392},
	{"AMUJ", 4, 256393},
	{"AKOZ", 4, 256394},
	{"VALLHUND", 8, 256395},
	{"PROTOPORPHYRIN", 14, 256396},
	{"PETRON", 6, 256397},
	{"KREN", 4, 256398},
	{"JUVIO", 5, 256399},
	{"DOWNLOADFREE", 12, 256400},
	{"TARGETSEARCH", 12, 256401},
	{"DARDIS", 6, 256402},
	{"AVERNUS", 7, 256403},
	{"CONSILIUM", 9, 256404},
	{"LADENS", 6, 256405},
	{"COMINS", 6, 256406},
	{"JARVIE", 6, 256407},
	{"RLB", 3, 256408},
	{"EARECKSON", 9, 256409},
	{"DINKS", 5, 256410},
	{"WWWTHEHUN", 9, 256411},
	{"MOVERMIKE", 9, 256412},
	{"METZENBAUM", 10, 256413},
	{"GLORIOSA", 8, 256414},
	{"DISTRIBUIDORES", 14, 256415},
	{"CYBERCHAT", 9, 256416},
	{"BARBUS", 6, 256417},
	{"WELLNIGH", 8, 256418},
	{"RECRYSTALLIZED", 14, 256419},
	{"COKATO", 6, 256420},
	{"MEUBLE", 6, 256421},
	{"MAILMERGE", 9, 256422},
	{"CAUTERIZING", 11, 256423},
	{"AXID", 4, 256424},
	{"TILERS", 6, 256425},
	{"SPATIALE", 8, 256426},
	{"MODERNBILL", 10, 256427},
	{"HPMS", 4, 256428},
	{"EIGENSCHAPPEN", 13, 256429},
	{"YAOOO", 5, 256430},
	{"UNRECOVERED", 11, 256431},
	{"FOTOGRAF", 8, 256432},
	{"CDRP", 4, 256433},
	{"WRISTOP", 7, 256434},
	{"RICKETT", 7, 256435},
	{"INTOSH", 6, 256436},
	{"ZANON", 5, 256437},
	{"INTERACTIVO", 11, 256438},
	{"HOBBIEST", 8, 256439},
	{"CRAGGS", 6, 256440},
	{"COSIDA", 6, 256441},
	{"OBILE", 5, 256442},
	{"FURNATURE", 9, 256443},
	{"MEDIVAL", 7, 256444},
	{"MFCC", 4, 256445},
	{"MARGT", 5, 256446},
	{"WMNF", 4, 256447},
	{"UNMISTAKEABLE", 13, 256448},
	{"PONTRESINA", 10, 256449},
	{"TADSCH", 6, 256450},
	{"GRIGOR", 6, 256451},
	{"ARDI", 4, 256452},
	{"SIFICATION", 10, 256453},
	{"DRUGREPORTER", 12, 256454},
	{"BARTHELME", 9, 256455},
	{"WITTILY", 7, 256456},
	{"JESSYE", 6, 256457},
	{"AIRPARKS", 8, 256458},
	{"NOAHMEYERHANS", 13, 256459},
	{"HYDROMETERS", 11, 256460},
	{"CHATELET", 8, 256461},
	{"ALOAD", 5, 256462},
	{"RINGBOUND", 9, 256463},
	{"SHUBIN", 6, 256464},
	{"SAGERS", 6, 256465},
	{"HKME", 4, 256466},
	{"BOGOSIAN", 8, 256467},
	{"ECLECTION", 9, 256468},
	{"BRETHERTON", 10, 256469},
	{"VODOU", 5, 256470},
	{"TIRASPOL", 8, 256471},
	{"SCHMERZ", 7, 256472},
	{"FIZIOL", 6, 256473},
	{"DFU", 3, 256474},
	{"CASUALWEAR", 10, 256475},
	{"FRANKENBERG", 11, 256476},
	{"DOLGEVILLE", 10, 256477},
	{"ANPRM", 5, 256478},
	{"IMPOSTOS", 8, 256479},
	{"WOODVALE", 8, 256480},
	{"TECHNASIA", 9, 256481},
	{"SOAPING", 7, 256482},
	{"MINIDVD", 7, 256483},
	{"CARREZ", 6, 256484},
	{"PROCEEDURES", 11, 256485},
	{"FRANCISELLA", 11, 256486},
	{"CALIBRATES", 10, 256487},
	{"BECKENBAUER", 11, 256488},
	{"ULITSA", 6, 256489},
	{"CALZADA", 7, 256490},
	{"HURTIG", 6, 256491},
	{"AUTOMATIQUEMENT", 15, 256492},
	{"NABY", 4, 256493},
	{"IMMEDIATLEY", 11, 256494},
	{"HELLCATS", 8, 256495},
	{"NEWTOPICBGCOLOR", 15, 256496},
	{"FOOLERY", 7, 256497},
	{"CLAYDERMAN", 10, 256498},
	{"XAVIX", 5, 256499},
	{"FASTEXT", 7, 256500},
	{"EXULTING", 8, 256501},
	{"UITGEVERS", 9, 256502},
	{"TSUZUKI", 7, 256503},
	{"SHREWDER", 8, 256504},
	{"RHYTHMYX", 8, 256505},
	{"MRKT", 4, 256506},
	{"WMAQ", 4, 256507},
	{"QUALIFIEDNAME", 13, 256508},
	{"HULTGREN", 8, 256509},
	{"ANALIZA", 7, 256510},
	{"MOISI", 5, 256511},
	{"INVDESCRIPT", 11, 256512},
	{"GERDAU", 6, 256513},
	{"XPB", 3, 256514},
	{"PROCESSEVENT", 12, 256515},
	{"AIRER", 5, 256516},
	{"AKITAS", 6, 256517},
	{"TELIGENT", 8, 256518},
	{"KAMMEN", 6, 256519},
	{"FIGLI", 5, 256520},
	{"BRODART", 7, 256521},
	{"COINTEGRATED", 12, 256522},
	{"BIOCHIPS", 8, 256523},
	{"RUBRICA", 7, 256524},
	{"PSYCHOTROPICS", 13, 256525},
	{"ARTSAKH", 7, 256526},
	{"MIFF", 4, 256527},
	{"MARLINTON", 9, 256528},
	{"EFINITION", 9, 256529},
	{"EBBY", 4, 256530},
	{"BEHRMANN", 8, 256531},
	{"JAYCE", 5, 256532},
	{"ERBITUX", 7, 256533},
	{"SHIMER", 6, 256534},
	{"FRANZUS", 7, 256535},
	{"TVECTOR", 7, 256536},
	{"QUERIDA", 7, 256537},
	{"PROFESSORIATE", 13, 256538},
	{"NAZAROV", 7, 256539},
	{"SUMMANDS", 8, 256540},
	{"RECIEPS", 7, 256541},
	{"PTHRP", 5, 256542},
	{"ARKANGEL", 8, 256543},
	{"ANDROPOGON", 10, 256544},
	{"WATASE", 6, 256545},
	{"FRIGORIFERO", 11, 256546},
	{"CORRIES", 7, 256547},
	{"CERTEGY", 7, 256548},
	{"VOLKMAN", 7, 256549},
	{"TRAVEK", 6, 256550},
	{"NOESY", 5, 256551},
	{"BBAY", 4, 256552},
	{"UBM", 3, 256553},
	{"CURPS", 5, 256554},
	{"CTSIM", 5, 256555},
	{"YAHOOMAILCOM", 12, 256556},
	{"RUTZ", 4, 256557},
	{"KIRKLEY", 7, 256558},
	{"DEEPNESS", 8, 256559},
	{"FACILIT", 7, 256560},
	{"DUNCHURCH", 9, 256561},
	{"ARCAST", 6, 256562},
	{"INTERNI", 7, 256563},
	{"CAPRYLIC", 8, 256564},
	{"WISK", 4, 256565},
	{"TURBOCACHE", 10, 256566},
	{"ROPEWALK", 8, 256567},
	{"PROPAGATIONS", 12, 256568},
	{"CAROTOVORA", 10, 256569},
	{"CORNERBACKS", 11, 256570},
	{"TEAWARE", 7, 256571},
	{"CULIACAN", 8, 256572},
	{"AMBROS", 6, 256573},
	{"DEJAVIEW", 8, 256574},
	{"MHTML", 5, 256575},
	{"HOVEDSIDE", 9, 256576},
	{"GRAYER", 6, 256577},
	{"OTTERTAIL", 9, 256578},
	{"BUSINESSPUNDIT", 14, 256579},
	{"HELGELAND", 9, 256580},
	{"MOTUL", 5, 256581},
	{"HABITANT", 8, 256582},
	{"BLOGSHEROES", 11, 256583},
	{"SKAKEL", 6, 256584},
	{"NEWSELINELEM", 12, 256585},
	{"FLEMINGSBURG", 12, 256586},
	{"CROSSCOURT", 10, 256587},
	{"BRABAZON", 8, 256588},
	{"UCED", 4, 256589},
	{"CRANED", 6, 256590},
	{"COPT", 4, 256591},
	{"TOSHIYA", 7, 256592},
	{"PSEUDOMEMBRANOUS", 16, 256593},
	{"OPPENHEIMERFUNDS", 16, 256594},
	{"CHERRYVALE", 10, 256595},
	{"BOCCI", 5, 256596},
	{"DVDIT", 5, 256597},
	{"BEDSORES", 8, 256598},
	{"SETCMYKCOLOR", 12, 256599},
	{"KECIL", 5, 256600},
	{"VBL", 3, 256601},
	{"SPITTOON", 8, 256602},
	{"NETCON", 6, 256603},
	{"JUNIN", 5, 256604},
	{"EMPIDONAX", 9, 256605},
	{"BREADALBANE", 11, 256606},
	{"BLORT", 5, 256607},
	{"WIELKANOC", 9, 256608},
	{"PICANTO", 7, 256609},
	{"NELLCOR", 7, 256610},
	{"VANQUISHING", 11, 256611},
	{"TECHNOLEG", 9, 256612},
	{"SCRIVENS", 8, 256613},
	{"ENGNE", 5, 256614},
	{"DEFINICION", 10, 256615},
	{"COVERKING", 9, 256616},
	{"FINET", 5, 256617},
	{"GANAPATHY", 9, 256618},
	{"DOWNSWING", 9, 256619},
	{"ALERTCREATE", 11, 256620},
	{"AFILIADOS", 9, 256621},
	{"RESEMBLENCE", 11, 256622},
	{"KLEBANOV", 8, 256623},
	{"KLB", 3, 256624},
	{"IMRF", 4, 256625},
	{"SPECSHEET", 9, 256626},
	{"SISTED", 6, 256627},
	{"RUANO", 5, 256628},
	{"CONTRY", 6, 256629},
	{"BOSENTAN", 8, 256630},
	{"CROSSGRADE", 10, 256631},
	{"BRITTHAVEN", 10, 256632},
	{"HTIBS", 5, 256633},
	{"FRSH", 4, 256634},
	{"COTHRAN", 7, 256635},
	{"SEITAN", 6, 256636},
	{"LTCI", 4, 256637},
	{"JIDDAH", 6, 256638},
	{"INCOMPETENTS", 12, 256639},
	{"ADSORBER", 8, 256640},
	{"SADDLING", 8, 256641},
	{"ROSADA", 6, 256642},
	{"NERNST", 6, 256643},
	{"MIVIES", 6, 256644},
	{"KIRIM", 5, 256645},
	{"CONSTRUIR", 9, 256646},
	{"ZUPPA", 5, 256647},
	{"SCIAM", 5, 256648},
	{"DELVAUX", 7, 256649},
	{"BORTZMEYER", 10, 256650},
	{"ZUMU", 4, 256651},
	{"ZEAV", 4, 256652},
	{"YUWI", 4, 256653},
	{"YROK", 4, 256654},
	{"YDSW", 4, 256655},
	{"YDSR", 4, 256656},
	{"YDOJ", 4, 256657},
	{"XBLU", 4, 256658},
	{"WEYH", 4, 256659},
	{"VOFE", 4, 256660},
	{"VEOM", 4, 256661},
	{"VCCO", 4, 256662},
	{"UVON", 4, 256663},
	{"UPYM", 4, 256664},
	{"UPEG", 4, 256665},
	{"UDDD", 4, 256666},
	{"SHYY", 4, 256667},
	{"SFTF", 4, 256668},
	{"SFFA", 4, 256669},
	{"SEJR", 4, 256670},
	{"SAYQ", 4, 256671},
	{"RUIL", 4, 256672},
	{"RTUK", 4, 256673},
	{"RPPU", 4, 256674},
	{"RLHU", 4, 256675},
	{"RCYK", 4, 256676},
	{"PYIM", 4, 256677},
	{"PNOD", 4, 256678},
	{"PGSE", 4, 256679},
	{"ONXX", 4, 256680},
	{"OMRN", 4, 256681},
	{"OGKE", 4, 256682},
	{"NTZR", 4, 256683},
	{"NOMF", 4, 256684},
	{"MSLY", 4, 256685},
	{"MRYU", 4, 256686},
	{"MOOB", 4, 256687},
	{"MNSD", 4, 256688},
	{"MMCE", 4, 256689},
	{"LVOB", 4, 256690},
	{"LTDG", 4, 256691},
	{"LMFU", 4, 256692},
	{"LIZR", 4, 256693},
	{"LIAZ", 4, 256694},
	{"LCPA", 4, 256695},
	{"KYIA", 4, 256696},
	{"KGAY", 4, 256697},
	{"JOPP", 4, 256698},
	{"IDFC", 4, 256699},
	{"IAKL", 4, 256700},
	{"GUIF", 4, 256701},
	{"GHZC", 4, 256702},
	{"FSOG", 4, 256703},
	{"FKUT", 4, 256704},
	{"FABH", 4, 256705},
	{"EZVA", 4, 256706},
	{"ERGQ", 4, 256707},
	{"DNCH", 4, 256708},
	{"DEYI", 4, 256709},
	{"DAJD", 4, 256710},
	{"DAGD", 4, 256711},
	{"CWEW", 4, 256712},
	{"CVOY", 4, 256713},
	{"CUWE", 4, 256714},
	{"CTIU", 4, 256715},
	{"BTIL", 4, 256716},
	{"BTDU", 4, 256717},
	{"AQDI", 4, 256718},
	{"AOCL", 4, 256719},
	{"AFEJ", 4, 256720},
	{"URSIN", 5, 256721},
	{"TRUSTUDIO", 9, 256722},
	{"VIDEOPHONES", 11, 256723},
	{"SERVERWATCH", 11, 256724},
	{"FALT", 4, 256725},
	{"YAHLL", 5, 256726},
	{"ERSYS", 5, 256727},
	{"TELEFONY", 8, 256728},
	{"THEGUESTBOOK", 12, 256729},
	{"SMARTSCAN", 9, 256730},
	{"MAGOITO", 7, 256731},
	{"LIMULUS", 7, 256732},
	{"FILESOUP", 8, 256733},
	{"WEATHERLINK", 11, 256734},
	{"SVEC", 4, 256735},
	{"NETCONG", 7, 256736},
	{"IMPROMPTUS", 10, 256737},
	{"ACYLTRANSFERASES", 16, 256738},
	{"AAMAS", 5, 256739},
	{"SONAM", 5, 256740},
	{"PACHUCA", 7, 256741},
	{"DREADZONE", 9, 256742},
	{"TAKESHITA", 9, 256743},
	{"SHOWHD", 6, 256744},
	{"SERJ", 4, 256745},
	{"MEOWS", 5, 256746},
	{"GROOTHANDEL", 11, 256747},
	{"INSERTITEM", 10, 256748},
	{"FAUSTIN", 7, 256749},
	{"DARST", 5, 256750},
	{"QUOCIRCA", 8, 256751},
	{"NAGIE", 5, 256752},
	{"MILLAS", 6, 256753},
	{"ENNOBLED", 8, 256754},
	{"PATROLLERS", 10, 256755},
	{"KYNG", 4, 256756},
	{"ROCKVALE", 8, 256757},
	{"TIRUMALA", 8, 256758},
	{"EPISCOPACY", 10, 256759},
	{"CFIT", 4, 256760},
	{"CAVU", 4, 256761},
	{"BOHAI", 5, 256762},
	{"ALEXX", 5, 256763},
	{"WATERLOW", 8, 256764},
	{"TANAGERS", 8, 256765},
	{"SHULCHAN", 8, 256766},
	{"SEPTENTRIONALIS", 15, 256767},
	{"TOROKHOV", 8, 256768},
	{"GETAMPED", 8, 256769},
	{"PROFUNDO", 8, 256770},
	{"PANTEGO", 7, 256771},
	{"EISENBEIS", 9, 256772},
	{"UNIQLO", 6, 256773},
	{"SREBP", 5, 256774},
	{"BOYO", 4, 256775},
	{"BACKGROUD", 9, 256776},
	{"WISLA", 5, 256777},
	{"SRRD", 4, 256778},
	{"QUASIMOTO", 9, 256779},
	{"UNCODIFIED", 10, 256780},
	{"MATTAWAN", 8, 256781},
	{"PHYLLOXERA", 10, 256782},
	{"OCCIPUT", 7, 256783},
	{"HANYU", 5, 256784},
	{"HALAKHA", 7, 256785},
	{"FLESHER", 7, 256786},
	{"DREAMWAVER", 10, 256787},
	{"APICALLY", 8, 256788},
	{"PHERNTERMINE", 12, 256789},
	{"PHARMACOTHER", 12, 256790},
	{"SOUHWEST", 8, 256791},
	{"SHIANUX", 7, 256792},
	{"PROPRI", 6, 256793},
	{"XMLCH", 5, 256794},
	{"REVERSER", 8, 256795},
	{"SHINIER", 7, 256796},
	{"RANGAN", 6, 256797},
	{"KOSKELA", 7, 256798},
	{"PLESS", 5, 256799},
	{"MRCPCH", 6, 256800},
	{"MADRASAS", 8, 256801},
	{"LUTHIEN", 7, 256802},
	{"EORGE", 5, 256803},
	{"CLARES", 6, 256804},
	{"ANNOTATORS", 10, 256805},
	{"VMASSOL", 7, 256806},
	{"OCKER", 5, 256807},
	{"KAARE", 5, 256808},
	{"ISLAAM", 6, 256809},
	{"NEWORK", 6, 256810},
	{"CITOTEL", 7, 256811},
	{"ARBEID", 6, 256812},
	{"ROOMSFORRENT", 12, 256813},
	{"PROVEMENTS", 10, 256814},
	{"MOUNTMEDIA", 10, 256815},
	{"FRENK", 5, 256816},
	{"APULEIUS", 8, 256817},
	{"OVERHAULIN", 10, 256818},
	{"EXPEDITORS", 10, 256819},
	{"MOSPORT", 7, 256820},
	{"DIPAK", 5, 256821},
	{"DABBA", 5, 256822},
	{"PAPERCRAFTS", 11, 256823},
	{"OLAND", 5, 256824},
	{"GOLDFINCHES", 11, 256825},
	{"EWORK", 5, 256826},
	{"DELWEDD", 7, 256827},
	{"COMMISSARS", 10, 256828},
	{"ACCOMPANISTS", 12, 256829},
	{"KADETT", 6, 256830},
	{"CRIMSONLAND", 11, 256831},
	{"CHANTHABURI", 11, 256832},
	{"ARTISTICA", 9, 256833},
	{"THUNDERER", 9, 256834},
	{"TFRC", 4, 256835},
	{"RAPORT", 6, 256836},
	{"NASTASIA", 8, 256837},
	{"MARTIGNY", 8, 256838},
	{"MALAMA", 6, 256839},
	{"SAARLANDES", 10, 256840},
	{"RETICAL", 7, 256841},
	{"POURTANT", 8, 256842},
	{"FINISHLINE", 10, 256843},
	{"SPIKESOURCE", 11, 256844},
	{"GLENOLDEN", 9, 256845},
	{"DEINTERLACE", 11, 256846},
	{"ANDANTINO", 9, 256847},
	{"METHODOLOGIC", 12, 256848},
	{"LEIDY", 5, 256849},
	{"CONFEREN", 8, 256850},
	{"RECOGNIZERS", 11, 256851},
	{"PANGBURN", 8, 256852},
	{"HERLONG", 7, 256853},
	{"GAMESSAMSUNG", 12, 256854},
	{"HOLWELL", 7, 256855},
	{"SEIGNIORAGE", 11, 256856},
	{"KLIKNI", 6, 256857},
	{"JORJA", 5, 256858},
	{"TRACEL", 6, 256859},
	{"PAWB", 4, 256860},
	{"CHIDESTER", 9, 256861},
	{"WFR", 3, 256862},
	{"SAMAJWADI", 9, 256863},
	{"PEATTIE", 7, 256864},
	{"EIDERS", 6, 256865},
	{"CALCAGNO", 8, 256866},
	{"CHABA", 5, 256867},
	{"WANTONNESS", 10, 256868},
	{"TMCXP", 5, 256869},
	{"DIARMAID", 8, 256870},
	{"CARAMELISED", 11, 256871},
	{"BOWWOW", 6, 256872},
	{"ANVER", 5, 256873},
	{"HODKINSON", 9, 256874},
	{"CLCS", 4, 256875},
	{"MAGNETOS", 8, 256876},
	{"KINER", 5, 256877},
	{"DIFESA", 6, 256878},
	{"CHICKENHEAD", 11, 256879},
	{"MICROFILAMENTS", 14, 256880},
	{"CORNVILLE", 9, 256881},
	{"WATING", 6, 256882},
	{"ACTINOMYCES", 11, 256883},
	{"MMHMM", 5, 256884},
	{"HAMMELL", 7, 256885},
	{"GEEKMART", 8, 256886},
	{"URPOSE", 6, 256887},
	{"TARC", 4, 256888},
	{"MADRASAH", 8, 256889},
	{"KOSTON", 6, 256890},
	{"KINMAN", 6, 256891},
	{"HENTAL", 6, 256892},
	{"GROT", 4, 256893},
	{"ZAINO", 5, 256894},
	{"WALKDEN", 7, 256895},
	{"UMANA", 5, 256896},
	{"TRADUCCION", 10, 256897},
	{"OGLEY", 5, 256898},
	{"MOLLI", 5, 256899},
	{"LAWFIRM", 7, 256900},
	{"DERSTAND", 8, 256901},
	{"CHIANCIANO", 10, 256902},
	{"MERGANSERS", 10, 256903},
	{"CUTCHOGUE", 9, 256904},
	{"CLODFELTER", 10, 256905},
	{"FACTURA", 7, 256906},
	{"KUNSAN", 6, 256907},
	{"EYEPATCH", 8, 256908},
	{"MAXILLO", 7, 256909},
	{"HIPCS", 5, 256910},
	{"MOWATT", 6, 256911},
	{"MELLOWER", 8, 256912},
	{"ECPAT", 5, 256913},
	{"SMARTMARKET", 11, 256914},
	{"MUSQUODOBOIT", 12, 256915},
	{"GALERIJA", 8, 256916},
	{"ZORP", 4, 256917},
	{"READHEAD", 8, 256918},
	{"KEYMAT", 6, 256919},
	{"EMLEY", 5, 256920},
	{"AKHMATOVA", 9, 256921},
	{"GAGEQD", 6, 256922},
	{"FIREFIGHTS", 10, 256923},
	{"EXPLICITY", 9, 256924},
	{"WUMPUS", 6, 256925},
	{"AROON", 5, 256926},
	{"REYNOLDSVILLE", 13, 256927},
	{"RANKO", 5, 256928},
	{"MULTILANG", 9, 256929},
	{"LEACHES", 7, 256930},
	{"DOBE", 4, 256931},
	{"TAMPABAYCOM", 11, 256932},
	{"UNIVERSITES", 11, 256933},
	{"SCENTING", 8, 256934},
	{"PHYTIC", 6, 256935},
	{"WABER", 5, 256936},
	{"EARMUFF", 7, 256937},
	{"DRUIDISM", 8, 256938},
	{"ALSAT", 5, 256939},
	{"GNBD", 4, 256940},
	{"MISKA", 5, 256941},
	{"MCKISSICK", 9, 256942},
	{"FXGUIDE", 7, 256943},
	{"FREYBERG", 8, 256944},
	{"DAICHI", 6, 256945},
	{"BEZIEHUNG", 9, 256946},
	{"SIRBER", 6, 256947},
	{"QUESTOR", 7, 256948},
	{"NAGESH", 6, 256949},
	{"MEATSPACE", 9, 256950},
	{"MADAGASCA", 9, 256951},
	{"NEUROTROPHINS", 13, 256952},
	{"LEANDRA", 7, 256953},
	{"FUTCH", 5, 256954},
	{"TOMBRAIDER", 10, 256955},
	{"PROJECTE", 8, 256956},
	{"HAYDENVILLE", 11, 256957},
	{"DEWATERED", 9, 256958},
	{"YAHKK", 5, 256959},
	{"TEASEL", 6, 256960},
	{"SAPNA", 5, 256961},
	{"PHOTOCURRENT", 12, 256962},
	{"LAYUPS", 6, 256963},
	{"CALABRIAN", 9, 256964},
	{"XCHG", 4, 256965},
	{"TRAVELLINKER", 12, 256966},
	{"SEDIN", 5, 256967},
	{"HUDKINS", 7, 256968},
	{"HOVERSPEED", 10, 256969},
	{"TMIC", 4, 256970},
	{"FARUQI", 6, 256971},
	{"STACHE", 6, 256972},
	{"RLMS", 4, 256973},
	{"PONTES", 6, 256974},
	{"INSUREME", 8, 256975},
	{"IMPERIOLI", 9, 256976},
	{"MEDPAC", 6, 256977},
	{"VERTEL", 6, 256978},
	{"TUGWELL", 7, 256979},
	{"SIDERABLE", 9, 256980},
	{"NURMI", 5, 256981},
	{"ARMACAO", 7, 256982},
	{"MADALYN", 7, 256983},
	{"HAFEEZ", 6, 256984},
	{"ADOBES", 6, 256985},
	{"BELMOND", 7, 256986},
	{"SEEBERG", 7, 256987},
	{"INDYK", 5, 256988},
	{"INCONTROL", 9, 256989},
	{"FLINTY", 6, 256990},
	{"WWWVIRGIN", 9, 256991},
	{"INVED", 5, 256992},
	{"INITIALE", 8, 256993},
	{"CROES", 5, 256994},
	{"MULLICAN", 8, 256995},
	{"GAYPATRIOT", 10, 256996},
	{"ZELLERBACH", 10, 256997},
	{"VIGNON", 6, 256998},
	{"PUROHIT", 7, 256999},
	{"COMANCHES", 9, 257000},
	{"VIPNET", 6, 257001},
	{"NTLWORLD", 8, 257002},
	{"ACTIVEDIR", 9, 257003},
	{"NEWTOPICFONTCOLOR", 17, 257004},
	{"GLYCOSAMINOGLYCAN", 17, 257005},
	{"CLOCKMAKERS", 11, 257006},
	{"SPRT", 4, 257007},
	{"PORKERS", 7, 257008},
	{"FREDMAN", 7, 257009},
	{"RHODEY", 6, 257010},
	{"PRACTICAR", 9, 257011},
	{"INTERLACHEN", 11, 257012},
	{"REORGANISING", 12, 257013},
	{"RAQUETBALL", 10, 257014},
	{"NECKLETS", 8, 257015},
	{"BRANCHLETS", 10, 257016},
	{"ZUZT", 4, 257017},
	{"ZOGI", 4, 257018},
	{"YSRY", 4, 257019},
	{"YNUA", 4, 257020},
	{"YMIH", 4, 257021},
	{"WLBO", 4, 257022},
	{"VRSQ", 4, 257023},
	{"VEYZ", 4, 257024},
	{"VEVS", 4, 257025},
	{"UIRF", 4, 257026},
	{"TWYC", 4, 257027},
	{"TVCL", 4, 257028},
	{"TUPQ", 4, 257029},
	{"TODF", 4, 257030},
	{"SHMP", 4, 257031},
	{"RUBC", 4, 257032},
	{"RNFC", 4, 257033},
	{"RCUO", 4, 257034},
	{"RCSR", 4, 257035},
	{"RBCT", 4, 257036},
	{"PUNR", 4, 257037},
	{"OXYH", 4, 257038},
	{"NKOJ", 4, 257039},
	{"NHYU", 4, 257040},
	{"NBWA", 4, 257041},
	{"MOAG", 4, 257042},
	{"MLUS", 4, 257043},
	{"MIBY", 4, 257044},
	{"MEKW", 4, 257045},
	{"LZIS", 4, 257046},
	{"LVDN", 4, 257047},
	{"LUPJ", 4, 257048},
	{"LUFR", 4, 257049},
	{"LTIK", 4, 257050},
	{"LRUP", 4, 257051},
	{"LPJA", 4, 257052},
	{"LLNS", 4, 257053},
	{"LAEW", 4, 257054},
	{"KYKA", 4, 257055},
	{"KWIE", 4, 257056},
	{"KMTA", 4, 257057},
	{"KBLV", 4, 257058},
	{"JIPA", 4, 257059},
	{"IEUF", 4, 257060},
	{"HUKK", 4, 257061},
	{"HGOM", 4, 257062},
	{"GYID", 4, 257063},
	{"GULW", 4, 257064},
	{"GUBB", 4, 257065},
	{"GPCA", 4, 257066},
	{"GKOT", 4, 257067},
	{"GCAE", 4, 257068},
	{"GBOC", 4, 257069},
	{"FYMI", 4, 257070},
	{"FYID", 4, 257071},
	{"FVAP", 4, 257072},
	{"FMRF", 4, 257073},
	{"FGAO", 4, 257074},
	{"FCYA", 4, 257075},
	{"ETDB", 4, 257076},
	{"EDMN", 4, 257077},
	{"DPGO", 4, 257078},
	{"DOJE", 4, 257079},
	{"DDGI", 4, 257080},
	{"DBSC", 4, 257081},
	{"DBOK", 4, 257082},
	{"CSNU", 4, 257083},
	{"CIEG", 4, 257084},
	{"BEVP", 4, 257085},
	{"AMFC", 4, 257086},
	{"AKZA", 4, 257087},
	{"AKYM", 4, 257088},
	{"AIUL", 4, 257089},
	{"RIEM", 4, 257090},
	{"FASCICULE", 9, 257091},
	{"PCMV", 4, 257092},
	{"COVO", 4, 257093},
	{"BLONDELL", 8, 257094},
	{"HALPHA", 6, 257095},
	{"DAMAGEPLAN", 10, 257096},
	{"CREATEINSTANCE", 14, 257097},
	{"CATDOC", 6, 257098},
	{"WORDWARE", 8, 257099},
	{"VEGSS", 5, 257100},
	{"MIKRODATORN", 11, 257101},
	{"CARDILLO", 8, 257102},
	{"NARCOLEPTIC", 11, 257103},
	{"JAYLAN", 6, 257104},
	{"GAMERCARD", 9, 257105},
	{"WICHSEN", 7, 257106},
	{"WOMBLES", 7, 257107},
	{"SUPERBUGS", 9, 257108},
	{"SEISMOLOGIST", 12, 257109},
	{"MCCLIM", 6, 257110},
	{"IGCP", 4, 257111},
	{"ARMINIANISM", 11, 257112},
	{"MONCKTON", 8, 257113},
	{"KEENEN", 6, 257114},
	{"AYMENT", 6, 257115},
	{"WEBBUILDER", 10, 257116},
	{"WARRA", 5, 257117},
	{"WESTERGAARD", 11, 257118},
	{"KAMAY", 5, 257119},
	{"FLATUS", 6, 257120},
	{"ARDITI", 6, 257121},
	{"BASICALY", 8, 257122},
	{"YESTERYEARS", 11, 257123},
	{"CHIGGERS", 8, 257124},
	{"AMUST", 5, 257125},
	{"SIMBABWE", 8, 257126},
	{"GOLFSTAT", 8, 257127},
	{"ANITEC", 6, 257128},
	{"PARMINDER", 9, 257129},
	{"STRONGSWAN", 10, 257130},
	{"PASSYM", 6, 257131},
	{"CSNCH", 5, 257132},
	{"ARALUEN", 7, 257133},
	{"WWWVIAGRA", 9, 257134},
	{"SNOUTS", 6, 257135},
	{"PROXIMATION", 11, 257136},
	{"IBLIST", 6, 257137},
	{"FRAPPUCCINO", 11, 257138},
	{"DELPHINUS", 9, 257139},
	{"BANGSAR", 7, 257140},
	{"ADAMCHIK", 8, 257141},
	{"UNBOWED", 7, 257142},
	{"PRESAGED", 8, 257143},
	{"GANTOS", 6, 257144},
	{"RERELEASED", 10, 257145},
	{"DAVEP", 5, 257146},
	{"REACTIONMAP", 11, 257147},
	{"COUNTERTRANSFERENCE", 19, 257148},
	{"TANNAHILL", 9, 257149},
	{"NTRY", 4, 257150},
	{"MILKO", 5, 257151},
	{"HAGG", 4, 257152},
	{"YELLOWHAMMER", 12, 257153},
	{"VERMELHO", 8, 257154},
	{"LINNEWEH", 8, 257155},
	{"OVULATED", 8, 257156},
	{"DCKIDS", 6, 257157},
	{"BEDANKT", 7, 257158},
	{"UNBOX", 5, 257159},
	{"TELESUD", 7, 257160},
	{"PLAKIAS", 7, 257161},
	{"ORDNUNG", 7, 257162},
	{"INFORMATIONSALES", 16, 257163},
	{"ARABISCHE", 9, 257164},
	{"SHINDENGEN", 10, 257165},
	{"NUSANTARA", 9, 257166},
	{"NRHP", 4, 257167},
	{"LLINELL", 7, 257168},
	{"TOLHURST", 8, 257169},
	{"CEREMONIOUSLY", 13, 257170},
	{"NUTATION", 8, 257171},
	{"LINNA", 5, 257172},
	{"RCOND", 5, 257173},
	{"DANU", 4, 257174},
	{"VEGAD", 5, 257175},
	{"REISERT", 7, 257176},
	{"PURKEY", 6, 257177},
	{"ADZUKI", 6, 257178},
	{"VMIN", 4, 257179},
	{"TROODOS", 7, 257180},
	{"HELLSPAWN", 9, 257181},
	{"PANIX", 5, 257182},
	{"MACVICAR", 8, 257183},
	{"DOMINIE", 7, 257184},
	{"SURATTHANI", 10, 257185},
	{"RIKE", 4, 257186},
	{"LPX", 3, 257187},
	{"LIBUNICODE", 10, 257188},
	{"GLOIRE", 6, 257189},
	{"ESSAYEDGE", 9, 257190},
	{"SEDL", 4, 257191},
	{"PYGRESQL", 8, 257192},
	{"HAMMONDSPORT", 12, 257193},
	{"DUBREUIL", 8, 257194},
	{"BALLASTED", 9, 257195},
	{"SCATTERPLOTS", 12, 257196},
	{"PONZA", 5, 257197},
	{"MERISTEMS", 9, 257198},
	{"MENIN", 5, 257199},
	{"LETUNIC", 7, 257200},
	{"BENDALL", 7, 257201},
	{"ZEITZ", 5, 257202},
	{"VAISNAVA", 8, 257203},
	{"HJALMAR", 7, 257204},
	{"CLERGERIE", 9, 257205},
	{"POSTTREATMENT", 13, 257206},
	{"IRRADIO", 7, 257207},
	{"ABDOU", 5, 257208},
	{"PROPSHAFT", 9, 257209},
	{"POLKI", 5, 257210},
	{"CHILANKO", 8, 257211},
	{"LRECL", 5, 257212},
	{"FERRETT", 7, 257213},
	{"WWWUSAJOBSOPMGOV", 16, 257214},
	{"RECKLINGHAUSEN", 14, 257215},
	{"NCIP", 4, 257216},
	{"AUSLINK", 7, 257217},
	{"SESTAMIBI", 9, 257218},
	{"NONCOOPERATIVE", 14, 257219},
	{"KUZMIN", 6, 257220},
	{"BLOUSON", 7, 257221},
	{"ATIVELY", 7, 257222},
	{"WOBEI", 5, 257223},
	{"UBIQUE", 6, 257224},
	{"ENGLISHNESS", 11, 257225},
	{"DAMAGEDCOPIES", 13, 257226},
	{"BERNARDUS", 9, 257227},
	{"STEIDL", 6, 257228},
	{"CRITZ", 5, 257229},
	{"ANIMOTION", 9, 257230},
	{"KASSOVITZ", 9, 257231},
	{"ZIGLER", 6, 257232},
	{"TENSIVE", 7, 257233},
	{"SURGERYCOSMETIC", 15, 257234},
	{"SERVCIES", 8, 257235},
	{"MEMLING", 7, 257236},
	{"HOLLOWNESS", 10, 257237},
	{"GUINEY", 6, 257238},
	{"INFORMATIVA", 11, 257239},
	{"INDOLOGICAL", 11, 257240},
	{"CAINO", 5, 257241},
	{"VIPERA", 6, 257242},
	{"METABLOGGING", 12, 257243},
	{"PARALIMNI", 9, 257244},
	{"ECKSTINE", 8, 257245},
	{"BROZMAN", 7, 257246},
	{"SHIRTED", 7, 257247},
	{"ZEGGEN", 6, 257248},
	{"UNVOICED", 8, 257249},
	{"INSTRUCTER", 10, 257250},
	{"HIUSE", 5, 257251},
	{"SCHLUPPIPUPPIE", 14, 257252},
	{"DECOUPLES", 9, 257253},
	{"SEAPOINT", 8, 257254},
	{"ENTICEMENTS", 11, 257255},
	{"BEGINGROUP", 10, 257256},
	{"ADOLESCENTI", 11, 257257},
	{"TAGASI", 6, 257258},
	{"DETYA", 5, 257259},
	{"TRIPEL", 6, 257260},
	{"JARDINIER", 9, 257261},
	{"FIELDBOOK", 9, 257262},
	{"EXCITERS", 8, 257263},
	{"ROCKAFILLY", 10, 257264},
	{"PERSIE", 6, 257265},
	{"MITGLIEDES", 10, 257266},
	{"LEITAO", 6, 257267},
	{"INTERNTIONAL", 12, 257268},
	{"GIBBERELLIN", 11, 257269},
	{"UREY", 4, 257270},
	{"MYLOR", 5, 257271},
	{"WWWWEATHER", 10, 257272},
	{"FORGAN", 6, 257273},
	{"COLEGIALA", 9, 257274},
	{"CARINI", 6, 257275},
	{"WWWTOYOTA", 9, 257276},
	{"VOLTZ", 5, 257277},
	{"VESTNIK", 7, 257278},
	{"KHABAR", 6, 257279},
	{"KIDTECH", 7, 257280},
	{"DUNDJINNI", 9, 257281},
	{"WWWTSAGOV", 9, 257282},
	{"LAIKIPIA", 8, 257283},
	{"FLES", 4, 257284},
	{"SCULTURA", 8, 257285},
	{"ROGGIO", 6, 257286},
	{"PAININNEC", 9, 257287},
	{"GLUCARATE", 9, 257288},
	{"EASYROOMMATE", 12, 257289},
	{"UAAP", 4, 257290},
	{"TEKLE", 5, 257291},
	{"CARANO", 6, 257292},
	{"TOPPAGE", 7, 257293},
	{"REHDER", 6, 257294},
	{"XAVERIAN", 8, 257295},
	{"WINDOWEVENT", 11, 257296},
	{"LEDERLE", 7, 257297},
	{"WWWUSPSGOV", 10, 257298},
	{"MARMALADES", 10, 257299},
	{"EXCHANG", 7, 257300},
	{"ARKH", 4, 257301},
	{"SMARTDETOUR", 11, 257302},
	{"WAMBACH", 7, 257303},
	{"MWAM", 4, 257304},
	{"HYPEREXTENSION", 14, 257305},
	{"ANDORA", 6, 257306},
	{"PHOTOSTUDIO", 11, 257307},
	{"CROSSHURD", 9, 257308},
	{"POUSADAS", 8, 257309},
	{"MOBILEREAD", 10, 257310},
	{"SERAI", 5, 257311},
	{"YACHTCHARTER", 12, 257312},
	{"WEBPORTAL", 9, 257313},
	{"SYPHER", 6, 257314},
	{"SAWLOGS", 7, 257315},
	{"MASSIMA", 7, 257316},
	{"IHOTELIER", 9, 257317},
	{"SAPDB", 5, 257318},
	{"DISCRETES", 9, 257319},
	{"CAUX", 4, 257320},
	{"PETFRIENDLY", 11, 257321},
	{"GYSYLLTIEDIG", 12, 257322},
	{"WWWVERIZONNET", 13, 257323},
	{"WWWVERIZONCOM", 13, 257324},
	{"SYNNEX", 6, 257325},
	{"ATPL", 4, 257326},
	{"WWWUH", 5, 257327},
	{"WINNECONNE", 10, 257328},
	{"ROSETT", 6, 257329},
	{"MISCFS", 6, 257330},
	{"LIZARDTECH", 10, 257331},
	{"WWWVAGOV", 8, 257332},
	{"SUSCEP", 6, 257333},
	{"ORTELIUS", 8, 257334},
	{"REALIA", 6, 257335},
	{"GUMMIES", 7, 257336},
	{"EHOMEUPGRADE", 12, 257337},
	{"WAFFLER", 7, 257338},
	{"ROCCHI", 6, 257339},
	{"MEGAFOOD", 8, 257340},
	{"LTIP", 4, 257341},
	{"HAEMATOMA", 9, 257342},
	{"DIRVISH", 7, 257343},
	{"SONORITY", 8, 257344},
	{"MOLESKINERIE", 12, 257345},
	{"AUSTUDY", 7, 257346},
	{"WWWVOILAFR", 10, 257347},
	{"WWWTHEHUNNET", 12, 257348},
	{"MOKORO", 6, 257349},
	{"MIDDLEBROOKS", 12, 257350},
	{"CUJ", 3, 257351},
	{"ARTUS", 5, 257352},
	{"ACCORDO", 7, 257353},
	{"TENOSYNOVITIS", 13, 257354},
	{"MACIEK", 6, 257355},
	{"JOUY", 4, 257356},
	{"FILEFORMAT", 10, 257357},
	{"APPLERA", 7, 257358},
	{"UNAVAIL", 7, 257359},
	{"REINTRODUCES", 12, 257360},
	{"MOORTHY", 7, 257361},
	{"CONTEXTUALIZING", 15, 257362},
	{"SIETSEMA", 8, 257363},
	{"PAED", 4, 257364},
	{"MOBIS", 5, 257365},
	{"ACING", 5, 257366},
	{"WWWVIRGILIOIT", 13, 257367},
	{"WWWUTEXASEDU", 12, 257368},
	{"JGTC", 4, 257369},
	{"INNERVISIONS", 12, 257370},
	{"DEANSGATE", 9, 257371},
	{"WWWVERIZONWIRELESS", 18, 257372},
	{"WWWTOMMYS", 9, 257373},
	{"RECENSION", 9, 257374},
	{"CLIMATISEUR", 11, 257375},
	{"PLW", 3, 257376},
	{"BELLAH", 6, 257377},
	{"ALDINGTON", 9, 257378},
	{"YAHIII", 6, 257379},
	{"WWWUSARMYMIL", 12, 257380},
	{"WWWTSPGOV", 9, 257381},
	{"STIPA", 5, 257382},
	{"LPCSTR", 6, 257383},
	{"CEZAR", 5, 257384},
	{"ZSEF", 4, 257385},
	{"ZOSV", 4, 257386},
	{"ZERZ", 4, 257387},
	{"YDGR", 4, 257388},
	{"YCCO", 4, 257389},
	{"WYFO", 4, 257390},
	{"WIFN", 4, 257391},
	{"UYFF", 4, 257392},
	{"USLS", 4, 257393},
	{"USCN", 4, 257394},
	{"UMCY", 4, 257395},
	{"UKOO", 4, 257396},
	{"UCEQ", 4, 257397},
	{"TYRW", 4, 257398},
	{"TGNR", 4, 257399},
	{"SUAF", 4, 257400},
	{"SGAC", 4, 257401},
	{"RPCW", 4, 257402},
	{"RPBL", 4, 257403},
	{"RNPC", 4, 257404},
	{"RIZF", 4, 257405},
	{"RARF", 4, 257406},
	{"QINM", 4, 257407},
	{"PYVO", 4, 257408},
	{"PTSK", 4, 257409},
	{"OXIB", 4, 257410},
	{"OXEY", 4, 257411},
	{"OUGJ", 4, 257412},
	{"OFZR", 4, 257413},
	{"ODDV", 4, 257414},
	{"NSYK", 4, 257415},
	{"NNUB", 4, 257416},
	{"NEGP", 4, 257417},
	{"MTVB", 4, 257418},
	{"MMGR", 4, 257419},
	{"MIMG", 4, 257420},
	{"MEGC", 4, 257421},
	{"MDUG", 4, 257422},
	{"MDOV", 4, 257423},
	{"MDNA", 4, 257424},
	{"LLKY", 4, 257425},
	{"KPIO", 4, 257426},
	{"KOAD", 4, 257427},
	{"KILU", 4, 257428},
	{"KAIY", 4, 257429},
	{"JPLE", 4, 257430},
	{"JMAT", 4, 257431},
	{"JMAC", 4, 257432},
	{"IZFR", 4, 257433},
	{"IYAY", 4, 257434},
	{"IKHL", 4, 257435},
	{"ICFC", 4, 257436},
	{"HTYJ", 4, 257437},
	{"HKMT", 4, 257438},
	{"GYER", 4, 257439},
	{"GOLR", 4, 257440},
	{"GEBB", 4, 257441},
	{"GCED", 4, 257442},
	{"FYER", 4, 257443},
	{"FYBR", 4, 257444},
	{"FCAY", 4, 257445},
	{"FAAW", 4, 257446},
	{"EXMR", 4, 257447},
	{"EULU", 4, 257448},
	{"DLTO", 4, 257449},
	{"DKMT", 4, 257450},
	{"DJUK", 4, 257451},
	{"DGUZ", 4, 257452},
	{"CLOH", 4, 257453},
	{"CCAK", 4, 257454},
	{"BUCU", 4, 257455},
	{"BPIL", 4, 257456},
	{"BGYN", 4, 257457},
	{"BFIT", 4, 257458},
	{"BBUL", 4, 257459},
	{"AJUT", 4, 257460},
	{"ADUV", 4, 257461},
	{"WWWYAHOOCA", 10, 257462},
	{"WWWTMFNL", 8, 257463},
	{"TCRS", 4, 257464},
	{"WWWYAHHOOCHATCOM", 16, 257465},
	{"WWWVZW", 6, 257466},
	{"WWWVODAFONEIE", 13, 257467},
	{"WWWUSMINTGOV", 12, 257468},
	{"WWWUSAJOBSGOV", 13, 257469},
	{"WWWUPSCGOVIN", 12, 257470},
	{"TABLESIDE", 9, 257471},
	{"PASSADO", 7, 257472},
	{"FLYFF", 5, 257473},
	{"BOYSHORTS", 9, 257474},
	{"WWWYAHOOMAILCOM", 15, 257475},
	{"WWWYAHOOCOUK", 12, 257476},
	{"WWWVDABBE", 9, 257477},
	{"WWWUNIPBR", 9, 257478},
	{"WWWTORONTOCA", 12, 257479},
	{"COURSON", 7, 257480},
	{"TVCI", 4, 257481},
	{"DESIERTO", 8, 257482},
	{"BSEC", 4, 257483},
	{"WWWYAHOOES", 10, 257484},
	{"WWWYAHOOCOMMX", 13, 257485},
	{"OMNIMAX", 7, 257486},
	{"YSGOO", 5, 257487},
	{"WWWYAHOOGAMESCOM", 16, 257488},
	{"WWWYAHOOCOMAR", 13, 257489},
	{"HARTGE", 6, 257490},
	{"ADRANNAU", 8, 257491},
	{"WEXO", 4, 257492},
	{"PHARMACYPHENTERMINE", 19, 257493},
	{"RODELINDA", 9, 257494},
	{"CONET", 5, 257495},
	{"TELEDU", 6, 257496},
	{"SNIFTER", 7, 257497},
	{"FLUIDISED", 9, 257498},
	{"NOEVIR", 6, 257499},
	{"MCMATH", 6, 257500},
	{"SOLARIA", 7, 257501},
	{"SKYSCAPES", 9, 257502},
	{"MVY", 3, 257503},
	{"GGTCC", 5, 257504},
	{"ALBUMINS", 8, 257505},
	{"OKFUSKEE", 8, 257506},
	{"EXPENDABLES", 11, 257507},
	{"CONCOR", 6, 257508},
	{"POTERBA", 7, 257509},
	{"POLED", 5, 257510},
	{"ODSP", 4, 257511},
	{"GAHRAN", 6, 257512},
	{"AAPC", 4, 257513},
	{"HERSHAM", 7, 257514},
	{"WERBEN", 6, 257515},
	{"ARTHROTEC", 9, 257516},
	{"SEMINARI", 8, 257517},
	{"SCAREMONGERING", 14, 257518},
	{"VIZARD", 6, 257519},
	{"GORDIJNEN", 9, 257520},
	{"DECISON", 7, 257521},
	{"TUNDE", 5, 257522},
	{"POOTER", 6, 257523},
	{"BEAUTIFIER", 10, 257524},
	{"SWFBUTTON", 9, 257525},
	{"NONUSERS", 8, 257526},
	{"FANCYING", 8, 257527},
	{"UNGERLEIDER", 11, 257528},
	{"TEAVEL", 6, 257529},
	{"RUFFS", 5, 257530},
	{"RAYET", 5, 257531},
	{"HELLIP", 6, 257532},
	{"BEERMAN", 7, 257533},
	{"WOODCARVER", 10, 257534},
	{"PIGGYBACKED", 11, 257535},
	{"MIRSKY", 6, 257536},
	{"COWPEAS", 7, 257537},
	{"SOFTMOC", 7, 257538},
	{"PREFERE", 7, 257539},
	{"PROTUBERANCE", 12, 257540},
	{"OVERMARS", 8, 257541},
	{"GOOGLETESTAD", 12, 257542},
	{"VRGAS", 5, 257543},
	{"SPANGLEMONKEY", 13, 257544},
	{"GACIE", 5, 257545},
	{"DAMER", 5, 257546},
	{"UNDERPASSES", 11, 257547},
	{"SIGMON", 6, 257548},
	{"LIVEDOCS", 8, 257549},
	{"KETCHESON", 9, 257550},
	{"FACUNDO", 7, 257551},
	{"ALLEGRIA", 8, 257552},
	{"UNSTINTING", 10, 257553},
	{"PAPERING", 8, 257554},
	{"JASTROW", 7, 257555},
	{"FRICATIVES", 10, 257556},
	{"COMMERC", 7, 257557},
	{"CMNS", 4, 257558},
	{"YLLOW", 5, 257559},
	{"SUBWATERSHEDS", 13, 257560},
	{"PICKE", 5, 257561},
	{"WOULDVE", 7, 257562},
	{"STREAMREADER", 12, 257563},
	{"NAVTREE", 7, 257564},
	{"FFWEB", 5, 257565},
	{"EECTIVE", 7, 257566},
	{"BIOELECTRIC", 11, 257567},
	{"ALTAMA", 6, 257568},
	{"UHRICHSVILLE", 12, 257569},
	{"SIEVER", 6, 257570},
	{"OTFORD", 6, 257571},
	{"LOUTS", 5, 257572},
	{"DUANY", 5, 257573},
	{"BIOPSIED", 8, 257574},
	{"HOMECRAFT", 9, 257575},
	{"GULAR", 5, 257576},
	{"DEMAT", 5, 257577},
	{"MACROCARPA", 10, 257578},
	{"BORAGINACEAE", 12, 257579},
	{"NEWC", 4, 257580},
	{"KOEPKE", 6, 257581},
	{"ARINA", 5, 257582},
	{"AMESS", 5, 257583},
	{"SWITCHYARD", 10, 257584},
	{"FOUCAN", 6, 257585},
	{"MAETERLINCK", 11, 257586},
	{"FRIS", 4, 257587},
	{"CRYPTIX", 7, 257588},
	{"WTCC", 4, 257589},
	{"WARDWELL", 8, 257590},
	{"SHURFLO", 7, 257591},
	{"MUSCOLI", 7, 257592},
	{"LARGEUR", 7, 257593},
	{"DICOTS", 6, 257594},
	{"USERCP", 6, 257595},
	{"BEGUINE", 7, 257596},
	{"ARNIM", 5, 257597},
	{"YASUKO", 6, 257598},
	{"SHALLOWEST", 10, 257599},
	{"INTRODUCERS", 11, 257600},
	{"CRAIGSVILLE", 11, 257601},
	{"THEHOTEL", 8, 257602},
	{"BRUGMANSIA", 10, 257603},
	{"ANOVAS", 6, 257604},
	{"WHYNOT", 6, 257605},
	{"VIBO", 4, 257606},
	{"SMEDEGAARD", 10, 257607},
	{"IBOATS", 6, 257608},
	{"BRAATHENS", 9, 257609},
	{"INTERNATIONALISTS", 17, 257610},
	{"SERVERROOT", 10, 257611},
	{"CLUNKER", 7, 257612},
	{"ALARME", 6, 257613},
	{"JAPANESES", 9, 257614},
	{"BSUB", 4, 257615},
	{"TRANSKETOLASE", 13, 257616},
	{"TEECE", 5, 257617},
	{"QUATRAINS", 9, 257618},
	{"INITIALCONTEXT", 14, 257619},
	{"DEGUSTATION", 11, 257620},
	{"JORDA", 5, 257621},
	{"CTPS", 4, 257622},
	{"MEEGAN", 6, 257623},
	{"CRITISISM", 9, 257624},
	{"ADORO", 5, 257625},
	{"TRABAJADOR", 10, 257626},
	{"LIVADIA", 7, 257627},
	{"GOZA", 4, 257628},
	{"PARADICE", 8, 257629},
	{"IPPON", 5, 257630},
	{"DROOG", 5, 257631},
	{"DIDGERIDOOS", 11, 257632},
	{"CSFS", 4, 257633},
	{"LRQL", 4, 257634},
	{"KOZMA", 5, 257635},
	{"QUIRINALE", 9, 257636},
	{"DISHNET", 7, 257637},
	{"GRALL", 5, 257638},
	{"BSTRACT", 7, 257639},
	{"POTENTIA", 8, 257640},
	{"PILLORIED", 9, 257641},
	{"NEOSTIGMINE", 11, 257642},
	{"MATEUSZ", 7, 257643},
	{"IDRS", 4, 257644},
	{"FUCING", 6, 257645},
	{"CIDI", 4, 257646},
	{"BELLWETHERS", 11, 257647},
	{"LPRINT", 6, 257648},
	{"GARDENCONSTRUCTION", 18, 257649},
	{"NYGARD", 6, 257650},
	{"HAHAHAHAH", 9, 257651},
	{"ABRADING", 8, 257652},
	{"TIMEA", 5, 257653},
	{"MUCHACHOS", 9, 257654},
	{"LANZERAC", 8, 257655},
	{"HATTEBERG", 9, 257656},
	{"GODMOON", 7, 257657},
	{"BTAB", 4, 257658},
	{"YIKERS", 6, 257659},
	{"SAIRA", 5, 257660},
	{"MEDICAMENTOS", 12, 257661},
	{"EVROPA", 6, 257662},
	{"COLOSSI", 7, 257663},
	{"KPKG", 4, 257664},
	{"JIUZHAIGOU", 10, 257665},
	{"HYPOPHYSEAL", 11, 257666},
	{"DIVIN", 5, 257667},
	{"CHILOQUIN", 9, 257668},
	{"GRAPPLERS", 9, 257669},
	{"JARC", 4, 257670},
	{"IKVM", 4, 257671},
	{"DEMARK", 6, 257672},
	{"ZILERI", 6, 257673},
	{"VASTERAS", 8, 257674},
	{"SUEHIRO", 7, 257675},
	{"BXNEXCHILD", 10, 257676},
	{"SEAFIELD", 8, 257677},
	{"BUTTONBOX", 9, 257678},
	{"SUBE", 4, 257679},
	{"PANETTONE", 9, 257680},
	{"TUMORIGENICITY", 14, 257681},
	{"ESCHBORN", 8, 257682},
	{"PINTORES", 8, 257683},
	{"PEPT", 4, 257684},
	{"ONMOUSEMOVE", 11, 257685},
	{"KONKAN", 6, 257686},
	{"GITTINGS", 8, 257687},
	{"STICKERED", 9, 257688},
	{"SENDPAGE", 8, 257689},
	{"NOVAMUTE", 8, 257690},
	{"GRAVESITES", 10, 257691},
	{"ASTIGMATIC", 10, 257692},
	{"ASGND", 5, 257693},
	{"VARBERG", 7, 257694},
	{"TCKETS", 6, 257695},
	{"PORTAIT", 7, 257696},
	{"IMBB", 4, 257697},
	{"UZUMAKI", 7, 257698},
	{"UNDRAWN", 7, 257699},
	{"GRTIS", 5, 257700},
	{"STABI", 5, 257701},
	{"REPURPOSE", 9, 257702},
	{"MEINS", 5, 257703},
	{"HAPTEN", 6, 257704},
	{"URLSEARCHHOOK", 13, 257705},
	{"TARTARUGHE", 10, 257706},
	{"NEMOTO", 6, 257707},
	{"GETPATH", 7, 257708},
	{"BRATION", 7, 257709},
	{"BOSU", 4, 257710},
	{"RENEWAMERICA", 12, 257711},
	{"MONKLY", 6, 257712},
	{"QSUB", 4, 257713},
	{"KEDIT", 5, 257714},
	{"FFTS", 4, 257715},
	{"PANESAR", 7, 257716},
	{"COMPATIABLE", 11, 257717},
	{"NEPHROSIS", 9, 257718},
	{"MONOPOL", 7, 257719},
	{"KENNEX", 6, 257720},
	{"DAVIDSONVILLE", 13, 257721},
	{"POSTRACH", 8, 257722},
	{"EXCEEDENCES", 11, 257723},
	{"CHOLMONDELEY", 12, 257724},
	{"TERSELY", 7, 257725},
	{"SYMC", 4, 257726},
	{"DATAFLEX", 8, 257727},
	{"HOLLANDSWORTH", 13, 257728},
	{"DISARMS", 7, 257729},
	{"TRAKAI", 6, 257730},
	{"MIDNIGHTBLUE", 12, 257731},
	{"ODYSSEYS", 8, 257732},
	{"MCLAWS", 6, 257733},
	{"HANNSTAR", 8, 257734},
	{"GARTRELL", 8, 257735},
	{"ABPM", 4, 257736},
	{"TSIMSHATSUI", 11, 257737},
	{"SAILIN", 6, 257738},
	{"AFAICT", 6, 257739},
	{"TRALFAZ", 7, 257740},
	{"SATELLIT", 8, 257741},
	{"TESTFILE", 8, 257742},
	{"PROPE", 5, 257743},
	{"COMBATE", 7, 257744},
	{"AUSTRALES", 9, 257745},
	{"EILFIN", 6, 257746},
	{"COLADAS", 7, 257747},
	{"BARBIROLLI", 10, 257748},
	{"UNEXCEPTIONAL", 13, 257749},
	{"PGDM", 4, 257750},
	{"OSTEOPONTIN", 11, 257751},
	{"HANNELORE", 9, 257752},
	{"FYC", 3, 257753},
	{"ALIWAL", 6, 257754},
	{"ZILINA", 6, 257755},
	{"WORKMATE", 8, 257756},
	{"SEMILINEAR", 10, 257757},
	{"CDSE", 4, 257758},
	{"KDBG", 4, 257759},
	{"FOTOGRAFICHE", 12, 257760},
	{"DUROS", 5, 257761},
	{"BROADMEADOW", 11, 257762},
	{"BALDAUF", 7, 257763},
	{"TELECOMMAND", 11, 257764},
	{"RRAVEL", 6, 257765},
	{"PENDERFYNIAD", 12, 257766},
	{"NORDTVEDT", 9, 257767},
	{"GLL", 3, 257768},
	{"DRACONIC", 8, 257769},
	{"ANSIEDAD", 8, 257770},
	{"ZPOP", 4, 257771},
	{"ZAMW", 4, 257772},
	{"YMCV", 4, 257773},
	{"YIDT", 4, 257774},
	{"YFUZ", 4, 257775},
	{"YDRK", 4, 257776},
	{"XIAC", 4, 257777},
	{"WDBY", 4, 257778},
	{"VIIM", 4, 257779},
	{"VAUC", 4, 257780},
	{"UAJI", 4, 257781},
	{"TYLL", 4, 257782},
	{"TULY", 4, 257783},
	{"SZUK", 4, 257784},
	{"SRWE", 4, 257785},
	{"SKMC", 4, 257786},
	{"SHRD", 4, 257787},
	{"SDJA", 4, 257788},
	{"RUJO", 4, 257789},
	{"RKMM", 4, 257790},
	{"RJUP", 4, 257791},
	{"RFDR", 4, 257792},
	{"RALX", 4, 257793},
	{"PPSG", 4, 257794},
	{"POBR", 4, 257795},
	{"PMOI", 4, 257796},
	{"OSXL", 4, 257797},
	{"OKYR", 4, 257798},
	{"OKUE", 4, 257799},
	{"OKRD", 4, 257800},
	{"NLPA", 4, 257801},
	{"NGNP", 4, 257802},
	{"NDJM", 4, 257803},
	{"MXIN", 4, 257804},
	{"MPYP", 4, 257805},
	{"MIXN", 4, 257806},
	{"MAJW", 4, 257807},
	{"LVAY", 4, 257808},
	{"LLGM", 4, 257809},
	{"LBCS", 4, 257810},
	{"LAKP", 4, 257811},
	{"KUNR", 4, 257812},
	{"JRPA", 4, 257813},
	{"JRCH", 4, 257814},
	{"IKDA", 4, 257815},
	{"IEUB", 4, 257816},
	{"HDRC", 4, 257817},
	{"GUGA", 4, 257818},
	{"GOZZ", 4, 257819},
	{"GMSD", 4, 257820},
	{"GBAF", 4, 257821},
	{"GAZU", 4, 257822},
	{"FOPO", 4, 257823},
	{"FMEO", 4, 257824},
	{"EPPD", 4, 257825},
	{"ENFB", 4, 257826},
	{"EJRC", 4, 257827},
	{"EGPH", 4, 257828},
	{"EDJT", 4, 257829},
	{"EDJC", 4, 257830},
	{"EAVG", 4, 257831},
	{"DYDY", 4, 257832},
	{"DUTU", 4, 257833},
	{"DSPT", 4, 257834},
	{"DMPP", 4, 257835},
	{"DEBC", 4, 257836},
	{"CUZI", 4, 257837},
	{"CJEN", 4, 257838},
	{"BYCZ", 4, 257839},
	{"BUGN", 4, 257840},
	{"BSSW", 4, 257841},
	{"BSSD", 4, 257842},
	{"BIZT", 4, 257843},
	{"BIMU", 4, 257844},
	{"ASVL", 4, 257845},
	{"AGUZ", 4, 257846},
	{"AFGO", 4, 257847},
	{"UCASE", 5, 257848},
	{"TTAVEL", 6, 257849},
	{"TDAXP", 5, 257850},
	{"BROWNSTONES", 11, 257851},
	{"TIRZAH", 6, 257852},
	{"TAKHT", 5, 257853},
	{"PROMATHIA", 9, 257854},
	{"FIVESTAR", 8, 257855},
	{"AUREN", 5, 257856},
	{"PRIMERY", 7, 257857},
	{"COMMISIONER", 11, 257858},
	{"SKYEUROPE", 9, 257859},
	{"PATHMARK", 8, 257860},
	{"DEPLORING", 9, 257861},
	{"BERRIMA", 7, 257862},
	{"BELLON", 6, 257863},
	{"NOKEY", 5, 257864},
	{"DAILYUPDATES", 12, 257865},
	{"ATTAKUS", 7, 257866},
	{"GRAAG", 5, 257867},
	{"DATACAD", 7, 257868},
	{"USADO", 5, 257869},
	{"SABBAGH", 7, 257870},
	{"KINGSLEYS", 9, 257871},
	{"OPPEN", 5, 257872},
	{"MINDGATE", 8, 257873},
	{"GOIZUETA", 8, 257874},
	{"SOREX", 5, 257875},
	{"RELATI", 6, 257876},
	{"LOTTOS", 6, 257877},
	{"INTEREALMS", 10, 257878},
	{"WALTARI", 7, 257879},
	{"INTEGERP", 8, 257880},
	{"DISARMINGLY", 11, 257881},
	{"TORRIDON", 8, 257882},
	{"ROUTEUR", 7, 257883},
	{"JICK", 4, 257884},
	{"DIVERTENTI", 10, 257885},
	{"CRAINE", 6, 257886},
	{"COSMECEUTICAL", 13, 257887},
	{"AFFO", 4, 257888},
	{"JOHNSCOTT", 9, 257889},
	{"VCAA", 4, 257890},
	{"OUSMANE", 7, 257891},
	{"FDOPEN", 6, 257892},
	{"AKWARD", 6, 257893},
	{"IVETA", 5, 257894},
	{"GIESECKE", 8, 257895},
	{"ZONECHECK", 9, 257896},
	{"UNDRENTIDE", 10, 257897},
	{"FREEPHOTO", 9, 257898},
	{"SECUREDATA", 10, 257899},
	{"BABBLERS", 8, 257900},
	{"ULTRAMAGNETIC", 13, 257901},
	{"LICL", 4, 257902},
	{"HALCO", 5, 257903},
	{"HALBERG", 7, 257904},
	{"ELETTRONICO", 11, 257905},
	{"ZOMG", 4, 257906},
	{"JOVENCITA", 9, 257907},
	{"KWALITEIT", 9, 257908},
	{"FASCISTIC", 9, 257909},
	{"SCHOOLAGED", 10, 257910},
	{"QUAICHS", 7, 257911},
	{"KEYTAB", 6, 257912},
	{"AMRAVATI", 8, 257913},
	{"WHITW", 5, 257914},
	{"INNUENDOS", 9, 257915},
	{"FREUNDLICHEN", 12, 257916},
	{"WEBCONTROL", 10, 257917},
	{"SATURNBOY", 9, 257918},
	{"DIEF", 4, 257919},
	{"CONTAINERISED", 13, 257920},
	{"MORINO", 6, 257921},
	{"COBOS", 5, 257922},
	{"UNINSURABLE", 11, 257923},
	{"PERPETUUM", 9, 257924},
	{"HERTZLER", 8, 257925},
	{"DAUCUS", 6, 257926},
	{"DOWNTOWNER", 10, 257927},
	{"DELCALDO", 8, 257928},
	{"RECLASSIFYING", 13, 257929},
	{"JAGJIT", 6, 257930},
	{"KURIER", 6, 257931},
	{"JAFARI", 6, 257932},
	{"BOZZIO", 6, 257933},
	{"VARSHA", 6, 257934},
	{"CFEC", 4, 257935},
	{"BRONDBY", 7, 257936},
	{"MINIMAN", 7, 257937},
	{"FOLKSINGER", 10, 257938},
	{"BESIGYE", 7, 257939},
	{"SALLIES", 7, 257940},
	{"NATALITY", 8, 257941},
	{"MABIS", 5, 257942},
	{"JEPHTHAH", 8, 257943},
	{"HERMANAS", 8, 257944},
	{"MATURELY", 8, 257945},
	{"ANICET", 6, 257946},
	{"RNPS", 4, 257947},
	{"WUITE", 5, 257948},
	{"PUBBLICATO", 10, 257949},
	{"PHILIPE", 7, 257950},
	{"LIVEWELL", 8, 257951},
	{"CAPRIMULGUS", 11, 257952},
	{"BAZELON", 7, 257953},
	{"WIZDOM", 6, 257954},
	{"LIBTAO", 6, 257955},
	{"GLENOID", 7, 257956},
	{"TOKAR", 5, 257957},
	{"GEOENVIRONMENTAL", 16, 257958},
	{"BASESTATION", 11, 257959},
	{"ZYUGANOV", 8, 257960},
	{"TERAFLOPS", 9, 257961},
	{"PRCNT", 5, 257962},
	{"PLENTYOFFISH", 12, 257963},
	{"BONESTEEL", 9, 257964},
	{"WILKINSONS", 10, 257965},
	{"TRANSPOD", 8, 257966},
	{"WANNSEE", 7, 257967},
	{"MANTHEY", 7, 257968},
	{"AUTHINFO", 8, 257969},
	{"SAUDE", 5, 257970},
	{"CONTINENTALS", 12, 257971},
	{"COLORATURA", 10, 257972},
	{"CAPITULO", 8, 257973},
	{"SCOOTING", 8, 257974},
	{"CHARDONNAYS", 11, 257975},
	{"CHAPOUTIER", 10, 257976},
	{"BOOKPAGE", 8, 257977},
	{"OOOHHH", 6, 257978},
	{"KILODALTON", 10, 257979},
	{"ILLEAGLE", 8, 257980},
	{"HAMMARSKJOLD", 12, 257981},
	{"FRONTIERSMEN", 12, 257982},
	{"ANDERMATT", 9, 257983},
	{"ZMZ", 3, 257984},
	{"UCCELLI", 7, 257985},
	{"DOPPELPACK", 10, 257986},
	{"BROTHERHOODS", 12, 257987},
	{"BRODERSEN", 9, 257988},
	{"SULFONYLUREAS", 13, 257989},
	{"JEMMY", 5, 257990},
	{"DRUMRIGHT", 9, 257991},
	{"MAJORAS", 7, 257992},
	{"JELLIED", 7, 257993},
	{"CONTRARIES", 10, 257994},
	{"BOLLIER", 7, 257995},
	{"ARCHBALD", 8, 257996},
	{"ZZRIL", 5, 257997},
	{"SUPRESSED", 9, 257998},
	{"FREEGALLERIES", 13, 257999},
	{"BUTTNER", 7, 258000},
	{"TRULL", 5, 258001},
	{"LIFSON", 6, 258002},
	{"MARGAM", 6, 258003},
	{"EXEMPTIVE", 9, 258004},
	{"CLHEP", 5, 258005},
	{"CHEMISORPTION", 13, 258006},
	{"ARMFUL", 6, 258007},
	{"NERVY", 5, 258008},
	{"GABONESE", 8, 258009},
	{"ENVERS", 6, 258010},
	{"DOCG", 4, 258011},
	{"ALTEMUS", 7, 258012},
	{"TIGGERS", 7, 258013},
	{"RUMPELSTILTSKIN", 15, 258014},
	{"DEMBO", 5, 258015},
	{"LOOBYLU", 7, 258016},
	{"GREGGS", 6, 258017},
	{"FREDERIKSHAVN", 13, 258018},
	{"CIPHERSUITE", 11, 258019},
	{"BYRE", 4, 258020},
	{"NONSTATUTORY", 12, 258021},
	{"LOLTA", 5, 258022},
	{"AVERNUM", 7, 258023},
	{"VUKOVIC", 7, 258024},
	{"EASTERNS", 8, 258025},
	{"REQUESTFOCUSINWINDOW", 20, 258026},
	{"MMSA", 4, 258027},
	{"JANDY", 5, 258028},
	{"IAPSS", 5, 258029},
	{"GAZZANIGA", 9, 258030},
	{"MELKOR", 6, 258031},
	{"LADONIA", 7, 258032},
	{"KHWAJA", 6, 258033},
	{"FIBERSPACE", 10, 258034},
	{"CANTT", 5, 258035},
	{"MATSUZAKI", 9, 258036},
	{"MANNOSYLTRANSFERASE", 19, 258037},
	{"LEASK", 5, 258038},
	{"STIGMATISED", 11, 258039},
	{"EUBUSINESS", 10, 258040},
	{"DELFINES", 8, 258041},
	{"TABCORP", 7, 258042},
	{"NURSERYMAN", 10, 258043},
	{"GREYBOY", 7, 258044},
	{"BRUDENELL", 9, 258045},
	{"THUMBSCREW", 10, 258046},
	{"HILLANDALE", 10, 258047},
	{"BONDVILLE", 9, 258048},
	{"SOTHERN", 7, 258049},
	{"RIGHI", 5, 258050},
	{"POTHIER", 7, 258051},
	{"IFPA", 4, 258052},
	{"IDPA", 4, 258053},
	{"NORIA", 5, 258054},
	{"BECHT", 5, 258055},
	{"UNCONFIGURED", 12, 258056},
	{"PROMOTORS", 9, 258057},
	{"KNELLER", 7, 258058},
	{"CARDAMON", 8, 258059},
	{"SAVELA", 6, 258060},
	{"REGRES", 6, 258061},
	{"LEXEME", 6, 258062},
	{"EXTRICATED", 10, 258063},
	{"TENAGA", 6, 258064},
	{"NYSSBA", 6, 258065},
	{"MCGAUGH", 7, 258066},
	{"PACFIC", 6, 258067},
	{"DDINBYCH", 8, 258068},
	{"BYSOFT", 6, 258069},
	{"PELIT", 5, 258070},
	{"OFWS", 4, 258071},
	{"EIJIRO", 6, 258072},
	{"UNCDF", 5, 258073},
	{"PROVOS", 6, 258074},
	{"PEREYRA", 7, 258075},
	{"MELOCHE", 7, 258076},
	{"INFORMATIONPRE", 14, 258077},
	{"EURSOC", 6, 258078},
	{"BALFE", 5, 258079},
	{"SOBERRECOVERY", 13, 258080},
	{"JDAM", 4, 258081},
	{"IRRC", 4, 258082},
	{"THEKKADY", 8, 258083},
	{"OSTEOBLASTIC", 12, 258084},
	{"MERICAL", 7, 258085},
	{"INAPPOSITE", 10, 258086},
	{"CRACS", 5, 258087},
	{"QUM", 3, 258088},
	{"KOVEN", 5, 258089},
	{"PORTOROZ", 8, 258090},
	{"MARGARITE", 9, 258091},
	{"TETHERBALL", 10, 258092},
	{"INTESA", 6, 258093},
	{"SHMEIWSE", 8, 258094},
	{"SELAM", 5, 258095},
	{"MRYCAR", 6, 258096},
	{"YAOHO", 5, 258097},
	{"SCPI", 4, 258098},
	{"RMST", 4, 258099},
	{"JIGGS", 5, 258100},
	{"AMERIVEST", 9, 258101},
	{"ZELAYA", 6, 258102},
	{"TRONS", 5, 258103},
	{"SELAND", 6, 258104},
	{"FIRECAT", 7, 258105},
	{"DISSEMBLE", 9, 258106},
	{"NOVEDGE", 7, 258107},
	{"ZXX", 3, 258108},
	{"HATRY", 5, 258109},
	{"BOUTEILLE", 9, 258110},
	{"TURNHAM", 7, 258111},
	{"DAGGERSPINE", 11, 258112},
	{"ALLBRANDS", 9, 258113},
	{"LAZZARA", 7, 258114},
	{"GRESSION", 8, 258115},
	{"VISWANATH", 9, 258116},
	{"NATUZZI", 7, 258117},
	{"GORENJE", 7, 258118},
	{"GROOVERS", 8, 258119},
	{"BEITRAGVERFASST", 15, 258120},
	{"TICKETWATCH", 11, 258121},
	{"GUNZE", 5, 258122},
	{"GRENE", 5, 258123},
	{"BYKER", 5, 258124},
	{"BESPIN", 6, 258125},
	{"SETING", 6, 258126},
	{"COHABIT", 7, 258127},
	{"BILINGUALS", 10, 258128},
	{"FFURFLENNI", 10, 258129},
	{"EYNON", 5, 258130},
	{"XXIAO", 5, 258131},
	{"PRDS", 4, 258132},
	{"MEMORYCARD", 10, 258133},
	{"GERKE", 5, 258134},
	{"CHISSINI", 8, 258135},
	{"ZEETV", 5, 258136},
	{"HOTSPOTZZ", 9, 258137},
	{"FLUVIATILIS", 11, 258138},
	{"CPPS", 4, 258139},
	{"ADBORTH", 7, 258140},
	{"AVAKIAN", 7, 258141},
	{"UTOPIANS", 8, 258142},
	{"CONNECTEUR", 10, 258143},
	{"YUKU", 4, 258144},
	{"YOCU", 4, 258145},
	{"YKMN", 4, 258146},
	{"YAKP", 4, 258147},
	{"XFUE", 4, 258148},
	{"VUNT", 4, 258149},
	{"VOLW", 4, 258150},
	{"VIBA", 4, 258151},
	{"VEKM", 4, 258152},
	{"UXPL", 4, 258153},
	{"UXLI", 4, 258154},
	{"UISY", 4, 258155},
	{"UFNA", 4, 258156},
	{"TZWR", 4, 258157},
	{"TWAP", 4, 258158},
	{"TUCT", 4, 258159},
	{"THWC", 4, 258160},
	{"THDF", 4, 258161},
	{"TBAX", 4, 258162},
	{"SPSR", 4, 258163},
	{"RYFF", 4, 258164},
	{"RUTF", 4, 258165},
	{"RKEJ", 4, 258166},
	{"RJAA", 4, 258167},
	{"RFGR", 4, 258168},
	{"REHD", 4, 258169},
	{"QICA", 4, 258170},
	{"PVRE", 4, 258171},
	{"PKEP", 4, 258172},
	{"PGSI", 4, 258173},
	{"PACN", 4, 258174},
	{"OXJO", 4, 258175},
	{"OFXX", 4, 258176},
	{"NRMI", 4, 258177},
	{"NOXD", 4, 258178},
	{"NKJR", 4, 258179},
	{"NDUY", 4, 258180},
	{"NDDG", 4, 258181},
	{"NBRN", 4, 258182},
	{"MWCA", 4, 258183},
	{"MRKN", 4, 258184},
	{"MNWR", 4, 258185},
	{"MMNE", 4, 258186},
	{"MKAU", 4, 258187},
	{"LLHT", 4, 258188},
	{"LFUC", 4, 258189},
	{"LDLL", 4, 258190},
	{"KRYL", 4, 258191},
	{"KMYR", 4, 258192},
	{"KHUA", 4, 258193},
	{"IKKY", 4, 258194},
	{"HZIP", 4, 258195},
	{"HYRT", 4, 258196},
	{"HMRK", 4, 258197},
	{"HEBK", 4, 258198},
	{"GYSW", 4, 258199},
	{"GNTV", 4, 258200},
	{"GKIE", 4, 258201},
	{"GDPC", 4, 258202},
	{"FTEK", 4, 258203},
	{"FJAT", 4, 258204},
	{"FCSF", 4, 258205},
	{"EWMP", 4, 258206},
	{"EVPS", 4, 258207},
	{"EUQU", 4, 258208},
	{"ETDC", 4, 258209},
	{"ERWD", 4, 258210},
	{"EPPV", 4, 258211},
	{"EMBC", 4, 258212},
	{"EICF", 4, 258213},
	{"EGKE", 4, 258214},
	{"ECIJ", 4, 258215},
	{"DIRL", 4, 258216},
	{"DIMY", 4, 258217},
	{"DGUD", 4, 258218},
	{"COXN", 4, 258219},
	{"CHDC", 4, 258220},
	{"BYLD", 4, 258221},
	{"BUNL", 4, 258222},
	{"BPSB", 4, 258223},
	{"BMUC", 4, 258224},
	{"BDUB", 4, 258225},
	{"APMG", 4, 258226},
	{"ANMW", 4, 258227},
	{"AIBM", 4, 258228},
	{"WYP", 3, 258229},
	{"RICHESON", 8, 258230},
	{"SUBPROGRAMME", 12, 258231},
	{"IMPOST", 6, 258232},
	{"DRESSS", 6, 258233},
	{"DATACORE", 8, 258234},
	{"PACIENTE", 8, 258235},
	{"DUBUIS", 6, 258236},
	{"PARABOLAS", 9, 258237},
	{"ENGLEMAN", 8, 258238},
	{"CITYWEST", 8, 258239},
	{"ABSORPTIONS", 11, 258240},
	{"UNIFLAME", 8, 258241},
	{"BOBER", 5, 258242},
	{"APPLICATIONSERVER", 17, 258243},
	{"RUNRS", 5, 258244},
	{"PERMALINKSATURDAY", 17, 258245},
	{"MIDLETS", 7, 258246},
	{"DTEP", 4, 258247},
	{"SWADDLE", 7, 258248},
	{"STEINMEIER", 10, 258249},
	{"OVERTOPPING", 11, 258250},
	{"MLPA", 4, 258251},
	{"BIOPESTICIDES", 13, 258252},
	{"SNIFFLING", 9, 258253},
	{"MEDIADIS", 8, 258254},
	{"JUNY", 4, 258255},
	{"HIDESHOWGROUP", 13, 258256},
	{"FLEETCENTER", 11, 258257},
	{"KADEK", 5, 258258},
	{"COUNTENANCED", 12, 258259},
	{"MSXBOX", 6, 258260},
	{"CALLPLUS", 8, 258261},
	{"ARTETA", 6, 258262},
	{"STRAM", 5, 258263},
	{"MOULTONBOROUGH", 14, 258264},
	{"MELODICALLY", 11, 258265},
	{"MEGASET", 7, 258266},
	{"APOSTOL", 7, 258267},
	{"VIRESCENS", 9, 258268},
	{"STEHLIK", 7, 258269},
	{"PORLOCK", 7, 258270},
	{"NUCLEONICS", 10, 258271},
	{"GERARDS", 7, 258272},
	{"ESSAYED", 7, 258273},
	{"DEEPINGS", 8, 258274},
	{"CEBAS", 5, 258275},
	{"TENEBRIL", 8, 258276},
	{"RCSDIFF", 7, 258277},
	{"LECLERCQ", 8, 258278},
	{"GOUSE", 5, 258279},
	{"PEATS", 5, 258280},
	{"FINDETH", 7, 258281},
	{"CARWASHES", 9, 258282},
	{"METZLI", 6, 258283},
	{"GESAGT", 6, 258284},
	{"DENATA", 6, 258285},
	{"WEBCGM", 6, 258286},
	{"RELATIE", 7, 258287},
	{"MUSASHINO", 9, 258288},
	{"LIKELIEST", 9, 258289},
	{"AKKUS", 5, 258290},
	{"ZIYANG", 6, 258291},
	{"ZARO", 4, 258292},
	{"UNUSAL", 6, 258293},
	{"BERGHE", 6, 258294},
	{"NATURALIS", 9, 258295},
	{"ARNTZEN", 7, 258296},
	{"JAYBEE", 6, 258297},
	{"ROCKEFELLERS", 12, 258298},
	{"DIACRITIC", 9, 258299},
	{"ARNOUD", 6, 258300},
	{"WFMC", 4, 258301},
	{"TANLINES", 8, 258302},
	{"SLIMEY", 6, 258303},
	{"NICOR", 5, 258304},
	{"DIPHTHERIAE", 11, 258305},
	{"CRYPTOAPI", 9, 258306},
	{"ADULTSHOP", 9, 258307},
	{"SMOAK", 5, 258308},
	{"CDJAPAN", 7, 258309},
	{"PHILBROOK", 9, 258310},
	{"NIGGLES", 7, 258311},
	{"KOMAN", 5, 258312},
	{"BUYSELL", 7, 258313},
	{"CHROMOPHORES", 12, 258314},
	{"BLANCK", 6, 258315},
	{"BALITA", 6, 258316},
	{"HVPS", 4, 258317},
	{"ALGODONES", 9, 258318},
	{"WAKATIPU", 8, 258319},
	{"SQUARTING", 9, 258320},
	{"PHILIPPIC", 9, 258321},
	{"ONLYE", 5, 258322},
	{"ACCUSLIM", 8, 258323},
	{"ZUSTAND", 7, 258324},
	{"PRINCIPESSA", 11, 258325},
	{"DAUNCE", 6, 258326},
	{"JEZIK", 5, 258327},
	{"EPITOMISED", 10, 258328},
	{"SAGAING", 7, 258329},
	{"MACNICOL", 8, 258330},
	{"ANMELDUNGSDATUM", 15, 258331},
	{"TARDIEU", 7, 258332},
	{"HANSTIMM", 8, 258333},
	{"DKC", 3, 258334},
	{"ALERTBOX", 8, 258335},
	{"WIREFRAMES", 10, 258336},
	{"SUPERSTATION", 12, 258337},
	{"GHOSN", 5, 258338},
	{"AGRIBUSINESSES", 14, 258339},
	{"STOCKPRICE", 10, 258340},
	{"PINHAS", 6, 258341},
	{"BOOYA", 5, 258342},
	{"OPENGUIDES", 10, 258343},
	{"ATHER", 5, 258344},
	{"SHERA", 5, 258345},
	{"SEAGOON", 7, 258346},
	{"IMGNAME", 7, 258347},
	{"SUPERSATURATED", 14, 258348},
	{"GITTIN", 6, 258349},
	{"ELSPA", 5, 258350},
	{"GDBSERVER", 9, 258351},
	{"FAUVISM", 7, 258352},
	{"TRAFEL", 6, 258353},
	{"SKYFIRE", 7, 258354},
	{"POSTKARTE", 9, 258355},
	{"MUNGKIN", 7, 258356},
	{"ISHIZUKA", 8, 258357},
	{"CEGELIS", 7, 258358},
	{"ACONDICIONADO", 13, 258359},
	{"TPIXEL", 6, 258360},
	{"PARIAHS", 7, 258361},
	{"PANDAVAS", 8, 258362},
	{"EXACTO", 6, 258363},
	{"BIOBANNER", 9, 258364},
	{"TAKAYASU", 8, 258365},
	{"RAINN", 5, 258366},
	{"TOADFLAX", 8, 258367},
	{"LGX", 3, 258368},
	{"FREBERG", 7, 258369},
	{"DREAMWORK", 9, 258370},
	{"NEWSHOUND", 9, 258371},
	{"KANDAL", 6, 258372},
	{"CLAWLESS", 8, 258373},
	{"BOUY", 4, 258374},
	{"AUDITORIA", 9, 258375},
	{"POBLACION", 9, 258376},
	{"CHOJIN", 6, 258377},
	{"BRANCHS", 7, 258378},
	{"HATJE", 5, 258379},
	{"GLOBOSE", 7, 258380},
	{"AQIP", 4, 258381},
	{"SPEEDOMETERS", 12, 258382},
	{"GRIPHYN", 7, 258383},
	{"DIARRA", 6, 258384},
	{"GETPAGESIZE", 11, 258385},
	{"WEBCENTER", 9, 258386},
	{"ISLANDSURF", 10, 258387},
	{"ESVON", 5, 258388},
	{"WHISTLERS", 9, 258389},
	{"SECTRA", 6, 258390},
	{"VALUESHOP", 9, 258391},
	{"PAJA", 4, 258392},
	{"MANAHAN", 7, 258393},
	{"ANNUUS", 6, 258394},
	{"SOISSONS", 8, 258395},
	{"GETLOCALIZEDMESSAGE", 19, 258396},
	{"DEADHEADS", 9, 258397},
	{"CLUBLIFE", 8, 258398},
	{"BABIC", 5, 258399},
	{"VAGUEST", 7, 258400},
	{"VACAS", 5, 258401},
	{"ONESTEEL", 8, 258402},
	{"NAHAL", 5, 258403},
	{"MASSBIKE", 8, 258404},
	{"CLIPSTER", 8, 258405},
	{"UNCONSCIONABILITY", 17, 258406},
	{"SMARTPHONETODAY", 15, 258407},
	{"SHUFORD", 7, 258408},
	{"MURRAYLANDS", 11, 258409},
	{"MOROGORO", 8, 258410},
	{"KURASHIKI", 9, 258411},
	{"DEPRECIATES", 11, 258412},
	{"OGNIZED", 7, 258413},
	{"MOUCHE", 6, 258414},
	{"FLUMAZENIL", 10, 258415},
	{"DUKAS", 5, 258416},
	{"DETMOLD", 7, 258417},
	{"BERSHAD", 7, 258418},
	{"AMSTER", 6, 258419},
	{"SONATINE", 8, 258420},
	{"SHUP", 4, 258421},
	{"PLAYHOU", 7, 258422},
	{"GLYCOLIPID", 10, 258423},
	{"TRIUMPHALISM", 12, 258424},
	{"OKADAIC", 7, 258425},
	{"SRVR", 4, 258426},
	{"SILVERCITY", 10, 258427},
	{"SHANTE", 6, 258428},
	{"PROSKAUER", 9, 258429},
	{"HINATA", 6, 258430},
	{"SEIGENTHALER", 12, 258431},
	{"LIQUEFY", 7, 258432},
	{"PROTOPLANETARY", 14, 258433},
	{"NEWSALERT", 9, 258434},
	{"HINDA", 5, 258435},
	{"AMPK", 4, 258436},
	{"TWEEDS", 6, 258437},
	{"SZMOCY", 6, 258438},
	{"DISOUNT", 7, 258439},
	{"DUNYA", 5, 258440},
	{"ALEXANDROVNA", 12, 258441},
	{"STRAWSON", 8, 258442},
	{"NINTEEN", 7, 258443},
	{"LEABHAR", 7, 258444},
	{"GLORANTHA", 9, 258445},
	{"XRACER", 6, 258446},
	{"WAISTLINES", 10, 258447},
	{"ORASCOM", 7, 258448},
	{"COMUNQUE", 8, 258449},
	{"OIKONOMIKWN", 11, 258450},
	{"UEED", 4, 258451},
	{"TRANSLOCATOR", 12, 258452},
	{"QDATASTREAM", 11, 258453},
	{"OHUSE", 5, 258454},
	{"NORMENT", 7, 258455},
	{"DISPLAYERS", 10, 258456},
	{"ASHKENAZ", 8, 258457},
	{"APOCYNACEAE", 11, 258458},
	{"INNERLEITHEN", 12, 258459},
	{"CODEFREE", 8, 258460},
	{"TRIPPE", 6, 258461},
	{"KASER", 5, 258462},
	{"FENETRE", 7, 258463},
	{"ANOUNCEMENT", 11, 258464},
	{"XAFS", 4, 258465},
	{"FIREBOLT", 8, 258466},
	{"FARDEEN", 7, 258467},
	{"DANLEY", 6, 258468},
	{"ARRC", 4, 258469},
	{"PITOCIN", 7, 258470},
	{"FWL", 3, 258471},
	{"DOVR", 4, 258472},
	{"DOOBY", 5, 258473},
	{"COEXPRESSED", 11, 258474},
	{"YUD", 3, 258475},
	{"SCHOOLMASTERS", 13, 258476},
	{"RACKABLE", 8, 258477},
	{"GOMOKU", 6, 258478},
	{"GLISS", 5, 258479},
	{"CHANDERPAUL", 11, 258480},
	{"STEAGALL", 8, 258481},
	{"MCGEER", 6, 258482},
	{"GHRH", 4, 258483},
	{"FLATBACK", 8, 258484},
	{"ALVESTON", 8, 258485},
	{"PAPAGEORGIOU", 12, 258486},
	{"LLAMADAS", 8, 258487},
	{"ABROGATES", 9, 258488},
	{"DOLLFIE", 7, 258489},
	{"APROACH", 7, 258490},
	{"PASSEN", 6, 258491},
	{"INTERFET", 8, 258492},
	{"EQNARRAY", 8, 258493},
	{"YORKNEW", 7, 258494},
	{"UPADHYAY", 8, 258495},
	{"UNISONIC", 8, 258496},
	{"ICMELER", 7, 258497},
	{"GBENGA", 6, 258498},
	{"BABELGUIDES", 11, 258499},
	{"GANGBUSTERS", 11, 258500},
	{"WFMY", 4, 258501},
	{"KORNFIELD", 9, 258502},
	{"FEEBLENESS", 10, 258503},
	{"ZOSTA", 5, 258504},
	{"SALOPES", 7, 258505},
	{"EYESHADOWS", 10, 258506},
	{"DWIVEDI", 7, 258507},
	{"DRACHMAE", 8, 258508},
	{"DOSTUM", 6, 258509},
	{"ALKENYL", 7, 258510},
	{"TRAVWL", 6, 258511},
	{"TERFACE", 7, 258512},
	{"GERSTMANN", 9, 258513},
	{"LANDSTAR", 8, 258514},
	{"SUMBER", 6, 258515},
	{"HUMFREY", 7, 258516},
	{"CHIPCON", 7, 258517},
	{"CUBANOS", 7, 258518},
	{"MUTAGENIX", 9, 258519},
	{"MSCD", 4, 258520},
	{"LONGNOSE", 8, 258521},
	{"ZINJ", 4, 258522},
	{"ZIMS", 4, 258523},
	{"YRIZ", 4, 258524},
	{"YHTM", 4, 258525},
	{"YGAX", 4, 258526},
	{"YFOY", 4, 258527},
	{"XREN", 4, 258528},
	{"XPTH", 4, 258529},
	{"WDBO", 4, 258530},
	{"VYOP", 4, 258531},
	{"VUEI", 4, 258532},
	{"VKLO", 4, 258533},
	{"VDAM", 4, 258534},
	{"UTUO", 4, 258535},
	{"UOQU", 4, 258536},
	{"ULZB", 4, 258537},
	{"UJAD", 4, 258538},
	{"UFAV", 4, 258539},
	{"UEFF", 4, 258540},
	{"TUWE", 4, 258541},
	{"TSKL", 4, 258542},
	{"THVU", 4, 258543},
	{"SSRF", 4, 258544},
	{"SPEJ", 4, 258545},
	{"SFYO", 4, 258546},
	{"RPKA", 4, 258547},
	{"ROCQ", 4, 258548},
	{"RKUC", 4, 258549},
	{"RHYU", 4, 258550},
	{"QUIJ", 4, 258551},
	{"PRYL", 4, 258552},
	{"POWL", 4, 258553},
	{"OWIZ", 4, 258554},
	{"NYUH", 4, 258555},
	{"NYLG", 4, 258556},
	{"NULR", 4, 258557},
	{"NPFA", 4, 258558},
	{"NDJF", 4, 258559},
	{"MWCO", 4, 258560},
	{"MMXM", 4, 258561},
	{"MBCR", 4, 258562},
	{"MAKB", 4, 258563},
	{"LMRM", 4, 258564},
	{"LIIF", 4, 258565},
	{"LBJO", 4, 258566},
	{"LBDR", 4, 258567},
	{"LAEU", 4, 258568},
	{"KOCR", 4, 258569},
	{"KKOM", 4, 258570},
	{"JASF", 4, 258571},
	{"ISWU", 4, 258572},
	{"IPKU", 4, 258573},
	{"INLW", 4, 258574},
	{"ILAQ", 4, 258575},
	{"IDTB", 4, 258576},
	{"IBDA", 4, 258577},
	{"HMRL", 4, 258578},
	{"HIVF", 4, 258579},
	{"HDIB", 4, 258580},
	{"HAKD", 4, 258581},
	{"GSPY", 4, 258582},
	{"GRIJ", 4, 258583},
	{"FSKN", 4, 258584},
	{"FCRD", 4, 258585},
	{"FCOX", 4, 258586},
	{"FAML", 4, 258587},
	{"EYNW", 4, 258588},
	{"EUFR", 4, 258589},
	{"EUEW", 4, 258590},
	{"ESFD", 4, 258591},
	{"ERJG", 4, 258592},
	{"ERFG", 4, 258593},
	{"EGRC", 4, 258594},
	{"DUGB", 4, 258595},
	{"DSWB", 4, 258596},
	{"DSRB", 4, 258597},
	{"DRKH", 4, 258598},
	{"DRCU", 4, 258599},
	{"DFGT", 4, 258600},
	{"DDVE", 4, 258601},
	{"CYTW", 4, 258602},
	{"BWEO", 4, 258603},
	{"BUNW", 4, 258604},
	{"BTIC", 4, 258605},
	{"BPEG", 4, 258606},
	{"BOGH", 4, 258607},
	{"BLOL", 4, 258608},
	{"AXOV", 4, 258609},
	{"AWGH", 4, 258610},
	{"AVDI", 4, 258611},
	{"AJOP", 4, 258612},
	{"VITEL", 5, 258613},
	{"LIFEWORKS", 9, 258614},
	{"IZPACK", 6, 258615},
	{"PUNGGOL", 7, 258616},
	{"TANNHAUSER", 10, 258617},
	{"MULATION", 8, 258618},
	{"SILLYSOFT", 9, 258619},
	{"SEKHMET", 7, 258620},
	{"IMPLANTOLOGY", 12, 258621},
	{"HARPSICHORDS", 12, 258622},
	{"ZETADOCS", 8, 258623},
	{"TSTCLNT", 7, 258624},
	{"WALLPAPE", 8, 258625},
	{"POWERQUICC", 10, 258626},
	{"FOOTBALLPHOTO", 13, 258627},
	{"DHARMAS", 7, 258628},
	{"THUNDERPANTS", 12, 258629},
	{"PETROCELLI", 10, 258630},
	{"RECIT", 5, 258631},
	{"ENCANTA", 7, 258632},
	{"GREATIS", 7, 258633},
	{"ECCLESIASTICUS", 14, 258634},
	{"DEADCELL", 8, 258635},
	{"ARRLWEB", 7, 258636},
	{"OGRISH", 6, 258637},
	{"DIMENHYDRINATE", 14, 258638},
	{"AKADEMY", 7, 258639},
	{"WINDHORST", 9, 258640},
	{"UTOPOLIS", 8, 258641},
	{"SANTAOLALLA", 11, 258642},
	{"PLODDED", 7, 258643},
	{"OVERMATCHED", 11, 258644},
	{"IMACAT", 6, 258645},
	{"DISCOLORATIONS", 14, 258646},
	{"PLANETEE", 8, 258647},
	{"JERVOIS", 7, 258648},
	{"ICOP", 4, 258649},
	{"HULI", 4, 258650},
	{"FPNP", 4, 258651},
	{"LOCURA", 6, 258652},
	{"LEPINE", 6, 258653},
	{"WAVENUMBERS", 11, 258654},
	{"ROOMLINX", 8, 258655},
	{"PUBLICIDADE", 11, 258656},
	{"PRAKASHAN", 9, 258657},
	{"BEHZAD", 6, 258658},
	{"SHALOTT", 7, 258659},
	{"RACHIS", 6, 258660},
	{"TOYSHOP", 7, 258661},
	{"SWABIAN", 7, 258662},
	{"DPUT", 4, 258663},
	{"COMPANIESCONTACT", 16, 258664},
	{"GIOCARE", 7, 258665},
	{"DISASTE", 7, 258666},
	{"MOZER", 5, 258667},
	{"YDYM", 4, 258668},
	{"VILLANELLE", 10, 258669},
	{"PLANETXOOPS", 11, 258670},
	{"KOFMAN", 6, 258671},
	{"PROCO", 5, 258672},
	{"ENVISAGING", 10, 258673},
	{"WLWT", 4, 258674},
	{"TOTTINGTON", 10, 258675},
	{"MEMTEST", 7, 258676},
	{"LESQUELS", 8, 258677},
	{"EXCELLENTE", 10, 258678},
	{"BELOWGROUND", 11, 258679},
	{"SCRUMPY", 7, 258680},
	{"CANNELLONI", 10, 258681},
	{"SENKO", 5, 258682},
	{"GERVIN", 6, 258683},
	{"ESPP", 4, 258684},
	{"CRYSTALLITES", 12, 258685},
	{"SCHEWE", 6, 258686},
	{"NIEDER", 6, 258687},
	{"MOCH", 4, 258688},
	{"MILON", 5, 258689},
	{"BRISE", 5, 258690},
	{"SETMX", 5, 258691},
	{"KMAN", 4, 258692},
	{"FIEFDOMS", 8, 258693},
	{"ATTORNEYFIND", 12, 258694},
	{"ILLINOISAN", 10, 258695},
	{"AUDIOLOGIC", 10, 258696},
	{"SKEMP", 5, 258697},
	{"POKERSTRIP", 10, 258698},
	{"MENGEL", 6, 258699},
	{"ANTOON", 6, 258700},
	{"PADLOCKED", 9, 258701},
	{"MULTIMODEM", 10, 258702},
	{"FACILEMENT", 10, 258703},
	{"AVIOM", 5, 258704},
	{"CLIFFWOOD", 9, 258705},
	{"YAFFS", 5, 258706},
	{"WELSHOFER", 9, 258707},
	{"TETRINETX", 9, 258708},
	{"GWADAR", 6, 258709},
	{"INFLAMING", 9, 258710},
	{"HEINDEL", 7, 258711},
	{"GOLDENER", 8, 258712},
	{"MOSHING", 7, 258713},
	{"COASTEERING", 11, 258714},
	{"ORTHOD", 6, 258715},
	{"ORNETA", 6, 258716},
	{"ECAP", 4, 258717},
	{"TAIPANS", 7, 258718},
	{"PHONEBOOKS", 10, 258719},
	{"BAYB", 4, 258720},
	{"WIDEANGLE", 9, 258721},
	{"SIMPLISTICALLY", 14, 258722},
	{"REAWAKENED", 10, 258723},
	{"KIELER", 6, 258724},
	{"PEEKABOOTY", 10, 258725},
	{"HOYSE", 5, 258726},
	{"DEMINERALIZED", 13, 258727},
	{"DANANN", 6, 258728},
	{"AIRLNE", 6, 258729},
	{"PERINUCLEAR", 11, 258730},
	{"COISA", 5, 258731},
	{"BLOWGUNS", 8, 258732},
	{"REALCLIMATE", 11, 258733},
	{"VENEERING", 9, 258734},
	{"PAKA", 4, 258735},
	{"MARINOL", 7, 258736},
	{"VAMPIR", 6, 258737},
	{"COSIMA", 6, 258738},
	{"BITSTREAMS", 10, 258739},
	{"PSYCHOSTATS", 11, 258740},
	{"OSTRO", 5, 258741},
	{"PRETE", 5, 258742},
	{"ORCHITIS", 8, 258743},
	{"CLTV", 4, 258744},
	{"STACHYS", 7, 258745},
	{"WSCF", 4, 258746},
	{"KAYLAN", 6, 258747},
	{"DILEMNA", 7, 258748},
	{"VINYLIDENE", 10, 258749},
	{"WEAPONSMITH", 11, 258750},
	{"KRINKLES", 8, 258751},
	{"UMK", 3, 258752},
	{"SCHRIER", 7, 258753},
	{"PROBACKUP", 9, 258754},
	{"FLIPSIDES", 9, 258755},
	{"AUGURY", 6, 258756},
	{"FAVORITETHING", 13, 258757},
	{"BIKESBIKES", 10, 258758},
	{"WRAGGE", 6, 258759},
	{"PENTAGONS", 9, 258760},
	{"MILLIN", 6, 258761},
	{"ELUATE", 6, 258762},
	{"PERMETTENT", 10, 258763},
	{"BLOGIT", 6, 258764},
	{"NATALY", 6, 258765},
	{"DRQUEUE", 7, 258766},
	{"CHRISTAMS", 9, 258767},
	{"INFLECT", 7, 258768},
	{"DARTERS", 7, 258769},
	{"CHELSIE", 7, 258770},
	{"LOLS", 4, 258771},
	{"AMYNAS", 6, 258772},
	{"ROEHL", 5, 258773},
	{"HOUSW", 5, 258774},
	{"GIESBRECHT", 10, 258775},
	{"DIABOLUS", 8, 258776},
	{"TRANSRECTAL", 11, 258777},
	{"THRESHERS", 9, 258778},
	{"LINECRUISE", 10, 258779},
	{"KERKRADE", 8, 258780},
	{"VERTICALLINE", 12, 258781},
	{"EITZEN", 6, 258782},
	{"DONORA", 6, 258783},
	{"ANALAGOUS", 9, 258784},
	{"TASMANIANA", 10, 258785},
	{"PHANTIS", 7, 258786},
	{"NARGIN", 6, 258787},
	{"LADOMAT", 7, 258788},
	{"HEEGER", 6, 258789},
	{"FOUKE", 5, 258790},
	{"ECOLY", 5, 258791},
	{"CRUISECELEBRITY", 15, 258792},
	{"SMMES", 5, 258793},
	{"ROLAIDS", 7, 258794},
	{"RAFFAELLA", 9, 258795},
	{"FERTILISING", 11, 258796},
	{"IZHEVSK", 7, 258797},
	{"HELLSCREAM", 10, 258798},
	{"LOLIA", 5, 258799},
	{"LITTORALIS", 10, 258800},
	{"FERGHANA", 8, 258801},
	{"FEWE", 4, 258802},
	{"ALUPKA", 6, 258803},
	{"RECEIPTING", 10, 258804},
	{"JUDICAL", 7, 258805},
	{"EASYCLICKTRAVEL", 15, 258806},
	{"PATTEMPLATE", 11, 258807},
	{"LDIR", 4, 258808},
	{"ULTRALOW", 8, 258809},
	{"TRCA", 4, 258810},
	{"NUMEDGES", 8, 258811},
	{"YALDEX", 6, 258812},
	{"TFSAT", 5, 258813},
	{"QXP", 3, 258814},
	{"KOMPUTEROWE", 11, 258815},
	{"DETTORI", 7, 258816},
	{"ARTICLETECHNOLOGY", 17, 258817},
	{"STRIN", 5, 258818},
	{"MIDDENDORF", 10, 258819},
	{"LOGICO", 6, 258820},
	{"JOBC", 4, 258821},
	{"SMTWTFS", 7, 258822},
	{"FINNAN", 6, 258823},
	{"FETTUCINI", 9, 258824},
	{"ARRANG", 6, 258825},
	{"SOCKETED", 8, 258826},
	{"REVELLED", 8, 258827},
	{"HOSTINGS", 8, 258828},
	{"HAILIE", 6, 258829},
	{"DATABAZAAR", 10, 258830},
	{"WYKONAWCY", 9, 258831},
	{"RAINSVILLE", 10, 258832},
	{"BINLEY", 6, 258833},
	{"BELCAMP", 7, 258834},
	{"PLISSON", 7, 258835},
	{"CAEEL", 5, 258836},
	{"SECRETNET", 9, 258837},
	{"LYRICSOLOGY", 11, 258838},
	{"KRAD", 4, 258839},
	{"JALON", 5, 258840},
	{"CERVEJA", 7, 258841},
	{"SNIVELING", 9, 258842},
	{"JCOVERAGE", 9, 258843},
	{"ICALP", 5, 258844},
	{"BLIGHTS", 7, 258845},
	{"BALIUNAS", 8, 258846},
	{"SINDARIN", 8, 258847},
	{"MAYHAP", 6, 258848},
	{"TETRACAINE", 10, 258849},
	{"BIGNELL", 7, 258850},
	{"RAMAYAN", 7, 258851},
	{"HUMBLES", 7, 258852},
	{"VXML", 4, 258853},
	{"SETTOPICEDITLOCK", 16, 258854},
	{"RINGTONS", 8, 258855},
	{"EACHING", 7, 258856},
	{"AMLWG", 5, 258857},
	{"WAIPARA", 7, 258858},
	{"RECASTS", 7, 258859},
	{"PHYLOGEOGRAPHY", 14, 258860},
	{"RGTI", 4, 258861},
	{"DAMOS", 5, 258862},
	{"LABCONCO", 8, 258863},
	{"GLOBINS", 7, 258864},
	{"DODE", 4, 258865},
	{"REALIZA", 7, 258866},
	{"NARROWBOATS", 11, 258867},
	{"MEATUS", 6, 258868},
	{"WELTED", 6, 258869},
	{"LOGUES", 6, 258870},
	{"ISORDIL", 7, 258871},
	{"POSTUMUS", 8, 258872},
	{"PLATITUDE", 9, 258873},
	{"DUMMERSTON", 10, 258874},
	{"COFFEA", 6, 258875},
	{"WALRASIAN", 9, 258876},
	{"ROBERTI", 7, 258877},
	{"KALINKA", 7, 258878},
	{"CASTON", 6, 258879},
	{"PARKLAWN", 8, 258880},
	{"VASANTH", 7, 258881},
	{"REDSHIRTED", 10, 258882},
	{"ONSTAD", 6, 258883},
	{"FUNAKOSHI", 9, 258884},
	{"ZZOO", 4, 258885},
	{"ZKEL", 4, 258886},
	{"XTSL", 4, 258887},
	{"XKMN", 4, 258888},
	{"XIIW", 4, 258889},
	{"WUJI", 4, 258890},
	{"WGHE", 4, 258891},
	{"VUST", 4, 258892},
	{"VIGD", 4, 258893},
	{"UPRY", 4, 258894},
	{"ULRH", 4, 258895},
	{"UGIF", 4, 258896},
	{"UBOE", 4, 258897},
	{"TUYE", 4, 258898},
	{"TGMI", 4, 258899},
	{"TDSF", 4, 258900},
	{"SVCO", 4, 258901},
	{"SUMK", 4, 258902},
	{"SUAK", 4, 258903},
	{"SRPO", 4, 258904},
	{"SLFI", 4, 258905},
	{"SHUX", 4, 258906},
	{"SDRN", 4, 258907},
	{"RRLI", 4, 258908},
	{"RPRS", 4, 258909},
	{"RPGG", 4, 258910},
	{"RHOK", 4, 258911},
	{"RFWE", 4, 258912},
	{"RDZH", 4, 258913},
	{"RAFV", 4, 258914},
	{"PNCL", 4, 258915},
	{"PGCA", 4, 258916},
	{"PEEU", 4, 258917},
	{"PAKR", 4, 258918},
	{"OXTV", 4, 258919},
	{"OUMC", 4, 258920},
	{"ODRB", 4, 258921},
	{"NPPP", 4, 258922},
	{"NMFT", 4, 258923},
	{"NLBE", 4, 258924},
	{"NKIU", 4, 258925},
	{"NDWN", 4, 258926},
	{"NBLY", 4, 258927},
	{"MYRR", 4, 258928},
	{"LNGU", 4, 258929},
	{"LBWE", 4, 258930},
	{"KYIW", 4, 258931},
	{"KVOR", 4, 258932},
	{"KSOK", 4, 258933},
	{"KSFT", 4, 258934},
	{"KOLU", 4, 258935},
	{"KLIL", 4, 258936},
	{"KLAF", 4, 258937},
	{"KIAU", 4, 258938},
	{"KFON", 4, 258939},
	{"KDAH", 4, 258940},
	{"JOPA", 4, 258941},
	{"JEDW", 4, 258942},
	{"IYAU", 4, 258943},
	{"IVBA", 4, 258944},
	{"IUBI", 4, 258945},
	{"IGYM", 4, 258946},
	{"HOGC", 4, 258947},
	{"HCEC", 4, 258948},
	{"GUOF", 4, 258949},
	{"FSYI", 4, 258950},
	{"FLYZ", 4, 258951},
	{"ERHC", 4, 258952},
	{"EPRF", 4, 258953},
	{"EBTV", 4, 258954},
	{"DUNY", 4, 258955},
	{"DJAA", 4, 258956},
	{"DGOY", 4, 258957},
	{"DFUK", 4, 258958},
	{"DFUD", 4, 258959},
	{"DBWA", 4, 258960},
	{"CKUL", 4, 258961},
	{"CEAX", 4, 258962},
	{"BYIW", 4, 258963},
	{"BINQ", 4, 258964},
	{"BBSJ", 4, 258965},
	{"AOLM", 4, 258966},
	{"AABW", 4, 258967},
	{"BIOPIRACY", 9, 258968},
	{"STAYER", 6, 258969},
	{"SKORPION", 8, 258970},
	{"WYX", 3, 258971},
	{"FSPNET", 6, 258972},
	{"REVOLTEC", 8, 258973},
	{"KERATOMILEUSIS", 14, 258974},
	{"EKANE", 5, 258975},
	{"DISTORTIONARY", 13, 258976},
	{"BOKARO", 6, 258977},
	{"WINNICOTT", 9, 258978},
	{"PAYSAGES", 8, 258979},
	{"NUNAVAT", 7, 258980},
	{"MINSHALL", 8, 258981},
	{"FLEADH", 6, 258982},
	{"BOLEK", 5, 258983},
	{"LEVOTHROID", 10, 258984},
	{"DINEOUT", 7, 258985},
	{"CATHERINA", 9, 258986},
	{"BOKTAI", 6, 258987},
	{"ANDRIST", 7, 258988},
	{"VNEXPRESS", 9, 258989},
	{"PYPER", 5, 258990},
	{"PAVUK", 5, 258991},
	{"MIEEE", 5, 258992},
	{"DIEGUITO", 8, 258993},
	{"LUBRENSE", 8, 258994},
	{"TRAVROUTE", 9, 258995},
	{"EVENUE", 6, 258996},
	{"DYSPROSIUM", 10, 258997},
	{"TWEAKUI", 7, 258998},
	{"COMPUTERGAMES", 13, 258999},
	{"SPORTSDESK", 10, 259000},
	{"RANTHAMBHORE", 12, 259001},
	{"CONSEQUENTIALLY", 15, 259002},
	{"LCQ", 3, 259003},
	{"DISMISSIVELY", 12, 259004},
	{"INTTD", 5, 259005},
	{"PUTBACK", 7, 259006},
	{"SANIDAD", 7, 259007},
	{"COCCOLITHUS", 11, 259008},
	{"PRATUNAM", 8, 259009},
	{"PLAMO", 5, 259010},
	{"AIRSERVICES", 11, 259011},
	{"HOUSD", 5, 259012},
	{"DYAR", 4, 259013},
	{"AERICAN", 7, 259014},
	{"DENISA", 6, 259015},
	{"BLOGO", 5, 259016},
	{"SDAVIS", 6, 259017},
	{"LIFEGUARDING", 12, 259018},
	{"AMALEKITES", 10, 259019},
	{"TRICHLOROETHENE", 15, 259020},
	{"ARROCHAR", 8, 259021},
	{"ZEITLER", 7, 259022},
	{"BREDENBERG", 10, 259023},
	{"ZAMBON", 6, 259024},
	{"OSSANA", 6, 259025},
	{"ORGRIMMAR", 9, 259026},
	{"DIAPHRAM", 8, 259027},
	{"TACRINE", 7, 259028},
	{"POETES", 6, 259029},
	{"LIZATION", 8, 259030},
	{"CHEME", 5, 259031},
	{"ALLMOST", 7, 259032},
	{"SOMITES", 7, 259033},
	{"LIGHTWARE", 9, 259034},
	{"ELISION", 7, 259035},
	{"DRAFTHOUSE", 10, 259036},
	{"STOMATOL", 8, 259037},
	{"METIER", 6, 259038},
	{"PERSONNAGES", 11, 259039},
	{"FORMNAME", 8, 259040},
	{"AURAVISION", 10, 259041},
	{"GLIM", 4, 259042},
	{"GLENFORD", 8, 259043},
	{"TFPSAT", 6, 259044},
	{"CINK", 4, 259045},
	{"SALTINE", 7, 259046},
	{"FROB", 4, 259047},
	{"DEMOISELLE", 10, 259048},
	{"BOYLAND", 7, 259049},
	{"BLOXOM", 6, 259050},
	{"KURDO", 5, 259051},
	{"BILLPAY", 7, 259052},
	{"VERLAGSGRUPPE", 13, 259053},
	{"OPTOCOUPLERS", 12, 259054},
	{"ATHELSTANE", 10, 259055},
	{"ARCHZOOM", 8, 259056},
	{"MASSEYS", 7, 259057},
	{"LISPWORKS", 9, 259058},
	{"JABATAN", 7, 259059},
	{"DITTA", 5, 259060},
	{"ANSCO", 5, 259061},
	{"SCHEMERS", 8, 259062},
	{"UNHAMPERED", 10, 259063},
	{"OLYMPIADS", 9, 259064},
	{"NEWSFLASHES", 11, 259065},
	{"FITNESSPHOTOS", 13, 259066},
	{"ATENVELDT", 9, 259067},
	{"REPRODUC", 8, 259068},
	{"NPFIT", 5, 259069},
	{"SOSTENIBLE", 10, 259070},
	{"SECTIONPREVIOUS", 15, 259071},
	{"OGGOK", 5, 259072},
	{"HASHER", 6, 259073},
	{"HARKAT", 6, 259074},
	{"DUNGEN", 6, 259075},
	{"CGCG", 4, 259076},
	{"MONOCOTS", 8, 259077},
	{"DESJARLAIS", 10, 259078},
	{"URODYNAMIC", 10, 259079},
	{"STELLARIA", 9, 259080},
	{"SCENERIO", 8, 259081},
	{"OSSMAN", 6, 259082},
	{"MATELAS", 7, 259083},
	{"MADSCI", 6, 259084},
	{"NOLD", 4, 259085},
	{"HAVLICEK", 8, 259086},
	{"XIZANG", 6, 259087},
	{"PUISSE", 6, 259088},
	{"MELWOOD", 7, 259089},
	{"CRIMBO", 6, 259090},
	{"ERGOGENIC", 9, 259091},
	{"CONVOLVED", 9, 259092},
	{"STAKKA", 6, 259093},
	{"MUCHENJE", 8, 259094},
	{"FITZALAN", 8, 259095},
	{"DEATHERAGE", 10, 259096},
	{"CARMUSTINE", 10, 259097},
	{"ALEICHEM", 8, 259098},
	{"RAFAELA", 7, 259099},
	{"FLUORENE", 8, 259100},
	{"CONTROLPANEL", 12, 259101},
	{"CLARISWORKS", 11, 259102},
	{"AGWNA", 5, 259103},
	{"ZEPPO", 5, 259104},
	{"TORTOSA", 7, 259105},
	{"SUMMERSET", 9, 259106},
	{"NATOLI", 6, 259107},
	{"JWHOIS", 6, 259108},
	{"TRAGEL", 6, 259109},
	{"TECHNOSONIC", 11, 259110},
	{"INDISSOLUBLE", 12, 259111},
	{"HAEFNER", 7, 259112},
	{"DVORKIN", 7, 259113},
	{"BOLEX", 5, 259114},
	{"PNAX", 4, 259115},
	{"OSTRA", 5, 259116},
	{"NFUSE", 5, 259117},
	{"COROUTINES", 10, 259118},
	{"AECB", 4, 259119},
	{"UAED", 4, 259120},
	{"HUGUESDB", 8, 259121},
	{"AMPEROMETRIC", 12, 259122},
	{"PICTUREBOX", 10, 259123},
	{"FREEHILLS", 9, 259124},
	{"ARGENTOVIVO", 11, 259125},
	{"ACCELLION", 9, 259126},
	{"TABULARIUM", 10, 259127},
	{"LUYKEN", 6, 259128},
	{"YPOYRGO", 7, 259129},
	{"USERFILE", 8, 259130},
	{"JOLIVET", 7, 259131},
	{"COMPUSEARCH", 11, 259132},
	{"PROEHL", 6, 259133},
	{"HELTH", 5, 259134},
	{"SRCBLOCK", 8, 259135},
	{"PARTEE", 6, 259136},
	{"JINJIANG", 8, 259137},
	{"ISRINGHAUSEN", 12, 259138},
	{"DIRCTORY", 8, 259139},
	{"CROCKET", 7, 259140},
	{"STRINGPREP", 10, 259141},
	{"KREATEL", 7, 259142},
	{"POLYANDRY", 9, 259143},
	{"JOHNNO", 6, 259144},
	{"BUSHED", 6, 259145},
	{"BFU", 3, 259146},
	{"UNTAINT", 7, 259147},
	{"MANORAMA", 8, 259148},
	{"KLONE", 5, 259149},
	{"GOURAUD", 7, 259150},
	{"CFDC", 4, 259151},
	{"FFCJ", 4, 259152},
	{"DATCHET", 7, 259153},
	{"ARYDI", 5, 259154},
	{"ARNISTON", 8, 259155},
	{"FINGS", 5, 259156},
	{"CYSTICERCOSIS", 13, 259157},
	{"SMARTECH", 8, 259158},
	{"BIGMOUTHMEDIA", 13, 259159},
	{"TELECENTERS", 11, 259160},
	{"KOSTIS", 6, 259161},
	{"DELILA", 6, 259162},
	{"CAMICIE", 7, 259163},
	{"CAMC", 4, 259164},
	{"MAJI", 4, 259165},
	{"CORRER", 6, 259166},
	{"COLUMNED", 8, 259167},
	{"BOBCAYGEON", 10, 259168},
	{"HOKIANGA", 8, 259169},
	{"GAELTACHTA", 10, 259170},
	{"BERHANE", 7, 259171},
	{"TATOR", 5, 259172},
	{"STEREOTYPIC", 11, 259173},
	{"PASAREL", 7, 259174},
	{"JUGCENTRAL", 10, 259175},
	{"CAMERACANON", 11, 259176},
	{"SUMING", 6, 259177},
	{"GLASSHOUSES", 11, 259178},
	{"FISIOLOGIA", 10, 259179},
	{"BIGHEAD", 7, 259180},
	{"TORVALD", 7, 259181},
	{"PHOTOART", 8, 259182},
	{"MACROOM", 7, 259183},
	{"PSYCHOCHIC", 10, 259184},
	{"BARANSKI", 8, 259185},
	{"ONSUMER", 7, 259186},
	{"MECANIQUE", 9, 259187},
	{"FERNO", 5, 259188},
	{"CHOREOGRAPHIES", 14, 259189},
	{"BICONES", 7, 259190},
	{"AIRTRAVEL", 9, 259191},
	{"WICKREMESINGHE", 14, 259192},
	{"RECVD", 5, 259193},
	{"TULKARM", 7, 259194},
	{"REACCREDITATION", 15, 259195},
	{"ZCIN", 4, 259196},
	{"MAINTAINE", 9, 259197},
	{"CNBCWLD", 7, 259198},
	{"AMAROO", 6, 259199},
	{"TISHMAN", 7, 259200},
	{"SOLEPLATE", 9, 259201},
	{"KEYPOINT", 8, 259202},
	{"DATACOLUMN", 10, 259203},
	{"UNOWNED", 7, 259204},
	{"PROTOPLAST", 10, 259205},
	{"LOVATT", 6, 259206},
	{"JILDOR", 6, 259207},
	{"BISHARA", 7, 259208},
	{"CNOC", 4, 259209},
	{"CANY", 4, 259210},
	{"NEWCHURCH", 9, 259211},
	{"CENSORIAL", 9, 259212},
	{"INDPLS", 6, 259213},
	{"ESCAMILLA", 9, 259214},
	{"CIPKA", 5, 259215},
	{"SPRINGTAILS", 11, 259216},
	{"LAMECH", 6, 259217},
	{"NICETY", 6, 259218},
	{"MYTOB", 5, 259219},
	{"MOSCOU", 6, 259220},
	{"PROFUMO", 7, 259221},
	{"ORIGINALI", 9, 259222},
	{"KENTUCK", 7, 259223},
	{"IMAGEWARE", 9, 259224},
	{"EZCONTENTOBJECTATTRIBUTE", 24, 259225},
	{"MEDIWIRE", 8, 259226},
	{"LYF", 3, 259227},
	{"LAAKSONEN", 9, 259228},
	{"BECC", 4, 259229},
	{"TRAINNING", 9, 259230},
	{"NETLANTIS", 9, 259231},
	{"PAYDIRT", 7, 259232},
	{"NURA", 4, 259233},
	{"FLARION", 7, 259234},
	{"ENLIGHTMENT", 11, 259235},
	{"CLYDESDALES", 11, 259236},
	{"AUTREY", 6, 259237},
	{"SUBTERRANEA", 11, 259238},
	{"VIAPAL", 6, 259239},
	{"TRKS", 4, 259240},
	{"INTARWEB", 8, 259241},
	{"BACKBENCH", 9, 259242},
	{"TABLESPOONFULS", 14, 259243},
	{"NATALIYA", 8, 259244},
	{"MIDIFILE", 8, 259245},
	{"MALOS", 5, 259246},
	{"WITTICISMS", 10, 259247},
	{"MORDIALLOC", 10, 259248},
	{"ALJZ", 4, 259249},
	{"MSEB", 4, 259250},
	{"MAILENABLE", 10, 259251},
	{"COEYMANS", 8, 259252},
	{"AAJTK", 5, 259253},
	{"WAIG", 4, 259254},
	{"DUPATTA", 7, 259255},
	{"AGUILAS", 7, 259256},
	{"STRONIE", 7, 259257},
	{"SPORTSPERSON", 12, 259258},
	{"SCARABAEIDAE", 12, 259259},
	{"ANONG", 5, 259260},
	{"ALTENA", 6, 259261},
	{"SHIPPIN", 7, 259262},
	{"RIAGE", 5, 259263},
	{"RAFFARIN", 8, 259264},
	{"JAVACRAWL", 9, 259265},
	{"ZODO", 4, 259266},
	{"ZEGU", 4, 259267},
	{"ZCZY", 4, 259268},
	{"ZAJO", 4, 259269},
	{"YPCO", 4, 259270},
	{"YELC", 4, 259271},
	{"YBCI", 4, 259272},
	{"XVIT", 4, 259273},
	{"XPAL", 4, 259274},
	{"XIFR", 4, 259275},
	{"WUMA", 4, 259276},
	{"WOAX", 4, 259277},
	{"VOLB", 4, 259278},
	{"VEMM", 4, 259279},
	{"UZOV", 4, 259280},
	{"UYBY", 4, 259281},
	{"URMR", 4, 259282},
	{"UHUM", 4, 259283},
	{"UGII", 4, 259284},
	{"SDJP", 4, 259285},
	{"RYCZ", 4, 259286},
	{"RUKW", 4, 259287},
	{"RSWW", 4, 259288},
	{"RPGM", 4, 259289},
	{"QMIA", 4, 259290},
	{"PMCR", 4, 259291},
	{"PEMM", 4, 259292},
	{"OYQU", 4, 259293},
	{"OSKR", 4, 259294},
	{"ORJC", 4, 259295},
	{"OPUG", 4, 259296},
	{"OMCW", 4, 259297},
	{"OHGR", 4, 259298},
	{"OFVY", 4, 259299},
	{"NMSF", 4, 259300},
	{"NIDK", 4, 259301},
	{"NFEY", 4, 259302},
	{"NDUQ", 4, 259303},
	{"MYUT", 4, 259304},
	{"MGEL", 4, 259305},
	{"LSLT", 4, 259306},
	{"LMUA", 4, 259307},
	{"LLVU", 4, 259308},
	{"LIQA", 4, 259309},
	{"LAQA", 4, 259310},
	{"JRSC", 4, 259311},
	{"INBJ", 4, 259312},
	{"IFWR", 4, 259313},
	{"HVAG", 4, 259314},
	{"HMRW", 4, 259315},
	{"HLWE", 4, 259316},
	{"HIRF", 4, 259317},
	{"GOXI", 4, 259318},
	{"GIDU", 4, 259319},
	{"FMSM", 4, 259320},
	{"FLBA", 4, 259321},
	{"FKED", 4, 259322},
	{"FBEO", 4, 259323},
	{"EXSB", 4, 259324},
	{"EVOV", 4, 259325},
	{"ETMM", 4, 259326},
	{"EMTB", 4, 259327},
	{"EGRN", 4, 259328},
	{"EBGE", 4, 259329},
	{"DJRE", 4, 259330},
	{"DIPF", 4, 259331},
	{"DIIF", 4, 259332},
	{"DGNE", 4, 259333},
	{"DEWC", 4, 259334},
	{"BRTH", 4, 259335},
	{"BICG", 4, 259336},
	{"BCOD", 4, 259337},
	{"ALXR", 4, 259338},
	{"ADNC", 4, 259339},
	{"TOUTPUT", 7, 259340},
	{"STWFLWAR", 8, 259341},
	{"SPINDEL", 7, 259342},
	{"HOWREY", 6, 259343},
	{"HALIMA", 6, 259344},
	{"LENNA", 5, 259345},
	{"IFRAH", 5, 259346},
	{"SHAABAN", 7, 259347},
	{"FLIEGEN", 7, 259348},
	{"SLOVIC", 6, 259349},
	{"ENVIRONEMENT", 12, 259350},
	{"AUTHORIT", 8, 259351},
	{"KEGWORTH", 8, 259352},
	{"GOKART", 6, 259353},
	{"BROWNOUTS", 9, 259354},
	{"ASKERIC", 7, 259355},
	{"RIGOBERTO", 9, 259356},
	{"ONLEIN", 6, 259357},
	{"ENFEEBLED", 9, 259358},
	{"ETUDIANTE", 9, 259359},
	{"CFILE", 5, 259360},
	{"ZGUJ", 4, 259361},
	{"VASILIY", 7, 259362},
	{"CRQ", 3, 259363},
	{"CORNUTA", 7, 259364},
	{"TIPPIE", 6, 259365},
	{"SHARECROPPERS", 13, 259366},
	{"RELINING", 8, 259367},
	{"LOCALL", 6, 259368},
	{"GOVERMENTS", 10, 259369},
	{"VIVAL", 5, 259370},
	{"TFAVEL", 6, 259371},
	{"ARTMUSIC", 8, 259372},
	{"MEINRAD", 7, 259373},
	{"ELLEAFTYPE", 10, 259374},
	{"BURANO", 6, 259375},
	{"JERRELL", 7, 259376},
	{"HERFINDAHL", 10, 259377},
	{"FROX", 4, 259378},
	{"DIENTES", 7, 259379},
	{"PARTENER", 8, 259380},
	{"MILLIONARE", 10, 259381},
	{"CONTEXTUALISED", 14, 259382},
	{"CLEARSILVER", 11, 259383},
	{"TRAFTON", 7, 259384},
	{"JHUMPA", 6, 259385},
	{"TYRANNIS", 8, 259386},
	{"KEKAHA", 6, 259387},
	{"GEERTS", 6, 259388},
	{"TATRY", 5, 259389},
	{"MEGATV", 6, 259390},
	{"MARTINSEN", 9, 259391},
	{"KOIKA", 5, 259392},
	{"INGOMAR", 7, 259393},
	{"DLV", 3, 259394},
	{"WWWFREE", 7, 259395},
	{"WETTBEWERB", 10, 259396},
	{"SPEICAL", 7, 259397},
	{"PROCTORING", 10, 259398},
	{"SHIPPEN", 7, 259399},
	{"GADHAFI", 7, 259400},
	{"FISCHL", 6, 259401},
	{"ANYANG", 6, 259402},
	{"SORBITAN", 8, 259403},
	{"RETREADS", 8, 259404},
	{"MASSCOT", 7, 259405},
	{"LRMP", 4, 259406},
	{"BUCHREZENSIONEN", 15, 259407},
	{"PERISHER", 8, 259408},
	{"PARRYING", 8, 259409},
	{"MUSCADINE", 9, 259410},
	{"ENTEROVIRUSES", 13, 259411},
	{"ABNEHMEN", 8, 259412},
	{"SPEZIALI", 8, 259413},
	{"JINDALEE", 8, 259414},
	{"AMPERSANDS", 10, 259415},
	{"AMBULANT", 8, 259416},
	{"MUGA", 4, 259417},
	{"LJSF", 4, 259418},
	{"LISTI", 5, 259419},
	{"GILLIAP", 7, 259420},
	{"FELDBERG", 8, 259421},
	{"ANIMESUKI", 9, 259422},
	{"VOKEY", 5, 259423},
	{"NTVPL", 5, 259424},
	{"NATCHER", 7, 259425},
	{"BLADESYSTEM", 11, 259426},
	{"RAMGARH", 7, 259427},
	{"CDFIS", 5, 259428},
	{"WOWTVD", 6, 259429},
	{"EMPSON", 6, 259430},
	{"THIOLASE", 8, 259431},
	{"RAVID", 5, 259432},
	{"ARTAMER", 7, 259433},
	{"SOFTPHONES", 10, 259434},
	{"GRANAT", 6, 259435},
	{"EJACULATES", 10, 259436},
	{"WINTASK", 7, 259437},
	{"PESTI", 5, 259438},
	{"FURIN", 5, 259439},
	{"SURVEILLER", 10, 259440},
	{"GURINDER", 8, 259441},
	{"SHIVAREE", 8, 259442},
	{"RELINKING", 9, 259443},
	{"READFIELD", 9, 259444},
	{"MANEGARM", 8, 259445},
	{"BATTERIEN", 9, 259446},
	{"SSRASH", 6, 259447},
	{"SAVATE", 6, 259448},
	{"KINOPOL", 7, 259449},
	{"ALBERTAN", 8, 259450},
	{"JUNCKER", 7, 259451},
	{"EASYMOUNT", 9, 259452},
	{"ACCMU", 5, 259453},
	{"SEKAR", 5, 259454},
	{"INCONSISTANT", 12, 259455},
	{"DELISI", 6, 259456},
	{"ANDX", 4, 259457},
	{"TUFTING", 7, 259458},
	{"MUCILAGE", 8, 259459},
	{"HPUSE", 5, 259460},
	{"WATEVER", 7, 259461},
	{"REVOLUTIONISTS", 14, 259462},
	{"BRAINSTER", 9, 259463},
	{"PACESETTERS", 11, 259464},
	{"STDMETHOD", 9, 259465},
	{"PETICOLAS", 9, 259466},
	{"MORBO", 5, 259467},
	{"MASTOPEXY", 9, 259468},
	{"COZEN", 5, 259469},
	{"OLITA", 5, 259470},
	{"NEXTDAY", 7, 259471},
	{"MENEFEE", 7, 259472},
	{"TRISODIUM", 9, 259473},
	{"PELAGIUS", 8, 259474},
	{"MIDDEL", 6, 259475},
	{"HOUAE", 5, 259476},
	{"GALAXIAS", 8, 259477},
	{"SINGAL", 6, 259478},
	{"LACANIAN", 8, 259479},
	{"HATFILL", 7, 259480},
	{"DUMARESQ", 8, 259481},
	{"AMOF", 4, 259482},
	{"EDITPAD", 7, 259483},
	{"AUTOWARRANTY", 12, 259484},
	{"XPHOME", 6, 259485},
	{"VORP", 4, 259486},
	{"SCHWEIGERT", 10, 259487},
	{"CVCL", 4, 259488},
	{"LUFIA", 5, 259489},
	{"BUUG", 4, 259490},
	{"BLANDON", 7, 259491},
	{"AIRGLOW", 7, 259492},
	{"TUSC", 4, 259493},
	{"SEBORRHEA", 9, 259494},
	{"RUTACEAE", 8, 259495},
	{"COMEDYSPORTZ", 12, 259496},
	{"BOVERI", 6, 259497},
	{"STREETSVILLE", 12, 259498},
	{"RAFINESQUE", 10, 259499},
	{"PORTCHESTER", 11, 259500},
	{"GEEKMAP", 7, 259501},
	{"OSCILLATED", 10, 259502},
	{"OLIVACEUS", 9, 259503},
	{"BOPHUTHATSWANA", 14, 259504},
	{"TRAVDL", 6, 259505},
	{"MUSEUMKIDS", 10, 259506},
	{"KILLERMOVIES", 12, 259507},
	{"HOLLIN", 6, 259508},
	{"GANGREL", 7, 259509},
	{"ARCHETYPICAL", 12, 259510},
	{"ADAJJA", 6, 259511},
	{"SHEREMETYEVO", 12, 259512},
	{"RADIOGRAPHICALLY", 16, 259513},
	{"MUSIKAL", 7, 259514},
	{"LANGMAN", 7, 259515},
	{"VERSTAPPEN", 10, 259516},
	{"TEMORA", 6, 259517},
	{"PENITENTS", 9, 259518},
	{"KNOBLOCK", 8, 259519},
	{"TOYSCAMP", 8, 259520},
	{"TALKTALK", 8, 259521},
	{"LICENCEES", 9, 259522},
	{"BOSSIDY", 7, 259523},
	{"PVF", 3, 259524},
	{"MRID", 4, 259525},
	{"KULPSVILLE", 10, 259526},
	{"SUTU", 4, 259527},
	{"LINDEMULDER", 11, 259528},
	{"WNTR", 4, 259529},
	{"PHAMACY", 7, 259530},
	{"LENNOXVILLE", 11, 259531},
	{"FASTREPORT", 10, 259532},
	{"BIOMCH", 6, 259533},
	{"ALIMTA", 6, 259534},
	{"ANNIHILATES", 11, 259535},
	{"OFFERTO", 7, 259536},
	{"LANOU", 5, 259537},
	{"IRITIS", 6, 259538},
	{"IMPRUDENCE", 10, 259539},
	{"COMISSIONS", 10, 259540},
	{"KOMPENDIUM", 10, 259541},
	{"VPG", 3, 259542},
	{"SASSAMAN", 8, 259543},
	{"GEOTV", 5, 259544},
	{"ECIJA", 5, 259545},
	{"SCORECARDING", 12, 259546},
	{"PACTIV", 6, 259547},
	{"CLADDAUGH", 9, 259548},
	{"OFERTY", 6, 259549},
	{"GLEANN", 6, 259550},
	{"BWXT", 4, 259551},
	{"RAIRD", 5, 259552},
	{"FONTEYN", 7, 259553},
	{"VARNELL", 7, 259554},
	{"RZESZOW", 7, 259555},
	{"KELKAR", 6, 259556},
	{"VEDIUS", 6, 259557},
	{"UOUSE", 5, 259558},
	{"RADVISION", 9, 259559},
	{"LEVESON", 7, 259560},
	{"GACC", 4, 259561},
	{"FCAR", 4, 259562},
	{"TIPTOED", 7, 259563},
	{"NUMEROFF", 8, 259564},
	{"KCLS", 4, 259565},
	{"AMBR", 4, 259566},
	{"KLIMOV", 6, 259567},
	{"ISKANDER", 8, 259568},
	{"FLIPPO", 6, 259569},
	{"LIMOGE", 6, 259570},
	{"PERATION", 8, 259571},
	{"PUREPOWER", 9, 259572},
	{"OPTICRON", 8, 259573},
	{"ADFERO", 6, 259574},
	{"HERSTMONCEUX", 12, 259575},
	{"PCHEM", 5, 259576},
	{"GLOMERULOSCLEROSIS", 18, 259577},
	{"FOLLOWIN", 8, 259578},
	{"COLLAGENS", 9, 259579},
	{"SECRETOS", 8, 259580},
	{"BEEVER", 6, 259581},
	{"SOFIELDCONTAINER", 16, 259582},
	{"BROOKHURST", 10, 259583},
	{"GHANEM", 6, 259584},
	{"EVOLUZIONE", 10, 259585},
	{"EIGENSPACE", 10, 259586},
	{"ARANCI", 6, 259587},
	{"CYBERSHIFT", 10, 259588},
	{"SPREADABLE", 10, 259589},
	{"SHINSUKE", 8, 259590},
	{"PENDLEY", 7, 259591},
	{"NOLLE", 5, 259592},
	{"DOGMATICALLY", 12, 259593},
	{"APHASIE", 7, 259594},
	{"SEGRETA", 7, 259595},
	{"SCHOENHERR", 10, 259596},
	{"ROOTDIR", 7, 259597},
	{"MULTICOLUMN", 11, 259598},
	{"BANNABLE", 8, 259599},
	{"WORLDSTREAM", 11, 259600},
	{"YASUHIKO", 8, 259601},
	{"PHENOTHIAZINE", 13, 259602},
	{"METLAKATLA", 10, 259603},
	{"MESIAL", 6, 259604},
	{"CADCAM", 6, 259605},
	{"BSTATIC", 7, 259606},
	{"WORLDBEAT", 9, 259607},
	{"FLAUTIST", 8, 259608},
	{"ENTREPENEURS", 12, 259609},
	{"DOTNETSLACKERS", 14, 259610},
	{"CHAIRLIFTS", 10, 259611},
	{"REICHER", 7, 259612},
	{"OYER", 4, 259613},
	{"DELORS", 6, 259614},
	{"PUER", 4, 259615},
	{"MIXI", 4, 259616},
	{"OBDII", 5, 259617},
	{"ELNEXT", 6, 259618},
	{"SLEEZY", 6, 259619},
	{"ROMIG", 5, 259620},
	{"GULLETT", 7, 259621},
	{"CREATEWITH", 10, 259622},
	{"CARTELES", 8, 259623},
	{"MAGYARS", 7, 259624},
	{"AGNETA", 6, 259625},
	{"MILIS", 5, 259626},
	{"LBCC", 4, 259627},
	{"CHILLINGWORTH", 13, 259628},
	{"URUM", 4, 259629},
	{"MRCA", 4, 259630},
	{"LIBRUS", 6, 259631},
	{"LOCALFILE", 9, 259632},
	{"SETRLIMIT", 9, 259633},
	{"RESIPES", 7, 259634},
	{"MYRTLES", 7, 259635},
	{"ANDALO", 6, 259636},
	{"NONIMMIGRANTS", 13, 259637},
	{"MOGGY", 5, 259638},
	{"INTERBORO", 9, 259639},
	{"ZESZ", 4, 259640},
	{"ZEKW", 4, 259641},
	{"YNIB", 4, 259642},
	{"YLRA", 4, 259643},
	{"YIZH", 4, 259644},
	{"XMEX", 4, 259645},
	{"WNGP", 4, 259646},
	{"WMCG", 4, 259647},
	{"VPSE", 4, 259648},
	{"VEWY", 4, 259649},
	{"UTZL", 4, 259650},
	{"UKUW", 4, 259651},
	{"UIYA", 4, 259652},
	{"UINQ", 4, 259653},
	{"TTGL", 4, 259654},
	{"TPWH", 4, 259655},
	{"TLLN", 4, 259656},
	{"TKIW", 4, 259657},
	{"SZUB", 4, 259658},
	{"SVMA", 4, 259659},
	{"RSLD", 4, 259660},
	{"RRTE", 4, 259661},
	{"RPEX", 4, 259662},
	{"RHPD", 4, 259663},
	{"RGMC", 4, 259664},
	{"RBUK", 4, 259665},
	{"RBEZ", 4, 259666},
	{"QUMR", 4, 259667},
	{"PHSY", 4, 259668},
	{"PAUI", 4, 259669},
	{"OHRW", 4, 259670},
	{"OFLM", 4, 259671},
	{"OEPF", 4, 259672},
	{"NGJP", 4, 259673},
	{"NEFC", 4, 259674},
	{"MSSR", 4, 259675},
	{"MLHA", 4, 259676},
	{"MIGM", 4, 259677},
	{"LZIP", 4, 259678},
	{"LULS", 4, 259679},
	{"KSIP", 4, 259680},
	{"KOLP", 4, 259681},
	{"JPMF", 4, 259682},
	{"JAIC", 4, 259683},
	{"IYSK", 4, 259684},
	{"IRLV", 4, 259685},
	{"HYNU", 4, 259686},
	{"HRWI", 4, 259687},
	{"HIDK", 4, 259688},
	{"GUAH", 4, 259689},
	{"GOWM", 4, 259690},
	{"GKUA", 4, 259691},
	{"GGSV", 4, 259692},
	{"GGFA", 4, 259693},
	{"GDPH", 4, 259694},
	{"FZHU", 4, 259695},
	{"FTEP", 4, 259696},
	{"FGOW", 4, 259697},
	{"FCEY", 4, 259698},
	{"FAPT", 4, 259699},
	{"EZUI", 4, 259700},
	{"ERJB", 4, 259701},
	{"DYSJ", 4, 259702},
	{"DGTA", 4, 259703},
	{"DCSW", 4, 259704},
	{"CTTV", 4, 259705},
	{"CRYC", 4, 259706},
	{"COSQ", 4, 259707},
	{"CORJ", 4, 259708},
	{"CIUL", 4, 259709},
	{"CDUM", 4, 259710},
	{"CDOI", 4, 259711},
	{"CCAJ", 4, 259712},
	{"BYNM", 4, 259713},
	{"BYDN", 4, 259714},
	{"AYLL", 4, 259715},
	{"RENOVO", 6, 259716},
	{"MROE", 4, 259717},
	{"CHAPUNGU", 8, 259718},
	{"CAMPHILL", 8, 259719},
	{"PINKARD", 7, 259720},
	{"JAILBIRD", 8, 259721},
	{"APROXIMATELY", 12, 259722},
	{"SISULU", 6, 259723},
	{"PASHTUNISTAN", 12, 259724},
	{"NAFZIGER", 8, 259725},
	{"CIOB", 4, 259726},
	{"ZASTAVA", 7, 259727},
	{"PANISSE", 7, 259728},
	{"EDGINESS", 8, 259729},
	{"COMPABILITY", 11, 259730},
	{"REBUYS", 6, 259731},
	{"PIENSA", 6, 259732},
	{"LANDSER", 7, 259733},
	{"KABEER", 6, 259734},
	{"INTERARRIVAL", 12, 259735},
	{"SHIFFLETT", 9, 259736},
	{"CIVILITIES", 10, 259737},
	{"TRIEST", 6, 259738},
	{"PPAI", 4, 259739},
	{"TRENHOLM", 8, 259740},
	{"TITMUS", 6, 259741},
	{"GUCCIONE", 8, 259742},
	{"DEISGN", 6, 259743},
	{"ATHEROGENESIS", 13, 259744},
	{"AGWAY", 5, 259745},
	{"LEZCANO", 7, 259746},
	{"XAND", 4, 259747},
	{"XADD", 4, 259748},
	{"OSTERHAUS", 9, 259749},
	{"FOLCROFT", 8, 259750},
	{"CCEL", 4, 259751},
	{"SUOMINEN", 8, 259752},
	{"SIDERING", 8, 259753},
	{"BIOHAZARDS", 10, 259754},
	{"UNJLC", 5, 259755},
	{"TEMBEC", 6, 259756},
	{"DIPHTHONG", 9, 259757},
	{"BRES", 4, 259758},
	{"NATOR", 5, 259759},
	{"BLUS", 4, 259760},
	{"UNCF", 4, 259761},
	{"THREADPOOL", 10, 259762},
	{"RANTISI", 7, 259763},
	{"MEWBURN", 7, 259764},
	{"ARONS", 5, 259765},
	{"SENAST", 6, 259766},
	{"EMBLEMATA", 9, 259767},
	{"APSARA", 6, 259768},
	{"GLYNCO", 6, 259769},
	{"FLUFFER", 7, 259770},
	{"WITNESSETH", 10, 259771},
	{"SATUN", 5, 259772},
	{"BSAFE", 5, 259773},
	{"CRUISECARIBBEAN", 15, 259774},
	{"SHIMBA", 6, 259775},
	{"KSCD", 4, 259776},
	{"BLADER", 6, 259777},
	{"ATVHC", 5, 259778},
	{"TRUSSED", 7, 259779},
	{"SPOMESS", 7, 259780},
	{"CARDSCREDIT", 11, 259781},
	{"TUNEZ", 5, 259782},
	{"TACNA", 5, 259783},
	{"KIBBUTZIM", 9, 259784},
	{"DATAI", 5, 259785},
	{"ABLETT", 6, 259786},
	{"USAMO", 5, 259787},
	{"SEARCHASSISTANT", 15, 259788},
	{"MANDOLF", 7, 259789},
	{"ELLERBEE", 8, 259790},
	{"BRIGMAN", 7, 259791},
	{"KERATOTOMY", 10, 259792},
	{"XERISCAPING", 11, 259793},
	{"SCENARIST", 9, 259794},
	{"RAFIKI", 6, 259795},
	{"MEIKLEJOHN", 10, 259796},
	{"SATCON", 6, 259797},
	{"POLYAMOROUS", 11, 259798},
	{"APICULTURE", 10, 259799},
	{"LATPOP", 6, 259800},
	{"JHEAD", 5, 259801},
	{"CSSB", 4, 259802},
	{"PARAEDUCATORS", 13, 259803},
	{"GUB", 3, 259804},
	{"DIECTORY", 8, 259805},
	{"CUV", 3, 259806},
	{"CADIGAN", 7, 259807},
	{"WILDCHILD", 9, 259808},
	{"SWEETLEAF", 9, 259809},
	{"GAYMAN", 6, 259810},
	{"PETRINI", 7, 259811},
	{"BALDUCCI", 8, 259812},
	{"WELLSFORD", 9, 259813},
	{"BROWSERSHOTS", 12, 259814},
	{"BRANI", 5, 259815},
	{"TECHNOPARK", 10, 259816},
	{"ETHERIA", 7, 259817},
	{"DULCET", 6, 259818},
	{"MIAMIX", 6, 259819},
	{"KOHIMA", 6, 259820},
	{"CAVIES", 6, 259821},
	{"SCHWARZBAUM", 11, 259822},
	{"PERIN", 5, 259823},
	{"MODIFI", 6, 259824},
	{"LATSTY", 6, 259825},
	{"ECHOJAN", 7, 259826},
	{"DREGER", 6, 259827},
	{"CELESTINO", 9, 259828},
	{"AUDFMEX", 7, 259829},
	{"TRAVEO", 6, 259830},
	{"SIRRAH", 6, 259831},
	{"GOSUDARSTVENNYI", 15, 259832},
	{"CNCP", 4, 259833},
	{"THORNLEIGH", 10, 259834},
	{"CECILIE", 7, 259835},
	{"LIYE", 4, 259836},
	{"GYMEA", 5, 259837},
	{"CRASSLY", 7, 259838},
	{"KOBOLDS", 7, 259839},
	{"CACY", 4, 259840},
	{"XFSDUMP", 7, 259841},
	{"VERZAMELINGEN", 13, 259842},
	{"SHADOWSONG", 10, 259843},
	{"RAMCHANDANI", 11, 259844},
	{"JANETS", 6, 259845},
	{"TRAVSL", 6, 259846},
	{"REMLINGER", 9, 259847},
	{"PATINO", 6, 259848},
	{"HOMEDALE", 8, 259849},
	{"ANGOL", 5, 259850},
	{"MALHERBE", 8, 259851},
	{"GAYMONKEY", 9, 259852},
	{"EDUCAZIONE", 10, 259853},
	{"ULTRICES", 8, 259854},
	{"ROYDEN", 6, 259855},
	{"MATRIKON", 8, 259856},
	{"LIFEWATCH", 9, 259857},
	{"BRUMMETT", 8, 259858},
	{"AUTHORIZER", 10, 259859},
	{"WREG", 4, 259860},
	{"SALAMONE", 8, 259861},
	{"OKAWVILLE", 9, 259862},
	{"MENTMORE", 8, 259863},
	{"MACKER", 6, 259864},
	{"TANGLIN", 7, 259865},
	{"RIGOBERTA", 9, 259866},
	{"INDOWS", 6, 259867},
	{"CALLUNA", 7, 259868},
	{"ALBERO", 6, 259869},
	{"VAVUNIYA", 8, 259870},
	{"FRCA", 4, 259871},
	{"BACTERIOLOGIST", 14, 259872},
	{"HOUEE", 5, 259873},
	{"MATTICK", 7, 259874},
	{"INTERMITTANT", 12, 259875},
	{"BIPS", 4, 259876},
	{"RAPPORTER", 9, 259877},
	{"EXPENSEWATCH", 12, 259878},
	{"COMPLEJO", 8, 259879},
	{"LOCHLYN", 7, 259880},
	{"BOEKE", 5, 259881},
	{"STUDIOLOGIC", 11, 259882},
	{"SENSITISE", 9, 259883},
	{"FESTAL", 6, 259884},
	{"DIYALA", 6, 259885},
	{"BRCM", 4, 259886},
	{"CHULO", 5, 259887},
	{"TOTURE", 6, 259888},
	{"QSYS", 4, 259889},
	{"MAXAGE", 6, 259890},
	{"CHEWIN", 6, 259891},
	{"WOLFFORTH", 9, 259892},
	{"SEMBRA", 6, 259893},
	{"SCOOBIES", 8, 259894},
	{"LONGUM", 6, 259895},
	{"RNEWS", 5, 259896},
	{"LEVENBERG", 9, 259897},
	{"FIPP", 4, 259898},
	{"BURROWES", 8, 259899},
	{"XEROSTOMIA", 10, 259900},
	{"OHMMETER", 8, 259901},
	{"MUSEET", 6, 259902},
	{"KINDRA", 6, 259903},
	{"DOMESTICATE", 11, 259904},
	{"ADFF", 4, 259905},
	{"ABDULLAHI", 9, 259906},
	{"SILAGRA", 7, 259907},
	{"RAYES", 5, 259908},
	{"LIGHTIN", 7, 259909},
	{"BOOKCOURIER", 11, 259910},
	{"PROLATE", 7, 259911},
	{"LUCKMAN", 7, 259912},
	{"LANTINGA", 8, 259913},
	{"WANNABEE", 8, 259914},
	{"TSAREVO", 7, 259915},
	{"MIRACOSTA", 9, 259916},
	{"KXK", 3, 259917},
	{"BERGEVIN", 8, 259918},
	{"KATERI", 6, 259919},
	{"BERROA", 6, 259920},
	{"YUENGLING", 9, 259921},
	{"FOLKBUM", 7, 259922},
	{"COUTEAU", 7, 259923},
	{"CAYRE", 5, 259924},
	{"BANKR", 5, 259925},
	{"AMATERASU", 9, 259926},
	{"PROCRIT", 7, 259927},
	{"CYTOXAN", 7, 259928},
	{"BARONNE", 7, 259929},
	{"SIMOVIC", 7, 259930},
	{"ISTHMIAN", 8, 259931},
	{"SUMBA", 5, 259932},
	{"PITTSTOWN", 9, 259933},
	{"ORGANIZACION", 12, 259934},
	{"KOOSKIA", 7, 259935},
	{"KAPLANSKY", 9, 259936},
	{"FRANCESCHI", 10, 259937},
	{"CLOU", 4, 259938},
	{"TUKI", 4, 259939},
	{"STATACORP", 9, 259940},
	{"INTERSPACE", 10, 259941},
	{"CEFZIL", 6, 259942},
	{"WJM", 3, 259943},
	{"TVOUT", 5, 259944},
	{"RECENTCHANGESLINKED", 19, 259945},
	{"PERDEW", 6, 259946},
	{"HEARTRENDING", 12, 259947},
	{"FASSUNG", 7, 259948},
	{"DEVOTEDLY", 9, 259949},
	{"UPCONVERT", 9, 259950},
	{"PLANCHER", 8, 259951},
	{"FPX", 3, 259952},
	{"CHATBUG", 7, 259953},
	{"AXELSON", 7, 259954},
	{"REALLUSION", 10, 259955},
	{"TEXTALOUD", 9, 259956},
	{"NACLA", 5, 259957},
	{"MAGNETOGRAM", 11, 259958},
	{"SURLATABLE", 10, 259959},
	{"ANDRATX", 7, 259960},
	{"THERMOPLASMA", 12, 259961},
	{"GENDREAU", 8, 259962},
	{"PCJ", 3, 259963},
	{"FITED", 5, 259964},
	{"XIXTH", 5, 259965},
	{"SOMMERSET", 9, 259966},
	{"ROADWORTHY", 10, 259967},
	{"GINSANA", 7, 259968},
	{"BANGHEAD", 8, 259969},
	{"MERRIONETTE", 11, 259970},
	{"TRAVEP", 6, 259971},
	{"ELKANAH", 7, 259972},
	{"AMIES", 5, 259973},
	{"LONGBOARDING", 12, 259974},
	{"JURIDISCHE", 10, 259975},
	{"HARBORLINK", 10, 259976},
	{"AQUARAMA", 8, 259977},
	{"IPRU", 4, 259978},
	{"STARKES", 7, 259979},
	{"SCHILDERS", 9, 259980},
	{"PAHALA", 6, 259981},
	{"EUROSIDS", 8, 259982},
	{"AMATHUS", 7, 259983},
	{"SLSC", 4, 259984},
	{"OPENLASZLO", 10, 259985},
	{"MPSUPERSTORE", 12, 259986},
	{"ZONECD", 6, 259987},
	{"THAMMASAT", 9, 259988},
	{"ROUNDELS", 8, 259989},
	{"MOTIAN", 6, 259990},
	{"GABION", 6, 259991},
	{"AIRINE", 6, 259992},
	{"NIBAQ", 5, 259993},
	{"FIRSTSTREET", 11, 259994},
	{"DULE", 4, 259995},
	{"ARSDALE", 7, 259996},
	{"INPUTRC", 7, 259997},
	{"PRENTIS", 7, 259998},
	{"FSTYPE", 6, 259999},
	{"DISPOSITIF", 10, 260000},
	{"CDCD", 4, 260001},
	{"READIRIS", 8, 260002},
	{"HOSPITALISATIONS", 16, 260003},
	{"ETHNOGRAPHIES", 13, 260004},
	{"AUTHORATIVE", 11, 260005},
	{"TRZVEL", 6, 260006},
	{"THIABENDAZOLE", 13, 260007},
	{"TAITTINGER", 10, 260008},
	{"OUNTRY", 6, 260009},
	{"LTDL", 4, 260010},
	{"REGNI", 5, 260011},
	{"INDIGENOUSLY", 12, 260012},
	{"INBOUNDS", 8, 260013},
	{"GOODWILLSTACY", 13, 260014},
	{"FIRENZA", 7, 260015},
	{"VICARIATE", 9, 260016},
	{"USRD", 4, 260017},
	{"OLIAN", 5, 260018},
	{"LONGAN", 6, 260019},
	{"DMSA", 4, 260020},
	{"TEMBO", 5, 260021},
	{"NEWUSERTEMPLATE", 15, 260022},
	{"NDINGS", 6, 260023},
	{"MAPID", 5, 260024},
	{"WHEELINPUTCURRENT", 17, 260025},
	{"SEAGLASS", 8, 260026},
	{"NECCO", 5, 260027},
	{"WAKEFORD", 8, 260028},
	{"NERVA", 5, 260029},
	{"MOBITV", 6, 260030},
	{"KIBA", 4, 260031},
	{"BAUDOIN", 7, 260032},
	{"TREUTLEN", 8, 260033},
	{"TOUCHEZ", 7, 260034},
	{"PRIJON", 6, 260035},
	{"FISHBOWLDC", 10, 260036},
	{"DAKINI", 6, 260037},
	{"CADENAS", 7, 260038},
	{"PCCM", 4, 260039},
	{"ZTWO", 4, 260040},
	{"ZOBO", 4, 260041},
	{"YTEV", 4, 260042},
	{"YPPP", 4, 260043},
	{"YKAK", 4, 260044},
	{"YDRT", 4, 260045},
	{"YAMG", 4, 260046},
	{"XONU", 4, 260047},
	{"WYNY", 4, 260048},
	{"WWSI", 4, 260049},
	{"WSTP", 4, 260050},
	{"WALV", 4, 260051},
	{"VGOV", 4, 260052},
	{"UCYF", 4, 260053},
	{"TPWA", 4, 260054},
	{"TFUD", 4, 260055},
	{"TCYD", 4, 260056},
	{"SRSL", 4, 260057},
	{"SNDR", 4, 260058},
	{"RWEJ", 4, 260059},
	{"RUYF", 4, 260060},
	{"RUKK", 4, 260061},
	{"RUCU", 4, 260062},
	{"RRSB", 4, 260063},
	{"RMCQ", 4, 260064},
	{"PNWH", 4, 260065},
	{"PEYW", 4, 260066},
	{"OZWI", 4, 260067},
	{"OYVO", 4, 260068},
	{"OWUM", 4, 260069},
	{"OWSZ", 4, 260070},
	{"OSYB", 4, 260071},
	{"ODNY", 4, 260072},
	{"OCSM", 4, 260073},
	{"NXIP", 4, 260074},
	{"NTBC", 4, 260075},
	{"NSKG", 4, 260076},
	{"NOYM", 4, 260077},
	{"NMRN", 4, 260078},
	{"NMMF", 4, 260079},
	{"NHDD", 4, 260080},
	{"NGNR", 4, 260081},
	{"NGDB", 4, 260082},
	{"MVOR", 4, 260083},
	{"MUGW", 4, 260084},
	{"MMMS", 4, 260085},
	{"MDOP", 4, 260086},
	{"MCZE", 4, 260087},
	{"LTHK", 4, 260088},
	{"LPFL", 4, 260089},
	{"LJFO", 4, 260090},
	{"LELN", 4, 260091},
	{"JIGI", 4, 260092},
	{"IXSF", 4, 260093},
	{"ILXO", 4, 260094},
	{"IGTV", 4, 260095},
	{"HIGD", 4, 260096},
	{"GWOW", 4, 260097},
	{"GUWH", 4, 260098},
	{"GPCO", 4, 260099},
	{"GORQ", 4, 260100},
	{"GKES", 4, 260101},
	{"GECB", 4, 260102},
	{"FRIQ", 4, 260103},
	{"FOEC", 4, 260104},
	{"EXSD", 4, 260105},
	{"EUXO", 4, 260106},
	{"ERCG", 4, 260107},
	{"EPYM", 4, 260108},
	{"EDJD", 4, 260109},
	{"EAJC", 4, 260110},
	{"DTSW", 4, 260111},
	{"DSZO", 4, 260112},
	{"DPHU", 4, 260113},
	{"DAVL", 4, 260114},
	{"CNUN", 4, 260115},
	{"CEFC", 4, 260116},
	{"BYUF", 4, 260117},
	{"BYGW", 4, 260118},
	{"BPIE", 4, 260119},
	{"BAEC", 4, 260120},
	{"AKSJ", 4, 260121},
	{"PIYA", 4, 260122},
	{"KENNICOTT", 9, 260123},
	{"GRUENBERG", 9, 260124},
	{"FRIGIDITY", 9, 260125},
	{"ENGADIN", 7, 260126},
	{"CIARDI", 6, 260127},
	{"AUSINDUSTRY", 11, 260128},
	{"ARQUES", 6, 260129},
	{"WEIGHTMAN", 9, 260130},
	{"MASSASOIT", 9, 260131},
	{"DFCS", 4, 260132},
	{"RESCUECOM", 9, 260133},
	{"PIDF", 4, 260134},
	{"IDUNK", 5, 260135},
	{"HORSENS", 7, 260136},
	{"AIKAWA", 6, 260137},
	{"TAZZA", 5, 260138},
	{"ORNDORFF", 8, 260139},
	{"OAKLYN", 6, 260140},
	{"MORITSCH", 8, 260141},
	{"DDED", 4, 260142},
	{"THOMPKINS", 9, 260143},
	{"SUPERVENIENCE", 13, 260144},
	{"MANLINE", 7, 260145},
	{"INVESTABLE", 10, 260146},
	{"CYCLON", 6, 260147},
	{"APPROV", 6, 260148},
	{"SHREEVE", 7, 260149},
	{"IWEAR", 5, 260150},
	{"IGRE", 4, 260151},
	{"HISTORICALS", 11, 260152},
	{"PROPORCIONA", 11, 260153},
	{"JABLER", 6, 260154},
	{"COSTIMULATORY", 13, 260155},
	{"GEOSTRATEGIC", 12, 260156},
	{"EMIKO", 5, 260157},
	{"DISCIPLINARIANS", 15, 260158},
	{"CGGCC", 5, 260159},
	{"PARTIERS", 8, 260160},
	{"MAGICBOX", 8, 260161},
	{"SHEHARYAARSAAHIL", 16, 260162},
	{"NIGIRI", 6, 260163},
	{"INSERTERS", 9, 260164},
	{"BUGGLES", 7, 260165},
	{"KANTOOR", 7, 260166},
	{"DAINA", 5, 260167},
	{"THROWRAG", 8, 260168},
	{"PLAYDAY", 7, 260169},
	{"FRANCISZEK", 10, 260170},
	{"FABULEUX", 8, 260171},
	{"CONTROLES", 9, 260172},
	{"ROPP", 4, 260173},
	{"NOSIG", 5, 260174},
	{"DENIGRATES", 10, 260175},
	{"FLUOROCARBONS", 13, 260176},
	{"DANYEL", 6, 260177},
	{"SUNGEI", 6, 260178},
	{"SMALLHOLDINGS", 13, 260179},
	{"SHOCKUMENTARIES", 15, 260180},
	{"MYFILES", 7, 260181},
	{"BUFFIE", 6, 260182},
	{"KFF", 3, 260183},
	{"GENRAL", 6, 260184},
	{"BRENDANS", 8, 260185},
	{"WASHINGTONUSA", 13, 260186},
	{"KAWACHI", 7, 260187},
	{"CIASNE", 6, 260188},
	{"UPTIMES", 7, 260189},
	{"PEARSONS", 8, 260190},
	{"LXIV", 4, 260191},
	{"STLSOFT", 7, 260192},
	{"KSTP", 4, 260193},
	{"HILBORN", 7, 260194},
	{"GSTABS", 6, 260195},
	{"FOOTBALLRUGBY", 13, 260196},
	{"LITHOLOGIES", 11, 260197},
	{"CUCKOLDS", 8, 260198},
	{"BETTYS", 6, 260199},
	{"MUFASA", 6, 260200},
	{"GLENSHAW", 8, 260201},
	{"BARRASFORD", 10, 260202},
	{"WIKIPEDIAN", 10, 260203},
	{"SAYAKA", 6, 260204},
	{"TAIPA", 5, 260205},
	{"STATMAN", 7, 260206},
	{"DIALOGBOX", 9, 260207},
	{"TCKS", 4, 260208},
	{"SHAKEEL", 7, 260209},
	{"OVANDO", 6, 260210},
	{"LEONGATHA", 9, 260211},
	{"EONLINE", 7, 260212},
	{"VATIVE", 6, 260213},
	{"SQUIBS", 6, 260214},
	{"MONERA", 6, 260215},
	{"HALLGREN", 8, 260216},
	{"UNIONCRICKETICE", 15, 260217},
	{"PINTOS", 6, 260218},
	{"ROSSANA", 7, 260219},
	{"LOADEDWEB", 9, 260220},
	{"LDOS", 4, 260221},
	{"GALLERIESARCHIVEPOKER", 21, 260222},
	{"FOREND", 6, 260223},
	{"ASTACIO", 7, 260224},
	{"TRESHOLD", 8, 260225},
	{"SHINRIKYO", 9, 260226},
	{"SHIBLEY", 7, 260227},
	{"HLUSE", 5, 260228},
	{"BARRAGAN", 8, 260229},
	{"TARKIO", 6, 260230},
	{"SHARELOOK", 9, 260231},
	{"SDLX", 4, 260232},
	{"MCWTRAINER", 10, 260233},
	{"LLANES", 6, 260234},
	{"KHUMALO", 7, 260235},
	{"YESSY", 5, 260236},
	{"SANDO", 5, 260237},
	{"HOUXE", 5, 260238},
	{"PROTEACHER", 10, 260239},
	{"DAYKIN", 6, 260240},
	{"TIPPETS", 7, 260241},
	{"LAEVIGATA", 9, 260242},
	{"CENARION", 8, 260243},
	{"BIOTECHNICAL", 12, 260244},
	{"UMBERGER", 8, 260245},
	{"MAINERS", 7, 260246},
	{"KEURBOOMS", 9, 260247},
	{"GOLDONI", 7, 260248},
	{"RIVETT", 6, 260249},
	{"ITCHINESS", 9, 260250},
	{"DPAC", 4, 260251},
	{"BAUZA", 5, 260252},
	{"TELEOPERATION", 13, 260253},
	{"VIGORELLE", 9, 260254},
	{"SAMPAI", 6, 260255},
	{"HOLLERAN", 8, 260256},
	{"ELECTRODIAGNOSTIC", 17, 260257},
	{"USBCORE", 7, 260258},
	{"INTERMAIL", 9, 260259},
	{"DOERKSEN", 8, 260260},
	{"SANITISING", 10, 260261},
	{"MPLUS", 5, 260262},
	{"FFRAINC", 7, 260263},
	{"ARBIL", 5, 260264},
	{"WCNC", 4, 260265},
	{"TOBACK", 6, 260266},
	{"NATIONSCUP", 10, 260267},
	{"HIGHTON", 7, 260268},
	{"XMC", 3, 260269},
	{"TWOULD", 6, 260270},
	{"GALIA", 5, 260271},
	{"BLOODHOOF", 9, 260272},
	{"TECAN", 5, 260273},
	{"RISDON", 6, 260274},
	{"PREWIRED", 8, 260275},
	{"REANEY", 6, 260276},
	{"SENDIRI", 7, 260277},
	{"LCID", 4, 260278},
	{"DEMILITARISATION", 16, 260279},
	{"CERTAGON", 8, 260280},
	{"BIONEERS", 8, 260281},
	{"CONNAH", 6, 260282},
	{"SYPHILITIC", 10, 260283},
	{"SUMUS", 5, 260284},
	{"OVERFITTING", 11, 260285},
	{"KABBAH", 6, 260286},
	{"DATOR", 5, 260287},
	{"CONSPECIFICS", 12, 260288},
	{"ALPHAGEN", 8, 260289},
	{"JAYWALKING", 10, 260290},
	{"FIAG", 4, 260291},
	{"DRUMCONDRA", 10, 260292},
	{"FLAGMAN", 7, 260293},
	{"BLINDERN", 8, 260294},
	{"SNORNA", 6, 260295},
	{"SABURO", 6, 260296},
	{"SHORTBOARD", 10, 260297},
	{"KONTRA", 6, 260298},
	{"FREESURFER", 10, 260299},
	{"ACCESSIBLECONTEXT", 17, 260300},
	{"SCAMMON", 7, 260301},
	{"NONSKID", 7, 260302},
	{"VIPIN", 5, 260303},
	{"ROBINAIR", 8, 260304},
	{"OTTERBURN", 9, 260305},
	{"CALHAN", 6, 260306},
	{"BARCAROLLE", 10, 260307},
	{"PSUSP", 5, 260308},
	{"PRESENTACIONES", 14, 260309},
	{"USART", 5, 260310},
	{"SAFEDISC", 8, 260311},
	{"PELAGICS", 8, 260312},
	{"ORGULLO", 7, 260313},
	{"LEMMENS", 7, 260314},
	{"KASTENHOLZ", 10, 260315},
	{"ENDREGION", 9, 260316},
	{"CRAVATS", 7, 260317},
	{"WORC", 4, 260318},
	{"VSOCIAL", 7, 260319},
	{"KERNE", 5, 260320},
	{"MONOTYPIC", 9, 260321},
	{"TRQVEL", 6, 260322},
	{"PULCHELLA", 9, 260323},
	{"JUNR", 4, 260324},
	{"ADAMANTIX", 9, 260325},
	{"PIPKA", 5, 260326},
	{"PERSPIRE", 8, 260327},
	{"FXM", 3, 260328},
	{"LETTERKILLS", 11, 260329},
	{"BRAINSTRUST", 11, 260330},
	{"BOEL", 4, 260331},
	{"SIGULDA", 7, 260332},
	{"CCHE", 4, 260333},
	{"WHIPED", 6, 260334},
	{"UNCLEARED", 9, 260335},
	{"TANKSLEY", 8, 260336},
	{"RDCS", 4, 260337},
	{"OPENSG", 6, 260338},
	{"TYRESMOKE", 9, 260339},
	{"ENGORGEMENT", 11, 260340},
	{"DEMINERALIZATION", 16, 260341},
	{"CORTANA", 7, 260342},
	{"YOFFSET", 7, 260343},
	{"NORTHHAMPTON", 12, 260344},
	{"INETFORMFILLER", 14, 260345},
	{"TILLANDSIA", 10, 260346},
	{"NWBA", 4, 260347},
	{"GOODWELL", 8, 260348},
	{"FIELDSHEER", 10, 260349},
	{"TELEVIDEO", 9, 260350},
	{"EKIM", 4, 260351},
	{"COUNTERCHANGED", 14, 260352},
	{"CERVICITIS", 10, 260353},
	{"UZZIAH", 6, 260354},
	{"SELIGER", 7, 260355},
	{"LEVOY", 5, 260356},
	{"HYPALON", 7, 260357},
	{"HEWARD", 6, 260358},
	{"ATTDEF", 6, 260359},
	{"TRUSTABLE", 9, 260360},
	{"TOPOGRAPHIES", 12, 260361},
	{"LOYER", 5, 260362},
	{"LIFEVENTURE", 11, 260363},
	{"PARSA", 5, 260364},
	{"HOJSE", 5, 260365},
	{"HASFOCUS", 8, 260366},
	{"FIKES", 5, 260367},
	{"FIELDTYPE", 9, 260368},
	{"VITIELLO", 8, 260369},
	{"MOHOLY", 6, 260370},
	{"DIRECTCD", 8, 260371},
	{"STEEPS", 6, 260372},
	{"KYRENE", 6, 260373},
	{"SALUBRIOUS", 10, 260374},
	{"CCFP", 4, 260375},
	{"SWFSPRITE", 9, 260376},
	{"SUPERDUPER", 10, 260377},
	{"PAGETEMPLATES", 13, 260378},
	{"ODDFELLOWS", 10, 260379},
	{"SPEISER", 7, 260380},
	{"INITATIVE", 9, 260381},
	{"GORDES", 6, 260382},
	{"FORSCH", 6, 260383},
	{"DONATELLI", 9, 260384},
	{"SAVOYE", 6, 260385},
	{"ETHNOLOGIST", 11, 260386},
	{"ARCHIF", 6, 260387},
	{"TIMECARDS", 9, 260388},
	{"CATTE", 5, 260389},
	{"BOWRAVILLE", 10, 260390},
	{"ARISTARCHUS", 11, 260391},
	{"SPEEDWAYS", 9, 260392},
	{"FSMA", 4, 260393},
	{"VGX", 3, 260394},
	{"POCKETHUB", 9, 260395},
	{"HABIL", 5, 260396},
	{"SEACHEM", 7, 260397},
	{"SACHGEBIET", 10, 260398},
	{"POMC", 4, 260399},
	{"HIERMENUS", 9, 260400},
	{"GIBS", 4, 260401},
	{"OBJV", 4, 260402},
	{"MICROPHONIC", 11, 260403},
	{"IRRADIATE", 9, 260404},
	{"INTERDISTRICT", 13, 260405},
	{"INPRO", 5, 260406},
	{"DERMATOLOGIE", 12, 260407},
	{"BESEN", 5, 260408},
	{"LFY", 3, 260409},
	{"JESSEL", 6, 260410},
	{"DORSO", 5, 260411},
	{"COREEN", 6, 260412},
	{"ADAB", 4, 260413},
	{"TERASTATION", 11, 260414},
	{"LIBREP", 6, 260415},
	{"HKUSE", 5, 260416},
	{"REJUVENATOR", 11, 260417},
	{"BARBATUS", 8, 260418},
	{"RFRA", 4, 260419},
	{"NANTOU", 6, 260420},
	{"LOOPBACKS", 9, 260421},
	{"WHINGER", 7, 260422},
	{"REDDS", 5, 260423},
	{"FORKEY", 6, 260424},
	{"BOOKLIGHT", 9, 260425},
	{"YEOW", 4, 260426},
	{"TWISTOR", 7, 260427},
	{"RURUTSE", 7, 260428},
	{"KRISTIANSTAD", 12, 260429},
	{"ULTRASLIM", 9, 260430},
	{"HARPSTER", 8, 260431},
	{"DEMOTTE", 7, 260432},
	{"UNSYSTEMATIC", 12, 260433},
	{"OPTEC", 5, 260434},
	{"NEDDICK", 7, 260435},
	{"CEEP", 4, 260436},
	{"BLOGGERNITY", 11, 260437},
	{"ZZOM", 4, 260438},
	{"ZOFW", 4, 260439},
	{"ZDOW", 4, 260440},
	{"YUPN", 4, 260441},
	{"YNLI", 4, 260442},
	{"YNIR", 4, 260443},
	{"YMSU", 4, 260444},
	{"XDOT", 4, 260445},
	{"WWPI", 4, 260446},
	{"WRBR", 4, 260447},
	{"WAPF", 4, 260448},
	{"VOSR", 4, 260449},
	{"VMAH", 4, 260450},
	{"VLED", 4, 260451},
	{"VIGU", 4, 260452},
	{"VEUK", 4, 260453},
	{"TYZE", 4, 260454},
	{"TXOR", 4, 260455},
	{"TPYO", 4, 260456},
	{"TOCQ", 4, 260457},
	{"TLLL", 4, 260458},
	{"THPF", 4, 260459},
	{"RHDT", 4, 260460},
	{"RAXO", 4, 260461},
	{"PEGN", 4, 260462},
	{"PECF", 4, 260463},
	{"OYDK", 4, 260464},
	{"OELQ", 4, 260465},
	{"NTZV", 4, 260466},
	{"NTBB", 4, 260467},
	{"NSMM", 4, 260468},
	{"NRGI", 4, 260469},
	{"NNFU", 4, 260470},
	{"NAWM", 4, 260471},
	{"NAUJ", 4, 260472},
	{"MOPY", 4, 260473},
	{"MIIW", 4, 260474},
	{"MFIB", 4, 260475},
	{"MEPT", 4, 260476},
	{"LHTM", 4, 260477},
	{"KYCE", 4, 260478},
	{"KUOF", 4, 260479},
	{"KHYD", 4, 260480},
	{"KEJR", 4, 260481},
	{"JUKA", 4, 260482},
	{"IWEK", 4, 260483},
	{"IRKJ", 4, 260484},
	{"ILRD", 4, 260485},
	{"IEQB", 4, 260486},
	{"IBNU", 4, 260487},
	{"IBIF", 4, 260488},
	{"GLEZ", 4, 260489},
	{"FYOF", 4, 260490},
	{"FAXD", 4, 260491},
	{"ETRP", 4, 260492},
	{"ERXB", 4, 260493},
	{"ERLF", 4, 260494},
	{"EPYB", 4, 260495},
	{"DEGM", 4, 260496},
	{"CGAD", 4, 260497},
	{"CEYN", 4, 260498},
	{"CELJ", 4, 260499},
	{"CBCB", 4, 260500},
	{"BUNR", 4, 260501},
	{"BPLE", 4, 260502},
	{"BPDI", 4, 260503},
	{"BMSP", 4, 260504},
	{"BGLA", 4, 260505},
	{"AWWR", 4, 260506},
	{"AVYK", 4, 260507},
	{"ATZF", 4, 260508},
	{"ABBF", 4, 260509},
	{"WHELK", 5, 260510},
	{"SPEARMEN", 8, 260511},
	{"RESPONSIBILI", 12, 260512},
	{"MARQUART", 8, 260513},
	{"JOHTO", 5, 260514},
	{"INTRATHORACIC", 13, 260515},
	{"HOLZAPFEL", 9, 260516},
	{"DEPARTMEN", 9, 260517},
	{"MAINCONCEPT", 11, 260518},
	{"ACEPHATE", 8, 260519},
	{"SHAITAN", 7, 260520},
	{"LAZARIDIS", 9, 260521},
	{"COSIS", 5, 260522},
	{"BALDWYN", 7, 260523},
	{"EVENTTIME", 9, 260524},
	{"VNCVIEWER", 9, 260525},
	{"PROVOCATEURS", 12, 260526},
	{"LINKSPOT", 8, 260527},
	{"MCELWAIN", 8, 260528},
	{"MITAKA", 6, 260529},
	{"EUROMICRO", 9, 260530},
	{"DARROCH", 7, 260531},
	{"SHOPPPING", 9, 260532},
	{"SCOREIMP", 8, 260533},
	{"MSLEEP", 6, 260534},
	{"KMIEC", 5, 260535},
	{"KARAGANDA", 9, 260536},
	{"EROIC", 5, 260537},
	{"ENTENSITY", 9, 260538},
	{"CYSTEINYL", 9, 260539},
	{"REYCOM", 6, 260540},
	{"HOPFGARTEN", 10, 260541},
	{"WESTLUND", 8, 260542},
	{"TOPED", 5, 260543},
	{"INDIS", 5, 260544},
	{"TEXTISM", 7, 260545},
	{"LVB", 3, 260546},
	{"CALCULADORA", 11, 260547},
	{"ROVERETO", 8, 260548},
	{"MARCUSCOM", 9, 260549},
	{"JELLYCAT", 8, 260550},
	{"BLANCHESTER", 11, 260551},
	{"ODKAZY", 6, 260552},
	{"HANAUER", 7, 260553},
	{"CAERNARVONSHIRE", 15, 260554},
	{"AUGH", 4, 260555},
	{"IZZET", 5, 260556},
	{"CERVIA", 6, 260557},
	{"SHUANG", 6, 260558},
	{"MODELLS", 7, 260559},
	{"VIRTUOSA", 8, 260560},
	{"MORF", 4, 260561},
	{"KYODAI", 6, 260562},
	{"HOUDEN", 6, 260563},
	{"DIGGTHIS", 8, 260564},
	{"WOUS", 4, 260565},
	{"LONGARM", 7, 260566},
	{"DONNELLSON", 10, 260567},
	{"CANLEY", 6, 260568},
	{"UTILIDADES", 10, 260569},
	{"RIADA", 5, 260570},
	{"PIPELINETEST", 12, 260571},
	{"MORAVA", 6, 260572},
	{"HOOTERVILLE", 11, 260573},
	{"EXOCET", 6, 260574},
	{"ELIZARIO", 8, 260575},
	{"CUSTOMLOG", 9, 260576},
	{"COSMOTE", 7, 260577},
	{"KAZACHSTAN", 10, 260578},
	{"EXTERMINATES", 12, 260579},
	{"PRIAVCY", 7, 260580},
	{"STRIDOR", 7, 260581},
	{"MINONK", 6, 260582},
	{"JUBILO", 6, 260583},
	{"GOOSEGRASS", 10, 260584},
	{"ERSATZTEILE", 11, 260585},
	{"LOGING", 6, 260586},
	{"DKSTONE", 7, 260587},
	{"CONCRETIONS", 11, 260588},
	{"AARONOVITCH", 11, 260589},
	{"MARRIAGEABLE", 12, 260590},
	{"DISENO", 6, 260591},
	{"AREL", 4, 260592},
	{"POCKETKNIFE", 11, 260593},
	{"MINUTTER", 8, 260594},
	{"LESCO", 5, 260595},
	{"LEBON", 5, 260596},
	{"ELMET", 5, 260597},
	{"SUREGRIP", 8, 260598},
	{"MENDELL", 7, 260599},
	{"KAIKAN", 6, 260600},
	{"CHOOLS", 6, 260601},
	{"AFPS", 4, 260602},
	{"VITADIGEST", 10, 260603},
	{"NACCHIO", 7, 260604},
	{"MODSQUAD", 8, 260605},
	{"GANNETS", 7, 260606},
	{"DUTASTERIDE", 11, 260607},
	{"PLUMBAGO", 8, 260608},
	{"ILLUSTS", 7, 260609},
	{"SPRADLING", 9, 260610},
	{"SOMNATH", 7, 260611},
	{"RATTNER", 7, 260612},
	{"MORETECH", 8, 260613},
	{"CURITEL", 7, 260614},
	{"CLUBSTAR", 8, 260615},
	{"BOERGER", 7, 260616},
	{"WESTWATER", 9, 260617},
	{"WEBBEAMS", 8, 260618},
	{"NTERNAL", 7, 260619},
	{"MIFARE", 6, 260620},
	{"JOISE", 5, 260621},
	{"DDYDD", 5, 260622},
	{"GLENNY", 6, 260623},
	{"EUROA", 5, 260624},
	{"SUMMICRON", 9, 260625},
	{"SAJAK", 5, 260626},
	{"PILAS", 5, 260627},
	{"MEAM", 4, 260628},
	{"IMPOSTURE", 9, 260629},
	{"EULBERG", 7, 260630},
	{"CITTONE", 7, 260631},
	{"SEISMO", 6, 260632},
	{"ANIMALCONCERNS", 14, 260633},
	{"TEUKOLSKY", 9, 260634},
	{"STEIGERWALD", 11, 260635},
	{"KONY", 4, 260636},
	{"FANTI", 5, 260637},
	{"ACCIS", 5, 260638},
	{"BACKBREAKING", 12, 260639},
	{"JEWLRY", 6, 260640},
	{"BISINESS", 8, 260641},
	{"GOOLIE", 6, 260642},
	{"BPSS", 4, 260643},
	{"NONVETERAN", 10, 260644},
	{"HARC", 4, 260645},
	{"DELFIELD", 8, 260646},
	{"BURREL", 6, 260647},
	{"LASCALA", 7, 260648},
	{"WERTUNG", 7, 260649},
	{"UNBAKED", 7, 260650},
	{"SUMIKO", 6, 260651},
	{"LICENCIATURA", 12, 260652},
	{"OFFENBURG", 9, 260653},
	{"MOSSYROCK", 9, 260654},
	{"METHYLCHOLANTHRENE", 18, 260655},
	{"LATONYA", 7, 260656},
	{"GLENROWAN", 9, 260657},
	{"ESCRIBE", 7, 260658},
	{"BEEVERS", 7, 260659},
	{"TELEVISUAL", 10, 260660},
	{"HORY", 4, 260661},
	{"AGAMBEN", 7, 260662},
	{"ADDNOTIFY", 9, 260663},
	{"EGSM", 4, 260664},
	{"CANNAS", 6, 260665},
	{"ALVERA", 6, 260666},
	{"MALANDA", 7, 260667},
	{"TAPLINGER", 9, 260668},
	{"PUSHD", 5, 260669},
	{"POTREBBE", 8, 260670},
	{"MUTINOUS", 8, 260671},
	{"MARKLEEVILLE", 12, 260672},
	{"ZANONI", 6, 260673},
	{"WITCHWOOD", 9, 260674},
	{"SMARTSEARCH", 11, 260675},
	{"POWERTEL", 8, 260676},
	{"GENENCOR", 8, 260677},
	{"STROKEJOB", 9, 260678},
	{"QGP", 3, 260679},
	{"PREMODDED", 9, 260680},
	{"LEASIDE", 7, 260681},
	{"JABBERING", 9, 260682},
	{"ETARY", 5, 260683},
	{"ARCHAIA", 7, 260684},
	{"QUAICH", 6, 260685},
	{"LIBOPENAFS", 10, 260686},
	{"BROADWOVEN", 10, 260687},
	{"HONOKAA", 7, 260688},
	{"CONAL", 5, 260689},
	{"RURALPROPERTYGUIDE", 18, 260690},
	{"MEOWSER", 7, 260691},
	{"HTTPHTTP", 8, 260692},
	{"DESCRIPTIVELY", 13, 260693},
	{"MCGILLIGAN", 10, 260694},
	{"HTLIST", 6, 260695},
	{"HISER", 5, 260696},
	{"COLECCIONES", 11, 260697},
	{"BURGAW", 6, 260698},
	{"WEMM", 4, 260699},
	{"MULTIPROGRAMMING", 16, 260700},
	{"FEMJOY", 6, 260701},
	{"CLARKES", 7, 260702},
	{"SICARD", 6, 260703},
	{"ANTIALIAS", 9, 260704},
	{"RINGOLD", 7, 260705},
	{"RBJ", 3, 260706},
	{"QUIKQUOTE", 9, 260707},
	{"HALCON", 6, 260708},
	{"CHICORA", 7, 260709},
	{"UNDEGROUND", 10, 260710},
	{"FACTIVE", 7, 260711},
	{"ADBE", 4, 260712},
	{"RAKI", 4, 260713},
	{"FLANN", 5, 260714},
	{"REPORTAGES", 10, 260715},
	{"LANGTANG", 8, 260716},
	{"IDUKKI", 6, 260717},
	{"BECAM", 5, 260718},
	{"SUPERSOUND", 10, 260719},
	{"COLEBY", 6, 260720},
	{"CHEVROLETS", 10, 260721},
	{"AMETRINE", 8, 260722},
	{"PEMAQUID", 8, 260723},
	{"NEGRU", 5, 260724},
	{"THIRTYSIX", 9, 260725},
	{"MASTODONS", 9, 260726},
	{"ORGANIZADOS", 11, 260727},
	{"EUROSEEK", 8, 260728},
	{"AUTRIJUS", 8, 260729},
	{"WURMAN", 6, 260730},
	{"TEXASS", 6, 260731},
	{"SUPERTYPES", 10, 260732},
	{"SHINUI", 6, 260733},
	{"QALCULATE", 9, 260734},
	{"PSIRT", 5, 260735},
	{"PJP", 3, 260736},
	{"PITCHFORKS", 10, 260737},
	{"COLORGUARD", 10, 260738},
	{"VESPOLI", 7, 260739},
	{"TYRIAN", 6, 260740},
	{"SPARR", 5, 260741},
	{"KELE", 4, 260742},
	{"KASPRZAK", 8, 260743},
	{"INGRAIN", 7, 260744},
	{"ALBCLUB", 7, 260745},
	{"OTHMER", 6, 260746},
	{"ADEPTUS", 7, 260747},
	{"REPETATIVE", 10, 260748},
	{"POURRA", 6, 260749},
	{"PEREMPTORILY", 12, 260750},
	{"MAALAEA", 7, 260751},
	{"KYRBY", 5, 260752},
	{"AFPD", 4, 260753},
	{"WHIRLWINDS", 10, 260754},
	{"SEGHE", 5, 260755},
	{"SAORI", 5, 260756},
	{"REPRODUTOR", 10, 260757},
	{"GRUPOTEL", 8, 260758},
	{"FAVORITESFAVORITES", 18, 260759},
	{"INTERNALISATION", 15, 260760},
	{"GENNA", 5, 260761},
	{"COALGATE", 8, 260762},
	{"ZEESE", 5, 260763},
	{"DESPOILED", 9, 260764},
	{"LUGUBRIOUS", 10, 260765},
	{"CHEMORADIOTHERAPY", 17, 260766},
	{"VASSE", 5, 260767},
	{"VIRTUALI", 8, 260768},
	{"JUNOSE", 6, 260769},
	{"FINISHINGS", 10, 260770},
	{"CRYNODEB", 8, 260771},
	{"CRACKD", 6, 260772},
	{"MIASTO", 6, 260773},
	{"RINGLEADERS", 11, 260774},
	{"ORGANISATEUR", 12, 260775},
	{"RACZ", 4, 260776},
	{"GEODUCK", 7, 260777},
	{"BRANCHIOSTOMA", 13, 260778},
	{"ARCHONS", 7, 260779},
	{"SVARTLING", 9, 260780},
	{"RENOVATA", 8, 260781},
	{"CRYPTSETUP", 10, 260782},
	{"SIERRE", 6, 260783},
	{"ROTIS", 5, 260784},
	{"OVERBEEK", 8, 260785},
	{"NETCENTRAL", 10, 260786},
	{"KEEFFE", 6, 260787},
	{"GINORMOUS", 9, 260788},
	{"COUBERTIN", 9, 260789},
	{"BYTECOUNT", 9, 260790},
	{"BEGRIFFE", 8, 260791},
	{"POLITA", 6, 260792},
	{"MANSO", 5, 260793},
	{"LISTLESSLY", 10, 260794},
	{"EASYMAIL", 8, 260795},
	{"AFFRONTED", 9, 260796},
	{"STOWAWAYS", 9, 260797},
	{"SRIDHARAN", 9, 260798},
	{"MULTICENTRIC", 12, 260799},
	{"JAVATV", 6, 260800},
	{"HAUTESPOT", 9, 260801},
	{"SEAMY", 5, 260802},
	{"ANZFA", 5, 260803},
	{"CUABA", 5, 260804},
	{"ALLOSAURUS", 10, 260805},
	{"AMAZONA", 7, 260806},
	{"SUMEET", 6, 260807},
	{"QNTY", 4, 260808},
	{"PYSOL", 5, 260809},
	{"PERENNIS", 8, 260810},
	{"LGCC", 4, 260811},
	{"DPDMIRYIDEFGQTTTRM", 18, 260812},
	{"DISTINTOS", 9, 260813},
	{"AMAZ", 4, 260814},
	{"SPLITER", 7, 260815},
	{"SOHMA", 5, 260816},
	{"QFC", 3, 260817},
	{"SKYPEIN", 7, 260818},
	{"PNEUMO", 6, 260819},
	{"MONORAILS", 9, 260820},
	{"JENERATION", 10, 260821},
	{"CURMUDGEONS", 11, 260822},
	{"ALOUDS", 6, 260823},
	{"TREEMAP", 7, 260824},
	{"NIUC", 4, 260825},
	{"GENR", 4, 260826},
	{"CELB", 4, 260827},
	{"THEUN", 5, 260828},
	{"PUAMA", 5, 260829},
	{"KERIM", 5, 260830},
	{"KOCAELI", 7, 260831},
	{"KARRY", 5, 260832},
	{"HOTRONIC", 8, 260833},
	{"DERDE", 5, 260834},
	{"NEUROTOXICOLOGY", 15, 260835},
	{"MACROMOL", 8, 260836},
	{"LOHNER", 6, 260837},
	{"FLIPCHARTS", 10, 260838},
	{"CHOM", 4, 260839},
	{"STREQ", 5, 260840},
	{"PNEUMOCOCCUS", 12, 260841},
	{"ROSSTON", 7, 260842},
	{"MINIFALDAS", 10, 260843},
	{"FULP", 4, 260844},
	{"ZYKI", 4, 260845},
	{"YMYK", 4, 260846},
	{"WWUN", 4, 260847},
	{"WWKI", 4, 260848},
	{"WJAS", 4, 260849},
	{"WEYI", 4, 260850},
	{"WBUM", 4, 260851},
	{"VPRA", 4, 260852},
	{"VONZ", 4, 260853},
	{"VEKW", 4, 260854},
	{"UURE", 4, 260855},
	{"UTOX", 4, 260856},
	{"TYPC", 4, 260857},
	{"TRLE", 4, 260858},
	{"SZEU", 4, 260859},
	{"SWBC", 4, 260860},
	{"SVWA", 4, 260861},
	{"SUOK", 4, 260862},
	{"SJRG", 4, 260863},
	{"SBEX", 4, 260864},
	{"RUIJ", 4, 260865},
	{"RTVN", 4, 260866},
	{"RTBS", 4, 260867},
	{"RSBB", 4, 260868},
	{"RLGB", 4, 260869},
	{"RIKY", 4, 260870},
	{"RGSY", 4, 260871},
	{"QINF", 4, 260872},
	{"QBKE", 4, 260873},
	{"PRDE", 4, 260874},
	{"POFZ", 4, 260875},
	{"OTYB", 4, 260876},
	{"OHPR", 4, 260877},
	{"OFTQ", 4, 260878},
	{"NWMA", 4, 260879},
	{"NSCW", 4, 260880},
	{"NIUP", 4, 260881},
	{"NGSX", 4, 260882},
	{"NDFW", 4, 260883},
	{"MRPM", 4, 260884},
	{"MNSR", 4, 260885},
	{"MIYE", 4, 260886},
	{"MIAV", 4, 260887},
	{"LOBW", 4, 260888},
	{"LAVB", 4, 260889},
	{"KPAA", 4, 260890},
	{"KGUR", 4, 260891},
	{"KELJ", 4, 260892},
	{"JIBB", 4, 260893},
	{"JASR", 4, 260894},
	{"IOLW", 4, 260895},
	{"IMMD", 4, 260896},
	{"HDUG", 4, 260897},
	{"GOVU", 4, 260898},
	{"GOGN", 4, 260899},
	{"GMBO", 4, 260900},
	{"GEML", 4, 260901},
	{"FNGO", 4, 260902},
	{"DRIW", 4, 260903},
	{"DJPA", 4, 260904},
	{"DJBO", 4, 260905},
	{"DEVV", 4, 260906},
	{"CPRT", 4, 260907},
	{"CMMA", 4, 260908},
	{"CGOS", 4, 260909},
	{"CDDE", 4, 260910},
	{"BMAH", 4, 260911},
	{"BKAR", 4, 260912},
	{"AZAV", 4, 260913},
	{"ASFM", 4, 260914},
	{"AOJU", 4, 260915},
	{"AHLR", 4, 260916},
	{"MEFENAMIC", 9, 260917},
	{"ANTIWPA", 7, 260918},
	{"VEGAA", 5, 260919},
	{"ASCOSPORES", 10, 260920},
	{"WOODLORE", 8, 260921},
	{"APOTELEI", 8, 260922},
	{"TWELVES", 7, 260923},
	{"RECEPTIVENESS", 13, 260924},
	{"MAUCK", 5, 260925},
	{"COPYCENTRE", 10, 260926},
	{"CITTERIO", 8, 260927},
	{"CAMBRILS", 8, 260928},
	{"PEETE", 5, 260929},
	{"HELLOOOO", 8, 260930},
	{"DOPPIA", 6, 260931},
	{"DANFORD", 7, 260932},
	{"CASGLIAD", 8, 260933},
	{"BHIMA", 5, 260934},
	{"NETSVILLE", 9, 260935},
	{"MASTERBLASTER", 13, 260936},
	{"JASNA", 5, 260937},
	{"GCNEW", 5, 260938},
	{"BENDERMAN", 9, 260939},
	{"RINGLET", 7, 260940},
	{"MAJU", 4, 260941},
	{"TRESSA", 6, 260942},
	{"INGLEBURN", 9, 260943},
	{"HAMELN", 6, 260944},
	{"CHLORIS", 7, 260945},
	{"YONCALLA", 8, 260946},
	{"NANASE", 6, 260947},
	{"INVECE", 6, 260948},
	{"HOSTRAID", 8, 260949},
	{"SUIDPERL", 8, 260950},
	{"ALTAZIMUTH", 10, 260951},
	{"EIDETIC", 7, 260952},
	{"NUDEBOYS", 8, 260953},
	{"ENCOUN", 6, 260954},
	{"DEBOUT", 6, 260955},
	{"COVARRUBIAS", 11, 260956},
	{"PROCESSER", 9, 260957},
	{"DOBA", 4, 260958},
	{"CHLOROPHENOL", 12, 260959},
	{"AUSCULTURE", 10, 260960},
	{"ANTHROPOL", 9, 260961},
	{"MORISETTE", 9, 260962},
	{"BLOEDEL", 7, 260963},
	{"UNCOMPRESSING", 13, 260964},
	{"SEABRIGHT", 9, 260965},
	{"NOGAL", 5, 260966},
	{"MSCP", 4, 260967},
	{"CELEBORN", 8, 260968},
	{"TAXACT", 6, 260969},
	{"PROBABLEMENT", 12, 260970},
	{"FLOQUET", 7, 260971},
	{"WELLSFARGO", 10, 260972},
	{"USEMOD", 6, 260973},
	{"SOUKS", 5, 260974},
	{"PASQUIER", 8, 260975},
	{"MUTHER", 6, 260976},
	{"JENELLE", 7, 260977},
	{"SCENIUM", 7, 260978},
	{"PRINTPAL", 8, 260979},
	{"ZOYSIA", 6, 260980},
	{"THOMASINA", 9, 260981},
	{"SCRUTINEERS", 11, 260982},
	{"APROPRIATE", 10, 260983},
	{"NUMARRAY", 8, 260984},
	{"NUBAIN", 6, 260985},
	{"ACEXML", 6, 260986},
	{"REELER", 6, 260987},
	{"UNSTRIPPED", 10, 260988},
	{"HYSICAL", 7, 260989},
	{"AHPR", 4, 260990},
	{"PLANARIZATION", 13, 260991},
	{"PERMEABILITIES", 14, 260992},
	{"PARAMETERNAME", 13, 260993},
	{"PARISHILTON", 11, 260994},
	{"IGUALDAD", 8, 260995},
	{"WHOLESAL", 8, 260996},
	{"SUBPANEL", 8, 260997},
	{"PARAGUAI", 8, 260998},
	{"MOTORBASE", 9, 260999},
	{"TEREZIN", 7, 261000},
	{"PERICARP", 8, 261001},
	{"MAKOWER", 7, 261002},
	{"LINSKY", 6, 261003},
	{"HOTAIR", 6, 261004},
	{"DOMODEDOVO", 10, 261005},
	{"VOGES", 5, 261006},
	{"REDFEARN", 8, 261007},
	{"CEDX", 4, 261008},
	{"PORTNUMBER", 10, 261009},
	{"PLUTA", 5, 261010},
	{"FREUEN", 6, 261011},
	{"ARTSERVE", 8, 261012},
	{"PCSO", 4, 261013},
	{"SICKENINGLY", 11, 261014},
	{"RECREA", 6, 261015},
	{"PANAY", 5, 261016},
	{"CHOCOHOLICS", 11, 261017},
	{"UZED", 4, 261018},
	{"KOMBINATION", 11, 261019},
	{"GULLICKSON", 10, 261020},
	{"CURRENTDICT", 11, 261021},
	{"SKYCAM", 6, 261022},
	{"MICROGRAPHICS", 13, 261023},
	{"DRAGGABLE", 9, 261024},
	{"COSMIDS", 7, 261025},
	{"FINNIX", 6, 261026},
	{"SELFHYPNOTISM", 13, 261027},
	{"PALEOANTHROPOLOGY", 17, 261028},
	{"MFUSE", 5, 261029},
	{"BEDRICH", 7, 261030},
	{"SCOTHORSE", 9, 261031},
	{"MONEYORDER", 10, 261032},
	{"FANNISH", 7, 261033},
	{"BRUYERE", 7, 261034},
	{"RONHILL", 7, 261035},
	{"IDIOTEQUE", 9, 261036},
	{"SPIEREN", 7, 261037},
	{"SOFTWAREENTWICKLUNG", 19, 261038},
	{"FACTSET", 7, 261039},
	{"OXIDASES", 8, 261040},
	{"MILENKO", 7, 261041},
	{"MDEV", 4, 261042},
	{"FBSET", 5, 261043},
	{"VIGILANTLY", 10, 261044},
	{"TRENTY", 6, 261045},
	{"RECALCULATING", 13, 261046},
	{"QUANGOS", 7, 261047},
	{"PREPETITION", 11, 261048},
	{"MCLURE", 6, 261049},
	{"FLAPJACKS", 9, 261050},
	{"TINKA", 5, 261051},
	{"PROJECTO", 8, 261052},
	{"WOODWARE", 8, 261053},
	{"MOLKO", 5, 261054},
	{"CHEPAEST", 8, 261055},
	{"VEAZEY", 6, 261056},
	{"MECANO", 6, 261057},
	{"JENIS", 5, 261058},
	{"HAIGLER", 7, 261059},
	{"BAJWA", 5, 261060},
	{"MOVIRS", 6, 261061},
	{"DAINTILY", 8, 261062},
	{"BELENIX", 7, 261063},
	{"AVITAR", 6, 261064},
	{"VLADIMIROVICH", 13, 261065},
	{"PROPOSITO", 9, 261066},
	{"PIKEMEN", 7, 261067},
	{"VOTIVO", 6, 261068},
	{"DEARMOND", 8, 261069},
	{"VENEREOLOGY", 11, 261070},
	{"KDED", 4, 261071},
	{"OMIGOD", 6, 261072},
	{"INCURRENCE", 10, 261073},
	{"DIGLYCERIDES", 12, 261074},
	{"WORZEL", 6, 261075},
	{"TOXINE", 6, 261076},
	{"SHOBDON", 7, 261077},
	{"REIFSCHNEIDER", 13, 261078},
	{"GEOSCI", 6, 261079},
	{"DISBURSES", 9, 261080},
	{"BRIONI", 6, 261081},
	{"AUTOWIRED", 9, 261082},
	{"TEXICAN", 7, 261083},
	{"SPIKERS", 7, 261084},
	{"NIDHI", 5, 261085},
	{"MILSTEAD", 8, 261086},
	{"CUBING", 6, 261087},
	{"UTSTYR", 6, 261088},
	{"RIBEIRAO", 8, 261089},
	{"HYLAS", 5, 261090},
	{"NTODD", 5, 261091},
	{"MUDFLAPS", 8, 261092},
	{"CARLESS", 7, 261093},
	{"PEDREGON", 8, 261094},
	{"EPIDENDRUM", 10, 261095},
	{"PIETERSE", 8, 261096},
	{"PEDICELS", 8, 261097},
	{"FAIRWATER", 9, 261098},
	{"PASTILLES", 9, 261099},
	{"HENNEN", 6, 261100},
	{"PHPGRABCOMICS", 13, 261101},
	{"SPIROCHETES", 11, 261102},
	{"RASMUSEN", 8, 261103},
	{"PERIGUEUX", 9, 261104},
	{"MICROTURBINE", 12, 261105},
	{"GAMEFACE", 8, 261106},
	{"BIOMAGNETICS", 12, 261107},
	{"BASIT", 5, 261108},
	{"KOUWELL", 7, 261109},
	{"INTERSERVICE", 12, 261110},
	{"EFNEP", 5, 261111},
	{"KFAI", 4, 261112},
	{"CHITTERING", 10, 261113},
	{"ARRIETA", 7, 261114},
	{"NORINE", 6, 261115},
	{"KENAUK", 6, 261116},
	{"DJW", 3, 261117},
	{"CREG", 4, 261118},
	{"AYALON", 6, 261119},
	{"FINEART", 7, 261120},
	{"COLINTON", 8, 261121},
	{"TOMOMI", 6, 261122},
	{"PONEME", 6, 261123},
	{"HENLOW", 6, 261124},
	{"TIMOLEON", 8, 261125},
	{"SWAGGART", 8, 261126},
	{"PANNON", 6, 261127},
	{"USWD", 4, 261128},
	{"KDESU", 5, 261129},
	{"FORMELY", 7, 261130},
	{"STICHWORTE", 10, 261131},
	{"LMES", 4, 261132},
	{"WEATHE", 6, 261133},
	{"SUCCESSFULY", 11, 261134},
	{"METRICBIKES", 11, 261135},
	{"MAGRAM", 6, 261136},
	{"CYCLERS", 7, 261137},
	{"ATLANTAPROG", 11, 261138},
	{"SUNLINK", 7, 261139},
	{"EMAAR", 5, 261140},
	{"LICSW", 5, 261141},
	{"IFMAIL", 6, 261142},
	{"RACEMES", 7, 261143},
	{"ABQJOURNAL", 10, 261144},
	{"MDESIGN", 7, 261145},
	{"FOXIT", 5, 261146},
	{"DEINEM", 6, 261147},
	{"BURNABLE", 8, 261148},
	{"ADMINISTATION", 13, 261149},
	{"STRATEGERY", 10, 261150},
	{"RELGIOUS", 8, 261151},
	{"AMOISONIC", 9, 261152},
	{"UPGRADETWIKI", 12, 261153},
	{"SMED", 4, 261154},
	{"SIGPROCMASK", 11, 261155},
	{"MEZOTRACE", 9, 261156},
	{"DICHLORVOS", 10, 261157},
	{"XISHUANGBANNA", 13, 261158},
	{"WELLFORD", 8, 261159},
	{"TRAVELCARD", 10, 261160},
	{"PARTAGER", 8, 261161},
	{"ZOPICLONE", 9, 261162},
	{"SARDINA", 7, 261163},
	{"NOVOA", 5, 261164},
	{"NIMZO", 5, 261165},
	{"MUSICTRACKS", 11, 261166},
	{"JABAR", 5, 261167},
	{"TAMPERPROOF", 11, 261168},
	{"SKAGERRAK", 9, 261169},
	{"MINORA", 6, 261170},
	{"BOGANMELDELSER", 14, 261171},
	{"WREBBIT", 7, 261172},
	{"VERATEX", 7, 261173},
	{"IODATE", 6, 261174},
	{"ANTIPOP", 7, 261175},
	{"NETHERFIELD", 11, 261176},
	{"LAZERQUICK", 10, 261177},
	{"ENLIL", 5, 261178},
	{"DINDIGUL", 8, 261179},
	{"POUNCES", 7, 261180},
	{"DEEPDALE", 8, 261181},
	{"WELCOMEUROPE", 12, 261182},
	{"EXACTION", 8, 261183},
	{"PONDMASTER", 10, 261184},
	{"ZZBO", 4, 261185},
	{"ZRAE", 4, 261186},
	{"ZOFB", 4, 261187},
	{"ZGAN", 4, 261188},
	{"ZALP", 4, 261189},
	{"YUZT", 4, 261190},
	{"YFFE", 4, 261191},
	{"XOFJ", 4, 261192},
	{"XERG", 4, 261193},
	{"VYEL", 4, 261194},
	{"VWEB", 4, 261195},
	{"VEZB", 4, 261196},
	{"VCLI", 4, 261197},
	{"VADY", 4, 261198},
	{"UXHE", 4, 261199},
	{"ULIZ", 4, 261200},
	{"UDDP", 4, 261201},
	{"TVJO", 4, 261202},
	{"TFIZ", 4, 261203},
	{"TCMU", 4, 261204},
	{"TCJU", 4, 261205},
	{"SMEJ", 4, 261206},
	{"SKLD", 4, 261207},
	{"SFUK", 4, 261208},
	{"RZIG", 4, 261209},
	{"RPMU", 4, 261210},
	{"ROVR", 4, 261211},
	{"RLAJ", 4, 261212},
	{"RFCC", 4, 261213},
	{"RCIU", 4, 261214},
	{"PRIJ", 4, 261215},
	{"PFRU", 4, 261216},
	{"OWLK", 4, 261217},
	{"ONFX", 4, 261218},
	{"OMBJ", 4, 261219},
	{"OIPC", 4, 261220},
	{"OGCI", 4, 261221},
	{"OAZU", 4, 261222},
	{"NRUA", 4, 261223},
	{"NMCQ", 4, 261224},
	{"NJUE", 4, 261225},
	{"NIVC", 4, 261226},
	{"NIFV", 4, 261227},
	{"NDLR", 4, 261228},
	{"NCDB", 4, 261229},
	{"MEUK", 4, 261230},
	{"MDFR", 4, 261231},
	{"LORZ", 4, 261232},
	{"LLML", 4, 261233},
	{"KNUB", 4, 261234},
	{"JWOU", 4, 261235},
	{"JRSP", 4, 261236},
	{"JHOL", 4, 261237},
	{"IUPR", 4, 261238},
	{"INMV", 4, 261239},
	{"INFD", 4, 261240},
	{"HWAX", 4, 261241},
	{"HUSQ", 4, 261242},
	{"HLGE", 4, 261243},
	{"FYAW", 4, 261244},
	{"FWEY", 4, 261245},
	{"FNYC", 4, 261246},
	{"ELUH", 4, 261247},
	{"EDXR", 4, 261248},
	{"EDMH", 4, 261249},
	{"EBVE", 4, 261250},
	{"DXRE", 4, 261251},
	{"DKUA", 4, 261252},
	{"DJTH", 4, 261253},
	{"DEWD", 4, 261254},
	{"DABT", 4, 261255},
	{"BSOB", 4, 261256},
	{"BJAS", 4, 261257},
	{"BILU", 4, 261258},
	{"BBDI", 4, 261259},
	{"AZVI", 4, 261260},
	{"AMWY", 4, 261261},
	{"NEUROTRAUMA", 11, 261262},
	{"HOTSPRINGS", 10, 261263},
	{"GURUDEV", 7, 261264},
	{"DIBDEN", 6, 261265},
	{"XLPE", 4, 261266},
	{"NITRAM", 6, 261267},
	{"UNLIGHTED", 9, 261268},
	{"POSTEVENT", 9, 261269},
	{"PERIPOY", 7, 261270},
	{"COWRIES", 7, 261271},
	{"CONTAMINATIONS", 14, 261272},
	{"SAILBOARD", 9, 261273},
	{"GIBEON", 6, 261274},
	{"FINKENBERG", 10, 261275},
	{"SCIOSCIA", 8, 261276},
	{"MEHITABLE", 9, 261277},
	{"FLOWSHEET", 9, 261278},
	{"ELEANORA", 8, 261279},
	{"BEGAS", 5, 261280},
	{"POPPYSEED", 9, 261281},
	{"ISLAMIA", 7, 261282},
	{"HISTRENACT", 10, 261283},
	{"BODHIDHARMA", 11, 261284},
	{"GIMPEL", 6, 261285},
	{"FINGLOBE", 8, 261286},
	{"SANGUIS", 7, 261287},
	{"LEGACE", 6, 261288},
	{"WEDDIG", 6, 261289},
	{"RAPIERS", 7, 261290},
	{"DOUMA", 5, 261291},
	{"DOMINATRICE", 11, 261292},
	{"COMMITT", 7, 261293},
	{"ANNOG", 5, 261294},
	{"ANISMS", 6, 261295},
	{"FOCO", 4, 261296},
	{"ECLASSIFIEDS", 12, 261297},
	{"PASTERNACK", 10, 261298},
	{"CEGAS", 5, 261299},
	{"BIGDOG", 6, 261300},
	{"WASHSTAND", 9, 261301},
	{"NICIAS", 6, 261302},
	{"POLJE", 5, 261303},
	{"PENAS", 5, 261304},
	{"OVERSPREAD", 10, 261305},
	{"INSULINS", 8, 261306},
	{"HYPERICIN", 9, 261307},
	{"BRIERFIELD", 10, 261308},
	{"STEREOGRAM", 10, 261309},
	{"SHTOOL", 6, 261310},
	{"LAKHDAR", 7, 261311},
	{"ADUIT", 5, 261312},
	{"ZHONKA", 6, 261313},
	{"MANEK", 5, 261314},
	{"JEWEILS", 7, 261315},
	{"CASANDRA", 8, 261316},
	{"BILTONG", 7, 261317},
	{"ARLAN", 5, 261318},
	{"TUMULUS", 7, 261319},
	{"OCHRATOXIN", 10, 261320},
	{"METTI", 5, 261321},
	{"LANDRACE", 8, 261322},
	{"TRWVEL", 6, 261323},
	{"CANIZARES", 9, 261324},
	{"MATSUZAWA", 9, 261325},
	{"LIBEVENT", 8, 261326},
	{"KAZAKHSTANI", 11, 261327},
	{"HOTTINGER", 9, 261328},
	{"CLICKETY", 8, 261329},
	{"TECHTOOL", 8, 261330},
	{"RAQUET", 6, 261331},
	{"NEDMIRROR", 9, 261332},
	{"MCCANCE", 7, 261333},
	{"NATHANIAL", 9, 261334},
	{"MUSHA", 5, 261335},
	{"LUCZAK", 6, 261336},
	{"MADSHRIMPS", 10, 261337},
	{"CONNECTRA", 9, 261338},
	{"BOUYANCY", 8, 261339},
	{"SCENTA", 6, 261340},
	{"SAXONBURG", 9, 261341},
	{"DUNNS", 5, 261342},
	{"DEROGATING", 10, 261343},
	{"ROBBI", 5, 261344},
	{"MAPMAP", 6, 261345},
	{"LOSSE", 5, 261346},
	{"SHAFIQ", 6, 261347},
	{"NEEPER", 6, 261348},
	{"ALEEM", 5, 261349},
	{"TWIKISHORTHAND", 14, 261350},
	{"PHAETHON", 8, 261351},
	{"ENDLER", 6, 261352},
	{"CCSS", 4, 261353},
	{"STORMARE", 8, 261354},
	{"RATBAG", 6, 261355},
	{"DENNON", 6, 261356},
	{"COULTHRD", 8, 261357},
	{"UKU", 3, 261358},
	{"COMPUMENTOR", 11, 261359},
	{"INSUREANCE", 10, 261360},
	{"GINAL", 5, 261361},
	{"EMBEDMENT", 9, 261362},
	{"DBSA", 4, 261363},
	{"DELEK", 5, 261364},
	{"RECREATIONISTS", 14, 261365},
	{"PHYLON", 6, 261366},
	{"KLEENA", 6, 261367},
	{"DONAGHADEE", 10, 261368},
	{"DATABASENAME", 12, 261369},
	{"OSEPH", 5, 261370},
	{"DEALTALK", 8, 261371},
	{"CPSP", 4, 261372},
	{"TULIO", 5, 261373},
	{"PITEOUSLY", 9, 261374},
	{"KALMUS", 6, 261375},
	{"FRUSTRATORS", 11, 261376},
	{"FLUKER", 6, 261377},
	{"RANGITIKEI", 10, 261378},
	{"LARMOR", 6, 261379},
	{"LABORATORI", 10, 261380},
	{"GBPUSD", 6, 261381},
	{"PLASTICWARE", 11, 261382},
	{"HIGIENE", 7, 261383},
	{"GERAD", 5, 261384},
	{"SAHALIE", 7, 261385},
	{"METLA", 5, 261386},
	{"KAJU", 4, 261387},
	{"ALIZARIN", 8, 261388},
	{"NORMING", 7, 261389},
	{"CUCINOTTA", 9, 261390},
	{"VIRGINIS", 8, 261391},
	{"AMABILIS", 8, 261392},
	{"ACQUITTALS", 10, 261393},
	{"PRIBRAM", 7, 261394},
	{"DOREL", 5, 261395},
	{"TICKETD", 7, 261396},
	{"MCNICOL", 7, 261397},
	{"MATTHIES", 8, 261398},
	{"MDSTONE", 7, 261399},
	{"FEASABLE", 8, 261400},
	{"BREM", 4, 261401},
	{"OPENPHOTO", 9, 261402},
	{"BMWNA", 5, 261403},
	{"TOUCHLESS", 9, 261404},
	{"SAKYAMUNI", 9, 261405},
	{"POLITISCHEN", 11, 261406},
	{"MIKER", 5, 261407},
	{"LOANWORDS", 9, 261408},
	{"ECIENCY", 7, 261409},
	{"WEATHERSBY", 10, 261410},
	{"MEREWETHER", 10, 261411},
	{"LEMENT", 6, 261412},
	{"HOSPITALISTS", 12, 261413},
	{"WALLPAPERZONE", 13, 261414},
	{"COVARIATION", 11, 261415},
	{"SUPERCONDUCTIVE", 15, 261416},
	{"SARTHE", 6, 261417},
	{"LAPWORTH", 8, 261418},
	{"DIRECTPLAY", 10, 261419},
	{"TAREQ", 5, 261420},
	{"LOTREL", 6, 261421},
	{"MCGILLICUDDY", 12, 261422},
	{"MCAR", 4, 261423},
	{"MASOCHISTS", 10, 261424},
	{"KNICKKNACKS", 11, 261425},
	{"GCGCC", 5, 261426},
	{"TAGER", 5, 261427},
	{"CCOUNT", 6, 261428},
	{"BEATSON", 7, 261429},
	{"WORKCENTERS", 11, 261430},
	{"KIDJO", 5, 261431},
	{"FASTBOOT", 8, 261432},
	{"POLER", 5, 261433},
	{"MARZOLLO", 8, 261434},
	{"SOKOLOVA", 8, 261435},
	{"FONTTESTER", 10, 261436},
	{"TOEHOLD", 7, 261437},
	{"PRICKLE", 7, 261438},
	{"FOGH", 4, 261439},
	{"EBSEN", 5, 261440},
	{"WHITS", 5, 261441},
	{"TYNDAREUS", 9, 261442},
	{"SILTING", 7, 261443},
	{"RENDEMENT", 9, 261444},
	{"GULDBERG", 8, 261445},
	{"CROUCHES", 8, 261446},
	{"AUVERS", 6, 261447},
	{"GOZAR", 5, 261448},
	{"WHITESTOWN", 10, 261449},
	{"IMPLEMENATION", 13, 261450},
	{"SYNTHESISING", 12, 261451},
	{"CELEBERITY", 10, 261452},
	{"TECLADOS", 8, 261453},
	{"CHRISTLIKE", 10, 261454},
	{"BAQARAH", 7, 261455},
	{"LARGESS", 7, 261456},
	{"WEIGHTIER", 9, 261457},
	{"CECOM", 5, 261458},
	{"HMUG", 4, 261459},
	{"SOLARIZATION", 12, 261460},
	{"MONSEN", 6, 261461},
	{"KANAMORI", 8, 261462},
	{"ERTEL", 5, 261463},
	{"RATTAY", 6, 261464},
	{"CHPTR", 5, 261465},
	{"SUNBATHERS", 10, 261466},
	{"STICKIED", 8, 261467},
	{"PERSEVERES", 10, 261468},
	{"FAPESP", 6, 261469},
	{"NRTC", 4, 261470},
	{"FWG", 3, 261471},
	{"TYRER", 5, 261472},
	{"SPMS", 4, 261473},
	{"NEOVOICE", 8, 261474},
	{"MELLIEHA", 8, 261475},
	{"MATRE", 5, 261476},
	{"DAVIDEYOUNG", 11, 261477},
	{"CORMEGA", 7, 261478},
	{"TARKIN", 6, 261479},
	{"SCHLENKER", 9, 261480},
	{"DIMWITTED", 9, 261481},
	{"DATASTRUCTURES", 14, 261482},
	{"VIRULENTLY", 10, 261483},
	{"PARTICIPAT", 10, 261484},
	{"CRACE", 5, 261485},
	{"ALIZATION", 9, 261486},
	{"SCMOBJ", 6, 261487},
	{"ONEKAMA", 7, 261488},
	{"LANGUAGEHAT", 11, 261489},
	{"PICTRUE", 7, 261490},
	{"MAGHULL", 7, 261491},
	{"MACRI", 5, 261492},
	{"TATLAYOKO", 9, 261493},
	{"STARZL", 6, 261494},
	{"SLEEPAWAY", 9, 261495},
	{"PLENIPOTENTIARIES", 17, 261496},
	{"BENZIGER", 8, 261497},
	{"MUKA", 4, 261498},
	{"EITHNE", 6, 261499},
	{"ATRIUMS", 7, 261500},
	{"OVEREMPHASIS", 12, 261501},
	{"ORRINGTON", 9, 261502},
	{"ASHWINI", 7, 261503},
	{"MULTISCREEN", 11, 261504},
	{"LEAG", 4, 261505},
	{"INSENSIBLY", 10, 261506},
	{"ANGARA", 6, 261507},
	{"RAVENSDALE", 10, 261508},
	{"BRANDNAMEZ", 10, 261509},
	{"ZINGERS", 7, 261510},
	{"RNDR", 4, 261511},
	{"PORAL", 5, 261512},
	{"PHOTOCHROME", 11, 261513},
	{"CHODRON", 7, 261514},
	{"TRANSACTS", 9, 261515},
	{"TODORELATOSCOM", 14, 261516},
	{"LIEBING", 7, 261517},
	{"GLYCYRRHIZA", 11, 261518},
	{"CIDOFOVIR", 9, 261519},
	{"SNART", 5, 261520},
	{"REAWAKEN", 8, 261521},
	{"AWDRY", 5, 261522},
	{"CONTENTO", 8, 261523},
	{"PARCHMENTS", 10, 261524},
	{"MEMC", 4, 261525},
	{"HELBIG", 6, 261526},
	{"UUSI", 4, 261527},
	{"TIGERT", 6, 261528},
	{"SHOEGAZE", 8, 261529},
	{"POCKETMAC", 9, 261530},
	{"MATTIOLI", 8, 261531},
	{"EROYIC", 6, 261532},
	{"DWLRQ", 5, 261533},
	{"DBEXPRESS", 9, 261534},
	{"VLIEGTUIGEN", 11, 261535},
	{"TPAD", 4, 261536},
	{"ANTONINE", 8, 261537},
	{"REMOVEATTRIBUTE", 15, 261538},
	{"FULVA", 5, 261539},
	{"FRONTI", 6, 261540},
	{"CLEARHARMONY", 12, 261541},
	{"PROLETARIANS", 12, 261542},
	{"BEBIDAS", 7, 261543},
	{"WEERT", 5, 261544},
	{"WARBLOGGING", 11, 261545},
	{"TTAATTACHATTRIBUTE", 18, 261546},
	{"SWIZERLAND", 10, 261547},
	{"GEMSBOK", 7, 261548},
	{"DYP", 3, 261549},
	{"BORHOOD", 7, 261550},
	{"KOSTKA", 6, 261551},
	{"ENDOPTERYGOTA", 13, 261552},
	{"STOIXEIA", 8, 261553},
	{"MEADOWLAND", 10, 261554},
	{"ASHENFELTER", 11, 261555},
	{"AGUTTER", 7, 261556},
	{"ZZHE", 4, 261557},
	{"ZLIC", 4, 261558},
	{"ZCUT", 4, 261559},
	{"ZALK", 4, 261560},
	{"YUHE", 4, 261561},
	{"YKOI", 4, 261562},
	{"YAYU", 4, 261563},
	{"YAEG", 4, 261564},
	{"XYET", 4, 261565},
	{"XYAC", 4, 261566},
	{"WYRI", 4, 261567},
	{"WDAC", 4, 261568},
	{"VIWO", 4, 261569},
	{"UUTA", 4, 261570},
	{"USGH", 4, 261571},
	{"UERJ", 4, 261572},
	{"TYVU", 4, 261573},
	{"TVIJ", 4, 261574},
	{"TVCU", 4, 261575},
	{"TMUF", 4, 261576},
	{"TGOY", 4, 261577},
	{"TEVU", 4, 261578},
	{"SUAC", 4, 261579},
	{"SPWE", 4, 261580},
	{"SEFK", 4, 261581},
	{"RTZG", 4, 261582},
	{"RSWU", 4, 261583},
	{"RRME", 4, 261584},
	{"RRGA", 4, 261585},
	{"RLOZ", 4, 261586},
	{"RGBL", 4, 261587},
	{"RFIJ", 4, 261588},
	{"RDTP", 4, 261589},
	{"RCPI", 4, 261590},
	{"QDEC", 4, 261591},
	{"OYID", 4, 261592},
	{"OPYU", 4, 261593},
	{"ONWD", 4, 261594},
	{"NGWT", 4, 261595},
	{"NGLG", 4, 261596},
	{"NBUH", 4, 261597},
	{"MYEG", 4, 261598},
	{"MSLR", 4, 261599},
	{"MOEW", 4, 261600},
	{"MNPE", 4, 261601},
	{"LOBD", 4, 261602},
	{"LNRO", 4, 261603},
	{"LKGE", 4, 261604},
	{"LEPY", 4, 261605},
	{"KUSL", 4, 261606},
	{"JISR", 4, 261607},
	{"JADD", 4, 261608},
	{"HWIP", 4, 261609},
	{"HTCD", 4, 261610},
	{"HPSP", 4, 261611},
	{"HACD", 4, 261612},
	{"GMJO", 4, 261613},
	{"FYOK", 4, 261614},
	{"FUNV", 4, 261615},
	{"FEYR", 4, 261616},
	{"FALN", 4, 261617},
	{"EZSG", 4, 261618},
	{"EXYF", 4, 261619},
	{"EWFP", 4, 261620},
	{"ETZP", 4, 261621},
	{"EEKQ", 4, 261622},
	{"EEGP", 4, 261623},
	{"ECFM", 4, 261624},
	{"EAVP", 4, 261625},
	{"DTSV", 4, 261626},
	{"DNRA", 4, 261627},
	{"DMSE", 4, 261628},
	{"DEWW", 4, 261629},
	{"DETD", 4, 261630},
	{"DBFL", 4, 261631},
	{"CBWA", 4, 261632},
	{"BTEM", 4, 261633},
	{"BRUH", 4, 261634},
	{"BGAT", 4, 261635},
	{"AXSL", 4, 261636},
	{"AWEK", 4, 261637},
	{"AUEX", 4, 261638},
	{"ATDD", 4, 261639},
	{"ARHD", 4, 261640},
	{"ENDEMOL", 7, 261641},
	{"DTYPE", 5, 261642},
	{"ACCOMAC", 7, 261643},
	{"WFG", 3, 261644},
	{"SCRIPTYGODDESS", 14, 261645},
	{"MKW", 3, 261646},
	{"LAKEN", 5, 261647},
	{"SMARTBUY", 8, 261648},
	{"GRAMMATICA", 10, 261649},
	{"MASHIACH", 8, 261650},
	{"CARECODES", 9, 261651},
	{"INTSERV", 7, 261652},
	{"SELCO", 5, 261653},
	{"DISCHARGEABLE", 13, 261654},
	{"CYRRAEDD", 8, 261655},
	{"COLONIZER", 9, 261656},
	{"SHWING", 6, 261657},
	{"HLTV", 4, 261658},
	{"EXECUTESYNCIMPL", 15, 261659},
	{"ERESEARCH", 9, 261660},
	{"ARHOOLIE", 8, 261661},
	{"ANISTONS", 8, 261662},
	{"RENCES", 6, 261663},
	{"OYLY", 4, 261664},
	{"LYST", 4, 261665},
	{"GROSSA", 6, 261666},
	{"DORAS", 5, 261667},
	{"TRACON", 6, 261668},
	{"TACTS", 5, 261669},
	{"MASKIN", 6, 261670},
	{"ISOLATIE", 8, 261671},
	{"GODCHILD", 8, 261672},
	{"FACILTY", 7, 261673},
	{"SOURCINGPARTS", 13, 261674},
	{"BEARSVILLE", 10, 261675},
	{"OBSTRUCTIONISM", 14, 261676},
	{"LOVATO", 6, 261677},
	{"LANGUISHES", 10, 261678},
	{"VINCENTELLI", 11, 261679},
	{"SCOTCHMAN", 9, 261680},
	{"MOUNTIANS", 9, 261681},
	{"GETPOSITION", 11, 261682},
	{"DOJOS", 5, 261683},
	{"DEWEES", 6, 261684},
	{"SPECFORCE", 9, 261685},
	{"SPANKER", 7, 261686},
	{"HASSIDIC", 8, 261687},
	{"CONINGSBY", 9, 261688},
	{"BOOGY", 5, 261689},
	{"ZORAK", 5, 261690},
	{"NOMAN", 5, 261691},
	{"FFMPEGVIDEO", 11, 261692},
	{"SASTRA", 6, 261693},
	{"GUESTLISTS", 10, 261694},
	{"ARCADY", 6, 261695},
	{"POCHETTES", 9, 261696},
	{"TERNET", 6, 261697},
	{"SHANGRILA", 9, 261698},
	{"MUNCHIE", 7, 261699},
	{"CUTWORMS", 8, 261700},
	{"UPHOLSTERING", 12, 261701},
	{"BROCHU", 6, 261702},
	{"BENAHAVIS", 9, 261703},
	{"SNOWBLOOD", 9, 261704},
	{"SNAPSHOTZ", 9, 261705},
	{"REPOUSSE", 8, 261706},
	{"LAMBASTING", 10, 261707},
	{"INGRATIATING", 12, 261708},
	{"VDMA", 4, 261709},
	{"YOMEGA", 6, 261710},
	{"ENGBERG", 7, 261711},
	{"BREAULT", 7, 261712},
	{"ZAYD", 4, 261713},
	{"MODIFICAR", 9, 261714},
	{"HOLLMAN", 7, 261715},
	{"BONADUCE", 8, 261716},
	{"BEEST", 5, 261717},
	{"BAIRN", 5, 261718},
	{"VEINING", 7, 261719},
	{"YAWNER", 6, 261720},
	{"STOLLEN", 7, 261721},
	{"PUNDA", 5, 261722},
	{"POISONER", 8, 261723},
	{"CARREG", 6, 261724},
	{"SABELT", 6, 261725},
	{"ORAVA", 5, 261726},
	{"NCPI", 4, 261727},
	{"LEUKODYSTROPHY", 14, 261728},
	{"ICONCOOL", 8, 261729},
	{"CASHABLE", 8, 261730},
	{"HISTORYKILL", 11, 261731},
	{"GLORSCLAWS", 10, 261732},
	{"GLENMORANGIE", 12, 261733},
	{"DEBA", 4, 261734},
	{"RHOGAM", 6, 261735},
	{"MILERS", 6, 261736},
	{"HOMESUITES", 10, 261737},
	{"AGUSTINA", 8, 261738},
	{"HIETANIEMI", 10, 261739},
	{"SEMALE", 6, 261740},
	{"SCHINKEL", 8, 261741},
	{"PHONEISDNWIRELESS", 17, 261742},
	{"HETMAN", 6, 261743},
	{"GLOBECOM", 8, 261744},
	{"COPPERHEADS", 11, 261745},
	{"RETICULATE", 10, 261746},
	{"MOOLA", 5, 261747},
	{"FRENCE", 6, 261748},
	{"VIDLER", 6, 261749},
	{"VERDELHO", 8, 261750},
	{"GIRDLER", 7, 261751},
	{"DSDT", 4, 261752},
	{"WERKZEUGE", 9, 261753},
	{"ELGON", 5, 261754},
	{"HEALTHBOARDS", 12, 261755},
	{"ARISAEMA", 8, 261756},
	{"WAURIKA", 7, 261757},
	{"PPTPD", 5, 261758},
	{"KODAKA", 6, 261759},
	{"KIMBRO", 6, 261760},
	{"GEODYNAMIC", 10, 261761},
	{"SHETTLESTON", 11, 261762},
	{"POWERFLEX", 9, 261763},
	{"BITOLA", 6, 261764},
	{"PSICOLOGO", 9, 261765},
	{"FLERA", 5, 261766},
	{"TZADDIK", 7, 261767},
	{"TENKO", 5, 261768},
	{"RENFORCEMENT", 12, 261769},
	{"SETTY", 5, 261770},
	{"CONTINENTIAL", 12, 261771},
	{"CCMC", 4, 261772},
	{"BLANKA", 6, 261773},
	{"YOUNGISH", 8, 261774},
	{"WANKEL", 6, 261775},
	{"TAKAKA", 6, 261776},
	{"MIDCONTINENT", 12, 261777},
	{"DELOCALIZED", 11, 261778},
	{"UPED", 4, 261779},
	{"POSSIBILI", 9, 261780},
	{"PINCE", 5, 261781},
	{"NANAMI", 6, 261782},
	{"AGONISTES", 9, 261783},
	{"PAREOS", 6, 261784},
	{"HOLTMAN", 7, 261785},
	{"GRADUA", 6, 261786},
	{"DELEGATOR", 9, 261787},
	{"MACDESKTOPS", 11, 261788},
	{"LAVALIN", 7, 261789},
	{"HOELLER", 7, 261790},
	{"TURMEL", 6, 261791},
	{"SCORPIONFISH", 12, 261792},
	{"HOURIHAN", 8, 261793},
	{"SCHURMAN", 8, 261794},
	{"VERINT", 6, 261795},
	{"TEXIER", 6, 261796},
	{"SOUFFLES", 8, 261797},
	{"RUDDICK", 7, 261798},
	{"PUPPYS", 6, 261799},
	{"LOOKATMUSIC", 11, 261800},
	{"SLYDER", 6, 261801},
	{"HUGES", 5, 261802},
	{"ROUCH", 5, 261803},
	{"PLIB", 4, 261804},
	{"DERIVATIZED", 11, 261805},
	{"MURREN", 6, 261806},
	{"RAQUETTE", 8, 261807},
	{"HAILSTONE", 9, 261808},
	{"EXSIST", 6, 261809},
	{"CYTOSTATIC", 10, 261810},
	{"PRODIGIOUSLY", 12, 261811},
	{"LANGUR", 6, 261812},
	{"HYPOTHESIZES", 12, 261813},
	{"TAMANHO", 7, 261814},
	{"INFLAMATORY", 11, 261815},
	{"IDTECH", 6, 261816},
	{"NCPAD", 5, 261817},
	{"HANSENII", 8, 261818},
	{"FALLACI", 7, 261819},
	{"CYTOPATHIC", 10, 261820},
	{"LYRICSCLAN", 10, 261821},
	{"GOOFLE", 6, 261822},
	{"DRANE", 5, 261823},
	{"HDRI", 4, 261824},
	{"UNERRINGLY", 10, 261825},
	{"DIAMELLE", 8, 261826},
	{"INCONVENIENTLY", 14, 261827},
	{"ACTRA", 5, 261828},
	{"HUNTERIAN", 9, 261829},
	{"FALUDI", 6, 261830},
	{"FACETIME", 8, 261831},
	{"QUALM", 5, 261832},
	{"GEISTESWISSENSCHAFTEN", 21, 261833},
	{"DORCY", 5, 261834},
	{"DOBLER", 6, 261835},
	{"CRUSHABLE", 9, 261836},
	{"BRONDESBURY", 11, 261837},
	{"AQUEL", 5, 261838},
	{"ALIBRE", 6, 261839},
	{"PRAZE", 5, 261840},
	{"LIVERWORT", 9, 261841},
	{"GUARDE", 6, 261842},
	{"NIKOLAEVICH", 11, 261843},
	{"JSED", 4, 261844},
	{"WHITEMARSH", 10, 261845},
	{"SILVERSMITHING", 14, 261846},
	{"RAINSFORD", 9, 261847},
	{"YEASTY", 6, 261848},
	{"VEFAS", 5, 261849},
	{"PYTHO", 5, 261850},
	{"POSTCOLONIALISM", 15, 261851},
	{"GAMEPUBLIC", 10, 261852},
	{"GAIRDNER", 8, 261853},
	{"BOLTFOLIO", 9, 261854},
	{"KRINSKY", 7, 261855},
	{"CARIBSEEK", 9, 261856},
	{"TURBOCHARGING", 13, 261857},
	{"TIZARD", 6, 261858},
	{"SCPC", 4, 261859},
	{"SCHAIBLE", 8, 261860},
	{"JEANSWEAR", 9, 261861},
	{"HOMAGES", 7, 261862},
	{"JENNEY", 6, 261863},
	{"STIEGLER", 8, 261864},
	{"PIZZ", 4, 261865},
	{"NCCAA", 5, 261866},
	{"DILEPTON", 8, 261867},
	{"COPPINGER", 9, 261868},
	{"CASSI", 5, 261869},
	{"SUJATHA", 7, 261870},
	{"PLEP", 4, 261871},
	{"BAGGOTT", 7, 261872},
	{"RULAND", 6, 261873},
	{"NONCONVENTIONAL", 15, 261874},
	{"INTERVET", 8, 261875},
	{"BIGSTEP", 7, 261876},
	{"METHOCARBAMOL", 13, 261877},
	{"KSFO", 4, 261878},
	{"ANDW", 4, 261879},
	{"AERNET", 6, 261880},
	{"SONICATED", 9, 261881},
	{"FOREWARNING", 11, 261882},
	{"SIGNSEARCH", 10, 261883},
	{"JUICIEST", 8, 261884},
	{"INTRAV", 6, 261885},
	{"EPOZ", 4, 261886},
	{"SUSCRIBIENDO", 12, 261887},
	{"OXBLOOD", 7, 261888},
	{"MARSEILLAISE", 12, 261889},
	{"NOORDAM", 7, 261890},
	{"MARYKAY", 7, 261891},
	{"SALLALLAAHU", 11, 261892},
	{"HEMATOMAS", 9, 261893},
	{"FORTEPIANO", 10, 261894},
	{"DEGR", 4, 261895},
	{"COXES", 5, 261896},
	{"ARNOS", 5, 261897},
	{"STREICH", 7, 261898},
	{"GARC", 4, 261899},
	{"BUFID", 5, 261900},
	{"SPEECHTEK", 9, 261901},
	{"OLTSIK", 6, 261902},
	{"KAUA", 4, 261903},
	{"FIGEAC", 6, 261904},
	{"LINKOV", 6, 261905},
	{"UNCHARITABLE", 12, 261906},
	{"CORPERATION", 11, 261907},
	{"FLUORSPAR", 9, 261908},
	{"STUBBINGS", 9, 261909},
	{"BESTIMMUNG", 10, 261910},
	{"ARTICULATELY", 12, 261911},
	{"ALBUMALBUM", 10, 261912},
	{"INCHWORM", 8, 261913},
	{"HAIRBALLS", 9, 261914},
	{"ALBOX", 5, 261915},
	{"MISSLER", 7, 261916},
	{"TEXASBESTGROK", 13, 261917},
	{"LIBTW", 5, 261918},
	{"DEERBROOK", 9, 261919},
	{"YAWKEY", 6, 261920},
	{"WONDERFOOLS", 11, 261921},
	{"MELWAY", 6, 261922},
	{"DIETRICK", 8, 261923},
	{"CAFENET", 7, 261924},
	{"PRATLEY", 7, 261925},
	{"COCTAIL", 7, 261926},
	{"CICHLIDAE", 9, 261927},
	{"STAIRLIFT", 9, 261928},
	{"CASTIGATE", 9, 261929},
	{"SHINGLETOWN", 11, 261930},
	{"OUSIDE", 6, 261931},
	{"OPERCULUM", 9, 261932},
	{"MELEON", 6, 261933},
	{"AUBER", 5, 261934},
	{"SMARTIE", 7, 261935},
	{"MAGNASONIC", 10, 261936},
	{"ZZAK", 4, 261937},
	{"ZUBO", 4, 261938},
	{"ZITW", 4, 261939},
	{"YSPC", 4, 261940},
	{"YAIB", 4, 261941},
	{"XWEI", 4, 261942},
	{"XFIX", 4, 261943},
	{"WLIQ", 4, 261944},
	{"VQUI", 4, 261945},
	{"VOSM", 4, 261946},
	{"VIKK", 4, 261947},
	{"VBEA", 4, 261948},
	{"UPHY", 4, 261949},
	{"TKIF", 4, 261950},
	{"TJEP", 4, 261951},
	{"TIZD", 4, 261952},
	{"TFIJ", 4, 261953},
	{"SSRM", 4, 261954},
	{"SLWH", 4, 261955},
	{"RWIJ", 4, 261956},
	{"RUXE", 4, 261957},
	{"RMMR", 4, 261958},
	{"RLRU", 4, 261959},
	{"RIEQ", 4, 261960},
	{"RCOZ", 4, 261961},
	{"PEWC", 4, 261962},
	{"PEIU", 4, 261963},
	{"OYZI", 4, 261964},
	{"OSZC", 4, 261965},
	{"ONWK", 4, 261966},
	{"OLYQ", 4, 261967},
	{"OGEB", 4, 261968},
	{"OBGU", 4, 261969},
	{"OACD", 4, 261970},
	{"NWUR", 4, 261971},
	{"NWIV", 4, 261972},
	{"NTFD", 4, 261973},
	{"NOVJ", 4, 261974},
	{"NGHV", 4, 261975},
	{"MGTO", 4, 261976},
	{"LNGP", 4, 261977},
	{"LGUM", 4, 261978},
	{"KRTH", 4, 261979},
	{"JSBA", 4, 261980},
	{"JOSQ", 4, 261981},
	{"JAXC", 4, 261982},
	{"IZFE", 4, 261983},
	{"IRJI", 4, 261984},
	{"IEUG", 4, 261985},
	{"HMMO", 4, 261986},
	{"HEMZ", 4, 261987},
	{"GUGI", 4, 261988},
	{"GPSF", 4, 261989},
	{"GDWI", 4, 261990},
	{"GBST", 4, 261991},
	{"GAIB", 4, 261992},
	{"FYGE", 4, 261993},
	{"FJUG", 4, 261994},
	{"FCUC", 4, 261995},
	{"ELBW", 4, 261996},
	{"EHLM", 4, 261997},
	{"EDVM", 4, 261998},
	{"EBSR", 4, 261999},
	{"EBMX", 4, 262000},
	{"DURV", 4, 262001},
	{"DTDO", 4, 262002},
	{"DPAF", 4, 262003},
	{"DLRE", 4, 262004},
	{"CSUT", 4, 262005},
	{"CIUN", 4, 262006},
	{"CHUZ", 4, 262007},
	{"BYUG", 4, 262008},
	{"BRNN", 4, 262009},
	{"BNCH", 4, 262010},
	{"BKNE", 4, 262011},
	{"AWIV", 4, 262012},
	{"RKWDL", 5, 262013},
	{"TTANEWATTRIBUTE", 15, 262014},
	{"MANITOWISH", 10, 262015},
	{"MCCOTTER", 8, 262016},
	{"HYPOPARATHYROIDISM", 18, 262017},
	{"GETMETHOD", 9, 262018},
	{"CSUX", 4, 262019},
	{"CONSTA", 6, 262020},
	{"SPRG", 4, 262021},
	{"SCHWING", 7, 262022},
	{"RESHMA", 6, 262023},
	{"OULUN", 5, 262024},
	{"MULTIPHYSICS", 12, 262025},
	{"LYNGEMARK", 9, 262026},
	{"FIXATOR", 7, 262027},
	{"VINY", 4, 262028},
	{"MELLES", 6, 262029},
	{"COSES", 5, 262030},
	{"CHAINES", 7, 262031},
	{"ACOUSTIQUE", 10, 262032},
	{"MARKETPLACEJOBSCARSREAL", 23, 262033},
	{"LOANHEAD", 8, 262034},
	{"CRMC", 4, 262035},
	{"COMPACTIFIED", 12, 262036},
	{"ABIDIN", 6, 262037},
	{"MACTUTOR", 8, 262038},
	{"JELGAVA", 7, 262039},
	{"HAMLEY", 6, 262040},
	{"GCIS", 4, 262041},
	{"VOORHIES", 8, 262042},
	{"PNTABLE", 7, 262043},
	{"PAGEREF", 7, 262044},
	{"LICHTY", 6, 262045},
	{"DDWEUD", 6, 262046},
	{"SHIFTLESS", 9, 262047},
	{"ORACLEAS", 8, 262048},
	{"BEDEVERE", 8, 262049},
	{"VEESHAN", 7, 262050},
	{"SKORTON", 7, 262051},
	{"OLIVIERO", 8, 262052},
	{"NORMATIVELY", 11, 262053},
	{"LINEARIS", 8, 262054},
	{"BROOKNER", 8, 262055},
	{"VISAGES", 7, 262056},
	{"DAZEY", 5, 262057},
	{"COLVARD", 7, 262058},
	{"BBIG", 4, 262059},
	{"SCATOLOGICAL", 12, 262060},
	{"LEGITIMIZATION", 14, 262061},
	{"TRUEAIR", 7, 262062},
	{"SOBRAN", 6, 262063},
	{"NHCD", 4, 262064},
	{"LAML", 4, 262065},
	{"FILEFIND", 8, 262066},
	{"CWTS", 4, 262067},
	{"ARUNDINACEA", 11, 262068},
	{"ONDERWERPEN", 11, 262069},
	{"HEXAMER", 7, 262070},
	{"DIVORZIO", 8, 262071},
	{"DISOLVE", 7, 262072},
	{"ALMUDENA", 8, 262073},
	{"IMAGEICON", 9, 262074},
	{"ZXK", 3, 262075},
	{"ZVK", 3, 262076},
	{"ZJK", 3, 262077},
	{"ZJF", 3, 262078},
	{"XRQ", 3, 262079},
	{"XPZ", 3, 262080},
	{"XKJ", 3, 262081},
	{"VZY", 3, 262082},
	{"VVQ", 3, 262083},
	{"VCQ", 3, 262084},
	{"UQZ", 3, 262085},
	{"UQY", 3, 262086},
	{"QKK", 3, 262087},
	{"QGK", 3, 262088},
	{"QGF", 3, 262089},
	{"QFQ", 3, 262090},
	{"JZP", 3, 262091},
	{"JXB", 3, 262092},
	{"JCX", 3, 262093},
	{"FQJ", 3, 262094},
	{"CXQ", 3, 262095},
	{"CWZ", 3, 262096},
	{"BQV", 3, 262097},
	{"SUBJOINED", 9, 262098},
	{"MUGUR", 5, 262099},
	{"LABOVITZ", 8, 262100},
	{"ESTATESHOPPING", 14, 262101},
	{"BLAEN", 5, 262102},
	{"SONDHI", 6, 262103},
	{"POLSKY", 6, 262104},
	{"MACHINEGUNS", 11, 262105},
	{"JGC", 3, 262106},
	{"HITOTSUBASHI", 12, 262107},
	{"HANDFORTH", 9, 262108},
	{"EMANUELLE", 9, 262109},
	{"EBERLEIN", 8, 262110},
	{"TRADESCANTIA", 12, 262111},
	{"RETAMA", 6, 262112},
	{"BOEKRECENSIES", 13, 262113},
	{"CARTMELL", 8, 262114},
	{"TRACID", 6, 262115},
	{"SONSHINE", 8, 262116},
	{"SANDBOXES", 9, 262117},
	{"NOWFREE", 7, 262118},
	{"ESLINGER", 8, 262119},
	{"PUECH", 5, 262120},
	{"GOROKA", 6, 262121},
	{"FOSC", 4, 262122},
	{"PCQUEST", 7, 262123},
	{"ENVIROMENTS", 11, 262124},
	{"OIKONOMIAS", 10, 262125},
	{"CHILDNODES", 10, 262126},
	{"BASSLER", 7, 262127},
	{"SPEEDCOM", 8, 262128},
	{"MENSE", 5, 262129},
	{"CORALLO", 7, 262130},
	{"YILDIRIM", 8, 262131},
	{"HILTY", 5, 262132},
	{"CSID", 4, 262133},
	{"BLUECOAT", 8, 262134},
	{"BATCO", 5, 262135},
	{"MUSICSPACE", 10, 262136},
	{"DARKWATER", 9, 262137},
	{"TEMPLER", 7, 262138},
	{"NONBUILDING", 11, 262139},
	{"YANAI", 5, 262140},
	{"YOGIBEAR", 8, 262141},
	{"UWED", 4, 262142},
    {"ROSIDS", 1, 262143},
};
